(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  18897653,    1841924]*)
(*NotebookOutlinePosition[  18898708,    1841960]*)
(*  CellTagsIndexPosition[  18898664,    1841956]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[TextData[{
  StyleBox[
  "John E. Everett and Joel M. Weisberg\nCarleton College Department of \
Physics and Astronomy\neverettj, jweisber@carleton.edu\n",
    Evaluatable->False,
    TextAlignment->Right,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["Last Revision: August 1, 1995\n",
    Evaluatable->False,
    TextAlignment->Right,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}]
}], "Text",
  Evaluatable->False,
  TextAlignment->Right,
  AspectRatioFixed->True,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{Cell[TextData["The Free Precession of an Oblate Star"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tConsider an axially symmetric oblate object, e.g. a star, spinning about \
an axis that is not its symmetry axis.  It can be shown (as in mechanics \
texts by Baierlein and Marion) that this object will undergo  \"free\" \
precession: a phenomenon that occurs in the absence of external influences."],
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tOur purpose with this notebook is to build an animation sequence that will \
show us how the star moves when undergoing free precession.  Not only do we \
want to be able to see how the star is moving, but we also want to see how \
the symmetry axis of the body moves, and how an arbitrarily placed vector on \
the surface of that star moves.  This arbitrary vector could, for example, \
represent the linearly polarized emission in the radio beam emitted from a \
pulsar. \n\tWe'll define our arbitrary vector as a unit vector with \
colatitude alpha with respect to the symmetry axis and longitude beta.  This \
is an elaboration of Shaham, J, 1986, ApJ, 310, 780, \"Free Precesion in \
Quasi-Periodic Oscillators\""], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tFirst, we clear out some of the variables we'll be using, to insure that \
previous definitions or values do not interfere with this notebook."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[xcomp, ycomp, zcomp, alpha, beta, omegap, omega, theta];"], "Input",
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Equations of Motion in an Inertial Frame"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "\tIn deriving the equations of motion, we recall that in free precession, \
there are no ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["external",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " torques at work on the star, and this means that the total angular \
momentum vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", is constant in magnitude and direction. It can be shown that the \
symmetry axis, offset an angle theta from ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", precesses around ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" along a fixed cone of half-angle theta and rotating about ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " with an angular frequency of omega.  Omega is defined in the direction of \
",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", while the angular frequency of precession, which we'll call omegap, is \
defined in the direction of the symmetry axis, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ".  As Mr. Shaham points out, the motion of the star \"is basically a \
rotation at omega around ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", plus a rotation about the symmetry axis at -omegap.\"  \n\tIn addition \
to the motion of the star itself, it is interesting to observe the motion of \
a point on the star.  While many mechanics texts carefully analyze the \
general motion of the star in both corotating and inertial frames, rarely is \
the motion of a ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["point",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " on the body discussed.   Because it was difficult for us to visualize the \
motion of a particular point on the star, we developed this notebook, which \
addresses this motion in order to study the behavior of a pulsar emission \
beam.\n\tThe arbitrary unit vector (which can be considered , for example, to \
be the pulsar emission beam).on the star that we follow has colatitude alpha \
and longitude beta, and the coordinates:\n\t\n\t\t\t",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" = ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" cos ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["\[Alpha]",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" cos ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["\[Beta]",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" + ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["j",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" cos ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["\[Alpha]",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" sin ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["\[Beta]",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" + ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" sin ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["\[Alpha]",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["\n\t\n\twhere ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["j",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" are a system of axes tied to the star. The vector ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" is the symmetry axis of the star, while ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["j",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" are two vectors orthogonal to ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ".  The colatitude, alpha, is measured with respect to the the symmetry \
axis, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", while the longitude, beta, is the angle measured around ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" from the ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["i-k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " plane to our arbitrary vector. \n\tThe equations of motion are derived \
similarly to Shaham, except that we have added the longitude, beta.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"arbVectorX[t_, alpha_, beta_, omegap_, omega_, theta_] :=\n\t\t(Cos[beta] \
Cos[alpha]) * (Cos[omegap t] Cos[omega t] + \n\t\t Cos[theta] Sin[omegap t] \
Sin[omega t]) + \n\t\t(Sin[beta] Cos[alpha]) * (Sin[omegap t] Cos[omega t] - \
\n\t\t Cos[theta] Cos[omegap t] Sin[omega t]) - \n\t\t(Sin[alpha]) * \
(Sin[theta] Sin[omega t]);\narbVectorY[t_, alpha_, beta_, omegap_, omega_, \
theta_] :=\n\t\t(Cos[beta] Cos[alpha]) * (Cos[omegap t] Sin[omega t] - \n\t\t \
Cos[theta] Sin[omegap t] Cos[omega t]) + \n\t\t(Sin[beta] Cos[alpha]) * \
(Sin[omegap t] Sin[omega t] + \n\t\t Cos[theta] Cos[omegap t] Cos[omega t]) + \
\n\t\t(Sin[alpha]) * (Sin[theta] Cos[omega t]);\narbVectorZ[t_, alpha_, \
beta_, omegap_, omega_, theta_] :=\n\t\t(Cos[beta] Cos[alpha]) * (Sin[omegap \
t] Sin[theta]) - \n\t\t(Sin[beta] Cos[alpha]) * (Cos[omegap t] Sin[theta]) + \
\n\t\t(Sin[alpha] * Cos[theta]);"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"arbVector[t_, alpha_, beta_, omegap_, omega_, theta_] :=\n\t\t{arbVectorX[t, \
beta, alpha, omegap, omega, theta], \n\t\t arbVectorY[t, beta, alpha, omegap, \
omega, theta], \n\t\t arbVectorZ[t, beta, alpha, omegap, omega, theta]};"], 
  "Input",
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData[" Building the Program"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tOur main goal here is to build up a series of plots showing how the star \
and various vectors on it might be oriented in an inertial frame as time goes \
on.  As the star precesses, it is going to be rotating as well as moving back \
and forth, and while all of this is going on,we'll be trying to watch and \
sort out what is happening.   "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Some Constants"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tHere we define and specify values for some constants that we shall use:"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"theta = Pi/10;     (* precession cone half-angle -- *)\n\t\t\t\t   (*   \
(angle between the symmetry axis k and the total *)\n\t\t\t\t   (*    angular \
momentum vector L) *)\nbeta  = Pi/5;      (* longitude from the i-k plane*)\n\
alpha = Pi/7;      (* colatitude from symmetry axis*)\nomegap = 10;       (* \
precession frequency *)\nomega  = 100;      (* rotation frequency *)"], 
  "Input",
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Precession Cone"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "\tWe really need a stationary reference, by which we can judge the motion \
of everything else on the star and even the star itself.  Such a constant \
reference is the cone traced out by the symmetry axis of the star as it \
\.05spins around the angular momentum vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ".  Here we define the precession cone, or the cone that symmetry axis, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", describes around the total angular momentum vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["L",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData[
"cone = ParametricPlot3D[{h Sin[theta] Cos[t], \n\t\t\t\t\t\t\th Sin[theta] \
Sin[t], h Cos[theta]}, \n\t\t\t\t\t\t{t, 0, 2 Pi}, {h, 0.8, 1.3}, \n\t\t\t\t\t\
\tShading -> False];\n\t\t\t\t\t\t"], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91004 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0249602 0.998408 0.00291114 0.998408 [
[(-0.4)] .07786 .25163 1 .97024 Msboxa
[(-0.2)] .20876 .19886 .93566 1 Msboxa
[(0)] .34716 .14308 .84066 1 Msboxa
[(0.2)] .49373 .08404 .74565 1 Msboxa
[(0.4)] .64921 .02146 .65064 1 Msboxa
[(-0.4)] .69266 .03239 -1 .39841 Msboxa
[(-0.2)] .7641 .14404 -1 .37239 Msboxa
[(0)] .82837 .24452 -1 .34956 Msboxa
[(0.2)] .8865 .3354 -1 .32936 Msboxa
[(0.4)] .93933 .41801 -1 .31138 Msboxa
[(0.8)] .06017 .29925 1 -0.39524 Msboxa
[(0.9)] .05046 .36024 1 -0.383 Msboxa
[(1)] .04032 .42389 1 -0.37017 Msboxa
[(1.1)] .02973 .49039 1 -0.35672 Msboxa
[(1.2)] .01865 .55992 1 -0.34258 Msboxa
[ 0 0 0 0 ]
[ 1 .91004 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.07656 .26444 m
.67336 .02496 L
s
P
p
.002 w
.08681 .26032 m
.09129 .26467 L
s
P
[(-0.4)] .07786 .25163 1 .97024 Mshowa
p
.002 w
.21728 .20797 m
.22155 .21253 L
s
P
[(-0.2)] .20876 .19886 .93566 1 Mshowa
p
.002 w
.35519 .15263 m
.3592 .15741 L
s
P
[(0)] .34716 .14308 .84066 1 Mshowa
p
.002 w
.50119 .09405 m
.50492 .09905 L
s
P
[(0.2)] .49373 .08404 .74565 1 Mshowa
p
.002 w
.65602 .03192 m
.65942 .03715 L
s
P
[(0.4)] .64921 .02146 .65064 1 Mshowa
p
.001 w
.11234 .25008 m
.115 .25271 L
s
P
p
.001 w
.13815 .23972 m
.14078 .24238 L
s
P
p
.001 w
.16424 .22925 m
.16685 .23194 L
s
P
p
.001 w
.19061 .21867 m
.1932 .22138 L
s
P
p
.001 w
.24425 .19715 m
.24678 .19991 L
s
P
p
.001 w
.27152 .18621 m
.27402 .18899 L
s
P
p
.001 w
.29909 .17514 m
.30156 .17795 L
s
P
p
.001 w
.32698 .16395 m
.32942 .16679 L
s
P
p
.001 w
.38372 .14118 m
.3861 .14408 L
s
P
p
.001 w
.41258 .1296 m
.41492 .13252 L
s
P
p
.001 w
.44177 .11789 m
.44408 .12083 L
s
P
p
.001 w
.47131 .10604 m
.47358 .10901 L
s
P
p
.001 w
.53142 .08191 m
.53362 .08494 L
s
P
p
.001 w
.56202 .06964 m
.56418 .07269 L
s
P
p
.001 w
.59298 .05721 m
.5951 .0603 L
s
P
p
.001 w
.62431 .04464 m
.62639 .04775 L
s
P
P
p
p
.002 w
.67336 .02496 m
.93252 .42969 L
s
P
p
.002 w
.68107 .037 m
.67527 .03931 L
s
P
[(-0.4)] .69266 .03239 -1 .39841 Mshowa
p
.002 w
.7524 .1484 m
.74655 .15058 L
s
P
[(-0.2)] .7641 .14404 -1 .37239 Mshowa
p
.002 w
.81659 .24863 m
.81069 .25069 L
s
P
[(0)] .82837 .24452 -1 .34956 Mshowa
p
.002 w
.87465 .3393 m
.86872 .34126 L
s
P
[(0.2)] .8865 .3354 -1 .32936 Mshowa
p
.002 w
.92742 .42172 m
.92146 .42357 L
s
P
[(0.4)] .93933 .41801 -1 .31138 Mshowa
p
.001 w
.69596 .06026 m
.69248 .06163 L
s
P
p
.001 w
.71053 .08302 m
.70704 .08437 L
s
P
p
.001 w
.72479 .10528 m
.72129 .10662 L
s
P
p
.001 w
.73874 .12707 m
.73524 .12839 L
s
P
p
.001 w
.76577 .16928 m
.76226 .17058 L
s
P
p
.001 w
.77887 .18974 m
.77535 .19101 L
s
P
p
.001 w
.7917 .20977 m
.78817 .21103 L
s
P
p
.001 w
.80427 .2294 m
.80074 .23065 L
s
P
p
.001 w
.82866 .26749 m
.82512 .26871 L
s
P
p
.001 w
.84049 .28597 m
.83695 .28718 L
s
P
p
.001 w
.8521 .30409 m
.84855 .30529 L
s
P
p
.001 w
.86348 .32187 m
.85993 .32305 L
s
P
p
.001 w
.8856 .35641 m
.88204 .35757 L
s
P
p
.001 w
.89635 .37319 m
.89278 .37434 L
s
P
p
.001 w
.9069 .38967 m
.90333 .3908 L
s
P
p
.001 w
.91725 .40584 m
.91368 .40696 L
s
P
P
p
p
.002 w
.07656 .26444 m
.02496 .59065 L
s
P
p
.002 w
.07178 .29466 m
.07758 .29236 L
s
P
[(0.8)] .06017 .29925 1 -0.39524 Mshowa
p
.002 w
.06211 .35578 m
.06794 .35354 L
s
P
[(0.9)] .05046 .36024 1 -0.383 Mshowa
p
.002 w
.05202 .41956 m
.05787 .4174 L
s
P
[(1)] .04032 .42389 1 -0.37017 Mshowa
p
.002 w
.04148 .4862 m
.04736 .4841 L
s
P
[(1.1)] .02973 .49039 1 -0.35672 Mshowa
p
.002 w
.03046 .55587 m
.03636 .55385 L
s
P
[(1.2)] .01865 .55992 1 -0.34258 Mshowa
p
.001 w
.06988 .30668 m
.07336 .30531 L
s
P
p
.001 w
.06796 .3188 m
.07145 .31743 L
s
P
p
.001 w
.06603 .33102 m
.06952 .32966 L
s
P
p
.001 w
.06408 .34334 m
.06757 .342 L
s
P
p
.001 w
.06013 .36831 m
.06363 .36698 L
s
P
p
.001 w
.05813 .38096 m
.06163 .37964 L
s
P
p
.001 w
.05611 .39372 m
.05962 .3924 L
s
P
p
.001 w
.05407 .40658 m
.05758 .40528 L
s
P
p
.001 w
.04995 .43266 m
.05346 .43136 L
s
P
p
.001 w
.04786 .44586 m
.05138 .44458 L
s
P
p
.001 w
.04575 .45919 m
.04927 .45791 L
s
P
p
.001 w
.04363 .47263 m
.04715 .47137 L
s
P
p
.001 w
.03932 .49988 m
.04285 .49863 L
s
P
p
.001 w
.03713 .51369 m
.04067 .51245 L
s
P
p
.001 w
.03493 .52762 m
.03847 .52639 L
s
P
p
.001 w
.03271 .54169 m
.03624 .54046 L
s
P
p
.001 w
.07366 .28274 m
.07714 .28136 L
s
P
p
.001 w
.07553 .27092 m
.07901 .26953 L
s
P
p
.001 w
.0282 .57019 m
.03174 .56899 L
s
P
p
.001 w
.02591 .58464 m
.02946 .58345 L
s
P
P
0 0 m
1 0 L
1 .91004 L
0 .91004 L
closepath
clip
newpath
p
.002 w
.07656 .26444 m
.02496 .59065 L
s
.02496 .59065 m
.40442 .88508 L
s
.40442 .88508 m
.41466 .59005 L
s
.41466 .59005 m
.07656 .26444 L
s
.67336 .02496 m
.93252 .42969 L
s
.93252 .42969 m
.97504 .74153 L
s
.97504 .74153 m
.69303 .36652 L
s
.69303 .36652 m
.67336 .02496 L
s
.07656 .26444 m
.02496 .59065 L
s
.02496 .59065 m
.69303 .36652 L
s
.69303 .36652 m
.67336 .02496 L
s
.67336 .02496 m
.07656 .26444 L
s
.41466 .59005 m
.93252 .42969 L
s
.93252 .42969 m
.97504 .74153 L
s
.97504 .74153 m
.40442 .88508 L
s
.40442 .88508 m
.41466 .59005 L
s
P
p
.002 w
.4781 .48474 m .53745 .48766 L .53694 .47007 L p
1 g
F P
s
P
p
.002 w
.53694 .47007 m .47963 .46722 L .4781 .48474 L p
1 g
F P
s
P
p
.002 w
.59295 .46152 m .53694 .47007 L .53745 .48766 L p
1 g
F P
s
P
p
.002 w
.42266 .47034 m .4781 .48474 L .47963 .46722 L p
1 g
F P
s
P
p
.002 w
.47963 .46722 m .42612 .45317 L .42266 .47034 L p
1 g
F P
s
P
p
.002 w
.47656 .50236 m .53796 .50534 L .53745 .48766 L p
1 g
F P
s
P
p
.002 w
.53745 .48766 m .4781 .48474 L .47656 .50236 L p
1 g
F P
s
P
p
.002 w
.59547 .4789 m .53745 .48766 L .53796 .50534 L p
1 g
F P
s
P
p
.002 w
.53745 .48766 m .59547 .4789 L .59295 .46152 L p
1 g
F P
s
P
p
.002 w
.41917 .4876 m .47656 .50236 L .4781 .48474 L p
1 g
F P
s
P
p
.002 w
.4781 .48474 m .42266 .47034 L .41917 .4876 L p
1 g
F P
s
P
p
.002 w
.6426 .44217 m .59295 .46152 L .59547 .4789 L p
1 g
F P
s
P
p
.002 w
.47501 .52006 m .53848 .52312 L .53796 .50534 L p
1 g
F P
s
P
p
.002 w
.53796 .50534 m .47656 .50236 L .47501 .52006 L p
1 g
F P
s
P
p
.002 w
.598 .49637 m .53796 .50534 L .53848 .52312 L p
1 g
F P
s
P
p
.002 w
.53796 .50534 m .598 .49637 L .59547 .4789 L p
1 g
F P
s
P
p
.002 w
.41566 .50497 m .47501 .52006 L .47656 .50236 L p
1 g
F P
s
P
p
.002 w
.47656 .50236 m .41917 .4876 L .41566 .50497 L p
1 g
F P
s
P
p
.002 w
.47345 .53786 m .53899 .54098 L .53848 .52312 L p
1 g
F P
s
P
p
.002 w
.53848 .52312 m .47501 .52006 L .47345 .53786 L p
1 g
F P
s
P
p
.002 w
.60054 .51394 m .53848 .52312 L .53899 .54098 L p
1 g
F P
s
P
p
.002 w
.53848 .52312 m .60054 .51394 L .598 .49637 L p
1 g
F P
s
P
p
.002 w
.64695 .45905 m .59547 .4789 L .598 .49637 L p
1 g
F P
s
P
p
.002 w
.59547 .4789 m .64695 .45905 L .6426 .44217 L p
1 g
F P
s
P
p
.002 w
.41213 .52245 m .47345 .53786 L .47501 .52006 L p
1 g
F P
s
P
p
.002 w
.47501 .52006 m .41566 .50497 L .41213 .52245 L p
1 g
F P
s
P
p
.002 w
.37627 .44547 m .42266 .47034 L .42612 .45317 L p
1 g
F P
s
P
p
.002 w
.42612 .45317 m .38142 .42893 L .37627 .44547 L p
1 g
F P
s
P
p
.002 w
.47189 .55576 m .53952 .55894 L .53899 .54098 L p
1 g
F P
s
P
p
.002 w
.53899 .54098 m .47345 .53786 L .47189 .55576 L p
1 g
F P
s
P
p
.002 w
.6031 .53161 m .53899 .54098 L .53952 .55894 L p
1 g
F P
s
P
p
.002 w
.53899 .54098 m .6031 .53161 L .60054 .51394 L p
1 g
F P
s
P
p
.002 w
.65132 .47605 m .598 .49637 L .60054 .51394 L p
1 g
F P
s
P
p
.002 w
.598 .49637 m .65132 .47605 L .64695 .45905 L p
1 g
F P
s
P
p
.002 w
.40858 .54003 m .47189 .55576 L .47345 .53786 L p
1 g
F P
s
P
p
.002 w
.47345 .53786 m .41213 .52245 L .40858 .54003 L p
1 g
F P
s
P
p
.002 w
.37108 .46212 m .41917 .4876 L .42266 .47034 L p
1 g
F P
s
P
p
.002 w
.42266 .47034 m .37627 .44547 L .37108 .46212 L p
1 g
F P
s
P
p
.002 w
.47032 .57375 m .54004 .577 L .53952 .55894 L p
1 g
F P
s
P
p
.002 w
.53952 .55894 m .47189 .55576 L .47032 .57375 L p
1 g
F P
s
P
p
.002 w
.60568 .54938 m .53952 .55894 L .54004 .577 L p
1 g
F P
s
P
p
.002 w
.53952 .55894 m .60568 .54938 L .6031 .53161 L p
1 g
F P
s
P
p
.002 w
.65572 .49315 m .60054 .51394 L .6031 .53161 L p
1 g
F P
s
P
p
.002 w
.60054 .51394 m .65572 .49315 L .65132 .47605 L p
1 g
F P
s
P
p
.002 w
.40501 .55771 m .47032 .57375 L .47189 .55576 L p
1 g
F P
s
P
p
.002 w
.47189 .55576 m .40858 .54003 L .40501 .55771 L p
1 g
F P
s
P
p
.002 w
.46873 .59184 m .54057 .59515 L .54004 .577 L p
1 g
F P
s
P
p
.002 w
.54004 .577 m .47032 .57375 L .46873 .59184 L p
1 g
F P
s
P
p
.002 w
.60826 .56725 m .54004 .577 L .54057 .59515 L p
1 g
F P
s
P
p
.002 w
.54004 .577 m .60826 .56725 L .60568 .54938 L p
1 g
F P
s
P
p
.002 w
.36586 .47888 m .41566 .50497 L .41917 .4876 L p
1 g
F P
s
P
p
.002 w
.41917 .4876 m .37108 .46212 L .36586 .47888 L p
1 g
F P
s
P
p
.002 w
.66015 .51035 m .6031 .53161 L .60568 .54938 L p
1 g
F P
s
P
p
.002 w
.6031 .53161 m .66015 .51035 L .65572 .49315 L p
1 g
F P
s
P
p
.002 w
.68104 .41347 m .6426 .44217 L .64695 .45905 L p
1 g
F P
s
P
p
.002 w
.40141 .5755 m .46873 .59184 L .47032 .57375 L p
1 g
F P
s
P
p
.002 w
.47032 .57375 m .40501 .55771 L .40141 .5755 L p
1 g
F P
s
P
p
.002 w
.46714 .61003 m .5411 .6134 L .54057 .59515 L p
1 g
F P
s
P
p
.002 w
.54057 .59515 m .46873 .59184 L .46714 .61003 L p
1 g
F P
s
P
p
.002 w
.61087 .58522 m .54057 .59515 L .5411 .6134 L p
1 g
F P
s
P
p
.002 w
.54057 .59515 m .61087 .58522 L .60826 .56725 L p
1 g
F P
s
P
p
.002 w
.3606 .49577 m .41213 .52245 L .41566 .50497 L p
1 g
F P
s
P
p
.002 w
.41566 .50497 m .36586 .47888 L .3606 .49577 L p
1 g
F P
s
P
p
.002 w
.6646 .52768 m .60568 .54938 L .60826 .56725 L p
1 g
F P
s
P
p
.002 w
.60568 .54938 m .6646 .52768 L .66015 .51035 L p
1 g
F P
s
P
p
.002 w
.68688 .42959 m .64695 .45905 L .65132 .47605 L p
1 g
F P
s
P
p
.002 w
.64695 .45905 m .68688 .42959 L .68104 .41347 L p
1 g
F P
s
P
p
.002 w
.3978 .5934 m .46714 .61003 L .46873 .59184 L p
1 g
F P
s
P
p
.002 w
.46873 .59184 m .40141 .5755 L .3978 .5934 L p
1 g
F P
s
P
p
.002 w
.46555 .62832 m .54163 .63174 L .5411 .6134 L p
1 g
F P
s
P
p
.002 w
.5411 .6134 m .46714 .61003 L .46555 .62832 L p
1 g
F P
s
P
p
.002 w
.61348 .60329 m .5411 .6134 L .54163 .63174 L p
1 g
F P
s
P
p
.002 w
.5411 .6134 m .61348 .60329 L .61087 .58522 L p
1 g
F P
s
P
p
.002 w
.66909 .54511 m .60826 .56725 L .61087 .58522 L p
1 g
F P
s
P
p
.002 w
.60826 .56725 m .66909 .54511 L .6646 .52768 L p
1 g
F P
s
P
p
.002 w
.35531 .51277 m .40858 .54003 L .41213 .52245 L p
1 g
F P
s
P
p
.002 w
.41213 .52245 m .3606 .49577 L .35531 .51277 L p
1 g
F P
s
P
p
.002 w
.69276 .44583 m .65132 .47605 L .65572 .49315 L p
1 g
F P
s
P
p
.002 w
.65132 .47605 m .69276 .44583 L .68688 .42959 L p
1 g
F P
s
P
p
.002 w
.39416 .6114 m .46555 .62832 L .46714 .61003 L p
1 g
F P
s
P
p
.002 w
.46714 .61003 m .3978 .5934 L .39416 .6114 L p
1 g
F P
s
P
p
.002 w
.46394 .64671 m .54216 .65018 L .54163 .63174 L p
1 g
F P
s
P
p
.002 w
.54163 .63174 m .46555 .62832 L .46394 .64671 L p
1 g
F P
s
P
p
.002 w
.61612 .62147 m .54163 .63174 L .54216 .65018 L p
1 g
F P
s
P
p
.002 w
.54163 .63174 m .61612 .62147 L .61348 .60329 L p
1 g
F P
s
P
p
.002 w
.34375 .41204 m .37627 .44547 L .38142 .42893 L p
1 g
F P
s
P
p
.002 w
.38142 .42893 m .35017 .39639 L .34375 .41204 L p
1 g
F P
s
P
p
.002 w
.6736 .56266 m .61087 .58522 L .61348 .60329 L p
1 g
F P
s
P
p
.002 w
.61087 .58522 m .6736 .56266 L .66909 .54511 L p
1 g
F P
s
P
p
.002 w
.34997 .52989 m .40501 .55771 L .40858 .54003 L p
1 g
F P
s
P
p
.002 w
.40858 .54003 m .35531 .51277 L .34997 .52989 L p
1 g
F P
s
P
p
.002 w
.3905 .62952 m .46394 .64671 L .46555 .62832 L p
1 g
F P
s
P
p
.002 w
.46555 .62832 m .39416 .6114 L .3905 .62952 L p
1 g
F P
s
P
p
.002 w
.69868 .4622 m .65572 .49315 L .66015 .51035 L p
1 g
F P
s
P
p
.002 w
.65572 .49315 m .69868 .4622 L .69276 .44583 L p
1 g
F P
s
P
p
.002 w
.46232 .66519 m .5427 .66872 L .54216 .65018 L p
1 g
F P
s
P
p
.002 w
.54216 .65018 m .46394 .64671 L .46232 .66519 L p
1 g
F P
s
P
p
.002 w
.61876 .63975 m .54216 .65018 L .5427 .66872 L p
1 g
F P
s
P
p
.002 w
.54216 .65018 m .61876 .63975 L .61612 .62147 L p
1 g
F P
s
P
p
.002 w
.67815 .58032 m .61348 .60329 L .61612 .62147 L p
1 g
F P
s
P
p
.002 w
.61348 .60329 m .67815 .58032 L .6736 .56266 L p
1 g
F P
s
P
p
.002 w
.33729 .42782 m .37108 .46212 L .37627 .44547 L p
1 g
F P
s
P
p
.002 w
.37627 .44547 m .34375 .41204 L .33729 .42782 L p
1 g
F P
s
P
p
.002 w
.3446 .54714 m .40141 .5755 L .40501 .55771 L p
1 g
F P
s
P
p
.002 w
.40501 .55771 m .34997 .52989 L .3446 .54714 L p
1 g
F P
s
P
p
.002 w
.38682 .64774 m .46232 .66519 L .46394 .64671 L p
1 g
F P
s
P
p
.002 w
.46394 .64671 m .3905 .62952 L .38682 .64774 L p
1 g
F P
s
P
p
.002 w
.4607 .68378 m .54324 .68736 L .5427 .66872 L p
1 g
F P
s
P
p
.002 w
.5427 .66872 m .46232 .66519 L .4607 .68378 L p
1 g
F P
s
P
p
.002 w
.62143 .65813 m .5427 .66872 L .54324 .68736 L p
1 g
F P
s
P
p
.002 w
.5427 .66872 m .62143 .65813 L .61876 .63975 L p
1 g
F P
s
P
p
.002 w
.70465 .47869 m .66015 .51035 L .6646 .52768 L p
1 g
F P
s
P
p
.002 w
.66015 .51035 m .70465 .47869 L .69868 .4622 L p
1 g
F P
s
P
p
.002 w
.68272 .5981 m .61612 .62147 L .61876 .63975 L p
1 g
F P
s
P
p
.002 w
.61612 .62147 m .68272 .5981 L .67815 .58032 L p
1 g
F P
s
P
p
.002 w
.33919 .56451 m .3978 .5934 L .40141 .5755 L p
1 g
F P
s
P
p
.002 w
.40141 .5755 m .3446 .54714 L .33919 .56451 L p
1 g
F P
s
P
p
.002 w
.33076 .44373 m .36586 .47888 L .37108 .46212 L p
1 g
F P
s
P
p
.002 w
.37108 .46212 m .33729 .42782 L .33076 .44373 L p
1 g
F P
s
P
p
.002 w
.38311 .66608 m .4607 .68378 L .46232 .66519 L p
1 g
F P
s
P
p
.002 w
.46232 .66519 m .38682 .64774 L .38311 .66608 L p
1 g
F P
s
P
p
.002 w
.45907 .70247 m .54379 .7061 L .54324 .68736 L p
1 g
F P
s
P
p
.002 w
.54324 .68736 m .4607 .68378 L .45907 .70247 L p
1 g
F P
s
P
p
.002 w
.6241 .67662 m .54324 .68736 L .54379 .7061 L p
1 g
F P
s
P
p
.002 w
.54324 .68736 m .6241 .67662 L .62143 .65813 L p
1 g
F P
s
P
p
.002 w
.71067 .49531 m .6646 .52768 L .66909 .54511 L p
1 g
F P
s
P
p
.002 w
.6646 .52768 m .71067 .49531 L .70465 .47869 L p
1 g
F P
s
P
p
.002 w
.70392 .37777 m .68104 .41347 L .68688 .42959 L p
1 g
F P
s
P
p
.002 w
.68733 .61599 m .61876 .63975 L .62143 .65813 L p
1 g
F P
s
P
p
.002 w
.61876 .63975 m .68733 .61599 L .68272 .5981 L p
1 g
F P
s
P
p
.002 w
.33374 .582 m .39416 .6114 L .3978 .5934 L p
1 g
F P
s
P
p
.002 w
.3978 .5934 m .33919 .56451 L .33374 .582 L p
1 g
F P
s
P
p
.002 w
.37938 .68453 m .45907 .70247 L .4607 .68378 L p
1 g
F P
s
P
p
.002 w
.4607 .68378 m .38311 .66608 L .37938 .68453 L p
1 g
F P
s
P
p
.002 w
.45742 .72127 m .54433 .72493 L .54379 .7061 L p
1 g
F P
s
P
p
.002 w
.54379 .7061 m .45907 .70247 L .45742 .72127 L p
1 g
F P
s
P
p
.002 w
.6268 .69521 m .54379 .7061 L .54433 .72493 L p
1 g
F P
s
P
p
.002 w
.54379 .7061 m .6268 .69521 L .6241 .67662 L p
1 g
F P
s
P
p
.002 w
.32419 .45978 m .3606 .49577 L .36586 .47888 L p
1 g
F P
s
P
p
.002 w
.36586 .47888 m .33076 .44373 L .32419 .45978 L p
1 g
F P
s
P
p
.002 w
.71673 .51206 m .66909 .54511 L .6736 .56266 L p
1 g
F P
s
P
p
.002 w
.66909 .54511 m .71673 .51206 L .71067 .49531 L p
1 g
F P
s
P
p
.002 w
.69196 .634 m .62143 .65813 L .6241 .67662 L p
1 g
F P
s
P
p
.002 w
.62143 .65813 m .69196 .634 L .68733 .61599 L p
1 g
F P
s
P
p
.002 w
.37563 .70309 m .45742 .72127 L .45907 .70247 L p
1 g
F P
s
P
p
.002 w
.45907 .70247 m .37938 .68453 L .37563 .70309 L p
1 g
F P
s
P
p
.002 w
.32826 .59962 m .3905 .62952 L .39416 .6114 L p
1 g
F P
s
P
p
.002 w
.39416 .6114 m .33374 .582 L .32826 .59962 L p
1 g
F P
s
P
p
.002 w
.71074 .39289 m .68688 .42959 L .69276 .44583 L p
1 g
F P
s
P
p
.002 w
.68688 .42959 m .71074 .39289 L .70392 .37777 L p
1 g
F P
s
P
p
.002 w
.45577 .74017 m .54488 .74387 L .54433 .72493 L p
1 g
F P
s
P
p
.002 w
.54433 .72493 m .45742 .72127 L .45577 .74017 L p
1 g
F P
s
P
p
.002 w
.62951 .71391 m .54433 .72493 L .54488 .74387 L p
1 g
F P
s
P
p
.002 w
.54433 .72493 m .62951 .71391 L .6268 .69521 L p
1 g
F P
s
P
p
.002 w
.31756 .47596 m .35531 .51277 L .3606 .49577 L p
1 g
F P
s
P
p
.002 w
.3606 .49577 m .32419 .45978 L .31756 .47596 L p
1 g
F P
s
P
p
.002 w
.69662 .65213 m .6241 .67662 L .6268 .69521 L p
1 g
F P
s
P
p
.002 w
.6241 .67662 m .69662 .65213 L .69196 .634 L p
1 g
F P
s
P
p
.002 w
.72284 .52894 m .6736 .56266 L .67815 .58032 L p
1 g
F P
s
P
p
.002 w
.6736 .56266 m .72284 .52894 L .71673 .51206 L p
1 g
F P
s
P
p
.002 w
.37186 .72177 m .45577 .74017 L .45742 .72127 L p
1 g
F P
s
P
p
.002 w
.45742 .72127 m .37563 .70309 L .37186 .72177 L p
1 g
F P
s
P
p
.002 w
.45411 .75917 m .54544 .76292 L .54488 .74387 L p
1 g
F P
s
P
p
.002 w
.54488 .74387 m .45577 .74017 L .45411 .75917 L p
1 g
F P
s
P
p
.002 w
.63223 .73272 m .54488 .74387 L .54544 .76292 L p
1 g
F P
s
P
p
.002 w
.54488 .74387 m .63223 .73272 L .62951 .71391 L p
1 g
F P
s
P
p
.002 w
.32273 .61736 m .38682 .64774 L .3905 .62952 L p
1 g
F P
s
P
p
.002 w
.3905 .62952 m .32826 .59962 L .32273 .61736 L p
1 g
F P
s
P
p
.002 w
.71762 .40815 m .69276 .44583 L .69868 .4622 L p
1 g
F P
s
P
p
.002 w
.69276 .44583 m .71762 .40815 L .71074 .39289 L p
1 g
F P
s
P
p
.002 w
.31087 .49228 m .34997 .52989 L .35531 .51277 L p
1 g
F P
s
P
p
.002 w
.35531 .51277 m .31756 .47596 L .31087 .49228 L p
1 g
F P
s
P
p
.002 w
.70132 .67038 m .6268 .69521 L .62951 .71391 L p
1 g
F P
s
P
p
.002 w
.6268 .69521 m .70132 .67038 L .69662 .65213 L p
1 g
F P
s
P
p
.002 w
.729 .54595 m .67815 .58032 L .68272 .5981 L p
1 g
F P
s
P
p
.002 w
.67815 .58032 m .729 .54595 L .72284 .52894 L p
1 g
F P
s
P
p
.002 w
.36806 .74057 m .45411 .75917 L .45577 .74017 L p
1 g
F P
s
P
p
.002 w
.45577 .74017 m .37186 .72177 L .36806 .74057 L p
1 g
F P
s
P
p
.002 w
.45244 .77828 m .54599 .78206 L .54544 .76292 L p
1 g
F P
s
P
p
.002 w
.54544 .76292 m .45411 .75917 L .45244 .77828 L p
1 g
F P
s
P
p
.002 w
.63497 .75164 m .54544 .76292 L .54599 .78206 L p
1 g
F P
s
P
p
.002 w
.54544 .76292 m .63497 .75164 L .63223 .73272 L p
1 g
F P
s
P
p
.002 w
.32921 .37295 m .34375 .41204 L .35017 .39639 L p
1 g
F P
s
P
p
.002 w
.35017 .39639 m .33629 .35839 L .32921 .37295 L p
1 g
F P
s
P
p
.002 w
.31716 .63523 m .38311 .66608 L .38682 .64774 L p
1 g
F P
s
P
p
.002 w
.38682 .64774 m .32273 .61736 L .31716 .63523 L p
1 g
F P
s
P
p
.002 w
.72457 .42355 m .69868 .4622 L .70465 .47869 L p
1 g
F P
s
P
p
.002 w
.69868 .4622 m .72457 .42355 L .71762 .40815 L p
1 g
F P
s
P
p
.002 w
.70605 .68876 m .62951 .71391 L .63223 .73272 L p
1 g
F P
s
P
p
.002 w
.62951 .71391 m .70605 .68876 L .70132 .67038 L p
1 g
F P
s
P
p
.002 w
.36424 .75948 m .45244 .77828 L .45411 .75917 L p
1 g
F P
s
P
p
.002 w
.45411 .75917 m .36806 .74057 L .36424 .75948 L p
1 g
F P
s
P
p
.002 w
.45076 .79749 m .54655 .80131 L .54599 .78206 L p
1 g
F P
s
P
p
.002 w
.54599 .78206 m .45244 .77828 L .45076 .79749 L p
1 g
F P
s
P
p
.002 w
.63773 .77067 m .54599 .78206 L .54655 .80131 L p
1 g
F P
s
P
p
.002 w
.54599 .78206 m .63773 .77067 L .63497 .75164 L p
1 g
F P
s
P
p
.002 w
.30412 .50874 m .3446 .54714 L .34997 .52989 L p
1 g
F P
s
P
p
.002 w
.34997 .52989 m .31087 .49228 L .30412 .50874 L p
1 g
F P
s
P
p
.002 w
.7352 .5631 m .68272 .5981 L .68733 .61599 L p
1 g
F P
s
P
p
.002 w
.68272 .5981 m .7352 .5631 L .729 .54595 L p
1 g
F P
s
P
p
.002 w
.31156 .65324 m .37938 .68453 L .38311 .66608 L p
1 g
F P
s
P
p
.002 w
.38311 .66608 m .31716 .63523 L .31156 .65324 L p
1 g
F P
s
P
p
.002 w
.32205 .38765 m .33729 .42782 L .34375 .41204 L p
1 g
F P
s
P
p
.002 w
.34375 .41204 m .32921 .37295 L .32205 .38765 L p
1 g
F P
s
P
p
.002 w
.71081 .70725 m .63223 .73272 L .63497 .75164 L p
1 g
F P
s
P
p
.002 w
.63223 .73272 m .71081 .70725 L .70605 .68876 L p
1 g
F P
s
P
p
.002 w
.44907 .81681 m .54711 .82067 L .54655 .80131 L p
1 g
F P
s
P
p
.002 w
.54655 .80131 m .45076 .79749 L .44907 .81681 L p
1 g
F P
s
P
p
.002 w
.6405 .78981 m .54655 .80131 L .54711 .82067 L p
1 g
F P
s
P
p
.002 w
.54655 .80131 m .6405 .78981 L .63773 .77067 L p
1 g
F P
s
P
p
.002 w
.3604 .7785 m .45076 .79749 L .45244 .77828 L p
1 g
F P
s
P
p
.002 w
.45244 .77828 m .36424 .75948 L .3604 .7785 L p
1 g
F P
s
P
p
.002 w
.73157 .43909 m .70465 .47869 L .71067 .49531 L p
1 g
F P
s
P
p
.002 w
.70465 .47869 m .73157 .43909 L .72457 .42355 L p
1 g
F P
s
P
p
.002 w
.29732 .52534 m .33919 .56451 L .3446 .54714 L p
1 g
F P
s
P
p
.002 w
.3446 .54714 m .30412 .50874 L .29732 .52534 L p
1 g
F P
s
P
p
.002 w
.74146 .58038 m .68733 .61599 L .69196 .634 L p
1 g
F P
s
P
p
.002 w
.68733 .61599 m .74146 .58038 L .7352 .5631 L p
1 g
F P
s
P
p
.002 w
.30591 .67137 m .37563 .70309 L .37938 .68453 L p
1 g
F P
s
P
p
.002 w
.37938 .68453 m .31156 .65324 L .30591 .67137 L p
1 g
F P
s
P
p
.002 w
.7156 .72587 m .63497 .75164 L .63773 .77067 L p
1 g
F P
s
P
p
.002 w
.63497 .75164 m .7156 .72587 L .71081 .70725 L p
1 g
F P
s
P
p
.002 w
.54711 .82067 m .64329 .80907 L .6405 .78981 L p
1 g
F P
s
P
p
.002 w
.35653 .79765 m .44907 .81681 L .45076 .79749 L p
1 g
F P
s
P
p
.002 w
.45076 .79749 m .3604 .7785 L .35653 .79765 L p
1 g
F P
s
P
p
.002 w
.31482 .4025 m .33076 .44373 L .33729 .42782 L p
1 g
F P
s
P
p
.002 w
.33729 .42782 m .32205 .38765 L .31482 .4025 L p
1 g
F P
s
P
p
.002 w
.74776 .59779 m .69196 .634 L .69662 .65213 L p
1 g
F P
s
P
p
.002 w
.69196 .634 m .74776 .59779 L .74146 .58038 L p
1 g
F P
s
P
p
.002 w
.30022 .68963 m .37186 .72177 L .37563 .70309 L p
1 g
F P
s
P
p
.002 w
.37563 .70309 m .30591 .67137 L .30022 .68963 L p
1 g
F P
s
P
p
.002 w
.73865 .45478 m .71067 .49531 L .71673 .51206 L p
1 g
F P
s
P
p
.002 w
.71067 .49531 m .73865 .45478 L .73157 .43909 L p
1 g
F P
s
P
p
.002 w
.29045 .54209 m .33374 .582 L .33919 .56451 L p
1 g
F P
s
P
p
.002 w
.33919 .56451 m .29732 .52534 L .29045 .54209 L p
1 g
F P
s
P
p
.002 w
.72042 .74462 m .63773 .77067 L .6405 .78981 L p
1 g
F P
s
P
p
.002 w
.63773 .77067 m .72042 .74462 L .7156 .72587 L p
1 g
F P
s
P
p
.002 w
.70789 .3384 m .70392 .37777 L .71074 .39289 L p
1 g
F P
s
P
p
.002 w
.29449 .70803 m .36806 .74057 L .37186 .72177 L p
1 g
F P
s
P
p
.002 w
.37186 .72177 m .30022 .68963 L .29449 .70803 L p
1 g
F P
s
P
p
.002 w
.75411 .61535 m .69662 .65213 L .70132 .67038 L p
1 g
F P
s
P
p
.002 w
.69662 .65213 m .75411 .61535 L .74776 .59779 L p
1 g
F P
s
P
p
.002 w
.30752 .4175 m .32419 .45978 L .33076 .44373 L p
1 g
F P
s
P
p
.002 w
.33076 .44373 m .31482 .4025 L .30752 .4175 L p
1 g
F P
s
P
p
.002 w
.28353 .55898 m .32826 .59962 L .33374 .582 L p
1 g
F P
s
P
p
.002 w
.33374 .582 m .29045 .54209 L .28353 .55898 L p
1 g
F P
s
P
p
.002 w
.74579 .47062 m .71673 .51206 L .72284 .52894 L p
1 g
F P
s
P
p
.002 w
.71673 .51206 m .74579 .47062 L .73865 .45478 L p
1 g
F P
s
P
p
.002 w
.72527 .76349 m .6405 .78981 L .64329 .80907 L p
1 g
F P
s
P
p
.002 w
.6405 .78981 m .72527 .76349 L .72042 .74462 L p
1 g
F P
s
P
p
.002 w
.71502 .35236 m .71074 .39289 L .71762 .40815 L p
1 g
F P
s
P
p
.002 w
.71074 .39289 m .71502 .35236 L .70789 .3384 L p
1 g
F P
s
P
p
.002 w
.28872 .72657 m .36424 .75948 L .36806 .74057 L p
1 g
F P
s
P
p
.002 w
.36806 .74057 m .29449 .70803 L .28872 .72657 L p
1 g
F P
s
P
p
.002 w
.76052 .63304 m .70132 .67038 L .70605 .68876 L p
1 g
F P
s
P
p
.002 w
.70132 .67038 m .76052 .63304 L .75411 .61535 L p
1 g
F P
s
P
p
.002 w
.64329 .80907 m .73016 .78249 L .72527 .76349 L p
1 g
F P
s
P
p
.002 w
.27655 .57601 m .32273 .61736 L .32826 .59962 L p
1 g
F P
s
P
p
.002 w
.32826 .59962 m .28353 .55898 L .27655 .57601 L p
1 g
F P
s
P
p
.002 w
.30014 .43265 m .31756 .47596 L .32419 .45978 L p
1 g
F P
s
P
p
.002 w
.32419 .45978 m .30752 .4175 L .30014 .43265 L p
1 g
F P
s
P
p
.002 w
.753 .4866 m .72284 .52894 L .729 .54595 L p
1 g
F P
s
P
p
.002 w
.72284 .52894 m .753 .4866 L .74579 .47062 L p
1 g
F P
s
P
p
.002 w
.2829 .74524 m .3604 .7785 L .36424 .75948 L p
1 g
F P
s
P
p
.002 w
.36424 .75948 m .28872 .72657 L .2829 .74524 L p
1 g
F P
s
P
p
.002 w
.76697 .65088 m .70605 .68876 L .71081 .70725 L p
1 g
F P
s
P
p
.002 w
.70605 .68876 m .76697 .65088 L .76052 .63304 L p
1 g
F P
s
P
p
.002 w
.72223 .36646 m .71762 .40815 L .72457 .42355 L p
1 g
F P
s
P
p
.002 w
.71762 .40815 m .72223 .36646 L .71502 .35236 L p
1 g
F P
s
P
p
.002 w
.26951 .5932 m .31716 .63523 L .32273 .61736 L p
1 g
F P
s
P
p
.002 w
.32273 .61736 m .27655 .57601 L .26951 .5932 L p
1 g
F P
s
P
p
.002 w
.29269 .44796 m .31087 .49228 L .31756 .47596 L p
1 g
F P
s
P
p
.002 w
.31756 .47596 m .30014 .43265 L .29269 .44796 L p
1 g
F P
s
P
p
.002 w
.76027 .50273 m .729 .54595 L .7352 .5631 L p
1 g
F P
s
P
p
.002 w
.729 .54595 m .76027 .50273 L .753 .4866 L p
1 g
F P
s
P
p
.002 w
.3354 .33205 m .32921 .37295 L .33629 .35839 L p
1 g
F P
s
P
p
.002 w
.33629 .35839 m .34241 .31871 L .3354 .33205 L p
1 g
F P
s
P
p
.002 w
.27704 .76405 m .35653 .79765 L .3604 .7785 L p
1 g
F P
s
P
p
.002 w
.3604 .7785 m .2829 .74524 L .27704 .76405 L p
1 g
F P
s
P
p
.002 w
.77348 .66886 m .71081 .70725 L .7156 .72587 L p
1 g
F P
s
P
p
.002 w
.71081 .70725 m .77348 .66886 L .76697 .65088 L p
1 g
F P
s
P
p
.002 w
.2624 .61053 m .31156 .65324 L .31716 .63523 L p
1 g
F P
s
P
p
.002 w
.31716 .63523 m .26951 .5932 L .2624 .61053 L p
1 g
F P
s
P
p
.002 w
.72951 .38072 m .72457 .42355 L .73157 .43909 L p
1 g
F P
s
P
p
.002 w
.72457 .42355 m .72951 .38072 L .72223 .36646 L p
1 g
F P
s
P
p
.002 w
.76762 .51902 m .7352 .5631 L .74146 .58038 L p
1 g
F P
s
P
p
.002 w
.7352 .5631 m .76762 .51902 L .76027 .50273 L p
1 g
F P
s
P
p
.002 w
.28516 .46342 m .30412 .50874 L .31087 .49228 L p
1 g
F P
s
P
p
.002 w
.31087 .49228 m .29269 .44796 L .28516 .46342 L p
1 g
F P
s
P
p
.002 w
.78004 .68698 m .7156 .72587 L .72042 .74462 L p
1 g
F P
s
P
p
.002 w
.7156 .72587 m .78004 .68698 L .77348 .66886 L p
1 g
F P
s
P
p
.002 w
.3283 .34556 m .32205 .38765 L .32921 .37295 L p
1 g
F P
s
P
p
.002 w
.32921 .37295 m .3354 .33205 L .3283 .34556 L p
1 g
F P
s
P
p
.002 w
.25523 .62802 m .30591 .67137 L .31156 .65324 L p
1 g
F P
s
P
p
.002 w
.31156 .65324 m .2624 .61053 L .25523 .62802 L p
1 g
F P
s
P
p
.002 w
.77503 .53546 m .74146 .58038 L .74776 .59779 L p
1 g
F P
s
P
p
.002 w
.74146 .58038 m .77503 .53546 L .76762 .51902 L p
1 g
F P
s
P
p
.002 w
.73688 .39514 m .73157 .43909 L .73865 .45478 L p
1 g
F P
s
P
p
.002 w
.73157 .43909 m .73688 .39514 L .72951 .38072 L p
1 g
F P
s
P
p
.002 w
.78666 .70526 m .72042 .74462 L .72527 .76349 L p
1 g
F P
s
P
p
.002 w
.72042 .74462 m .78666 .70526 L .78004 .68698 L p
1 g
F P
s
P
p
.002 w
.27756 .47904 m .29732 .52534 L .30412 .50874 L p
1 g
F P
s
P
p
.002 w
.30412 .50874 m .28516 .46342 L .27756 .47904 L p
1 g
F P
s
P
p
.002 w
.248 .64567 m .30022 .68963 L .30591 .67137 L p
1 g
F P
s
P
p
.002 w
.30591 .67137 m .25523 .62802 L .248 .64567 L p
1 g
F P
s
P
p
.002 w
.32113 .35922 m .31482 .4025 L .32205 .38765 L p
1 g
F P
s
P
p
.002 w
.32205 .38765 m .3283 .34556 L .32113 .35922 L p
1 g
F P
s
P
p
.002 w
.79332 .72368 m .72527 .76349 L .73016 .78249 L p
1 g
F P
s
P
p
.002 w
.72527 .76349 m .79332 .72368 L .78666 .70526 L p
1 g
F P
s
P
p
.002 w
.69127 .29953 m .70789 .3384 L .71502 .35236 L p
1 g
F P
s
P
p
.002 w
.78252 .55206 m .74776 .59779 L .75411 .61535 L p
1 g
F P
s
P
p
.002 w
.74776 .59779 m .78252 .55206 L .77503 .53546 L p
1 g
F P
s
P
p
.002 w
.74433 .40972 m .73865 .45478 L .74579 .47062 L p
1 g
F P
s
P
p
.002 w
.73865 .45478 m .74433 .40972 L .73688 .39514 L p
1 g
F P
s
P
p
.002 w
.26987 .49483 m .29045 .54209 L .29732 .52534 L p
1 g
F P
s
P
p
.002 w
.29732 .52534 m .27756 .47904 L .26987 .49483 L p
1 g
F P
s
P
p
.002 w
.24071 .66347 m .29449 .70803 L .30022 .68963 L p
1 g
F P
s
P
p
.002 w
.30022 .68963 m .248 .64567 L .24071 .66347 L p
1 g
F P
s
P
p
.002 w
.73016 .78249 m .80005 .74225 L .79332 .72368 L p
1 g
F P
s
P
p
.002 w
.31387 .37304 m .30752 .4175 L .31482 .4025 L p
1 g
F P
s
P
p
.002 w
.31482 .4025 m .32113 .35922 L .31387 .37304 L p
1 g
F P
s
P
p
.002 w
.79008 .56881 m .75411 .61535 L .76052 .63304 L p
1 g
F P
s
P
p
.002 w
.75411 .61535 m .79008 .56881 L .78252 .55206 L p
1 g
F P
s
P
p
.002 w
.69791 .31226 m .71502 .35236 L .72223 .36646 L p
1 g
F P
s
P
p
.002 w
.71502 .35236 m .69791 .31226 L .69127 .29953 L p
1 g
F P
s
P
p
.002 w
.26211 .51078 m .28353 .55898 L .29045 .54209 L p
1 g
F P
s
P
p
.002 w
.29045 .54209 m .26987 .49483 L .26211 .51078 L p
1 g
F P
s
P
p
.002 w
.75186 .42446 m .74579 .47062 L .753 .4866 L p
1 g
F P
s
P
p
.002 w
.74579 .47062 m .75186 .42446 L .74433 .40972 L p
1 g
F P
s
P
p
.002 w
.23335 .68142 m .28872 .72657 L .29449 .70803 L p
1 g
F P
s
P
p
.002 w
.29449 .70803 m .24071 .66347 L .23335 .68142 L p
1 g
F P
s
P
p
.002 w
.79771 .58573 m .76052 .63304 L .76697 .65088 L p
1 g
F P
s
P
p
.002 w
.76052 .63304 m .79771 .58573 L .79008 .56881 L p
1 g
F P
s
P
p
.002 w
.30652 .38703 m .30014 .43265 L .30752 .4175 L p
1 g
F P
s
P
p
.002 w
.30752 .4175 m .31387 .37304 L .30652 .38703 L p
1 g
F P
s
P
p
.002 w
.22592 .69954 m .2829 .74524 L .28872 .72657 L p
1 g
F P
s
P
p
.002 w
.28872 .72657 m .23335 .68142 L .22592 .69954 L p
1 g
F P
s
P
p
.002 w
.25426 .52689 m .27655 .57601 L .28353 .55898 L p
1 g
F P
s
P
p
.002 w
.28353 .55898 m .26211 .51078 L .25426 .52689 L p
1 g
F P
s
P
p
.002 w
.75947 .43936 m .753 .4866 L .76027 .50273 L p
1 g
F P
s
P
p
.002 w
.753 .4866 m .75947 .43936 L .75186 .42446 L p
1 g
F P
s
P
p
.002 w
.70462 .32516 m .72223 .36646 L .72951 .38072 L p
1 g
F P
s
P
p
.002 w
.72223 .36646 m .70462 .32516 L .69791 .31226 L p
1 g
F P
s
P
p
.002 w
.36302 .29396 m .3354 .33205 L .34241 .31871 L p
1 g
F P
s
P
p
.002 w
.34241 .31871 m .36912 .2818 L .36302 .29396 L p
1 g
F P
s
P
p
.002 w
.80541 .60282 m .76697 .65088 L .77348 .66886 L p
1 g
F P
s
P
p
.002 w
.76697 .65088 m .80541 .60282 L .79771 .58573 L p
1 g
F P
s
P
p
.002 w
.21843 .71783 m .27704 .76405 L .2829 .74524 L p
1 g
F P
s
P
p
.002 w
.2829 .74524 m .22592 .69954 L .21843 .71783 L p
1 g
F P
s
P
p
.002 w
.29908 .40119 m .29269 .44796 L .30014 .43265 L p
1 g
F P
s
P
p
.002 w
.30014 .43265 m .30652 .38703 L .29908 .40119 L p
1 g
F P
s
P
p
.002 w
.24634 .54318 m .26951 .5932 L .27655 .57601 L p
1 g
F P
s
P
p
.002 w
.27655 .57601 m .25426 .52689 L .24634 .54318 L p
1 g
F P
s
P
p
.002 w
.76717 .45443 m .76027 .50273 L .76762 .51902 L p
1 g
F P
s
P
p
.002 w
.76027 .50273 m .76717 .45443 L .75947 .43936 L p
1 g
F P
s
P
p
.002 w
.81319 .62007 m .77348 .66886 L .78004 .68698 L p
1 g
F P
s
P
p
.002 w
.77348 .66886 m .81319 .62007 L .80541 .60282 L p
1 g
F P
s
P
p
.002 w
.71143 .33822 m .72951 .38072 L .73688 .39514 L p
1 g
F P
s
P
p
.002 w
.72951 .38072 m .71143 .33822 L .70462 .32516 L p
1 g
F P
s
P
p
.002 w
.35685 .30628 m .3283 .34556 L .3354 .33205 L p
1 g
F P
s
P
p
.002 w
.3354 .33205 m .36302 .29396 L .35685 .30628 L p
1 g
F P
s
P
p
.002 w
.23832 .55964 m .2624 .61053 L .26951 .5932 L p
1 g
F P
s
P
p
.002 w
.26951 .5932 m .24634 .54318 L .23832 .55964 L p
1 g
F P
s
P
p
.002 w
.29155 .41552 m .28516 .46342 L .29269 .44796 L p
1 g
F P
s
P
p
.002 w
.29269 .44796 m .29908 .40119 L .29155 .41552 L p
1 g
F P
s
P
p
.002 w
.77496 .46968 m .76762 .51902 L .77503 .53546 L p
1 g
F P
s
P
p
.002 w
.76762 .51902 m .77496 .46968 L .76717 .45443 L p
1 g
F P
s
P
p
.002 w
.82105 .63749 m .78004 .68698 L .78666 .70526 L p
1 g
F P
s
P
p
.002 w
.78004 .68698 m .82105 .63749 L .81319 .62007 L p
1 g
F P
s
P
p
.002 w
.65473 .26579 m .69127 .29953 L .69791 .31226 L p
1 g
F P
s
P
p
.002 w
.71832 .35145 m .73688 .39514 L .74433 .40972 L p
1 g
F P
s
P
p
.002 w
.73688 .39514 m .71832 .35145 L .71143 .33822 L p
1 g
F P
s
P
p
.002 w
.35059 .31877 m .32113 .35922 L .3283 .34556 L p
1 g
F P
s
P
p
.002 w
.3283 .34556 m .35685 .30628 L .35059 .31877 L p
1 g
F P
s
P
p
.002 w
.23023 .57627 m .25523 .62802 L .2624 .61053 L p
1 g
F P
s
P
p
.002 w
.2624 .61053 m .23832 .55964 L .23023 .57627 L p
1 g
F P
s
P
p
.002 w
.28394 .43002 m .27756 .47904 L .28516 .46342 L p
1 g
F P
s
P
p
.002 w
.28516 .46342 m .29155 .41552 L .28394 .43002 L p
1 g
F P
s
P
p
.002 w
.82898 .65508 m .78666 .70526 L .79332 .72368 L p
1 g
F P
s
P
p
.002 w
.78666 .70526 m .82898 .65508 L .82105 .63749 L p
1 g
F P
s
P
p
.002 w
.78283 .48509 m .77503 .53546 L .78252 .55206 L p
1 g
F P
s
P
p
.002 w
.77503 .53546 m .78283 .48509 L .77496 .46968 L p
1 g
F P
s
P
p
.002 w
.72529 .36484 m .74433 .40972 L .75186 .42446 L p
1 g
F P
s
P
p
.002 w
.74433 .40972 m .72529 .36484 L .71832 .35145 L p
1 g
F P
s
P
p
.002 w
.22204 .59308 m .248 .64567 L .25523 .62802 L p
1 g
F P
s
P
p
.002 w
.25523 .62802 m .23023 .57627 L .22204 .59308 L p
1 g
F P
s
P
p
.002 w
.66003 .27742 m .69791 .31226 L .70462 .32516 L p
1 g
F P
s
P
p
.002 w
.69791 .31226 m .66003 .27742 L .65473 .26579 L p
1 g
F P
s
P
p
.002 w
.83699 .67284 m .79332 .72368 L .80005 .74225 L p
1 g
F P
s
P
p
.002 w
.79332 .72368 m .83699 .67284 L .82898 .65508 L p
1 g
F P
s
P
p
.002 w
.34424 .33143 m .31387 .37304 L .32113 .35922 L p
1 g
F P
s
P
p
.002 w
.32113 .35922 m .35059 .31877 L .34424 .33143 L p
1 g
F P
s
P
p
.002 w
.7908 .50068 m .78252 .55206 L .79008 .56881 L p
1 g
F P
s
P
p
.002 w
.78252 .55206 m .7908 .50068 L .78283 .48509 L p
1 g
F P
s
P
p
.002 w
.27623 .4447 m .26987 .49483 L .27756 .47904 L p
1 g
F P
s
P
p
.002 w
.27756 .47904 m .28394 .43002 L .27623 .4447 L p
1 g
F P
s
P
p
.002 w
.41002 .26352 m .36302 .29396 L .36912 .2818 L p
1 g
F P
s
P
p
.002 w
.36912 .2818 m .41439 .25234 L .41002 .26352 L p
1 g
F P
s
P
p
.002 w
.21377 .61008 m .24071 .66347 L .248 .64567 L p
1 g
F P
s
P
p
.002 w
.248 .64567 m .22204 .59308 L .21377 .61008 L p
1 g
F P
s
P
p
.002 w
.80005 .74225 m .84509 .69079 L .83699 .67284 L p
1 g
F P
s
P
p
.002 w
.73236 .37841 m .75186 .42446 L .75947 .43936 L p
1 g
F P
s
P
p
.002 w
.75186 .42446 m .73236 .37841 L .72529 .36484 L p
1 g
F P
s
P
p
.002 w
.6654 .28921 m .70462 .32516 L .71143 .33822 L p
1 g
F P
s
P
p
.002 w
.70462 .32516 m .6654 .28921 L .66003 .27742 L p
1 g
F P
s
P
p
.002 w
.79885 .51645 m .79008 .56881 L .79771 .58573 L p
1 g
F P
s
P
p
.002 w
.79008 .56881 m .79885 .51645 L .7908 .50068 L p
1 g
F P
s
P
p
.002 w
.33781 .34426 m .30652 .38703 L .31387 .37304 L p
1 g
F P
s
P
p
.002 w
.31387 .37304 m .34424 .33143 L .33781 .34426 L p
1 g
F P
s
P
p
.002 w
.26842 .45956 m .26211 .51078 L .26987 .49483 L p
1 g
F P
s
P
p
.002 w
.26987 .49483 m .27623 .4447 L .26842 .45956 L p
1 g
F P
s
P
p
.002 w
.20541 .62725 m .23335 .68142 L .24071 .66347 L p
1 g
F P
s
P
p
.002 w
.24071 .66347 m .21377 .61008 L .20541 .62725 L p
1 g
F P
s
P
p
.002 w
.40559 .27485 m .35685 .30628 L .36302 .29396 L p
1 g
F P
s
P
p
.002 w
.36302 .29396 m .41002 .26352 L .40559 .27485 L p
1 g
F P
s
P
p
.002 w
.73952 .39215 m .75947 .43936 L .76717 .45443 L p
1 g
F P
s
P
p
.002 w
.75947 .43936 m .73952 .39215 L .73236 .37841 L p
1 g
F P
s
P
p
.002 w
.807 .5324 m .79771 .58573 L .80541 .60282 L p
1 g
F P
s
P
p
.002 w
.79771 .58573 m .807 .5324 L .79885 .51645 L p
1 g
F P
s
P
p
.002 w
.60177 .24169 m .65473 .26579 L .66003 .27742 L p
1 g
F P
s
P
p
.002 w
.26052 .4746 m .25426 .52689 L .26211 .51078 L p
1 g
F P
s
P
p
.002 w
.26211 .51078 m .26842 .45956 L .26052 .4746 L p
1 g
F P
s
P
p
.002 w
.67085 .30117 m .71143 .33822 L .71832 .35145 L p
1 g
F P
s
P
p
.002 w
.71143 .33822 m .67085 .30117 L .6654 .28921 L p
1 g
F P
s
P
p
.002 w
.33129 .35726 m .29908 .40119 L .30652 .38703 L p
1 g
F P
s
P
p
.002 w
.30652 .38703 m .33781 .34426 L .33129 .35726 L p
1 g
F P
s
P
p
.002 w
.19696 .64462 m .22592 .69954 L .23335 .68142 L p
1 g
F P
s
P
p
.002 w
.23335 .68142 m .20541 .62725 L .19696 .64462 L p
1 g
F P
s
P
p
.002 w
.81525 .54854 m .80541 .60282 L .81319 .62007 L p
1 g
F P
s
P
p
.002 w
.80541 .60282 m .81525 .54854 L .807 .5324 L p
1 g
F P
s
P
p
.002 w
.74677 .40608 m .76717 .45443 L .77496 .46968 L p
1 g
F P
s
P
p
.002 w
.76717 .45443 m .74677 .40608 L .73952 .39215 L p
1 g
F P
s
P
p
.002 w
.40109 .28635 m .35059 .31877 L .35685 .30628 L p
1 g
F P
s
P
p
.002 w
.35685 .30628 m .40559 .27485 L .40109 .28635 L p
1 g
F P
s
P
p
.002 w
.25252 .48983 m .24634 .54318 L .25426 .52689 L p
1 g
F P
s
P
p
.002 w
.25426 .52689 m .26052 .4746 L .25252 .48983 L p
1 g
F P
s
P
p
.002 w
.18841 .66217 m .21843 .71783 L .22592 .69954 L p
1 g
F P
s
P
p
.002 w
.22592 .69954 m .19696 .64462 L .18841 .66217 L p
1 g
F P
s
P
p
.002 w
.32468 .37044 m .29155 .41552 L .29908 .40119 L p
1 g
F P
s
P
p
.002 w
.29908 .40119 m .33129 .35726 L .32468 .37044 L p
1 g
F P
s
P
p
.002 w
.60499 .25249 m .66003 .27742 L .6654 .28921 L p
1 g
F P
s
P
p
.002 w
.66003 .27742 m .60499 .25249 L .60177 .24169 L p
1 g
F P
s
P
p
.002 w
.67637 .3133 m .71832 .35145 L .72529 .36484 L p
1 g
F P
s
P
p
.002 w
.71832 .35145 m .67637 .3133 L .67085 .30117 L p
1 g
F P
s
P
p
.002 w
.47131 .24497 m .41002 .26352 L .41439 .25234 L p
1 g
F P
s
P
p
.002 w
.41439 .25234 m .47331 .23442 L .47131 .24497 L p
1 g
F P
s
P
p
.002 w
.82359 .56487 m .81319 .62007 L .82105 .63749 L p
1 g
F P
s
P
p
.002 w
.81319 .62007 m .82359 .56487 L .81525 .54854 L p
1 g
F P
s
P
p
.002 w
.75412 .42018 m .77496 .46968 L .78283 .48509 L p
1 g
F P
s
P
p
.002 w
.77496 .46968 m .75412 .42018 L .74677 .40608 L p
1 g
F P
s
P
p
.002 w
.24442 .50525 m .23832 .55964 L .24634 .54318 L p
1 g
F P
s
P
p
.002 w
.24634 .54318 m .25252 .48983 L .24442 .50525 L p
1 g
F P
s
P
p
.002 w
.39653 .29802 m .34424 .33143 L .35059 .31877 L p
1 g
F P
s
P
p
.002 w
.35059 .31877 m .40109 .28635 L .39653 .29802 L p
1 g
F P
s
P
p
.002 w
.53861 .23068 m .60177 .24169 L .60499 .25249 L p
1 g
F P
s
P
p
.002 w
.31798 .38381 m .28394 .43002 L .29155 .41552 L p
1 g
F P
s
P
p
.002 w
.29155 .41552 m .32468 .37044 L .31798 .38381 L p
1 g
F P
s
P
p
.002 w
.68197 .3256 m .72529 .36484 L .73236 .37841 L p
1 g
F P
s
P
p
.002 w
.72529 .36484 m .68197 .3256 L .67637 .3133 L p
1 g
F P
s
P
p
.002 w
.60825 .26346 m .6654 .28921 L .67085 .30117 L p
1 g
F P
s
P
p
.002 w
.6654 .28921 m .60825 .26346 L .60499 .25249 L p
1 g
F P
s
P
p
.002 w
.83203 .58138 m .82105 .63749 L .82898 .65508 L p
1 g
F P
s
P
p
.002 w
.82105 .63749 m .83203 .58138 L .82359 .56487 L p
1 g
F P
s
P
p
.002 w
.46927 .25568 m .40559 .27485 L .41002 .26352 L p
1 g
F P
s
P
p
.002 w
.41002 .26352 m .47131 .24497 L .46927 .25568 L p
1 g
F P
s
P
p
.002 w
.76157 .43447 m .78283 .48509 L .7908 .50068 L p
1 g
F P
s
P
p
.002 w
.78283 .48509 m .76157 .43447 L .75412 .42018 L p
1 g
F P
s
P
p
.002 w
.23621 .52087 m .23023 .57627 L .23832 .55964 L p
1 g
F P
s
P
p
.002 w
.23832 .55964 m .24442 .50525 L .23621 .52087 L p
1 g
F P
s
P
p
.002 w
.53926 .2411 m .47131 .24497 L .47331 .23442 L p
1 g
F P
s
P
p
.002 w
.47331 .23442 m .53861 .23068 L .53926 .2411 L p
1 g
F P
s
P
p
.002 w
.39189 .30986 m .33781 .34426 L .34424 .33143 L p
1 g
F P
s
P
p
.002 w
.34424 .33143 m .39653 .29802 L .39189 .30986 L p
1 g
F P
s
P
p
.002 w
.60499 .25249 m .53926 .2411 L .53861 .23068 L p
1 g
F P
s
P
p
.002 w
.31118 .39736 m .27623 .4447 L .28394 .43002 L p
1 g
F P
s
P
p
.002 w
.28394 .43002 m .31798 .38381 L .31118 .39736 L p
1 g
F P
s
P
p
.002 w
.84057 .5981 m .82898 .65508 L .83699 .67284 L p
1 g
F P
s
P
p
.002 w
.82898 .65508 m .84057 .5981 L .83203 .58138 L p
1 g
F P
s
P
p
.002 w
.68766 .33807 m .73236 .37841 L .73952 .39215 L p
1 g
F P
s
P
p
.002 w
.73236 .37841 m .68766 .33807 L .68197 .3256 L p
1 g
F P
s
P
p
.002 w
.53926 .2411 m .60499 .25249 L .60825 .26346 L p
1 g
F P
s
P
p
.002 w
.61157 .27459 m .67085 .30117 L .67637 .3133 L p
1 g
F P
s
P
p
.002 w
.67085 .30117 m .61157 .27459 L .60825 .26346 L p
1 g
F P
s
P
p
.002 w
.22791 .53668 m .22204 .59308 L .23023 .57627 L p
1 g
F P
s
P
p
.002 w
.23023 .57627 m .23621 .52087 L .22791 .53668 L p
1 g
F P
s
P
p
.002 w
.46719 .26656 m .40109 .28635 L .40559 .27485 L p
1 g
F P
s
P
p
.002 w
.40559 .27485 m .46927 .25568 L .46719 .26656 L p
1 g
F P
s
P
p
.002 w
.76911 .44896 m .7908 .50068 L .79885 .51645 L p
1 g
F P
s
P
p
.002 w
.7908 .50068 m .76911 .44896 L .76157 .43447 L p
1 g
F P
s
P
p
.002 w
.84921 .61501 m .83699 .67284 L .84509 .69079 L p
1 g
F P
s
P
p
.002 w
.83699 .67284 m .84921 .61501 L .84057 .5981 L p
1 g
F P
s
P
p
.002 w
.53993 .25168 m .46927 .25568 L .47131 .24497 L p
1 g
F P
s
P
p
.002 w
.47131 .24497 m .53926 .2411 L .53993 .25168 L p
1 g
F P
s
P
p
.002 w
.38719 .32189 m .33129 .35726 L .33781 .34426 L p
1 g
F P
s
P
p
.002 w
.33781 .34426 m .39189 .30986 L .38719 .32189 L p
1 g
F P
s
P
p
.002 w
.30429 .4111 m .26842 .45956 L .27623 .4447 L p
1 g
F P
s
P
p
.002 w
.27623 .4447 m .31118 .39736 L .30429 .4111 L p
1 g
F P
s
P
p
.002 w
.60825 .26346 m .53993 .25168 L .53926 .2411 L p
1 g
F P
s
P
p
.002 w
.69342 .35073 m .73952 .39215 L .74677 .40608 L p
1 g
F P
s
P
p
.002 w
.73952 .39215 m .69342 .35073 L .68766 .33807 L p
1 g
F P
s
P
p
.002 w
.21949 .5527 m .21377 .61008 L .22204 .59308 L p
1 g
F P
s
P
p
.002 w
.22204 .59308 m .22791 .53668 L .21949 .5527 L p
1 g
F P
s
P
p
.002 w
.77675 .46363 m .79885 .51645 L .807 .5324 L p
1 g
F P
s
P
p
.002 w
.79885 .51645 m .77675 .46363 L .76911 .44896 L p
1 g
F P
s
P
p
.002 w
.53993 .25168 m .60825 .26346 L .61157 .27459 L p
1 g
F P
s
P
p
.002 w
.61493 .2859 m .67637 .3133 L .68197 .3256 L p
1 g
F P
s
P
p
.002 w
.67637 .3133 m .61493 .2859 L .61157 .27459 L p
1 g
F P
s
P
p
.002 w
.46509 .27761 m .39653 .29802 L .40109 .28635 L p
1 g
F P
s
P
p
.002 w
.40109 .28635 m .46719 .26656 L .46509 .27761 L p
1 g
F P
s
P
p
.002 w
.84509 .69079 m .85795 .63213 L .84921 .61501 L p
1 g
F P
s
P
p
.002 w
.29731 .42504 m .26052 .4746 L .26842 .45956 L p
1 g
F P
s
P
p
.002 w
.26842 .45956 m .30429 .4111 L .29731 .42504 L p
1 g
F P
s
P
p
.002 w
.38242 .33409 m .32468 .37044 L .33129 .35726 L p
1 g
F P
s
P
p
.002 w
.33129 .35726 m .38719 .32189 L .38242 .33409 L p
1 g
F P
s
P
p
.002 w
.5406 .26243 m .46719 .26656 L .46927 .25568 L p
1 g
F P
s
P
p
.002 w
.46927 .25568 m .53993 .25168 L .5406 .26243 L p
1 g
F P
s
P
p
.002 w
.21097 .56892 m .20541 .62725 L .21377 .61008 L p
1 g
F P
s
P
p
.002 w
.21377 .61008 m .21949 .5527 L .21097 .56892 L p
1 g
F P
s
P
p
.002 w
.69927 .36358 m .74677 .40608 L .75412 .42018 L p
1 g
F P
s
P
p
.002 w
.74677 .40608 m .69927 .36358 L .69342 .35073 L p
1 g
F P
s
P
p
.002 w
.7845 .47851 m .807 .5324 L .81525 .54854 L p
1 g
F P
s
P
p
.002 w
.807 .5324 m .7845 .47851 L .77675 .46363 L p
1 g
F P
s
P
p
.002 w
.61157 .27459 m .5406 .26243 L .53993 .25168 L p
1 g
F P
s
P
p
.002 w
.61835 .29737 m .68197 .3256 L .68766 .33807 L p
1 g
F P
s
P
p
.002 w
.68197 .3256 m .61835 .29737 L .61493 .2859 L p
1 g
F P
s
P
p
.002 w
.5406 .26243 m .61157 .27459 L .61493 .2859 L p
1 g
F P
s
P
p
.002 w
.46295 .28883 m .39189 .30986 L .39653 .29802 L p
1 g
F P
s
P
p
.002 w
.39653 .29802 m .46509 .27761 L .46295 .28883 L p
1 g
F P
s
P
p
.002 w
.29022 .43918 m .25252 .48983 L .26052 .4746 L p
1 g
F P
s
P
p
.002 w
.26052 .4746 m .29731 .42504 L .29022 .43918 L p
1 g
F P
s
P
p
.002 w
.20234 .58535 m .19696 .64462 L .20541 .62725 L p
1 g
F P
s
P
p
.002 w
.20541 .62725 m .21097 .56892 L .20234 .58535 L p
1 g
F P
s
P
p
.002 w
.37757 .34648 m .31798 .38381 L .32468 .37044 L p
1 g
F P
s
P
p
.002 w
.32468 .37044 m .38242 .33409 L .37757 .34648 L p
1 g
F P
s
P
p
.002 w
.79236 .49358 m .81525 .54854 L .82359 .56487 L p
1 g
F P
s
P
p
.002 w
.81525 .54854 m .79236 .49358 L .7845 .47851 L p
1 g
F P
s
P
p
.002 w
.70521 .37661 m .75412 .42018 L .76157 .43447 L p
1 g
F P
s
P
p
.002 w
.75412 .42018 m .70521 .37661 L .69927 .36358 L p
1 g
F P
s
P
p
.002 w
.54129 .27334 m .46509 .27761 L .46719 .26656 L p
1 g
F P
s
P
p
.002 w
.46719 .26656 m .5406 .26243 L .54129 .27334 L p
1 g
F P
s
P
p
.002 w
.61493 .2859 m .54129 .27334 L .5406 .26243 L p
1 g
F P
s
P
p
.002 w
.62182 .30903 m .68766 .33807 L .69342 .35073 L p
1 g
F P
s
P
p
.002 w
.68766 .33807 m .62182 .30903 L .61835 .29737 L p
1 g
F P
s
P
p
.002 w
.54129 .27334 m .61493 .2859 L .61835 .29737 L p
1 g
F P
s
P
p
.002 w
.1936 .602 m .18841 .66217 L .19696 .64462 L p
1 g
F P
s
P
p
.002 w
.19696 .64462 m .20234 .58535 L .1936 .602 L p
1 g
F P
s
P
p
.002 w
.28303 .45352 m .24442 .50525 L .25252 .48983 L p
1 g
F P
s
P
p
.002 w
.25252 .48983 m .29022 .43918 L .28303 .45352 L p
1 g
F P
s
P
p
.002 w
.46078 .30023 m .38719 .32189 L .39189 .30986 L p
1 g
F P
s
P
p
.002 w
.39189 .30986 m .46295 .28883 L .46078 .30023 L p
1 g
F P
s
P
p
.002 w
.80032 .50886 m .82359 .56487 L .83203 .58138 L p
1 g
F P
s
P
p
.002 w
.82359 .56487 m .80032 .50886 L .79236 .49358 L p
1 g
F P
s
P
p
.002 w
.37265 .35907 m .31118 .39736 L .31798 .38381 L p
1 g
F P
s
P
p
.002 w
.31798 .38381 m .37757 .34648 L .37265 .35907 L p
1 g
F P
s
P
p
.002 w
.71124 .38983 m .76157 .43447 L .76911 .44896 L p
1 g
F P
s
P
p
.002 w
.76157 .43447 m .71124 .38983 L .70521 .37661 L p
1 g
F P
s
P
p
.002 w
.54198 .28443 m .46295 .28883 L .46509 .27761 L p
1 g
F P
s
P
p
.002 w
.46509 .27761 m .54129 .27334 L .54198 .28443 L p
1 g
F P
s
P
p
.002 w
.61835 .29737 m .54198 .28443 L .54129 .27334 L p
1 g
F P
s
P
p
.002 w
.62534 .32086 m .69342 .35073 L .69927 .36358 L p
1 g
F P
s
P
p
.002 w
.69342 .35073 m .62534 .32086 L .62182 .30903 L p
1 g
F P
s
P
p
.002 w
.27574 .46806 m .23621 .52087 L .24442 .50525 L p
1 g
F P
s
P
p
.002 w
.24442 .50525 m .28303 .45352 L .27574 .46806 L p
1 g
F P
s
P
p
.002 w
.54198 .28443 m .61835 .29737 L .62182 .30903 L p
1 g
F P
s
P
p
.002 w
.80839 .52436 m .83203 .58138 L .84057 .5981 L p
1 g
F P
s
P
p
.002 w
.83203 .58138 m .80839 .52436 L .80032 .50886 L p
1 g
F P
s
P
p
.002 w
.45858 .31181 m .38242 .33409 L .38719 .32189 L p
1 g
F P
s
P
p
.002 w
.38719 .32189 m .46078 .30023 L .45858 .31181 L p
1 g
F P
s
P
p
.002 w
.36765 .37184 m .30429 .4111 L .31118 .39736 L p
1 g
F P
s
P
p
.002 w
.31118 .39736 m .37265 .35907 L .36765 .37184 L p
1 g
F P
s
P
p
.002 w
.71735 .40326 m .76911 .44896 L .77675 .46363 L p
1 g
F P
s
P
p
.002 w
.76911 .44896 m .71735 .40326 L .71124 .38983 L p
1 g
F P
s
P
p
.002 w
.54269 .2957 m .46078 .30023 L .46295 .28883 L p
1 g
F P
s
P
p
.002 w
.46295 .28883 m .54198 .28443 L .54269 .2957 L p
1 g
F P
s
P
p
.002 w
.26834 .48282 m .22791 .53668 L .23621 .52087 L p
1 g
F P
s
P
p
.002 w
.23621 .52087 m .27574 .46806 L .26834 .48282 L p
1 g
F P
s
P
p
.002 w
.81657 .54006 m .84057 .5981 L .84921 .61501 L p
1 g
F P
s
P
p
.002 w
.84057 .5981 m .81657 .54006 L .80839 .52436 L p
1 g
F P
s
P
p
.002 w
.62892 .33289 m .69927 .36358 L .70521 .37661 L p
1 g
F P
s
P
p
.002 w
.69927 .36358 m .62892 .33289 L .62534 .32086 L p
1 g
F P
s
P
p
.002 w
.62182 .30903 m .54269 .2957 L .54198 .28443 L p
1 g
F P
s
P
p
.002 w
.54269 .2957 m .62182 .30903 L .62534 .32086 L p
1 g
F P
s
P
p
.002 w
.45633 .32358 m .37757 .34648 L .38242 .33409 L p
1 g
F P
s
P
p
.002 w
.38242 .33409 m .45858 .31181 L .45633 .32358 L p
1 g
F P
s
P
p
.002 w
.72356 .41689 m .77675 .46363 L .7845 .47851 L p
1 g
F P
s
P
p
.002 w
.77675 .46363 m .72356 .41689 L .71735 .40326 L p
1 g
F P
s
P
p
.002 w
.36258 .38482 m .29731 .42504 L .30429 .4111 L p
1 g
F P
s
P
p
.002 w
.30429 .4111 m .36765 .37184 L .36258 .38482 L p
1 g
F P
s
P
p
.002 w
.26083 .4978 m .21949 .5527 L .22791 .53668 L p
1 g
F P
s
P
p
.002 w
.22791 .53668 m .26834 .48282 L .26083 .4978 L p
1 g
F P
s
P
p
.002 w
.82486 .55599 m .84921 .61501 L .85795 .63213 L p
1 g
F P
s
P
p
.002 w
.84921 .61501 m .82486 .55599 L .81657 .54006 L p
1 g
F P
s
P
p
.002 w
.54341 .30715 m .45858 .31181 L .46078 .30023 L p
1 g
F P
s
P
p
.002 w
.46078 .30023 m .54269 .2957 L .54341 .30715 L p
1 g
F P
s
P
p
.002 w
.63256 .3451 m .70521 .37661 L .71124 .38983 L p
1 g
F P
s
P
p
.002 w
.70521 .37661 m .63256 .3451 L .62892 .33289 L p
1 g
F P
s
P
p
.002 w
.62534 .32086 m .54341 .30715 L .54269 .2957 L p
1 g
F P
s
P
p
.002 w
.72986 .43072 m .7845 .47851 L .79236 .49358 L p
1 g
F P
s
P
p
.002 w
.7845 .47851 m .72986 .43072 L .72356 .41689 L p
1 g
F P
s
P
p
.002 w
.54341 .30715 m .62534 .32086 L .62892 .33289 L p
1 g
F P
s
P
p
.002 w
.45406 .33554 m .37265 .35907 L .37757 .34648 L p
1 g
F P
s
P
p
.002 w
.37757 .34648 m .45633 .32358 L .45406 .33554 L p
1 g
F P
s
P
p
.002 w
.35742 .398 m .29022 .43918 L .29731 .42504 L p
1 g
F P
s
P
p
.002 w
.29731 .42504 m .36258 .38482 L .35742 .398 L p
1 g
F P
s
P
p
.002 w
.85795 .63213 m .83327 .57214 L .82486 .55599 L p
1 g
F P
s
P
p
.002 w
.25321 .513 m .21097 .56892 L .21949 .5527 L p
1 g
F P
s
P
p
.002 w
.21949 .5527 m .26083 .4978 L .25321 .513 L p
1 g
F P
s
P
p
.002 w
.54414 .31878 m .45633 .32358 L .45858 .31181 L p
1 g
F P
s
P
p
.002 w
.45858 .31181 m .54341 .30715 L .54414 .31878 L p
1 g
F P
s
P
p
.002 w
.63625 .35752 m .71124 .38983 L .71735 .40326 L p
1 g
F P
s
P
p
.002 w
.71124 .38983 m .63625 .35752 L .63256 .3451 L p
1 g
F P
s
P
p
.002 w
.73626 .44476 m .79236 .49358 L .80032 .50886 L p
1 g
F P
s
P
p
.002 w
.79236 .49358 m .73626 .44476 L .72986 .43072 L p
1 g
F P
s
P
p
.002 w
.62892 .33289 m .54414 .31878 L .54341 .30715 L p
1 g
F P
s
P
p
.002 w
.35218 .41139 m .28303 .45352 L .29022 .43918 L p
1 g
F P
s
P
p
.002 w
.29022 .43918 m .35742 .398 L .35218 .41139 L p
1 g
F P
s
P
p
.002 w
.54414 .31878 m .62892 .33289 L .63256 .3451 L p
1 g
F P
s
P
p
.002 w
.45174 .3477 m .36765 .37184 L .37265 .35907 L p
1 g
F P
s
P
p
.002 w
.37265 .35907 m .45406 .33554 L .45174 .3477 L p
1 g
F P
s
P
p
.002 w
.24548 .52842 m .20234 .58535 L .21097 .56892 L p
1 g
F P
s
P
p
.002 w
.21097 .56892 m .25321 .513 L .24548 .52842 L p
1 g
F P
s
P
p
.002 w
.54488 .33061 m .45406 .33554 L .45633 .32358 L p
1 g
F P
s
P
p
.002 w
.45633 .32358 m .54414 .31878 L .54488 .33061 L p
1 g
F P
s
P
p
.002 w
.64001 .37013 m .71735 .40326 L .72356 .41689 L p
1 g
F P
s
P
p
.002 w
.71735 .40326 m .64001 .37013 L .63625 .35752 L p
1 g
F P
s
P
p
.002 w
.74275 .45903 m .80032 .50886 L .80839 .52436 L p
1 g
F P
s
P
p
.002 w
.80032 .50886 m .74275 .45903 L .73626 .44476 L p
1 g
F P
s
P
p
.002 w
.34686 .425 m .27574 .46806 L .28303 .45352 L p
1 g
F P
s
P
p
.002 w
.28303 .45352 m .35218 .41139 L .34686 .425 L p
1 g
F P
s
P
p
.002 w
.23763 .54408 m .1936 .602 L .20234 .58535 L p
1 g
F P
s
P
p
.002 w
.20234 .58535 m .24548 .52842 L .23763 .54408 L p
1 g
F P
s
P
p
.002 w
.63256 .3451 m .54488 .33061 L .54414 .31878 L p
1 g
F P
s
P
p
.002 w
.44939 .36006 m .36258 .38482 L .36765 .37184 L p
1 g
F P
s
P
p
.002 w
.36765 .37184 m .45174 .3477 L .44939 .36006 L p
1 g
F P
s
P
p
.002 w
.54488 .33061 m .63256 .3451 L .63625 .35752 L p
1 g
F P
s
P
p
.002 w
.74935 .47351 m .80839 .52436 L .81657 .54006 L p
1 g
F P
s
P
p
.002 w
.80839 .52436 m .74935 .47351 L .74275 .45903 L p
1 g
F P
s
P
p
.002 w
.64382 .38294 m .72356 .41689 L .72986 .43072 L p
1 g
F P
s
P
p
.002 w
.72356 .41689 m .64382 .38294 L .64001 .37013 L p
1 g
F P
s
P
p
.002 w
.54564 .34263 m .45174 .3477 L .45406 .33554 L p
1 g
F P
s
P
p
.002 w
.45406 .33554 m .54488 .33061 L .54564 .34263 L p
1 g
F P
s
P
p
.002 w
.34146 .43882 m .26834 .48282 L .27574 .46806 L p
1 g
F P
s
P
p
.002 w
.27574 .46806 m .34686 .425 L .34146 .43882 L p
1 g
F P
s
P
p
.002 w
.447 .37262 m .35742 .398 L .36258 .38482 L p
1 g
F P
s
P
p
.002 w
.36258 .38482 m .44939 .36006 L .447 .37262 L p
1 g
F P
s
P
p
.002 w
.54564 .34263 m .63625 .35752 L .64001 .37013 L p
1 g
F P
s
P
p
.002 w
.63625 .35752 m .54564 .34263 L .54488 .33061 L p
1 g
F P
s
P
p
.002 w
.75605 .48822 m .81657 .54006 L .82486 .55599 L p
1 g
F P
s
P
p
.002 w
.81657 .54006 m .75605 .48822 L .74935 .47351 L p
1 g
F P
s
P
p
.002 w
.6477 .39597 m .72986 .43072 L .73626 .44476 L p
1 g
F P
s
P
p
.002 w
.72986 .43072 m .6477 .39597 L .64382 .38294 L p
1 g
F P
s
P
p
.002 w
.33596 .45287 m .26083 .4978 L .26834 .48282 L p
1 g
F P
s
P
p
.002 w
.26834 .48282 m .34146 .43882 L .33596 .45287 L p
1 g
F P
s
P
p
.002 w
.54641 .35486 m .44939 .36006 L .45174 .3477 L p
1 g
F P
s
P
p
.002 w
.45174 .3477 m .54564 .34263 L .54641 .35486 L p
1 g
F P
s
P
p
.002 w
.44456 .38539 m .35218 .41139 L .35742 .398 L p
1 g
F P
s
P
p
.002 w
.35742 .398 m .447 .37262 L .44456 .38539 L p
1 g
F P
s
P
p
.002 w
.54641 .35486 m .64001 .37013 L .64382 .38294 L p
1 g
F P
s
P
p
.002 w
.64001 .37013 m .54641 .35486 L .54564 .34263 L p
1 g
F P
s
P
p
.002 w
.76286 .50316 m .82486 .55599 L .83327 .57214 L p
1 g
F P
s
P
p
.002 w
.82486 .55599 m .76286 .50316 L .75605 .48822 L p
1 g
F P
s
P
p
.002 w
.65164 .40921 m .73626 .44476 L .74275 .45903 L p
1 g
F P
s
P
p
.002 w
.73626 .44476 m .65164 .40921 L .6477 .39597 L p
1 g
F P
s
P
p
.002 w
.33038 .46715 m .25321 .513 L .26083 .4978 L p
1 g
F P
s
P
p
.002 w
.26083 .4978 m .33596 .45287 L .33038 .46715 L p
1 g
F P
s
P
p
.002 w
.54719 .36729 m .447 .37262 L .44939 .36006 L p
1 g
F P
s
P
p
.002 w
.44939 .36006 m .54641 .35486 L .54719 .36729 L p
1 g
F P
s
P
p
.002 w
.44209 .39838 m .34686 .425 L .35218 .41139 L p
1 g
F P
s
P
p
.002 w
.35218 .41139 m .44456 .38539 L .44209 .39838 L p
1 g
F P
s
P
p
.002 w
.54719 .36729 m .64382 .38294 L .6477 .39597 L p
1 g
F P
s
P
p
.002 w
.64382 .38294 m .54719 .36729 L .54641 .35486 L p
1 g
F P
s
P
p
.002 w
.83327 .57214 m .76977 .51834 L .76286 .50316 L p
1 g
F P
s
P
p
.002 w
.65565 .42268 m .74275 .45903 L .74935 .47351 L p
1 g
F P
s
P
p
.002 w
.74275 .45903 m .65565 .42268 L .65164 .40921 L p
1 g
F P
s
P
p
.002 w
.3247 .48166 m .24548 .52842 L .25321 .513 L p
1 g
F P
s
P
p
.002 w
.25321 .513 m .33038 .46715 L .3247 .48166 L p
1 g
F P
s
P
p
.002 w
.54798 .37993 m .44456 .38539 L .447 .37262 L p
1 g
F P
s
P
p
.002 w
.447 .37262 m .54719 .36729 L .54798 .37993 L p
1 g
F P
s
P
p
.002 w
.43957 .41159 m .34146 .43882 L .34686 .425 L p
1 g
F P
s
P
p
.002 w
.34686 .425 m .44209 .39838 L .43957 .41159 L p
1 g
F P
s
P
p
.002 w
.54798 .37993 m .6477 .39597 L .65164 .40921 L p
1 g
F P
s
P
p
.002 w
.6477 .39597 m .54798 .37993 L .54719 .36729 L p
1 g
F P
s
P
p
.002 w
.65973 .43637 m .74935 .47351 L .75605 .48822 L p
1 g
F P
s
P
p
.002 w
.74935 .47351 m .65973 .43637 L .65565 .42268 L p
1 g
F P
s
P
p
.002 w
.31893 .49642 m .23763 .54408 L .24548 .52842 L p
1 g
F P
s
P
p
.002 w
.24548 .52842 m .3247 .48166 L .31893 .49642 L p
1 g
F P
s
P
p
.002 w
.54879 .39279 m .44209 .39838 L .44456 .38539 L p
1 g
F P
s
P
p
.002 w
.44456 .38539 m .54798 .37993 L .54879 .39279 L p
1 g
F P
s
P
p
.002 w
.43701 .42503 m .33596 .45287 L .34146 .43882 L p
1 g
F P
s
P
p
.002 w
.34146 .43882 m .43957 .41159 L .43701 .42503 L p
1 g
F P
s
P
p
.002 w
.54879 .39279 m .65164 .40921 L .65565 .42268 L p
1 g
F P
s
P
p
.002 w
.65164 .40921 m .54879 .39279 L .54798 .37993 L p
1 g
F P
s
P
p
.002 w
.66387 .45029 m .75605 .48822 L .76286 .50316 L p
1 g
F P
s
P
p
.002 w
.75605 .48822 m .66387 .45029 L .65973 .43637 L p
1 g
F P
s
P
p
.002 w
.54961 .40587 m .43957 .41159 L .44209 .39838 L p
1 g
F P
s
P
p
.002 w
.44209 .39838 m .54879 .39279 L .54961 .40587 L p
1 g
F P
s
P
p
.002 w
.43441 .43871 m .33038 .46715 L .33596 .45287 L p
1 g
F P
s
P
p
.002 w
.33596 .45287 m .43701 .42503 L .43441 .43871 L p
1 g
F P
s
P
p
.002 w
.54961 .40587 m .65565 .42268 L .65973 .43637 L p
1 g
F P
s
P
p
.002 w
.65565 .42268 m .54961 .40587 L .54879 .39279 L p
1 g
F P
s
P
p
.002 w
.66809 .46445 m .76286 .50316 L .76977 .51834 L p
1 g
F P
s
P
p
.002 w
.76286 .50316 m .66809 .46445 L .66387 .45029 L p
1 g
F P
s
P
p
.002 w
.55045 .41918 m .43701 .42503 L .43957 .41159 L p
1 g
F P
s
P
p
.002 w
.43957 .41159 m .54961 .40587 L .55045 .41918 L p
1 g
F P
s
P
p
.002 w
.43176 .45262 m .3247 .48166 L .33038 .46715 L p
1 g
F P
s
P
p
.002 w
.33038 .46715 m .43441 .43871 L .43176 .45262 L p
1 g
F P
s
P
p
.002 w
.55045 .41918 m .65973 .43637 L .66387 .45029 L p
1 g
F P
s
P
p
.002 w
.65973 .43637 m .55045 .41918 L .54961 .40587 L p
1 g
F P
s
P
p
.002 w
.76977 .51834 m .67238 .47886 L .66809 .46445 L p
1 g
F P
s
P
p
.002 w
.5513 .43272 m .43441 .43871 L .43701 .42503 L p
1 g
F P
s
P
p
.002 w
.43701 .42503 m .55045 .41918 L .5513 .43272 L p
1 g
F P
s
P
p
.002 w
.42906 .46678 m .31893 .49642 L .3247 .48166 L p
1 g
F P
s
P
p
.002 w
.3247 .48166 m .43176 .45262 L .42906 .46678 L p
1 g
F P
s
P
p
.002 w
.5513 .43272 m .66387 .45029 L .66809 .46445 L p
1 g
F P
s
P
p
.002 w
.66387 .45029 m .5513 .43272 L .55045 .41918 L p
1 g
F P
s
P
p
.002 w
.55216 .4465 m .43176 .45262 L .43441 .43871 L p
1 g
F P
s
P
p
.002 w
.43441 .43871 m .5513 .43272 L .55216 .4465 L p
1 g
F P
s
P
p
.002 w
.55216 .4465 m .66809 .46445 L .67238 .47886 L p
1 g
F P
s
P
p
.002 w
.66809 .46445 m .55216 .4465 L .5513 .43272 L p
1 g
F P
s
P
p
.002 w
.55305 .46053 m .42906 .46678 L .43176 .45262 L p
1 g
F P
s
P
p
.002 w
.43176 .45262 m .55216 .4465 L .55305 .46053 L p
1 g
F P
s
P
p
.002 w
.67238 .47886 m .55305 .46053 L .55216 .4465 L p
1 g
F P
s
P
p
.002 w
.67336 .02496 m
.93252 .42969 L
s
.93252 .42969 m
.97504 .74153 L
s
.97504 .74153 m
.69303 .36652 L
s
.69303 .36652 m
.67336 .02496 L
s
.07656 .26444 m
.02496 .59065 L
s
.02496 .59065 m
.69303 .36652 L
s
.69303 .36652 m
.67336 .02496 L
s
.67336 .02496 m
.07656 .26444 L
s
P
p
p
.002 w
.07656 .26444 m
.67336 .02496 L
s
P
p
.002 w
.08681 .26032 m
.09129 .26467 L
s
P
[(-0.4)] .07786 .25163 1 .97024 Mshowa
p
.002 w
.21728 .20797 m
.22155 .21253 L
s
P
[(-0.2)] .20876 .19886 .93566 1 Mshowa
p
.002 w
.35519 .15263 m
.3592 .15741 L
s
P
[(0)] .34716 .14308 .84066 1 Mshowa
p
.002 w
.50119 .09405 m
.50492 .09905 L
s
P
[(0.2)] .49373 .08404 .74565 1 Mshowa
p
.002 w
.65602 .03192 m
.65942 .03715 L
s
P
[(0.4)] .64921 .02146 .65064 1 Mshowa
p
.001 w
.11234 .25008 m
.115 .25271 L
s
P
p
.001 w
.13815 .23972 m
.14078 .24238 L
s
P
p
.001 w
.16424 .22925 m
.16685 .23194 L
s
P
p
.001 w
.19061 .21867 m
.1932 .22138 L
s
P
p
.001 w
.24425 .19715 m
.24678 .19991 L
s
P
p
.001 w
.27152 .18621 m
.27402 .18899 L
s
P
p
.001 w
.29909 .17514 m
.30156 .17795 L
s
P
p
.001 w
.32698 .16395 m
.32942 .16679 L
s
P
p
.001 w
.38372 .14118 m
.3861 .14408 L
s
P
p
.001 w
.41258 .1296 m
.41492 .13252 L
s
P
p
.001 w
.44177 .11789 m
.44408 .12083 L
s
P
p
.001 w
.47131 .10604 m
.47358 .10901 L
s
P
p
.001 w
.53142 .08191 m
.53362 .08494 L
s
P
p
.001 w
.56202 .06964 m
.56418 .07269 L
s
P
p
.001 w
.59298 .05721 m
.5951 .0603 L
s
P
p
.001 w
.62431 .04464 m
.62639 .04775 L
s
P
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{256, 233},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Module"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tBelow, we define the function that will generate the sequence of plots \
that we will eventually animate.  The function requires the users to input \
eight parameters: t1 and t2 define the beginning and ending times for \
plotting, while numPlots is simply the number of graphs that the user wishes \
to see in that time period.  alpha, beta, omegap, omega, and theta are all \
the parameters for the location of the arbitrary vector as well as the \
frequency of the star's precessional and rotational motion."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"PrecessionMovie[t1_, t2_, numPlots_, alpha_, beta_, \n\t\t\t\t\tomegap_, \
omega_, theta_] := Module[\n\t{timeInc, time, star}, \n\t\n\ttimeInc = \
(t2-t1)/(numPlots-1);\n\tFor[time = t1, time <= t2, time = time + timeInc, \n\
\t   posVector = 1.5*arbVector[time, alpha, beta, omegap, omega, theta];\n\t  \
 symVector = 1.5*arbVector[time, 0, Pi/2, omegap, omega, theta];\n\t   star = \
ParametricPlot3D[\n\t   \t\t\t\tarbVector[time, alphaLoop, betaLoop, omegap, \
omega, theta], \n  \t\t\t\t\t{alphaLoop, 0, 2*Pi}, {betaLoop, -Pi/2, Pi/2}, \n\
\t\t\t\t\tCompiled -> False, \n\t\t\t\t\tShading -> False, \n\t\t\t\t\t\
DisplayFunction -> Identity]; \n\t   Show[Graphics3D[{Line[{{0,0,0}, \
posVector}], \n\t          Text[FontForm[\"n\", {\"Courier-Bold\", 14}], \n\t\
\t\t\t\tposVector], \n\t          Line[{{0,0,0}, symVector}], \n\t\t\t  \
Text[FontForm[\"k\", {\"Courier-Bold\", 14}],\n\t\t\t\t\tsymVector]}], \n\t   \
      star,\n\t         cone,\n\t         Shading -> False,\n\t         Boxed \
-> False,\n\t         PlotLabel  -> time,\n\t         PlotRange -> \
{{-1.7,1.7}, {-1.7,1.7}, {-1.7,1.7}},\n\t         ViewPoint -> {1, 0, 2},\n  \
\t \t\t DisplayFunction -> $DisplayFunction ]; ]; ];"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["Watching the Star Precess"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["One Spin Period"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData[
"Alpha = Pi/7, Beta = Pi/5, Omega = 10, OmegaP = 100, Theta = Pi/10"], 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tNow, we will finally take a look at the motion of the entire star due to \
precession.  First, we look at one spin period, from t = 0 to t = 0.07.  We \
have the function generate 20 plots in this time range for the animation \
sequence."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData[
"PrecessionMovie[0, 0.07, 20, alpha, beta, omegap, omega, theta]"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47437 .46387 m .50591 .44905 L .49026 .42515 L p
1 g
F P
s
P
p
.002 w
.49026 .42515 m .46581 .43658 L .47437 .46387 L p
1 g
F P
s
P
p
.002 w
.51061 .40729 m .49026 .42515 L .50591 .44905 L p
1 g
F P
s
P
p
.002 w
.46581 .43658 m .49026 .42515 L .4748 .40134 L p
1 g
F P
s
P
p
.002 w
.49026 .42515 m .51061 .40729 L .48871 .3891 L p
1 g
F P
s
P
p
.002 w
.48871 .3891 m .4748 .40134 L .49026 .42515 L p
1 g
F P
s
P
p
.002 w
.4836 .49051 m .52149 .47259 L .50591 .44905 L p
1 g
F P
s
P
p
.002 w
.50591 .44905 m .47437 .46387 L .4836 .49051 L p
1 g
F P
s
P
p
.002 w
.53222 .426 m .50591 .44905 L .52149 .47259 L p
1 g
F P
s
P
p
.002 w
.50591 .44905 m .53222 .426 L .51061 .40729 L p
1 g
F P
s
P
p
.002 w
.52482 .38474 m .51061 .40729 L .53222 .426 L p
1 g
F P
s
P
p
.002 w
.51061 .40729 m .52482 .38474 L .49835 .37365 L p
1 g
F P
s
P
p
.002 w
.49835 .37365 m .48871 .3891 L .51061 .40729 L p
1 g
F P
s
P
p
.002 w
.52149 .47259 m .55315 .44492 L .53222 .426 L p
1 g
F P
s
P
p
.002 w
.55071 .39694 m .53222 .426 L .55315 .44492 L p
1 g
F P
s
P
p
.002 w
.53222 .426 m .55071 .39694 L .52482 .38474 L p
1 g
F P
s
P
p
.002 w
.44061 .46897 m .47437 .46387 L .46581 .43658 L p
1 g
F P
s
P
p
.002 w
.46581 .43658 m .43967 .44038 L .44061 .46897 L p
1 g
F P
s
P
p
.002 w
.43967 .44038 m .46581 .43658 L .45806 .40911 L p
1 g
F P
s
P
p
.002 w
.4748 .40134 m .45806 .40911 L .46581 .43658 L p
1 g
F P
s
P
p
.002 w
.45806 .40911 m .4748 .40134 L .45983 .37803 L p
1 g
F P
s
P
p
.002 w
.4748 .40134 m .48871 .3891 L .46691 .37178 L p
1 g
F P
s
P
p
.002 w
.46691 .37178 m .45983 .37803 L .4748 .40134 L p
1 g
F P
s
P
p
.002 w
.44301 .49686 m .4836 .49051 L .47437 .46387 L p
1 g
F P
s
P
p
.002 w
.47437 .46387 m .44061 .46897 L .44301 .49686 L p
1 g
F P
s
P
p
.002 w
.48871 .3891 m .49835 .37365 L .47179 .36389 L p
1 g
F P
s
P
p
.002 w
.47179 .36389 m .46691 .37178 L .48871 .3891 L p
1 g
F P
s
P
p
.002 w
.45806 .40911 m .4402 .41161 L .43967 .44038 L p
1 g
F P
s
P
p
.002 w
.4402 .41161 m .45806 .40911 L .45129 .38197 L p
1 g
F P
s
P
p
.002 w
.45983 .37803 m .45129 .38197 L .45806 .40911 L p
1 g
F P
s
P
p
.002 w
.49334 .51597 m .53671 .49536 L .52149 .47259 L p
1 g
F P
s
P
p
.002 w
.52149 .47259 m .4836 .49051 L .49334 .51597 L p
1 g
F P
s
P
p
.002 w
.55315 .44492 m .52149 .47259 L .53671 .49536 L p
1 g
F P
s
P
p
.002 w
.53139 .35972 m .52482 .38474 L .55071 .39694 L p
1 g
F P
s
P
p
.002 w
.52482 .38474 m .53139 .35972 L .50271 .35655 L p
1 g
F P
s
P
p
.002 w
.50271 .35655 m .49835 .37365 L .52482 .38474 L p
1 g
F P
s
P
p
.002 w
.53671 .49536 m .57301 .46369 L .55315 .44492 L p
1 g
F P
s
P
p
.002 w
.57554 .41006 m .55315 .44492 L .57301 .46369 L p
1 g
F P
s
P
p
.002 w
.55315 .44492 m .57554 .41006 L .55071 .39694 L p
1 g
F P
s
P
p
.002 w
.49835 .37365 m .50271 .35655 L .47394 .35519 L p
1 g
F P
s
P
p
.002 w
.47394 .35519 m .47179 .36389 L .49835 .37365 L p
1 g
F P
s
P
p
.002 w
.55945 .36464 m .55071 .39694 L .57554 .41006 L p
1 g
F P
s
P
p
.002 w
.55071 .39694 m .55945 .36464 L .53139 .35972 L p
1 g
F P
s
P
p
.002 w
.40796 .46365 m .44061 .46897 L .43967 .44038 L p
1 g
F P
s
P
p
.002 w
.43967 .44038 m .41448 .43606 L .40796 .46365 L p
1 g
F P
s
P
p
.002 w
.41448 .43606 m .43967 .44038 L .4402 .41161 L p
1 g
F P
s
P
p
.002 w
.44685 .5235 m .49334 .51597 L .4836 .49051 L p
1 g
F P
s
P
p
.002 w
.4836 .49051 m .44301 .49686 L .44685 .5235 L p
1 g
F P
s
P
p
.002 w
.4402 .41161 m .42305 .40853 L .41448 .43606 L p
1 g
F P
s
P
p
.002 w
.42305 .40853 m .4402 .41161 L .44219 .3832 L p
1 g
F P
s
P
p
.002 w
.45129 .38197 m .44219 .3832 L .4402 .41161 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .45129 .38197 L .45983 .37803 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .45983 .37803 L .46691 .37178 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .46691 .37178 L .47179 .36389 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .44219 .3832 L .45129 .38197 L closepath p
1 g
F P
s
P
p
.002 w
.40363 .49076 m .44301 .49686 L .44061 .46897 L p
1 g
F P
s
P
p
.002 w
.44061 .46897 m .40796 .46365 L .40363 .49076 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .47179 .36389 L .47394 .35519 L closepath p
1 g
F P
s
P
p
.002 w
.50125 .33957 m .50271 .35655 L .53139 .35972 L p
1 g
F P
s
P
p
.002 w
.50271 .35655 m .50125 .33957 L .47311 .34659 L p
1 g
F P
s
P
p
.002 w
.47311 .34659 m .47394 .35519 L .50271 .35655 L p
1 g
F P
s
P
p
.002 w
.50341 .53978 m .55128 .51691 L .53671 .49536 L p
1 g
F P
s
P
p
.002 w
.53671 .49536 m .49334 .51597 L .50341 .53978 L p
1 g
F P
s
P
p
.002 w
.57301 .46369 m .53671 .49536 L .55128 .51691 L p
1 g
F P
s
P
p
.002 w
.44219 .3832 m .4335 .38156 L .42305 .40853 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .4335 .38156 L .44219 .3832 L closepath p
1 g
F P
s
P
p
.002 w
.52949 .33476 m .53139 .35972 L .55945 .36464 L p
1 g
F P
s
P
p
.002 w
.53139 .35972 m .52949 .33476 L .50125 .33957 L p
1 g
F P
s
P
p
.002 w
.57301 .46369 m .59884 .42384 L .57554 .41006 L p
1 g
F P
s
P
p
.002 w
.58634 .37123 m .57554 .41006 L .59884 .42384 L p
1 g
F P
s
P
p
.002 w
.57554 .41006 m .58634 .37123 L .55945 .36464 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .47394 .35519 L .47311 .34659 L closepath p
1 g
F P
s
P
p
.002 w
.39287 .42389 m .41448 .43606 L .42305 .40853 L p
1 g
F P
s
P
p
.002 w
.42305 .40853 m .40843 .40009 L .39287 .42389 L p
1 g
F P
s
P
p
.002 w
.40843 .40009 m .42305 .40853 L .4335 .38156 L p
1 g
F P
s
P
p
.002 w
.55128 .51691 m .59141 .48196 L .57301 .46369 L p
1 g
F P
s
P
p
.002 w
.59884 .42384 m .57301 .46369 L .59141 .48196 L p
1 g
F P
s
P
p
.002 w
.4335 .38156 m .42613 .3772 L .40843 .40009 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42613 .3772 L .4335 .38156 L closepath p
1 g
F P
s
P
p
.002 w
.37977 .44816 m .40796 .46365 L .41448 .43606 L p
1 g
F P
s
P
p
.002 w
.41448 .43606 m .39287 .42389 L .37977 .44816 L p
1 g
F P
s
P
p
.002 w
.4521 .54833 m .50341 .53978 L .49334 .51597 L p
1 g
F P
s
P
p
.002 w
.49334 .51597 m .44685 .5235 L .4521 .54833 L p
1 g
F P
s
P
p
.002 w
.40163 .51685 m .44685 .5235 L .44301 .49686 L p
1 g
F P
s
P
p
.002 w
.44301 .49686 m .40363 .49076 L .40163 .51685 L p
1 g
F P
s
P
p
.002 w
.46937 .33901 m .47311 .34659 L .50125 .33957 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .47311 .34659 L .46937 .33901 L closepath p
1 g
F P
s
P
p
.002 w
.5573 .33227 m .55945 .36464 L .58634 .37123 L p
1 g
F P
s
P
p
.002 w
.55945 .36464 m .5573 .33227 L .52949 .33476 L p
1 g
F P
s
P
p
.002 w
.49402 .32452 m .50125 .33957 L .52949 .33476 L p
1 g
F P
s
P
p
.002 w
.50125 .33957 m .49402 .32452 L .46937 .33901 L p
1 g
F P
s
P
p
.002 w
.39795 .38712 m .40843 .40009 L .42613 .3772 L p
1 g
F P
s
P
p
.002 w
.42613 .3772 m .42091 .37059 L .39795 .38712 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42091 .37059 L .42613 .3772 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .44581 .32976 L .4367 .33236 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .4367 .33236 L .42862 .33762 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42862 .33762 L .42247 .34495 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42247 .34495 L .41895 .35353 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .41895 .35353 L .41842 .3624 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .41842 .3624 L .42091 .37059 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .46937 .33901 L .4631 .3333 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .4631 .3333 L .45495 .33009 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .45495 .33009 L .44581 .32976 L closepath p
1 g
F P
s
P
p
.002 w
.37723 .40496 m .39287 .42389 L .40843 .40009 L p
1 g
F P
s
P
p
.002 w
.40843 .40009 m .39795 .38712 L .37723 .40496 L p
1 g
F P
s
P
p
.002 w
.4631 .3333 m .46937 .33901 L .49402 .32452 L p
1 g
F P
s
P
p
.002 w
.36946 .47241 m .40363 .49076 L .40796 .46365 L p
1 g
F P
s
P
p
.002 w
.40796 .46365 m .37977 .44816 L .36946 .47241 L p
1 g
F P
s
P
p
.002 w
.59141 .48196 m .62012 .43805 L .59884 .42384 L p
1 g
F P
s
P
p
.002 w
.61153 .37941 m .59884 .42384 L .62012 .43805 L p
1 g
F P
s
P
p
.002 w
.59884 .42384 m .61153 .37941 L .58634 .37123 L p
1 g
F P
s
P
p
.002 w
.39284 .37094 m .39795 .38712 L .42091 .37059 L p
1 g
F P
s
P
p
.002 w
.42091 .37059 m .41842 .3624 L .39284 .37094 L p
1 g
F P
s
P
p
.002 w
.51911 .3125 m .52949 .33476 L .5573 .33227 L p
1 g
F P
s
P
p
.002 w
.52949 .33476 m .51911 .3125 L .49402 .32452 L p
1 g
F P
s
P
p
.002 w
.51363 .5614 m .56489 .53678 L .55128 .51691 L p
1 g
F P
s
P
p
.002 w
.55128 .51691 m .50341 .53978 L .51363 .5614 L p
1 g
F P
s
P
p
.002 w
.59141 .48196 m .55128 .51691 L .56489 .53678 L p
1 g
F P
s
P
p
.002 w
.49402 .32452 m .48172 .31307 L .4631 .3333 L p
1 g
F P
s
P
p
.002 w
.45495 .33009 m .4631 .3333 L .48172 .31307 L p
1 g
F P
s
P
p
.002 w
.58411 .3322 m .58634 .37123 L .61153 .37941 L p
1 g
F P
s
P
p
.002 w
.58634 .37123 m .58411 .3322 L .5573 .33227 L p
1 g
F P
s
P
p
.002 w
.56489 .53678 m .60795 .49937 L .59141 .48196 L p
1 g
F P
s
P
p
.002 w
.62012 .43805 m .59141 .48196 L .60795 .49937 L p
1 g
F P
s
P
p
.002 w
.48172 .31307 m .49402 .32452 L .51911 .3125 L p
1 g
F P
s
P
p
.002 w
.39376 .35328 m .39284 .37094 L .41842 .3624 L p
1 g
F P
s
P
p
.002 w
.41842 .3624 m .41895 .35353 L .39376 .35328 L p
1 g
F P
s
P
p
.002 w
.40209 .54135 m .4521 .54833 L .44685 .5235 L p
1 g
F P
s
P
p
.002 w
.44685 .5235 m .40163 .51685 L .40209 .54135 L p
1 g
F P
s
P
p
.002 w
.3592 .42378 m .37977 .44816 L .39287 .42389 L p
1 g
F P
s
P
p
.002 w
.39287 .42389 m .37723 .40496 L .3592 .42378 L p
1 g
F P
s
P
p
.002 w
.45868 .57081 m .51363 .5614 L .50341 .53978 L p
1 g
F P
s
P
p
.002 w
.50341 .53978 m .4521 .54833 L .45868 .57081 L p
1 g
F P
s
P
p
.002 w
.48172 .31307 m .46558 .30655 L .45495 .33009 L p
1 g
F P
s
P
p
.002 w
.44581 .32976 m .45495 .33009 L .46558 .30655 L p
1 g
F P
s
P
p
.002 w
.36945 .38114 m .37723 .40496 L .39795 .38712 L p
1 g
F P
s
P
p
.002 w
.39795 .38712 m .39284 .37094 L .36945 .38114 L p
1 g
F P
s
P
p
.002 w
.40071 .33613 m .39376 .35328 L .41895 .35353 L p
1 g
F P
s
P
p
.002 w
.41895 .35353 m .42247 .34495 L .40071 .33613 L p
1 g
F P
s
P
p
.002 w
.36225 .49614 m .40163 .51685 L .40363 .49076 L p
1 g
F P
s
P
p
.002 w
.40363 .49076 m .36946 .47241 L .36225 .49614 L p
1 g
F P
s
P
p
.002 w
.54412 .30324 m .5573 .33227 L .58411 .3322 L p
1 g
F P
s
P
p
.002 w
.5573 .33227 m .54412 .30324 L .51911 .3125 L p
1 g
F P
s
P
p
.002 w
.4367 .33236 m .44581 .32976 L .44737 .30579 L p
1 g
F P
s
P
p
.002 w
.46558 .30655 m .44737 .30579 L .44581 .32976 L p
1 g
F P
s
P
p
.002 w
.41296 .32145 m .40071 .33613 L .42247 .34495 L p
1 g
F P
s
P
p
.002 w
.42247 .34495 m .42862 .33762 L .41296 .32145 L p
1 g
F P
s
P
p
.002 w
.44737 .30579 m .42914 .31093 L .4367 .33236 L p
1 g
F P
s
P
p
.002 w
.42862 .33762 m .4367 .33236 L .42914 .31093 L p
1 g
F P
s
P
p
.002 w
.42914 .31093 m .41296 .32145 L .42862 .33762 L p
1 g
F P
s
P
p
.002 w
.51911 .3125 m .50113 .29542 L .48172 .31307 L p
1 g
F P
s
P
p
.002 w
.46558 .30655 m .48172 .31307 L .50113 .29542 L p
1 g
F P
s
P
p
.002 w
.50113 .29542 m .51911 .3125 L .54412 .30324 L p
1 g
F P
s
P
p
.002 w
.60795 .49937 m .63888 .45242 L .62012 .43805 L p
1 g
F P
s
P
p
.002 w
.63445 .38906 m .62012 .43805 L .63888 .45242 L p
1 g
F P
s
P
p
.002 w
.62012 .43805 m .63445 .38906 L .61153 .37941 L p
1 g
F P
s
P
p
.002 w
.34435 .44322 m .36946 .47241 L .37977 .44816 L p
1 g
F P
s
P
p
.002 w
.37977 .44816 m .3592 .42378 L .34435 .44322 L p
1 g
F P
s
P
p
.002 w
.37063 .35499 m .36945 .38114 L .39284 .37094 L p
1 g
F P
s
P
p
.002 w
.39284 .37094 m .39376 .35328 L .37063 .35499 L p
1 g
F P
s
P
p
.002 w
.60936 .33462 m .61153 .37941 L .63445 .38906 L p
1 g
F P
s
P
p
.002 w
.61153 .37941 m .60936 .33462 L .58411 .3322 L p
1 g
F P
s
P
p
.002 w
.52379 .5803 m .57725 .55453 L .56489 .53678 L p
1 g
F P
s
P
p
.002 w
.56489 .53678 m .51363 .5614 L .52379 .5803 L p
1 g
F P
s
P
p
.002 w
.60795 .49937 m .56489 .53678 L .57725 .55453 L p
1 g
F P
s
P
p
.002 w
.34881 .39286 m .3592 .42378 L .37723 .40496 L p
1 g
F P
s
P
p
.002 w
.37723 .40496 m .36945 .38114 L .34881 .39286 L p
1 g
F P
s
P
p
.002 w
.40507 .56367 m .45868 .57081 L .4521 .54833 L p
1 g
F P
s
P
p
.002 w
.4521 .54833 m .40209 .54135 L .40507 .56367 L p
1 g
F P
s
P
p
.002 w
.57725 .55453 m .62222 .51552 L .60795 .49937 L p
1 g
F P
s
P
p
.002 w
.63888 .45242 m .60795 .49937 L .62222 .51552 L p
1 g
F P
s
P
p
.002 w
.50113 .29542 m .47734 .28559 L .46558 .30655 L p
1 g
F P
s
P
p
.002 w
.44737 .30579 m .46558 .30655 L .47734 .28559 L p
1 g
F P
s
P
p
.002 w
.56856 .29701 m .58411 .3322 L .60936 .33462 L p
1 g
F P
s
P
p
.002 w
.58411 .3322 m .56856 .29701 L .54412 .30324 L p
1 g
F P
s
P
p
.002 w
.35839 .51882 m .40209 .54135 L .40163 .51685 L p
1 g
F P
s
P
p
.002 w
.40163 .51685 m .36225 .49614 L .35839 .51882 L p
1 g
F P
s
P
p
.002 w
.38085 .32946 m .37063 .35499 L .39376 .35328 L p
1 g
F P
s
P
p
.002 w
.39376 .35328 m .40071 .33613 L .38085 .32946 L p
1 g
F P
s
P
p
.002 w
.46653 .59035 m .52379 .5803 L .51363 .5614 L p
1 g
F P
s
P
p
.002 w
.51363 .5614 m .45868 .57081 L .46653 .59035 L p
1 g
F P
s
P
p
.002 w
.52095 .28081 m .54412 .30324 L .56856 .29701 L p
1 g
F P
s
P
p
.002 w
.54412 .30324 m .52095 .28081 L .50113 .29542 L p
1 g
F P
s
P
p
.002 w
.47734 .28559 m .50113 .29542 L .52095 .28081 L p
1 g
F P
s
P
p
.002 w
.42914 .31093 m .44737 .30579 L .45032 .28431 L p
1 g
F P
s
P
p
.002 w
.47734 .28559 m .45032 .28431 L .44737 .30579 L p
1 g
F P
s
P
p
.002 w
.39905 .30756 m .38085 .32946 L .40071 .33613 L p
1 g
F P
s
P
p
.002 w
.40071 .33613 m .41296 .32145 L .39905 .30756 L p
1 g
F P
s
P
p
.002 w
.33312 .46286 m .36225 .49614 L .36946 .47241 L p
1 g
F P
s
P
p
.002 w
.36946 .47241 m .34435 .44322 L .33312 .46286 L p
1 g
F P
s
P
p
.002 w
.45032 .28431 m .42316 .2919 L .42914 .31093 L p
1 g
F P
s
P
p
.002 w
.41296 .32145 m .42914 .31093 L .42316 .2919 L p
1 g
F P
s
P
p
.002 w
.42316 .2919 m .39905 .30756 L .41296 .32145 L p
1 g
F P
s
P
p
.002 w
.35014 .3587 m .34881 .39286 L .36945 .38114 L p
1 g
F P
s
P
p
.002 w
.36945 .38114 m .37063 .35499 L .35014 .3587 L p
1 g
F P
s
P
p
.002 w
.62222 .51552 m .65465 .46664 L .63888 .45242 L p
1 g
F P
s
P
p
.002 w
.65454 .40002 m .63888 .45242 L .65465 .46664 L p
1 g
F P
s
P
p
.002 w
.63888 .45242 m .65454 .40002 L .63445 .38906 L p
1 g
F P
s
P
p
.002 w
.63244 .33955 m .63445 .38906 L .65454 .40002 L p
1 g
F P
s
P
p
.002 w
.63445 .38906 m .63244 .33955 L .60936 .33462 L p
1 g
F P
s
P
p
.002 w
.33148 .4059 m .34435 .44322 L .3592 .42378 L p
1 g
F P
s
P
p
.002 w
.3592 .42378 m .34881 .39286 L .33148 .4059 L p
1 g
F P
s
P
p
.002 w
.59186 .29405 m .60936 .33462 L .63244 .33955 L p
1 g
F P
s
P
p
.002 w
.60936 .33462 m .59186 .29405 L .56856 .29701 L p
1 g
F P
s
P
p
.002 w
.53368 .59596 m .58802 .56967 L .57725 .55453 L p
1 g
F P
s
P
p
.002 w
.57725 .55453 m .52379 .5803 L .53368 .59596 L p
1 g
F P
s
P
p
.002 w
.62222 .51552 m .57725 .55453 L .58802 .56967 L p
1 g
F P
s
P
p
.002 w
.41063 .58321 m .46653 .59035 L .45868 .57081 L p
1 g
F P
s
P
p
.002 w
.45868 .57081 m .40507 .56367 L .41063 .58321 L p
1 g
F P
s
P
p
.002 w
.52095 .28081 m .49001 .26776 L .47734 .28559 L p
1 g
F P
s
P
p
.002 w
.45032 .28431 m .47734 .28559 L .49001 .26776 L p
1 g
F P
s
P
p
.002 w
.35813 .53988 m .40507 .56367 L .40209 .54135 L p
1 g
F P
s
P
p
.002 w
.40209 .54135 m .35839 .51882 L .35813 .53988 L p
1 g
F P
s
P
p
.002 w
.58802 .56967 m .6338 .53 L .62222 .51552 L p
1 g
F P
s
P
p
.002 w
.65465 .46664 m .62222 .51552 L .6338 .53 L p
1 g
F P
s
P
p
.002 w
.3634 .32519 m .35014 .3587 L .37063 .35499 L p
1 g
F P
s
P
p
.002 w
.37063 .35499 m .38085 .32946 L .3634 .32519 L p
1 g
F P
s
P
p
.002 w
.54078 .26965 m .56856 .29701 L .59186 .29405 L p
1 g
F P
s
P
p
.002 w
.56856 .29701 m .54078 .26965 L .52095 .28081 L p
1 g
F P
s
P
p
.002 w
.49001 .26776 m .52095 .28081 L .54078 .26965 L p
1 g
F P
s
P
p
.002 w
.47551 .60636 m .53368 .59596 L .52379 .5803 L p
1 g
F P
s
P
p
.002 w
.52379 .5803 m .46653 .59035 L .47551 .60636 L p
1 g
F P
s
P
p
.002 w
.32593 .48227 m .35839 .51882 L .36225 .49614 L p
1 g
F P
s
P
p
.002 w
.36225 .49614 m .33312 .46286 L .32593 .48227 L p
1 g
F P
s
P
p
.002 w
.42316 .2919 m .45032 .28431 L .45465 .26592 L p
1 g
F P
s
P
p
.002 w
.49001 .26776 m .45465 .26592 L .45032 .28431 L p
1 g
F P
s
P
p
.002 w
.33288 .36441 m .33148 .4059 L .34881 .39286 L p
1 g
F P
s
P
p
.002 w
.34881 .39286 m .35014 .3587 L .33288 .36441 L p
1 g
F P
s
P
p
.002 w
.31802 .42002 m .33312 .46286 L .34435 .44322 L p
1 g
F P
s
P
p
.002 w
.34435 .44322 m .33148 .4059 L .31802 .42002 L p
1 g
F P
s
P
p
.002 w
.38727 .29639 m .3634 .32519 L .38085 .32946 L p
1 g
F P
s
P
p
.002 w
.38085 .32946 m .39905 .30756 L .38727 .29639 L p
1 g
F P
s
P
p
.002 w
.65465 .46664 m .67124 .41211 L .65454 .40002 L p
1 g
F P
s
P
p
.002 w
.65276 .347 m .65454 .40002 L .67124 .41211 L p
1 g
F P
s
P
p
.002 w
.65454 .40002 m .65276 .347 L .63244 .33955 L p
1 g
F P
s
P
p
.002 w
.45465 .26592 m .41897 .27581 L .42316 .2919 L p
1 g
F P
s
P
p
.002 w
.39905 .30756 m .42316 .2919 L .41897 .27581 L p
1 g
F P
s
P
p
.002 w
.6338 .53 m .66691 .4804 L .65465 .46664 L p
1 g
F P
s
P
p
.002 w
.67124 .41211 m .65465 .46664 L .66691 .4804 L p
1 g
F P
s
P
p
.002 w
.41897 .27581 m .38727 .29639 L .39905 .30756 L p
1 g
F P
s
P
p
.002 w
.61346 .29458 m .63244 .33955 L .65276 .347 L p
1 g
F P
s
P
p
.002 w
.63244 .33955 m .61346 .29458 L .59186 .29405 L p
1 g
F P
s
P
p
.002 w
.54078 .26965 m .50336 .2536 L .49001 .26776 L p
1 g
F P
s
P
p
.002 w
.45465 .26592 m .49001 .26776 L .50336 .2536 L p
1 g
F P
s
P
p
.002 w
.41876 .59937 m .47551 .60636 L .46653 .59035 L p
1 g
F P
s
P
p
.002 w
.46653 .59035 m .41063 .58321 L .41876 .59937 L p
1 g
F P
s
P
p
.002 w
.36164 .55874 m .41063 .58321 L .40507 .56367 L p
1 g
F P
s
P
p
.002 w
.40507 .56367 m .35813 .53988 L .36164 .55874 L p
1 g
F P
s
P
p
.002 w
.56015 .26236 m .59186 .29405 L .61346 .29458 L p
1 g
F P
s
P
p
.002 w
.59186 .29405 m .56015 .26236 L .54078 .26965 L p
1 g
F P
s
P
p
.002 w
.54305 .60784 m .59688 .58171 L .58802 .56967 L p
1 g
F P
s
P
p
.002 w
.58802 .56967 m .53368 .59596 L .54305 .60784 L p
1 g
F P
s
P
p
.002 w
.6338 .53 m .58802 .56967 L .59688 .58171 L p
1 g
F P
s
P
p
.002 w
.50336 .2536 m .54078 .26965 L .56015 .26236 L p
1 g
F P
s
P
p
.002 w
.34892 .32355 m .33288 .36441 L .35014 .3587 L p
1 g
F P
s
P
p
.002 w
.35014 .3587 m .3634 .32519 L .34892 .32355 L p
1 g
F P
s
P
p
.002 w
.59688 .58171 m .64229 .54241 L .6338 .53 L p
1 g
F P
s
P
p
.002 w
.66691 .4804 m .6338 .53 L .64229 .54241 L p
1 g
F P
s
P
p
.002 w
.32315 .50096 m .35813 .53988 L .35839 .51882 L p
1 g
F P
s
P
p
.002 w
.35839 .51882 m .32593 .48227 L .32315 .50096 L p
1 g
F P
s
P
p
.002 w
.48548 .61829 m .54305 .60784 L .53368 .59596 L p
1 g
F P
s
P
p
.002 w
.53368 .59596 m .47551 .60636 L .48548 .61829 L p
1 g
F P
s
P
p
.002 w
.30897 .43492 m .32593 .48227 L .33312 .46286 L p
1 g
F P
s
P
p
.002 w
.33312 .46286 m .31802 .42002 L .30897 .43492 L p
1 g
F P
s
P
p
.002 w
.31944 .37211 m .31802 .42002 L .33148 .4059 L p
1 g
F P
s
P
p
.002 w
.33148 .4059 m .33288 .36441 L .31944 .37211 L p
1 g
F P
s
P
p
.002 w
.41897 .27581 m .45465 .26592 L .46034 .25121 L p
1 g
F P
s
P
p
.002 w
.50336 .2536 m .46034 .25121 L .45465 .26592 L p
1 g
F P
s
P
p
.002 w
.66691 .4804 m .68399 .4251 L .67124 .41211 L p
1 g
F P
s
P
p
.002 w
.66971 .3569 m .67124 .41211 L .68399 .4251 L p
1 g
F P
s
P
p
.002 w
.67124 .41211 m .66971 .3569 L .65276 .347 L p
1 g
F P
s
P
p
.002 w
.37803 .28834 m .34892 .32355 L .3634 .32519 L p
1 g
F P
s
P
p
.002 w
.3634 .32519 m .38727 .29639 L .37803 .28834 L p
1 g
F P
s
P
p
.002 w
.63276 .29874 m .65276 .347 L .66971 .3569 L p
1 g
F P
s
P
p
.002 w
.65276 .347 m .63276 .29874 L .61346 .29458 L p
1 g
F P
s
P
p
.002 w
.64229 .54241 m .6752 .49335 L .66691 .4804 L p
1 g
F P
s
P
p
.002 w
.68399 .4251 m .66691 .4804 L .6752 .49335 L p
1 g
F P
s
P
p
.002 w
.46034 .25121 m .41677 .2632 L .41897 .27581 L p
1 g
F P
s
P
p
.002 w
.38727 .29639 m .41897 .27581 L .41677 .2632 L p
1 g
F P
s
P
p
.002 w
.41677 .2632 m .37803 .28834 L .38727 .29639 L p
1 g
F P
s
P
p
.002 w
.36904 .57479 m .41876 .59937 L .41063 .58321 L p
1 g
F P
s
P
p
.002 w
.41063 .58321 m .36164 .55874 L .36904 .57479 L p
1 g
F P
s
P
p
.002 w
.56015 .26236 m .5171 .24364 L .50336 .2536 L p
1 g
F P
s
P
p
.002 w
.46034 .25121 m .50336 .2536 L .5171 .24364 L p
1 g
F P
s
P
p
.002 w
.57859 .25931 m .61346 .29458 L .63276 .29874 L p
1 g
F P
s
P
p
.002 w
.61346 .29458 m .57859 .25931 L .56015 .26236 L p
1 g
F P
s
P
p
.002 w
.4294 .61156 m .48548 .61829 L .47551 .60636 L p
1 g
F P
s
P
p
.002 w
.47551 .60636 m .41876 .59937 L .4294 .61156 L p
1 g
F P
s
P
p
.002 w
.5171 .24364 m .56015 .26236 L .57859 .25931 L p
1 g
F P
s
P
p
.002 w
.3251 .51841 m .36164 .55874 L .35813 .53988 L p
1 g
F P
s
P
p
.002 w
.35813 .53988 m .32315 .50096 L .3251 .51841 L p
1 g
F P
s
P
p
.002 w
.55163 .61543 m .60351 .59019 L .59688 .58171 L p
1 g
F P
s
P
p
.002 w
.59688 .58171 m .54305 .60784 L .55163 .61543 L p
1 g
F P
s
P
p
.002 w
.64229 .54241 m .59688 .58171 L .60351 .59019 L p
1 g
F P
s
P
p
.002 w
.33793 .32474 m .31944 .37211 L .33288 .36441 L p
1 g
F P
s
P
p
.002 w
.33288 .36441 m .34892 .32355 L .33793 .32474 L p
1 g
F P
s
P
p
.002 w
.60351 .59019 m .64731 .55232 L .64229 .54241 L p
1 g
F P
s
P
p
.002 w
.6752 .49335 m .64229 .54241 L .64731 .55232 L p
1 g
F P
s
P
p
.002 w
.3048 .45027 m .32315 .50096 L .32593 .48227 L p
1 g
F P
s
P
p
.002 w
.32593 .48227 m .30897 .43492 L .3048 .45027 L p
1 g
F P
s
P
p
.002 w
.3104 .38171 m .30897 .43492 L .31802 .42002 L p
1 g
F P
s
P
p
.002 w
.31802 .42002 m .31944 .37211 L .3104 .38171 L p
1 g
F P
s
P
p
.002 w
.49625 .62558 m .55163 .61543 L .54305 .60784 L p
1 g
F P
s
P
p
.002 w
.54305 .60784 m .48548 .61829 L .49625 .62558 L p
1 g
F P
s
P
p
.002 w
.5171 .24364 m .46732 .24074 L .46034 .25121 L p
1 g
F P
s
P
p
.002 w
.41677 .2632 m .46034 .25121 L .46732 .24074 L p
1 g
F P
s
P
p
.002 w
.6752 .49335 m .69225 .43873 L .68399 .4251 L p
1 g
F P
s
P
p
.002 w
.68268 .36915 m .68399 .4251 L .69225 .43873 L p
1 g
F P
s
P
p
.002 w
.68399 .4251 m .68268 .36915 L .66971 .3569 L p
1 g
F P
s
P
p
.002 w
.64915 .30661 m .66971 .3569 L .68268 .36915 L p
1 g
F P
s
P
p
.002 w
.66971 .3569 m .64915 .30661 L .63276 .29874 L p
1 g
F P
s
P
p
.002 w
.37171 .28381 m .33793 .32474 L .34892 .32355 L p
1 g
F P
s
P
p
.002 w
.34892 .32355 m .37803 .28834 L .37171 .28381 L p
1 g
F P
s
P
p
.002 w
.64731 .55232 m .67907 .50511 L .6752 .49335 L p
1 g
F P
s
P
p
.002 w
.69225 .43873 m .6752 .49335 L .67907 .50511 L p
1 g
F P
s
P
p
.002 w
.46732 .24074 m .41674 .2546 L .41677 .2632 L p
1 g
F P
s
P
p
.002 w
.37803 .28834 m .41677 .2632 L .41674 .2546 L p
1 g
F P
s
P
p
.002 w
.59557 .26079 m .63276 .29874 L .64915 .30661 L p
1 g
F P
s
P
p
.002 w
.63276 .29874 m .59557 .26079 L .57859 .25931 L p
1 g
F P
s
P
p
.002 w
.41674 .2546 m .37171 .28381 L .37803 .28834 L p
1 g
F P
s
P
p
.002 w
.38035 .58745 m .4294 .61156 L .41876 .59937 L p
1 g
F P
s
P
p
.002 w
.41876 .59937 m .36904 .57479 L .38035 .58745 L p
1 g
F P
s
P
p
.002 w
.57859 .25931 m .5309 .23837 L .5171 .24364 L p
1 g
F P
s
P
p
.002 w
.46732 .24074 m .5171 .24364 L .5309 .23837 L p
1 g
F P
s
P
p
.002 w
.4424 .61922 m .49625 .62558 L .48548 .61829 L p
1 g
F P
s
P
p
.002 w
.48548 .61829 m .4294 .61156 L .4424 .61922 L p
1 g
F P
s
P
p
.002 w
.5309 .23837 m .57859 .25931 L .59557 .26079 L p
1 g
F P
s
P
p
.002 w
.33198 .53408 m .36904 .57479 L .36164 .55874 L p
1 g
F P
s
P
p
.002 w
.36164 .55874 m .3251 .51841 L .33198 .53408 L p
1 g
F P
s
P
p
.002 w
.33094 .32889 m .3104 .38171 L .31944 .37211 L p
1 g
F P
s
P
p
.002 w
.31944 .37211 m .33793 .32474 L .33094 .32889 L p
1 g
F P
s
P
p
.002 w
.55917 .61825 m .60759 .59467 L .60351 .59019 L p
1 g
F P
s
P
p
.002 w
.60351 .59019 m .55163 .61543 L .55917 .61825 L p
1 g
F P
s
P
p
.002 w
.64731 .55232 m .60351 .59019 L .60759 .59467 L p
1 g
F P
s
P
p
.002 w
.3059 .46567 m .3251 .51841 L .32315 .50096 L p
1 g
F P
s
P
p
.002 w
.32315 .50096 m .3048 .45027 L .3059 .46567 L p
1 g
F P
s
P
p
.002 w
.30627 .39307 m .3048 .45027 L .30897 .43492 L p
1 g
F P
s
P
p
.002 w
.30897 .43492 m .3104 .38171 L .30627 .39307 L p
1 g
F P
s
P
p
.002 w
.60759 .59467 m .6485 .55931 L .64731 .55232 L p
1 g
F P
s
P
p
.002 w
.67907 .50511 m .64731 .55232 L .6485 .55931 L p
1 g
F P
s
P
p
.002 w
.50756 .62775 m .55917 .61825 L .55163 .61543 L p
1 g
F P
s
P
p
.002 w
.55163 .61543 m .49625 .62558 L .50756 .62775 L p
1 g
F P
s
P
p
.002 w
.67907 .50511 m .69556 .45266 L .69225 .43873 L p
1 g
F P
s
P
p
.002 w
.69112 .38354 m .69225 .43873 L .69556 .45266 L p
1 g
F P
s
P
p
.002 w
.69225 .43873 m .69112 .38354 L .68268 .36915 L p
1 g
F P
s
P
p
.002 w
.5309 .23837 m .47549 .23506 L .46732 .24074 L p
1 g
F P
s
P
p
.002 w
.41674 .2546 m .46732 .24074 L .47549 .23506 L p
1 g
F P
s
P
p
.002 w
.66203 .31819 m .68268 .36915 L .69112 .38354 L p
1 g
F P
s
P
p
.002 w
.68268 .36915 m .66203 .31819 L .64915 .30661 L p
1 g
F P
s
P
p
.002 w
.36867 .28316 m .33094 .32889 L .33793 .32474 L p
1 g
F P
s
P
p
.002 w
.33793 .32474 m .37171 .28381 L .36867 .28316 L p
1 g
F P
s
P
p
.002 w
.61055 .26703 m .64915 .30661 L .66203 .31819 L p
1 g
F P
s
P
p
.002 w
.64915 .30661 m .61055 .26703 L .59557 .26079 L p
1 g
F P
s
P
p
.002 w
.6485 .55931 m .67816 .5153 L .67907 .50511 L p
1 g
F P
s
P
p
.002 w
.69556 .45266 m .67907 .50511 L .67816 .5153 L p
1 g
F P
s
P
p
.002 w
.39546 .59617 m .4424 .61922 L .4294 .61156 L p
1 g
F P
s
P
p
.002 w
.4294 .61156 m .38035 .58745 L .39546 .59617 L p
1 g
F P
s
P
p
.002 w
.59557 .26079 m .5444 .23821 L .5309 .23837 L p
1 g
F P
s
P
p
.002 w
.47549 .23506 m .5309 .23837 L .5444 .23821 L p
1 g
F P
s
P
p
.002 w
.47549 .23506 m .41901 .2505 L .41674 .2546 L p
1 g
F P
s
P
p
.002 w
.37171 .28381 m .41674 .2546 L .41901 .2505 L p
1 g
F P
s
P
p
.002 w
.5444 .23821 m .59557 .26079 L .61055 .26703 L p
1 g
F P
s
P
p
.002 w
.34389 .54741 m .38035 .58745 L .36904 .57479 L p
1 g
F P
s
P
p
.002 w
.36904 .57479 m .33198 .53408 L .34389 .54741 L p
1 g
F P
s
P
p
.002 w
.41901 .2505 m .36867 .28316 L .37171 .28381 L p
1 g
F P
s
P
p
.002 w
.45755 .62186 m .50756 .62775 L .49625 .62558 L p
1 g
F P
s
P
p
.002 w
.49625 .62558 m .4424 .61922 L .45755 .62186 L p
1 g
F P
s
P
p
.002 w
.31257 .48068 m .33198 .53408 L .3251 .51841 L p
1 g
F P
s
P
p
.002 w
.3251 .51841 m .3059 .46567 L .31257 .48068 L p
1 g
F P
s
P
p
.002 w
.32843 .33609 m .30627 .39307 L .3104 .38171 L p
1 g
F P
s
P
p
.002 w
.3104 .38171 m .33094 .32889 L .32843 .33609 L p
1 g
F P
s
P
p
.002 w
.30747 .40596 m .3059 .46567 L .3048 .45027 L p
1 g
F P
s
P
p
.002 w
.3048 .45027 m .30627 .39307 L .30747 .40596 L p
1 g
F P
s
P
p
.002 w
.56536 .61593 m .60884 .59476 L .60759 .59467 L p
1 g
F P
s
P
p
.002 w
.60759 .59467 m .55917 .61825 L .56536 .61593 L p
1 g
F P
s
P
p
.002 w
.6485 .55931 m .60759 .59467 L .60884 .59476 L p
1 g
F P
s
P
p
.002 w
.60884 .59476 m .64558 .563 L .6485 .55931 L p
1 g
F P
s
P
p
.002 w
.67816 .5153 m .6485 .55931 L .64558 .563 L p
1 g
F P
s
P
p
.002 w
.69556 .45266 m .69453 .3998 L .69112 .38354 L p
1 g
F P
s
P
p
.002 w
.69112 .38354 m .67085 .33337 L .66203 .31819 L p
1 g
F P
s
P
p
.002 w
.67085 .33337 m .69112 .38354 L .69453 .3998 L p
1 g
F P
s
P
p
.002 w
.67816 .5153 m .69352 .46653 L .69556 .45266 L p
1 g
F P
s
P
p
.002 w
.69453 .3998 m .69556 .45266 L .69352 .46653 L p
1 g
F P
s
P
p
.002 w
.51913 .62443 m .56536 .61593 L .55917 .61825 L p
1 g
F P
s
P
p
.002 w
.55917 .61825 m .50756 .62775 L .51913 .62443 L p
1 g
F P
s
P
p
.002 w
.5444 .23821 m .4847 .23463 L .47549 .23506 L p
1 g
F P
s
P
p
.002 w
.41901 .2505 m .47549 .23506 L .4847 .23463 L p
1 g
F P
s
P
p
.002 w
.66203 .31819 m .62299 .27813 L .61055 .26703 L p
1 g
F P
s
P
p
.002 w
.62299 .27813 m .66203 .31819 L .67085 .33337 L p
1 g
F P
s
P
p
.002 w
.36923 .28666 m .32843 .33609 L .33094 .32889 L p
1 g
F P
s
P
p
.002 w
.33094 .32889 m .36867 .28316 L .36923 .28666 L p
1 g
F P
s
P
p
.002 w
.41414 .60046 m .45755 .62186 L .4424 .61922 L p
1 g
F P
s
P
p
.002 w
.4424 .61922 m .39546 .59617 L .41414 .60046 L p
1 g
F P
s
P
p
.002 w
.64558 .563 m .67217 .52354 L .67816 .5153 L p
1 g
F P
s
P
p
.002 w
.69352 .46653 m .67816 .5153 L .67217 .52354 L p
1 g
F P
s
P
p
.002 w
.61055 .26703 m .5572 .24348 L .5444 .23821 L p
1 g
F P
s
P
p
.002 w
.5572 .24348 m .61055 .26703 L .62299 .27813 L p
1 g
F P
s
P
p
.002 w
.36073 .55785 m .39546 .59617 L .38035 .58745 L p
1 g
F P
s
P
p
.002 w
.38035 .58745 m .34389 .54741 L .36073 .55785 L p
1 g
F P
s
P
p
.002 w
.4847 .23463 m .5444 .23821 L .5572 .24348 L p
1 g
F P
s
P
p
.002 w
.4847 .23463 m .42369 .25133 L .41901 .2505 L p
1 g
F P
s
P
p
.002 w
.36867 .28316 m .41901 .2505 L .42369 .25133 L p
1 g
F P
s
P
p
.002 w
.4745 .6191 m .51913 .62443 L .50756 .62775 L p
1 g
F P
s
P
p
.002 w
.50756 .62775 m .45755 .62186 L .4745 .6191 L p
1 g
F P
s
P
p
.002 w
.42369 .25133 m .36923 .28666 L .36867 .28316 L p
1 g
F P
s
P
p
.002 w
.32492 .4948 m .34389 .54741 L .33198 .53408 L p
1 g
F P
s
P
p
.002 w
.33198 .53408 m .31257 .48068 L .32492 .4948 L p
1 g
F P
s
P
p
.002 w
.33075 .34633 m .30747 .40596 L .30627 .39307 L p
1 g
F P
s
P
p
.002 w
.30627 .39307 m .32843 .33609 L .33075 .34633 L p
1 g
F P
s
P
p
.002 w
.3143 .42008 m .31257 .48068 L .3059 .46567 L p
1 g
F P
s
P
p
.002 w
.3059 .46567 m .30747 .40596 L .3143 .42008 L p
1 g
F P
s
P
p
.002 w
.56996 .60819 m .60703 .59015 L .60884 .59476 L p
1 g
F P
s
P
p
.002 w
.60884 .59476 m .56536 .61593 L .56996 .60819 L p
1 g
F P
s
P
p
.002 w
.64558 .563 m .60884 .59476 L .60703 .59015 L p
1 g
F P
s
P
p
.002 w
.69352 .46653 m .69253 .41755 L .69453 .3998 L p
1 g
F P
s
P
p
.002 w
.67511 .35189 m .69453 .3998 L .69253 .41755 L p
1 g
F P
s
P
p
.002 w
.69453 .3998 m .67511 .35189 L .67085 .33337 L p
1 g
F P
s
P
p
.002 w
.60703 .59015 m .63837 .56306 L .64558 .563 L p
1 g
F P
s
P
p
.002 w
.67217 .52354 m .64558 .563 L .63837 .56306 L p
1 g
F P
s
P
p
.002 w
.67217 .52354 m .68587 .47994 L .69352 .46653 L p
1 g
F P
s
P
p
.002 w
.69253 .41755 m .69352 .46653 L .68587 .47994 L p
1 g
F P
s
P
p
.002 w
.53063 .61537 m .56996 .60819 L .56536 .61593 L p
1 g
F P
s
P
p
.002 w
.56536 .61593 m .51913 .62443 L .53063 .61537 L p
1 g
F P
s
P
p
.002 w
.63238 .29402 m .67085 .33337 L .67511 .35189 L p
1 g
F P
s
P
p
.002 w
.67085 .33337 m .63238 .29402 L .62299 .27813 L p
1 g
F P
s
P
p
.004 w
.66333 .28778 m
.67671 .27609 L
s
P
p
.002 w
.5572 .24348 m .49475 .2398 L .4847 .23463 L p
1 g
F P
s
P
p
.002 w
.42369 .25133 m .4847 .23463 L .49475 .2398 L p
1 g
F P
s
P
p
.002 w
.43599 .59993 m .4745 .6191 L .45755 .62186 L p
1 g
F P
s
P
p
.002 w
.45755 .62186 m .41414 .60046 L .43599 .59993 L p
1 g
F P
s
P
p
.002 w
.38224 .56493 m .41414 .60046 L .39546 .59617 L p
1 g
F P
s
P
p
.002 w
.39546 .59617 m .36073 .55785 L .38224 .56493 L p
1 g
F P
s
P
p
.002 w
.3736 .29449 m .33075 .34633 L .32843 .33609 L p
1 g
F P
s
P
p
.002 w
.32843 .33609 m .36923 .28666 L .3736 .29449 L p
1 g
F P
s
P
p
.002 w
.56886 .25434 m .62299 .27813 L .63238 .29402 L p
1 g
F P
s
P
p
.002 w
.62299 .27813 m .56886 .25434 L .5572 .24348 L p
1 g
F P
s
P
p
.002 w
.63837 .56306 m .66098 .52943 L .67217 .52354 L p
1 g
F P
s
P
p
.002 w
.68587 .47994 m .67217 .52354 L .66098 .52943 L p
1 g
F P
s
P
p
.002 w
.49475 .2398 m .5572 .24348 L .56886 .25434 L p
1 g
F P
s
P
p
.002 w
.34287 .50753 m .36073 .55785 L .34389 .54741 L p
1 g
F P
s
P
p
.002 w
.34389 .54741 m .32492 .4948 L .34287 .50753 L p
1 g
F P
s
P
p
.002 w
.49283 .61073 m .53063 .61537 L .51913 .62443 L p
1 g
F P
s
P
p
.002 w
.51913 .62443 m .4745 .6191 L .49283 .61073 L p
1 g
F P
s
P
p
.002 w
.49475 .2398 m .43077 .25739 L .42369 .25133 L p
1 g
F P
s
P
p
.002 w
.36923 .28666 m .42369 .25133 L .43077 .25739 L p
1 g
F P
s
P
p
.002 w
.43077 .25739 m .3736 .29449 L .36923 .28666 L p
1 g
F P
s
P
p
.002 w
.33814 .35946 m .3143 .42008 L .30747 .40596 L p
1 g
F P
s
P
p
.002 w
.30747 .40596 m .33075 .34633 L .33814 .35946 L p
1 g
F P
s
P
p
.002 w
.32687 .43505 m .32492 .4948 L .31257 .48068 L p
1 g
F P
s
P
p
.002 w
.31257 .48068 m .3143 .42008 L .32687 .43505 L p
1 g
F P
s
P
p
.002 w
.68587 .47994 m .68486 .43633 L .69253 .41755 L p
1 g
F P
s
P
p
.002 w
.67443 .37336 m .69253 .41755 L .68486 .43633 L p
1 g
F P
s
P
p
.002 w
.69253 .41755 m .67443 .37336 L .67511 .35189 L p
1 g
F P
s
P
p
.002 w
.66098 .52943 m .67251 .49242 L .68587 .47994 L p
1 g
F P
s
P
p
.002 w
.68486 .43633 m .68587 .47994 L .67251 .49242 L p
1 g
F P
s
P
p
.002 w
.5727 .59492 m .60202 .58068 L .60703 .59015 L p
1 g
F P
s
P
p
.002 w
.60703 .59015 m .56996 .60819 L .5727 .59492 L p
1 g
F P
s
P
p
.002 w
.63837 .56306 m .60703 .59015 L .60202 .58068 L p
1 g
F P
s
P
p
.002 w
.63823 .31448 m .67511 .35189 L .67443 .37336 L p
1 g
F P
s
P
p
.002 w
.67511 .35189 m .63823 .31448 L .63238 .29402 L p
1 g
F P
s
P
p
.004 w
.65076 .29877 m
.66333 .28778 L
s
P
p
.002 w
.60202 .58068 m .6268 .55924 L .63837 .56306 L p
1 g
F P
s
P
p
.002 w
.66098 .52943 m .63837 .56306 L .6268 .55924 L p
1 g
F P
s
P
p
.002 w
.54167 .6005 m .5727 .59492 L .56996 .60819 L p
1 g
F P
s
P
p
.002 w
.56996 .60819 m .53063 .61537 L .54167 .6005 L p
1 g
F P
s
P
p
.002 w
.56886 .25434 m .50536 .25077 L .49475 .2398 L p
1 g
F P
s
P
p
.002 w
.43077 .25739 m .49475 .2398 L .50536 .25077 L p
1 g
F P
s
P
p
.002 w
.40794 .56824 m .43599 .59993 L .41414 .60046 L p
1 g
F P
s
P
p
.002 w
.41414 .60046 m .38224 .56493 L .40794 .56824 L p
1 g
F P
s
P
p
.002 w
.46045 .59436 m .49283 .61073 L .4745 .6191 L p
1 g
F P
s
P
p
.002 w
.4745 .6191 m .43599 .59993 L .46045 .59436 L p
1 g
F P
s
P
p
.002 w
.57894 .27079 m .63238 .29402 L .63823 .31448 L p
1 g
F P
s
P
p
.002 w
.63238 .29402 m .57894 .27079 L .56886 .25434 L p
1 g
F P
s
P
p
.002 w
.50536 .25077 m .56886 .25434 L .57894 .27079 L p
1 g
F P
s
P
p
.002 w
.3819 .30667 m .33814 .35946 L .33075 .34633 L p
1 g
F P
s
P
p
.002 w
.33075 .34633 m .3736 .29449 L .3819 .30667 L p
1 g
F P
s
P
p
.002 w
.6268 .55924 m .6446 .53266 L .66098 .52943 L p
1 g
F P
s
P
p
.002 w
.67251 .49242 m .66098 .52943 L .6446 .53266 L p
1 g
F P
s
P
p
.002 w
.3661 .51838 m .38224 .56493 L .36073 .55785 L p
1 g
F P
s
P
p
.002 w
.36073 .55785 m .34287 .50753 L .3661 .51838 L p
1 g
F P
s
P
p
.002 w
.51201 .59672 m .54167 .6005 L .53063 .61537 L p
1 g
F P
s
P
p
.002 w
.53063 .61537 m .49283 .61073 L .51201 .59672 L p
1 g
F P
s
P
p
.002 w
.34507 .4504 m .34287 .50753 L .32492 .4948 L p
1 g
F P
s
P
p
.002 w
.32492 .4948 m .32687 .43505 L .34507 .4504 L p
1 g
F P
s
P
p
.002 w
.50536 .25077 m .4402 .2688 L .43077 .25739 L p
1 g
F P
s
P
p
.002 w
.3736 .29449 m .43077 .25739 L .4402 .2688 L p
1 g
F P
s
P
p
.002 w
.35065 .37522 m .32687 .43505 L .3143 .42008 L p
1 g
F P
s
P
p
.002 w
.3143 .42008 m .33814 .35946 L .35065 .37522 L p
1 g
F P
s
P
p
.002 w
.4402 .2688 m .3819 .30667 L .3736 .29449 L p
1 g
F P
s
P
p
.002 w
.67251 .49242 m .67147 .45559 L .68486 .43633 L p
1 g
F P
s
P
p
.002 w
.66856 .39723 m .68486 .43633 L .67147 .45559 L p
1 g
F P
s
P
p
.002 w
.68486 .43633 m .66856 .39723 L .67443 .37336 L p
1 g
F P
s
P
p
.002 w
.64017 .33906 m .67443 .37336 L .66856 .39723 L p
1 g
F P
s
P
p
.002 w
.67443 .37336 m .64017 .33906 L .63823 .31448 L p
1 g
F P
s
P
p
.002 w
.6446 .53266 m .65356 .50351 L .67251 .49242 L p
1 g
F P
s
P
p
.002 w
.67147 .45559 m .67251 .49242 L .65356 .50351 L p
1 g
F P
s
P
p
.002 w
.57338 .57623 m .59377 .56636 L .60202 .58068 L p
1 g
F P
s
P
p
.002 w
.60202 .58068 m .5727 .59492 L .57338 .57623 L p
1 g
F P
s
P
p
.002 w
.6268 .55924 m .60202 .58068 L .59377 .56636 L p
1 g
F P
s
P
p
.002 w
.43712 .56749 m .46045 .59436 L .43599 .59993 L p
1 g
F P
s
P
p
.002 w
.43599 .59993 m .40794 .56824 L .43712 .56749 L p
1 g
F P
s
P
p
.002 w
.59377 .56636 m .61099 .55144 L .6268 .55924 L p
1 g
F P
s
P
p
.002 w
.6446 .53266 m .6268 .55924 L .61099 .55144 L p
1 g
F P
s
P
p
.002 w
.58703 .29257 m .63823 .31448 L .64017 .33906 L p
1 g
F P
s
P
p
.002 w
.63823 .31448 m .58703 .29257 L .57894 .27079 L p
1 g
F P
s
P
p
.002 w
.4868 .58371 m .51201 .59672 L .49283 .61073 L p
1 g
F P
s
P
p
.002 w
.49283 .61073 m .46045 .59436 L .4868 .58371 L p
1 g
F P
s
P
p
.002 w
.4402 .2688 m .50536 .25077 L .51621 .26751 L p
1 g
F P
s
P
p
.002 w
.57894 .27079 m .51621 .26751 L .50536 .25077 L p
1 g
F P
s
P
p
.002 w
.55186 .58002 m .57338 .57623 L .5727 .59492 L p
1 g
F P
s
P
p
.002 w
.5727 .59492 m .54167 .6005 L .55186 .58002 L p
1 g
F P
s
P
p
.002 w
.39403 .52686 m .40794 .56824 L .38224 .56493 L p
1 g
F P
s
P
p
.002 w
.38224 .56493 m .3661 .51838 L .39403 .52686 L p
1 g
F P
s
P
p
.002 w
.51621 .26751 m .57894 .27079 L .58703 .29257 L p
1 g
F P
s
P
p
.002 w
.61099 .55144 m .6233 .53296 L .6446 .53266 L p
1 g
F P
s
P
p
.002 w
.65356 .50351 m .6446 .53266 L .6233 .53296 L p
1 g
F P
s
P
p
.002 w
.39407 .32304 m .35065 .37522 L .33814 .35946 L p
1 g
F P
s
P
p
.002 w
.33814 .35946 m .3819 .30667 L .39407 .32304 L p
1 g
F P
s
P
p
.002 w
.5314 .57727 m .55186 .58002 L .54167 .6005 L p
1 g
F P
s
P
p
.002 w
.54167 .6005 m .51201 .59672 L .5314 .57727 L p
1 g
F P
s
P
p
.002 w
.36853 .46562 m .3661 .51838 L .34287 .50753 L p
1 g
F P
s
P
p
.002 w
.34287 .50753 m .34507 .4504 L .36853 .46562 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.65356 .50351 m .65254 .47469 L .67147 .45559 L p
1 g
F P
s
P
p
.002 w
.65748 .4228 m .67147 .45559 L .65254 .47469 L p
1 g
F P
s
P
p
.002 w
.67147 .45559 m .65748 .4228 L .66856 .39723 L p
1 g
F P
s
P
p
.002 w
.36813 .3932 m .34507 .4504 L .32687 .43505 L p
1 g
F P
s
P
p
.002 w
.32687 .43505 m .35065 .37522 L .36813 .3932 L p
1 g
F P
s
P
p
.002 w
.51621 .26751 m .45179 .28552 L .4402 .2688 L p
1 g
F P
s
P
p
.002 w
.3819 .30667 m .4402 .2688 L .45179 .28552 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63795 .36712 m .66856 .39723 L .65748 .4228 L p
1 g
F P
s
P
p
.002 w
.66856 .39723 m .63795 .36712 L .64017 .33906 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45179 .28552 m .39407 .32304 L .3819 .30667 L p
1 g
F P
s
P
p
.002 w
.6233 .53296 m .62937 .51278 L .65356 .50351 L p
1 g
F P
s
P
p
.002 w
.65254 .47469 m .65356 .50351 L .62937 .51278 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46045 .59436 m .46601 .57332 L .47147 .57605 L 1 g
F
P
p
.002 w
.4868 .58371 m .48509 .5844 L p
.47147 .57605 L 1 g
F P
s
P
p
.002 w
.48509 .5844 m .46045 .59436 L p
.47147 .57605 L 1 g
F P
s
P
p
.002 w
.46839 .57416 m .46872 .57265 L p
.46074 .56946 L 1 g
F P
s
P
p
.48921 .57862 m .47854 .57774 L .48311 .57936 L 1 g
F
P
p
.002 w
.49086 .5814 m .4868 .58371 L p
.48822 .5809 L 1 g
F P
s
P
p
.48822 .5809 m .48831 .58073 L .48904 .58092 L 1 g
F
P
p
.48822 .5809 m .48904 .58092 L .49086 .5814 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58092 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58092 L .49156 .581 L 1 g
F
P
p
.51201 .59672 m .49551 .58403 L .51326 .58025 L 1 g
F
P
p
.49551 .58403 m .49156 .581 L .51092 .58033 L 1 g
F
P
p
.49551 .58403 m .51092 .58033 L .51326 .58025 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58033 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58033 L .52106 .57789 L 1 g
F
P
p
.51079 .57862 m .49156 .581 L .50041 .5807 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51201 .59672 m .4868 .58371 L .49156 .581 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.49156 .581 m .51417 .56816 L p
.51326 .58025 L 1 g
F P
s
P
p
.002 w
.5314 .57727 m .51201 .59672 L p
.51329 .57976 L 1 g
F P
s
P
p
.53128 .57265 m .52106 .57789 L .52898 .57599 L 1 g
F
P
p
.002 w
.5314 .57727 m .52968 .57636 L p
.53227 .5748 L 1 g
F P
s
P
p
.002 w
.52968 .57636 m .52898 .57599 L p
.53179 .57498 L 1 g
F P
s
P
p
.52968 .57636 m .53179 .57498 L .53227 .5748 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53179 .57498 L p
1 g
F P
s
P
p
.54854 .56129 m .53179 .57498 L .53464 .5731 L 1 g
F
P
p
.55186 .58002 m .53894 .57483 L .55084 .56191 L 1 g
F
P
p
.53894 .57483 m .53464 .5731 L .54919 .56304 L 1 g
F
P
p
.53894 .57483 m .54919 .56304 L .55084 .56191 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .55457 .55687 L 1 g
F
P
p
.54854 .56129 m .53464 .5731 L .54013 .56931 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55186 .58002 m .5314 .57727 L .53373 .57428 L p
1 g
F P
s
P
p
.002 w
.53373 .57428 m .53464 .5731 L p
.53564 .5735 L 1 g
F P
s
P
p
.55186 .58002 m .53373 .57428 L .53564 .5735 L 1 g
F
P
p
.002 w
.52898 .57599 m .5314 .57727 L p
.51329 .57976 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54161 .54811 m .55033 .55286 L .5314 .57727 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .53186 .5753 L p
.52422 .57813 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51504 .58185 L p
.52422 .57813 L 1 g
F P
s
P
p
.002 w
.51504 .58185 m .5322 .57686 L p
.52422 .57813 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53464 .5731 m .55033 .55286 L p
.55084 .56191 L 1 g
F P
s
P
p
.002 w
.56079 .55435 m .55186 .58002 L p
.5508 .5612 L 1 g
F P
s
P
p
.56075 .54566 m .55457 .55687 L .5572 .55384 L 1 g
F
P
p
.002 w
.56291 .54561 m .56079 .55435 L .5595 .55417 L p
1 g
F P
s
P
p
.002 w
.5595 .55417 m .5572 .55384 L p
.56167 .54739 L 1 g
F P
s
P
p
.5595 .55417 m .56167 .54739 L .56291 .54561 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .54739 L p
1 g
F P
s
P
p
.56654 .52734 m .56167 .54739 L .56447 .53865 L 1 g
F
P
p
.002 w
.56167 .54739 m .56075 .54566 L p
.5572 .55384 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56654 .52734 m .56447 .53865 L .56495 .53718 L 1 g
F
P
p
.002 w
.56838 .52644 m .57186 .55246 L p
.56806 .54407 L 1 g
F P
s
P
p
.56806 .54407 m .56495 .53718 L .5676 .52888 L 1 g
F
P
p
.56806 .54407 m .5676 .52888 L .56838 .52644 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5676 .52888 L p
1 g
F P
s
P
p
.56515 .50826 m .5676 .52888 L .56753 .52652 L 1 g
F
P
p
.56515 .50826 m .56753 .52652 L .56747 .52495 L 1 g
F
P
p
.002 w
.56725 .52207 m .56808 .52422 L .56737 .52347 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .52495 L .56746 .52454 L 1 g
F
P
p
.002 w
.56744 .52435 m .56808 .52422 L .56746 .52454 L p
1 g
F P
s
P
p
.56745 .52443 m .56746 .52454 L .56745 .52444 L 1 g
F
P
p
.56515 .50826 m .56746 .52454 L .56745 .52443 L 1 g
F
P
p
.56515 .50826 m .56745 .52444 L .56744 .52432 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53557 .54057 m .53292 .53103 L .56744 .52435 L p
1 g
F P
s
P
p
.002 w
.56746 .52454 m .53557 .54057 L p
.56744 .52435 L 1 g
F P
s
P
p
.56515 .50826 m .56745 .52435 L .56744 .52421 L 1 g
F
P
p
.56515 .50826 m .56744 .52426 L .56741 .52392 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.53292 .53103 m .53398 .52051 L .56743 .52415 L p
1 g
F P
s
P
p
.002 w
.56743 .52415 m .56808 .52422 L .56744 .52435 L p
1 g
F P
s
P
p
.002 w
.56744 .52435 m .53292 .53103 L p
.56743 .52415 L 1 g
F P
s
P
p
.56744 .52432 m .56745 .52444 L .56745 .52435 L 1 g
F
P
p
.56744 .52421 m .56745 .52435 L .56744 .52426 L 1 g
F
P
p
.56515 .50826 m .56743 .52405 L .5672 .52158 L 1 g
F
P
p
.002 w
.53398 .52051 m .53866 .51019 L .56741 .5239 L p
1 g
F P
s
P
p
.002 w
.56741 .5239 m .56808 .52422 L .56743 .52415 L p
1 g
F P
s
P
p
.002 w
.56743 .52415 m .53398 .52051 L p
.56741 .5239 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53866 .51019 m .54648 .5012 L .56737 .52347 L p
1 g
F P
s
P
p
.002 w
.56737 .52347 m .56808 .52422 L .56741 .5239 L p
1 g
F P
s
P
p
.002 w
.56741 .5239 m .53866 .51019 L p
.56737 .52347 L 1 g
F P
s
P
p
.56741 .52392 m .56744 .52426 L .56743 .52405 L 1 g
F
P
p
.5672 .52158 m .56743 .52405 L .56736 .52262 L 1 g
F
P
p
.002 w
.56778 .49106 m .56808 .52422 L .56725 .52207 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56448 .4921 m .56778 .49106 L p
.56742 .5122 L 1 g
F P
s
P
p
.56607 .50936 m .56742 .5122 L .56725 .52207 L 1 g
F
P
p
.56448 .4921 m .56742 .5122 L .56607 .50936 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50936 L p
1 g
F P
s
P
p
.55661 .4905 m .56607 .50936 L .56232 .50142 L 1 g
F
P
p
.002 w
.56746 .52454 m .56808 .52422 L .56747 .52478 L p
1 g
F P
s
P
p
.002 w
.56747 .52478 m .56808 .52422 L .56748 .52519 L p
1 g
F P
s
P
p
.002 w
.56748 .52519 m .56808 .52422 L .56753 .52652 L p
1 g
F P
s
P
p
.002 w
.56808 .52422 m .56838 .52644 L p
.5676 .52888 L 1 g
F P
s
P
p
.002 w
.5676 .52888 m .56654 .52734 L p
.56495 .53718 L 1 g
F P
s
P
p
.002 w
.56495 .53718 m .56753 .52652 L p
.5676 .52888 L 1 g
F P
s
P
p
.002 w
.56753 .52652 m .56808 .52422 L p
.5676 .52888 L 1 g
F P
s
P
p
.002 w
.58238 .54739 m .57186 .55246 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.59125 .53969 m .58238 .54739 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.59754 .53016 m .59125 .53969 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.60059 .51979 m .59754 .53016 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.60003 .50968 m .60059 .51979 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.5959 .50091 m .60003 .50968 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.58858 .49444 m .5959 .50091 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.57886 .49103 m .58858 .49444 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.56778 .49106 m .57886 .49103 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56704 .51051 L p
1 g
F P
s
P
p
.002 w
.56704 .51051 m .56607 .50936 L p
.56733 .51999 L 1 g
F P
s
P
p
.56733 .51999 m .56854 .53025 L .56704 .51051 L 1 g
F
P
p
.002 w
.56607 .50936 m .56515 .50826 L p
.5672 .52158 L 1 g
F P
s
P
p
.5672 .52158 m .56854 .53025 L .56607 .50936 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55876 .49389 m .56448 .4921 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.54363 .46374 m .54307 .4624 L p
.55758 .49153 L 1 g
F P
s
P
p
.55758 .49153 m .55876 .49389 L .55756 .49151 L 1 g
F
P
p
.55758 .49153 m .55756 .49151 L .54363 .46374 L 1 g
F
P
p
.55677 .49082 m .56232 .50142 L .55775 .49176 L 1 g
F
P
p
.55677 .49082 m .55775 .49176 L .5577 .49166 L 1 g
F
P
p
.002 w
.5577 .49166 m .55661 .4905 L p
.55677 .49082 L 1 g
F P
s
P
p
.002 w
.55971 .4936 m .55876 .49389 L p
.55758 .49153 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55756 .49151 L p
1 g
F P
s
P
p
.54174 .47608 m .55756 .49151 L .55371 .48778 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55371 .48778 m .55657 .49458 L p
.54009 .47566 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .47671 L p
1 g
F P
s
P
p
.52214 .46667 m .54231 .47671 L .53369 .47265 L 1 g
F
P
p
.53383 .46846 m .54231 .47671 L .54009 .47566 L 1 g
F
P
p
.54231 .47671 m .55371 .48778 L .54009 .47566 L 1 g
F
P
p
.002 w
.52303 .47555 m .53005 .47094 L p
.55657 .49458 L 1 g
F P
s
P
p
.52214 .46667 m .53369 .47265 L .53005 .47094 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53005 .47094 m .52303 .47555 L .51458 .46609 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .51458 .46609 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51458 .46609 m .52303 .47555 L p
.4945 .46467 L 1 g
F P
s
P
p
.5 .46382 m .51458 .46609 L .4945 .46467 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.4829 .46647 m .4945 .46467 L .52303 .47555 L 1 g
F
P
p
.002 w
.5 .46382 m .5 .46442 L p
.48875 .46556 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .48875 .46556 L 1 g
F
P
p
.002 w
.47595 .47457 m .4829 .46647 L p
.52303 .47555 L 1 g
F P
s
P
p
.47786 .46667 m .48875 .46556 L .4829 .46647 L 1 g
F
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.4829 .46647 m .47595 .47457 L .47019 .4708 L p
1 g
F P
s
P
p
.47754 .4672 m .4829 .46647 L .47019 .4708 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44882 .4853 m .45177 .48243 L .47595 .47457 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47019 .4708 m .47595 .47457 L p
.45177 .48243 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47656 L p
1 g
F P
s
P
p
.44339 .4905 m .45782 .47656 L .44843 .48568 L 1 g
F
P
p
.43006 .48949 m .45782 .47656 L .45177 .48243 L 1 g
F
P
p
.45782 .47656 m .47019 .4708 L .45177 .48243 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44272 .49121 L p
1 g
F P
s
P
p
.43485 .50826 m .44272 .49121 L .43975 .49714 L 1 g
F
P
p
.002 w
.42627 .52591 m .42841 .49337 L .43524 .49564 L p
1 g
F P
s
P
p
.002 w
.43524 .49564 m .43975 .49714 L p
.43415 .50909 L 1 g
F P
s
P
p
.42627 .52591 m .43524 .49564 L .43415 .50909 L 1 g
F
P
p
.002 w
.43257 .52863 m .43346 .52734 L p
.43322 .52056 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42583 .5326 m .42627 .52591 L p
.43311 .52195 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43415 .50909 L p
1 g
F P
s
P
p
.43346 .52734 m .43415 .50909 L .43322 .52056 L 1 g
F
P
p
.43267 .52745 m .43311 .52195 L .46277 .5048 L 1 g
F
P
p
.42583 .5326 m .43311 .52195 L .43267 .52745 L 1 g
F
P
p
.43485 .50826 m .43975 .49714 L .43808 .50072 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43975 .49714 m .42841 .49337 L p
.44491 .48684 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43975 .49714 m .46277 .5048 L p
.42627 .52591 L 1 g
F P
s
P
p
.002 w
.43415 .50909 m .43287 .51061 L p
.43322 .52056 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43374 .53321 m .42583 .5326 L p
.43234 .5277 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43225 .5291 L p
1 g
F P
s
P
p
.002 w
.43712 .56749 m .42583 .5326 L .43374 .53321 L p
1 g
F P
s
P
p
.43712 .56749 m .43454 .54139 L .44311 .55921 L 1 g
F
P
p
.43454 .54139 m .43374 .53321 L .43864 .54681 L 1 g
F
P
p
.43454 .54139 m .43864 .54681 L .44311 .55921 L 1 g
F
P
p
.43925 .54566 m .43225 .5291 L .43567 .53859 L 1 g
F
P
p
.002 w
.43766 .54866 m .43925 .54566 L p
.43452 .53631 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .54681 L p
1 g
F P
s
P
p
.45146 .56129 m .43864 .54681 L .446 .55654 L 1 g
F
P
p
.002 w
.43374 .53321 m .46042 .53528 L p
.44551 .55589 L 1 g
F P
s
P
p
.44311 .55921 m .43864 .54681 L .44551 .55589 L 1 g
F
P
p
.43864 .54681 m .43374 .53321 L .44551 .55589 L 1 g
F
P
p
.002 w
.45084 .56295 m .45146 .56129 L p
.446 .55654 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45339 .56496 m .43712 .56749 L p
.44418 .55773 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45071 .56331 L p
1 g
F P
s
P
p
.46872 .57265 m .45071 .56331 L .46074 .56946 L 1 g
F
P
p
.002 w
.48311 .57936 m .4868 .58371 L p
.46601 .57332 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46812 .57541 L p
1 g
F P
s
P
p
.002 w
.46812 .57541 m .4678 .57686 L p
.47627 .57756 L 1 g
F P
s
P
p
.48921 .57862 m .46812 .57541 L .47627 .57756 L 1 g
F
P
p
.002 w
.48904 .58092 m .48921 .57862 L p
.48311 .57936 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46886 .56255 m .50208 .5535 L p
.48831 .58073 L 1 g
F P
s
P
p
.002 w
.4868 .58371 m .48311 .57936 L p
.48831 .58073 L 1 g
F P
s
P
p
.002 w
.48311 .57936 m .46886 .56255 L p
.48831 .58073 L 1 g
F P
s
P
p
.002 w
.46886 .56255 m .48311 .57936 L p
.46839 .57416 L 1 g
F P
s
P
p
.46601 .57332 m .46615 .57278 L .46839 .57416 L 1 g
F
P
p
.46615 .57278 m .46886 .56255 L .46839 .57416 L 1 g
F
P
p
.002 w
.46045 .59436 m .43712 .56749 L .46886 .56255 L p
1 g
F P
s
P
p
.002 w
.45071 .56331 m .45002 .56518 L p
.46074 .56946 L 1 g
F P
s
P
p
.002 w
.46042 .53528 m .46886 .56255 L .45339 .56496 L p
1 g
F P
s
P
p
.44418 .55773 m .46042 .53528 L .45339 .56496 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46791 .57635 L p
1 g
F P
s
P
p
.002 w
.46791 .57635 m .46839 .57416 L p
.45972 .56992 L 1 g
F P
s
P
p
.45972 .56992 m .45002 .56518 L .46791 .57635 L 1 g
F
P
p
.002 w
.43864 .54681 m .43743 .5491 L p
.446 .55654 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45084 .56295 L p
1 g
F P
s
P
p
.446 .55654 m .43743 .5491 L .45084 .56295 L 1 g
F
P
p
.002 w
.43225 .5291 m .43146 .53025 L p
.43567 .53859 L 1 g
F P
s
P
p
.002 w
.46277 .5048 m .46042 .53528 L .43374 .53321 L p
1 g
F P
s
P
p
.43234 .5277 m .46277 .5048 L .43374 .53321 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43766 .54866 L p
1 g
F P
s
P
p
.43452 .53631 m .43146 .53025 L .43766 .54866 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43257 .52863 L p
1 g
F P
s
P
p
.43322 .52056 m .43287 .51061 L .43257 .52863 L 1 g
F
P
p
.43808 .50072 m .43975 .49714 L .43875 .49915 L 1 g
F
P
p
.002 w
.47595 .47457 m .46277 .5048 L .43975 .49714 L p
1 g
F P
s
P
p
.002 w
.44272 .49121 m .44339 .4905 L p
.44843 .48568 L 1 g
F P
s
P
p
.44272 .49121 m .47595 .47457 L .43975 .49714 L 1 g
F
P
p
.44491 .48684 m .44882 .4853 L .44272 .49121 L 1 g
F
P
p
.44882 .4853 m .47595 .47457 L .44272 .49121 L 1 g
F
P
p
.002 w
.44272 .49121 m .44166 .49233 L p
.43875 .49915 L 1 g
F P
s
P
p
.002 w
.45782 .47656 m .45698 .47747 L p
.44843 .48568 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44272 .49121 L p
1 g
F P
s
P
p
.44843 .48568 m .45698 .47747 L .44272 .49121 L 1 g
F
P
p
.002 w
.42841 .49337 m .43006 .48949 L p
.45177 .48243 L 1 g
F P
s
P
p
.42841 .49337 m .45177 .48243 L .44882 .4853 L 1 g
F
P
p
.45826 .47608 m .47754 .4672 L .46919 .47129 L 1 g
F
P
p
.002 w
.45733 .47709 m .45826 .47608 L p
.46919 .47129 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.43006 .48949 m .44506 .45431 L .47019 .4708 L p
1 g
F P
s
P
p
.46919 .47129 m .47019 .4708 L .47718 .46778 L 1 g
F
P
p
.002 w
.47754 .4672 m .47739 .46744 L p
.47019 .4708 L 1 g
F P
s
P
p
.002 w
.47739 .46744 m .47718 .46778 L p
.47019 .4708 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46691 .46864 m .44506 .45431 L p
.48056 .46572 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.4829 .46647 L 1 g
F P
s
P
p
.48056 .46572 m .4829 .46647 L .47754 .4672 L 1 g
F
P
p
.48056 .46572 m .47754 .4672 L .46691 .46864 L 1 g
F
P
p
.002 w
.47019 .4708 m .46691 .46864 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45733 .47709 L p
1 g
F P
s
P
p
.46919 .47129 m .47718 .46778 L .45733 .47709 L 1 g
F
P
p
.002 w
.47747 .46731 m .47754 .4672 L p
.4829 .46647 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.49859 .4482 m .4829 .46647 L p
.44506 .45431 L 1 g
F P
s
P
p
.002 w
.4829 .46647 m .48693 .46178 L p
.4945 .46467 L 1 g
F P
s
P
p
.48693 .46178 m .5 .46382 L .4945 .46467 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46731 L p
1 g
F P
s
P
p
.48875 .46556 m .5 .46442 L .47747 .46731 L 1 g
F
P
p
.51143 .4656 m .51458 .46609 L .51235 .46577 L 1 g
F
P
p
.5 .4634 m .51458 .46609 L .51143 .4656 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.52246 .4672 m .53005 .47094 L .51458 .46609 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48693 .46178 m .49859 .4482 L .51458 .46609 L p
1 g
F P
s
P
p
.002 w
.51458 .46609 m .51016 .46114 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52282 .46778 L p
.51235 .46577 L 1 g
F P
s
P
p
.002 w
.5226 .46743 m .52246 .4672 L p
.53005 .47094 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53005 .47094 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54307 .4624 m .53005 .47094 L p
.49859 .4482 L 1 g
F P
s
P
p
.002 w
.51016 .46114 m .49859 .4482 L p
.53005 .47094 L 1 g
F P
s
P
p
.002 w
.53005 .47094 m .53383 .46846 L p
.54009 .47566 L 1 g
F P
s
P
p
.53005 .47094 m .54009 .47566 L .55657 .49458 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5226 .46743 L p
1 g
F P
s
P
p
.53369 .47265 m .54302 .47747 L .5226 .46743 L 1 g
F
P
p
.002 w
.54231 .47671 m .54302 .47747 L p
.53369 .47265 L 1 g
F P
s
P
p
.5504 .48456 m .55371 .48778 L .55083 .48498 L 1 g
F
P
p
.54174 .47608 m .55371 .48778 L .5504 .48456 L 1 g
F
P
p
.002 w
.54243 .47683 m .54174 .47608 L p
.55083 .48498 L 1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53383 .46846 m .54307 .4624 L .55371 .48778 L p
1 g
F P
s
P
p
.002 w
.55876 .49389 m .55657 .49458 L .54363 .46374 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .5577 .49166 L p
.56488 .5061 L 1 g
F P
s
P
p
.56232 .50142 m .56713 .51061 L .5577 .49166 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54243 .47683 L p
1 g
F P
s
P
p
.55083 .48498 m .55834 .49233 L .54243 .47683 L 1 g
F
P
p
.002 w
.55756 .49151 m .55834 .49233 L p
.55083 .48498 L 1 g
F P
s
P
p
.002 w
.56778 .49106 m .55971 .4936 L p
.54307 .4624 L 1 g
F P
s
P
p
.54307 .4624 m .55971 .4936 L .55758 .49153 L 1 g
F
P
p
.002 w
.56713 .51061 m .56666 .50965 L p
.56488 .5061 L 1 g
F P
s
P
p
.002 w
.56666 .50965 m .55834 .49233 L p
.56488 .5061 L 1 g
F P
s
P
p
.002 w
.56725 .52207 m .55657 .49458 L .55876 .49389 L p
1 g
F P
s
P
p
.55876 .49389 m .56607 .50936 L .56725 .52207 L 1 g
F
P
p
.002 w
.56607 .50936 m .56713 .51061 L p
.56232 .50142 L 1 g
F P
s
P
p
.002 w
.54648 .5012 m .55657 .49458 L .56725 .52207 L p
1 g
F P
s
P
p
.002 w
.56737 .52347 m .54648 .5012 L p
.56725 .52207 L 1 g
F P
s
P
p
.56736 .52262 m .56744 .52416 L .56741 .5229 L 1 g
F
P
p
.56744 .52416 m .56747 .52495 L .56746 .52436 L 1 g
F
P
p
.56744 .52416 m .56746 .52436 L .56741 .5229 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54161 .54811 m .53557 .54057 L .56746 .52454 L p
1 g
F P
s
P
p
.002 w
.56747 .52478 m .54161 .54811 L p
.56746 .52454 L 1 g
F P
s
P
p
.002 w
.55033 .55286 m .54161 .54811 L .56747 .52478 L p
1 g
F P
s
P
p
.002 w
.56748 .52519 m .55033 .55286 L p
.56747 .52478 L 1 g
F P
s
P
p
.56741 .5229 m .56748 .52519 L .56742 .52298 L 1 g
F
P
p
.56748 .52519 m .56753 .52652 L .5675 .5256 L 1 g
F
P
p
.56748 .52519 m .5675 .5256 L .56742 .52298 L 1 g
F
P
p
.002 w
.55033 .55286 m .56748 .52519 L p
.56495 .53718 L 1 g
F P
s
P
p
.002 w
.56753 .52652 m .56495 .53718 L p
.56748 .52519 L 1 g
F P
s
P
p
.002 w
.5676 .52888 m .56854 .53025 L p
.56742 .52298 L 1 g
F P
s
P
p
.002 w
.56761 .52889 m .5676 .52888 L p
.56495 .53718 L 1 g
F P
s
P
p
.002 w
.57186 .55246 m .56079 .55435 L .56495 .53718 L p
1 g
F P
s
P
p
.002 w
.56495 .53718 m .56291 .54561 L p
.56209 .54608 L 1 g
F P
s
P
p
.56209 .54608 m .55033 .55286 L .56495 .53718 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56761 .52889 L p
1 g
F P
s
P
p
.56447 .53865 m .56257 .5491 L .56761 .52889 L 1 g
F
P
p
.002 w
.5572 .55384 m .55033 .55286 L p
.56291 .54561 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56257 .5491 L p
.56447 .53865 L 1 g
F P
s
P
p
.002 w
.5621 .54822 m .56167 .54739 L p
.5572 .55384 L 1 g
F P
s
P
p
.002 w
.55033 .55286 m .5572 .55384 L p
.5508 .5612 L 1 g
F P
s
P
p
.002 w
.5572 .55384 m .56079 .55435 L p
.5508 .5612 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5621 .54822 L p
1 g
F P
s
P
p
.55457 .55687 m .54998 .56518 L .5621 .54822 L 1 g
F
P
p
.002 w
.54919 .56304 m .54998 .56518 L p
.55457 .55687 L 1 g
F P
s
P
p
.54013 .56931 m .53464 .5731 L .53952 .56988 L 1 g
F
P
p
.002 w
.53179 .57498 m .53128 .57265 L p
.52898 .57599 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51417 .56816 m .54161 .54811 L p
.53227 .5748 L 1 g
F P
s
P
p
.002 w
.52898 .57599 m .51417 .56816 L p
.53227 .5748 L 1 g
F P
s
P
p
.002 w
.53179 .57498 m .5322 .57686 L p
.53952 .56988 L 1 g
F P
s
P
p
.002 w
.53186 .5753 m .53179 .57498 L p
.52898 .57599 L 1 g
F P
s
P
p
.002 w
.51417 .56816 m .52898 .57599 L p
.51329 .57976 L 1 g
F P
s
P
p
.52106 .57789 m .51111 .583 L .53186 .5753 L 1 g
F
P
p
.002 w
.51092 .58033 m .51111 .583 L p
.52106 .57789 L 1 g
F P
s
P
p
.50041 .5807 m .49156 .581 L .49786 .5812 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50208 .5535 m .51417 .56816 L .49086 .5814 L p
1 g
F P
s
P
p
.48831 .58073 m .50208 .5535 L .49086 .5814 L 1 g
F
P
p
.002 w
.48904 .58092 m .48889 .583 L p
.49786 .5812 L 1 g
F P
s
P
p
.002 w
.489 .58144 m .48904 .58092 L p
.48311 .57936 L 1 g
F P
s
P
p
.46074 .56946 m .45002 .56518 L .46839 .57416 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .489 .58144 L p
1 g
F P
s
P
p
.47854 .57774 m .4678 .57686 L .489 .58144 L 1 g
F
P
p
.002 w
.59274 .31921 m .64017 .33906 L .63795 .36712 L p
1 g
F P
s
P
p
.002 w
.64017 .33906 m .59274 .31921 L .58703 .29257 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.60839 .33579 L
s
P
p
.004 w
.63347 .31387 m
.65076 .29877 L
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51716 .45413 L
s
P
p
.004 w
.53952 .48491 m
.54979 .49904 L
s
P
p
.002 w
.42583 .5326 m .43712 .56749 L .40794 .56824 L p
1 g
F P
s
P
p
.002 w
.40794 .56824 m .39403 .52686 L .42583 .5326 L p
1 g
F P
s
P
p
.002 w
.57186 .55246 m .58238 .54739 L .59377 .56636 L p
1 g
F P
s
P
p
.002 w
.59377 .56636 m .57338 .57623 L .57186 .55246 L p
1 g
F P
s
P
p
.002 w
.61099 .55144 m .59377 .56636 L .58238 .54739 L p
1 g
F P
s
P
p
.004 w
.59654 .56338 m
.60899 .58053 L
s
P
p
.002 w
.58238 .54739 m .59125 .53969 L .61099 .55144 L p
1 g
F P
s
P
p
.002 w
.6233 .53296 m .61099 .55144 L .59125 .53969 L p
1 g
F P
s
P
p
.002 w
.45179 .28552 m .51621 .26751 L .52695 .28976 L p
1 g
F P
s
P
p
.002 w
.58703 .29257 m .52695 .28976 L .51621 .26751 L p
1 g
F P
s
P
p
.002 w
.56079 .55435 m .57186 .55246 L .57338 .57623 L p
1 g
F P
s
P
p
.002 w
.57338 .57623 m .55186 .58002 L .56079 .55435 L p
1 g
F P
s
P
p
.002 w
.52695 .28976 m .58703 .29257 L .59274 .31921 L p
1 g
F P
s
P
p
.002 w
.59125 .53969 m .59754 .53016 L .6233 .53296 L p
1 g
F P
s
P
p
.002 w
.62937 .51278 m .6233 .53296 L .59754 .53016 L p
1 g
F P
s
P
p
.002 w
.39661 .48013 m .39403 .52686 L .3661 .51838 L p
1 g
F P
s
P
p
.002 w
.3661 .51838 m .36853 .46562 L .39661 .48013 L p
1 g
F P
s
P
p
.002 w
.40989 .34326 m .36813 .3932 L .35065 .37522 L p
1 g
F P
s
P
p
.002 w
.35065 .37522 m .39407 .32304 L .40989 .34326 L p
1 g
F P
s
P
p
.002 w
.62937 .51278 m .6285 .49295 L .65254 .47469 L p
1 g
F P
s
P
p
.002 w
.64135 .44923 m .65254 .47469 L .6285 .49295 L p
1 g
F P
s
P
p
.002 w
.65254 .47469 m .64135 .44923 L .65748 .4228 L p
1 g
F P
s
P
p
.002 w
.63148 .39778 m .65748 .4228 L .64135 .44923 L p
1 g
F P
s
P
p
.002 w
.65748 .4228 m .63148 .39778 L .63795 .36712 L p
1 g
F P
s
P
p
.002 w
.39017 .41284 m .36853 .46562 L .34507 .4504 L p
1 g
F P
s
P
p
.002 w
.34507 .4504 m .36813 .3932 L .39017 .41284 L p
1 g
F P
s
P
p
.002 w
.59754 .53016 m .60059 .51979 L .62937 .51278 L p
1 g
F P
s
P
p
.002 w
.6285 .49295 m .62937 .51278 L .60059 .51979 L p
1 g
F P
s
P
p
.002 w
.52695 .28976 m .46524 .30724 L .45179 .28552 L p
1 g
F P
s
P
p
.002 w
.39407 .32304 m .45179 .28552 L .46524 .30724 L p
1 g
F P
s
P
p
.002 w
.59575 .34993 m .63795 .36712 L .63148 .39778 L p
1 g
F P
s
P
p
.002 w
.63795 .36712 m .59575 .34993 L .59274 .31921 L p
1 g
F P
s
P
p
.004 w
.62314 .3229 m
.63347 .31387 L
s
P
p
.004 w
.61022 .33419 m
.6111 .33342 L
s
P
p
.004 w
.6111 .33342 m
.62314 .3229 L
s
P
p
.002 w
.46524 .30724 m .40989 .34326 L .39407 .32304 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.53718 .31697 m .59274 .31921 L .59575 .34993 L p
1 g
F P
s
P
p
.002 w
.59274 .31921 m .53718 .31697 L .52695 .28976 L p
1 g
F P
s
P
p
.002 w
.46524 .30724 m .52695 .28976 L .53718 .31697 L p
1 g
F P
s
P
p
.002 w
.42841 .49337 m .42583 .5326 L .39403 .52686 L p
1 g
F P
s
P
p
.002 w
.39403 .52686 m .39661 .48013 L .42841 .49337 L p
1 g
F P
s
P
p
.002 w
.60059 .51979 m .60003 .50968 L .6285 .49295 L p
1 g
F P
s
P
p
.002 w
.62061 .47559 m .6285 .49295 L .60003 .50968 L p
1 g
F P
s
P
p
.002 w
.6285 .49295 m .62061 .47559 L .64135 .44923 L p
1 g
F P
s
P
p
.002 w
.62086 .43001 m .64135 .44923 L .62061 .47559 L p
1 g
F P
s
P
p
.002 w
.64135 .44923 m .62086 .43001 L .63148 .39778 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.53557 .54057 m .54161 .54811 L .51417 .56816 L p
1 g
F P
s
P
p
.002 w
.51417 .56816 m .50208 .5535 L .53557 .54057 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42894 .36674 m .39017 .41284 L .36813 .3932 L p
1 g
F P
s
P
p
.002 w
.36813 .3932 m .40989 .34326 L .42894 .36674 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41611 .43347 m .39661 .48013 L .36853 .46562 L p
1 g
F P
s
P
p
.002 w
.36853 .46562 m .39017 .41284 L .41611 .43347 L p
1 g
F P
s
P
p
.002 w
.49657 .53476 m .50208 .5535 L .46886 .56255 L p
1 g
F P
s
P
p
.002 w
.46886 .56255 m .46042 .53528 L .49657 .53476 L p
1 g
F P
s
P
p
.002 w
.59588 .38373 m .63148 .39778 L .62086 .43001 L p
1 g
F P
s
P
p
.002 w
.63148 .39778 m .59588 .38373 L .59575 .34993 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60003 .50968 m .5959 .50091 L .62061 .47559 L p
1 g
F P
s
P
p
.002 w
.6064 .46264 m .62061 .47559 L .5959 .50091 L p
1 g
F P
s
P
p
.002 w
.62061 .47559 m .6064 .46264 L .62086 .43001 L p
1 g
F P
s
P
p
.002 w
.53718 .31697 m .48015 .33337 L .46524 .30724 L p
1 g
F P
s
P
p
.002 w
.40989 .34326 m .46524 .30724 L .48015 .33337 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48015 .33337 m .42894 .36674 L .40989 .34326 L p
1 g
F P
s
P
p
.002 w
.54649 .34833 m .59575 .34993 L .59588 .38373 L p
1 g
F P
s
P
p
.002 w
.59575 .34993 m .54649 .34833 L .53718 .31697 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53292 .53103 m .53557 .54057 L .50208 .5535 L p
1 g
F P
s
P
p
.002 w
.50208 .5535 m .49657 .53476 L .53292 .53103 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59303 .41942 m .62086 .43001 L .6064 .46264 L p
1 g
F P
s
P
p
.002 w
.62086 .43001 m .59303 .41942 L .59588 .38373 L p
1 g
F P
s
P
p
.002 w
.48015 .33337 m .53718 .31697 L .54649 .34833 L p
1 g
F P
s
P
p
.002 w
.5959 .50091 m .58858 .49444 L .6064 .46264 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44506 .45431 m .42841 .49337 L .39661 .48013 L p
1 g
F P
s
P
p
.002 w
.39661 .48013 m .41611 .43347 L .44506 .45431 L p
1 g
F P
s
P
p
.002 w
.49842 .51397 m .49657 .53476 L .46042 .53528 L p
1 g
F P
s
P
p
.002 w
.46042 .53528 m .46277 .5048 L .49842 .51397 L p
1 g
F P
s
P
p
.002 w
.45062 .39271 m .41611 .43347 L .39017 .41284 L p
1 g
F P
s
P
p
.002 w
.39017 .41284 m .42894 .36674 L .45062 .39271 L p
1 g
F P
s
P
p
.002 w
.58729 .45564 m .6064 .46264 L .58858 .49444 L p
1 g
F P
s
P
p
.002 w
.6064 .46264 m .58729 .45564 L .59303 .41942 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58858 .49444 m .57886 .49103 L .58729 .45564 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5545 .38275 m .59588 .38373 L .59303 .41942 L p
1 g
F P
s
P
p
.002 w
.59588 .38373 m .5545 .38275 L .54649 .34833 L p
1 g
F P
s
P
p
.002 w
.53398 .52051 m .53292 .53103 L .49657 .53476 L p
1 g
F P
s
P
p
.002 w
.49657 .53476 m .49842 .51397 L .53398 .52051 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57886 .49103 m .56778 .49106 L .56535 .45552 L p
1 g
F P
s
P
p
.002 w
.56535 .45552 m .58729 .45564 L .57886 .49103 L p
1 g
F P
s
P
p
.002 w
.54649 .34833 m .49599 .3631 L .48015 .33337 L p
1 g
F P
s
P
p
.002 w
.42894 .36674 m .48015 .33337 L .49599 .3631 L p
1 g
F P
s
P
p
.002 w
.53866 .51019 m .53398 .52051 L .49842 .51397 L p
1 g
F P
s
P
p
.002 w
.49599 .3631 m .45062 .39271 L .42894 .36674 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49599 .3631 m .54649 .34833 L .5545 .38275 L p
1 g
F P
s
P
p
.002 w
.56087 .41895 m .59303 .41942 L .58729 .45564 L p
1 g
F P
s
P
p
.002 w
.59303 .41942 m .56087 .41895 L .5545 .38275 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.54307 .4624 m .56535 .45552 L .56778 .49106 L p
1 g
F P
s
P
p
.002 w
.58729 .45564 m .56535 .45552 L .56087 .41895 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54648 .5012 m .53866 .51019 L .50756 .49343 L p
1 g
F P
s
P
p
.002 w
.49842 .51397 m .50756 .49343 L .53866 .51019 L p
1 g
F P
s
P
p
.002 w
.55657 .49458 m .54648 .5012 L .52303 .47555 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.50756 .49343 m .52303 .47555 L .54648 .5012 L p
1 g
F P
s
P
p
.002 w
.47413 .42021 m .44506 .45431 L .41611 .43347 L p
1 g
F P
s
P
p
.002 w
.41611 .43347 m .45062 .39271 L .47413 .42021 L p
1 g
F P
s
P
p
.002 w
.50756 .49343 m .49842 .51397 L .46277 .5048 L p
1 g
F P
s
P
p
.002 w
.46277 .5048 m .47595 .47457 L .50756 .49343 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51218 .39535 m .5545 .38275 L .56087 .41895 L p
1 g
F P
s
P
p
.002 w
.5545 .38275 m .51218 .39535 L .49599 .3631 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56535 .45552 m .54307 .4624 L .52808 .42889 L p
1 g
F P
s
P
p
.002 w
.52808 .42889 m .56087 .41895 L .56535 .45552 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.45062 .39271 m .49599 .3631 L .51218 .39535 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.52303 .47555 m .50756 .49343 L .47595 .47457 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.51218 .39535 m .47413 .42021 L .45062 .39271 L p
1 g
F P
s
P
p
.002 w
.56087 .41895 m .52808 .42889 L .51218 .39535 L p
1 g
F P
s
P
p
.002 w
.44506 .45431 m .47413 .42021 L .49859 .4482 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49859 .4482 m .52808 .42889 L .54307 .4624 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47413 .42021 m .51218 .39535 L .52808 .42889 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.52808 .42889 m .49859 .4482 L .47413 .42021 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59095 .55569 m
.59654 .56338 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .67671 .27609 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60899 .58053 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.00368421)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.00368421)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48405 .4715 m .52232 .45433 L .50744 .43005 L p
1 g
F P
s
P
p
.002 w
.50744 .43005 m .47555 .44432 L .48405 .4715 L p
1 g
F P
s
P
p
.002 w
.53434 .40801 m .50744 .43005 L .52232 .45433 L p
1 g
F P
s
P
p
.002 w
.47555 .44432 m .50744 .43005 L .4924 .4058 L p
1 g
F P
s
P
p
.002 w
.50744 .43005 m .53434 .40801 L .51322 .38865 L p
1 g
F P
s
P
p
.002 w
.51322 .38865 m .4924 .4058 L .50744 .43005 L p
1 g
F P
s
P
p
.002 w
.4924 .4058 m .46764 .41684 L .47555 .44432 L p
1 g
F P
s
P
p
.002 w
.46764 .41684 m .4924 .4058 L .47745 .38201 L p
1 g
F P
s
P
p
.002 w
.4924 .4058 m .51322 .38865 L .49168 .37023 L p
1 g
F P
s
P
p
.002 w
.49168 .37023 m .47745 .38201 L .4924 .4058 L p
1 g
F P
s
P
p
.002 w
.4434 .47785 m .48405 .4715 L .47555 .44432 L p
1 g
F P
s
P
p
.002 w
.47555 .44432 m .44168 .44943 L .4434 .47785 L p
1 g
F P
s
P
p
.002 w
.44168 .44943 m .47555 .44432 L .46764 .41684 L p
1 g
F P
s
P
p
.002 w
.49301 .4979 m .53676 .4782 L .52232 .45433 L p
1 g
F P
s
P
p
.002 w
.52232 .45433 m .48405 .4715 L .49301 .4979 L p
1 g
F P
s
P
p
.002 w
.55468 .42795 m .52232 .45433 L .53676 .4782 L p
1 g
F P
s
P
p
.002 w
.52232 .45433 m .55468 .42795 L .53434 .40801 L p
1 g
F P
s
P
p
.002 w
.46764 .41684 m .44137 .42067 L .44168 .44943 L p
1 g
F P
s
P
p
.002 w
.44137 .42067 m .46764 .41684 L .46049 .38956 L p
1 g
F P
s
P
p
.002 w
.47745 .38201 m .46049 .38956 L .46764 .41684 L p
1 g
F P
s
P
p
.002 w
.55362 .38025 m .53434 .40801 L .55468 .42795 L p
1 g
F P
s
P
p
.002 w
.53434 .40801 m .55362 .38025 L .52801 .36705 L p
1 g
F P
s
P
p
.002 w
.52801 .36705 m .51322 .38865 L .53434 .40801 L p
1 g
F P
s
P
p
.002 w
.51322 .38865 m .52801 .36705 L .50171 .3554 L p
1 g
F P
s
P
p
.002 w
.50171 .3554 m .49168 .37023 L .51322 .38865 L p
1 g
F P
s
P
p
.002 w
.44653 .50538 m .49301 .4979 L .48405 .4715 L p
1 g
F P
s
P
p
.002 w
.48405 .4715 m .4434 .47785 L .44653 .50538 L p
1 g
F P
s
P
p
.002 w
.46049 .38956 m .47745 .38201 L .46288 .35913 L p
1 g
F P
s
P
p
.002 w
.47745 .38201 m .49168 .37023 L .47013 .3531 L p
1 g
F P
s
P
p
.002 w
.47013 .3531 m .46288 .35913 L .47745 .38201 L p
1 g
F P
s
P
p
.002 w
.53676 .4782 m .57386 .44813 L .55468 .42795 L p
1 g
F P
s
P
p
.002 w
.57806 .39474 m .55468 .42795 L .57386 .44813 L p
1 g
F P
s
P
p
.002 w
.55468 .42795 m .57806 .39474 L .55362 .38025 L p
1 g
F P
s
P
p
.002 w
.46049 .38956 m .4425 .39209 L .44137 .42067 L p
1 g
F P
s
P
p
.002 w
.4425 .39209 m .46049 .38956 L .45422 .36297 L p
1 g
F P
s
P
p
.002 w
.46288 .35913 m .45422 .36297 L .46049 .38956 L p
1 g
F P
s
P
p
.002 w
.40909 .44474 m .44168 .44943 L .44137 .42067 L p
1 g
F P
s
P
p
.002 w
.44137 .42067 m .41618 .41682 L .40909 .44474 L p
1 g
F P
s
P
p
.002 w
.41618 .41682 m .44137 .42067 L .4425 .39209 L p
1 g
F P
s
P
p
.002 w
.50227 .523 m .5505 .50123 L .53676 .4782 L p
1 g
F P
s
P
p
.002 w
.53676 .4782 m .49301 .4979 L .50227 .523 L p
1 g
F P
s
P
p
.002 w
.57386 .44813 m .53676 .4782 L .5505 .50123 L p
1 g
F P
s
P
p
.002 w
.49168 .37023 m .50171 .3554 L .47519 .34551 L p
1 g
F P
s
P
p
.002 w
.47519 .34551 m .47013 .3531 L .49168 .37023 L p
1 g
F P
s
P
p
.002 w
.40417 .47253 m .4434 .47785 L .44168 .44943 L p
1 g
F P
s
P
p
.002 w
.44168 .44943 m .40909 .44474 L .40417 .47253 L p
1 g
F P
s
P
p
.002 w
.45104 .53149 m .50227 .523 L .49301 .4979 L p
1 g
F P
s
P
p
.002 w
.49301 .4979 m .44653 .50538 L .45104 .53149 L p
1 g
F P
s
P
p
.002 w
.4425 .39209 m .42532 .38932 L .41618 .41682 L p
1 g
F P
s
P
p
.002 w
.42532 .38932 m .4425 .39209 L .44504 .36422 L p
1 g
F P
s
P
p
.002 w
.45422 .36297 m .44504 .36422 L .4425 .39209 L p
1 g
F P
s
P
p
.002 w
.5352 .34309 m .52801 .36705 L .55362 .38025 L p
1 g
F P
s
P
p
.002 w
.52801 .36705 m .5352 .34309 L .50645 .339 L p
1 g
F P
s
P
p
.002 w
.50645 .339 m .50171 .3554 L .52801 .36705 L p
1 g
F P
s
P
p
.002 w
.56322 .34936 m .55362 .38025 L .57806 .39474 L p
1 g
F P
s
P
p
.002 w
.55362 .38025 m .56322 .34936 L .5352 .34309 L p
1 g
F P
s
P
p
.002 w
.40157 .49965 m .44653 .50538 L .4434 .47785 L p
1 g
F P
s
P
p
.002 w
.4434 .47785 m .40417 .47253 L .40157 .49965 L p
1 g
F P
s
P
p
.002 w
.50171 .3554 m .50645 .339 L .47752 .33715 L p
1 g
F P
s
P
p
.002 w
.47752 .33715 m .47519 .34551 L .50171 .3554 L p
1 g
F P
s
P
p
.002 w
.5505 .50123 m .5915 .46816 L .57386 .44813 L p
1 g
F P
s
P
p
.002 w
.60084 .41028 m .57386 .44813 L .5915 .46816 L p
1 g
F P
s
P
p
.002 w
.57386 .44813 m .60084 .41028 L .57806 .39474 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .45422 .36297 L .46288 .35913 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .46288 .35913 L .47013 .3531 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .44504 .36422 L .45422 .36297 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .47013 .3531 L .47519 .34551 L closepath p
1 g
F P
s
P
p
.002 w
.38107 .43041 m .40909 .44474 L .41618 .41682 L p
1 g
F P
s
P
p
.002 w
.41618 .41682 m .39467 .40551 L .38107 .43041 L p
1 g
F P
s
P
p
.002 w
.39467 .40551 m .41618 .41682 L .42532 .38932 L p
1 g
F P
s
P
p
.002 w
.42532 .38932 m .41074 .38144 L .39467 .40551 L p
1 g
F P
s
P
p
.002 w
.41074 .38144 m .42532 .38932 L .43631 .36274 L p
1 g
F P
s
P
p
.002 w
.44504 .36422 m .43631 .36274 L .42532 .38932 L p
1 g
F P
s
P
p
.002 w
.58996 .3577 m .57806 .39474 L .60084 .41028 L p
1 g
F P
s
P
p
.002 w
.57806 .39474 m .58996 .3577 L .56322 .34936 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .43631 .36274 L .44504 .36422 L closepath p
1 g
F P
s
P
p
.002 w
.51165 .54631 m .56325 .52295 L .5505 .50123 L p
1 g
F P
s
P
p
.002 w
.5505 .50123 m .50227 .523 L .51165 .54631 L p
1 g
F P
s
P
p
.002 w
.5915 .46816 m .5505 .50123 L .56325 .52295 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .47519 .34551 L .47752 .33715 L closepath p
1 g
F P
s
P
p
.002 w
.50533 .32273 m .50645 .339 L .5352 .34309 L p
1 g
F P
s
P
p
.002 w
.50645 .339 m .50533 .32273 L .47685 .32891 L p
1 g
F P
s
P
p
.002 w
.47685 .32891 m .47752 .33715 L .50645 .339 L p
1 g
F P
s
P
p
.002 w
.4014 .52555 m .45104 .53149 L .44653 .50538 L p
1 g
F P
s
P
p
.002 w
.44653 .50538 m .40157 .49965 L .4014 .52555 L p
1 g
F P
s
P
p
.002 w
.37027 .45566 m .40417 .47253 L .40909 .44474 L p
1 g
F P
s
P
p
.002 w
.40909 .44474 m .38107 .43041 L .37027 .45566 L p
1 g
F P
s
P
p
.002 w
.45686 .55562 m .51165 .54631 L .50227 .523 L p
1 g
F P
s
P
p
.002 w
.50227 .523 m .45104 .53149 L .45686 .55562 L p
1 g
F P
s
P
p
.002 w
.43631 .36274 m .42896 .35865 L .41074 .38144 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .42896 .35865 L .43631 .36274 L closepath p
1 g
F P
s
P
p
.002 w
.53385 .31918 m .5352 .34309 L .56322 .34936 L p
1 g
F P
s
P
p
.002 w
.5352 .34309 m .53385 .31918 L .50533 .32273 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .47752 .33715 L .47685 .32891 L closepath p
1 g
F P
s
P
p
.002 w
.56325 .52295 m .60721 .48765 L .5915 .46816 L p
1 g
F P
s
P
p
.002 w
.6215 .42659 m .5915 .46816 L .60721 .48765 L p
1 g
F P
s
P
p
.002 w
.5915 .46816 m .6215 .42659 L .60084 .41028 L p
1 g
F P
s
P
p
.002 w
.40038 .36918 m .41074 .38144 L .42896 .35865 L p
1 g
F P
s
P
p
.002 w
.42896 .35865 m .4238 .35238 L .40038 .36918 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .4238 .35238 L .42896 .35865 L closepath p
1 g
F P
s
P
p
.002 w
.3792 .3877 m .39467 .40551 L .41074 .38144 L p
1 g
F P
s
P
p
.002 w
.41074 .38144 m .40038 .36918 L .3792 .3877 L p
1 g
F P
s
P
p
.002 w
.61486 .368 m .60084 .41028 L .6215 .42659 L p
1 g
F P
s
P
p
.002 w
.60084 .41028 m .61486 .368 L .58996 .3577 L p
1 g
F P
s
P
p
.002 w
.56185 .31838 m .56322 .34936 L .58996 .3577 L p
1 g
F P
s
P
p
.002 w
.56322 .34936 m .56185 .31838 L .53385 .31918 L p
1 g
F P
s
P
p
.002 w
.47321 .32168 m .47685 .32891 L .50533 .32273 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .47685 .32891 L .47321 .32168 L closepath p
1 g
F P
s
P
p
.002 w
.36254 .48075 m .40157 .49965 L .40417 .47253 L p
1 g
F P
s
P
p
.002 w
.40417 .47253 m .37027 .45566 L .36254 .48075 L p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .45879 .31324 L .44956 .31301 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .44956 .31301 L .44031 .3156 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .44031 .3156 L .43206 .32073 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .43206 .32073 L .42575 .32782 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .42575 .32782 L .42207 .33608 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .42207 .33608 L .4214 .34458 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .4214 .34458 L .4238 .35238 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .47321 .32168 L .46697 .31625 L closepath p
1 g
F P
s
P
p
.002 w
.44897 .3376 m .46697 .31625 L .45879 .31324 L closepath p
1 g
F P
s
P
p
.002 w
.49833 .30833 m .50533 .32273 L .53385 .31918 L p
1 g
F P
s
P
p
.002 w
.50533 .32273 m .49833 .30833 L .47321 .32168 L p
1 g
F P
s
P
p
.002 w
.36073 .40759 m .38107 .43041 L .39467 .40551 L p
1 g
F P
s
P
p
.002 w
.39467 .40551 m .3792 .3877 L .36073 .40759 L p
1 g
F P
s
P
p
.002 w
.39544 .35379 m .40038 .36918 L .4238 .35238 L p
1 g
F P
s
P
p
.002 w
.4238 .35238 m .4214 .34458 L .39544 .35379 L p
1 g
F P
s
P
p
.002 w
.52097 .5673 m .57473 .54289 L .56325 .52295 L p
1 g
F P
s
P
p
.002 w
.56325 .52295 m .51165 .54631 L .52097 .5673 L p
1 g
F P
s
P
p
.002 w
.60721 .48765 m .56325 .52295 L .57473 .54289 L p
1 g
F P
s
P
p
.002 w
.46697 .31625 m .47321 .32168 L .49833 .30833 L p
1 g
F P
s
P
p
.002 w
.40373 .54965 m .45686 .55562 L .45104 .53149 L p
1 g
F P
s
P
p
.002 w
.45104 .53149 m .4014 .52555 L .40373 .54965 L p
1 g
F P
s
P
p
.002 w
.58874 .32039 m .58996 .3577 L .61486 .368 L p
1 g
F P
s
P
p
.002 w
.58996 .3577 m .58874 .32039 L .56185 .31838 L p
1 g
F P
s
P
p
.002 w
.52384 .29787 m .53385 .31918 L .56185 .31838 L p
1 g
F P
s
P
p
.002 w
.53385 .31918 m .52384 .29787 L .49833 .30833 L p
1 g
F P
s
P
p
.002 w
.46394 .57722 m .52097 .5673 L .51165 .54631 L p
1 g
F P
s
P
p
.002 w
.51165 .54631 m .45686 .55562 L .46394 .57722 L p
1 g
F P
s
P
p
.002 w
.39659 .33691 m .39544 .35379 L .4214 .34458 L p
1 g
F P
s
P
p
.002 w
.4214 .34458 m .42207 .33608 L .39659 .33691 L p
1 g
F P
s
P
p
.002 w
.37164 .36512 m .3792 .3877 L .40038 .36918 L p
1 g
F P
s
P
p
.002 w
.40038 .36918 m .39544 .35379 L .37164 .36512 L p
1 g
F P
s
P
p
.002 w
.34543 .42846 m .37027 .45566 L .38107 .43041 L p
1 g
F P
s
P
p
.002 w
.38107 .43041 m .36073 .40759 L .34543 .42846 L p
1 g
F P
s
P
p
.002 w
.49833 .30833 m .4861 .29742 L .46697 .31625 L p
1 g
F P
s
P
p
.002 w
.45879 .31324 m .46697 .31625 L .4861 .29742 L p
1 g
F P
s
P
p
.002 w
.35816 .50512 m .4014 .52555 L .40157 .49965 L p
1 g
F P
s
P
p
.002 w
.40157 .49965 m .36254 .48075 L .35816 .50512 L p
1 g
F P
s
P
p
.002 w
.57473 .54289 m .62062 .50621 L .60721 .48765 L p
1 g
F P
s
P
p
.002 w
.63956 .44335 m .60721 .48765 L .62062 .50621 L p
1 g
F P
s
P
p
.002 w
.60721 .48765 m .63956 .44335 L .6215 .42659 L p
1 g
F P
s
P
p
.002 w
.63736 .38008 m .6215 .42659 L .63956 .44335 L p
1 g
F P
s
P
p
.002 w
.6215 .42659 m .63736 .38008 L .61486 .368 L p
1 g
F P
s
P
p
.002 w
.4861 .29742 m .49833 .30833 L .52384 .29787 L p
1 g
F P
s
P
p
.002 w
.40382 .3204 m .39659 .33691 L .42207 .33608 L p
1 g
F P
s
P
p
.002 w
.42207 .33608 m .42575 .32782 L .40382 .3204 L p
1 g
F P
s
P
p
.002 w
.44956 .31301 m .45879 .31324 L .46988 .2913 L p
1 g
F P
s
P
p
.002 w
.4861 .29742 m .46988 .2913 L .45879 .31324 L p
1 g
F P
s
P
p
.002 w
.4164 .30617 m .40382 .3204 L .42575 .32782 L p
1 g
F P
s
P
p
.002 w
.42575 .32782 m .43206 .32073 L .4164 .30617 L p
1 g
F P
s
P
p
.002 w
.46988 .2913 m .45146 .29074 L .44956 .31301 L p
1 g
F P
s
P
p
.002 w
.44031 .3156 m .44956 .31301 L .45146 .29074 L p
1 g
F P
s
P
p
.002 w
.54921 .29058 m .56185 .31838 L .58874 .32039 L p
1 g
F P
s
P
p
.002 w
.56185 .31838 m .54921 .29058 L .52384 .29787 L p
1 g
F P
s
P
p
.002 w
.35059 .37838 m .36073 .40759 L .3792 .3877 L p
1 g
F P
s
P
p
.002 w
.3792 .3877 m .37164 .36512 L .35059 .37838 L p
1 g
F P
s
P
p
.002 w
.43291 .29589 m .4164 .30617 L .43206 .32073 L p
1 g
F P
s
P
p
.002 w
.43206 .32073 m .44031 .3156 L .43291 .29589 L p
1 g
F P
s
P
p
.002 w
.45146 .29074 m .43291 .29589 L .44031 .3156 L p
1 g
F P
s
P
p
.002 w
.37311 .34014 m .37164 .36512 L .39544 .35379 L p
1 g
F P
s
P
p
.002 w
.39544 .35379 m .39659 .33691 L .37311 .34014 L p
1 g
F P
s
P
p
.002 w
.61393 .32524 m .61486 .368 L .63736 .38008 L p
1 g
F P
s
P
p
.002 w
.61486 .368 m .61393 .32524 L .58874 .32039 L p
1 g
F P
s
P
p
.002 w
.33376 .4499 m .36254 .48075 L .37027 .45566 L p
1 g
F P
s
P
p
.002 w
.37027 .45566 m .34543 .42846 L .33376 .4499 L p
1 g
F P
s
P
p
.002 w
.40861 .57135 m .46394 .57722 L .45686 .55562 L p
1 g
F P
s
P
p
.002 w
.45686 .55562 m .40373 .54965 L .40861 .57135 L p
1 g
F P
s
P
p
.002 w
.52384 .29787 m .50597 .28158 L .4861 .29742 L p
1 g
F P
s
P
p
.002 w
.46988 .2913 m .4861 .29742 L .50597 .28158 L p
1 g
F P
s
P
p
.002 w
.50597 .28158 m .52384 .29787 L .54921 .29058 L p
1 g
F P
s
P
p
.002 w
.53005 .58542 m .58465 .56058 L .57473 .54289 L p
1 g
F P
s
P
p
.002 w
.57473 .54289 m .52097 .5673 L .53005 .58542 L p
1 g
F P
s
P
p
.002 w
.62062 .50621 m .57473 .54289 L .58465 .56058 L p
1 g
F P
s
P
p
.002 w
.35735 .52823 m .40373 .54965 L .4014 .52555 L p
1 g
F P
s
P
p
.002 w
.4014 .52555 m .35816 .50512 L .35735 .52823 L p
1 g
F P
s
P
p
.002 w
.47217 .5957 m .53005 .58542 L .52097 .5673 L p
1 g
F P
s
P
p
.002 w
.52097 .5673 m .46394 .57722 L .47217 .5957 L p
1 g
F P
s
P
p
.002 w
.38371 .31558 m .37311 .34014 L .39659 .33691 L p
1 g
F P
s
P
p
.002 w
.39659 .33691 m .40382 .3204 L .38371 .31558 L p
1 g
F P
s
P
p
.002 w
.62062 .50621 m .65453 .46024 L .63956 .44335 L p
1 g
F P
s
P
p
.002 w
.6569 .39376 m .63956 .44335 L .65453 .46024 L p
1 g
F P
s
P
p
.002 w
.63956 .44335 m .6569 .39376 L .63736 .38008 L p
1 g
F P
s
P
p
.002 w
.33284 .39334 m .34543 .42846 L .36073 .40759 L p
1 g
F P
s
P
p
.002 w
.36073 .40759 m .35059 .37838 L .33284 .39334 L p
1 g
F P
s
P
p
.002 w
.57389 .28671 m .58874 .32039 L .61393 .32524 L p
1 g
F P
s
P
p
.002 w
.58874 .32039 m .57389 .28671 L .54921 .29058 L p
1 g
F P
s
P
p
.002 w
.58465 .56058 m .63135 .52339 L .62062 .50621 L p
1 g
F P
s
P
p
.002 w
.65453 .46024 m .62062 .50621 L .63135 .52339 L p
1 g
F P
s
P
p
.002 w
.45146 .29074 m .46988 .2913 L .48204 .27232 L p
1 g
F P
s
P
p
.002 w
.50597 .28158 m .48204 .27232 L .46988 .2913 L p
1 g
F P
s
P
p
.002 w
.35224 .34582 m .35059 .37838 L .37164 .36512 L p
1 g
F P
s
P
p
.002 w
.37164 .36512 m .37311 .34014 L .35224 .34582 L p
1 g
F P
s
P
p
.002 w
.40238 .29434 m .38371 .31558 L .40382 .3204 L p
1 g
F P
s
P
p
.002 w
.40382 .3204 m .4164 .30617 L .40238 .29434 L p
1 g
F P
s
P
p
.002 w
.63681 .33294 m .63736 .38008 L .6569 .39376 L p
1 g
F P
s
P
p
.002 w
.63736 .38008 m .63681 .33294 L .61393 .32524 L p
1 g
F P
s
P
p
.002 w
.32611 .47143 m .35816 .50512 L .36254 .48075 L p
1 g
F P
s
P
p
.002 w
.36254 .48075 m .33376 .4499 L .32611 .47143 L p
1 g
F P
s
P
p
.002 w
.48204 .27232 m .45466 .27137 L .45146 .29074 L p
1 g
F P
s
P
p
.002 w
.43291 .29589 m .45146 .29074 L .45466 .27137 L p
1 g
F P
s
P
p
.002 w
.5262 .26916 m .54921 .29058 L .57389 .28671 L p
1 g
F P
s
P
p
.002 w
.54921 .29058 m .5262 .26916 L .50597 .28158 L p
1 g
F P
s
P
p
.002 w
.48204 .27232 m .50597 .28158 L .5262 .26916 L p
1 g
F P
s
P
p
.002 w
.427 .27898 m .40238 .29434 L .4164 .30617 L p
1 g
F P
s
P
p
.002 w
.4164 .30617 m .43291 .29589 L .427 .27898 L p
1 g
F P
s
P
p
.002 w
.45466 .27137 m .427 .27898 L .43291 .29589 L p
1 g
F P
s
P
p
.002 w
.41605 .59005 m .47217 .5957 L .46394 .57722 L p
1 g
F P
s
P
p
.002 w
.46394 .57722 m .40861 .57135 L .41605 .59005 L p
1 g
F P
s
P
p
.002 w
.36028 .54946 m .40861 .57135 L .40373 .54965 L p
1 g
F P
s
P
p
.002 w
.40373 .54965 m .35735 .52823 L .36028 .54946 L p
1 g
F P
s
P
p
.002 w
.31896 .40974 m .33376 .4499 L .34543 .42846 L p
1 g
F P
s
P
p
.002 w
.34543 .42846 m .33284 .39334 L .31896 .40974 L p
1 g
F P
s
P
p
.002 w
.59732 .28648 m .61393 .32524 L .63681 .33294 L p
1 g
F P
s
P
p
.002 w
.61393 .32524 m .59732 .28648 L .57389 .28671 L p
1 g
F P
s
P
p
.002 w
.53866 .60015 m .59273 .57551 L .58465 .56058 L p
1 g
F P
s
P
p
.002 w
.58465 .56058 m .53005 .58542 L .53866 .60015 L p
1 g
F P
s
P
p
.002 w
.63135 .52339 m .58465 .56058 L .59273 .57551 L p
1 g
F P
s
P
p
.002 w
.36594 .31361 m .35224 .34582 L .37311 .34014 L p
1 g
F P
s
P
p
.002 w
.37311 .34014 m .38371 .31558 L .36594 .31361 L p
1 g
F P
s
P
p
.002 w
.63135 .52339 m .66597 .47688 L .65453 .46024 L p
1 g
F P
s
P
p
.002 w
.67293 .4088 m .65453 .46024 L .66597 .47688 L p
1 g
F P
s
P
p
.002 w
.65453 .46024 m .67293 .4088 L .6569 .39376 L p
1 g
F P
s
P
p
.002 w
.48141 .61048 m .53866 .60015 L .53005 .58542 L p
1 g
F P
s
P
p
.002 w
.53005 .58542 m .47217 .5957 L .48141 .61048 L p
1 g
F P
s
P
p
.002 w
.33457 .35391 m .33284 .39334 L .35059 .37838 L p
1 g
F P
s
P
p
.002 w
.35059 .37838 m .35224 .34582 L .33457 .35391 L p
1 g
F P
s
P
p
.002 w
.5262 .26916 m .49505 .25687 L .48204 .27232 L p
1 g
F P
s
P
p
.002 w
.45466 .27137 m .48204 .27232 L .49505 .25687 L p
1 g
F P
s
P
p
.002 w
.32285 .49254 m .35735 .52823 L .35816 .50512 L p
1 g
F P
s
P
p
.002 w
.35816 .50512 m .32611 .47143 L .32285 .49254 L p
1 g
F P
s
P
p
.002 w
.59273 .57551 m .63903 .53875 L .63135 .52339 L p
1 g
F P
s
P
p
.002 w
.66597 .47688 m .63135 .52339 L .63903 .53875 L p
1 g
F P
s
P
p
.002 w
.65675 .34342 m .6569 .39376 L .67293 .4088 L p
1 g
F P
s
P
p
.002 w
.6569 .39376 m .65675 .34342 L .63681 .33294 L p
1 g
F P
s
P
p
.002 w
.54634 .26059 m .57389 .28671 L .59732 .28648 L p
1 g
F P
s
P
p
.002 w
.57389 .28671 m .54634 .26059 L .5262 .26916 L p
1 g
F P
s
P
p
.002 w
.49505 .25687 m .5262 .26916 L .54634 .26059 L p
1 g
F P
s
P
p
.002 w
.3904 .28565 m .36594 .31361 L .38371 .31558 L p
1 g
F P
s
P
p
.002 w
.38371 .31558 m .40238 .29434 L .3904 .28565 L p
1 g
F P
s
P
p
.002 w
.49505 .25687 m .45916 .25548 L .45466 .27137 L p
1 g
F P
s
P
p
.002 w
.427 .27898 m .45466 .27137 L .45916 .25548 L p
1 g
F P
s
P
p
.002 w
.30947 .42725 m .32611 .47143 L .33376 .4499 L p
1 g
F P
s
P
p
.002 w
.33376 .4499 m .31896 .40974 L .30947 .42725 L p
1 g
F P
s
P
p
.002 w
.426 .60513 m .48141 .61048 L .47217 .5957 L p
1 g
F P
s
P
p
.002 w
.47217 .5957 m .41605 .59005 L .426 .60513 L p
1 g
F P
s
P
p
.002 w
.42279 .26544 m .3904 .28565 L .40238 .29434 L p
1 g
F P
s
P
p
.002 w
.40238 .29434 m .427 .27898 L .42279 .26544 L p
1 g
F P
s
P
p
.002 w
.36706 .5682 m .41605 .59005 L .40861 .57135 L p
1 g
F P
s
P
p
.002 w
.40861 .57135 m .36028 .54946 L .36706 .5682 L p
1 g
F P
s
P
p
.002 w
.61888 .29005 m .63681 .33294 L .65675 .34342 L p
1 g
F P
s
P
p
.002 w
.63681 .33294 m .61888 .29005 L .59732 .28648 L p
1 g
F P
s
P
p
.002 w
.45916 .25548 m .42279 .26544 L .427 .27898 L p
1 g
F P
s
P
p
.002 w
.35108 .31468 m .33457 .35391 L .35224 .34582 L p
1 g
F P
s
P
p
.002 w
.35224 .34582 m .36594 .31361 L .35108 .31468 L p
1 g
F P
s
P
p
.002 w
.3207 .36435 m .31896 .40974 L .33284 .39334 L p
1 g
F P
s
P
p
.002 w
.33284 .39334 m .33457 .35391 L .3207 .36435 L p
1 g
F P
s
P
p
.002 w
.54657 .61094 m .59866 .58717 L .59273 .57551 L p
1 g
F P
s
P
p
.002 w
.59273 .57551 m .53866 .60015 L .54657 .61094 L p
1 g
F P
s
P
p
.002 w
.63903 .53875 m .59273 .57551 L .59866 .58717 L p
1 g
F P
s
P
p
.002 w
.63903 .53875 m .67341 .49289 L .66597 .47688 L p
1 g
F P
s
P
p
.002 w
.6849 .4249 m .66597 .47688 L .67341 .49289 L p
1 g
F P
s
P
p
.002 w
.66597 .47688 m .6849 .4249 L .67293 .4088 L p
1 g
F P
s
P
p
.002 w
.32428 .51268 m .36028 .54946 L .35735 .52823 L p
1 g
F P
s
P
p
.002 w
.35735 .52823 m .32285 .49254 L .32428 .51268 L p
1 g
F P
s
P
p
.002 w
.45916 .25548 m .49505 .25687 L .50865 .24547 L p
1 g
F P
s
P
p
.002 w
.54634 .26059 m .50865 .24547 L .49505 .25687 L p
1 g
F P
s
P
p
.002 w
.56591 .25626 m .59732 .28648 L .61888 .29005 L p
1 g
F P
s
P
p
.002 w
.59732 .28648 m .56591 .25626 L .54634 .26059 L p
1 g
F P
s
P
p
.002 w
.49151 .62099 m .54657 .61094 L .53866 .60015 L p
1 g
F P
s
P
p
.002 w
.53866 .60015 m .48141 .61048 L .49151 .62099 L p
1 g
F P
s
P
p
.002 w
.67315 .35656 m .67293 .4088 L .6849 .4249 L p
1 g
F P
s
P
p
.002 w
.67293 .4088 m .67315 .35656 L .65675 .34342 L p
1 g
F P
s
P
p
.002 w
.50865 .24547 m .54634 .26059 L .56591 .25626 L p
1 g
F P
s
P
p
.002 w
.59866 .58717 m .6433 .55182 L .63903 .53875 L p
1 g
F P
s
P
p
.002 w
.67341 .49289 m .63903 .53875 L .6433 .55182 L p
1 g
F P
s
P
p
.002 w
.38088 .2805 m .35108 .31468 L .36594 .31361 L p
1 g
F P
s
P
p
.002 w
.36594 .31361 m .3904 .28565 L .38088 .2805 L p
1 g
F P
s
P
p
.002 w
.30484 .44546 m .32285 .49254 L .32611 .47143 L p
1 g
F P
s
P
p
.002 w
.32611 .47143 m .30947 .42725 L .30484 .44546 L p
1 g
F P
s
P
p
.002 w
.63795 .29751 m .65675 .34342 L .67315 .35656 L p
1 g
F P
s
P
p
.002 w
.65675 .34342 m .63795 .29751 L .61888 .29005 L p
1 g
F P
s
P
p
.002 w
.50865 .24547 m .46494 .24365 L .45916 .25548 L p
1 g
F P
s
P
p
.002 w
.42279 .26544 m .45916 .25548 L .46494 .24365 L p
1 g
F P
s
P
p
.002 w
.37772 .58384 m .426 .60513 L .41605 .59005 L p
1 g
F P
s
P
p
.002 w
.41605 .59005 m .36706 .5682 L .37772 .58384 L p
1 g
F P
s
P
p
.002 w
.43834 .61603 m .49151 .62099 L .48141 .61048 L p
1 g
F P
s
P
p
.002 w
.48141 .61048 m .426 .60513 L .43834 .61603 L p
1 g
F P
s
P
p
.002 w
.42049 .25577 m .38088 .2805 L .3904 .28565 L p
1 g
F P
s
P
p
.002 w
.3904 .28565 m .42279 .26544 L .42049 .25577 L p
1 g
F P
s
P
p
.002 w
.31122 .377 m .30947 .42725 L .31896 .40974 L p
1 g
F P
s
P
p
.002 w
.31896 .40974 m .3207 .36435 L .31122 .377 L p
1 g
F P
s
P
p
.002 w
.46494 .24365 m .42049 .25577 L .42279 .26544 L p
1 g
F P
s
P
p
.002 w
.33968 .31895 m .3207 .36435 L .33457 .35391 L p
1 g
F P
s
P
p
.002 w
.33457 .35391 m .35108 .31468 L .33968 .31895 L p
1 g
F P
s
P
p
.002 w
.33061 .53127 m .36706 .5682 L .36028 .54946 L p
1 g
F P
s
P
p
.002 w
.36028 .54946 m .32428 .51268 L .33061 .53127 L p
1 g
F P
s
P
p
.002 w
.58438 .25648 m .61888 .29005 L .63795 .29751 L p
1 g
F P
s
P
p
.002 w
.61888 .29005 m .58438 .25648 L .56591 .25626 L p
1 g
F P
s
P
p
.002 w
.6433 .55182 m .67646 .50782 L .67341 .49289 L p
1 g
F P
s
P
p
.002 w
.6923 .44172 m .67341 .49289 L .67646 .50782 L p
1 g
F P
s
P
p
.002 w
.67341 .49289 m .6923 .44172 L .6849 .4249 L p
1 g
F P
s
P
p
.002 w
.68541 .37214 m .6849 .4249 L .6923 .44172 L p
1 g
F P
s
P
p
.002 w
.6849 .4249 m .68541 .37214 L .67315 .35656 L p
1 g
F P
s
P
p
.002 w
.55355 .61729 m .60217 .59508 L .59866 .58717 L p
1 g
F P
s
P
p
.002 w
.59866 .58717 m .54657 .61094 L .55355 .61729 L p
1 g
F P
s
P
p
.002 w
.6433 .55182 m .59866 .58717 L .60217 .59508 L p
1 g
F P
s
P
p
.002 w
.46494 .24365 m .50865 .24547 L .52252 .23864 L p
1 g
F P
s
P
p
.002 w
.56591 .25626 m .52252 .23864 L .50865 .24547 L p
1 g
F P
s
P
p
.002 w
.52252 .23864 m .56591 .25626 L .58438 .25648 L p
1 g
F P
s
P
p
.002 w
.50225 .62673 m .55355 .61729 L .54657 .61094 L p
1 g
F P
s
P
p
.002 w
.54657 .61094 m .49151 .62099 L .50225 .62673 L p
1 g
F P
s
P
p
.002 w
.30546 .46392 m .32428 .51268 L .32285 .49254 L p
1 g
F P
s
P
p
.002 w
.32285 .49254 m .30484 .44546 L .30546 .46392 L p
1 g
F P
s
P
p
.002 w
.60217 .59508 m .64385 .56213 L .6433 .55182 L p
1 g
F P
s
P
p
.002 w
.67646 .50782 m .6433 .55182 L .64385 .56213 L p
1 g
F P
s
P
p
.002 w
.6539 .30887 m .67315 .35656 L .68541 .37214 L p
1 g
F P
s
P
p
.002 w
.67315 .35656 m .6539 .30887 L .63795 .29751 L p
1 g
F P
s
P
p
.002 w
.37422 .27925 m .33968 .31895 L .35108 .31468 L p
1 g
F P
s
P
p
.002 w
.35108 .31468 m .38088 .2805 L .37422 .27925 L p
1 g
F P
s
P
p
.002 w
.39216 .59578 m .43834 .61603 L .426 .60513 L p
1 g
F P
s
P
p
.002 w
.426 .60513 m .37772 .58384 L .39216 .59578 L p
1 g
F P
s
P
p
.002 w
.52252 .23864 m .47192 .23645 L .46494 .24365 L p
1 g
F P
s
P
p
.002 w
.42049 .25577 m .46494 .24365 L .47192 .23645 L p
1 g
F P
s
P
p
.002 w
.30662 .39164 m .30484 .44546 L .30947 .42725 L p
1 g
F P
s
P
p
.002 w
.30947 .42725 m .31122 .377 L .30662 .39164 L p
1 g
F P
s
P
p
.002 w
.45286 .62218 m .50225 .62673 L .49151 .62099 L p
1 g
F P
s
P
p
.002 w
.49151 .62099 m .43834 .61603 L .45286 .62218 L p
1 g
F P
s
P
p
.002 w
.33226 .32649 m .31122 .377 L .3207 .36435 L p
1 g
F P
s
P
p
.002 w
.3207 .36435 m .33968 .31895 L .33226 .32649 L p
1 g
F P
s
P
p
.002 w
.3419 .54768 m .37772 .58384 L .36706 .5682 L p
1 g
F P
s
P
p
.002 w
.36706 .5682 m .33061 .53127 L .3419 .54768 L p
1 g
F P
s
P
p
.002 w
.42027 .25049 m .37422 .27925 L .38088 .2805 L p
1 g
F P
s
P
p
.002 w
.38088 .2805 m .42049 .25577 L .42027 .25049 L p
1 g
F P
s
P
p
.002 w
.60121 .26149 m .63795 .29751 L .6539 .30887 L p
1 g
F P
s
P
p
.002 w
.63795 .29751 m .60121 .26149 L .58438 .25648 L p
1 g
F P
s
P
p
.002 w
.47192 .23645 m .42027 .25049 L .42049 .25577 L p
1 g
F P
s
P
p
.002 w
.67646 .50782 m .69469 .45886 L .6923 .44172 L p
1 g
F P
s
P
p
.002 w
.69299 .38989 m .6923 .44172 L .69469 .45886 L p
1 g
F P
s
P
p
.002 w
.6923 .44172 m .69299 .38989 L .68541 .37214 L p
1 g
F P
s
P
p
.002 w
.64385 .56213 m .67478 .52121 L .67646 .50782 L p
1 g
F P
s
P
p
.002 w
.69469 .45886 m .67646 .50782 L .67478 .52121 L p
1 g
F P
s
P
p
.002 w
.58438 .25648 m .53633 .23683 L .52252 .23864 L p
1 g
F P
s
P
p
.002 w
.47192 .23645 m .52252 .23864 L .53633 .23683 L p
1 g
F P
s
P
p
.002 w
.53633 .23683 m .58438 .25648 L .60121 .26149 L p
1 g
F P
s
P
p
.002 w
.55935 .61874 m .60301 .59879 L .60217 .59508 L p
1 g
F P
s
P
p
.002 w
.60217 .59508 m .55355 .61729 L .55935 .61874 L p
1 g
F P
s
P
p
.002 w
.64385 .56213 m .60217 .59508 L .60301 .59879 L p
1 g
F P
s
P
p
.002 w
.31162 .48211 m .33061 .53127 L .32428 .51268 L p
1 g
F P
s
P
p
.002 w
.32428 .51268 m .30546 .46392 L .31162 .48211 L p
1 g
F P
s
P
p
.002 w
.51338 .62722 m .55935 .61874 L .55355 .61729 L p
1 g
F P
s
P
p
.002 w
.55355 .61729 m .50225 .62673 L .51338 .62722 L p
1 g
F P
s
P
p
.002 w
.66614 .32402 m .68541 .37214 L .69299 .38989 L p
1 g
F P
s
P
p
.002 w
.68541 .37214 m .66614 .32402 L .6539 .30887 L p
1 g
F P
s
P
p
.002 w
.60301 .59879 m .64043 .56923 L .64385 .56213 L p
1 g
F P
s
P
p
.002 w
.67478 .52121 m .64385 .56213 L .64043 .56923 L p
1 g
F P
s
P
p
.002 w
.3708 .28218 m .33226 .32649 L .33968 .31895 L p
1 g
F P
s
P
p
.002 w
.33968 .31895 m .37422 .27925 L .3708 .28218 L p
1 g
F P
s
P
p
.002 w
.41019 .60347 m .45286 .62218 L .43834 .61603 L p
1 g
F P
s
P
p
.002 w
.43834 .61603 m .39216 .59578 L .41019 .60347 L p
1 g
F P
s
P
p
.004 w
.70285 .35888 m
.70809 .35703 L
s
P
p
.004 w
.70809 .35703 m
.74321 .34463 L
s
P
p
.002 w
.30735 .40796 m .30546 .46392 L .30484 .44546 L p
1 g
F P
s
P
p
.002 w
.30484 .44546 m .30662 .39164 L .30735 .40796 L p
1 g
F P
s
P
p
.002 w
.53633 .23683 m .47998 .23435 L .47192 .23645 L p
1 g
F P
s
P
p
.002 w
.42027 .25049 m .47192 .23645 L .47998 .23435 L p
1 g
F P
s
P
p
.002 w
.35811 .56133 m .39216 .59578 L .37772 .58384 L p
1 g
F P
s
P
p
.002 w
.37772 .58384 m .3419 .54768 L .35811 .56133 L p
1 g
F P
s
P
p
.002 w
.6539 .30887 m .61584 .27144 L .60121 .26149 L p
1 g
F P
s
P
p
.002 w
.61584 .27144 m .6539 .30887 L .66614 .32402 L p
1 g
F P
s
P
p
.002 w
.32928 .33731 m .30662 .39164 L .31122 .377 L p
1 g
F P
s
P
p
.002 w
.31122 .377 m .33226 .32649 L .32928 .33731 L p
1 g
F P
s
P
p
.002 w
.46929 .62316 m .51338 .62722 L .50225 .62673 L p
1 g
F P
s
P
p
.002 w
.50225 .62673 m .45286 .62218 L .46929 .62316 L p
1 g
F P
s
P
p
.002 w
.42228 .25004 m .3708 .28218 L .37422 .27925 L p
1 g
F P
s
P
p
.002 w
.37422 .27925 m .42027 .25049 L .42228 .25004 L p
1 g
F P
s
P
p
.002 w
.67478 .52121 m .69173 .47585 L .69469 .45886 L p
1 g
F P
s
P
p
.002 w
.69469 .45886 m .69541 .40942 L .69299 .38989 L p
1 g
F P
s
P
p
.002 w
.69541 .40942 m .69469 .45886 L .69173 .47585 L p
1 g
F P
s
P
p
.002 w
.47998 .23435 m .42228 .25004 L .42027 .25049 L p
1 g
F P
s
P
p
.002 w
.64043 .56923 m .66813 .53261 L .67478 .52121 L p
1 g
F P
s
P
p
.002 w
.69173 .47585 m .67478 .52121 L .66813 .53261 L p
1 g
F P
s
P
p
.002 w
.60121 .26149 m .54968 .24038 L .53633 .23683 L p
1 g
F P
s
P
p
.002 w
.54968 .24038 m .60121 .26149 L .61584 .27144 L p
1 g
F P
s
P
p
.002 w
.47998 .23435 m .53633 .23683 L .54968 .24038 L p
1 g
F P
s
P
p
.002 w
.32341 .49947 m .3419 .54768 L .33061 .53127 L p
1 g
F P
s
P
p
.002 w
.33061 .53127 m .31162 .48211 L .32341 .49947 L p
1 g
F P
s
P
p
.002 w
.69299 .38989 m .67411 .34273 L .66614 .32402 L p
1 g
F P
s
P
p
.002 w
.67411 .34273 m .69299 .38989 L .69541 .40942 L p
1 g
F P
s
P
p
.002 w
.56373 .61493 m .60097 .59791 L .60301 .59879 L p
1 g
F P
s
P
p
.002 w
.60301 .59879 m .55935 .61874 L .56373 .61493 L p
1 g
F P
s
P
p
.002 w
.64043 .56923 m .60301 .59879 L .60097 .59791 L p
1 g
F P
s
P
p
.002 w
.52459 .62212 m .56373 .61493 L .55935 .61874 L p
1 g
F P
s
P
p
.002 w
.55935 .61874 m .51338 .62722 L .52459 .62212 L p
1 g
F P
s
P
p
.002 w
.60097 .59791 m .63287 .57269 L .64043 .56923 L p
1 g
F P
s
P
p
.002 w
.66813 .53261 m .64043 .56923 L .63287 .57269 L p
1 g
F P
s
P
p
.002 w
.43144 .60645 m .46929 .62316 L .45286 .62218 L p
1 g
F P
s
P
p
.002 w
.45286 .62218 m .41019 .60347 L .43144 .60645 L p
1 g
F P
s
P
p
.002 w
.31368 .42555 m .31162 .48211 L .30546 .46392 L p
1 g
F P
s
P
p
.002 w
.30546 .46392 m .30735 .40796 L .31368 .42555 L p
1 g
F P
s
P
p
.002 w
.37094 .2895 m .32928 .33731 L .33226 .32649 L p
1 g
F P
s
P
p
.002 w
.33226 .32649 m .3708 .28218 L .37094 .2895 L p
1 g
F P
s
P
p
.002 w
.6277 .2863 m .66614 .32402 L .67411 .34273 L p
1 g
F P
s
P
p
.002 w
.66614 .32402 m .6277 .2863 L .61584 .27144 L p
1 g
F P
s
P
p
.002 w
.37897 .57164 m .41019 .60347 L .39216 .59578 L p
1 g
F P
s
P
p
.002 w
.39216 .59578 m .35811 .56133 L .37897 .57164 L p
1 g
F P
s
P
p
.002 w
.33113 .35128 m .30735 .40796 L .30662 .39164 L p
1 g
F P
s
P
p
.002 w
.30662 .39164 m .32928 .33731 L .33113 .35128 L p
1 g
F P
s
P
p
.002 w
.54968 .24038 m .48895 .23775 L .47998 .23435 L p
1 g
F P
s
P
p
.002 w
.42228 .25004 m .47998 .23435 L .48895 .23775 L p
1 g
F P
s
P
p
.002 w
.48723 .61861 m .52459 .62212 L .51338 .62722 L p
1 g
F P
s
P
p
.002 w
.51338 .62722 m .46929 .62316 L .48723 .61861 L p
1 g
F P
s
P
p
.002 w
.66813 .53261 m .6832 .49218 L .69173 .47585 L p
1 g
F P
s
P
p
.002 w
.69234 .43024 m .69173 .47585 L .6832 .49218 L p
1 g
F P
s
P
p
.002 w
.69173 .47585 m .69234 .43024 L .69541 .40942 L p
1 g
F P
s
P
p
.002 w
.34076 .51539 m .35811 .56133 L .3419 .54768 L p
1 g
F P
s
P
p
.002 w
.3419 .54768 m .32341 .49947 L .34076 .51539 L p
1 g
F P
s
P
p
.002 w
.56214 .24953 m .61584 .27144 L .6277 .2863 L p
1 g
F P
s
P
p
.002 w
.61584 .27144 m .56214 .24953 L .54968 .24038 L p
1 g
F P
s
P
p
.002 w
.42661 .25475 m .37094 .2895 L .3708 .28218 L p
1 g
F P
s
P
p
.002 w
.3708 .28218 m .42228 .25004 L .42661 .25475 L p
1 g
F P
s
P
p
.002 w
.63287 .57269 m .65639 .54155 L .66813 .53261 L p
1 g
F P
s
P
p
.002 w
.6832 .49218 m .66813 .53261 L .65639 .54155 L p
1 g
F P
s
P
p
.002 w
.67734 .36461 m .69541 .40942 L .69234 .43024 L p
1 g
F P
s
P
p
.002 w
.69541 .40942 m .67734 .36461 L .67411 .34273 L p
1 g
F P
s
P
p
.002 w
.48895 .23775 m .54968 .24038 L .56214 .24953 L p
1 g
F P
s
P
p
.002 w
.48895 .23775 m .42661 .25475 L .42228 .25004 L p
1 g
F P
s
P
p
.002 w
.56645 .60562 m .59593 .59216 L .60097 .59791 L p
1 g
F P
s
P
p
.002 w
.60097 .59791 m .56373 .61493 L .56645 .60562 L p
1 g
F P
s
P
p
.002 w
.63287 .57269 m .60097 .59791 L .59593 .59216 L p
1 g
F P
s
P
p
.002 w
.32573 .44392 m .32341 .49947 L .31162 .48211 L p
1 g
F P
s
P
p
.002 w
.31162 .48211 m .31368 .42555 L .32573 .44392 L p
1 g
F P
s
P
p
.002 w
.53554 .61125 m .56645 .60562 L .56373 .61493 L p
1 g
F P
s
P
p
.002 w
.56373 .61493 m .52459 .62212 L .53554 .61125 L p
1 g
F P
s
P
p
.002 w
.45541 .60437 m .48723 .61861 L .46929 .62316 L p
1 g
F P
s
P
p
.002 w
.46929 .62316 m .43144 .60645 L .45541 .60437 L p
1 g
F P
s
P
p
.002 w
.63628 .30588 m .67411 .34273 L .67734 .36461 L p
1 g
F P
s
P
p
.002 w
.67411 .34273 m .63628 .30588 L .6277 .2863 L p
1 g
F P
s
P
p
.002 w
.40403 .57813 m .43144 .60645 L .41019 .60347 L p
1 g
F P
s
P
p
.002 w
.41019 .60347 m .37897 .57164 L .40403 .57813 L p
1 g
F P
s
P
p
.002 w
.59593 .59216 m .62115 .57219 L .63287 .57269 L p
1 g
F P
s
P
p
.002 w
.65639 .54155 m .63287 .57269 L .62115 .57219 L p
1 g
F P
s
P
p
.002 w
.37485 .30126 m .33113 .35128 L .32928 .33731 L p
1 g
F P
s
P
p
.002 w
.32928 .33731 m .37094 .2895 L .37485 .30126 L p
1 g
F P
s
P
p
.002 w
.33802 .36813 m .31368 .42555 L .30735 .40796 L p
1 g
F P
s
P
p
.002 w
.30735 .40796 m .33113 .35128 L .33802 .36813 L p
1 g
F P
s
P
p
.002 w
.65639 .54155 m .66904 .50733 L .6832 .49218 L p
1 g
F P
s
P
p
.002 w
.68357 .45176 m .6832 .49218 L .66904 .50733 L p
1 g
F P
s
P
p
.002 w
.6832 .49218 m .68357 .45176 L .69234 .43024 L p
1 g
F P
s
P
p
.002 w
.50619 .60838 m .53554 .61125 L .52459 .62212 L p
1 g
F P
s
P
p
.002 w
.52459 .62212 m .48723 .61861 L .50619 .60838 L p
1 g
F P
s
P
p
.002 w
.56214 .24953 m .49863 .24691 L .48895 .23775 L p
1 g
F P
s
P
p
.002 w
.42661 .25475 m .48895 .23775 L .49863 .24691 L p
1 g
F P
s
P
p
.002 w
.36336 .52928 m .37897 .57164 L .35811 .56133 L p
1 g
F P
s
P
p
.002 w
.35811 .56133 m .34076 .51539 L .36336 .52928 L p
1 g
F P
s
P
p
.002 w
.57326 .26431 m .6277 .2863 L .63628 .30588 L p
1 g
F P
s
P
p
.002 w
.6277 .2863 m .57326 .26431 L .56214 .24953 L p
1 g
F P
s
P
p
.002 w
.67549 .38913 m .69234 .43024 L .68357 .45176 L p
1 g
F P
s
P
p
.002 w
.69234 .43024 m .67549 .38913 L .67734 .36461 L p
1 g
F P
s
P
p
.004 w
.68459 .36533 m
.70285 .35888 L
s
P
p
.002 w
.62115 .57219 m .63963 .5476 L .65639 .54155 L p
1 g
F P
s
P
p
.002 w
.66904 .50733 m .65639 .54155 L .63963 .5476 L p
1 g
F P
s
P
p
.002 w
.49863 .24691 m .56214 .24953 L .57326 .26431 L p
1 g
F P
s
P
p
.002 w
.43328 .26482 m .37485 .30126 L .37094 .2895 L p
1 g
F P
s
P
p
.002 w
.37094 .2895 m .42661 .25475 L .43328 .26482 L p
1 g
F P
s
P
p
.002 w
.49863 .24691 m .43328 .26482 L .42661 .25475 L p
1 g
F P
s
P
p
.002 w
.34338 .46248 m .34076 .51539 L .32341 .49947 L p
1 g
F P
s
P
p
.002 w
.32341 .49947 m .32573 .44392 L .34338 .46248 L p
1 g
F P
s
P
p
.002 w
.64112 .32979 m .67734 .36461 L .67549 .38913 L p
1 g
F P
s
P
p
.002 w
.67734 .36461 m .64112 .32979 L .63628 .30588 L p
1 g
F P
s
P
p
.002 w
.43265 .58039 m .45541 .60437 L .43144 .60645 L p
1 g
F P
s
P
p
.002 w
.43144 .60645 m .40403 .57813 L .43265 .58039 L p
1 g
F P
s
P
p
.002 w
.48141 .59707 m .50619 .60838 L .48723 .61861 L p
1 g
F P
s
P
p
.002 w
.48723 .61861 m .45541 .60437 L .48141 .59707 L p
1 g
F P
s
P
p
.002 w
.56733 .59075 m .58785 .5814 L .59593 .59216 L p
1 g
F P
s
P
p
.002 w
.59593 .59216 m .56645 .60562 L .56733 .59075 L p
1 g
F P
s
P
p
.004 w
.58913 .59278 m
.60049 .61348 L
s
P
p
.002 w
.62115 .57219 m .59593 .59216 L .58785 .5814 L p
1 g
F P
s
P
p
.002 w
.54586 .59461 m .56733 .59075 L .56645 .60562 L p
1 g
F P
s
P
p
.002 w
.56645 .60562 m .53554 .61125 L .54586 .59461 L p
1 g
F P
s
P
p
.002 w
.38266 .31734 m .33802 .36813 L .33113 .35128 L p
1 g
F P
s
P
p
.002 w
.33113 .35128 m .37485 .30126 L .38266 .31734 L p
1 g
F P
s
P
p
.002 w
.58785 .5814 m .60537 .56749 L .62115 .57219 L p
1 g
F P
s
P
p
.002 w
.63963 .5476 m .62115 .57219 L .60537 .56749 L p
1 g
F P
s
P
p
.002 w
.35003 .38746 m .32573 .44392 L .31368 .42555 L p
1 g
F P
s
P
p
.002 w
.31368 .42555 m .33802 .36813 L .35003 .38746 L p
1 g
F P
s
P
p
.002 w
.39067 .54058 m .40403 .57813 L .37897 .57164 L p
1 g
F P
s
P
p
.002 w
.37897 .57164 m .36336 .52928 L .39067 .54058 L p
1 g
F P
s
P
p
.002 w
.63963 .5476 m .64942 .52072 L .66904 .50733 L p
1 g
F P
s
P
p
.002 w
.66913 .47333 m .66904 .50733 L .64942 .52072 L p
1 g
F P
s
P
p
.002 w
.66904 .50733 m .66913 .47333 L .68357 .45176 L p
1 g
F P
s
P
p
.002 w
.66839 .41559 m .68357 .45176 L .66913 .47333 L p
1 g
F P
s
P
p
.002 w
.68357 .45176 m .66839 .41559 L .67549 .38913 L p
1 g
F P
s
P
p
.002 w
.58261 .28455 m .63628 .30588 L .64112 .32979 L p
1 g
F P
s
P
p
.002 w
.63628 .30588 m .58261 .28455 L .57326 .26431 L p
1 g
F P
s
P
p
.002 w
.52559 .59252 m .54586 .59461 L .53554 .61125 L p
1 g
F P
s
P
p
.002 w
.53554 .61125 m .50619 .60838 L .52559 .59252 L p
1 g
F P
s
P
p
.002 w
.57326 .26431 m .50873 .26188 L .49863 .24691 L p
1 g
F P
s
P
p
.002 w
.43328 .26482 m .49863 .24691 L .50873 .26188 L p
1 g
F P
s
P
p
.002 w
.60537 .56749 m .61812 .5504 L .63963 .5476 L p
1 g
F P
s
P
p
.002 w
.64942 .52072 m .63963 .5476 L .61812 .5504 L p
1 g
F P
s
P
p
.002 w
.50873 .26188 m .57326 .26431 L .58261 .28455 L p
1 g
F P
s
P
p
.002 w
.36626 .48059 m .36336 .52928 L .34076 .51539 L p
1 g
F P
s
P
p
.002 w
.34076 .51539 m .34338 .46248 L .36626 .48059 L p
1 g
F P
s
P
p
.002 w
.64189 .35741 m .67549 .38913 L .66839 .41559 L p
1 g
F P
s
P
p
.002 w
.67549 .38913 m .64189 .35741 L .64112 .32979 L p
1 g
F P
s
P
p
.004 w
.6705 .37031 m
.68459 .36533 L
s
P
p
.002 w
.44221 .28023 m .38266 .31734 L .37485 .30126 L p
1 g
F P
s
P
p
.002 w
.37485 .30126 m .43328 .26482 L .44221 .28023 L p
1 g
F P
s
P
p
.002 w
.46395 .5782 m .48141 .59707 L .45541 .60437 L p
1 g
F P
s
P
p
.002 w
.45541 .60437 m .43265 .58039 L .46395 .5782 L p
1 g
F P
s
P
p
.002 w
.50873 .26188 m .44221 .28023 L .43328 .26482 L p
1 g
F P
s
P
p
.002 w
.50865 .58458 m .52559 .59252 L .50619 .60838 L p
1 g
F P
s
P
p
.002 w
.50619 .60838 m .48141 .59707 L .50865 .58458 L p
1 g
F P
s
P
p
.002 w
.42188 .54879 m .43265 .58039 L .40403 .57813 L p
1 g
F P
s
P
p
.002 w
.40403 .57813 m .39067 .54058 L .42188 .54879 L p
1 g
F P
s
P
p
.002 w
.36697 .40871 m .34338 .46248 L .32573 .44392 L p
1 g
F P
s
P
p
.002 w
.32573 .44392 m .35003 .38746 L .36697 .40871 L p
1 g
F P
s
P
p
.002 w
.56622 .57051 m .57681 .56569 L .58785 .5814 L p
1 g
F P
s
P
p
.002 w
.58785 .5814 m .56733 .59075 L .56622 .57051 L p
1 g
F P
s
P
p
.002 w
.60537 .56749 m .58785 .5814 L .57681 .56569 L p
1 g
F P
s
P
p
.002 w
.61812 .5504 m .62474 .53182 L .64942 .52072 L p
1 g
F P
s
P
p
.002 w
.64924 .49422 m .64942 .52072 L .62474 .53182 L p
1 g
F P
s
P
p
.002 w
.64942 .52072 m .64924 .49422 L .66913 .47333 L p
1 g
F P
s
P
p
.002 w
.65605 .44316 m .66913 .47333 L .64924 .49422 L p
1 g
F P
s
P
p
.002 w
.66913 .47333 m .65605 .44316 L .66839 .41559 L p
1 g
F P
s
P
p
.002 w
.55515 .57245 m .56622 .57051 L .56733 .59075 L p
1 g
F P
s
P
p
.002 w
.56733 .59075 m .54586 .59461 L .55515 .57245 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.3943 .33744 m .35003 .38746 L .33802 .36813 L p
1 g
F P
s
P
p
.002 w
.33802 .36813 m .38266 .31734 L .3943 .33744 L p
1 g
F P
s
P
p
.002 w
.58977 .30984 m .64112 .32979 L .64189 .35741 L p
1 g
F P
s
P
p
.002 w
.64112 .32979 m .58977 .30984 L .58261 .28455 L p
1 g
F P
s
P
p
.002 w
.57681 .56569 m .58584 .5585 L .60537 .56749 L p
1 g
F P
s
P
p
.002 w
.61812 .5504 m .60537 .56749 L .58584 .5585 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.54478 .57131 m .55515 .57245 L .54586 .59461 L p
1 g
F P
s
P
p
.002 w
.54586 .59461 m .52559 .59252 L .54478 .57131 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63838 .38794 m .66839 .41559 L .65605 .44316 L p
1 g
F P
s
P
p
.002 w
.66839 .41559 m .63838 .38794 L .64189 .35741 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.63913 .38138 L
s
P
p
.004 w
.65284 .37654 m
.65405 .37612 L
s
P
p
.004 w
.65405 .37612 m
.6705 .37031 L
s
P
p
.002 w
.58261 .28455 m .51893 .28247 L .50873 .26188 L p
1 g
F P
s
P
p
.002 w
.44221 .28023 m .50873 .26188 L .51893 .28247 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.39375 .49759 m .39067 .54058 L .36336 .52928 L p
1 g
F P
s
P
p
.002 w
.36336 .52928 m .36626 .48059 L .39375 .49759 L p
1 g
F P
s
P
p
.002 w
.58584 .5585 m .59235 .54968 L .61812 .5504 L p
1 g
F P
s
P
p
.002 w
.62474 .53182 m .61812 .5504 L .59235 .54968 L p
1 g
F P
s
P
p
.002 w
.51893 .28247 m .58261 .28455 L .58977 .30984 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50865 .58458 m .48141 .59707 L p
.49145 .5805 L 1 g
F P
s
P
p
.002 w
.50563 .58122 m .50865 .58458 L p
.49145 .5805 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48141 .59707 m .46395 .5782 L .47318 .57632 L p
1 g
F P
s
P
p
.002 w
.48908 .58037 m .48921 .57862 L p
.47886 .57777 L 1 g
F P
s
P
p
.48141 .59707 m .47449 .57963 L .49119 .58091 L 1 g
F
P
p
.47449 .57963 m .47318 .57632 L .48908 .58037 L 1 g
F
P
p
.47449 .57963 m .48908 .58037 L .49119 .58091 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58037 L p
1 g
F P
s
P
p
.51079 .57862 m .48908 .58037 L .49938 .5809 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46827 .57472 L p
1 g
F P
s
P
p
.48921 .57862 m .46827 .57472 L .47047 .57544 L 1 g
F
P
p
.46395 .5782 m .4681 .57466 L .46827 .57472 L 1 g
F
P
p
.002 w
.47318 .57632 m .47143 .57668 L p
.46827 .57472 L 1 g
F P
s
P
p
.002 w
.47143 .57668 m .46395 .5782 L p
.46827 .57472 L 1 g
F P
s
P
p
.002 w
.46827 .57472 m .46872 .57265 L p
.45922 .56886 L 1 g
F P
s
P
p
.002 w
.46146 .5705 m .46395 .5782 L p
.46195 .57594 L 1 g
F P
s
P
p
.44912 .56142 m .45092 .56275 L .46195 .57594 L 1 g
F
P
p
.45092 .56275 m .46146 .5705 L .46195 .57594 L 1 g
F
P
p
.002 w
.46395 .5782 m .43265 .58039 L p
.44912 .56142 L 1 g
F P
s
P
p
.002 w
.45092 .56275 m .45146 .56129 L p
.44503 .5557 L 1 g
F P
s
P
p
.45922 .56886 m .46146 .5705 L .46827 .57472 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45055 .56374 L p
1 g
F P
s
P
p
.002 w
.45055 .56374 m .45002 .56518 L p
.45804 .56838 L 1 g
F P
s
P
p
.46872 .57265 m .45055 .56374 L .45804 .56838 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45598 .55353 m .49175 .55454 L p
.46813 .57464 L 1 g
F P
s
P
p
.002 w
.46395 .5782 m .46146 .5705 L p
.46813 .57464 L 1 g
F P
s
P
p
.002 w
.46146 .5705 m .45598 .55353 L p
.46813 .57464 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45598 .55353 m .46146 .5705 L p
.45092 .56275 L 1 g
F P
s
P
p
.44912 .56142 m .44947 .56102 L .45092 .56275 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43852 .54704 L p
1 g
F P
s
P
p
.42188 .54879 m .43441 .54092 L .43852 .54704 L 1 g
F
P
p
.002 w
.44153 .55152 m .43982 .55128 L p
.43852 .54704 L 1 g
F P
s
P
p
.002 w
.43982 .55128 m .42188 .54879 L p
.43852 .54704 L 1 g
F P
s
P
p
.002 w
.43852 .54704 m .43925 .54566 L p
.43632 .53986 L 1 g
F P
s
P
p
.45146 .56129 m .43852 .54704 L .44037 .54979 L 1 g
F
P
p
.45146 .56129 m .43823 .54758 L .44503 .5557 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43852 .54704 m .45878 .5256 L .44153 .55152 L 1 g
F
P
p
.43441 .54092 m .43628 .53974 L .43852 .54704 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43278 .52833 L p
1 g
F P
s
P
p
.43925 .54566 m .43278 .52833 L .43632 .53986 L 1 g
F
P
p
.43628 .53974 m .45878 .5256 L .43852 .54704 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42188 .54879 m .42496 .51279 L .43331 .51596 L p
1 g
F P
s
P
p
.002 w
.43278 .52833 m .43346 .52734 L p
.43317 .51911 L 1 g
F P
s
P
p
.42188 .54879 m .43331 .51596 L .43219 .54232 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43402 .50925 L p
1 g
F P
s
P
p
.002 w
.43331 .51596 m .43117 .51515 L p
.43395 .50991 L 1 g
F P
s
P
p
.002 w
.43117 .51515 m .42496 .51279 L p
.43365 .51001 L 1 g
F P
s
P
p
.43365 .51001 m .43395 .50991 L .43117 .51515 L 1 g
F
P
p
.002 w
.43402 .50925 m .43485 .50826 L p
.43755 .50194 L 1 g
F P
s
P
p
.43346 .52734 m .43402 .50925 L .43312 .51769 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.42496 .51279 m .44214 .47648 L .44791 .4805 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44276 .49117 L p
1 g
F P
s
P
p
.43485 .50826 m .44276 .49117 L .43755 .50194 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43365 .51001 m .44276 .49117 L .47242 .49758 L 1 g
F
P
p
.002 w
.45133 .48288 m .47242 .49758 L p
.44276 .49117 L 1 g
F P
s
P
p
.42496 .51279 m .44791 .4805 L .43365 .51001 L 1 g
F
P
p
.002 w
.44276 .49117 m .44166 .49233 L p
.43755 .50194 L 1 g
F P
s
P
p
.002 w
.49554 .4728 m .47242 .49758 L .45133 .48288 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.45779 .4766 m .49554 .4728 L .45133 .48288 L 1 g
F
P
p
.002 w
.45779 .4766 m .45826 .47608 L p
.46514 .47306 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47762 .46706 L p
1 g
F P
s
P
p
.45826 .47608 m .47762 .46706 L .46514 .47306 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.44214 .47648 m .44715 .47105 L p
.49554 .4728 L 1 g
F P
s
P
p
.002 w
.47762 .46706 m .47786 .46667 L p
.48991 .46544 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49554 .4728 m .48947 .46551 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46714 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.508 .46512 m .52243 .46714 L .53959 .48727 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .4767 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53959 .48727 m .53323 .4724 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56618 .50949 L p
1 g
F P
s
P
p
.002 w
.56305 .50296 m .56208 .48047 L p
.56426 .49192 L 1 g
F P
s
P
p
.56426 .49192 m .56853 .51439 L .56618 .50949 L 1 g
F
P
p
.56426 .49192 m .56618 .50949 L .56305 .50296 L 1 g
F
P
p
.002 w
.56618 .50949 m .56515 .50826 L p
.56704 .52054 L 1 g
F P
s
P
p
.002 w
.57463 .51424 m .56769 .53286 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56672 .51443 m .57163 .51431 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.57163 .51431 m .57463 .51424 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56654 .52734 L p
.56427 .53978 L 1 g
F P
s
P
p
.56704 .52054 m .56672 .51443 L .56618 .50949 L 1 g
F
P
p
.002 w
.56769 .53286 m .56305 .54531 L p
.56332 .54307 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56177 .54758 L p
1 g
F P
s
P
p
.002 w
.56217 .54655 m .56305 .54531 L p
.56249 .54668 L 1 g
F P
s
P
p
.55204 .57211 m .56177 .54758 L .56249 .54668 L 1 g
F
P
p
.56177 .54758 m .56217 .54655 L .56249 .54668 L 1 g
F
P
p
.002 w
.56305 .54531 m .55515 .57245 L .55204 .57211 L p
1 g
F P
s
P
p
.002 w
.56177 .54758 m .56075 .54566 L p
.55512 .55587 L 1 g
F P
s
P
p
.002 w
.54478 .57131 m .5433 .57059 L p
.54924 .56318 L 1 g
F P
s
P
p
.002 w
.5592 .55079 m .55184 .56126 L p
.54924 .56318 L 1 g
F P
s
P
p
.002 w
.55184 .56126 m .54478 .57131 L p
.54924 .56318 L 1 g
F P
s
P
p
.002 w
.54924 .56318 m .54854 .56129 L p
.53878 .57059 L 1 g
F P
s
P
p
.002 w
.54086 .56941 m .54478 .57131 L p
.5335 .57359 L 1 g
F P
s
P
p
.53878 .57059 m .53707 .57223 L .54086 .56941 L 1 g
F
P
p
.53878 .57059 m .54086 .56941 L .54924 .56318 L 1 g
F
P
p
.002 w
.54478 .57131 m .52559 .59252 L p
.53328 .57412 L 1 g
F P
s
P
p
.002 w
.53171 .57461 m .53128 .57265 L p
.52092 .57796 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.52559 .59252 m .50865 .58458 L .51735 .57907 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .5809 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .5809 L .51222 .58054 L 1 g
F
P
p
.002 w
.50865 .58458 m .50649 .58218 L p
.51096 .5809 L 1 g
F P
s
P
p
.51201 .58084 m .51096 .5809 L .51229 .58052 L 1 g
F
P
p
.50865 .58458 m .51096 .5809 L .51201 .58084 L 1 g
F
P
p
.51079 .57862 m .49938 .5809 L .50563 .58122 L 1 g
F
P
p
.002 w
.51096 .5809 m .51079 .57862 L p
.50563 .58122 L 1 g
F P
s
P
p
.53128 .57265 m .51222 .58054 L .52092 .57796 L 1 g
F
P
p
.002 w
.51735 .57907 m .50865 .58458 L p
.51229 .58052 L 1 g
F P
s
P
p
.51222 .58054 m .51097 .58106 L .51735 .57907 L 1 g
F
P
p
.51222 .58054 m .51735 .57907 L .52092 .57796 L 1 g
F
P
p
.002 w
.50649 .58218 m .50563 .58122 L p
.51096 .5809 L 1 g
F P
s
P
p
.50563 .58122 m .48889 .583 L .511 .58149 L 1 g
F
P
p
.49938 .5809 m .4944 .5819 L .50563 .58122 L 1 g
F
P
p
.4944 .5819 m .48889 .583 L .50563 .58122 L 1 g
F
P
p
.51096 .5809 m .4969 .57149 L .51229 .58052 L 1 g
F
P
p
.002 w
.50563 .58122 m .4969 .57149 L p
.51096 .5809 L 1 g
F P
s
P
p
.002 w
.511 .58149 m .51096 .5809 L p
.50563 .58122 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.4969 .57149 m .53034 .56041 L p
.51229 .58052 L 1 g
F P
s
P
p
.52559 .59252 m .51904 .58182 L .53328 .57412 L 1 g
F
P
p
.51904 .58182 m .51735 .57907 L .53171 .57461 L 1 g
F
P
p
.51904 .58182 m .53171 .57461 L .53328 .57412 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57461 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57461 L .53878 .57059 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51735 .57907 m .53619 .56716 L p
.53328 .57412 L 1 g
F P
s
P
p
.53328 .57412 m .5335 .57359 L .53778 .57272 L 1 g
F
P
p
.53328 .57412 m .53778 .57272 L .54478 .57131 L 1 g
F
P
p
.002 w
.53171 .57461 m .5322 .57686 L p
.53878 .57059 L 1 g
F P
s
P
p
.002 w
.51097 .58106 m .51111 .583 L p
.52053 .57817 L 1 g
F P
s
P
p
.52092 .57796 m .51735 .57907 L .52053 .57817 L 1 g
F
P
p
.51735 .57907 m .51097 .58106 L .52053 .57817 L 1 g
F
P
p
.002 w
.51096 .5809 m .51097 .58106 L p
.51222 .58054 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53034 .56041 m .53619 .56716 L .51735 .57907 L p
1 g
F P
s
P
p
.51229 .58052 m .53034 .56041 L .51735 .57907 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57461 L p
1 g
F P
s
P
p
.52092 .57796 m .51111 .583 L .53171 .57461 L 1 g
F
P
p
.002 w
.53619 .56716 m .54086 .56941 L p
.5335 .57359 L 1 g
F P
s
P
p
.55512 .55587 m .5592 .55079 L .56177 .54758 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.55204 .57211 m .54478 .57131 L .55184 .56126 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .56321 L p
1 g
F P
s
P
p
.56075 .54566 m .54925 .56321 L .5551 .55591 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.54924 .56318 m .53619 .56716 L .5592 .55079 L 1 g
F
P
p
.002 w
.5433 .57059 m .54086 .56941 L p
.54924 .56318 L 1 g
F P
s
P
p
.002 w
.54086 .56941 m .53619 .56716 L p
.54924 .56318 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54925 .56321 L p
1 g
F P
s
P
p
.002 w
.54925 .56321 m .54924 .56318 L p
.54862 .56368 L 1 g
F P
s
P
p
.54862 .56368 m .5322 .57686 L .54925 .56321 L 1 g
F
P
p
.002 w
.55184 .56126 m .5592 .55079 L p
.55699 .55738 L 1 g
F P
s
P
p
.55204 .57211 m .55184 .56126 L .55699 .55738 L 1 g
F
P
p
.56654 .52734 m .56177 .54758 L .56217 .54655 L 1 g
F
P
p
.002 w
.56248 .54577 m .56305 .54531 L .56217 .54655 L p
1 g
F P
s
P
p
.56229 .54625 m .56217 .54655 L .56229 .54626 L 1 g
F
P
p
.56654 .52734 m .56217 .54655 L .56229 .54625 L 1 g
F
P
p
.56654 .52734 m .56228 .54629 L .56427 .53978 L 1 g
F
P
p
.56228 .54629 m .5626 .54545 L .56427 .53978 L 1 g
F
P
p
.002 w
.56263 .54538 m .56305 .54531 L .56257 .54553 L p
1 g
F P
s
P
p
.5626 .54545 m .56263 .54539 L .56264 .54535 L 1 g
F
P
p
.5626 .54545 m .56264 .54535 L .56427 .53978 L 1 g
F
P
p
.56263 .54539 m .56267 .54526 L .56427 .53978 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.52789 .55177 m .52915 .54215 L .56267 .54527 L p
1 g
F P
s
P
p
.002 w
.56267 .54527 m .56305 .54531 L .56263 .54538 L p
1 g
F P
s
P
p
.002 w
.56263 .54538 m .52789 .55177 L p
.56267 .54527 L 1 g
F P
s
P
p
.56265 .54533 m .56271 .54513 L .56427 .53978 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52915 .54215 m .53404 .53262 L .5627 .54515 L p
1 g
F P
s
P
p
.002 w
.5627 .54515 m .56305 .54531 L .56267 .54527 L p
1 g
F P
s
P
p
.002 w
.56267 .54527 m .52915 .54215 L p
.5627 .54515 L 1 g
F P
s
P
p
.56263 .54539 m .56265 .54533 L .56267 .54526 L 1 g
F
P
p
.56265 .54533 m .56267 .54528 L .56271 .54513 L 1 g
F
P
p
.56267 .54528 m .56279 .54487 L .56427 .53978 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.53404 .53262 m .54204 .52423 L .56275 .54501 L p
1 g
F P
s
P
p
.002 w
.56275 .54501 m .56305 .54531 L .5627 .54515 L p
1 g
F P
s
P
p
.002 w
.5627 .54515 m .53404 .53262 L p
.56275 .54501 L 1 g
F P
s
P
p
.56269 .54522 m .56307 .54391 L .56427 .53978 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54204 .52423 m .55226 .51796 L .56283 .54475 L p
1 g
F P
s
P
p
.002 w
.56283 .54475 m .56305 .54531 L .56275 .54501 L p
1 g
F P
s
P
p
.002 w
.56275 .54501 m .54204 .52423 L p
.56283 .54475 L 1 g
F P
s
P
p
.56267 .54528 m .56269 .54522 L .56279 .54487 L 1 g
F
P
p
.56269 .54522 m .56271 .54517 L .56307 .54391 L 1 g
F
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55226 .51796 m .56355 .5145 L .56307 .54391 L p
1 g
F P
s
P
p
.002 w
.56307 .54391 m .56305 .54531 L .56283 .54475 L p
1 g
F P
s
P
p
.002 w
.56283 .54475 m .55226 .51796 L p
.56307 .54391 L 1 g
F P
s
P
p
.002 w
.53034 .56041 m .52789 .55177 L .56263 .54538 L p
1 g
F P
s
P
p
.002 w
.56257 .54553 m .53034 .56041 L p
.56263 .54538 L 1 g
F P
s
P
p
.56257 .54553 m .56193 .54788 L .56271 .54517 L 1 g
F
P
p
.56228 .54629 m .56227 .54637 L .56257 .54553 L 1 g
F
P
p
.56227 .54637 m .56193 .54788 L .56257 .54553 L 1 g
F
P
p
.002 w
.53619 .56716 m .53034 .56041 L .56257 .54553 L p
1 g
F P
s
P
p
.002 w
.56257 .54553 m .56305 .54531 L .56248 .54577 L p
1 g
F P
s
P
p
.002 w
.56248 .54577 m .53619 .56716 L p
.56257 .54553 L 1 g
F P
s
P
p
.002 w
.53619 .56716 m .56248 .54577 L p
.5592 .55079 L 1 g
F P
s
P
p
.002 w
.56217 .54655 m .5592 .55079 L p
.56248 .54577 L 1 g
F P
s
P
p
.002 w
.5592 .55079 m .56217 .54655 L p
.56177 .54758 L 1 g
F P
s
P
p
.55204 .57211 m .5592 .55079 L .56177 .54758 L 1 g
F
P
p
.002 w
.54925 .56321 m .54998 .56518 L p
.5551 .55591 L 1 g
F P
s
P
p
.53707 .57223 m .5322 .57686 L .54924 .56318 L 1 g
F
P
p
.55512 .55587 m .5551 .55591 L .5592 .55079 L 1 g
F
P
p
.002 w
.56622 .57051 m .55515 .57245 L .56274 .54636 L p
1 g
F P
s
P
p
.002 w
.56274 .54636 m .56305 .54531 L .56312 .54588 L p
1 g
F P
s
P
p
.002 w
.56312 .54588 m .56622 .57051 L p
.56274 .54636 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56177 .54759 L p
1 g
F P
s
P
p
.002 w
.56177 .54759 m .56177 .54758 L p
.56169 .5477 L 1 g
F P
s
P
p
.56169 .5477 m .54998 .56518 L .56177 .54759 L 1 g
F
P
p
.5551 .55591 m .54998 .56518 L .56177 .54758 L 1 g
F
P
p
.002 w
.56177 .54758 m .56193 .54788 L p
.56229 .54626 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56672 .51443 m .56747 .5287 L .56332 .54307 L 1 g
F
P
p
.56747 .5287 m .56769 .53286 L .56332 .54307 L 1 g
F
P
p
.002 w
.56305 .54531 m .56355 .5145 L .56672 .51443 L p
1 g
F P
s
P
p
.002 w
.57681 .56569 m .56622 .57051 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.58584 .5585 m .57681 .56569 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.59235 .54968 m .58584 .5585 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.59565 .54015 m .59235 .54968 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.59535 .53091 m .59565 .54015 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.59143 .52296 m .59535 .53091 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.58428 .51718 m .59143 .52296 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.57463 .51424 m .58428 .51718 L .56305 .54531 L closepath p
1 g
F P
s
P
p
.002 w
.56193 .54788 m .56257 .5491 L p
.56427 .53978 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56747 .5287 L p
1 g
F P
s
P
p
.56427 .53978 m .56257 .5491 L .56747 .5287 L 1 g
F
P
p
.56704 .52054 m .56825 .52837 L .56672 .51443 L 1 g
F
P
p
.55661 .4905 m .56618 .50949 L .56305 .50296 L 1 g
F
P
p
.55661 .4905 m .56305 .50296 L .56206 .50093 L 1 g
F
P
p
.002 w
.56277 .49654 m .56305 .50296 L p
.55741 .49135 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49135 L p
1 g
F P
s
P
p
.54174 .47608 m .55741 .49135 L .55332 .4874 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53959 .48727 m .54995 .48414 L p
.56355 .5145 L 1 g
F P
s
P
p
.54174 .47608 m .55332 .4874 L .55125 .48539 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54995 .48414 m .55546 .48946 L .56355 .5145 L 1 g
F
P
p
.002 w
.56305 .50296 m .56355 .5145 L p
.55546 .48946 L 1 g
F P
s
P
p
.55741 .49135 m .56305 .50296 L .55546 .48946 L 1 g
F
P
p
.002 w
.54995 .48414 m .53959 .48727 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54266 .47708 L p
1 g
F P
s
P
p
.54174 .47608 m .55125 .48539 L .54995 .48414 L 1 g
F
P
p
.002 w
.54231 .4767 m .54174 .47608 L p
.54995 .48414 L 1 g
F P
s
P
p
.5255 .45434 m .55487 .48265 L .54231 .4767 L 1 g
F
P
p
.52214 .46667 m .54231 .4767 L .53838 .47484 L 1 g
F
P
p
.52214 .46667 m .54251 .47692 L .53294 .47226 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53323 .4724 m .5299 .46463 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.5299 .46463 m .5255 .45434 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.54266 .47708 m .54231 .4767 L p
.54995 .48414 L 1 g
F P
s
P
p
.55125 .48539 m .55834 .49233 L .54266 .47708 L 1 g
F
P
p
.5534 .4831 m .55741 .49135 L .55546 .48946 L 1 g
F
P
p
.002 w
.54995 .48414 m .5534 .4831 L p
.55546 .48946 L 1 g
F P
s
P
p
.55125 .48539 m .5579 .49187 L .55241 .48653 L 1 g
F
P
p
.55332 .4874 m .5579 .49187 L .55125 .48539 L 1 g
F
P
p
.002 w
.55741 .49135 m .5579 .49187 L p
.55332 .4874 L 1 g
F P
s
P
p
.002 w
.5534 .4831 m .56208 .48047 L .56277 .49654 L p
1 g
F P
s
P
p
.5534 .4831 m .56277 .49654 L .55741 .49135 L 1 g
F
P
p
.56206 .50093 m .56305 .50296 L .5622 .50119 L 1 g
F
P
p
.002 w
.56853 .51439 m .56355 .5145 L .56305 .50296 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56618 .50949 L p
1 g
F P
s
P
p
.56825 .52837 m .56854 .53025 L .56618 .50949 L 1 g
F
P
p
.002 w
.56618 .50949 m .56713 .51061 L p
.5622 .50119 L 1 g
F P
s
P
p
.002 w
.57463 .51424 m .56853 .51439 L p
.56208 .48047 L 1 g
F P
s
P
p
.002 w
.55487 .48265 m .54995 .48414 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.5579 .49187 m .55834 .49233 L p
.55241 .48653 L 1 g
F P
s
P
p
.002 w
.54231 .4767 m .54251 .47692 L p
.53838 .47484 L 1 g
F P
s
P
p
.002 w
.56208 .48047 m .55487 .48265 L p
.5255 .45434 L 1 g
F P
s
P
p
.002 w
.53323 .4724 m .53959 .48727 L p
.52243 .46714 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46714 L p
1 g
F P
s
P
p
.002 w
.52243 .46714 m .52214 .46667 L p
.53294 .47226 L 1 g
F P
s
P
p
.53294 .47226 m .54302 .47747 L .52243 .46714 L 1 g
F
P
p
.002 w
.5255 .45434 m .53152 .46842 L p
.52243 .46714 L 1 g
F P
s
P
p
.5 .4634 m .52243 .46714 L .51545 .46617 L 1 g
F
P
p
.5 .4634 m .52261 .46745 L .51356 .46601 L 1 g
F
P
p
.002 w
.49554 .4728 m .508 .46512 L p
.53959 .48727 L 1 g
F P
s
P
p
.002 w
.508 .46512 m .49554 .4728 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46385 L p
1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .4634 L p
.51356 .46601 L 1 g
F P
s
P
p
.51356 .46601 m .52282 .46778 L .5 .46385 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.47181 .44432 m .51354 .46171 L .5 .46385 L 1 g
F
P
p
.48991 .46544 m .48947 .46551 L .47762 .46706 L 1 g
F
P
p
.002 w
.48947 .46551 m .48626 .46166 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.48626 .46166 m .47181 .44432 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.508 .46512 m .51253 .46233 L p
.52243 .46714 L 1 g
F P
s
P
p
.002 w
.51253 .46233 m .5255 .45434 L p
.52243 .46714 L 1 g
F P
s
P
p
.002 w
.53152 .46842 m .53323 .4724 L p
.52243 .46714 L 1 g
F P
s
P
p
.002 w
.54251 .47692 m .54302 .47747 L p
.53294 .47226 L 1 g
F P
s
P
p
.002 w
.52243 .46714 m .52261 .46745 L p
.51545 .46617 L 1 g
F P
s
P
p
.002 w
.51354 .46171 m .508 .46512 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.52261 .46745 m .52282 .46778 L p
.51356 .46601 L 1 g
F P
s
P
p
.48991 .46544 m .49033 .4654 L .48947 .46551 L 1 g
F
P
p
.002 w
.5255 .45434 m .51354 .46171 L p
.47181 .44432 L 1 g
F P
s
P
p
.002 w
.44715 .47105 m .47181 .44432 L .48947 .46551 L p
1 g
F P
s
P
p
.002 w
.48947 .46551 m .49554 .4728 L p
.44715 .47105 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47762 .46706 L p
1 g
F P
s
P
p
.49033 .4654 m .5 .46442 L .47762 .46706 L 1 g
F
P
p
.002 w
.47762 .46706 m .47718 .46778 L p
.46514 .47306 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45779 .4766 L p
1 g
F P
s
P
p
.002 w
.45779 .4766 m .45698 .47747 L p
.45084 .48336 L 1 g
F P
s
P
p
.44339 .4905 m .45779 .4766 L .45084 .48336 L 1 g
F
P
p
.44214 .47648 m .4591 .47531 L .45779 .4766 L 1 g
F
P
p
.002 w
.45133 .48288 m .44862 .481 L p
.45779 .4766 L 1 g
F P
s
P
p
.002 w
.44862 .481 m .44214 .47648 L p
.45779 .4766 L 1 g
F P
s
P
p
.4591 .47531 m .46068 .4752 L .45779 .4766 L 1 g
F
P
p
.46068 .4752 m .49554 .4728 L .45779 .4766 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45779 .4766 L p
1 g
F P
s
P
p
.46514 .47306 m .47718 .46778 L .45779 .4766 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44205 .49192 L p
1 g
F P
s
P
p
.002 w
.44205 .49192 m .44276 .49117 L p
.4483 .48584 L 1 g
F P
s
P
p
.4483 .48584 m .45698 .47747 L .44205 .49192 L 1 g
F
P
p
.002 w
.44276 .49117 m .44339 .4905 L p
.45043 .48375 L 1 g
F P
s
P
p
.45043 .48375 m .45698 .47747 L .44276 .49117 L 1 g
F
P
p
.002 w
.44791 .4805 m .45133 .48288 L p
.44276 .49117 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43402 .50925 L p
1 g
F P
s
P
p
.43755 .50194 m .44166 .49233 L .43402 .50925 L 1 g
F
P
p
.002 w
.43402 .50925 m .43287 .51061 L p
.43312 .51769 L 1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.47242 .49758 m .45878 .5256 L .43331 .51596 L p
1 g
F P
s
P
p
.43395 .50991 m .47242 .49758 L .43331 .51596 L 1 g
F
P
p
.002 w
.43331 .51596 m .45878 .5256 L p
.43219 .54232 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43278 .52833 L p
1 g
F P
s
P
p
.43317 .51911 m .43287 .51061 L .43278 .52833 L 1 g
F
P
p
.002 w
.43278 .52833 m .43146 .53025 L p
.43632 .53986 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43852 .54704 L p
1 g
F P
s
P
p
.43632 .53986 m .43146 .53025 L .43852 .54704 L 1 g
F
P
p
.002 w
.43852 .54704 m .43823 .54758 L p
.44037 .54979 L 1 g
F P
s
P
p
.002 w
.45878 .5256 m .45598 .55353 L .44153 .55152 L p
1 g
F P
s
P
p
.44947 .56102 m .45598 .55353 L .45092 .56275 L 1 g
F
P
p
.002 w
.43265 .58039 m .42188 .54879 L .45598 .55353 L p
1 g
F P
s
P
p
.002 w
.43823 .54758 m .43743 .5491 L p
.44503 .5557 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45092 .56275 L p
1 g
F P
s
P
p
.44503 .5557 m .43743 .5491 L .45092 .56275 L 1 g
F
P
p
.45922 .56886 m .45804 .56838 L .46146 .5705 L 1 g
F
P
p
.48921 .57862 m .47047 .57544 L .47886 .57777 L 1 g
F
P
p
.47047 .57544 m .4682 .57505 L .47318 .57632 L 1 g
F
P
p
.47047 .57544 m .47318 .57632 L .47886 .57777 L 1 g
F
P
p
.4681 .57466 m .49175 .55454 L .47318 .57632 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57472 L p
1 g
F P
s
P
p
.45804 .56838 m .45002 .56518 L .46827 .57472 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.49175 .55454 m .4969 .57149 L .47318 .57632 L p
1 g
F P
s
P
p
.002 w
.46827 .57472 m .4682 .57505 L p
.47047 .57544 L 1 g
F P
s
P
p
.002 w
.4682 .57505 m .4678 .57686 L p
.47886 .57777 L 1 g
F P
s
P
p
.002 w
.47318 .57632 m .4969 .57149 L p
.49119 .58091 L 1 g
F P
s
P
p
.002 w
.48908 .58037 m .48889 .583 L p
.49938 .5809 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58037 L p
1 g
F P
s
P
p
.47886 .57777 m .4678 .57686 L .48908 .58037 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58149 L p
1 g
F P
s
P
p
.002 w
.4969 .57149 m .50563 .58122 L p
.49145 .5805 L 1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51167 .45176 L
s
P
p
.004 w
.52932 .4839 m
.54906 .51983 L
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.45322 .30077 m .3943 .33744 L .38266 .31734 L p
1 g
F P
s
P
p
.002 w
.38266 .31734 m .44221 .28023 L .45322 .30077 L p
1 g
F P
s
P
p
.002 w
.62474 .53182 m .6244 .51365 L .64924 .49422 L p
1 g
F P
s
P
p
.002 w
.63875 .47092 m .64924 .49422 L .6244 .51365 L p
1 g
F P
s
P
p
.002 w
.64924 .49422 m .63875 .47092 L .65605 .44316 L p
1 g
F P
s
P
p
.002 w
.51893 .28247 m .45322 .30077 L .44221 .28023 L p
1 g
F P
s
P
p
.002 w
.59235 .54968 m .59565 .54015 L .62474 .53182 L p
1 g
F P
s
P
p
.002 w
.6244 .51365 m .62474 .53182 L .59565 .54015 L p
1 g
F P
s
P
p
.002 w
.38845 .43117 m .36626 .48059 L .34338 .46248 L p
1 g
F P
s
P
p
.002 w
.34338 .46248 m .36697 .40871 L .38845 .43117 L p
1 g
F P
s
P
p
.002 w
.59439 .3395 m .64189 .35741 L .63838 .38794 L p
1 g
F P
s
P
p
.002 w
.64189 .35741 m .59439 .3395 L .58977 .30984 L p
1 g
F P
s
P
p
.002 w
.63058 .42036 m .65605 .44316 L .63875 .47092 L p
1 g
F P
s
P
p
.002 w
.65605 .44316 m .63058 .42036 L .63838 .38794 L p
1 g
F P
s
P
p
.002 w
.40955 .36101 m .36697 .40871 L .35003 .38746 L p
1 g
F P
s
P
p
.002 w
.35003 .38746 m .3943 .33744 L .40955 .36101 L p
1 g
F P
s
P
p
.002 w
.42496 .51279 m .42188 .54879 L .39067 .54058 L p
1 g
F P
s
P
p
.002 w
.39067 .54058 m .39375 .49759 L .42496 .51279 L p
1 g
F P
s
P
p
.002 w
.52887 .30822 m .58977 .30984 L .59439 .3395 L p
1 g
F P
s
P
p
.002 w
.58977 .30984 m .52887 .30822 L .51893 .28247 L p
1 g
F P
s
P
p
.002 w
.59565 .54015 m .59535 .53091 L .6244 .51365 L p
1 g
F P
s
P
p
.002 w
.61697 .49785 m .6244 .51365 L .59535 .53091 L p
1 g
F P
s
P
p
.002 w
.6244 .51365 m .61697 .49785 L .63875 .47092 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.45322 .30077 m .51893 .28247 L .52887 .30822 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.5962 .37258 m .63838 .38794 L .63058 .42036 L p
1 g
F P
s
P
p
.002 w
.63838 .38794 m .5962 .37258 L .59439 .3395 L p
1 g
F P
s
P
p
.002 w
.61868 .45352 m .63875 .47092 L .61697 .49785 L p
1 g
F P
s
P
p
.002 w
.63875 .47092 m .61868 .45352 L .63058 .42036 L p
1 g
F P
s
P
p
.002 w
.4138 .45406 m .39375 .49759 L .36626 .48059 L p
1 g
F P
s
P
p
.002 w
.36626 .48059 m .38845 .43117 L .4138 .45406 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.52789 .55177 m .53034 .56041 L .4969 .57149 L p
1 g
F P
s
P
p
.002 w
.4969 .57149 m .49175 .55454 L .52789 .55177 L p
1 g
F P
s
P
p
.002 w
.46601 .32594 m .40955 .36101 L .3943 .33744 L p
1 g
F P
s
P
p
.002 w
.3943 .33744 m .45322 .30077 L .46601 .32594 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59535 .53091 m .59143 .52296 L .61697 .49785 L p
1 g
F P
s
P
p
.002 w
.52887 .30822 m .46601 .32594 L .45322 .30077 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.60306 .4862 m .61697 .49785 L .59143 .52296 L p
1 g
F P
s
P
p
.002 w
.61697 .49785 m .60306 .4862 L .61868 .45352 L p
1 g
F P
s
P
p
.002 w
.42799 .38733 m .38845 .43117 L .36697 .40871 L p
1 g
F P
s
P
p
.002 w
.36697 .40871 m .40955 .36101 L .42799 .38733 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.53817 .33841 m .59439 .3395 L .5962 .37258 L p
1 g
F P
s
P
p
.002 w
.59439 .3395 m .53817 .33841 L .52887 .30822 L p
1 g
F P
s
P
p
.002 w
.59507 .40793 m .63058 .42036 L .61868 .45352 L p
1 g
F P
s
P
p
.002 w
.63058 .42036 m .59507 .40793 L .5962 .37258 L p
1 g
F P
s
P
p
.002 w
.49396 .53551 m .49175 .55454 L .45598 .55353 L p
1 g
F P
s
P
p
.002 w
.45598 .55353 m .45878 .5256 L .49396 .53551 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59143 .52296 m .58428 .51718 L .60306 .4862 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.46601 .32594 m .52887 .30822 L .53817 .33841 L p
1 g
F P
s
P
p
.002 w
.44214 .47648 m .42496 .51279 L .39375 .49759 L p
1 g
F P
s
P
p
.002 w
.39375 .49759 m .4138 .45406 L .44214 .47648 L p
1 g
F P
s
P
p
.002 w
.52915 .54215 m .52789 .55177 L .49175 .55454 L p
1 g
F P
s
P
p
.002 w
.49175 .55454 m .49396 .53551 L .52915 .54215 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59098 .44425 m .61868 .45352 L .60306 .4862 L p
1 g
F P
s
P
p
.002 w
.61868 .45352 m .59098 .44425 L .59507 .40793 L p
1 g
F P
s
P
p
.002 w
.58428 .51718 m .57463 .51424 L .58407 .48014 L p
1 g
F P
s
P
p
.002 w
.58407 .48014 m .60306 .4862 L .58428 .51718 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.60306 .4862 m .58407 .48014 L .59098 .44425 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.53404 .53262 m .52915 .54215 L .49396 .53551 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.48016 .35497 m .42799 .38733 L .40955 .36101 L p
1 g
F P
s
P
p
.002 w
.40955 .36101 m .46601 .32594 L .48016 .35497 L p
1 g
F P
s
P
p
.002 w
.54645 .37202 m .5962 .37258 L .59507 .40793 L p
1 g
F P
s
P
p
.002 w
.5962 .37258 m .54645 .37202 L .53817 .33841 L p
1 g
F P
s
P
p
.002 w
.56208 .48047 m .58407 .48014 L .57463 .51424 L p
1 g
F P
s
P
p
.002 w
.449 .41545 m .4138 .45406 L .38845 .43117 L p
1 g
F P
s
P
p
.002 w
.38845 .43117 m .42799 .38733 L .449 .41545 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.53817 .33841 m .48016 .35497 L .46601 .32594 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54204 .52423 m .53404 .53262 L .50345 .51652 L p
1 g
F P
s
P
p
.002 w
.49396 .53551 m .50345 .51652 L .53404 .53262 L p
1 g
F P
s
P
p
.002 w
.56355 .5145 m .55226 .51796 L .53959 .48727 L p
1 g
F P
s
P
p
.002 w
.50345 .51652 m .49396 .53551 L .45878 .5256 L p
1 g
F P
s
P
p
.002 w
.45878 .5256 m .47242 .49758 L .50345 .51652 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55226 .51796 m .54204 .52423 L .51926 .49978 L p
1 g
F P
s
P
p
.002 w
.50345 .51652 m .51926 .49978 L .54204 .52423 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.51926 .49978 m .53959 .48727 L .55226 .51796 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48016 .35497 m .53817 .33841 L .54645 .37202 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55337 .40783 m .59507 .40793 L .59098 .44425 L p
1 g
F P
s
P
p
.002 w
.59507 .40793 m .55337 .40783 L .54645 .37202 L p
1 g
F P
s
P
p
.002 w
.58407 .48014 m .56208 .48047 L .55865 .44446 L p
1 g
F P
s
P
p
.002 w
.55865 .44446 m .59098 .44425 L .58407 .48014 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.59098 .44425 m .55865 .44446 L .55337 .40783 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47181 .44432 m .44214 .47648 L .4138 .45406 L p
1 g
F P
s
P
p
.002 w
.4138 .45406 m .449 .41545 L .47181 .44432 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.51926 .49978 m .50345 .51652 L .47242 .49758 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49519 .38687 m .449 .41545 L .42799 .38733 L p
1 g
F P
s
P
p
.002 w
.42799 .38733 m .48016 .35497 L .49519 .38687 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.5255 .45434 m .55865 .44446 L .56208 .48047 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.54645 .37202 m .49519 .38687 L .48016 .35497 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49519 .38687 m .54645 .37202 L .55337 .40783 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.47242 .49758 m .49554 .4728 L .51926 .49978 L p
1 g
F P
s
P
p
.002 w
.53959 .48727 m .51926 .49978 L .49554 .4728 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.55865 .44446 m .5255 .45434 L .5105 .42043 L p
1 g
F P
s
P
p
.002 w
.5105 .42043 m .55337 .40783 L .55865 .44446 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55337 .40783 m .5105 .42043 L .49519 .38687 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5105 .42043 m .47181 .44432 L .449 .41545 L p
1 g
F P
s
P
p
.002 w
.449 .41545 m .49519 .38687 L .5105 .42043 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47181 .44432 m .5105 .42043 L .5255 .45434 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.58459 .58452 m
.58913 .59278 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .74321 .34463 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60049 .61348 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.00736842)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.00736842)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4492 .45985 m .49029 .45454 L .48304 .42691 L p
1 g
F P
s
P
p
.002 w
.48304 .42691 m .44876 .4312 L .4492 .45985 L p
1 g
F P
s
P
p
.002 w
.51554 .41395 m .48304 .42691 L .49029 .45454 L p
1 g
F P
s
P
p
.002 w
.44876 .4312 m .48304 .42691 L .47619 .39931 L p
1 g
F P
s
P
p
.002 w
.48304 .42691 m .51554 .41395 L .50143 .38924 L p
1 g
F P
s
P
p
.002 w
.50143 .38924 m .47619 .39931 L .48304 .42691 L p
1 g
F P
s
P
p
.002 w
.49029 .45454 m .52926 .43903 L .51554 .41395 L p
1 g
F P
s
P
p
.002 w
.54321 .39355 m .51554 .41395 L .52926 .43903 L p
1 g
F P
s
P
p
.002 w
.51554 .41395 m .54321 .39355 L .52284 .37331 L p
1 g
F P
s
P
p
.002 w
.52284 .37331 m .50143 .38924 L .51554 .41395 L p
1 g
F P
s
P
p
.002 w
.45088 .48797 m .49781 .48172 L .49029 .45454 L p
1 g
F P
s
P
p
.002 w
.49029 .45454 m .4492 .45985 L .45088 .48797 L p
1 g
F P
s
P
p
.002 w
.52926 .43903 m .49029 .45454 L .49781 .48172 L p
1 g
F P
s
P
p
.002 w
.49781 .48172 m .54233 .46402 L .52926 .43903 L p
1 g
F P
s
P
p
.002 w
.56255 .41471 m .52926 .43903 L .54233 .46402 L p
1 g
F P
s
P
p
.002 w
.52926 .43903 m .56255 .41471 L .54321 .39355 L p
1 g
F P
s
P
p
.002 w
.47619 .39931 m .44956 .40254 L .44876 .4312 L p
1 g
F P
s
P
p
.002 w
.44956 .40254 m .47619 .39931 L .46986 .37225 L p
1 g
F P
s
P
p
.002 w
.47619 .39931 m .50143 .38924 L .48717 .36534 L p
1 g
F P
s
P
p
.002 w
.48717 .36534 m .46986 .37225 L .47619 .39931 L p
1 g
F P
s
P
p
.002 w
.50143 .38924 m .52284 .37331 L .5018 .35435 L p
1 g
F P
s
P
p
.002 w
.5018 .35435 m .48717 .36534 L .50143 .38924 L p
1 g
F P
s
P
p
.002 w
.40976 .4543 m .4492 .45985 L .44876 .4312 L p
1 g
F P
s
P
p
.002 w
.44876 .4312 m .41594 .42632 L .40976 .4543 L p
1 g
F P
s
P
p
.002 w
.41594 .42632 m .44876 .4312 L .44956 .40254 L p
1 g
F P
s
P
p
.002 w
.45379 .51501 m .50546 .50795 L .49781 .48172 L p
1 g
F P
s
P
p
.002 w
.49781 .48172 m .45088 .48797 L .45379 .51501 L p
1 g
F P
s
P
p
.002 w
.54233 .46402 m .49781 .48172 L .50546 .50795 L p
1 g
F P
s
P
p
.002 w
.50546 .50795 m .55451 .48846 L .54233 .46402 L p
1 g
F P
s
P
p
.002 w
.5805 .4364 m .54233 .46402 L .55451 .48846 L p
1 g
F P
s
P
p
.002 w
.54233 .46402 m .5805 .4364 L .56255 .41471 L p
1 g
F P
s
P
p
.002 w
.56333 .36754 m .54321 .39355 L .56255 .41471 L p
1 g
F P
s
P
p
.002 w
.54321 .39355 m .56333 .36754 L .53825 .35302 L p
1 g
F P
s
P
p
.002 w
.53825 .35302 m .52284 .37331 L .54321 .39355 L p
1 g
F P
s
P
p
.002 w
.44956 .40254 m .42416 .39856 L .41594 .42632 L p
1 g
F P
s
P
p
.002 w
.42416 .39856 m .44956 .40254 L .4516 .3744 L p
1 g
F P
s
P
p
.002 w
.46986 .37225 m .4516 .3744 L .44956 .40254 L p
1 g
F P
s
P
p
.002 w
.40574 .48197 m .45088 .48797 L .4492 .45985 L p
1 g
F P
s
P
p
.002 w
.4492 .45985 m .40976 .4543 L .40574 .48197 L p
1 g
F P
s
P
p
.002 w
.52284 .37331 m .53825 .35302 L .51222 .34039 L p
1 g
F P
s
P
p
.002 w
.51222 .34039 m .5018 .35435 L .52284 .37331 L p
1 g
F P
s
P
p
.002 w
.58697 .38368 m .56255 .41471 L .5805 .4364 L p
1 g
F P
s
P
p
.002 w
.56255 .41471 m .58697 .38368 L .56333 .36754 L p
1 g
F P
s
P
p
.002 w
.4516 .3744 m .46986 .37225 L .46418 .34623 L p
1 g
F P
s
P
p
.002 w
.46986 .37225 m .48717 .36534 L .47303 .3427 L p
1 g
F P
s
P
p
.002 w
.47303 .3427 m .46418 .34623 L .46986 .37225 L p
1 g
F P
s
P
p
.002 w
.48717 .36534 m .5018 .35435 L .48048 .33706 L p
1 g
F P
s
P
p
.002 w
.48048 .33706 m .47303 .3427 L .48717 .36534 L p
1 g
F P
s
P
p
.002 w
.4516 .3744 m .43424 .37154 L .42416 .39856 L p
1 g
F P
s
P
p
.002 w
.43424 .37154 m .4516 .3744 L .45485 .3473 L p
1 g
F P
s
P
p
.002 w
.46418 .34623 m .45485 .3473 L .4516 .3744 L p
1 g
F P
s
P
p
.002 w
.40401 .50877 m .45379 .51501 L .45088 .48797 L p
1 g
F P
s
P
p
.002 w
.45088 .48797 m .40574 .48197 L .40401 .50877 L p
1 g
F P
s
P
p
.002 w
.5018 .35435 m .51222 .34039 L .48573 .3299 L p
1 g
F P
s
P
p
.002 w
.48573 .3299 m .48048 .33706 L .5018 .35435 L p
1 g
F P
s
P
p
.002 w
.4579 .54046 m .51311 .53272 L .50546 .50795 L p
1 g
F P
s
P
p
.002 w
.50546 .50795 m .45379 .51501 L .4579 .54046 L p
1 g
F P
s
P
p
.002 w
.55451 .48846 m .50546 .50795 L .51311 .53272 L p
1 g
F P
s
P
p
.002 w
.51311 .53272 m .56555 .5119 L .55451 .48846 L p
1 g
F P
s
P
p
.002 w
.59668 .45821 m .55451 .48846 L .56555 .5119 L p
1 g
F P
s
P
p
.002 w
.55451 .48846 m .59668 .45821 L .5805 .4364 L p
1 g
F P
s
P
p
.002 w
.60871 .40115 m .5805 .4364 L .59668 .45821 L p
1 g
F P
s
P
p
.002 w
.5805 .4364 m .60871 .40115 L .58697 .38368 L p
1 g
F P
s
P
p
.002 w
.38784 .41249 m .41594 .42632 L .42416 .39856 L p
1 g
F P
s
P
p
.002 w
.42416 .39856 m .40254 .3876 L .38784 .41249 L p
1 g
F P
s
P
p
.002 w
.40254 .3876 m .42416 .39856 L .43424 .37154 L p
1 g
F P
s
P
p
.002 w
.37579 .43807 m .40976 .4543 L .41594 .42632 L p
1 g
F P
s
P
p
.002 w
.41594 .42632 m .38784 .41249 L .37579 .43807 L p
1 g
F P
s
P
p
.002 w
.54599 .3303 m .53825 .35302 L .56333 .36754 L p
1 g
F P
s
P
p
.002 w
.53825 .35302 m .54599 .3303 L .51731 .32483 L p
1 g
F P
s
P
p
.002 w
.51731 .32483 m .51222 .34039 L .53825 .35302 L p
1 g
F P
s
P
p
.002 w
.43424 .37154 m .41957 .36389 L .40254 .3876 L p
1 g
F P
s
P
p
.002 w
.41957 .36389 m .43424 .37154 L .44601 .34577 L p
1 g
F P
s
P
p
.002 w
.45485 .3473 m .44601 .34577 L .43424 .37154 L p
1 g
F P
s
P
p
.002 w
.5737 .3383 m .56333 .36754 L .58697 .38368 L p
1 g
F P
s
P
p
.002 w
.56333 .36754 m .5737 .3383 L .54599 .3303 L p
1 g
F P
s
P
p
.002 w
.51222 .34039 m .51731 .32483 L .48822 .32197 L p
1 g
F P
s
P
p
.002 w
.48822 .32197 m .48573 .3299 L .51222 .34039 L p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .45485 .3473 L .46418 .34623 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .46418 .34623 L .47303 .3427 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .47303 .3427 L .48048 .33706 L closepath p
1 g
F P
s
P
p
.002 w
.36669 .46383 m .40574 .48197 L .40976 .4543 L p
1 g
F P
s
P
p
.002 w
.40976 .4543 m .37579 .43807 L .36669 .46383 L p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .44601 .34577 L .45485 .3473 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .48048 .33706 L .48573 .3299 L closepath p
1 g
F P
s
P
p
.002 w
.40467 .53415 m .4579 .54046 L .45379 .51501 L p
1 g
F P
s
P
p
.002 w
.45379 .51501 m .40401 .50877 L .40467 .53415 L p
1 g
F P
s
P
p
.002 w
.59986 .34869 m .58697 .38368 L .60871 .40115 L p
1 g
F P
s
P
p
.002 w
.58697 .38368 m .59986 .34869 L .5737 .3383 L p
1 g
F P
s
P
p
.002 w
.44601 .34577 m .43861 .3418 L .41957 .36389 L p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .43861 .3418 L .44601 .34577 L closepath p
1 g
F P
s
P
p
.002 w
.56555 .5119 m .61077 .47974 L .59668 .45821 L p
1 g
F P
s
P
p
.002 w
.62808 .41963 m .59668 .45821 L .61077 .47974 L p
1 g
F P
s
P
p
.002 w
.59668 .45821 m .62808 .41963 L .60871 .40115 L p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .48573 .3299 L .48822 .32197 L closepath p
1 g
F P
s
P
p
.002 w
.46317 .56373 m .5206 .5555 L .51311 .53272 L p
1 g
F P
s
P
p
.002 w
.51311 .53272 m .4579 .54046 L .46317 .56373 L p
1 g
F P
s
P
p
.002 w
.56555 .5119 m .51311 .53272 L .5206 .5555 L p
1 g
F P
s
P
p
.002 w
.38706 .3706 m .40254 .3876 L .41957 .36389 L p
1 g
F P
s
P
p
.002 w
.41957 .36389 m .4092 .35215 L .38706 .3706 L p
1 g
F P
s
P
p
.002 w
.4092 .35215 m .41957 .36389 L .43861 .3418 L p
1 g
F P
s
P
p
.002 w
.5206 .5555 m .57521 .53384 L .56555 .5119 L p
1 g
F P
s
P
p
.002 w
.61077 .47974 m .56555 .5119 L .57521 .53384 L p
1 g
F P
s
P
p
.002 w
.36749 .39078 m .38784 .41249 L .40254 .3876 L p
1 g
F P
s
P
p
.002 w
.40254 .3876 m .38706 .3706 L .36749 .39078 L p
1 g
F P
s
P
p
.002 w
.51641 .30928 m .51731 .32483 L .54599 .3303 L p
1 g
F P
s
P
p
.002 w
.51731 .32483 m .51641 .30928 L .48764 .3141 L p
1 g
F P
s
P
p
.002 w
.48764 .3141 m .48822 .32197 L .51731 .32483 L p
1 g
F P
s
P
p
.002 w
.3608 .48925 m .40401 .50877 L .40574 .48197 L p
1 g
F P
s
P
p
.002 w
.40574 .48197 m .36669 .46383 L .3608 .48925 L p
1 g
F P
s
P
p
.002 w
.43861 .3418 m .43344 .33577 L .4092 .35215 L p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .43344 .33577 L .43861 .3418 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .48822 .32197 L .48764 .3141 L closepath p
1 g
F P
s
P
p
.002 w
.54502 .30746 m .54599 .3303 L .5737 .3383 L p
1 g
F P
s
P
p
.002 w
.54599 .3303 m .54502 .30746 L .51641 .30928 L p
1 g
F P
s
P
p
.002 w
.62391 .3613 m .60871 .40115 L .62808 .41963 L p
1 g
F P
s
P
p
.002 w
.60871 .40115 m .62391 .3613 L .59986 .34869 L p
1 g
F P
s
P
p
.002 w
.35097 .41229 m .37579 .43807 L .38784 .41249 L p
1 g
F P
s
P
p
.002 w
.38784 .41249 m .36749 .39078 L .35097 .41229 L p
1 g
F P
s
P
p
.002 w
.40433 .3375 m .4092 .35215 L .43344 .33577 L p
1 g
F P
s
P
p
.002 w
.43344 .33577 m .43109 .32833 L .40433 .3375 L p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .43109 .32833 L .43344 .33577 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .47775 .30188 L .46946 .29891 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .46946 .29891 L .46006 .29858 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .46006 .29858 L .45061 .30095 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .45061 .30095 L .44216 .30574 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .44216 .30574 L .43567 .31243 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .43567 .31243 L .43185 .32025 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .43185 .32025 L .43109 .32833 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .48764 .3141 L .48403 .30715 L closepath p
1 g
F P
s
P
p
.002 w
.45928 .32178 m .48403 .30715 L .47775 .30188 L closepath p
1 g
F P
s
P
p
.002 w
.48403 .30715 m .48764 .3141 L .51641 .30928 L p
1 g
F P
s
P
p
.002 w
.40777 .55753 m .46317 .56373 L .4579 .54046 L p
1 g
F P
s
P
p
.002 w
.4579 .54046 m .40467 .53415 L .40777 .55753 L p
1 g
F P
s
P
p
.002 w
.57286 .30872 m .5737 .3383 L .59986 .34869 L p
1 g
F P
s
P
p
.002 w
.5737 .3383 m .57286 .30872 L .54502 .30746 L p
1 g
F P
s
P
p
.002 w
.37958 .34917 m .38706 .3706 L .4092 .35215 L p
1 g
F P
s
P
p
.002 w
.4092 .35215 m .40433 .3375 L .37958 .34917 L p
1 g
F P
s
P
p
.002 w
.57521 .53384 m .62239 .50055 L .61077 .47974 L p
1 g
F P
s
P
p
.002 w
.64462 .43877 m .61077 .47974 L .62239 .50055 L p
1 g
F P
s
P
p
.002 w
.61077 .47974 m .64462 .43877 L .62808 .41963 L p
1 g
F P
s
P
p
.002 w
.50949 .29543 m .51641 .30928 L .54502 .30746 L p
1 g
F P
s
P
p
.002 w
.51641 .30928 m .50949 .29543 L .48403 .30715 L p
1 g
F P
s
P
p
.002 w
.40564 .32147 m .40433 .3375 L .43109 .32833 L p
1 g
F P
s
P
p
.002 w
.43109 .32833 m .43185 .32025 L .40564 .32147 L p
1 g
F P
s
P
p
.002 w
.35835 .51376 m .40467 .53415 L .40401 .50877 L p
1 g
F P
s
P
p
.002 w
.40401 .50877 m .3608 .48925 L .35835 .51376 L p
1 g
F P
s
P
p
.002 w
.47775 .30188 m .48403 .30715 L .50949 .29543 L p
1 g
F P
s
P
p
.002 w
.33793 .43472 m .36669 .46383 L .37579 .43807 L p
1 g
F P
s
P
p
.002 w
.37579 .43807 m .35097 .41229 L .33793 .43472 L p
1 g
F P
s
P
p
.002 w
.46952 .58427 m .52779 .57575 L .5206 .5555 L p
1 g
F P
s
P
p
.002 w
.5206 .5555 m .46317 .56373 L .46952 .58427 L p
1 g
F P
s
P
p
.002 w
.57521 .53384 m .5206 .5555 L .52779 .57575 L p
1 g
F P
s
P
p
.002 w
.52779 .57575 m .58324 .55378 L .57521 .53384 L p
1 g
F P
s
P
p
.002 w
.62239 .50055 m .57521 .53384 L .58324 .55378 L p
1 g
F P
s
P
p
.002 w
.35742 .36314 m .36749 .39078 L .38706 .3706 L p
1 g
F P
s
P
p
.002 w
.38706 .3706 m .37958 .34917 L .35742 .36314 L p
1 g
F P
s
P
p
.002 w
.64529 .37593 m .62808 .41963 L .64462 .43877 L p
1 g
F P
s
P
p
.002 w
.62808 .41963 m .64529 .37593 L .62391 .3613 L p
1 g
F P
s
P
p
.002 w
.59934 .3131 m .59986 .34869 L .62391 .3613 L p
1 g
F P
s
P
p
.002 w
.59986 .34869 m .59934 .3131 L .57286 .30872 L p
1 g
F P
s
P
p
.002 w
.41311 .30585 m .40564 .32147 L .43185 .32025 L p
1 g
F P
s
P
p
.002 w
.43185 .32025 m .43567 .31243 L .41311 .30585 L p
1 g
F P
s
P
p
.002 w
.46946 .29891 m .47775 .30188 L .49715 .28485 L p
1 g
F P
s
P
p
.002 w
.50949 .29543 m .49715 .28485 L .47775 .30188 L p
1 g
F P
s
P
p
.002 w
.53512 .28694 m .54502 .30746 L .57286 .30872 L p
1 g
F P
s
P
p
.002 w
.54502 .30746 m .53512 .28694 L .50949 .29543 L p
1 g
F P
s
P
p
.002 w
.38123 .32552 m .37958 .34917 L .40433 .3375 L p
1 g
F P
s
P
p
.002 w
.40433 .3375 m .40564 .32147 L .38123 .32552 L p
1 g
F P
s
P
p
.002 w
.42602 .29242 m .41311 .30585 L .43567 .31243 L p
1 g
F P
s
P
p
.002 w
.43567 .31243 m .44216 .30574 L .42602 .29242 L p
1 g
F P
s
P
p
.002 w
.49715 .28485 m .48068 .27879 L .46946 .29891 L p
1 g
F P
s
P
p
.002 w
.46006 .29858 m .46946 .29891 L .48068 .27879 L p
1 g
F P
s
P
p
.002 w
.49715 .28485 m .50949 .29543 L .53512 .28694 L p
1 g
F P
s
P
p
.002 w
.32878 .4576 m .3608 .48925 L .36669 .46383 L p
1 g
F P
s
P
p
.002 w
.36669 .46383 m .33793 .43472 L .32878 .4576 L p
1 g
F P
s
P
p
.002 w
.44293 .28277 m .42602 .29242 L .44216 .30574 L p
1 g
F P
s
P
p
.002 w
.44216 .30574 m .45061 .30095 L .44293 .28277 L p
1 g
F P
s
P
p
.002 w
.48068 .27879 m .46188 .27806 L .46006 .29858 L p
1 g
F P
s
P
p
.002 w
.45061 .30095 m .46006 .29858 L .46188 .27806 L p
1 g
F P
s
P
p
.002 w
.41336 .5783 m .46952 .58427 L .46317 .56373 L p
1 g
F P
s
P
p
.002 w
.46317 .56373 m .40777 .55753 L .41336 .5783 L p
1 g
F P
s
P
p
.002 w
.33842 .37919 m .35097 .41229 L .36749 .39078 L p
1 g
F P
s
P
p
.002 w
.36749 .39078 m .35742 .36314 L .33842 .37919 L p
1 g
F P
s
P
p
.002 w
.46188 .27806 m .44293 .28277 L .45061 .30095 L p
1 g
F P
s
P
p
.002 w
.35953 .53678 m .40777 .55753 L .40467 .53415 L p
1 g
F P
s
P
p
.002 w
.40467 .53415 m .35835 .51376 L .35953 .53678 L p
1 g
F P
s
P
p
.002 w
.58324 .55378 m .63122 .52015 L .62239 .50055 L p
1 g
F P
s
P
p
.002 w
.65787 .45819 m .62239 .50055 L .63122 .52015 L p
1 g
F P
s
P
p
.002 w
.62239 .50055 m .65787 .45819 L .64462 .43877 L p
1 g
F P
s
P
p
.002 w
.5604 .28196 m .57286 .30872 L .59934 .3131 L p
1 g
F P
s
P
p
.002 w
.57286 .30872 m .5604 .28196 L .53512 .28694 L p
1 g
F P
s
P
p
.002 w
.62384 .3206 m .62391 .3613 L .64529 .37593 L p
1 g
F P
s
P
p
.002 w
.62391 .3613 m .62384 .3206 L .59934 .3131 L p
1 g
F P
s
P
p
.002 w
.39213 .30229 m .38123 .32552 L .40564 .32147 L p
1 g
F P
s
P
p
.002 w
.40564 .32147 m .41311 .30585 L .39213 .30229 L p
1 g
F P
s
P
p
.002 w
.66343 .39234 m .64462 .43877 L .65787 .45819 L p
1 g
F P
s
P
p
.002 w
.64462 .43877 m .66343 .39234 L .64529 .37593 L p
1 g
F P
s
P
p
.002 w
.35924 .33239 m .35742 .36314 L .37958 .34917 L p
1 g
F P
s
P
p
.002 w
.37958 .34917 m .38123 .32552 L .35924 .33239 L p
1 g
F P
s
P
p
.002 w
.53512 .28694 m .5171 .27113 L .49715 .28485 L p
1 g
F P
s
P
p
.002 w
.48068 .27879 m .49715 .28485 L .5171 .27113 L p
1 g
F P
s
P
p
.002 w
.5171 .27113 m .53512 .28694 L .5604 .28196 L p
1 g
F P
s
P
p
.002 w
.47688 .6015 m .5345 .59293 L .52779 .57575 L p
1 g
F P
s
P
p
.002 w
.52779 .57575 m .46952 .58427 L .47688 .6015 L p
1 g
F P
s
P
p
.002 w
.58324 .55378 m .52779 .57575 L .5345 .59293 L p
1 g
F P
s
P
p
.002 w
.5345 .59293 m .58938 .57119 L .58324 .55378 L p
1 g
F P
s
P
p
.002 w
.63122 .52015 m .58324 .55378 L .58938 .57119 L p
1 g
F P
s
P
p
.002 w
.32315 .39703 m .33793 .43472 L .35097 .41229 L p
1 g
F P
s
P
p
.002 w
.35097 .41229 m .33842 .37919 L .32315 .39703 L p
1 g
F P
s
P
p
.002 w
.3239 .48039 m .35835 .51376 L .3608 .48925 L p
1 g
F P
s
P
p
.002 w
.3608 .48925 m .32878 .4576 L .3239 .48039 L p
1 g
F P
s
P
p
.002 w
.41125 .28223 m .39213 .30229 L .41311 .30585 L p
1 g
F P
s
P
p
.002 w
.41311 .30585 m .42602 .29242 L .41125 .28223 L p
1 g
F P
s
P
p
.002 w
.5171 .27113 m .49274 .26199 L .48068 .27879 L p
1 g
F P
s
P
p
.002 w
.46188 .27806 m .48068 .27879 L .49274 .26199 L p
1 g
F P
s
P
p
.002 w
.58474 .2807 m .59934 .3131 L .62384 .3206 L p
1 g
F P
s
P
p
.002 w
.59934 .3131 m .58474 .2807 L .5604 .28196 L p
1 g
F P
s
P
p
.002 w
.64573 .33117 m .64529 .37593 L .66343 .39234 L p
1 g
F P
s
P
p
.002 w
.64529 .37593 m .64573 .33117 L .62384 .3206 L p
1 g
F P
s
P
p
.002 w
.43646 .2678 m .41125 .28223 L .42602 .29242 L p
1 g
F P
s
P
p
.002 w
.42602 .29242 m .44293 .28277 L .43646 .2678 L p
1 g
F P
s
P
p
.002 w
.42142 .59586 m .47688 .6015 L .46952 .58427 L p
1 g
F P
s
P
p
.002 w
.46952 .58427 m .41336 .5783 L .42142 .59586 L p
1 g
F P
s
P
p
.002 w
.36447 .55769 m .41336 .5783 L .40777 .55753 L p
1 g
F P
s
P
p
.002 w
.40777 .55753 m .35953 .53678 L .36447 .55769 L p
1 g
F P
s
P
p
.002 w
.49274 .26199 m .46476 .26079 L .46188 .27806 L p
1 g
F P
s
P
p
.002 w
.44293 .28277 m .46188 .27806 L .46476 .26079 L p
1 g
F P
s
P
p
.002 w
.34029 .34207 m .33842 .37919 L .35742 .36314 L p
1 g
F P
s
P
p
.002 w
.35742 .36314 m .35924 .33239 L .34029 .34207 L p
1 g
F P
s
P
p
.002 w
.46476 .26079 m .43646 .2678 L .44293 .28277 L p
1 g
F P
s
P
p
.002 w
.37328 .30198 m .35924 .33239 L .38123 .32552 L p
1 g
F P
s
P
p
.002 w
.38123 .32552 m .39213 .30229 L .37328 .30198 L p
1 g
F P
s
P
p
.002 w
.58938 .57119 m .63693 .53808 L .63122 .52015 L p
1 g
F P
s
P
p
.002 w
.66741 .47747 m .63122 .52015 L .63693 .53808 L p
1 g
F P
s
P
p
.002 w
.63122 .52015 m .66741 .47747 L .65787 .45819 L p
1 g
F P
s
P
p
.002 w
.67781 .4102 m .65787 .45819 L .66741 .47747 L p
1 g
F P
s
P
p
.002 w
.65787 .45819 m .67781 .4102 L .66343 .39234 L p
1 g
F P
s
P
p
.002 w
.5604 .28196 m .53716 .26116 L .5171 .27113 L p
1 g
F P
s
P
p
.002 w
.49274 .26199 m .5171 .27113 L .53716 .26116 L p
1 g
F P
s
P
p
.002 w
.53716 .26116 m .5604 .28196 L .58474 .2807 L p
1 g
F P
s
P
p
.002 w
.31214 .4163 m .32878 .4576 L .33793 .43472 L p
1 g
F P
s
P
p
.002 w
.33793 .43472 m .32315 .39703 L .31214 .4163 L p
1 g
F P
s
P
p
.002 w
.32359 .50255 m .35953 .53678 L .35835 .51376 L p
1 g
F P
s
P
p
.002 w
.35835 .51376 m .3239 .48039 L .32359 .50255 L p
1 g
F P
s
P
p
.002 w
.60753 .28336 m .62384 .3206 L .64573 .33117 L p
1 g
F P
s
P
p
.002 w
.62384 .3206 m .60753 .28336 L .58474 .2807 L p
1 g
F P
s
P
p
.002 w
.48513 .61484 m .54055 .60649 L .5345 .59293 L p
1 g
F P
s
P
p
.002 w
.5345 .59293 m .47688 .6015 L .48513 .61484 L p
1 g
F P
s
P
p
.002 w
.58938 .57119 m .5345 .59293 L .54055 .60649 L p
1 g
F P
s
P
p
.002 w
.54055 .60649 m .59341 .58556 L .58938 .57119 L p
1 g
F P
s
P
p
.002 w
.63693 .53808 m .58938 .57119 L .59341 .58556 L p
1 g
F P
s
P
p
.002 w
.39828 .27559 m .37328 .30198 L .39213 .30229 L p
1 g
F P
s
P
p
.002 w
.39213 .30229 m .41125 .28223 L .39828 .27559 L p
1 g
F P
s
P
p
.002 w
.66438 .34467 m .66343 .39234 L .67781 .4102 L p
1 g
F P
s
P
p
.002 w
.66343 .39234 m .66438 .34467 L .64573 .33117 L p
1 g
F P
s
P
p
.002 w
.53716 .26116 m .50541 .24904 L .49274 .26199 L p
1 g
F P
s
P
p
.002 w
.46476 .26079 m .49274 .26199 L .50541 .24904 L p
1 g
F P
s
P
p
.002 w
.32498 .35444 m .32315 .39703 L .33842 .37919 L p
1 g
F P
s
P
p
.002 w
.33842 .37919 m .34029 .34207 L .32498 .35444 L p
1 g
F P
s
P
p
.002 w
.37324 .57586 m .42142 .59586 L .41336 .5783 L p
1 g
F P
s
P
p
.002 w
.41336 .5783 m .36447 .55769 L .37324 .57586 L p
1 g
F P
s
P
p
.002 w
.35713 .3051 m .34029 .34207 L .35924 .33239 L p
1 g
F P
s
P
p
.002 w
.35924 .33239 m .37328 .30198 L .35713 .3051 L p
1 g
F P
s
P
p
.002 w
.55688 .25536 m .58474 .2807 L .60753 .28336 L p
1 g
F P
s
P
p
.002 w
.58474 .2807 m .55688 .25536 L .53716 .26116 L p
1 g
F P
s
P
p
.002 w
.43189 .60961 m .48513 .61484 L .47688 .6015 L p
1 g
F P
s
P
p
.002 w
.47688 .6015 m .42142 .59586 L .43189 .60961 L p
1 g
F P
s
P
p
.002 w
.43143 .25657 m .39828 .27559 L .41125 .28223 L p
1 g
F P
s
P
p
.002 w
.41125 .28223 m .43646 .2678 L .43143 .25657 L p
1 g
F P
s
P
p
.002 w
.50541 .24904 m .46868 .24736 L .46476 .26079 L p
1 g
F P
s
P
p
.002 w
.43646 .2678 m .46476 .26079 L .46868 .24736 L p
1 g
F P
s
P
p
.002 w
.30586 .43658 m .3239 .48039 L .32878 .4576 L p
1 g
F P
s
P
p
.002 w
.32878 .4576 m .31214 .4163 L .30586 .43658 L p
1 g
F P
s
P
p
.002 w
.50541 .24904 m .53716 .26116 L .55688 .25536 L p
1 g
F P
s
P
p
.002 w
.63693 .53808 m .67283 .49615 L .66741 .47747 L p
1 g
F P
s
P
p
.002 w
.68789 .42916 m .66741 .47747 L .67283 .49615 L p
1 g
F P
s
P
p
.002 w
.66741 .47747 m .68789 .42916 L .67781 .4102 L p
1 g
F P
s
P
p
.002 w
.59341 .58556 m .63921 .55381 L .63693 .53808 L p
1 g
F P
s
P
p
.002 w
.67283 .49615 m .63693 .53808 L .63921 .55381 L p
1 g
F P
s
P
p
.002 w
.46868 .24736 m .43143 .25657 L .43646 .2678 L p
1 g
F P
s
P
p
.002 w
.32808 .52345 m .36447 .55769 L .35953 .53678 L p
1 g
F P
s
P
p
.002 w
.35953 .53678 m .32359 .50255 L .32808 .52345 L p
1 g
F P
s
P
p
.002 w
.62816 .29005 m .64573 .33117 L .66438 .34467 L p
1 g
F P
s
P
p
.002 w
.64573 .33117 m .62816 .29005 L .60753 .28336 L p
1 g
F P
s
P
p
.002 w
.67918 .3609 m .67781 .4102 L .68789 .42916 L p
1 g
F P
s
P
p
.002 w
.67781 .4102 m .67918 .3609 L .66438 .34467 L p
1 g
F P
s
P
p
.002 w
.31391 .36934 m .31214 .4163 L .32315 .39703 L p
1 g
F P
s
P
p
.002 w
.32315 .39703 m .32498 .35444 L .31391 .36934 L p
1 g
F P
s
P
p
.002 w
.38753 .27286 m .35713 .3051 L .37328 .30198 L p
1 g
F P
s
P
p
.002 w
.37328 .30198 m .39828 .27559 L .38753 .27286 L p
1 g
F P
s
P
p
.002 w
.4941 .62372 m .54575 .61587 L .54055 .60649 L p
1 g
F P
s
P
p
.002 w
.54055 .60649 m .48513 .61484 L .4941 .62372 L p
1 g
F P
s
P
p
.002 w
.59341 .58556 m .54055 .60649 L .54575 .61587 L p
1 g
F P
s
P
p
.002 w
.54575 .61587 m .59508 .59635 L .59341 .58556 L p
1 g
F P
s
P
p
.002 w
.63921 .55381 m .59341 .58556 L .59508 .59635 L p
1 g
F P
s
P
p
.002 w
.55688 .25536 m .5184 .24047 L .50541 .24904 L p
1 g
F P
s
P
p
.002 w
.46868 .24736 m .50541 .24904 L .5184 .24047 L p
1 g
F P
s
P
p
.002 w
.57576 .25407 m .60753 .28336 L .62816 .29005 L p
1 g
F P
s
P
p
.002 w
.60753 .28336 m .57576 .25407 L .55688 .25536 L p
1 g
F P
s
P
p
.002 w
.34425 .31177 m .32498 .35444 L .34029 .34207 L p
1 g
F P
s
P
p
.002 w
.34029 .34207 m .35713 .3051 L .34425 .31177 L p
1 g
F P
s
P
p
.002 w
.30472 .45737 m .32359 .50255 L .3239 .48039 L p
1 g
F P
s
P
p
.002 w
.3239 .48039 m .30586 .43658 L .30472 .45737 L p
1 g
F P
s
P
p
.002 w
.38579 .59067 m .43189 .60961 L .42142 .59586 L p
1 g
F P
s
P
p
.002 w
.42142 .59586 m .37324 .57586 L .38579 .59067 L p
1 g
F P
s
P
p
.002 w
.5184 .24047 m .55688 .25536 L .57576 .25407 L p
1 g
F P
s
P
p
.002 w
.63921 .55381 m .67378 .51372 L .67283 .49615 L p
1 g
F P
s
P
p
.002 w
.69321 .44878 m .67283 .49615 L .67378 .51372 L p
1 g
F P
s
P
p
.002 w
.67283 .49615 m .69321 .44878 L .68789 .42916 L p
1 g
F P
s
P
p
.002 w
.44462 .61898 m .4941 .62372 L .48513 .61484 L p
1 g
F P
s
P
p
.002 w
.48513 .61484 m .43189 .60961 L .44462 .61898 L p
1 g
F P
s
P
p
.002 w
.42805 .24958 m .38753 .27286 L .39828 .27559 L p
1 g
F P
s
P
p
.002 w
.39828 .27559 m .43143 .25657 L .42805 .24958 L p
1 g
F P
s
P
p
.002 w
.64597 .30077 m .66438 .34467 L .67918 .3609 L p
1 g
F P
s
P
p
.002 w
.66438 .34467 m .64597 .30077 L .62816 .29005 L p
1 g
F P
s
P
p
.002 w
.5184 .24047 m .47362 .23834 L .46868 .24736 L p
1 g
F P
s
P
p
.002 w
.43143 .25657 m .46868 .24736 L .47362 .23834 L p
1 g
F P
s
P
p
.002 w
.33748 .54249 m .37324 .57586 L .36447 .55769 L p
1 g
F P
s
P
p
.002 w
.36447 .55769 m .32808 .52345 L .33748 .54249 L p
1 g
F P
s
P
p
.002 w
.59508 .59635 m .63782 .56682 L .63921 .55381 L p
1 g
F P
s
P
p
.002 w
.67378 .51372 m .63921 .55381 L .63782 .56682 L p
1 g
F P
s
P
p
.002 w
.47362 .23834 m .42805 .24958 L .43143 .25657 L p
1 g
F P
s
P
p
.002 w
.68956 .37957 m .68789 .42916 L .69321 .44878 L p
1 g
F P
s
P
p
.002 w
.68789 .42916 m .68956 .37957 L .67918 .3609 L p
1 g
F P
s
P
p
.002 w
.30761 .38647 m .30586 .43658 L .31214 .4163 L p
1 g
F P
s
P
p
.002 w
.31214 .4163 m .31391 .36934 L .30761 .38647 L p
1 g
F P
s
P
p
.002 w
.37943 .27438 m .34425 .31177 L .35713 .3051 L p
1 g
F P
s
P
p
.002 w
.35713 .3051 m .38753 .27286 L .37943 .27438 L p
1 g
F P
s
P
p
.002 w
.59324 .25757 m .62816 .29005 L .64597 .30077 L p
1 g
F P
s
P
p
.002 w
.62816 .29005 m .59324 .25757 L .57576 .25407 L p
1 g
F P
s
P
p
.002 w
.30902 .47812 m .32808 .52345 L .32359 .50255 L p
1 g
F P
s
P
p
.002 w
.32359 .50255 m .30472 .45737 L .30902 .47812 L p
1 g
F P
s
P
p
.002 w
.33519 .32201 m .31391 .36934 L .32498 .35444 L p
1 g
F P
s
P
p
.002 w
.32498 .35444 m .34425 .31177 L .33519 .32201 L p
1 g
F P
s
P
p
.002 w
.50361 .62765 m .54993 .62057 L .54575 .61587 L p
1 g
F P
s
P
p
.002 w
.54575 .61587 m .4941 .62372 L .50361 .62765 L p
1 g
F P
s
P
p
.002 w
.59508 .59635 m .54575 .61587 L .54993 .62057 L p
1 g
F P
s
P
p
.002 w
.57576 .25407 m .53141 .23677 L .5184 .24047 L p
1 g
F P
s
P
p
.002 w
.47362 .23834 m .5184 .24047 L .53141 .23677 L p
1 g
F P
s
P
p
.002 w
.54993 .62057 m .59422 .60305 L .59508 .59635 L p
1 g
F P
s
P
p
.002 w
.63782 .56682 m .59508 .59635 L .59422 .60305 L p
1 g
F P
s
P
p
.002 w
.40198 .60154 m .44462 .61898 L .43189 .60961 L p
1 g
F P
s
P
p
.002 w
.43189 .60961 m .38579 .59067 L .40198 .60154 L p
1 g
F P
s
P
p
.002 w
.53141 .23677 m .57576 .25407 L .59324 .25757 L p
1 g
F P
s
P
p
.002 w
.66035 .31546 m .67918 .3609 L .68956 .37957 L p
1 g
F P
s
P
p
.002 w
.67918 .3609 m .66035 .31546 L .64597 .30077 L p
1 g
F P
s
P
p
.002 w
.63782 .56682 m .67 .52968 L .67378 .51372 L p
1 g
F P
s
P
p
.002 w
.6934 .46859 m .67378 .51372 L .67 .52968 L p
1 g
F P
s
P
p
.002 w
.67378 .51372 m .6934 .46859 L .69321 .44878 L p
1 g
F P
s
P
p
.002 w
.35177 .55901 m .38579 .59067 L .37324 .57586 L p
1 g
F P
s
P
p
.002 w
.37324 .57586 m .33748 .54249 L .35177 .55901 L p
1 g
F P
s
P
p
.002 w
.4594 .62344 m .50361 .62765 L .4941 .62372 L p
1 g
F P
s
P
p
.002 w
.4941 .62372 m .44462 .61898 L .4594 .62344 L p
1 g
F P
s
P
p
.002 w
.42652 .24731 m .37943 .27438 L .38753 .27286 L p
1 g
F P
s
P
p
.002 w
.38753 .27286 m .42805 .24958 L .42652 .24731 L p
1 g
F P
s
P
p
.002 w
.59422 .60305 m .63255 .57661 L .63782 .56682 L p
1 g
F P
s
P
p
.002 w
.67 .52968 m .63782 .56682 L .63255 .57661 L p
1 g
F P
s
P
p
.002 w
.53141 .23677 m .47949 .23425 L .47362 .23834 L p
1 g
F P
s
P
p
.002 w
.42805 .24958 m .47362 .23834 L .47949 .23425 L p
1 g
F P
s
P
p
.002 w
.69502 .40028 m .69321 .44878 L .6934 .46859 L p
1 g
F P
s
P
p
.002 w
.69321 .44878 m .69502 .40028 L .68956 .37957 L p
1 g
F P
s
P
p
.002 w
.30652 .40549 m .30472 .45737 L .30586 .43658 L p
1 g
F P
s
P
p
.002 w
.30586 .43658 m .30761 .38647 L .30652 .40549 L p
1 g
F P
s
P
p
.002 w
.47949 .23425 m .42652 .24731 L .42805 .24958 L p
1 g
F P
s
P
p
.002 w
.64597 .30077 m .60878 .26603 L .59324 .25757 L p
1 g
F P
s
P
p
.002 w
.60878 .26603 m .64597 .30077 L .66035 .31546 L p
1 g
F P
s
P
p
.002 w
.3189 .49821 m .33748 .54249 L .32808 .52345 L p
1 g
F P
s
P
p
.002 w
.32808 .52345 m .30902 .47812 L .3189 .49821 L p
1 g
F P
s
P
p
.004 w
.6965 .42796 m
.71243 .42776 L
s
P
p
.004 w
.71243 .42776 m
.77821 .4269 L
s
P
p
.002 w
.37438 .28037 m .33519 .32201 L .34425 .31177 L p
1 g
F P
s
P
p
.002 w
.34425 .31177 m .37943 .27438 L .37438 .28037 L p
1 g
F P
s
P
p
.002 w
.33044 .33575 m .30761 .38647 L .31391 .36934 L p
1 g
F P
s
P
p
.002 w
.31391 .36934 m .33519 .32201 L .33044 .33575 L p
1 g
F P
s
P
p
.002 w
.59324 .25757 m .54408 .23833 L .53141 .23677 L p
1 g
F P
s
P
p
.002 w
.47949 .23425 m .53141 .23677 L .54408 .23833 L p
1 g
F P
s
P
p
.002 w
.68956 .37957 m .67072 .3339 L .66035 .31546 L p
1 g
F P
s
P
p
.002 w
.67072 .3339 m .68956 .37957 L .69502 .40028 L p
1 g
F P
s
P
p
.002 w
.42154 .60794 m .4594 .62344 L .44462 .61898 L p
1 g
F P
s
P
p
.002 w
.44462 .61898 m .40198 .60154 L .42154 .60794 L p
1 g
F P
s
P
p
.002 w
.54408 .23833 m .59324 .25757 L .60878 .26603 L p
1 g
F P
s
P
p
.002 w
.51342 .62619 m .5529 .62016 L .54993 .62057 L p
1 g
F P
s
P
p
.002 w
.54993 .62057 m .50361 .62765 L .51342 .62619 L p
1 g
F P
s
P
p
.002 w
.59422 .60305 m .54993 .62057 L .5529 .62016 L p
1 g
F P
s
P
p
.002 w
.5529 .62016 m .59069 .60521 L .59422 .60305 L p
1 g
F P
s
P
p
.002 w
.63255 .57661 m .59422 .60305 L .59069 .60521 L p
1 g
F P
s
P
p
.002 w
.37077 .5724 m .40198 .60154 L .38579 .59067 L p
1 g
F P
s
P
p
.002 w
.38579 .59067 m .35177 .55901 L .37077 .5724 L p
1 g
F P
s
P
p
.002 w
.63255 .57661 m .66131 .54347 L .67 .52968 L p
1 g
F P
s
P
p
.002 w
.67 .52968 m .68817 .48803 L .6934 .46859 L p
1 g
F P
s
P
p
.002 w
.68817 .48803 m .67 .52968 L .66131 .54347 L p
1 g
F P
s
P
p
.002 w
.6934 .46859 m .69514 .42253 L .69502 .40028 L p
1 g
F P
s
P
p
.002 w
.69514 .42253 m .6934 .46859 L .68817 .48803 L p
1 g
F P
s
P
p
.002 w
.31097 .42591 m .30902 .47812 L .30472 .45737 L p
1 g
F P
s
P
p
.002 w
.30472 .45737 m .30652 .40549 L .31097 .42591 L p
1 g
F P
s
P
p
.002 w
.47591 .6226 m .51342 .62619 L .50361 .62765 L p
1 g
F P
s
P
p
.002 w
.50361 .62765 m .4594 .62344 L .47591 .6226 L p
1 g
F P
s
P
p
.002 w
.427 .25014 m .37438 .28037 L .37943 .27438 L p
1 g
F P
s
P
p
.002 w
.37943 .27438 m .42652 .24731 L .427 .25014 L p
1 g
F P
s
P
p
.002 w
.59069 .60521 m .62333 .58269 L .63255 .57661 L p
1 g
F P
s
P
p
.002 w
.66131 .54347 m .63255 .57661 L .62333 .58269 L p
1 g
F P
s
P
p
.002 w
.54408 .23833 m .4862 .23553 L .47949 .23425 L p
1 g
F P
s
P
p
.002 w
.42652 .24731 m .47949 .23425 L .4862 .23553 L p
1 g
F P
s
P
p
.002 w
.6218 .27948 m .66035 .31546 L .67072 .3339 L p
1 g
F P
s
P
p
.002 w
.66035 .31546 m .6218 .27948 L .60878 .26603 L p
1 g
F P
s
P
p
.002 w
.33434 .51698 m .35177 .55901 L .33748 .54249 L p
1 g
F P
s
P
p
.002 w
.33748 .54249 m .3189 .49821 L .33434 .51698 L p
1 g
F P
s
P
p
.002 w
.4862 .23553 m .427 .25014 L .42652 .24731 L p
1 g
F P
s
P
p
.002 w
.33042 .35277 m .30652 .40549 L .30761 .38647 L p
1 g
F P
s
P
p
.002 w
.30761 .38647 m .33044 .33575 L .33042 .35277 L p
1 g
F P
s
P
p
.002 w
.67654 .35572 m .69502 .40028 L .69514 .42253 L p
1 g
F P
s
P
p
.002 w
.69502 .40028 m .67654 .35572 L .67072 .3339 L p
1 g
F P
s
P
p
.002 w
.37273 .29094 m .33044 .33575 L .33519 .32201 L p
1 g
F P
s
P
p
.002 w
.33519 .32201 m .37438 .28037 L .37273 .29094 L p
1 g
F P
s
P
p
.002 w
.556 .24542 m .60878 .26603 L .6218 .27948 L p
1 g
F P
s
P
p
.002 w
.60878 .26603 m .556 .24542 L .54408 .23833 L p
1 g
F P
s
P
p
.002 w
.4862 .23553 m .54408 .23833 L .556 .24542 L p
1 g
F P
s
P
p
.002 w
.44403 .60942 m .47591 .6226 L .4594 .62344 L p
1 g
F P
s
P
p
.002 w
.4594 .62344 m .42154 .60794 L .44403 .60942 L p
1 g
F P
s
P
p
.002 w
.39412 .58208 m .42154 .60794 L .40198 .60154 L p
1 g
F P
s
P
p
.002 w
.40198 .60154 m .37077 .5724 L .39412 .58208 L p
1 g
F P
s
P
p
.002 w
.62333 .58269 m .64768 .55457 L .66131 .54347 L p
1 g
F P
s
P
p
.002 w
.67739 .5065 m .66131 .54347 L .64768 .55457 L p
1 g
F P
s
P
p
.002 w
.66131 .54347 m .67739 .5065 L .68817 .48803 L p
1 g
F P
s
P
p
.002 w
.52326 .61904 m .55448 .6143 L .5529 .62016 L p
1 g
F P
s
P
p
.002 w
.5529 .62016 m .51342 .62619 L .52326 .61904 L p
1 g
F P
s
P
p
.002 w
.59069 .60521 m .5529 .62016 L .55448 .6143 L p
1 g
F P
s
P
p
.004 w
.57013 .61775 m
.57898 .64139 L
s
P
p
.002 w
.55448 .6143 m .5844 .60246 L .59069 .60521 L p
1 g
F P
s
P
p
.002 w
.62333 .58269 m .59069 .60521 L .5844 .60246 L p
1 g
F P
s
P
p
.002 w
.3211 .44715 m .3189 .49821 L .30902 .47812 L p
1 g
F P
s
P
p
.002 w
.30902 .47812 m .31097 .42591 L .3211 .44715 L p
1 g
F P
s
P
p
.002 w
.68966 .44574 m .68817 .48803 L .67739 .5065 L p
1 g
F P
s
P
p
.002 w
.68817 .48803 m .68966 .44574 L .69514 .42253 L p
1 g
F P
s
P
p
.002 w
.3551 .53378 m .37077 .5724 L .35177 .55901 L p
1 g
F P
s
P
p
.002 w
.35177 .55901 m .33434 .51698 L .3551 .53378 L p
1 g
F P
s
P
p
.002 w
.63177 .29778 m .67072 .3339 L .67654 .35572 L p
1 g
F P
s
P
p
.002 w
.67072 .3339 m .63177 .29778 L .6218 .27948 L p
1 g
F P
s
P
p
.002 w
.49374 .61615 m .52326 .61904 L .51342 .62619 L p
1 g
F P
s
P
p
.002 w
.51342 .62619 m .47591 .6226 L .49374 .61615 L p
1 g
F P
s
P
p
.002 w
.5844 .60246 m .61017 .58464 L .62333 .58269 L p
1 g
F P
s
P
p
.002 w
.64768 .55457 m .62333 .58269 L .61017 .58464 L p
1 g
F P
s
P
p
.002 w
.42962 .25831 m .37273 .29094 L .37438 .28037 L p
1 g
F P
s
P
p
.002 w
.37438 .28037 m .427 .25014 L .42962 .25831 L p
1 g
F P
s
P
p
.002 w
.556 .24542 m .4936 .24249 L .4862 .23553 L p
1 g
F P
s
P
p
.002 w
.427 .25014 m .4862 .23553 L .4936 .24249 L p
1 g
F P
s
P
p
.002 w
.67742 .3804 m .69514 .42253 L .68966 .44574 L p
1 g
F P
s
P
p
.002 w
.69514 .42253 m .67742 .3804 L .67654 .35572 L p
1 g
F P
s
P
p
.002 w
.33539 .37272 m .31097 .42591 L .30652 .40549 L p
1 g
F P
s
P
p
.002 w
.30652 .40549 m .33042 .35277 L .33539 .37272 L p
1 g
F P
s
P
p
.002 w
.4936 .24249 m .42962 .25831 L .427 .25014 L p
1 g
F P
s
P
p
.002 w
.37476 .30605 m .33042 .35277 L .33044 .33575 L p
1 g
F P
s
P
p
.002 w
.33044 .33575 m .37273 .29094 L .37476 .30605 L p
1 g
F P
s
P
p
.002 w
.56678 .25817 m .6218 .27948 L .63177 .29778 L p
1 g
F P
s
P
p
.002 w
.6218 .27948 m .56678 .25817 L .556 .24542 L p
1 g
F P
s
P
p
.002 w
.42124 .58757 m .44403 .60942 L .42154 .60794 L p
1 g
F P
s
P
p
.002 w
.42154 .60794 m .39412 .58208 L .42124 .58757 L p
1 g
F P
s
P
p
.002 w
.46888 .60571 m .49374 .61615 L .47591 .6226 L p
1 g
F P
s
P
p
.002 w
.47591 .6226 m .44403 .60942 L .46888 .60571 L p
1 g
F P
s
P
p
.002 w
.4936 .24249 m .556 .24542 L .56678 .25817 L p
1 g
F P
s
P
p
.002 w
.33685 .46855 m .33434 .51698 L .3189 .49821 L p
1 g
F P
s
P
p
.002 w
.3189 .49821 m .3211 .44715 L .33685 .46855 L p
1 g
F P
s
P
p
.002 w
.64768 .55457 m .66111 .52339 L .67739 .5065 L p
1 g
F P
s
P
p
.002 w
.67848 .4692 m .67739 .5065 L .66111 .52339 L p
1 g
F P
s
P
p
.002 w
.67739 .5065 m .67848 .4692 L .68966 .44574 L p
1 g
F P
s
P
p
.002 w
.61017 .58464 m .62926 .56248 L .64768 .55457 L p
1 g
F P
s
P
p
.002 w
.66111 .52339 m .64768 .55457 L .62926 .56248 L p
1 g
F P
s
P
p
.002 w
.38071 .54795 m .39412 .58208 L .37077 .5724 L p
1 g
F P
s
P
p
.002 w
.37077 .5724 m .3551 .53378 L .38071 .54795 L p
1 g
F P
s
P
p
.002 w
.6382 .3206 m .67654 .35572 L .67742 .3804 L p
1 g
F P
s
P
p
.002 w
.67654 .35572 m .6382 .3206 L .63177 .29778 L p
1 g
F P
s
P
p
.002 w
.53282 .60608 m .55453 .60281 L .55448 .6143 L p
1 g
F P
s
P
p
.002 w
.55448 .6143 m .52326 .61904 L .53282 .60608 L p
1 g
F P
s
P
p
.002 w
.5844 .60246 m .55448 .6143 L .55453 .60281 L p
1 g
F P
s
P
p
.002 w
.55453 .60281 m .57537 .59456 L .5844 .60246 L p
1 g
F P
s
P
p
.002 w
.61017 .58464 m .5844 .60246 L .57537 .59456 L p
1 g
F P
s
P
p
.002 w
.6731 .40729 m .68966 .44574 L .67848 .4692 L p
1 g
F P
s
P
p
.002 w
.68966 .44574 m .6731 .40729 L .67742 .3804 L p
1 g
F P
s
P
p
.004 w
.68795 .42807 m
.6965 .42796 L
s
P
p
.002 w
.5124 .60399 m .53282 .60608 L .52326 .61904 L p
1 g
F P
s
P
p
.002 w
.52326 .61904 m .49374 .61615 L .5124 .60399 L p
1 g
F P
s
P
p
.002 w
.57537 .59456 m .59326 .58215 L .61017 .58464 L p
1 g
F P
s
P
p
.002 w
.62926 .56248 m .61017 .58464 L .59326 .58215 L p
1 g
F P
s
P
p
.002 w
.34546 .39508 m .3211 .44715 L .31097 .42591 L p
1 g
F P
s
P
p
.002 w
.31097 .42591 m .33539 .37272 L .34546 .39508 L p
1 g
F P
s
P
p
.002 w
.43443 .27192 m .37476 .30605 L .37273 .29094 L p
1 g
F P
s
P
p
.002 w
.37273 .29094 m .42962 .25831 L .43443 .27192 L p
1 g
F P
s
P
p
.002 w
.56678 .25817 m .5015 .25528 L .4936 .24249 L p
1 g
F P
s
P
p
.002 w
.42962 .25831 m .4936 .24249 L .5015 .25528 L p
1 g
F P
s
P
p
.002 w
.45137 .58853 m .46888 .60571 L .44403 .60942 L p
1 g
F P
s
P
p
.002 w
.44403 .60942 m .42124 .58757 L .45137 .58853 L p
1 g
F P
s
P
p
.002 w
.57598 .2765 m .63177 .29778 L .6382 .3206 L p
1 g
F P
s
P
p
.002 w
.63177 .29778 m .57598 .2765 L .56678 .25817 L p
1 g
F P
s
P
p
.002 w
.35792 .48938 m .3551 .53378 L .33434 .51698 L p
1 g
F P
s
P
p
.002 w
.33434 .51698 m .33685 .46855 L .35792 .48938 L p
1 g
F P
s
P
p
.002 w
.38061 .32547 m .33539 .37272 L .33042 .35277 L p
1 g
F P
s
P
p
.002 w
.33042 .35277 m .37476 .30605 L .38061 .32547 L p
1 g
F P
s
P
p
.002 w
.5015 .25528 m .43443 .27192 L .42962 .25831 L p
1 g
F P
s
P
p
.002 w
.62926 .56248 m .63959 .53806 L .66111 .52339 L p
1 g
F P
s
P
p
.002 w
.66173 .49216 m .66111 .52339 L .63959 .53806 L p
1 g
F P
s
P
p
.002 w
.66111 .52339 m .66173 .49216 L .67848 .4692 L p
1 g
F P
s
P
p
.002 w
.49536 .59668 m .5124 .60399 L .49374 .61615 L p
1 g
F P
s
P
p
.002 w
.49374 .61615 m .46888 .60571 L .49536 .59668 L p
1 g
F P
s
P
p
.002 w
.41045 .55891 m .42124 .58757 L .39412 .58208 L p
1 g
F P
s
P
p
.002 w
.39412 .58208 m .38071 .54795 L .41045 .55891 L p
1 g
F P
s
P
p
.002 w
.5015 .25528 m .56678 .25817 L .57598 .2765 L p
1 g
F P
s
P
p
.002 w
.59326 .58215 m .60639 .56677 L .62926 .56248 L p
1 g
F P
s
P
p
.002 w
.63959 .53806 m .62926 .56248 L .60639 .56677 L p
1 g
F P
s
P
p
.002 w
.64071 .3474 m .67742 .3804 L .6731 .40729 L p
1 g
F P
s
P
p
.002 w
.67742 .3804 m .64071 .3474 L .6382 .3206 L p
1 g
F P
s
P
p
.002 w
.66351 .43555 m .67848 .4692 L .66173 .49216 L p
1 g
F P
s
P
p
.002 w
.67848 .4692 m .66351 .43555 L .6731 .40729 L p
1 g
F P
s
P
p
.004 w
.67646 .42822 m
.67784 .42821 L
s
P
p
.004 w
.5 .43051 m
.66595 .42836 L
s
P
p
.004 w
.67784 .42821 m
.68795 .42807 L
s
P
p
.002 w
.54176 .58739 m .55297 .58573 L .55453 .60281 L p
1 g
F P
s
P
p
.002 w
.55453 .60281 m .53282 .60608 L .54176 .58739 L p
1 g
F P
s
P
p
.002 w
.57537 .59456 m .55453 .60281 L .55297 .58573 L p
1 g
F P
s
P
p
.002 w
.55297 .58573 m .56373 .58146 L .57537 .59456 L p
1 g
F P
s
P
p
.002 w
.59326 .58215 m .57537 .59456 L .56373 .58146 L p
1 g
F P
s
P
p
.002 w
.36052 .41917 m .33685 .46855 L .3211 .44715 L p
1 g
F P
s
P
p
.002 w
.3211 .44715 m .34546 .39508 L .36052 .41917 L p
1 g
F P
s
P
p
.002 w
.53128 .58626 m .54176 .58739 L .53282 .60608 L p
1 g
F P
s
P
p
.002 w
.53282 .60608 m .5124 .60399 L .53128 .58626 L p
1 g
F P
s
P
p
.002 w
.56373 .58146 m .57294 .57504 L .59326 .58215 L p
1 g
F P
s
P
p
.002 w
.60639 .56677 m .59326 .58215 L .57294 .57504 L p
1 g
F P
s
P
p
.002 w
.48357 .58477 m .49536 .59668 L .46888 .60571 L p
1 g
F P
s
P
p
.002 w
.46888 .60571 m .45137 .58853 L .48357 .58477 L p
1 g
F P
s
P
p
.002 w
.38375 .50887 m .38071 .54795 L .3551 .53378 L p
1 g
F P
s
P
p
.002 w
.3551 .53378 m .35792 .48938 L .38375 .50887 L p
1 g
F P
s
P
p
.002 w
.58322 .30007 m .6382 .3206 L .64071 .3474 L p
1 g
F P
s
P
p
.002 w
.6382 .3206 m .58322 .30007 L .57598 .2765 L p
1 g
F P
s
P
p
.002 w
.4414 .29083 m .38061 .32547 L .37476 .30605 L p
1 g
F P
s
P
p
.002 w
.37476 .30605 m .43443 .27192 L .4414 .29083 L p
1 g
F P
s
P
p
.002 w
.60639 .56677 m .61333 .54994 L .63959 .53806 L p
1 g
F P
s
P
p
.002 w
.63977 .51382 m .63959 .53806 L .61333 .54994 L p
1 g
F P
s
P
p
.002 w
.63959 .53806 m .63977 .51382 L .66173 .49216 L p
1 g
F P
s
P
p
.002 w
.4434 .56618 m .45137 .58853 L .42124 .58757 L p
1 g
F P
s
P
p
.002 w
.42124 .58757 m .41045 .55891 L .4434 .56618 L p
1 g
F P
s
P
p
.002 w
.57598 .2765 m .50965 .27381 L .5015 .25528 L p
1 g
F P
s
P
p
.002 w
.43443 .27192 m .5015 .25528 L .50965 .27381 L p
1 g
F P
s
P
p
.002 w
.63904 .3774 m .6731 .40729 L .66351 .43555 L p
1 g
F P
s
P
p
.002 w
.6731 .40729 m .63904 .3774 L .64071 .3474 L p
1 g
F P
s
P
p
.002 w
.39029 .34873 m .34546 .39508 L .33539 .37272 L p
1 g
F P
s
P
p
.002 w
.33539 .37272 m .38061 .32547 L .39029 .34873 L p
1 g
F P
s
P
p
.002 w
.52263 .58243 m .53128 .58626 L .5124 .60399 L p
1 g
F P
s
P
p
.002 w
.5124 .60399 m .49536 .59668 L .52263 .58243 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.6488 .46425 m .66173 .49216 L .63977 .51382 L p
1 g
F P
s
P
p
.002 w
.66173 .49216 m .6488 .46425 L .66351 .43555 L p
1 g
F P
s
P
p
.002 w
.57294 .57504 m .57962 .5671 L .60639 .56677 L p
1 g
F P
s
P
p
.002 w
.61333 .54994 m .60639 .56677 L .57962 .5671 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.50965 .27381 m .57598 .2765 L .58322 .30007 L p
1 g
F P
s
P
p
.002 w
.50965 .27381 m .4414 .29083 L .43443 .27192 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53891 .53439 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.3802 .44418 m .35792 .48938 L .33685 .46855 L p
1 g
F P
s
P
p
.002 w
.33685 .46855 m .36052 .41917 L .3802 .44418 L p
1 g
F P
s
P
p
.002 w
.41355 .52627 m .41045 .55891 L .38071 .54795 L p
1 g
F P
s
P
p
.002 w
.38071 .54795 m .38375 .50887 L .41355 .52627 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52263 .58243 m .49536 .59668 L p
.51209 .58073 L 1 g
F P
s
P
p
.002 w
.51095 .58075 m .51079 .57862 L p
.49947 .58088 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.49536 .59668 m .48357 .58477 L .49875 .58089 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58078 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58078 L .4909 .5808 L 1 g
F
P
p
.002 w
.48357 .58477 m .48221 .58071 L p
.48905 .58078 L 1 g
F P
s
P
p
.49047 .58111 m .48905 .58078 L .49104 .58081 L 1 g
F
P
p
.48357 .58477 m .48905 .58078 L .49047 .58111 L 1 g
F
P
p
.002 w
.48905 .58078 m .48921 .57862 L p
.47766 .57767 L 1 g
F P
s
P
p
.002 w
.48167 .57908 m .48357 .58477 L p
.47037 .57511 L 1 g
F P
s
P
p
.47766 .57767 m .47442 .57741 L .48167 .57908 L 1 g
F
P
p
.47766 .57767 m .48167 .57908 L .48905 .58078 L 1 g
F
P
p
.002 w
.48357 .58477 m .45137 .58853 L p
.47037 .57511 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .5744 L p
1 g
F P
s
P
p
.45137 .58853 m .44545 .56637 L .46834 .5744 L 1 g
F
P
p
.46997 .5754 m .46834 .5744 L .47037 .57511 L 1 g
F
P
p
.45137 .58853 m .46834 .5744 L .46997 .5754 L 1 g
F
P
p
.002 w
.46834 .5744 m .46872 .57265 L p
.45942 .56893 L 1 g
F P
s
P
p
.48921 .57862 m .46834 .5744 L .47533 .57686 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.47037 .57511 m .46834 .5744 L .47844 .56942 L 1 g
F
P
p
.002 w
.44545 .56637 m .45697 .56743 L p
.46834 .5744 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56308 L p
1 g
F P
s
P
p
.002 w
.45697 .56743 m .45417 .56717 L p
.4511 .5633 L 1 g
F P
s
P
p
.002 w
.45417 .56717 m .4434 .56618 L p
.451 .56333 L 1 g
F P
s
P
p
.451 .56333 m .4511 .5633 L .45417 .56717 L 1 g
F
P
p
.002 w
.4434 .56618 m .41045 .55891 L p
.43736 .54538 L 1 g
F P
s
P
p
.43736 .54538 m .43853 .54702 L .4434 .56618 L 1 g
F
P
p
.002 w
.4446 .55558 m .44384 .56225 L p
.43853 .54702 L 1 g
F P
s
P
p
.002 w
.44384 .56225 m .4434 .56618 L p
.43853 .54702 L 1 g
F P
s
P
p
.002 w
.43853 .54702 m .43925 .54566 L p
.43537 .53799 L 1 g
F P
s
P
p
.002 w
.45079 .56308 m .45146 .56129 L p
.44413 .55492 L 1 g
F P
s
P
p
.44413 .55492 m .44386 .55469 L .4446 .55558 L 1 g
F
P
p
.44413 .55492 m .4446 .55558 L .45079 .56308 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43814 .54776 L p
1 g
F P
s
P
p
.002 w
.43814 .54776 m .43743 .5491 L p
.44386 .55469 L 1 g
F P
s
P
p
.45146 .56129 m .43814 .54776 L .44386 .55469 L 1 g
F
P
p
.46872 .57265 m .45079 .56308 L .45351 .56499 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44627 .54091 m .48073 .55221 L p
.451 .56333 L 1 g
F P
s
P
p
.002 w
.4434 .56618 m .4446 .55558 L p
.451 .56333 L 1 g
F P
s
P
p
.002 w
.4446 .55558 m .44627 .54091 L p
.451 .56333 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4327 .52844 L p
1 g
F P
s
P
p
.43925 .54566 m .4327 .52844 L .43382 .53277 L 1 g
F
P
p
.41355 .52627 m .4311 .52222 L .4327 .52844 L 1 g
F
P
p
.002 w
.43456 .53567 m .43224 .53463 L p
.4327 .52844 L 1 g
F P
s
P
p
.002 w
.43224 .53463 m .41355 .52627 L p
.4327 .52844 L 1 g
F P
s
P
p
.002 w
.4327 .52844 m .43346 .52734 L p
.43325 .52121 L 1 g
F P
s
P
p
.43925 .54566 m .43382 .53277 L .43537 .53799 L 1 g
F
P
p
.43382 .53277 m .43226 .52908 L .43456 .53567 L 1 g
F
P
p
.43382 .53277 m .43456 .53567 L .43537 .53799 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43416 .50908 L p
1 g
F P
s
P
p
.43346 .52734 m .43416 .50908 L .43325 .52121 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.41355 .52627 m .4309 .4933 L .43872 .49926 L p
1 g
F P
s
P
p
.002 w
.43416 .50908 m .43485 .50826 L p
.43849 .49975 L 1 g
F P
s
P
p
.41355 .52627 m .43872 .49926 L .4277 .52301 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44271 .49123 L p
1 g
F P
s
P
p
.002 w
.43872 .49926 m .4309 .4933 L p
.4417 .49326 L 1 g
F P
s
P
p
.43485 .50826 m .44271 .49123 L .43859 .49952 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.4417 .49326 m .44363 .49033 L .48357 .4931 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44363 .49033 m .45777 .47662 L .48357 .4931 L 1 g
F
P
p
.002 w
.45777 .47662 m .45826 .47608 L p
.46822 .47171 L 1 g
F P
s
P
p
.47645 .46765 m .51406 .47639 L .46729 .47217 L 1 g
F
P
p
.46822 .47171 m .46911 .47132 L .46729 .47217 L 1 g
F
P
p
.46822 .47171 m .46729 .47217 L .45777 .47662 L 1 g
F
P
p
.002 w
.51406 .47639 m .48357 .4931 L .46729 .47217 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46098 .46405 m .50038 .44231 L .50491 .45359 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47645 .46765 m .47762 .46707 L .51406 .47639 L 1 g
F
P
p
.47762 .46707 m .5 .46378 L .51406 .47639 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46713 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51406 .47639 m .50964 .46537 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .4767 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.53182 .47173 m .54231 .4767 L .55006 .50263 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56611 .5094 L p
1 g
F P
s
P
p
.002 w
.57245 .50247 m .56852 .51456 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.5629 .50254 m .56557 .50252 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.56557 .50252 m .57245 .50247 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.56611 .5094 m .56515 .50826 L p
.56691 .51969 L 1 g
F P
s
P
p
.002 w
.5669 .51952 m .57245 .50247 L p
.57056 .51711 L 1 g
F P
s
P
p
.57056 .51711 m .56805 .5365 L .56753 .52878 L 1 g
F
P
p
.57056 .51711 m .56753 .52878 L .5669 .51952 L 1 g
F
P
p
.002 w
.56753 .52878 m .56654 .52734 L p
.56425 .53988 L 1 g
F P
s
P
p
.002 w
.57171 .53752 m .56032 .55089 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.56569 .53583 m .56937 .53687 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.56937 .53687 m .57171 .53752 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.56161 .54728 m .56075 .54566 L p
.55486 .55634 L 1 g
F P
s
P
p
.56425 .53988 m .56569 .53583 L .56753 .52878 L 1 g
F
P
p
.002 w
.56032 .55089 m .54974 .56331 L p
.55 .56286 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5494 .56359 L p
1 g
F P
s
P
p
.002 w
.5495 .56348 m .54974 .56331 L p
.54959 .56347 L 1 g
F P
s
P
p
.52891 .58521 m .5494 .56359 L .54959 .56347 L 1 g
F
P
p
.5494 .56359 m .5495 .56348 L .54959 .56347 L 1 g
F
P
p
.002 w
.54974 .56331 m .53128 .58626 L .52891 .58521 L p
1 g
F P
s
P
p
.002 w
.5494 .56359 m .54854 .56129 L p
.53987 .56955 L 1 g
F P
s
P
p
.002 w
.52263 .58243 m .52137 .58112 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.54892 .56389 m .53557 .57331 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53557 .57331 m .52263 .58243 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53172 .57465 m .53128 .57265 L p
.51872 .5791 L 1 g
F P
s
P
p
.002 w
.51932 .57897 m .5209 .58063 L p
.5124 .58044 L 1 g
F P
s
P
p
.51872 .5791 m .51823 .57935 L .51932 .57897 L 1 g
F
P
p
.51872 .5791 m .51932 .57897 L .53172 .57465 L 1 g
F
P
p
.51209 .58073 m .5124 .58044 L .5209 .58063 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58075 L p
1 g
F P
s
P
p
.51209 .58073 m .51095 .58075 L .5124 .58044 L 1 g
F
P
p
.49536 .59668 m .49875 .58089 L .51209 .58073 L 1 g
F
P
p
.002 w
.5209 .58063 m .52263 .58243 L p
.51209 .58073 L 1 g
F P
s
P
p
.002 w
.51095 .58075 m .51103 .58185 L p
.51568 .57974 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58075 L .51568 .57974 L 1 g
F
P
p
.51079 .57862 m .50525 .57923 L .49956 .58086 L 1 g
F
P
p
.002 w
.49875 .58089 m .48357 .58477 L p
.49104 .58081 L 1 g
F P
s
P
p
.50525 .57923 m .48903 .58101 L .49956 .58086 L 1 g
F
P
p
.49956 .58086 m .48903 .58101 L .49947 .58088 L 1 g
F
P
p
.002 w
.49875 .58089 m .51675 .57629 L p
.5124 .58044 L 1 g
F P
s
P
p
.51095 .58075 m .49875 .58089 L .5124 .58044 L 1 g
F
P
p
.53128 .57265 m .51103 .58185 L .51823 .57935 L 1 g
F
P
p
.53987 .56955 m .54892 .56389 L .5494 .56359 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.52891 .58521 m .52263 .58243 L .53557 .57331 L p
1 g
F P
s
P
p
.002 w
.52137 .58112 m .51932 .57897 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57468 L p
1 g
F P
s
P
p
.002 w
.53172 .57468 m .53172 .57465 L p
.53101 .57494 L 1 g
F P
s
P
p
.53101 .57494 m .51111 .583 L .53172 .57468 L 1 g
F
P
p
.002 w
.53557 .57331 m .54892 .56389 L p
.54235 .57089 L 1 g
F P
s
P
p
.52891 .58521 m .53557 .57331 L .54235 .57089 L 1 g
F
P
p
.002 w
.54892 .56389 m .5495 .56348 L p
.5494 .56359 L 1 g
F P
s
P
p
.52891 .58521 m .54892 .56389 L .5494 .56359 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57468 L p
1 g
F P
s
P
p
.002 w
.53172 .57468 m .5322 .57686 L p
.53982 .5696 L 1 g
F P
s
P
p
.54854 .56129 m .53172 .57468 L .53982 .5696 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53172 .57465 m .51675 .57629 L .54892 .56389 L 1 g
F
P
p
.002 w
.51932 .57897 m .51675 .57629 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.51103 .58185 m .51111 .583 L p
.51823 .57935 L 1 g
F P
s
P
p
.002 w
.51675 .57629 m .51932 .57897 L p
.5124 .58044 L 1 g
F P
s
P
p
.51823 .57935 m .51111 .583 L .53172 .57465 L 1 g
F
P
p
.53987 .56955 m .53982 .5696 L .54892 .56389 L 1 g
F
P
p
.56075 .54566 m .5494 .56359 L .5495 .56348 L 1 g
F
P
p
.002 w
.54961 .56336 m .54974 .56331 L .5495 .56348 L p
1 g
F P
s
P
p
.54956 .56342 m .5495 .56348 L .54956 .56342 L 1 g
F
P
p
.56075 .54566 m .5495 .56348 L .54956 .56342 L 1 g
F
P
p
.56075 .54566 m .54956 .56342 L .55486 .55634 L 1 g
F
P
p
.54956 .56342 m .54942 .56365 L .54969 .56327 L 1 g
F
P
p
.54956 .56342 m .54965 .56333 L .55486 .55634 L 1 g
F
P
p
.002 w
.54966 .56331 m .54974 .56331 L .54965 .56333 L p
1 g
F P
s
P
p
.54965 .56333 m .54966 .56332 L .54966 .56331 L 1 g
F
P
p
.54965 .56333 m .54966 .56331 L .55486 .55634 L 1 g
F
P
p
.54966 .56332 m .54967 .5633 L .55486 .55634 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51432 .56845 m .51565 .55976 L .54966 .56331 L p
1 g
F P
s
P
p
.002 w
.54965 .56333 m .51432 .56845 L p
.54966 .56331 L 1 g
F P
s
P
p
.54966 .56331 m .54968 .56329 L .55486 .55634 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51565 .55976 m .52065 .55116 L .54968 .56329 L p
1 g
F P
s
P
p
.002 w
.54968 .56329 m .54974 .56331 L .54966 .56331 L p
1 g
F P
s
P
p
.002 w
.54966 .56331 m .51565 .55976 L p
.54968 .56329 L 1 g
F P
s
P
p
.54966 .56332 m .54966 .56331 L .54967 .5633 L 1 g
F
P
p
.54966 .56331 m .54967 .5633 L .54968 .56329 L 1 g
F
P
p
.54967 .5633 m .5497 .56327 L .55486 .55634 L 1 g
F
P
p
.002 w
.52065 .55116 m .5288 .54362 L .54969 .56327 L p
1 g
F P
s
P
p
.002 w
.54969 .56327 m .54974 .56331 L .54968 .56329 L p
1 g
F P
s
P
p
.002 w
.54968 .56329 m .52065 .55116 L p
.54969 .56327 L 1 g
F P
s
P
p
.54968 .56329 m .54973 .56323 L .55486 .55634 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5288 .54362 m .5392 .53799 L .54971 .56325 L p
1 g
F P
s
P
p
.002 w
.54971 .56325 m .54974 .56331 L .54969 .56327 L p
1 g
F P
s
P
p
.002 w
.54969 .56327 m .5288 .54362 L p
.54971 .56325 L 1 g
F P
s
P
p
.54967 .5633 m .54968 .56329 L .5497 .56327 L 1 g
F
P
p
.54968 .56329 m .54969 .56328 L .54973 .56323 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5392 .53799 m .55068 .53493 L .54974 .56321 L p
1 g
F P
s
P
p
.002 w
.54974 .56321 m .54974 .56331 L .54971 .56325 L p
1 g
F P
s
P
p
.002 w
.54971 .56325 m .5392 .53799 L p
.54974 .56321 L 1 g
F P
s
P
p
.54969 .56328 m .54984 .56308 L .55486 .55634 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55068 .53493 m .56194 .53478 L .54984 .56308 L p
1 g
F P
s
P
p
.002 w
.54984 .56308 m .54974 .56331 L .54974 .56321 L p
1 g
F P
s
P
p
.002 w
.54974 .56321 m .55068 .53493 L p
.54984 .56308 L 1 g
F P
s
P
p
.54969 .56328 m .54969 .56327 L .54984 .56308 L 1 g
F
P
p
.002 w
.51675 .57629 m .51432 .56845 L .54965 .56333 L p
1 g
F P
s
P
p
.002 w
.54965 .56333 m .54974 .56331 L .54961 .56336 L p
1 g
F P
s
P
p
.002 w
.54961 .56336 m .51675 .57629 L p
.54965 .56333 L 1 g
F P
s
P
p
.002 w
.51675 .57629 m .54961 .56336 L p
.54892 .56389 L 1 g
F P
s
P
p
.002 w
.5495 .56348 m .54892 .56389 L p
.54961 .56336 L 1 g
F P
s
P
p
.002 w
.55297 .58573 m .54176 .58739 L .54971 .56339 L p
1 g
F P
s
P
p
.002 w
.54971 .56339 m .54974 .56331 L .54975 .56337 L p
1 g
F P
s
P
p
.002 w
.54975 .56337 m .55297 .58573 L p
.54971 .56339 L 1 g
F P
s
P
p
.002 w
.54176 .58739 m .53128 .58626 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5494 .5636 L p
1 g
F P
s
P
p
.002 w
.5494 .5636 m .5494 .56359 L p
.54932 .56365 L 1 g
F P
s
P
p
.54932 .56365 m .5322 .57686 L .5494 .5636 L 1 g
F
P
p
.53982 .5696 m .5322 .57686 L .5494 .56359 L 1 g
F
P
p
.002 w
.5494 .56359 m .54942 .56365 L p
.54956 .56342 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .54731 L p
1 g
F P
s
P
p
.002 w
.56032 .55089 m .57171 .53752 L p
.55788 .5576 L 1 g
F P
s
P
p
.002 w
.56162 .54731 m .56235 .54869 L p
.56379 .54136 L 1 g
F P
s
P
p
.56654 .52734 m .56162 .54731 L .56379 .54136 L 1 g
F
P
p
.002 w
.57171 .53752 m .57893 .54284 L .55788 .5576 L p
1 g
F P
s
P
p
.002 w
.55788 .5576 m .54974 .56331 L .56032 .55089 L p
1 g
F P
s
P
p
.56654 .52734 m .56235 .54869 L .56333 .54495 L 1 g
F
P
p
.56691 .51969 m .5669 .51952 L .56611 .5094 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56764 .52894 L p
1 g
F P
s
P
p
.56515 .50826 m .56764 .52894 L .56692 .51972 L 1 g
F
P
p
.55661 .4905 m .56611 .5094 L .5629 .50254 L 1 g
F
P
p
.55661 .4905 m .5629 .50254 L .56284 .50242 L 1 g
F
P
p
.55858 .49248 m .5629 .50254 L .55734 .49128 L 1 g
F
P
p
.002 w
.57245 .50247 m .5629 .50254 L p
.54788 .46752 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55734 .49128 L p
1 g
F P
s
P
p
.54174 .47608 m .55734 .49128 L .55377 .48782 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.5629 .50254 m .55006 .50263 L .54884 .48305 L p
1 g
F P
s
P
p
.54174 .47608 m .55377 .48782 L .55013 .4843 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55734 .49128 m .5629 .50254 L .54884 .48305 L 1 g
F
P
p
.002 w
.54884 .48305 m .55006 .50263 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54231 .4767 L p
1 g
F P
s
P
p
.002 w
.54231 .4767 m .54174 .47608 L p
.55071 .48486 L 1 g
F P
s
P
p
.55071 .48486 m .55834 .49233 L .54231 .4767 L 1 g
F
P
p
.002 w
.54788 .46752 m .54863 .4797 L p
.54231 .4767 L 1 g
F P
s
P
p
.52214 .46667 m .54231 .4767 L .53707 .47422 L 1 g
F
P
p
.52214 .46667 m .5426 .47702 L .53378 .4727 L 1 g
F
P
p
.002 w
.51406 .47639 m .53182 .47173 L p
.55006 .50263 L 1 g
F P
s
P
p
.002 w
.53182 .47173 m .51406 .47639 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52241 .46713 L p
1 g
F P
s
P
p
.002 w
.52241 .46713 m .52214 .46667 L p
.53378 .4727 L 1 g
F P
s
P
p
.53378 .4727 m .54302 .47747 L .52241 .46713 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.50038 .44231 m .5401 .46956 L .52241 .46713 L 1 g
F
P
p
.5 .4634 m .52241 .46713 L .51453 .46604 L 1 g
F
P
p
.5 .4634 m .52265 .46751 L .51382 .46606 L 1 g
F
P
p
.002 w
.50964 .46537 m .51406 .47639 L p
.5 .46378 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46378 L p
1 g
F P
s
P
p
.002 w
.5 .46378 m .5 .4634 L p
.51382 .46606 L 1 g
F P
s
P
p
.51382 .46606 m .52282 .46778 L .5 .46378 L 1 g
F
P
p
.002 w
.50491 .45359 m .50849 .46253 L p
.5 .46378 L 1 g
F P
s
P
p
.002 w
.47762 .46707 m .47786 .46667 L p
.48584 .46586 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46378 L p
1 g
F P
s
P
p
.002 w
.5 .46378 m .5 .46442 L p
.48584 .46586 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46378 L .48584 .46586 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47762 .46707 L p
1 g
F P
s
P
p
.46098 .46405 m .50491 .45359 L .47762 .46707 L 1 g
F
P
p
.45826 .47608 m .47762 .46707 L .47104 .47032 L 1 g
F
P
p
.47538 .4674 m .47762 .46707 L .47645 .46765 L 1 g
F
P
p
.46098 .46405 m .47762 .46707 L .47538 .4674 L 1 g
F
P
p
.47762 .46707 m .48822 .46183 L .5 .46378 L 1 g
F
P
p
.48822 .46183 m .50491 .45359 L .5 .46378 L 1 g
F
P
p
.002 w
.50964 .46537 m .50738 .45976 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.50738 .45976 m .50038 .44231 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.53182 .47173 m .53605 .47062 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.53605 .47062 m .54788 .46752 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.54884 .48305 m .5482 .47276 L p
.55734 .49128 L 1 g
F P
s
P
p
.55013 .4843 m .55767 .49163 L .55071 .48486 L 1 g
F
P
p
.55377 .48782 m .55767 .49163 L .55013 .4843 L 1 g
F
P
p
.002 w
.55734 .49128 m .55767 .49163 L p
.55377 .48782 L 1 g
F P
s
P
p
.002 w
.5482 .47276 m .54788 .46752 L p
.55858 .49248 L 1 g
F P
s
P
p
.55858 .49248 m .55734 .49128 L .5482 .47276 L 1 g
F
P
p
.56284 .50242 m .5629 .50254 L .56287 .50248 L 1 g
F
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.5629 .50254 m .56611 .5094 L .56194 .53478 L 1 g
F
P
p
.002 w
.56852 .51456 m .5669 .51952 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.5669 .51952 m .56194 .53478 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.56764 .52894 m .56854 .53025 L p
.56692 .51972 L 1 g
F P
s
P
p
.002 w
.56194 .53478 m .5669 .51952 L p
.56753 .52878 L 1 g
F P
s
P
p
.002 w
.56805 .5365 m .56569 .53583 L p
.56753 .52878 L 1 g
F P
s
P
p
.002 w
.56569 .53583 m .56194 .53478 L p
.56753 .52878 L 1 g
F P
s
P
p
.002 w
.56235 .54869 m .56257 .5491 L p
.56333 .54495 L 1 g
F P
s
P
p
.56569 .53583 m .56161 .54728 L .55 .56286 L 1 g
F
P
p
.56161 .54728 m .56032 .55089 L .55 .56286 L 1 g
F
P
p
.002 w
.54974 .56331 m .56194 .53478 L .56569 .53583 L p
1 g
F P
s
P
p
.002 w
.56373 .58146 m .55297 .58573 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.57294 .57504 m .56373 .58146 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.57962 .5671 m .57294 .57504 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.58306 .55849 m .57962 .5671 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.58284 .55009 m .58306 .55849 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.57893 .54284 m .58284 .55009 L .54974 .56331 L closepath p
1 g
F P
s
P
p
.002 w
.54942 .56365 m .54998 .56518 L p
.55486 .55634 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56161 .54728 L p
1 g
F P
s
P
p
.55486 .55634 m .54998 .56518 L .56161 .54728 L 1 g
F
P
p
.56425 .53988 m .56333 .54495 L .56569 .53583 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56753 .52878 L p
1 g
F P
s
P
p
.56333 .54495 m .56257 .5491 L .56753 .52878 L 1 g
F
P
p
.56691 .51969 m .56692 .51972 L .5669 .51952 L 1 g
F
P
p
.002 w
.57171 .53752 m .56805 .5365 L p
.57245 .50247 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .5094 L p
1 g
F P
s
P
p
.56692 .51972 m .56854 .53025 L .56611 .5094 L 1 g
F
P
p
.002 w
.56611 .5094 m .56713 .51061 L p
.56287 .50248 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55006 .50263 m .5629 .50254 L p
.56194 .53478 L 1 g
F P
s
P
p
.002 w
.54863 .4797 m .54884 .48305 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.55767 .49163 m .55834 .49233 L p
.55071 .48486 L 1 g
F P
s
P
p
.002 w
.54231 .4767 m .5426 .47702 L p
.53707 .47422 L 1 g
F P
s
P
p
.002 w
.5401 .46956 m .53182 .47173 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.5426 .47702 m .54302 .47747 L p
.53378 .4727 L 1 g
F P
s
P
p
.002 w
.52241 .46713 m .52265 .46751 L p
.51453 .46604 L 1 g
F P
s
P
p
.002 w
.54788 .46752 m .5401 .46956 L p
.50038 .44231 L 1 g
F P
s
P
p
.002 w
.50849 .46253 m .50964 .46537 L p
.5 .46378 L 1 g
F P
s
P
p
.002 w
.52265 .46751 m .52282 .46778 L p
.51382 .46606 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47762 .46707 L p
1 g
F P
s
P
p
.48584 .46586 m .5 .46442 L .47762 .46707 L 1 g
F
P
p
.002 w
.47762 .46707 m .47738 .46746 L p
.47104 .47032 L 1 g
F P
s
P
p
.002 w
.47738 .46746 m .47718 .46778 L p
.46911 .47132 L 1 g
F P
s
P
p
.45826 .47608 m .47738 .46746 L .46911 .47132 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45777 .47662 L p
1 g
F P
s
P
p
.002 w
.45777 .47662 m .45698 .47747 L p
.4487 .48541 L 1 g
F P
s
P
p
.44339 .4905 m .45777 .47662 L .4487 .48541 L 1 g
F
P
p
.002 w
.44271 .49123 m .44339 .4905 L p
.4487 .48541 L 1 g
F P
s
P
p
.002 w
.45174 .47304 m .46098 .46405 L p
.44363 .49033 L 1 g
F P
s
P
p
.44271 .49123 m .44363 .49033 L .4417 .49326 L 1 g
F
P
p
.45174 .47304 m .44363 .49033 L .44271 .49123 L 1 g
F
P
p
.002 w
.46098 .46405 m .46517 .46944 L p
.45777 .47662 L 1 g
F P
s
P
p
.44363 .49033 m .45042 .48004 L .45777 .47662 L 1 g
F
P
p
.45042 .48004 m .46098 .46405 L .45777 .47662 L 1 g
F
P
p
.002 w
.46729 .47217 m .46098 .46405 L p
.47645 .46765 L 1 g
F P
s
P
p
.002 w
.46517 .46944 m .46729 .47217 L p
.45777 .47662 L 1 g
F P
s
P
p
.002 w
.46729 .47217 m .48357 .4931 L p
.45777 .47662 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45777 .47662 L p
1 g
F P
s
P
p
.46911 .47132 m .47718 .46778 L .45777 .47662 L 1 g
F
P
p
.002 w
.4309 .4933 m .45174 .47304 L p
.4417 .49326 L 1 g
F P
s
P
p
.002 w
.44271 .49123 m .44166 .49233 L p
.43859 .49952 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44271 .49123 L p
1 g
F P
s
P
p
.4487 .48541 m .45698 .47747 L .44271 .49123 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43338 .51002 L p
1 g
F P
s
P
p
.002 w
.43338 .51002 m .43416 .50908 L p
.43711 .5025 L 1 g
F P
s
P
p
.43711 .5025 m .44166 .49233 L .43338 .51002 L 1 g
F
P
p
.002 w
.48357 .4931 m .46009 .51554 L .43872 .49926 L p
1 g
F P
s
P
p
.4417 .49326 m .48357 .4931 L .43872 .49926 L 1 g
F
P
p
.002 w
.43872 .49926 m .46009 .51554 L p
.4277 .52301 L 1 g
F P
s
P
p
.43849 .49975 m .44166 .49233 L .43416 .50908 L 1 g
F
P
p
.002 w
.43416 .50908 m .43287 .51061 L p
.43325 .52121 L 1 g
F P
s
P
p
.4327 .52844 m .46009 .51554 L .43456 .53567 L 1 g
F
P
p
.4311 .52222 m .43321 .52174 L .4327 .52844 L 1 g
F
P
p
.43321 .52174 m .46009 .51554 L .4327 .52844 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4327 .52844 L p
1 g
F P
s
P
p
.43325 .52121 m .43287 .51061 L .4327 .52844 L 1 g
F
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.46009 .51554 m .44627 .54091 L .43456 .53567 L p
1 g
F P
s
P
p
.002 w
.4327 .52844 m .43226 .52908 L p
.43382 .53277 L 1 g
F P
s
P
p
.002 w
.41045 .55891 m .41355 .52627 L .44627 .54091 L p
1 g
F P
s
P
p
.002 w
.43226 .52908 m .43146 .53025 L p
.43537 .53799 L 1 g
F P
s
P
p
.002 w
.44627 .54091 m .4446 .55558 L p
.43853 .54702 L 1 g
F P
s
P
p
.43736 .54538 m .43787 .54513 L .43853 .54702 L 1 g
F
P
p
.43787 .54513 m .44627 .54091 L .43853 .54702 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43853 .54702 L p
1 g
F P
s
P
p
.43537 .53799 m .43146 .53025 L .43853 .54702 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45049 .56389 L p
1 g
F P
s
P
p
.002 w
.45049 .56389 m .45079 .56308 L p
.44741 .55955 L 1 g
F P
s
P
p
.44741 .55955 m .43743 .5491 L .45049 .56389 L 1 g
F
P
p
.44386 .55469 m .43743 .5491 L .45079 .56308 L 1 g
F
P
p
.002 w
.45079 .56308 m .45062 .56354 L p
.45351 .56499 L 1 g
F P
s
P
p
.46872 .57265 m .45062 .56354 L .45942 .56893 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48073 .55221 m .47844 .56942 L .45697 .56743 L p
1 g
F P
s
P
p
.4511 .5633 m .48073 .55221 L .45697 .56743 L 1 g
F
P
p
.002 w
.45697 .56743 m .47844 .56942 L p
.46834 .5744 L 1 g
F P
s
P
p
.002 w
.45062 .56354 m .45002 .56518 L p
.45942 .56893 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .5744 L p
1 g
F P
s
P
p
.45942 .56893 m .45002 .56518 L .46834 .5744 L 1 g
F
P
p
.002 w
.46834 .5744 m .468 .57592 L p
.47533 .57686 L 1 g
F P
s
P
p
.002 w
.45137 .58853 m .4434 .56618 L .44545 .56637 L p
1 g
F P
s
P
p
.48921 .57862 m .468 .57592 L .47442 .57741 L 1 g
F
P
p
.48905 .58078 m .47844 .56942 L .49104 .58081 L 1 g
F
P
p
.002 w
.48221 .58071 m .48167 .57908 L p
.48905 .58078 L 1 g
F P
s
P
p
.002 w
.48167 .57908 m .47844 .56942 L p
.48905 .58078 L 1 g
F P
s
P
p
.002 w
.468 .57592 m .4678 .57686 L p
.47442 .57741 L 1 g
F P
s
P
p
.002 w
.47844 .56942 m .48167 .57908 L p
.47037 .57511 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58078 L p
1 g
F P
s
P
p
.47442 .57741 m .4678 .57686 L .48905 .58078 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47844 .56942 m .51432 .56845 L p
.49104 .58081 L 1 g
F P
s
P
p
.002 w
.48903 .58101 m .48889 .583 L p
.49939 .5809 L 1 g
F P
s
P
p
.49947 .58088 m .49875 .58089 L .49939 .5809 L 1 g
F
P
p
.49875 .58089 m .48903 .58101 L .49939 .5809 L 1 g
F
P
p
.002 w
.48905 .58078 m .48903 .58101 L p
.4909 .5808 L 1 g
F P
s
P
p
.002 w
.51432 .56845 m .51675 .57629 L .49875 .58089 L p
1 g
F P
s
P
p
.49104 .58081 m .51432 .56845 L .49875 .58089 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58075 L p
1 g
F P
s
P
p
.49947 .58088 m .48889 .583 L .51095 .58075 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.57962 .5671 m .58306 .55849 L .61333 .54994 L p
1 g
F P
s
P
p
.002 w
.61319 .53338 m .61333 .54994 L .58306 .55849 L p
1 g
F P
s
P
p
.002 w
.61333 .54994 m .61319 .53338 L .63977 .51382 L p
1 g
F P
s
P
p
.002 w
.63311 .40964 m .66351 .43555 L .6488 .46425 L p
1 g
F P
s
P
p
.002 w
.66351 .43555 m .63311 .40964 L .63904 .3774 L p
1 g
F P
s
P
p
.002 w
.58814 .32829 m .64071 .3474 L .63904 .3774 L p
1 g
F P
s
P
p
.002 w
.64071 .3474 m .58814 .32829 L .58322 .30007 L p
1 g
F P
s
P
p
.002 w
.62936 .49237 m .63977 .51382 L .61319 .53338 L p
1 g
F P
s
P
p
.002 w
.63977 .51382 m .62936 .49237 L .6488 .46425 L p
1 g
F P
s
P
p
.002 w
.4504 .31465 m .39029 .34873 L .38061 .32547 L p
1 g
F P
s
P
p
.002 w
.38061 .32547 m .4414 .29083 L .4504 .31465 L p
1 g
F P
s
P
p
.002 w
.40362 .37518 m .36052 .41917 L .34546 .39508 L p
1 g
F P
s
P
p
.002 w
.34546 .39508 m .39029 .34873 L .40362 .37518 L p
1 g
F P
s
P
p
.002 w
.58322 .30007 m .51779 .29773 L .50965 .27381 L p
1 g
F P
s
P
p
.002 w
.4414 .29083 m .50965 .27381 L .51779 .29773 L p
1 g
F P
s
P
p
.002 w
.51779 .29773 m .58322 .30007 L .58814 .32829 L p
1 g
F P
s
P
p
.002 w
.40394 .46921 m .38375 .50887 L .35792 .48938 L p
1 g
F P
s
P
p
.002 w
.35792 .48938 m .3802 .44418 L .40394 .46921 L p
1 g
F P
s
P
p
.002 w
.58306 .55849 m .58284 .55009 L .61319 .53338 L p
1 g
F P
s
P
p
.002 w
.6058 .5189 m .61319 .53338 L .58284 .55009 L p
1 g
F P
s
P
p
.002 w
.61319 .53338 m .6058 .5189 L .62936 .49237 L p
1 g
F P
s
P
p
.002 w
.62302 .44299 m .6488 .46425 L .62936 .49237 L p
1 g
F P
s
P
p
.002 w
.6488 .46425 m .62302 .44299 L .63311 .40964 L p
1 g
F P
s
P
p
.002 w
.51779 .29773 m .4504 .31465 L .4414 .29083 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59046 .36033 m .63904 .3774 L .63311 .40964 L p
1 g
F P
s
P
p
.002 w
.63904 .3774 m .59046 .36033 L .58814 .32829 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.58284 .55009 m .57893 .54284 L .6058 .5189 L p
1 g
F P
s
P
p
.002 w
.60906 .47625 m .62936 .49237 L .6058 .5189 L p
1 g
F P
s
P
p
.002 w
.62936 .49237 m .60906 .47625 L .62302 .44299 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.51565 .55976 m .51432 .56845 L .47844 .56942 L p
1 g
F P
s
P
p
.002 w
.47844 .56942 m .48073 .55221 L .51565 .55976 L p
1 g
F P
s
P
p
.002 w
.4309 .4933 m .41355 .52627 L .38375 .50887 L p
1 g
F P
s
P
p
.002 w
.38375 .50887 m .40394 .46921 L .4309 .4933 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42024 .40393 m .3802 .44418 L .36052 .41917 L p
1 g
F P
s
P
p
.002 w
.36052 .41917 m .40362 .37518 L .42024 .40393 L p
1 g
F P
s
P
p
.002 w
.59174 .50815 m .6058 .5189 L .57893 .54284 L p
1 g
F P
s
P
p
.002 w
.6058 .5189 m .59174 .50815 L .60906 .47625 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57893 .54284 m .57171 .53752 L .59174 .50815 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46119 .34273 m .40362 .37518 L .39029 .34873 L p
1 g
F P
s
P
p
.002 w
.39029 .34873 m .4504 .31465 L .46119 .34273 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.52561 .32644 m .58814 .32829 L .59046 .36033 L p
1 g
F P
s
P
p
.002 w
.58814 .32829 m .52561 .32644 L .51779 .29773 L p
1 g
F P
s
P
p
.002 w
.59002 .39508 m .63311 .40964 L .62302 .44299 L p
1 g
F P
s
P
p
.002 w
.63311 .40964 m .59002 .39508 L .59046 .36033 L p
1 g
F P
s
P
p
.002 w
.4504 .31465 m .51779 .29773 L .52561 .32644 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52065 .55116 m .51565 .55976 L .48073 .55221 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.57245 .50247 m .59174 .50815 L .57171 .53752 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.52561 .32644 m .46119 .34273 L .4504 .31465 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58679 .43127 m .62302 .44299 L .60906 .47625 L p
1 g
F P
s
P
p
.002 w
.62302 .44299 m .58679 .43127 L .59002 .39508 L p
1 g
F P
s
P
p
.002 w
.48073 .55221 m .49039 .53506 L .52065 .55116 L p
1 g
F P
s
P
p
.002 w
.49039 .53506 m .48073 .55221 L .44627 .54091 L p
1 g
F P
s
P
p
.002 w
.44627 .54091 m .46009 .51554 L .49039 .53506 L p
1 g
F P
s
P
p
.002 w
.5288 .54362 m .52065 .55116 L .49039 .53506 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.56194 .53478 m .55068 .53493 L .55006 .50263 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4396 .43394 m .40394 .46921 L .3802 .44418 L p
1 g
F P
s
P
p
.002 w
.3802 .44418 m .42024 .40393 L .4396 .43394 L p
1 g
F P
s
P
p
.002 w
.59174 .50815 m .57245 .50247 L .58086 .46754 L p
1 g
F P
s
P
p
.002 w
.58086 .46754 m .60906 .47625 L .59174 .50815 L p
1 g
F P
s
P
p
.002 w
.60906 .47625 m .58086 .46754 L .58679 .43127 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5392 .53799 m .5288 .54362 L .50647 .51995 L p
1 g
F P
s
P
p
.002 w
.49039 .53506 m .50647 .51995 L .5288 .54362 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55068 .53493 m .5392 .53799 L .52716 .50868 L p
1 g
F P
s
P
p
.002 w
.52716 .50868 m .55006 .50263 L .55068 .53493 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.5328 .359 m .59046 .36033 L .59002 .39508 L p
1 g
F P
s
P
p
.002 w
.59046 .36033 m .5328 .359 L .52561 .32644 L p
1 g
F P
s
P
p
.002 w
.50647 .51995 m .52716 .50868 L .5392 .53799 L p
1 g
F P
s
P
p
.002 w
.47342 .37415 m .42024 .40393 L .40362 .37518 L p
1 g
F P
s
P
p
.002 w
.40362 .37518 m .46119 .34273 L .47342 .37415 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46119 .34273 m .52561 .32644 L .5328 .359 L p
1 g
F P
s
P
p
.002 w
.50647 .51995 m .49039 .53506 L .46009 .51554 L p
1 g
F P
s
P
p
.002 w
.46098 .46405 m .4309 .4933 L .40394 .46921 L p
1 g
F P
s
P
p
.002 w
.40394 .46921 m .4396 .43394 L .46098 .46405 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.54788 .46752 m .58086 .46754 L .57245 .50247 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53908 .39428 m .59002 .39508 L .58679 .43127 L p
1 g
F P
s
P
p
.002 w
.59002 .39508 m .53908 .39428 L .5328 .359 L p
1 g
F P
s
P
p
.002 w
.5328 .359 m .47342 .37415 L .46119 .34273 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.46009 .51554 m .48357 .4931 L .50647 .51995 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.52716 .50868 m .50647 .51995 L .48357 .4931 L p
1 g
F P
s
P
p
.002 w
.58086 .46754 m .54788 .46752 L .54417 .43093 L p
1 g
F P
s
P
p
.002 w
.54417 .43093 m .58679 .43127 L .58086 .46754 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55006 .50263 m .52716 .50868 L .51406 .47639 L p
1 g
F P
s
P
p
.002 w
.58679 .43127 m .54417 .43093 L .53908 .39428 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48665 .40778 m .4396 .43394 L .42024 .40393 L p
1 g
F P
s
P
p
.002 w
.42024 .40393 m .47342 .37415 L .48665 .40778 L p
1 g
F P
s
P
p
.002 w
.48357 .4931 m .51406 .47639 L .52716 .50868 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47342 .37415 m .5328 .359 L .53908 .39428 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.53908 .39428 m .48665 .40778 L .47342 .37415 L p
1 g
F P
s
P
p
.002 w
.50038 .44231 m .54417 .43093 L .54788 .46752 L p
1 g
F P
s
P
p
.002 w
.50038 .44231 m .46098 .46405 L .4396 .43394 L p
1 g
F P
s
P
p
.002 w
.4396 .43394 m .48665 .40778 L .50038 .44231 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48665 .40778 m .53908 .39428 L .54417 .43093 L p
1 g
F P
s
P
p
.002 w
.54417 .43093 m .50038 .44231 L .48665 .40778 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.56684 .60898 m
.57013 .61775 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .77821 .4269 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57898 .64139 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0110526)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0110526)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45983 .4742 m .50732 .47032 L .50169 .44253 L p
1 g
F P
s
P
p
.002 w
.50169 .44253 m .46008 .44584 L .45983 .4742 L p
1 g
F P
s
P
p
.002 w
.54135 .42944 m .50169 .44253 L .50732 .47032 L p
1 g
F P
s
P
p
.002 w
.46008 .44584 m .50169 .44253 L .49604 .41453 L p
1 g
F P
s
P
p
.002 w
.50169 .44253 m .54135 .42944 L .52913 .40353 L p
1 g
F P
s
P
p
.002 w
.52913 .40353 m .49604 .41453 L .50169 .44253 L p
1 g
F P
s
P
p
.002 w
.49604 .41453 m .4613 .41721 L .46008 .44584 L p
1 g
F P
s
P
p
.002 w
.4613 .41721 m .49604 .41453 L .49047 .38681 L p
1 g
F P
s
P
p
.002 w
.49604 .41453 m .52913 .40353 L .51617 .3782 L p
1 g
F P
s
P
p
.002 w
.51617 .3782 m .49047 .38681 L .49604 .41453 L p
1 g
F P
s
P
p
.002 w
.55745 .38517 m .52913 .40353 L .54135 .42944 L p
1 g
F P
s
P
p
.002 w
.52913 .40353 m .55745 .38517 L .53806 .36381 L p
1 g
F P
s
P
p
.002 w
.53806 .36381 m .51617 .3782 L .52913 .40353 L p
1 g
F P
s
P
p
.002 w
.46055 .50178 m .51281 .4974 L .50732 .47032 L p
1 g
F P
s
P
p
.002 w
.50732 .47032 m .45983 .4742 L .46055 .50178 L p
1 g
F P
s
P
p
.002 w
.55262 .45547 m .50732 .47032 L .51281 .4974 L p
1 g
F P
s
P
p
.002 w
.50732 .47032 m .55262 .45547 L .54135 .42944 L p
1 g
F P
s
P
p
.002 w
.42028 .43896 m .46008 .44584 L .4613 .41721 L p
1 g
F P
s
P
p
.002 w
.4613 .41721 m .42815 .41125 L .42028 .43896 L p
1 g
F P
s
P
p
.002 w
.42815 .41125 m .4613 .41721 L .46346 .38883 L p
1 g
F P
s
P
p
.002 w
.49047 .38681 m .46346 .38883 L .4613 .41721 L p
1 g
F P
s
P
p
.002 w
.57545 .40765 m .54135 .42944 L .55262 .45547 L p
1 g
F P
s
P
p
.002 w
.54135 .42944 m .57545 .40765 L .55745 .38517 L p
1 g
F P
s
P
p
.002 w
.41432 .46664 m .45983 .4742 L .46008 .44584 L p
1 g
F P
s
P
p
.002 w
.46008 .44584 m .42028 .43896 L .41432 .46664 L p
1 g
F P
s
P
p
.002 w
.46346 .38883 m .49047 .38681 L .48507 .35987 L p
1 g
F P
s
P
p
.002 w
.49047 .38681 m .51617 .3782 L .5027 .35393 L p
1 g
F P
s
P
p
.002 w
.5027 .35393 m .48507 .35987 L .49047 .38681 L p
1 g
F P
s
P
p
.002 w
.51617 .3782 m .53806 .36381 L .51764 .34398 L p
1 g
F P
s
P
p
.002 w
.51764 .34398 m .5027 .35393 L .51617 .3782 L p
1 g
F P
s
P
p
.002 w
.46346 .38883 m .43776 .38403 L .42815 .41125 L p
1 g
F P
s
P
p
.002 w
.43776 .38403 m .46346 .38883 L .46653 .36122 L p
1 g
F P
s
P
p
.002 w
.48507 .35987 m .46653 .36122 L .46346 .38883 L p
1 g
F P
s
P
p
.002 w
.51281 .4974 m .56271 .48115 L .55262 .45547 L p
1 g
F P
s
P
p
.002 w
.59171 .43084 m .55262 .45547 L .56271 .48115 L p
1 g
F P
s
P
p
.002 w
.55262 .45547 m .59171 .43084 L .57545 .40765 L p
1 g
F P
s
P
p
.002 w
.41041 .49377 m .46055 .50178 L .45983 .4742 L p
1 g
F P
s
P
p
.002 w
.45983 .4742 m .41432 .46664 L .41041 .49377 L p
1 g
F P
s
P
p
.002 w
.46226 .52803 m .51808 .52324 L .51281 .4974 L p
1 g
F P
s
P
p
.002 w
.51281 .4974 m .46055 .50178 L .46226 .52803 L p
1 g
F P
s
P
p
.002 w
.56271 .48115 m .51281 .4974 L .51808 .52324 L p
1 g
F P
s
P
p
.002 w
.46653 .36122 m .48507 .35987 L .47996 .33424 L p
1 g
F P
s
P
p
.002 w
.48507 .35987 m .5027 .35393 L .48897 .33119 L p
1 g
F P
s
P
p
.002 w
.48897 .33119 m .47996 .33424 L .48507 .35987 L p
1 g
F P
s
P
p
.002 w
.57818 .36106 m .55745 .38517 L .57545 .40765 L p
1 g
F P
s
P
p
.002 w
.55745 .38517 m .57818 .36106 L .55392 .34496 L p
1 g
F P
s
P
p
.002 w
.55392 .34496 m .53806 .36381 L .55745 .38517 L p
1 g
F P
s
P
p
.002 w
.38606 .42225 m .42028 .43896 L .42815 .41125 L p
1 g
F P
s
P
p
.002 w
.42815 .41125 m .3998 .39702 L .38606 .42225 L p
1 g
F P
s
P
p
.002 w
.3998 .39702 m .42815 .41125 L .43776 .38403 L p
1 g
F P
s
P
p
.002 w
.5027 .35393 m .51764 .34398 L .49657 .32606 L p
1 g
F P
s
P
p
.002 w
.49657 .32606 m .48897 .33119 L .5027 .35393 L p
1 g
F P
s
P
p
.002 w
.53806 .36381 m .55392 .34496 L .52834 .33097 L p
1 g
F P
s
P
p
.002 w
.52834 .33097 m .51764 .34398 L .53806 .36381 L p
1 g
F P
s
P
p
.002 w
.46653 .36122 m .44894 .35782 L .43776 .38403 L p
1 g
F P
s
P
p
.002 w
.44894 .35782 m .46653 .36122 L .47047 .33491 L p
1 g
F P
s
P
p
.002 w
.47996 .33424 m .47047 .33491 L .46653 .36122 L p
1 g
F P
s
P
p
.002 w
.43776 .38403 m .41592 .37277 L .3998 .39702 L p
1 g
F P
s
P
p
.002 w
.41592 .37277 m .43776 .38403 L .44894 .35782 L p
1 g
F P
s
P
p
.002 w
.60065 .37898 m .57545 .40765 L .59171 .43084 L p
1 g
F P
s
P
p
.002 w
.57545 .40765 m .60065 .37898 L .57818 .36106 L p
1 g
F P
s
P
p
.002 w
.37502 .44797 m .41432 .46664 L .42028 .43896 L p
1 g
F P
s
P
p
.002 w
.42028 .43896 m .38606 .42225 L .37502 .44797 L p
1 g
F P
s
P
p
.002 w
.51808 .52324 m .57141 .50599 L .56271 .48115 L p
1 g
F P
s
P
p
.002 w
.60591 .4543 m .56271 .48115 L .57141 .50599 L p
1 g
F P
s
P
p
.002 w
.56271 .48115 m .60591 .4543 L .59171 .43084 L p
1 g
F P
s
P
p
.002 w
.40866 .51981 m .46226 .52803 L .46055 .50178 L p
1 g
F P
s
P
p
.002 w
.46055 .50178 m .41041 .49377 L .40866 .51981 L p
1 g
F P
s
P
p
.002 w
.51764 .34398 m .52834 .33097 L .50194 .31938 L p
1 g
F P
s
P
p
.002 w
.50194 .31938 m .49657 .32606 L .51764 .34398 L p
1 g
F P
s
P
p
.002 w
.44894 .35782 m .4341 .34996 L .41592 .37277 L p
1 g
F P
s
P
p
.002 w
.4341 .34996 m .44894 .35782 L .4615 .33312 L p
1 g
F P
s
P
p
.002 w
.47047 .33491 m .4615 .33312 L .44894 .35782 L p
1 g
F P
s
P
p
.002 w
.62085 .39838 m .59171 .43084 L .60591 .4543 L p
1 g
F P
s
P
p
.002 w
.59171 .43084 m .62085 .39838 L .60065 .37898 L p
1 g
F P
s
P
p
.002 w
.36694 .47366 m .41041 .49377 L .41432 .46664 L p
1 g
F P
s
P
p
.002 w
.41432 .46664 m .37502 .44797 L .36694 .47366 L p
1 g
F P
s
P
p
.002 w
.46495 .55243 m .523 .54732 L .51808 .52324 L p
1 g
F P
s
P
p
.002 w
.51808 .52324 m .46226 .52803 L .46495 .55243 L p
1 g
F P
s
P
p
.002 w
.57141 .50599 m .51808 .52324 L .523 .54732 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .47047 .33491 L .47996 .33424 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .47996 .33424 L .48897 .33119 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .48897 .33119 L .49657 .32606 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .4615 .33312 L .47047 .33491 L closepath p
1 g
F P
s
P
p
.002 w
.56197 .32343 m .55392 .34496 L .57818 .36106 L p
1 g
F P
s
P
p
.002 w
.55392 .34496 m .56197 .32343 L .53361 .31622 L p
1 g
F P
s
P
p
.002 w
.53361 .31622 m .52834 .33097 L .55392 .34496 L p
1 g
F P
s
P
p
.002 w
.37925 .37565 m .3998 .39702 L .41592 .37277 L p
1 g
F P
s
P
p
.002 w
.41592 .37277 m .40027 .35601 L .37925 .37565 L p
1 g
F P
s
P
p
.002 w
.40027 .35601 m .41592 .37277 L .4341 .34996 L p
1 g
F P
s
P
p
.002 w
.52834 .33097 m .53361 .31622 L .5045 .31186 L p
1 g
F P
s
P
p
.002 w
.5045 .31186 m .50194 .31938 L .52834 .33097 L p
1 g
F P
s
P
p
.002 w
.523 .54732 m .57852 .52948 L .57141 .50599 L p
1 g
F P
s
P
p
.002 w
.61772 .47759 m .57141 .50599 L .57852 .52948 L p
1 g
F P
s
P
p
.002 w
.57141 .50599 m .61772 .47759 L .60591 .4543 L p
1 g
F P
s
P
p
.002 w
.4341 .34996 m .4236 .33838 L .40027 .35601 L p
1 g
F P
s
P
p
.002 w
.4236 .33838 m .4341 .34996 L .45399 .32904 L p
1 g
F P
s
P
p
.002 w
.4615 .33312 m .45399 .32904 L .4341 .34996 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .49657 .32606 L .50194 .31938 L closepath p
1 g
F P
s
P
p
.002 w
.40918 .54418 m .46495 .55243 L .46226 .52803 L p
1 g
F P
s
P
p
.002 w
.46226 .52803 m .40866 .51981 L .40918 .54418 L p
1 g
F P
s
P
p
.002 w
.58899 .33339 m .57818 .36106 L .60065 .37898 L p
1 g
F P
s
P
p
.002 w
.57818 .36106 m .58899 .33339 L .56197 .32343 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .45399 .32904 L .4615 .33312 L closepath p
1 g
F P
s
P
p
.002 w
.36102 .39693 m .38606 .42225 L .3998 .39702 L p
1 g
F P
s
P
p
.002 w
.3998 .39702 m .37925 .37565 L .36102 .39693 L p
1 g
F P
s
P
p
.002 w
.63834 .41889 m .60591 .4543 L .61772 .47759 L p
1 g
F P
s
P
p
.002 w
.60591 .4543 m .63834 .41889 L .62085 .39838 L p
1 g
F P
s
P
p
.002 w
.36208 .49879 m .40866 .51981 L .41041 .49377 L p
1 g
F P
s
P
p
.002 w
.41041 .49377 m .36694 .47366 L .36208 .49879 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .50194 .31938 L .5045 .31186 L closepath p
1 g
F P
s
P
p
.002 w
.45399 .32904 m .44875 .32308 L .4236 .33838 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .44875 .32308 L .45399 .32904 L closepath p
1 g
F P
s
P
p
.002 w
.6141 .34592 m .60065 .37898 L .62085 .39838 L p
1 g
F P
s
P
p
.002 w
.60065 .37898 m .6141 .34592 L .58899 .33339 L p
1 g
F P
s
P
p
.002 w
.34601 .41943 m .37502 .44797 L .38606 .42225 L p
1 g
F P
s
P
p
.002 w
.38606 .42225 m .36102 .39693 L .34601 .41943 L p
1 g
F P
s
P
p
.002 w
.50395 .30427 m .5045 .31186 L .53361 .31622 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .5045 .31186 L .50395 .30427 L closepath p
1 g
F P
s
P
p
.002 w
.41867 .32421 m .4236 .33838 L .44875 .32308 L p
1 g
F P
s
P
p
.002 w
.44875 .32308 m .44638 .31587 L .41867 .32421 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .44638 .31587 L .44875 .32308 L closepath p
1 g
F P
s
P
p
.002 w
.4686 .57439 m .52748 .56911 L .523 .54732 L p
1 g
F P
s
P
p
.002 w
.523 .54732 m .46495 .55243 L .4686 .57439 L p
1 g
F P
s
P
p
.002 w
.57852 .52948 m .523 .54732 L .52748 .56911 L p
1 g
F P
s
P
p
.002 w
.53276 .30123 m .53361 .31622 L .56197 .32343 L p
1 g
F P
s
P
p
.002 w
.53361 .31622 m .53276 .30123 L .50395 .30427 L p
1 g
F P
s
P
p
.002 w
.39268 .33533 m .40027 .35601 L .4236 .33838 L p
1 g
F P
s
P
p
.002 w
.4236 .33838 m .41867 .32421 L .39268 .33533 L p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .50029 .29746 L .49389 .29217 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .49389 .29217 L .48544 .28902 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .48544 .28902 L .47587 .28837 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .47587 .28837 L .46624 .29031 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .46624 .29031 L .45765 .29462 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .45765 .29462 L .45105 .3008 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .45105 .3008 L .44716 .30816 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .44716 .30816 L .44638 .31587 L closepath p
1 g
F P
s
P
p
.002 w
.47523 .31044 m .50395 .30427 L .50029 .29746 L closepath p
1 g
F P
s
P
p
.002 w
.56108 .30141 m .56197 .32343 L .58899 .33339 L p
1 g
F P
s
P
p
.002 w
.56197 .32343 m .56108 .30141 L .53276 .30123 L p
1 g
F P
s
P
p
.002 w
.36902 .34905 m .37925 .37565 L .40027 .35601 L p
1 g
F P
s
P
p
.002 w
.40027 .35601 m .39268 .33533 L .36902 .34905 L p
1 g
F P
s
P
p
.002 w
.63673 .36081 m .62085 .39838 L .63834 .41889 L p
1 g
F P
s
P
p
.002 w
.62085 .39838 m .63673 .36081 L .6141 .34592 L p
1 g
F P
s
P
p
.002 w
.33465 .44269 m .36694 .47366 L .37502 .44797 L p
1 g
F P
s
P
p
.002 w
.37502 .44797 m .34601 .41943 L .33465 .44269 L p
1 g
F P
s
P
p
.002 w
.50029 .29746 m .50395 .30427 L .53276 .30123 L p
1 g
F P
s
P
p
.002 w
.52748 .56911 m .58383 .5511 L .57852 .52948 L p
1 g
F P
s
P
p
.002 w
.62682 .50022 m .57852 .52948 L .58383 .5511 L p
1 g
F P
s
P
p
.002 w
.57852 .52948 m .62682 .50022 L .61772 .47759 L p
1 g
F P
s
P
p
.002 w
.41998 .30893 m .41867 .32421 L .44638 .31587 L p
1 g
F P
s
P
p
.002 w
.44638 .31587 m .44716 .30816 L .41998 .30893 L p
1 g
F P
s
P
p
.002 w
.65267 .44013 m .61772 .47759 L .62682 .50022 L p
1 g
F P
s
P
p
.002 w
.61772 .47759 m .65267 .44013 L .63834 .41889 L p
1 g
F P
s
P
p
.002 w
.41205 .56631 m .4686 .57439 L .46495 .55243 L p
1 g
F P
s
P
p
.002 w
.46495 .55243 m .40918 .54418 L .41205 .56631 L p
1 g
F P
s
P
p
.002 w
.36067 .52279 m .40918 .54418 L .40866 .51981 L p
1 g
F P
s
P
p
.002 w
.40866 .51981 m .36208 .49879 L .36067 .52279 L p
1 g
F P
s
P
p
.002 w
.5883 .30488 m .58899 .33339 L .6141 .34592 L p
1 g
F P
s
P
p
.002 w
.58899 .33339 m .5883 .30488 L .56108 .30141 L p
1 g
F P
s
P
p
.002 w
.34824 .36515 m .36102 .39693 L .37925 .37565 L p
1 g
F P
s
P
p
.002 w
.37925 .37565 m .36902 .34905 L .34824 .36515 L p
1 g
F P
s
P
p
.002 w
.53276 .30123 m .52573 .28764 L .50029 .29746 L p
1 g
F P
s
P
p
.002 w
.49389 .29217 m .50029 .29746 L .52573 .28764 L p
1 g
F P
s
P
p
.002 w
.42755 .29424 m .41998 .30893 L .44716 .30816 L p
1 g
F P
s
P
p
.002 w
.44716 .30816 m .45105 .3008 L .42755 .29424 L p
1 g
F P
s
P
p
.002 w
.52573 .28764 m .53276 .30123 L .56108 .30141 L p
1 g
F P
s
P
p
.002 w
.39429 .31283 m .39268 .33533 L .41867 .32421 L p
1 g
F P
s
P
p
.002 w
.41867 .32421 m .41998 .30893 L .39429 .31283 L p
1 g
F P
s
P
p
.002 w
.52573 .28764 m .51315 .277 L .49389 .29217 L p
1 g
F P
s
P
p
.002 w
.48544 .28902 m .49389 .29217 L .51315 .277 L p
1 g
F P
s
P
p
.002 w
.44064 .28181 m .42755 .29424 L .45105 .3008 L p
1 g
F P
s
P
p
.002 w
.45105 .3008 m .45765 .29462 L .44064 .28181 L p
1 g
F P
s
P
p
.002 w
.65632 .37782 m .63834 .41889 L .65267 .44013 L p
1 g
F P
s
P
p
.002 w
.63834 .41889 m .65632 .37782 L .63673 .36081 L p
1 g
F P
s
P
p
.002 w
.32733 .46621 m .36208 .49879 L .36694 .47366 L p
1 g
F P
s
P
p
.002 w
.36694 .47366 m .33465 .44269 L .32733 .46621 L p
1 g
F P
s
P
p
.002 w
.47317 .59334 m .5314 .58803 L .52748 .56911 L p
1 g
F P
s
P
p
.002 w
.52748 .56911 m .4686 .57439 L .47317 .59334 L p
1 g
F P
s
P
p
.002 w
.58383 .5511 m .52748 .56911 L .5314 .58803 L p
1 g
F P
s
P
p
.002 w
.61378 .31166 m .6141 .34592 L .63673 .36081 L p
1 g
F P
s
P
p
.002 w
.6141 .34592 m .61378 .31166 L .5883 .30488 L p
1 g
F P
s
P
p
.002 w
.51315 .277 m .49633 .2706 L .48544 .28902 L p
1 g
F P
s
P
p
.002 w
.47587 .28837 m .48544 .28902 L .49633 .2706 L p
1 g
F P
s
P
p
.002 w
.45783 .27313 m .44064 .28181 L .45765 .29462 L p
1 g
F P
s
P
p
.002 w
.45765 .29462 m .46624 .29031 L .45783 .27313 L p
1 g
F P
s
P
p
.002 w
.55103 .28127 m .56108 .30141 L .5883 .30488 L p
1 g
F P
s
P
p
.002 w
.56108 .30141 m .55103 .28127 L .52573 .28764 L p
1 g
F P
s
P
p
.002 w
.33093 .38334 m .34601 .41943 L .36102 .39693 L p
1 g
F P
s
P
p
.002 w
.36102 .39693 m .34824 .36515 L .33093 .38334 L p
1 g
F P
s
P
p
.002 w
.37072 .31988 m .36902 .34905 L .39268 .33533 L p
1 g
F P
s
P
p
.002 w
.39268 .33533 m .39429 .31283 L .37072 .31988 L p
1 g
F P
s
P
p
.002 w
.49633 .2706 m .47715 .26924 L .47587 .28837 L p
1 g
F P
s
P
p
.002 w
.46624 .29031 m .47587 .28837 L .47715 .26924 L p
1 g
F P
s
P
p
.002 w
.47715 .26924 m .45783 .27313 L .46624 .29031 L p
1 g
F P
s
P
p
.002 w
.58383 .5511 m .63292 .52168 L .62682 .50022 L p
1 g
F P
s
P
p
.002 w
.66342 .46166 m .62682 .50022 L .63292 .52168 L p
1 g
F P
s
P
p
.002 w
.62682 .50022 m .66342 .46166 L .65267 .44013 L p
1 g
F P
s
P
p
.002 w
.51315 .277 m .52573 .28764 L .55103 .28127 L p
1 g
F P
s
P
p
.002 w
.36286 .54506 m .41205 .56631 L .40918 .54418 L p
1 g
F P
s
P
p
.002 w
.40918 .54418 m .36067 .52279 L .36286 .54506 L p
1 g
F P
s
P
p
.002 w
.40526 .29102 m .39429 .31283 L .41998 .30893 L p
1 g
F P
s
P
p
.002 w
.41998 .30893 m .42755 .29424 L .40526 .29102 L p
1 g
F P
s
P
p
.002 w
.5314 .58803 m .58715 .5703 L .58383 .5511 L p
1 g
F P
s
P
p
.002 w
.63292 .52168 m .58383 .5511 L .58715 .5703 L p
1 g
F P
s
P
p
.002 w
.41731 .58561 m .47317 .59334 L .4686 .57439 L p
1 g
F P
s
P
p
.002 w
.4686 .57439 m .41205 .56631 L .41731 .58561 L p
1 g
F P
s
P
p
.002 w
.67231 .39661 m .65267 .44013 L .66342 .46166 L p
1 g
F P
s
P
p
.002 w
.65267 .44013 m .67231 .39661 L .65632 .37782 L p
1 g
F P
s
P
p
.002 w
.6369 .32169 m .63673 .36081 L .65632 .37782 L p
1 g
F P
s
P
p
.002 w
.63673 .36081 m .6369 .32169 L .61378 .31166 L p
1 g
F P
s
P
p
.002 w
.57561 .27862 m .5883 .30488 L .61378 .31166 L p
1 g
F P
s
P
p
.002 w
.5883 .30488 m .57561 .27862 L .55103 .28127 L p
1 g
F P
s
P
p
.002 w
.32438 .48944 m .36067 .52279 L .36208 .49879 L p
1 g
F P
s
P
p
.002 w
.36208 .49879 m .32733 .46621 L .32438 .48944 L p
1 g
F P
s
P
p
.002 w
.55103 .28127 m .5326 .26538 L .51315 .277 L p
1 g
F P
s
P
p
.002 w
.49633 .2706 m .51315 .277 L .5326 .26538 L p
1 g
F P
s
P
p
.002 w
.34989 .33002 m .34824 .36515 L .36902 .34905 L p
1 g
F P
s
P
p
.002 w
.36902 .34905 m .37072 .31988 L .34989 .33002 L p
1 g
F P
s
P
p
.002 w
.42461 .27245 m .40526 .29102 L .42755 .29424 L p
1 g
F P
s
P
p
.002 w
.42755 .29424 m .44064 .28181 L .42461 .27245 L p
1 g
F P
s
P
p
.002 w
.31763 .40327 m .33465 .44269 L .34601 .41943 L p
1 g
F P
s
P
p
.002 w
.34601 .41943 m .33093 .38334 L .31763 .40327 L p
1 g
F P
s
P
p
.002 w
.5326 .26538 m .55103 .28127 L .57561 .27862 L p
1 g
F P
s
P
p
.002 w
.38477 .29136 m .37072 .31988 L .39429 .31283 L p
1 g
F P
s
P
p
.002 w
.39429 .31283 m .40526 .29102 L .38477 .29136 L p
1 g
F P
s
P
p
.002 w
.5326 .26538 m .50767 .25574 L .49633 .2706 L p
1 g
F P
s
P
p
.002 w
.47715 .26924 m .49633 .2706 L .50767 .25574 L p
1 g
F P
s
P
p
.002 w
.45022 .25945 m .42461 .27245 L .44064 .28181 L p
1 g
F P
s
P
p
.002 w
.44064 .28181 m .45783 .27313 L .45022 .25945 L p
1 g
F P
s
P
p
.002 w
.47861 .6087 m .53464 .60353 L .5314 .58803 L p
1 g
F P
s
P
p
.002 w
.5314 .58803 m .47317 .59334 L .47861 .6087 L p
1 g
F P
s
P
p
.002 w
.58715 .5703 m .5314 .58803 L .53464 .60353 L p
1 g
F P
s
P
p
.002 w
.58715 .5703 m .63574 .54145 L .63292 .52168 L p
1 g
F P
s
P
p
.002 w
.6702 .48299 m .63292 .52168 L .63574 .54145 L p
1 g
F P
s
P
p
.002 w
.63292 .52168 m .6702 .48299 L .66342 .46166 L p
1 g
F P
s
P
p
.002 w
.36877 .565 m .41731 .58561 L .41205 .56631 L p
1 g
F P
s
P
p
.002 w
.41205 .56631 m .36286 .54506 L .36877 .565 L p
1 g
F P
s
P
p
.002 w
.50767 .25574 m .47908 .25364 L .47715 .26924 L p
1 g
F P
s
P
p
.002 w
.45783 .27313 m .47715 .26924 L .47908 .25364 L p
1 g
F P
s
P
p
.002 w
.47908 .25364 m .45022 .25945 L .45783 .27313 L p
1 g
F P
s
P
p
.002 w
.59889 .27988 m .61378 .31166 L .6369 .32169 L p
1 g
F P
s
P
p
.002 w
.61378 .31166 m .59889 .27988 L .57561 .27862 L p
1 g
F P
s
P
p
.002 w
.53464 .60353 m .58831 .58652 L .58715 .5703 L p
1 g
F P
s
P
p
.002 w
.63574 .54145 m .58715 .5703 L .58831 .58652 L p
1 g
F P
s
P
p
.002 w
.65702 .33487 m .65632 .37782 L .67231 .39661 L p
1 g
F P
s
P
p
.002 w
.65632 .37782 m .65702 .33487 L .6369 .32169 L p
1 g
F P
s
P
p
.002 w
.42495 .60146 m .47861 .6087 L .47317 .59334 L p
1 g
F P
s
P
p
.002 w
.47317 .59334 m .41731 .58561 L .42495 .60146 L p
1 g
F P
s
P
p
.002 w
.33243 .34316 m .33093 .38334 L .34824 .36515 L p
1 g
F P
s
P
p
.002 w
.34824 .36515 m .34989 .33002 L .33243 .34316 L p
1 g
F P
s
P
p
.002 w
.30883 .42452 m .32733 .46621 L .33465 .44269 L p
1 g
F P
s
P
p
.002 w
.33465 .44269 m .31763 .40327 L .30883 .42452 L p
1 g
F P
s
P
p
.002 w
.68419 .41683 m .66342 .46166 L .6702 .48299 L p
1 g
F P
s
P
p
.002 w
.66342 .46166 m .68419 .41683 L .67231 .39661 L p
1 g
F P
s
P
p
.002 w
.32607 .5118 m .36286 .54506 L .36067 .52279 L p
1 g
F P
s
P
p
.002 w
.36067 .52279 m .32438 .48944 L .32607 .5118 L p
1 g
F P
s
P
p
.002 w
.57561 .27862 m .5518 .25774 L .5326 .26538 L p
1 g
F P
s
P
p
.002 w
.50767 .25574 m .5326 .26538 L .5518 .25774 L p
1 g
F P
s
P
p
.002 w
.40999 .26695 m .38477 .29136 L .40526 .29102 L p
1 g
F P
s
P
p
.002 w
.40526 .29102 m .42461 .27245 L .40999 .26695 L p
1 g
F P
s
P
p
.002 w
.5518 .25774 m .57561 .27862 L .59889 .27988 L p
1 g
F P
s
P
p
.002 w
.36664 .29544 m .34989 .33002 L .37072 .31988 L p
1 g
F P
s
P
p
.002 w
.37072 .31988 m .38477 .29136 L .36664 .29544 L p
1 g
F P
s
P
p
.002 w
.62024 .2852 m .6369 .32169 L .65702 .33487 L p
1 g
F P
s
P
p
.002 w
.6369 .32169 m .62024 .2852 L .59889 .27988 L p
1 g
F P
s
P
p
.002 w
.5518 .25774 m .51923 .24497 L .50767 .25574 L p
1 g
F P
s
P
p
.002 w
.47908 .25364 m .50767 .25574 L .51923 .24497 L p
1 g
F P
s
P
p
.002 w
.44364 .24979 m .40999 .26695 L .42461 .27245 L p
1 g
F P
s
P
p
.002 w
.42461 .27245 m .45022 .25945 L .44364 .24979 L p
1 g
F P
s
P
p
.002 w
.58831 .58652 m .63506 .55898 L .63574 .54145 L p
1 g
F P
s
P
p
.002 w
.67266 .5036 m .63574 .54145 L .63506 .55898 L p
1 g
F P
s
P
p
.002 w
.63574 .54145 m .67266 .5036 L .6702 .48299 L p
1 g
F P
s
P
p
.002 w
.31895 .35911 m .31763 .40327 L .33093 .38334 L p
1 g
F P
s
P
p
.002 w
.33093 .38334 m .33243 .34316 L .31895 .35911 L p
1 g
F P
s
P
p
.002 w
.67352 .35099 m .67231 .39661 L .68419 .41683 L p
1 g
F P
s
P
p
.002 w
.67231 .39661 m .67352 .35099 L .65702 .33487 L p
1 g
F P
s
P
p
.002 w
.37845 .58197 m .42495 .60146 L .41731 .58561 L p
1 g
F P
s
P
p
.002 w
.41731 .58561 m .36877 .565 L .37845 .58197 L p
1 g
F P
s
P
p
.002 w
.30497 .44659 m .32438 .48944 L .32733 .46621 L p
1 g
F P
s
P
p
.002 w
.32733 .46621 m .30883 .42452 L .30497 .44659 L p
1 g
F P
s
P
p
.002 w
.48484 .6199 m .53708 .61503 L .53464 .60353 L p
1 g
F P
s
P
p
.002 w
.53464 .60353 m .47861 .6087 L .48484 .6199 L p
1 g
F P
s
P
p
.002 w
.58831 .58652 m .53464 .60353 L .53708 .61503 L p
1 g
F P
s
P
p
.002 w
.69148 .43803 m .6702 .48299 L .67266 .5036 L p
1 g
F P
s
P
p
.002 w
.6702 .48299 m .69148 .43803 L .68419 .41683 L p
1 g
F P
s
P
p
.002 w
.51923 .24497 m .48164 .24214 L .47908 .25364 L p
1 g
F P
s
P
p
.002 w
.45022 .25945 m .47908 .25364 L .48164 .24214 L p
1 g
F P
s
P
p
.002 w
.48164 .24214 m .44364 .24979 L .45022 .25945 L p
1 g
F P
s
P
p
.002 w
.33256 .53264 m .36877 .565 L .36286 .54506 L p
1 g
F P
s
P
p
.002 w
.36286 .54506 m .32607 .5118 L .33256 .53264 L p
1 g
F P
s
P
p
.002 w
.53708 .61503 m .58715 .59921 L .58831 .58652 L p
1 g
F P
s
P
p
.002 w
.63506 .55898 m .58831 .58652 L .58715 .59921 L p
1 g
F P
s
P
p
.002 w
.43491 .61329 m .48484 .6199 L .47861 .6087 L p
1 g
F P
s
P
p
.002 w
.47861 .6087 m .42495 .60146 L .43491 .61329 L p
1 g
F P
s
P
p
.002 w
.57028 .25445 m .59889 .27988 L .62024 .2852 L p
1 g
F P
s
P
p
.002 w
.59889 .27988 m .57028 .25445 L .5518 .25774 L p
1 g
F P
s
P
p
.002 w
.51923 .24497 m .5518 .25774 L .57028 .25445 L p
1 g
F P
s
P
p
.002 w
.35149 .30335 m .33243 .34316 L .34989 .33002 L p
1 g
F P
s
P
p
.002 w
.34989 .33002 m .36664 .29544 L .35149 .30335 L p
1 g
F P
s
P
p
.002 w
.39723 .26566 m .36664 .29544 L .38477 .29136 L p
1 g
F P
s
P
p
.002 w
.38477 .29136 m .40999 .26695 L .39723 .26566 L p
1 g
F P
s
P
p
.002 w
.63902 .29464 m .65702 .33487 L .67352 .35099 L p
1 g
F P
s
P
p
.002 w
.65702 .33487 m .63902 .29464 L .62024 .2852 L p
1 g
F P
s
P
p
.002 w
.31 .37757 m .30883 .42452 L .31763 .40327 L p
1 g
F P
s
P
p
.002 w
.31763 .40327 m .31895 .35911 L .31 .37757 L p
1 g
F P
s
P
p
.002 w
.6858 .36979 m .68419 .41683 L .69148 .43803 L p
1 g
F P
s
P
p
.002 w
.68419 .41683 m .6858 .36979 L .67352 .35099 L p
1 g
F P
s
P
p
.002 w
.3064 .46893 m .32607 .5118 L .32438 .48944 L p
1 g
F P
s
P
p
.002 w
.32438 .48944 m .30497 .44659 L .3064 .46893 L p
1 g
F P
s
P
p
.002 w
.58715 .59921 m .6307 .57369 L .63506 .55898 L p
1 g
F P
s
P
p
.002 w
.67054 .52294 m .63506 .55898 L .6307 .57369 L p
1 g
F P
s
P
p
.002 w
.63506 .55898 m .67054 .52294 L .67266 .5036 L p
1 g
F P
s
P
p
.002 w
.57028 .25445 m .53073 .2388 L .51923 .24497 L p
1 g
F P
s
P
p
.002 w
.48164 .24214 m .51923 .24497 L .53073 .2388 L p
1 g
F P
s
P
p
.002 w
.43832 .24465 m .39723 .26566 L .40999 .26695 L p
1 g
F P
s
P
p
.002 w
.40999 .26695 m .44364 .24979 L .43832 .24465 L p
1 g
F P
s
P
p
.002 w
.39182 .59537 m .43491 .61329 L .42495 .60146 L p
1 g
F P
s
P
p
.002 w
.42495 .60146 m .37845 .58197 L .39182 .59537 L p
1 g
F P
s
P
p
.002 w
.69376 .4597 m .67266 .5036 L .67054 .52294 L p
1 g
F P
s
P
p
.002 w
.67266 .5036 m .69376 .4597 L .69148 .43803 L p
1 g
F P
s
P
p
.002 w
.34392 .55134 m .37845 .58197 L .36877 .565 L p
1 g
F P
s
P
p
.002 w
.36877 .565 m .33256 .53264 L .34392 .55134 L p
1 g
F P
s
P
p
.002 w
.49175 .62639 m .53862 .62199 L .53708 .61503 L p
1 g
F P
s
P
p
.002 w
.53708 .61503 m .48484 .6199 L .49175 .62639 L p
1 g
F P
s
P
p
.002 w
.58715 .59921 m .53708 .61503 L .53862 .62199 L p
1 g
F P
s
P
p
.002 w
.58752 .25583 m .62024 .2852 L .63902 .29464 L p
1 g
F P
s
P
p
.002 w
.62024 .2852 m .58752 .25583 L .57028 .25445 L p
1 g
F P
s
P
p
.002 w
.33988 .31509 m .31895 .35911 L .33243 .34316 L p
1 g
F P
s
P
p
.002 w
.33243 .34316 m .35149 .30335 L .33988 .31509 L p
1 g
F P
s
P
p
.002 w
.53073 .2388 m .48481 .2353 L .48164 .24214 L p
1 g
F P
s
P
p
.002 w
.44364 .24979 m .48164 .24214 L .48481 .2353 L p
1 g
F P
s
P
p
.002 w
.48481 .2353 m .43832 .24465 L .44364 .24979 L p
1 g
F P
s
P
p
.002 w
.53073 .2388 m .57028 .25445 L .58752 .25583 L p
1 g
F P
s
P
p
.002 w
.38679 .26888 m .35149 .30335 L .36664 .29544 L p
1 g
F P
s
P
p
.002 w
.36664 .29544 m .39723 .26566 L .38679 .26888 L p
1 g
F P
s
P
p
.002 w
.53862 .62199 m .58356 .60782 L .58715 .59921 L p
1 g
F P
s
P
p
.002 w
.6307 .57369 m .58715 .59921 L .58356 .60782 L p
1 g
F P
s
P
p
.002 w
.44706 .62053 m .49175 .62639 L .48484 .6199 L p
1 g
F P
s
P
p
.002 w
.48484 .6199 m .43491 .61329 L .44706 .62053 L p
1 g
F P
s
P
p
.002 w
.6546 .30814 m .67352 .35099 L .6858 .36979 L p
1 g
F P
s
P
p
.002 w
.67352 .35099 m .6546 .30814 L .63902 .29464 L p
1 g
F P
s
P
p
.002 w
.30609 .39815 m .30497 .44659 L .30883 .42452 L p
1 g
F P
s
P
p
.002 w
.30883 .42452 m .31 .37757 L .30609 .39815 L p
1 g
F P
s
P
p
.002 w
.69333 .39087 m .69148 .43803 L .69376 .4597 L p
1 g
F P
s
P
p
.002 w
.69148 .43803 m .69333 .39087 L .6858 .36979 L p
1 g
F P
s
P
p
.002 w
.31332 .4909 m .33256 .53264 L .32607 .5118 L p
1 g
F P
s
P
p
.002 w
.32607 .5118 m .3064 .46893 L .31332 .4909 L p
1 g
F P
s
P
p
.002 w
.58356 .60782 m .62256 .58504 L .6307 .57369 L p
1 g
F P
s
P
p
.002 w
.66364 .54042 m .6307 .57369 L .62256 .58504 L p
1 g
F P
s
P
p
.002 w
.6307 .57369 m .66364 .54042 L .67054 .52294 L p
1 g
F P
s
P
p
.002 w
.69075 .48128 m .67054 .52294 L .66364 .54042 L p
1 g
F P
s
P
p
.002 w
.67054 .52294 m .69075 .48128 L .69376 .4597 L p
1 g
F P
s
P
p
.002 w
.40872 .60462 m .44706 .62053 L .43491 .61329 L p
1 g
F P
s
P
p
.002 w
.43491 .61329 m .39182 .59537 L .40872 .60462 L p
1 g
F P
s
P
p
.002 w
.58752 .25583 m .54185 .23768 L .53073 .2388 L p
1 g
F P
s
P
p
.002 w
.48481 .2353 m .53073 .2388 L .54185 .23768 L p
1 g
F P
s
P
p
.002 w
.36007 .56723 m .39182 .59537 L .37845 .58197 L p
1 g
F P
s
P
p
.002 w
.37845 .58197 m .34392 .55134 L .36007 .56723 L p
1 g
F P
s
P
p
.002 w
.43448 .24447 m .38679 .26888 L .39723 .26566 L p
1 g
F P
s
P
p
.002 w
.39723 .26566 m .43832 .24465 L .43448 .24447 L p
1 g
F P
s
P
p
.002 w
.60299 .26212 m .63902 .29464 L .6546 .30814 L p
1 g
F P
s
P
p
.002 w
.63902 .29464 m .60299 .26212 L .58752 .25583 L p
1 g
F P
s
P
p
.002 w
.33236 .33055 m .31 .37757 L .31895 .35911 L p
1 g
F P
s
P
p
.002 w
.31895 .35911 m .33988 .31509 L .33236 .33055 L p
1 g
F P
s
P
p
.002 w
.49918 .62769 m .53915 .62393 L .53862 .62199 L p
1 g
F P
s
P
p
.002 w
.53862 .62199 m .49175 .62639 L .49918 .62769 L p
1 g
F P
s
P
p
.002 w
.58356 .60782 m .53862 .62199 L .53915 .62393 L p
1 g
F P
s
P
p
.002 w
.54185 .23768 m .58752 .25583 L .60299 .26212 L p
1 g
F P
s
P
p
.002 w
.6858 .36979 m .66638 .32554 L .6546 .30814 L p
1 g
F P
s
P
p
.002 w
.66638 .32554 m .6858 .36979 L .69333 .39087 L p
1 g
F P
s
P
p
.002 w
.3791 .2768 m .33988 .31509 L .35149 .30335 L p
1 g
F P
s
P
p
.002 w
.35149 .30335 m .38679 .26888 L .3791 .2768 L p
1 g
F P
s
P
p
.004 w
.54224 .63523 m
.54753 .66089 L
s
P
p
.004 w
.69938 .48857 m
.78008 .51208 L
s
P
p
.002 w
.30757 .42036 m .3064 .46893 L .30497 .44659 L p
1 g
F P
s
P
p
.002 w
.30497 .44659 m .30609 .39815 L .30757 .42036 L p
1 g
F P
s
P
p
.002 w
.54185 .23768 m .48855 .2336 L .48481 .2353 L p
1 g
F P
s
P
p
.002 w
.43832 .24465 m .48481 .2353 L .48855 .2336 L p
1 g
F P
s
P
p
.002 w
.48855 .2336 m .43448 .24447 L .43832 .24465 L p
1 g
F P
s
P
p
.002 w
.69376 .4597 m .69566 .41374 L .69333 .39087 L p
1 g
F P
s
P
p
.002 w
.69566 .41374 m .69376 .4597 L .69075 .48128 L p
1 g
F P
s
P
p
.002 w
.53915 .62393 m .57748 .61185 L .58356 .60782 L p
1 g
F P
s
P
p
.002 w
.62256 .58504 m .58356 .60782 L .57748 .61185 L p
1 g
F P
s
P
p
.002 w
.46119 .62272 m .49918 .62769 L .49175 .62639 L p
1 g
F P
s
P
p
.002 w
.49175 .62639 m .44706 .62053 L .46119 .62272 L p
1 g
F P
s
P
p
.002 w
.3258 .51183 m .34392 .55134 L .33256 .53264 L p
1 g
F P
s
P
p
.002 w
.33256 .53264 m .31332 .4909 L .3258 .51183 L p
1 g
F P
s
P
p
.002 w
.62256 .58504 m .65189 .55546 L .66364 .54042 L p
1 g
F P
s
P
p
.002 w
.66364 .54042 m .68225 .50213 L .69075 .48128 L p
1 g
F P
s
P
p
.002 w
.68225 .50213 m .66364 .54042 L .65189 .55546 L p
1 g
F P
s
P
p
.002 w
.6546 .30814 m .61613 .27341 L .60299 .26212 L p
1 g
F P
s
P
p
.002 w
.61613 .27341 m .6546 .30814 L .66638 .32554 L p
1 g
F P
s
P
p
.002 w
.38074 .57971 m .40872 .60462 L .39182 .59537 L p
1 g
F P
s
P
p
.002 w
.39182 .59537 m .36007 .56723 L .38074 .57971 L p
1 g
F P
s
P
p
.002 w
.57748 .61185 m .61064 .59249 L .62256 .58504 L p
1 g
F P
s
P
p
.002 w
.65189 .55546 m .62256 .58504 L .61064 .59249 L p
1 g
F P
s
P
p
.002 w
.32938 .34947 m .30609 .39815 L .31 .37757 L p
1 g
F P
s
P
p
.002 w
.31 .37757 m .33236 .33055 L .32938 .34947 L p
1 g
F P
s
P
p
.002 w
.42883 .60923 m .46119 .62272 L .44706 .62053 L p
1 g
F P
s
P
p
.002 w
.44706 .62053 m .40872 .60462 L .42883 .60923 L p
1 g
F P
s
P
p
.002 w
.60299 .26212 m .55226 .24196 L .54185 .23768 L p
1 g
F P
s
P
p
.002 w
.48855 .2336 m .54185 .23768 L .55226 .24196 L p
1 g
F P
s
P
p
.002 w
.43234 .24959 m .3791 .2768 L .38679 .26888 L p
1 g
F P
s
P
p
.002 w
.38679 .26888 m .43448 .24447 L .43234 .24959 L p
1 g
F P
s
P
p
.002 w
.67382 .34652 m .69333 .39087 L .69566 .41374 L p
1 g
F P
s
P
p
.002 w
.69333 .39087 m .67382 .34652 L .66638 .32554 L p
1 g
F P
s
P
p
.002 w
.31469 .44357 m .31332 .4909 L .3064 .46893 L p
1 g
F P
s
P
p
.002 w
.3064 .46893 m .30757 .42036 L .31469 .44357 L p
1 g
F P
s
P
p
.002 w
.55226 .24196 m .60299 .26212 L .61613 .27341 L p
1 g
F P
s
P
p
.002 w
.69248 .43781 m .69075 .48128 L .68225 .50213 L p
1 g
F P
s
P
p
.002 w
.69075 .48128 m .69248 .43781 L .69566 .41374 L p
1 g
F P
s
P
p
.002 w
.37458 .28948 m .33236 .33055 L .33988 .31509 L p
1 g
F P
s
P
p
.002 w
.33988 .31509 m .3791 .2768 L .37458 .28948 L p
1 g
F P
s
P
p
.002 w
.34369 .53103 m .36007 .56723 L .34392 .55134 L p
1 g
F P
s
P
p
.002 w
.34392 .55134 m .3258 .51183 L .34369 .53103 L p
1 g
F P
s
P
p
.002 w
.50695 .62343 m .53859 .62046 L .53915 .62393 L p
1 g
F P
s
P
p
.002 w
.53915 .62393 m .49918 .62769 L .50695 .62343 L p
1 g
F P
s
P
p
.002 w
.57748 .61185 m .53915 .62393 L .53859 .62046 L p
1 g
F P
s
P
p
.002 w
.55226 .24196 m .49277 .23743 L .48855 .2336 L p
1 g
F P
s
P
p
.002 w
.43448 .24447 m .48855 .2336 L .49277 .23743 L p
1 g
F P
s
P
p
.002 w
.49277 .23743 m .43234 .24959 L .43448 .24447 L p
1 g
F P
s
P
p
.002 w
.53859 .62046 m .56892 .61089 L .57748 .61185 L p
1 g
F P
s
P
p
.002 w
.61064 .59249 m .57748 .61185 L .56892 .61089 L p
1 g
F P
s
P
p
.002 w
.477 .61946 m .50695 .62343 L .49918 .62769 L p
1 g
F P
s
P
p
.002 w
.49918 .62769 m .46119 .62272 L .477 .61946 L p
1 g
F P
s
P
p
.002 w
.62643 .28964 m .66638 .32554 L .67382 .34652 L p
1 g
F P
s
P
p
.002 w
.66638 .32554 m .62643 .28964 L .61613 .27341 L p
1 g
F P
s
P
p
.002 w
.61064 .59249 m .63539 .56746 L .65189 .55546 L p
1 g
F P
s
P
p
.002 w
.66826 .5216 m .65189 .55546 L .63539 .56746 L p
1 g
F P
s
P
p
.002 w
.65189 .55546 m .66826 .5216 L .68225 .50213 L p
1 g
F P
s
P
p
.002 w
.3313 .37144 m .30757 .42036 L .30609 .39815 L p
1 g
F P
s
P
p
.002 w
.30609 .39815 m .32938 .34947 L .3313 .37144 L p
1 g
F P
s
P
p
.002 w
.4055 .58822 m .42883 .60923 L .40872 .60462 L p
1 g
F P
s
P
p
.002 w
.40872 .60462 m .38074 .57971 L .4055 .58822 L p
1 g
F P
s
P
p
.002 w
.67646 .37061 m .69566 .41374 L .69248 .43781 L p
1 g
F P
s
P
p
.002 w
.69566 .41374 m .67646 .37061 L .67382 .34652 L p
1 g
F P
s
P
p
.002 w
.32746 .4671 m .3258 .51183 L .31332 .4909 L p
1 g
F P
s
P
p
.002 w
.31332 .4909 m .31469 .44357 L .32746 .4671 L p
1 g
F P
s
P
p
.002 w
.56892 .61089 m .59506 .59558 L .61064 .59249 L p
1 g
F P
s
P
p
.002 w
.63539 .56746 m .61064 .59249 L .59506 .59558 L p
1 g
F P
s
P
p
.002 w
.45169 .60881 m .477 .61946 L .46119 .62272 L p
1 g
F P
s
P
p
.002 w
.46119 .62272 m .42883 .60923 L .45169 .60881 L p
1 g
F P
s
P
p
.002 w
.68363 .46238 m .68225 .50213 L .66826 .5216 L p
1 g
F P
s
P
p
.002 w
.68225 .50213 m .68363 .46238 L .69248 .43781 L p
1 g
F P
s
P
p
.004 w
.69086 .48609 m
.69938 .48857 L
s
P
p
.004 w
.68761 .48515 m
.69086 .48609 L
s
P
p
.002 w
.61613 .27341 m .56159 .25184 L .55226 .24196 L p
1 g
F P
s
P
p
.002 w
.49277 .23743 m .55226 .24196 L .56159 .25184 L p
1 g
F P
s
P
p
.002 w
.36665 .54779 m .38074 .57971 L .36007 .56723 L p
1 g
F P
s
P
p
.002 w
.36007 .56723 m .34369 .53103 L .36665 .54779 L p
1 g
F P
s
P
p
.002 w
.43208 .2602 m .37458 .28948 L .3791 .2768 L p
1 g
F P
s
P
p
.002 w
.3791 .2768 m .43234 .24959 L .43208 .2602 L p
1 g
F P
s
P
p
.002 w
.56159 .25184 m .61613 .27341 L .62643 .28964 L p
1 g
F P
s
P
p
.002 w
.37356 .30681 m .32938 .34947 L .33236 .33055 L p
1 g
F P
s
P
p
.002 w
.33236 .33055 m .37458 .28948 L .37356 .30681 L p
1 g
F P
s
P
p
.002 w
.51486 .61337 m .53689 .61131 L .53859 .62046 L p
1 g
F P
s
P
p
.002 w
.53859 .62046 m .50695 .62343 L .51486 .61337 L p
1 g
F P
s
P
p
.002 w
.56892 .61089 m .53859 .62046 L .53689 .61131 L p
1 g
F P
s
P
p
.002 w
.56159 .25184 m .4974 .24706 L .49277 .23743 L p
1 g
F P
s
P
p
.002 w
.43234 .24959 m .49277 .23743 L .4974 .24706 L p
1 g
F P
s
P
p
.002 w
.4974 .24706 m .43208 .2602 L .43234 .24959 L p
1 g
F P
s
P
p
.002 w
.53689 .61131 m .558 .60464 L .56892 .61089 L p
1 g
F P
s
P
p
.002 w
.59506 .59558 m .56892 .61089 L .558 .60464 L p
1 g
F P
s
P
p
.002 w
.63338 .31058 m .67382 .34652 L .67646 .37061 L p
1 g
F P
s
P
p
.002 w
.67382 .34652 m .63338 .31058 L .62643 .28964 L p
1 g
F P
s
P
p
.002 w
.49409 .61056 m .51486 .61337 L .50695 .62343 L p
1 g
F P
s
P
p
.002 w
.50695 .62343 m .477 .61946 L .49409 .61056 L p
1 g
F P
s
P
p
.002 w
.3383 .39588 m .31469 .44357 L .30757 .42036 L p
1 g
F P
s
P
p
.002 w
.30757 .42036 m .3313 .37144 L .3383 .39588 L p
1 g
F P
s
P
p
.002 w
.674 .39718 m .69248 .43781 L .68363 .46238 L p
1 g
F P
s
P
p
.002 w
.69248 .43781 m .674 .39718 L .67646 .37061 L p
1 g
F P
s
P
p
.002 w
.59506 .59558 m .61439 .57591 L .63539 .56746 L p
1 g
F P
s
P
p
.002 w
.64895 .53901 m .63539 .56746 L .61439 .57591 L p
1 g
F P
s
P
p
.002 w
.63539 .56746 m .64895 .53901 L .66826 .5216 L p
1 g
F P
s
P
p
.002 w
.4337 .59232 m .45169 .60881 L .42883 .60923 L p
1 g
F P
s
P
p
.002 w
.42883 .60923 m .4055 .58822 L .4337 .59232 L p
1 g
F P
s
P
p
.002 w
.3457 .49014 m .34369 .53103 L .3258 .51183 L p
1 g
F P
s
P
p
.002 w
.3258 .51183 m .32746 .4671 L .3457 .49014 L p
1 g
F P
s
P
p
.002 w
.66916 .48668 m .66826 .5216 L .64895 .53901 L p
1 g
F P
s
P
p
.002 w
.66826 .5216 m .66916 .48668 L .68363 .46238 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.67267 .4808 L
s
P
p
.004 w
.68076 .48315 m
.68761 .48515 L
s
P
p
.004 w
.67939 .48275 m
.68076 .48315 L
s
P
p
.002 w
.3941 .56146 m .4055 .58822 L .38074 .57971 L p
1 g
F P
s
P
p
.002 w
.38074 .57971 m .36665 .54779 L .3941 .56146 L p
1 g
F P
s
P
p
.002 w
.558 .60464 m .57611 .59397 L .59506 .59558 L p
1 g
F P
s
P
p
.002 w
.61439 .57591 m .59506 .59558 L .57611 .59397 L p
1 g
F P
s
P
p
.002 w
.4767 .60312 m .49409 .61056 L .477 .61946 L p
1 g
F P
s
P
p
.002 w
.477 .61946 m .45169 .60881 L .4767 .60312 L p
1 g
F P
s
P
p
.002 w
.56949 .26737 m .62643 .28964 L .63338 .31058 L p
1 g
F P
s
P
p
.002 w
.62643 .28964 m .56949 .26737 L .56159 .25184 L p
1 g
F P
s
P
p
.002 w
.4974 .24706 m .56159 .25184 L .56949 .26737 L p
1 g
F P
s
P
p
.002 w
.37628 .32848 m .3313 .37144 L .32938 .34947 L p
1 g
F P
s
P
p
.002 w
.32938 .34947 m .37356 .30681 L .37628 .32848 L p
1 g
F P
s
P
p
.002 w
.43382 .2763 m .37356 .30681 L .37458 .28948 L p
1 g
F P
s
P
p
.002 w
.37458 .28948 m .43208 .2602 L .43382 .2763 L p
1 g
F P
s
P
p
.002 w
.6663 .42544 m .68363 .46238 L .66916 .48668 L p
1 g
F P
s
P
p
.002 w
.68363 .46238 m .6663 .42544 L .674 .39718 L p
1 g
F P
s
P
p
.002 w
.6366 .33575 m .67646 .37061 L .674 .39718 L p
1 g
F P
s
P
p
.002 w
.67646 .37061 m .6366 .33575 L .63338 .31058 L p
1 g
F P
s
P
p
.002 w
.36897 .5119 m .36665 .54779 L .34369 .53103 L p
1 g
F P
s
P
p
.002 w
.34369 .53103 m .3457 .49014 L .36897 .5119 L p
1 g
F P
s
P
p
.002 w
.35038 .42205 m .32746 .4671 L .31469 .44357 L p
1 g
F P
s
P
p
.002 w
.31469 .44357 m .3383 .39588 L .35038 .42205 L p
1 g
F P
s
P
p
.002 w
.57611 .59397 m .58935 .58034 L .61439 .57591 L p
1 g
F P
s
P
p
.002 w
.62474 .55369 m .61439 .57591 L .58935 .58034 L p
1 g
F P
s
P
p
.002 w
.61439 .57591 m .62474 .55369 L .64895 .53901 L p
1 g
F P
s
P
p
.002 w
.46454 .59169 m .4767 .60312 L .45169 .60881 L p
1 g
F P
s
P
p
.002 w
.45169 .60881 m .4337 .59232 L .46454 .59169 L p
1 g
F P
s
P
p
.002 w
.52264 .59748 m .53402 .59643 L .53689 .61131 L p
1 g
F P
s
P
p
.002 w
.53689 .61131 m .51486 .61337 L .52264 .59748 L p
1 g
F P
s
P
p
.002 w
.558 .60464 m .53689 .61131 L .53402 .59643 L p
1 g
F P
s
P
p
.002 w
.64933 .50989 m .64895 .53901 L .62474 .55369 L p
1 g
F P
s
P
p
.002 w
.64895 .53901 m .64933 .50989 L .66916 .48668 L p
1 g
F P
s
P
p
.002 w
.42524 .57147 m .4337 .59232 L .4055 .58822 L p
1 g
F P
s
P
p
.002 w
.4055 .58822 m .3941 .56146 L .42524 .57147 L p
1 g
F P
s
P
p
.002 w
.53402 .59643 m .54492 .59297 L .558 .60464 L p
1 g
F P
s
P
p
.002 w
.57611 .59397 m .558 .60464 L .54492 .59297 L p
1 g
F P
s
P
p
.002 w
.56949 .26737 m .50228 .26252 L .4974 .24706 L p
1 g
F P
s
P
p
.002 w
.43208 .2602 m .4974 .24706 L .50228 .26252 L p
1 g
F P
s
P
p
.002 w
.51195 .59599 m .52264 .59748 L .51486 .61337 L p
1 g
F P
s
P
p
.002 w
.51486 .61337 m .49409 .61056 L .51195 .59599 L p
1 g
F P
s
P
p
.002 w
.50228 .26252 m .43382 .2763 L .43208 .2602 L p
1 g
F P
s
P
p
.002 w
.54492 .59297 m .55422 .58744 L .57611 .59397 L p
1 g
F P
s
P
p
.002 w
.58935 .58034 m .57611 .59397 L .55422 .58744 L p
1 g
F P
s
P
p
.002 w
.50309 .59211 m .51195 .59599 L .49409 .61056 L p
1 g
F P
s
P
p
.002 w
.49409 .61056 m .4767 .60312 L .50309 .59211 L p
1 g
F P
s
P
p
.002 w
.5756 .28834 m .63338 .31058 L .6366 .33575 L p
1 g
F P
s
P
p
.002 w
.63338 .31058 m .5756 .28834 L .56949 .26737 L p
1 g
F P
s
P
p
.002 w
.38284 .35394 m .3383 .39588 L .3313 .37144 L p
1 g
F P
s
P
p
.002 w
.3313 .37144 m .37628 .32848 L .38284 .35394 L p
1 g
F P
s
P
p
.002 w
.65344 .45447 m .66916 .48668 L .64933 .50989 L p
1 g
F P
s
P
p
.002 w
.66916 .48668 m .65344 .45447 L .6663 .42544 L p
1 g
F P
s
P
p
.002 w
.39658 .53156 m .3941 .56146 L .36665 .54779 L p
1 g
F P
s
P
p
.002 w
.36665 .54779 m .36897 .5119 L .39658 .53156 L p
1 g
F P
s
P
p
.002 w
.50228 .26252 m .56949 .26737 L .5756 .28834 L p
1 g
F P
s
P
p
.002 w
.63579 .3645 m .674 .39718 L .6663 .42544 L p
1 g
F P
s
P
p
.002 w
.674 .39718 m .63579 .3645 L .6366 .33575 L p
1 g
F P
s
P
p
.002 w
.43762 .29766 m .37628 .32848 L .37356 .30681 L p
1 g
F P
s
P
p
.002 w
.37356 .30681 m .43382 .2763 L .43762 .29766 L p
1 g
F P
s
P
p
.002 w
.36728 .44908 m .3457 .49014 L .32746 .4671 L p
1 g
F P
s
P
p
.002 w
.32746 .4671 m .35038 .42205 L .36728 .44908 L p
1 g
F P
s
P
p
.002 w
.58935 .58034 m .59624 .56506 L .62474 .55369 L p
1 g
F P
s
P
p
.002 w
.62466 .53117 m .62474 .55369 L .59624 .56506 L p
1 g
F P
s
P
p
.002 w
.62474 .55369 m .62466 .53117 L .64933 .50989 L p
1 g
F P
s
P
p
.002 w
.45906 .57738 m .46454 .59169 L .4337 .59232 L p
1 g
F P
s
P
p
.002 w
.4337 .59232 m .42524 .57147 L .45906 .57738 L p
1 g
F P
s
P
p
.002 w
.55422 .58744 m .56094 .58042 L .58935 .58034 L p
1 g
F P
s
P
p
.002 w
.59624 .56506 m .58935 .58034 L .56094 .58042 L p
1 g
F P
s
P
p
.002 w
.49701 .58622 m .50309 .59211 L .4767 .60312 L p
1 g
F P
s
P
p
.002 w
.4767 .60312 m .46454 .59169 L .49701 .58622 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52347 .54427 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.53402 .59643 m .52264 .59748 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.54492 .59297 m .53402 .59643 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63573 .48326 m .64933 .50989 L .62466 .53117 L p
1 g
F P
s
P
p
.002 w
.64933 .50989 m .63573 .48326 L .65344 .45447 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.55422 .58744 m .54492 .59297 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.52264 .59748 m .51195 .59599 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.42764 .54836 m .42524 .57147 L .3941 .56146 L p
1 g
F P
s
P
p
.002 w
.3941 .56146 m .39658 .53156 L .42764 .54836 L p
1 g
F P
s
P
p
.002 w
.5756 .28834 m .50729 .28363 L .50228 .26252 L p
1 g
F P
s
P
p
.002 w
.43382 .2763 m .50228 .26252 L .50729 .28363 L p
1 g
F P
s
P
p
.002 w
.50729 .28363 m .43762 .29766 L .43382 .2763 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63084 .39591 m .6663 .42544 L .65344 .45447 L p
1 g
F P
s
P
p
.002 w
.6663 .42544 m .63084 .39591 L .63579 .3645 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.57962 .3143 m .6366 .33575 L .63579 .3645 L p
1 g
F P
s
P
p
.002 w
.6366 .33575 m .57962 .3143 L .5756 .28834 L p
1 g
F P
s
P
p
.002 w
.50309 .59211 m .49701 .58622 L .51555 .58047 L p
1 g
F P
s
P
p
.002 w
.51555 .58047 m .53001 .57598 L .52319 .58006 L p
1 g
F P
s
P
p
.002 w
.52319 .58006 m .50309 .59211 L p
.51555 .58047 L 1 g
F P
s
P
p
.002 w
.49701 .58622 m .46454 .59169 L p
.48954 .581 L 1 g
F P
s
P
p
.002 w
.48904 .58085 m .48921 .57862 L p
.4782 .57772 L 1 g
F P
s
P
p
.002 w
.48006 .57829 m .47407 .57803 L p
.4706 .57536 L 1 g
F P
s
P
p
.002 w
.47407 .57803 m .45906 .57738 L p
.46976 .57551 L 1 g
F P
s
P
p
.46976 .57551 m .4706 .57536 L .47407 .57803 L 1 g
F
P
p
.002 w
.45906 .57738 m .42524 .57147 L p
.45183 .56419 L 1 g
F P
s
P
p
.002 w
.45083 .56298 m .45146 .56129 L p
.44421 .55499 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.42524 .57147 m .42764 .54836 L .43509 .55133 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45083 .56298 L p
1 g
F P
s
P
p
.46872 .57265 m .45083 .56298 L .45821 .56845 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43845 .54716 L p
1 g
F P
s
P
p
.45146 .56129 m .43845 .54716 L .4409 .55048 L 1 g
F
P
p
.002 w
.44417 .55494 m .44063 .55353 L p
.43893 .54781 L 1 g
F P
s
P
p
.002 w
.44063 .55353 m .42764 .54836 L p
.43868 .54782 L 1 g
F P
s
P
p
.43868 .54782 m .43893 .54781 L .44063 .55353 L 1 g
F
P
p
.002 w
.42764 .54836 m .39658 .53156 L p
.43211 .52676 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43211 .52676 m .43261 .52857 L .42764 .54836 L 1 g
F
P
p
.002 w
.43476 .53633 m .43198 .54103 L p
.43261 .52857 L 1 g
F P
s
P
p
.002 w
.43198 .54103 m .42764 .54836 L p
.43261 .52857 L 1 g
F P
s
P
p
.002 w
.43261 .52857 m .43346 .52734 L p
.43315 .5184 L 1 g
F P
s
P
p
.41346 .50182 m .43474 .50345 L .43413 .50911 L 1 g
F
P
p
.002 w
.43312 .51867 m .43058 .51649 L p
.43413 .50911 L 1 g
F P
s
P
p
.002 w
.43058 .51649 m .41346 .50182 L p
.43413 .50911 L 1 g
F P
s
P
p
.002 w
.43413 .50911 m .43485 .50826 L p
.4373 .50252 L 1 g
F P
s
P
p
.43315 .5184 m .43312 .51867 L .43261 .52857 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43261 .52857 L p
1 g
F P
s
P
p
.45146 .56129 m .4409 .55048 L .44421 .55499 L 1 g
F
P
p
.002 w
.42764 .54836 m .43286 .53954 L p
.43868 .54782 L 1 g
F P
s
P
p
.4409 .55048 m .43817 .5477 L .44417 .55494 L 1 g
F
P
p
.4409 .55048 m .44417 .55494 L .44421 .55499 L 1 g
F
P
p
.002 w
.43286 .53954 m .43476 .53633 L p
.43845 .54716 L 1 g
F P
s
P
p
.43286 .53954 m .43845 .54716 L .43868 .54782 L 1 g
F
P
p
.43925 .54566 m .43261 .52857 L .43503 .53731 L 1 g
F
P
p
.002 w
.43845 .54716 m .43925 .54566 L p
.43522 .5377 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44114 .52554 m .47053 .54627 L p
.43868 .54782 L 1 g
F P
s
P
p
.002 w
.43476 .53633 m .44114 .52554 L p
.43868 .54782 L 1 g
F P
s
P
p
.43503 .53731 m .43476 .53633 L .43146 .53025 L 1 g
F
P
p
.002 w
.43261 .52857 m .43228 .52906 L p
.43476 .53633 L 1 g
F P
s
P
p
.002 w
.43228 .52906 m .43146 .53025 L p
.43476 .53633 L 1 g
F P
s
P
p
.002 w
.44114 .52554 m .43476 .53633 L p
.43261 .52857 L 1 g
F P
s
P
p
.43211 .52676 m .43271 .52668 L .43261 .52857 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43357 .50978 L p
1 g
F P
s
P
p
.43346 .52734 m .43357 .50978 L .43314 .51823 L 1 g
F
P
p
.43271 .52668 m .44114 .52554 L .43261 .52857 L 1 g
F
P
p
.002 w
.43357 .50978 m .43287 .51061 L p
.43314 .51823 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43413 .50911 m .46455 .50572 L .43312 .51867 L 1 g
F
P
p
.43474 .50345 m .43678 .5036 L .43413 .50911 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44277 .49116 L p
1 g
F P
s
P
p
.43485 .50826 m .44277 .49116 L .4373 .50252 L 1 g
F
P
p
.43678 .5036 m .46455 .50572 L .43413 .50911 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44277 .49116 m .44339 .4905 L p
.45048 .48371 L 1 g
F P
s
P
p
.45497 .47934 m .4953 .49142 L .44957 .48459 L 1 g
F
P
p
.45048 .48371 m .45137 .48286 L .44957 .48459 L 1 g
F
P
p
.45048 .48371 m .44957 .48459 L .44277 .49116 L 1 g
F
P
p
.002 w
.4953 .49142 m .46455 .50572 L .44957 .48459 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45778 .47661 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45497 .47934 m .45945 .47581 L .4953 .49142 L 1 g
F
P
p
.002 w
.45778 .47661 m .45826 .47608 L p
.4656 .47286 L 1 g
F P
s
P
p
.45945 .47581 m .47759 .46712 L .4953 .49142 L 1 g
F
P
p
.002 w
.47759 .46712 m .47786 .46667 L p
.48905 .46553 L 1 g
F P
s
P
p
.49561 .46447 m .5297 .48447 L .48626 .46599 L 1 g
F
P
p
.48905 .46553 m .49204 .46523 L .48626 .46599 L 1 g
F
P
p
.48905 .46553 m .48626 .46599 L .47759 .46712 L 1 g
F
P
p
.002 w
.5297 .48447 m .4953 .49142 L .48626 .46599 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48311 .45714 m .5277 .44814 L .52831 .45916 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.56351 .48574 m .5614 .48566 L p
.5277 .44814 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50922 L p
1 g
F P
s
P
p
.002 w
.5602 .49705 m .56351 .48574 L p
.56383 .48703 L 1 g
F P
s
P
p
.56383 .48703 m .57341 .52499 L .56595 .50922 L 1 g
F
P
p
.56383 .48703 m .56595 .50922 L .5602 .49705 L 1 g
F
P
p
.002 w
.56595 .50922 m .56515 .50826 L p
.56703 .52042 L 1 g
F P
s
P
p
.55661 .4905 m .56595 .50922 L .5618 .50044 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56756 .52882 L p
1 g
F P
s
P
p
.002 w
.57353 .52546 m .56774 .53294 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56733 .52357 m .56903 .52409 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56903 .52409 m .57353 .52546 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56756 .52882 m .56654 .52734 L p
.5645 .53851 L 1 g
F P
s
P
p
.002 w
.56529 .5361 m .57353 .52546 L p
.56635 .54043 L 1 g
F P
s
P
p
.56635 .54043 m .55842 .55698 L .56161 .54728 L 1 g
F
P
p
.56635 .54043 m .56161 .54728 L .56529 .5361 L 1 g
F
P
p
.002 w
.55986 .55798 m .55842 .55698 L p
.57353 .52546 L 1 g
F P
s
P
p
.002 w
.56161 .54728 m .56075 .54566 L p
.55432 .55731 L 1 g
F P
s
P
p
.002 w
.55986 .55798 m .547 .56574 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.55605 .55533 m .55836 .55694 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.55836 .55694 m .55986 .55798 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.54924 .56316 m .54854 .56129 L p
.53986 .56956 L 1 g
F P
s
P
p
.55432 .55731 m .55605 .55533 L .56161 .54728 L 1 g
F
P
p
.002 w
.53001 .57598 m .49701 .58622 L .49637 .58441 L p
1 g
F P
s
P
p
.002 w
.53181 .57505 m .53128 .57265 L p
.5216 .57794 L 1 g
F P
s
P
p
.5216 .57794 m .52887 .57607 L .53181 .57505 L 1 g
F
P
p
.002 w
.52951 .5759 m .53001 .57598 L .52887 .57607 L p
1 g
F P
s
P
p
.52887 .57607 m .52931 .57596 L .52934 .57595 L 1 g
F
P
p
.52887 .57607 m .52934 .57595 L .53181 .57505 L 1 g
F
P
p
.52931 .57596 m .52955 .57589 L .53181 .57505 L 1 g
F
P
p
.002 w
.52887 .57607 m .53001 .57598 L p
.51136 .58065 L 1 g
F P
s
P
p
.49637 .58441 m .51094 .58067 L .51136 .58065 L 1 g
F
P
p
.51094 .58067 m .52887 .57607 L .51136 .58065 L 1 g
F
P
p
.002 w
.51094 .58067 m .51079 .57862 L p
.49757 .58126 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51372 .58224 L p
.5216 .57794 L 1 g
F P
s
P
p
.53128 .57265 m .52035 .57826 L .5216 .57794 L 1 g
F
P
p
.52035 .57826 m .51111 .583 L .5216 .57794 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58085 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58085 L .49259 .58114 L 1 g
F
P
p
.4782 .57772 m .48006 .57829 L .48904 .58085 L 1 g
F
P
p
.002 w
.45906 .57738 m .4944 .57892 L p
.48974 .58091 L 1 g
F P
s
P
p
.002 w
.46454 .59169 m .45946 .57843 L p
.48974 .58091 L 1 g
F P
s
P
p
.002 w
.45946 .57843 m .45906 .57738 L p
.48974 .58091 L 1 g
F P
s
P
p
.48954 .581 m .48974 .58091 L .49005 .58114 L 1 g
F
P
p
.48954 .581 m .49005 .58114 L .49701 .58622 L 1 g
F
P
p
.002 w
.49528 .58137 m .49701 .58622 L p
.48974 .58091 L 1 g
F P
s
P
p
.002 w
.48904 .58085 m .48899 .58164 L p
.49259 .58114 L 1 g
F P
s
P
p
.002 w
.49637 .58441 m .49528 .58137 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.48899 .58164 m .48889 .583 L p
.49757 .58126 L 1 g
F P
s
P
p
.51079 .57862 m .48899 .58164 L .49757 .58126 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.4944 .57892 m .52887 .57607 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.49528 .58137 m .4944 .57892 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51094 .58067 L p
.49658 .58146 L 1 g
F P
s
P
p
.49757 .58126 m .49658 .58146 L .51094 .58067 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4944 .57892 m .4956 .57097 L .52951 .5759 L p
1 g
F P
s
P
p
.002 w
.52887 .57607 m .4944 .57892 L p
.52951 .5759 L 1 g
F P
s
P
p
.52951 .57591 m .52968 .57586 L .53181 .57505 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.4956 .57097 m .50053 .56326 L .52971 .57585 L p
1 g
F P
s
P
p
.002 w
.52971 .57585 m .53001 .57598 L .52951 .5759 L p
1 g
F P
s
P
p
.002 w
.52951 .5759 m .4956 .57097 L p
.52971 .57585 L 1 g
F P
s
P
p
.52931 .57596 m .52951 .57591 L .52955 .57589 L 1 g
F
P
p
.52951 .57591 m .52963 .57588 L .52968 .57586 L 1 g
F
P
p
.52963 .57588 m .52979 .57583 L .53181 .57505 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50053 .56326 m .50869 .55665 L .52983 .57581 L p
1 g
F P
s
P
p
.002 w
.52983 .57581 m .53001 .57598 L .52971 .57585 L p
1 g
F P
s
P
p
.002 w
.52971 .57585 m .50053 .56326 L p
.52983 .57581 L 1 g
F P
s
P
p
.52972 .57585 m .52989 .5758 L .53181 .57505 L 1 g
F
P
p
.002 w
.50869 .55665 m .51919 .55189 L .52993 .57578 L p
1 g
F P
s
P
p
.002 w
.52993 .57578 m .53001 .57598 L .52983 .57581 L p
1 g
F P
s
P
p
.002 w
.52983 .57581 m .50869 .55665 L p
.52993 .57578 L 1 g
F P
s
P
p
.52963 .57588 m .52972 .57585 L .52979 .57583 L 1 g
F
P
p
.52972 .57585 m .52978 .57584 L .52989 .5758 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.51919 .55189 m .53085 .54953 L .53002 .57575 L p
1 g
F P
s
P
p
.002 w
.53002 .57575 m .53001 .57598 L .52993 .57578 L p
1 g
F P
s
P
p
.002 w
.52993 .57578 m .51919 .55189 L p
.53002 .57575 L 1 g
F P
s
P
p
.52978 .57584 m .53002 .57575 L .53181 .57505 L 1 g
F
P
p
.51435 .58189 m .53104 .57536 L .53181 .57505 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53181 .57505 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53085 .54953 m .54235 .54984 L .53014 .57571 L p
1 g
F P
s
P
p
.002 w
.53014 .57571 m .53001 .57598 L .53002 .57575 L p
1 g
F P
s
P
p
.002 w
.53002 .57575 m .53085 .54953 L p
.53014 .57571 L 1 g
F P
s
P
p
.52978 .57584 m .52984 .57582 L .53002 .57575 L 1 g
F
P
p
.52984 .57582 m .52986 .57582 L .53004 .57574 L 1 g
F
P
p
.52984 .57582 m .53004 .57574 L .53181 .57505 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54235 .54984 m .55239 .55278 L .53035 .57563 L p
1 g
F P
s
P
p
.002 w
.53035 .57563 m .53001 .57598 L .53014 .57571 L p
1 g
F P
s
P
p
.002 w
.53014 .57571 m .54235 .54984 L p
.53035 .57563 L 1 g
F P
s
P
p
.5216 .57794 m .51435 .58189 L .52986 .57582 L 1 g
F
P
p
.51435 .58189 m .51372 .58224 L .53104 .57536 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .56319 L p
1 g
F P
s
P
p
.55986 .55798 m .54254 .57079 L .5468 .56596 L 1 g
F
P
p
.002 w
.53385 .57367 m .547 .56574 L p
.53086 .5757 L 1 g
F P
s
P
p
.002 w
.547 .56574 m .55986 .55798 L p
.5468 .56596 L 1 g
F P
s
P
p
.5468 .56596 m .53086 .5757 L .547 .56574 L 1 g
F
P
p
.55413 .55766 m .54972 .56447 L .55293 .55983 L 1 g
F
P
p
.56075 .54566 m .5529 .55905 L .55413 .55766 L 1 g
F
P
p
.5529 .55905 m .54972 .56447 L .55413 .55766 L 1 g
F
P
p
.002 w
.54925 .56319 m .54972 .56447 L p
.5529 .55905 L 1 g
F P
s
P
p
.56075 .54566 m .54925 .56319 L .5529 .55905 L 1 g
F
P
p
.002 w
.55986 .55798 m .56273 .56277 L p
.54254 .57079 L 1 g
F P
s
P
p
.5468 .56596 m .54254 .57079 L .53211 .57493 L 1 g
F
P
p
.5645 .53851 m .56529 .5361 L .56756 .52882 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56174 .54753 L p
1 g
F P
s
P
p
.56654 .52734 m .56174 .54753 L .56444 .53886 L 1 g
F
P
p
.56515 .50826 m .56756 .52882 L .56742 .52582 L 1 g
F
P
p
.56515 .50826 m .56787 .52928 L .56703 .52042 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56733 .52357 m .56756 .52882 L .55239 .55278 L 1 g
F
P
p
.002 w
.56774 .53294 m .56529 .5361 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56529 .5361 m .55239 .55278 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56174 .54753 m .56257 .5491 L p
.56444 .53886 L 1 g
F P
s
P
p
.002 w
.55239 .55278 m .56529 .5361 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.55842 .55698 m .55605 .55533 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.55605 .55533 m .55239 .55278 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.54972 .56447 m .54998 .56518 L p
.55293 .55983 L 1 g
F P
s
P
p
.002 w
.55239 .55278 m .55605 .55533 L p
.53055 .57555 L 1 g
F P
s
P
p
.002 w
.53001 .57598 m .53035 .57563 L p
.53055 .57555 L 1 g
F P
s
P
p
.002 w
.53035 .57563 m .55239 .55278 L p
.53055 .57555 L 1 g
F P
s
P
p
.54854 .56129 m .53181 .57505 L .53232 .5747 L 1 g
F
P
p
.002 w
.547 .56574 m .53385 .57367 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.56397 .56485 m .53086 .5757 L p
.53211 .57493 L 1 g
F P
s
P
p
.002 w
.56273 .56277 m .56397 .56485 L p
.53211 .57493 L 1 g
F P
s
P
p
.53986 .56956 m .53182 .57512 L .53821 .57114 L 1 g
F
P
p
.54854 .56129 m .5323 .57472 L .53986 .56956 L 1 g
F
P
p
.5323 .57472 m .53182 .57512 L .53986 .56956 L 1 g
F
P
p
.55605 .55533 m .54924 .56316 L .53104 .57536 L 1 g
F
P
p
.002 w
.53385 .57367 m .53104 .57536 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.53104 .57536 m .53001 .57598 L p
.53055 .57555 L 1 g
F P
s
P
p
.55605 .55533 m .53104 .57536 L .53055 .57555 L 1 g
F
P
p
.002 w
.53086 .5757 m .53001 .57598 L .53385 .57367 L p
1 g
F P
s
P
p
.002 w
.56094 .58042 m .55422 .58744 L .53026 .57609 L p
1 g
F P
s
P
p
.002 w
.53026 .57609 m .53001 .57598 L .53036 .57603 L p
1 g
F P
s
P
p
.002 w
.53036 .57603 m .56094 .58042 L p
.53026 .57609 L 1 g
F P
s
P
p
.002 w
.51195 .59599 m .50309 .59211 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.56432 .57261 m .56094 .58042 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.56397 .56485 m .56432 .57261 L .53001 .57598 L closepath p
1 g
F P
s
P
p
.002 w
.51372 .58224 m .5322 .57686 L .53181 .57506 L p
1 g
F P
s
P
p
.002 w
.53181 .57506 m .53181 .57505 L p
.53104 .57536 L 1 g
F P
s
P
p
.53104 .57536 m .51372 .58224 L .53181 .57506 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54924 .56316 L p
1 g
F P
s
P
p
.53986 .56956 m .5322 .57686 L .54924 .56316 L 1 g
F
P
p
.55432 .55731 m .55293 .55983 L .55605 .55533 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56161 .54728 L p
1 g
F P
s
P
p
.55293 .55983 m .54998 .56518 L .56161 .54728 L 1 g
F
P
p
.5645 .53851 m .56444 .53886 L .56529 .5361 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56756 .52882 L p
1 g
F P
s
P
p
.56444 .53886 m .56257 .5491 L .56756 .52882 L 1 g
F
P
p
.002 w
.56756 .52882 m .56787 .52928 L p
.56742 .52582 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55367 .51942 m .56733 .52357 L p
.55239 .55278 L 1 g
F P
s
P
p
.002 w
.55451 .4854 m .56351 .48574 L .56088 .49472 L p
1 g
F P
s
P
p
.002 w
.56088 .49472 m .5602 .49705 L p
.55743 .49137 L 1 g
F P
s
P
p
.55451 .4854 m .56088 .49472 L .55743 .49137 L 1 g
F
P
p
.002 w
.55743 .49137 m .55661 .4905 L p
.5626 .50197 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55743 .49137 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55743 .49137 L p
1 g
F P
s
P
p
.5626 .50197 m .56713 .51061 L .55743 .49137 L 1 g
F
P
p
.54174 .47608 m .55743 .49137 L .55419 .48824 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5297 .48447 m .55113 .48527 L p
.55367 .51942 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.55113 .48527 m .55444 .48848 L .55367 .51942 L 1 g
F
P
p
.54174 .47608 m .55419 .48824 L .55052 .48468 L 1 g
F
P
p
.002 w
.5602 .49705 m .55367 .51942 L p
.55444 .48848 L 1 g
F P
s
P
p
.55743 .49137 m .5602 .49705 L .55444 .48848 L 1 g
F
P
p
.55419 .48824 m .55774 .4917 L .55113 .48527 L 1 g
F
P
p
.55419 .48824 m .55113 .48527 L .55052 .48468 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55451 .4854 m .55743 .49137 L .55444 .48848 L 1 g
F
P
p
.002 w
.55113 .48527 m .55451 .4854 L p
.55444 .48848 L 1 g
F P
s
P
p
.002 w
.55113 .48527 m .5297 .48447 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.55774 .4917 m .55834 .49233 L p
.55076 .48491 L 1 g
F P
s
P
p
.55052 .48468 m .55113 .48527 L .55076 .48491 L 1 g
F
P
p
.55113 .48527 m .55774 .4917 L .55076 .48491 L 1 g
F
P
p
.002 w
.55743 .49137 m .55774 .4917 L p
.55419 .48824 L 1 g
F P
s
P
p
.002 w
.55367 .51942 m .5602 .49705 L p
.56597 .50933 L 1 g
F P
s
P
p
.002 w
.57353 .52546 m .56733 .52357 L p
.56597 .50933 L 1 g
F P
s
P
p
.002 w
.56733 .52357 m .55367 .51942 L p
.56597 .50933 L 1 g
F P
s
P
p
.002 w
.56787 .52928 m .56854 .53025 L p
.56703 .52042 L 1 g
F P
s
P
p
.57341 .52499 m .57353 .52546 L .5602 .49705 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50922 L p
1 g
F P
s
P
p
.56703 .52042 m .56854 .53025 L .56595 .50922 L 1 g
F
P
p
.002 w
.56595 .50922 m .56713 .51061 L p
.5618 .50044 L 1 g
F P
s
P
p
.002 w
.5297 .48447 m .52892 .47033 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54223 .47661 L p
1 g
F P
s
P
p
.002 w
.54223 .47661 m .54174 .47608 L p
.55052 .48468 L 1 g
F P
s
P
p
.55052 .48468 m .55834 .49233 L .54223 .47661 L 1 g
F
P
p
.5277 .44814 m .5614 .48566 L .54223 .47661 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47661 L p
1 g
F P
s
P
p
.52214 .46667 m .54223 .47661 L .53418 .47282 L 1 g
F
P
p
.52214 .46667 m .54276 .47719 L .53593 .47381 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52892 .47033 m .5297 .48447 L p
.51508 .46601 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .5224 .4671 L p
1 g
F P
s
P
p
.5 .4634 m .5224 .4671 L .50824 .46498 L 1 g
F
P
p
.51178 .46184 m .5224 .4671 L .51508 .46601 L 1 g
F
P
p
.5224 .4671 m .52892 .47033 L .51508 .46601 L 1 g
F
P
p
.49561 .46447 m .5 .46375 L .5297 .48447 L 1 g
F
P
p
.002 w
.5 .46375 m .5 .4634 L p
.50824 .46498 L 1 g
F P
s
P
p
.5 .46375 m .51178 .46184 L .51508 .46601 L 1 g
F
P
p
.5 .46375 m .51508 .46601 L .5297 .48447 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.50824 .46498 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.5224 .4671 m .52282 .46778 L p
.50824 .46498 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52892 .47033 m .52853 .46329 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.52853 .46329 m .5277 .44814 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.5614 .48566 m .55113 .48527 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.54223 .47661 m .54276 .47719 L p
.53418 .47282 L 1 g
F P
s
P
p
.002 w
.54276 .47719 m .54302 .47747 L p
.53593 .47381 L 1 g
F P
s
P
p
.002 w
.52831 .45916 m .52892 .47033 L p
.51178 .46184 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .4914 .46515 L 1 g
F
P
p
.48311 .45714 m .52831 .45916 L .49561 .46447 L 1 g
F
P
p
.002 w
.5 .46375 m .5 .46418 L p
.4914 .46515 L 1 g
F P
s
P
p
.002 w
.5 .46418 m .5 .46442 L p
.49204 .46523 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46418 L .49204 .46523 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46712 L p
1 g
F P
s
P
p
.002 w
.47759 .46712 m .47718 .46778 L p
.4656 .47286 L 1 g
F P
s
P
p
.45826 .47608 m .47759 .46712 L .4656 .47286 L 1 g
F
P
p
.002 w
.48311 .45714 m .48534 .46341 L p
.47759 .46712 L 1 g
F P
s
P
p
.45945 .47581 m .46904 .46824 L .47759 .46712 L 1 g
F
P
p
.46904 .46824 m .48311 .45714 L .47759 .46712 L 1 g
F
P
p
.002 w
.48626 .46599 m .48311 .45714 L p
.49561 .46447 L 1 g
F P
s
P
p
.002 w
.48534 .46341 m .48626 .46599 L p
.47759 .46712 L 1 g
F P
s
P
p
.002 w
.48626 .46599 m .4953 .49142 L p
.47759 .46712 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46712 L p
1 g
F P
s
P
p
.49204 .46523 m .5 .46442 L .47759 .46712 L 1 g
F
P
p
.002 w
.47277 .46202 m .48311 .45714 L p
.45497 .47934 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45778 .47661 L p
1 g
F P
s
P
p
.4656 .47286 m .47718 .46778 L .45778 .47661 L 1 g
F
P
p
.002 w
.45778 .47661 m .45698 .47747 L p
.45048 .48371 L 1 g
F P
s
P
p
.44339 .4905 m .45778 .47661 L .45048 .48371 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.4434 .47588 m .47277 .46202 L p
.45497 .47934 L 1 g
F P
s
P
p
.002 w
.44957 .48459 m .4434 .47588 L p
.45497 .47934 L 1 g
F P
s
P
p
.002 w
.41346 .50182 m .4434 .47588 L .44957 .48459 L p
1 g
F P
s
P
p
.002 w
.44957 .48459 m .46455 .50572 L p
.43039 .50311 L 1 g
F P
s
P
p
.41346 .50182 m .44957 .48459 L .43039 .50311 L 1 g
F
P
p
.002 w
.44277 .49116 m .44166 .49233 L p
.4373 .50252 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44277 .49116 L p
1 g
F P
s
P
p
.45137 .48286 m .45698 .47747 L .44277 .49116 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43413 .50911 L p
1 g
F P
s
P
p
.4373 .50252 m .44166 .49233 L .43413 .50911 L 1 g
F
P
p
.43315 .5184 m .43314 .51823 L .43312 .51867 L 1 g
F
P
p
.002 w
.46455 .50572 m .44114 .52554 L .43312 .51867 L p
1 g
F P
s
P
p
.002 w
.39658 .53156 m .41346 .50182 L .44114 .52554 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43261 .52857 L p
1 g
F P
s
P
p
.43314 .51823 m .43287 .51061 L .43261 .52857 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43799 .54803 L p
1 g
F P
s
P
p
.002 w
.43799 .54803 m .43845 .54716 L p
.43634 .54204 L 1 g
F P
s
P
p
.43634 .54204 m .43146 .53025 L .43799 .54803 L 1 g
F
P
p
.43522 .5377 m .43146 .53025 L .43845 .54716 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47053 .54627 m .46105 .56167 L .44417 .55494 L p
1 g
F P
s
P
p
.43893 .54781 m .47053 .54627 L .44417 .55494 L 1 g
F
P
p
.002 w
.43845 .54716 m .43817 .5477 L p
.4409 .55048 L 1 g
F P
s
P
p
.002 w
.43509 .55133 m .44417 .55494 L p
.45083 .56298 L 1 g
F P
s
P
p
.002 w
.43817 .5477 m .43743 .5491 L p
.44421 .55499 L 1 g
F P
s
P
p
.45229 .56406 m .45083 .56298 L .46105 .56167 L 1 g
F
P
p
.002 w
.44417 .55494 m .46105 .56167 L p
.45083 .56298 L 1 g
F P
s
P
p
.42524 .57147 m .43509 .55133 L .45229 .56406 L 1 g
F
P
p
.45183 .56419 m .45229 .56406 L .45318 .56583 L 1 g
F
P
p
.45183 .56419 m .45318 .56583 L .45906 .57738 L 1 g
F
P
p
.002 w
.46002 .56979 m .45906 .57738 L p
.45229 .56406 L 1 g
F P
s
P
p
.002 w
.45083 .56298 m .45002 .56518 L p
.45821 .56845 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45083 .56298 L p
1 g
F P
s
P
p
.44421 .55499 m .43743 .5491 L .45083 .56298 L 1 g
F
P
p
.002 w
.46829 .57464 m .46872 .57265 L p
.45673 .56786 L 1 g
F P
s
P
p
.002 w
.46105 .56167 m .46002 .56979 L p
.45229 .56406 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46829 .57464 L p
1 g
F P
s
P
p
.48921 .57862 m .46829 .57464 L .4782 .57772 L 1 g
F
P
p
.002 w
.46105 .56167 m .4956 .57097 L p
.4706 .57536 L 1 g
F P
s
P
p
.002 w
.45906 .57738 m .45974 .57199 L p
.4706 .57536 L 1 g
F P
s
P
p
.002 w
.45974 .57199 m .46105 .56167 L p
.4706 .57536 L 1 g
F P
s
P
p
.002 w
.46829 .57464 m .4678 .57686 L p
.4782 .57772 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46805 .57573 L p
1 g
F P
s
P
p
.002 w
.46805 .57573 m .46829 .57464 L p
.46257 .57168 L 1 g
F P
s
P
p
.46257 .57168 m .45002 .56518 L .46805 .57573 L 1 g
F
P
p
.45673 .56786 m .45002 .56518 L .46829 .57464 L 1 g
F
P
p
.4782 .57772 m .47797 .5777 L .48006 .57829 L 1 g
F
P
p
.002 w
.4956 .57097 m .4944 .57892 L .48006 .57829 L p
1 g
F P
s
P
p
.4706 .57536 m .4956 .57097 L .48006 .57829 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58085 L p
1 g
F P
s
P
p
.47797 .5777 m .4678 .57686 L .48904 .58085 L 1 g
F
P
p
.002 w
.4944 .57892 m .49528 .58137 L p
.48974 .58091 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51109 .58266 L p
1 g
F P
s
P
p
.002 w
.51109 .58266 m .51095 .58071 L p
.50049 .58179 L 1 g
F P
s
P
p
.50049 .58179 m .48889 .583 L .51109 .58266 L 1 g
F
P
p
.49658 .58146 m .48889 .583 L .51095 .58071 L 1 g
F
P
p
.002 w
.53181 .57505 m .53182 .57512 L p
.53232 .5747 L 1 g
F P
s
P
p
.002 w
.53182 .57512 m .5322 .57686 L p
.53821 .57114 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.56094 .58042 m .56432 .57261 L .59624 .56506 L p
1 g
F P
s
P
p
.002 w
.59589 .54972 m .59624 .56506 L .56432 .57261 L p
1 g
F P
s
P
p
.002 w
.59624 .56506 m .59589 .54972 L .62466 .53117 L p
1 g
F P
s
P
p
.002 w
.38854 .47601 m .36897 .5119 L .3457 .49014 L p
1 g
F P
s
P
p
.002 w
.3457 .49014 m .36728 .44908 L .38854 .47601 L p
1 g
F P
s
P
p
.002 w
.39318 .38244 m .35038 .42205 L .3383 .39588 L p
1 g
F P
s
P
p
.002 w
.3383 .39588 m .38284 .35394 L .39318 .38244 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.50729 .28363 m .5756 .28834 L .57962 .3143 L p
1 g
F P
s
P
p
.002 w
.44346 .32378 m .38284 .35394 L .37628 .32848 L p
1 g
F P
s
P
p
.002 w
.37628 .32848 m .43762 .29766 L .44346 .32378 L p
1 g
F P
s
P
p
.002 w
.6137 .51077 m .62466 .53117 L .59589 .54972 L p
1 g
F P
s
P
p
.002 w
.62466 .53117 m .6137 .51077 L .63573 .48326 L p
1 g
F P
s
P
p
.002 w
.56432 .57261 m .56397 .56485 L .59589 .54972 L p
1 g
F P
s
P
p
.002 w
.62179 .42894 m .65344 .45447 L .63573 .48326 L p
1 g
F P
s
P
p
.002 w
.65344 .45447 m .62179 .42894 L .63084 .39591 L p
1 g
F P
s
P
p
.002 w
.41346 .50182 m .39658 .53156 L .36897 .5119 L p
1 g
F P
s
P
p
.002 w
.36897 .5119 m .38854 .47601 L .41346 .50182 L p
1 g
F P
s
P
p
.002 w
.5881 .53599 m .59589 .54972 L .56397 .56485 L p
1 g
F P
s
P
p
.002 w
.59589 .54972 m .5881 .53599 L .6137 .51077 L p
1 g
F P
s
P
p
.002 w
.5813 .34453 m .63579 .3645 L .63084 .39591 L p
1 g
F P
s
P
p
.002 w
.63579 .3645 m .5813 .34453 L .57962 .3143 L p
1 g
F P
s
P
p
.002 w
.40704 .41303 m .36728 .44908 L .35038 .42205 L p
1 g
F P
s
P
p
.002 w
.35038 .42205 m .39318 .38244 L .40704 .41303 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.56397 .56485 m .55986 .55798 L .5881 .53599 L p
1 g
F P
s
P
p
.002 w
.57962 .3143 m .51223 .30993 L .50729 .28363 L p
1 g
F P
s
P
p
.002 w
.43762 .29766 m .50729 .28363 L .51223 .30993 L p
1 g
F P
s
P
p
.002 w
.51223 .30993 m .44346 .32378 L .43762 .29766 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.6089 .46236 m .63573 .48326 L .6137 .51077 L p
1 g
F P
s
P
p
.002 w
.63573 .48326 m .6089 .46236 L .62179 .42894 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.51223 .30993 m .57962 .3143 L .5813 .34453 L p
1 g
F P
s
P
p
.002 w
.57353 .52546 m .5881 .53599 L .55986 .55798 L p
1 g
F P
s
P
p
.002 w
.50053 .56326 m .4956 .57097 L .46105 .56167 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45121 .3539 m .39318 .38244 L .38284 .35394 L p
1 g
F P
s
P
p
.002 w
.38284 .35394 m .44346 .32378 L .45121 .3539 L p
1 g
F P
s
P
p
.002 w
.59261 .49495 m .6137 .51077 L .5881 .53599 L p
1 g
F P
s
P
p
.002 w
.6137 .51077 m .59261 .49495 L .6089 .46236 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.5881 .53599 m .57353 .52546 L .59261 .49495 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46105 .56167 m .47053 .54627 L .50053 .56326 L p
1 g
F P
s
P
p
.002 w
.5805 .37805 m .63084 .39591 L .62179 .42894 L p
1 g
F P
s
P
p
.002 w
.63084 .39591 m .5805 .37805 L .5813 .34453 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42399 .44457 m .38854 .47601 L .36728 .44908 L p
1 g
F P
s
P
p
.002 w
.36728 .44908 m .40704 .41303 L .42399 .44457 L p
1 g
F P
s
P
p
.002 w
.55239 .55278 m .54235 .54984 L .55367 .51942 L p
1 g
F P
s
P
p
.002 w
.50869 .55665 m .50053 .56326 L .47053 .54627 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.54235 .54984 m .53085 .54953 L .53076 .51869 L p
1 g
F P
s
P
p
.002 w
.53076 .51869 m .55367 .51942 L .54235 .54984 L p
1 g
F P
s
P
p
.002 w
.51919 .55189 m .50869 .55665 L .48659 .53297 L p
1 g
F P
s
P
p
.002 w
.47053 .54627 m .48659 .53297 L .50869 .55665 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53085 .54953 m .51919 .55189 L .50748 .52339 L p
1 g
F P
s
P
p
.002 w
.50748 .52339 m .53076 .51869 L .53085 .54953 L p
1 g
F P
s
P
p
.002 w
.48659 .53297 m .50748 .52339 L .51919 .55189 L p
1 g
F P
s
P
p
.002 w
.57719 .41367 m .62179 .42894 L .6089 .46236 L p
1 g
F P
s
P
p
.002 w
.62179 .42894 m .57719 .41367 L .5805 .37805 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.5813 .34453 m .51692 .34066 L .51223 .30993 L p
1 g
F P
s
P
p
.002 w
.44346 .32378 m .51223 .30993 L .51692 .34066 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51692 .34066 m .45121 .3539 L .44346 .32378 L p
1 g
F P
s
P
p
.002 w
.4434 .47588 m .41346 .50182 L .38854 .47601 L p
1 g
F P
s
P
p
.002 w
.38854 .47601 m .42399 .44457 L .4434 .47588 L p
1 g
F P
s
P
p
.002 w
.56351 .48574 m .59261 .49495 L .57353 .52546 L p
1 g
F P
s
P
p
.002 w
.48659 .53297 m .47053 .54627 L .44114 .52554 L p
1 g
F P
s
P
p
.002 w
.51692 .34066 m .5813 .34453 L .5805 .37805 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46064 .38701 m .40704 .41303 L .39318 .38244 L p
1 g
F P
s
P
p
.002 w
.39318 .38244 m .45121 .3539 L .46064 .38701 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57145 .45003 m .6089 .46236 L .59261 .49495 L p
1 g
F P
s
P
p
.002 w
.6089 .46236 m .57145 .45003 L .57719 .41367 L p
1 g
F P
s
P
p
.002 w
.59261 .49495 m .56351 .48574 L .57145 .45003 L p
1 g
F P
s
P
p
.002 w
.44114 .52554 m .46455 .50572 L .48659 .53297 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.55367 .51942 m .53076 .51869 L .5297 .48447 L p
1 g
F P
s
P
p
.002 w
.50748 .52339 m .48659 .53297 L .46455 .50572 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52118 .3748 m .5805 .37805 L .57719 .41367 L p
1 g
F P
s
P
p
.002 w
.5805 .37805 m .52118 .3748 L .51692 .34066 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47141 .42187 m .42399 .44457 L .40704 .41303 L p
1 g
F P
s
P
p
.002 w
.40704 .41303 m .46064 .38701 L .47141 .42187 L p
1 g
F P
s
P
p
.002 w
.53076 .51869 m .50748 .52339 L .4953 .49142 L p
1 g
F P
s
P
p
.002 w
.4953 .49142 m .5297 .48447 L .53076 .51869 L p
1 g
F P
s
P
p
.002 w
.46455 .50572 m .4953 .49142 L .50748 .52339 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45121 .3539 m .51692 .34066 L .52118 .3748 L p
1 g
F P
s
P
p
.002 w
.52118 .3748 m .46064 .38701 L .45121 .3539 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5277 .44814 m .57145 .45003 L .56351 .48574 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.54023 .62547 m
.54224 .63523 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52482 .4111 m .57719 .41367 L .57145 .45003 L p
1 g
F P
s
P
p
.002 w
.57719 .41367 m .52482 .4111 L .52118 .3748 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.48311 .45714 m .4434 .47588 L .42399 .44457 L p
1 g
F P
s
P
p
.002 w
.42399 .44457 m .47141 .42187 L .48311 .45714 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.57145 .45003 m .5277 .44814 L .52482 .4111 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.46064 .38701 m .52118 .3748 L .52482 .4111 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52482 .4111 m .47141 .42187 L .46064 .38701 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5277 .44814 m .48311 .45714 L .47141 .42187 L p
1 g
F P
s
P
p
.002 w
.47141 .42187 m .52482 .4111 L .5277 .44814 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .78008 .51208 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .54753 .66089 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0147368)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0147368)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47206 .46667 m .51987 .46591 L .5164 .43771 L p
1 g
F P
s
P
p
.002 w
.5164 .43771 m .47449 .43835 L .47206 .46667 L p
1 g
F P
s
P
p
.002 w
.55645 .42739 m .5164 .43771 L .51987 .46591 L p
1 g
F P
s
P
p
.002 w
.47449 .43835 m .5164 .43771 L .51253 .4094 L p
1 g
F P
s
P
p
.002 w
.5164 .43771 m .55645 .42739 L .54594 .40065 L p
1 g
F P
s
P
p
.002 w
.54594 .40065 m .51253 .4094 L .5164 .43771 L p
1 g
F P
s
P
p
.002 w
.51253 .4094 m .47753 .40991 L .47449 .43835 L p
1 g
F P
s
P
p
.002 w
.47753 .40991 m .51253 .4094 L .50835 .38147 L p
1 g
F P
s
P
p
.002 w
.51253 .4094 m .54594 .40065 L .53429 .37457 L p
1 g
F P
s
P
p
.002 w
.53429 .37457 m .50835 .38147 L .51253 .4094 L p
1 g
F P
s
P
p
.002 w
.42635 .45647 m .47206 .46667 L .47449 .43835 L p
1 g
F P
s
P
p
.002 w
.47449 .43835 m .43448 .42923 L .42635 .45647 L p
1 g
F P
s
P
p
.002 w
.43448 .42923 m .47449 .43835 L .47753 .40991 L p
1 g
F P
s
P
p
.002 w
.47753 .40991 m .44418 .40213 L .43448 .42923 L p
1 g
F P
s
P
p
.002 w
.44418 .40213 m .47753 .40991 L .48113 .38186 L p
1 g
F P
s
P
p
.002 w
.50835 .38147 m .48113 .38186 L .47753 .40991 L p
1 g
F P
s
P
p
.002 w
.47028 .49434 m .52289 .49349 L .51987 .46591 L p
1 g
F P
s
P
p
.002 w
.51987 .46591 m .47206 .46667 L .47028 .49434 L p
1 g
F P
s
P
p
.002 w
.56562 .45431 m .51987 .46591 L .52289 .49349 L p
1 g
F P
s
P
p
.002 w
.51987 .46591 m .56562 .45431 L .55645 .42739 L p
1 g
F P
s
P
p
.002 w
.41993 .48337 m .47028 .49434 L .47206 .46667 L p
1 g
F P
s
P
p
.002 w
.47206 .46667 m .42635 .45647 L .41993 .48337 L p
1 g
F P
s
P
p
.002 w
.48113 .38186 m .50835 .38147 L .50392 .35445 L p
1 g
F P
s
P
p
.002 w
.50835 .38147 m .53429 .37457 L .52171 .34965 L p
1 g
F P
s
P
p
.002 w
.52171 .34965 m .50392 .35445 L .50835 .38147 L p
1 g
F P
s
P
p
.002 w
.48113 .38186 m .45525 .37568 L .44418 .40213 L p
1 g
F P
s
P
p
.002 w
.45525 .37568 m .48113 .38186 L .48523 .35471 L p
1 g
F P
s
P
p
.002 w
.50392 .35445 m .48523 .35471 L .48113 .38186 L p
1 g
F P
s
P
p
.002 w
.57458 .38437 m .54594 .40065 L .55645 .42739 L p
1 g
F P
s
P
p
.002 w
.54594 .40065 m .57458 .38437 L .55641 .36175 L p
1 g
F P
s
P
p
.002 w
.55641 .36175 m .53429 .37457 L .54594 .40065 L p
1 g
F P
s
P
p
.002 w
.59096 .40815 m .55645 .42739 L .56562 .45431 L p
1 g
F P
s
P
p
.002 w
.55645 .42739 m .59096 .40815 L .57458 .38437 L p
1 g
F P
s
P
p
.002 w
.4001 .41096 m .43448 .42923 L .44418 .40213 L p
1 g
F P
s
P
p
.002 w
.44418 .40213 m .41566 .38664 L .4001 .41096 L p
1 g
F P
s
P
p
.002 w
.41566 .38664 m .44418 .40213 L .45525 .37568 L p
1 g
F P
s
P
p
.002 w
.38688 .43598 m .42635 .45647 L .43448 .42923 L p
1 g
F P
s
P
p
.002 w
.43448 .42923 m .4001 .41096 L .38688 .43598 L p
1 g
F P
s
P
p
.002 w
.53429 .37457 m .55641 .36175 L .53678 .34074 L p
1 g
F P
s
P
p
.002 w
.53678 .34074 m .52171 .34965 L .53429 .37457 L p
1 g
F P
s
P
p
.002 w
.46921 .52086 m .52539 .51992 L .52289 .49349 L p
1 g
F P
s
P
p
.002 w
.52289 .49349 m .47028 .49434 L .46921 .52086 L p
1 g
F P
s
P
p
.002 w
.57328 .48091 m .52289 .49349 L .52539 .51992 L p
1 g
F P
s
P
p
.002 w
.52289 .49349 m .57328 .48091 L .56562 .45431 L p
1 g
F P
s
P
p
.002 w
.60521 .43267 m .56562 .45431 L .57328 .48091 L p
1 g
F P
s
P
p
.002 w
.56562 .45431 m .60521 .43267 L .59096 .40815 L p
1 g
F P
s
P
p
.002 w
.4154 .50939 m .46921 .52086 L .47028 .49434 L p
1 g
F P
s
P
p
.002 w
.47028 .49434 m .41993 .48337 L .4154 .50939 L p
1 g
F P
s
P
p
.002 w
.45525 .37568 m .43324 .36346 L .41566 .38664 L p
1 g
F P
s
P
p
.002 w
.43324 .36346 m .45525 .37568 L .46749 .35039 L p
1 g
F P
s
P
p
.002 w
.48523 .35471 m .46749 .35039 L .45525 .37568 L p
1 g
F P
s
P
p
.002 w
.48523 .35471 m .50392 .35445 L .49933 .32885 L p
1 g
F P
s
P
p
.002 w
.50392 .35445 m .52171 .34965 L .50841 .32636 L p
1 g
F P
s
P
p
.002 w
.50841 .32636 m .49933 .32885 L .50392 .35445 L p
1 g
F P
s
P
p
.002 w
.46749 .35039 m .48523 .35471 L .48976 .32898 L p
1 g
F P
s
P
p
.002 w
.49933 .32885 m .48976 .32898 L .48523 .35471 L p
1 g
F P
s
P
p
.002 w
.3763 .46121 m .41993 .48337 L .42635 .45647 L p
1 g
F P
s
P
p
.002 w
.42635 .45647 m .38688 .43598 L .3763 .46121 L p
1 g
F P
s
P
p
.002 w
.52171 .34965 m .53678 .34074 L .51606 .32176 L p
1 g
F P
s
P
p
.002 w
.51606 .32176 m .50841 .32636 L .52171 .34965 L p
1 g
F P
s
P
p
.002 w
.46749 .35039 m .45251 .34188 L .43324 .36346 L p
1 g
F P
s
P
p
.002 w
.45251 .34188 m .46749 .35039 L .4807 .32673 L p
1 g
F P
s
P
p
.002 w
.48976 .32898 m .4807 .32673 L .46749 .35039 L p
1 g
F P
s
P
p
.002 w
.59555 .36192 m .57458 .38437 L .59096 .40815 L p
1 g
F P
s
P
p
.002 w
.57458 .38437 m .59555 .36192 L .57242 .34416 L p
1 g
F P
s
P
p
.002 w
.57242 .34416 m .55641 .36175 L .57458 .38437 L p
1 g
F P
s
P
p
.002 w
.52539 .51992 m .57924 .50668 L .57328 .48091 L p
1 g
F P
s
P
p
.002 w
.61703 .45745 m .57328 .48091 L .57924 .50668 L p
1 g
F P
s
P
p
.002 w
.57328 .48091 m .61703 .45745 L .60521 .43267 L p
1 g
F P
s
P
p
.002 w
.55641 .36175 m .57242 .34416 L .54756 .32859 L p
1 g
F P
s
P
p
.002 w
.54756 .32859 m .53678 .34074 L .55641 .36175 L p
1 g
F P
s
P
p
.002 w
.46889 .54568 m .52731 .54467 L .52539 .51992 L p
1 g
F P
s
P
p
.002 w
.52539 .51992 m .46921 .52086 L .46889 .54568 L p
1 g
F P
s
P
p
.002 w
.57924 .50668 m .52539 .51992 L .52731 .54467 L p
1 g
F P
s
P
p
.002 w
.61647 .38153 m .59096 .40815 L .60521 .43267 L p
1 g
F P
s
P
p
.002 w
.59096 .40815 m .61647 .38153 L .59555 .36192 L p
1 g
F P
s
P
p
.002 w
.39492 .3647 m .41566 .38664 L .43324 .36346 L p
1 g
F P
s
P
p
.002 w
.43324 .36346 m .41743 .34626 L .39492 .3647 L p
1 g
F P
s
P
p
.002 w
.41743 .34626 m .43324 .36346 L .45251 .34188 L p
1 g
F P
s
P
p
.002 w
.37484 .38497 m .4001 .41096 L .41566 .38664 L p
1 g
F P
s
P
p
.002 w
.41566 .38664 m .39492 .3647 L .37484 .38497 L p
1 g
F P
s
P
p
.002 w
.41289 .53399 m .46889 .54568 L .46921 .52086 L p
1 g
F P
s
P
p
.002 w
.46921 .52086 m .4154 .50939 L .41289 .53399 L p
1 g
F P
s
P
p
.002 w
.36865 .48614 m .4154 .50939 L .41993 .48337 L p
1 g
F P
s
P
p
.002 w
.41993 .48337 m .3763 .46121 L .36865 .48614 L p
1 g
F P
s
P
p
.002 w
.53678 .34074 m .54756 .32859 L .52146 .31552 L p
1 g
F P
s
P
p
.002 w
.52146 .31552 m .51606 .32176 L .53678 .34074 L p
1 g
F P
s
P
p
.002 w
.45251 .34188 m .44188 .32999 L .41743 .34626 L p
1 g
F P
s
P
p
.002 w
.44188 .32999 m .45251 .34188 L .47311 .32232 L p
1 g
F P
s
P
p
.002 w
.4807 .32673 m .47311 .32232 L .45251 .34188 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .48976 .32898 L .49933 .32885 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .49933 .32885 L .50841 .32636 L closepath p
1 g
F P
s
P
p
.002 w
.35763 .40667 m .38688 .43598 L .4001 .41096 L p
1 g
F P
s
P
p
.002 w
.4001 .41096 m .37484 .38497 L .35763 .40667 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .4807 .32673 L .48976 .32898 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .50841 .32636 L .51606 .32176 L closepath p
1 g
F P
s
P
p
.002 w
.63473 .40261 m .60521 .43267 L .61703 .45745 L p
1 g
F P
s
P
p
.002 w
.60521 .43267 m .63473 .40261 L .61647 .38153 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .47311 .32232 L .4807 .32673 L closepath p
1 g
F P
s
P
p
.002 w
.52731 .54467 m .58335 .5311 L .57924 .50668 L p
1 g
F P
s
P
p
.002 w
.62613 .482 m .57924 .50668 L .58335 .5311 L p
1 g
F P
s
P
p
.002 w
.57924 .50668 m .62613 .482 L .61703 .45745 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .51606 .32176 L .52146 .31552 L closepath p
1 g
F P
s
P
p
.002 w
.47311 .32232 m .46779 .31621 L .44188 .32999 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .46779 .31621 L .47311 .32232 L closepath p
1 g
F P
s
P
p
.002 w
.55282 .31439 m .54756 .32859 L .57242 .34416 L p
1 g
F P
s
P
p
.002 w
.54756 .32859 m .55282 .31439 L .52401 .30827 L p
1 g
F P
s
P
p
.002 w
.52401 .30827 m .52146 .31552 L .54756 .32859 L p
1 g
F P
s
P
p
.002 w
.58048 .32346 m .57242 .34416 L .59555 .36192 L p
1 g
F P
s
P
p
.002 w
.57242 .34416 m .58048 .32346 L .55282 .31439 L p
1 g
F P
s
P
p
.002 w
.34375 .42938 m .3763 .46121 L .38688 .43598 L p
1 g
F P
s
P
p
.002 w
.38688 .43598 m .35763 .40667 L .34375 .42938 L p
1 g
F P
s
P
p
.002 w
.36417 .51024 m .41289 .53399 L .4154 .50939 L p
1 g
F P
s
P
p
.002 w
.4154 .50939 m .36865 .48614 L .36417 .51024 L p
1 g
F P
s
P
p
.002 w
.40964 .32571 m .41743 .34626 L .44188 .32999 L p
1 g
F P
s
P
p
.002 w
.44188 .32999 m .43681 .3159 L .40964 .32571 L p
1 g
F P
s
P
p
.002 w
.43681 .3159 m .44188 .32999 L .46779 .31621 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .52146 .31552 L .52401 .30827 L closepath p
1 g
F P
s
P
p
.002 w
.46934 .56824 m .52859 .5672 L .52731 .54467 L p
1 g
F P
s
P
p
.002 w
.52731 .54467 m .46889 .54568 L .46934 .56824 L p
1 g
F P
s
P
p
.002 w
.58335 .5311 m .52731 .54467 L .52859 .5672 L p
1 g
F P
s
P
p
.002 w
.6064 .33533 m .59555 .36192 L .61647 .38153 L p
1 g
F P
s
P
p
.002 w
.59555 .36192 m .6064 .33533 L .58048 .32346 L p
1 g
F P
s
P
p
.002 w
.38442 .3383 m .39492 .3647 L .41743 .34626 L p
1 g
F P
s
P
p
.002 w
.41743 .34626 m .40964 .32571 L .38442 .3383 L p
1 g
F P
s
P
p
.002 w
.46779 .31621 m .46534 .30903 L .43681 .3159 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .46534 .30903 L .46779 .31621 L closepath p
1 g
F P
s
P
p
.002 w
.41254 .55662 m .46934 .56824 L .46889 .54568 L p
1 g
F P
s
P
p
.002 w
.46889 .54568 m .41289 .53399 L .41254 .55662 L p
1 g
F P
s
P
p
.002 w
.64989 .42477 m .61703 .45745 L .62613 .482 L p
1 g
F P
s
P
p
.002 w
.61703 .45745 m .64989 .42477 L .63473 .40261 L p
1 g
F P
s
P
p
.002 w
.36173 .35346 m .37484 .38497 L .39492 .3647 L p
1 g
F P
s
P
p
.002 w
.39492 .3647 m .38442 .3383 L .36173 .35346 L p
1 g
F P
s
P
p
.002 w
.5234 .30081 m .52401 .30827 L .55282 .31439 L p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .52401 .30827 L .5234 .30081 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .5234 .30081 L .51965 .29392 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .51965 .29392 L .51314 .28839 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .51314 .28839 L .50456 .28485 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .50456 .28485 L .49488 .2837 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .49488 .2837 L .48517 .28509 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .48517 .28509 L .47654 .28885 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .47654 .28885 L .46993 .29455 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .46993 .29455 L .46607 .30154 L closepath p
1 g
F P
s
P
p
.002 w
.49464 .30521 m .46607 .30154 L .46534 .30903 L closepath p
1 g
F P
s
P
p
.002 w
.438 .30107 m .43681 .3159 L .46534 .30903 L p
1 g
F P
s
P
p
.002 w
.46534 .30903 m .46607 .30154 L .438 .30107 L p
1 g
F P
s
P
p
.002 w
.63 .3498 m .61647 .38153 L .63473 .40261 L p
1 g
F P
s
P
p
.002 w
.61647 .38153 m .63 .3498 L .6064 .33533 L p
1 g
F P
s
P
p
.002 w
.33358 .45263 m .36865 .48614 L .3763 .46121 L p
1 g
F P
s
P
p
.002 w
.3763 .46121 m .34375 .42938 L .33358 .45263 L p
1 g
F P
s
P
p
.002 w
.55187 .29962 m .55282 .31439 L .58048 .32346 L p
1 g
F P
s
P
p
.002 w
.55282 .31439 m .55187 .29962 L .5234 .30081 L p
1 g
F P
s
P
p
.002 w
.52859 .5672 m .58545 .55361 L .58335 .5311 L p
1 g
F P
s
P
p
.002 w
.63223 .50581 m .58335 .5311 L .58545 .55361 L p
1 g
F P
s
P
p
.002 w
.58335 .5311 m .63223 .50581 L .62613 .482 L p
1 g
F P
s
P
p
.002 w
.41103 .3039 m .40964 .32571 L .43681 .3159 L p
1 g
F P
s
P
p
.002 w
.43681 .3159 m .438 .30107 L .41103 .3039 L p
1 g
F P
s
P
p
.002 w
.51965 .29392 m .5234 .30081 L .55187 .29962 L p
1 g
F P
s
P
p
.002 w
.34214 .37093 m .35763 .40667 L .37484 .38497 L p
1 g
F P
s
P
p
.002 w
.37484 .38497 m .36173 .35346 L .34214 .37093 L p
1 g
F P
s
P
p
.002 w
.44547 .28713 m .438 .30107 L .46607 .30154 L p
1 g
F P
s
P
p
.002 w
.46607 .30154 m .46993 .29455 L .44547 .28713 L p
1 g
F P
s
P
p
.002 w
.57944 .30175 m .58048 .32346 L .6064 .33533 L p
1 g
F P
s
P
p
.002 w
.58048 .32346 m .57944 .30175 L .55187 .29962 L p
1 g
F P
s
P
p
.002 w
.36309 .53293 m .41254 .55662 L .41289 .53399 L p
1 g
F P
s
P
p
.002 w
.41289 .53399 m .36417 .51024 L .36309 .53293 L p
1 g
F P
s
P
p
.002 w
.66153 .44756 m .62613 .482 L .63223 .50581 L p
1 g
F P
s
P
p
.002 w
.62613 .482 m .66153 .44756 L .64989 .42477 L p
1 g
F P
s
P
p
.002 w
.65071 .36661 m .63473 .40261 L .64989 .42477 L p
1 g
F P
s
P
p
.002 w
.63473 .40261 m .65071 .36661 L .63 .3498 L p
1 g
F P
s
P
p
.002 w
.55187 .29962 m .54463 .28589 L .51965 .29392 L p
1 g
F P
s
P
p
.002 w
.51314 .28839 m .51965 .29392 L .54463 .28589 L p
1 g
F P
s
P
p
.002 w
.38579 .31005 m .38442 .3383 L .40964 .32571 L p
1 g
F P
s
P
p
.002 w
.40964 .32571 m .41103 .3039 L .38579 .31005 L p
1 g
F P
s
P
p
.002 w
.45853 .27567 m .44547 .28713 L .46993 .29455 L p
1 g
F P
s
P
p
.002 w
.46993 .29455 m .47654 .28885 L .45853 .27567 L p
1 g
F P
s
P
p
.002 w
.47058 .58798 m .52918 .58692 L .52859 .5672 L p
1 g
F P
s
P
p
.002 w
.52859 .5672 m .46934 .56824 L .47058 .58798 L p
1 g
F P
s
P
p
.002 w
.58545 .55361 m .52859 .5672 L .52918 .58692 L p
1 g
F P
s
P
p
.002 w
.54463 .28589 m .55187 .29962 L .57944 .30175 L p
1 g
F P
s
P
p
.002 w
.41443 .57668 m .47058 .58798 L .46934 .56824 L p
1 g
F P
s
P
p
.002 w
.46934 .56824 m .41254 .55662 L .41443 .57668 L p
1 g
F P
s
P
p
.002 w
.32751 .47591 m .36417 .51024 L .36865 .48614 L p
1 g
F P
s
P
p
.002 w
.36865 .48614 m .33358 .45263 L .32751 .47591 L p
1 g
F P
s
P
p
.002 w
.54463 .28589 m .53178 .27477 L .51314 .28839 L p
1 g
F P
s
P
p
.002 w
.50456 .28485 m .51314 .28839 L .53178 .27477 L p
1 g
F P
s
P
p
.002 w
.6055 .30722 m .6064 .33533 L .63 .3498 L p
1 g
F P
s
P
p
.002 w
.6064 .33533 m .6055 .30722 L .57944 .30175 L p
1 g
F P
s
P
p
.002 w
.4218 .28321 m .41103 .3039 L .438 .30107 L p
1 g
F P
s
P
p
.002 w
.438 .30107 m .44547 .28713 L .4218 .28321 L p
1 g
F P
s
P
p
.002 w
.47579 .26807 m .45853 .27567 L .47654 .28885 L p
1 g
F P
s
P
p
.002 w
.47654 .28885 m .48517 .28509 L .47579 .26807 L p
1 g
F P
s
P
p
.002 w
.32622 .39037 m .34375 .42938 L .35763 .40667 L p
1 g
F P
s
P
p
.002 w
.35763 .40667 m .34214 .37093 L .32622 .39037 L p
1 g
F P
s
P
p
.002 w
.53178 .27477 m .51468 .2676 L .50456 .28485 L p
1 g
F P
s
P
p
.002 w
.49488 .2837 m .50456 .28485 L .51468 .2676 L p
1 g
F P
s
P
p
.002 w
.49526 .26526 m .47579 .26807 L .48517 .28509 L p
1 g
F P
s
P
p
.002 w
.48517 .28509 m .49488 .2837 L .49526 .26526 L p
1 g
F P
s
P
p
.002 w
.51468 .2676 m .49526 .26526 L .49488 .2837 L p
1 g
F P
s
P
p
.002 w
.36291 .3195 m .36173 .35346 L .38442 .3383 L p
1 g
F P
s
P
p
.002 w
.38442 .3383 m .38579 .31005 L .36291 .3195 L p
1 g
F P
s
P
p
.002 w
.52918 .58692 m .58541 .57365 L .58545 .55361 L p
1 g
F P
s
P
p
.002 w
.63508 .52832 m .58545 .55361 L .58541 .57365 L p
1 g
F P
s
P
p
.002 w
.58545 .55361 m .63508 .52832 L .63223 .50581 L p
1 g
F P
s
P
p
.002 w
.66797 .38548 m .64989 .42477 L .66153 .44756 L p
1 g
F P
s
P
p
.002 w
.64989 .42477 m .66797 .38548 L .65071 .36661 L p
1 g
F P
s
P
p
.002 w
.56905 .28139 m .57944 .30175 L .6055 .30722 L p
1 g
F P
s
P
p
.002 w
.57944 .30175 m .56905 .28139 L .54463 .28589 L p
1 g
F P
s
P
p
.002 w
.53178 .27477 m .54463 .28589 L .56905 .28139 L p
1 g
F P
s
P
p
.002 w
.66926 .47048 m .63223 .50581 L .63508 .52832 L p
1 g
F P
s
P
p
.002 w
.63223 .50581 m .66926 .47048 L .66153 .44756 L p
1 g
F P
s
P
p
.002 w
.62941 .31602 m .63 .3498 L .65071 .36661 L p
1 g
F P
s
P
p
.002 w
.63 .3498 m .62941 .31602 L .6055 .30722 L p
1 g
F P
s
P
p
.002 w
.44104 .2661 m .4218 .28321 L .44547 .28713 L p
1 g
F P
s
P
p
.002 w
.44547 .28713 m .45853 .27567 L .44104 .2661 L p
1 g
F P
s
P
p
.002 w
.36558 .55364 m .41443 .57668 L .41254 .55662 L p
1 g
F P
s
P
p
.002 w
.41254 .55662 m .36309 .53293 L .36558 .55364 L p
1 g
F P
s
P
p
.002 w
.39949 .28305 m .38579 .31005 L .41103 .3039 L p
1 g
F P
s
P
p
.002 w
.41103 .3039 m .4218 .28321 L .39949 .28305 L p
1 g
F P
s
P
p
.002 w
.31448 .41141 m .33358 .45263 L .34375 .42938 L p
1 g
F P
s
P
p
.002 w
.34375 .42938 m .32622 .39037 L .31448 .41141 L p
1 g
F P
s
P
p
.002 w
.32585 .49866 m .36309 .53293 L .36417 .51024 L p
1 g
F P
s
P
p
.002 w
.36417 .51024 m .32751 .47591 L .32585 .49866 L p
1 g
F P
s
P
p
.002 w
.34303 .33215 m .34214 .37093 L .36173 .35346 L p
1 g
F P
s
P
p
.002 w
.36173 .35346 m .36291 .3195 L .34303 .33215 L p
1 g
F P
s
P
p
.002 w
.56905 .28139 m .55017 .26478 L .53178 .27477 L p
1 g
F P
s
P
p
.002 w
.51468 .2676 m .53178 .27477 L .55017 .26478 L p
1 g
F P
s
P
p
.002 w
.47265 .60431 m .52904 .60328 L .52918 .58692 L p
1 g
F P
s
P
p
.002 w
.52918 .58692 m .47058 .58798 L .47265 .60431 L p
1 g
F P
s
P
p
.002 w
.58541 .57365 m .52918 .58692 L .52904 .60328 L p
1 g
F P
s
P
p
.002 w
.41865 .5936 m .47265 .60431 L .47058 .58798 L p
1 g
F P
s
P
p
.002 w
.47058 .58798 m .41443 .57668 L .41865 .5936 L p
1 g
F P
s
P
p
.002 w
.46669 .25469 m .44104 .2661 L .45853 .27567 L p
1 g
F P
s
P
p
.002 w
.45853 .27567 m .47579 .26807 L .46669 .25469 L p
1 g
F P
s
P
p
.002 w
.59234 .28066 m .6055 .30722 L .62941 .31602 L p
1 g
F P
s
P
p
.002 w
.6055 .30722 m .59234 .28066 L .56905 .28139 L p
1 g
F P
s
P
p
.002 w
.68124 .40602 m .66153 .44756 L .66926 .47048 L p
1 g
F P
s
P
p
.002 w
.66153 .44756 m .68124 .40602 L .66797 .38548 L p
1 g
F P
s
P
p
.002 w
.55017 .26478 m .52477 .254 L .51468 .2676 L p
1 g
F P
s
P
p
.002 w
.49526 .26526 m .51468 .2676 L .52477 .254 L p
1 g
F P
s
P
p
.002 w
.65054 .32807 m .65071 .36661 L .66797 .38548 L p
1 g
F P
s
P
p
.002 w
.65071 .36661 m .65054 .32807 L .62941 .31602 L p
1 g
F P
s
P
p
.002 w
.49578 .25048 m .46669 .25469 L .47579 .26807 L p
1 g
F P
s
P
p
.002 w
.47579 .26807 m .49526 .26526 L .49578 .25048 L p
1 g
F P
s
P
p
.002 w
.55017 .26478 m .56905 .28139 L .59234 .28066 L p
1 g
F P
s
P
p
.002 w
.52477 .254 m .49578 .25048 L .49526 .26526 L p
1 g
F P
s
P
p
.002 w
.37915 .28681 m .36291 .3195 L .38579 .31005 L p
1 g
F P
s
P
p
.002 w
.38579 .31005 m .39949 .28305 L .37915 .28681 L p
1 g
F P
s
P
p
.002 w
.52904 .60328 m .58313 .59063 L .58541 .57365 L p
1 g
F P
s
P
p
.002 w
.63448 .54898 m .58541 .57365 L .58313 .59063 L p
1 g
F P
s
P
p
.002 w
.58541 .57365 m .63448 .54898 L .63508 .52832 L p
1 g
F P
s
P
p
.002 w
.42449 .26055 m .39949 .28305 L .4218 .28321 L p
1 g
F P
s
P
p
.002 w
.4218 .28321 m .44104 .2661 L .42449 .26055 L p
1 g
F P
s
P
p
.002 w
.67273 .493 m .63508 .52832 L .63448 .54898 L p
1 g
F P
s
P
p
.002 w
.63508 .52832 m .67273 .493 L .66926 .47048 L p
1 g
F P
s
P
p
.002 w
.30741 .43358 m .32751 .47591 L .33358 .45263 L p
1 g
F P
s
P
p
.002 w
.33358 .45263 m .31448 .41141 L .30741 .43358 L p
1 g
F P
s
P
p
.002 w
.32677 .34783 m .32622 .39037 L .34214 .37093 L p
1 g
F P
s
P
p
.002 w
.34214 .37093 m .34303 .33215 L .32677 .34783 L p
1 g
F P
s
P
p
.002 w
.37177 .57175 m .41865 .5936 L .41443 .57668 L p
1 g
F P
s
P
p
.002 w
.41443 .57668 m .36558 .55364 L .37177 .57175 L p
1 g
F P
s
P
p
.002 w
.32884 .52028 m .36558 .55364 L .36309 .53293 L p
1 g
F P
s
P
p
.002 w
.36309 .53293 m .32585 .49866 L .32884 .52028 L p
1 g
F P
s
P
p
.002 w
.61388 .28388 m .62941 .31602 L .65054 .32807 L p
1 g
F P
s
P
p
.002 w
.62941 .31602 m .61388 .28388 L .59234 .28066 L p
1 g
F P
s
P
p
.002 w
.59234 .28066 m .56786 .25884 L .55017 .26478 L p
1 g
F P
s
P
p
.002 w
.52477 .254 m .55017 .26478 L .56786 .25884 L p
1 g
F P
s
P
p
.002 w
.66825 .3432 m .66797 .38548 L .68124 .40602 L p
1 g
F P
s
P
p
.002 w
.66797 .38548 m .66825 .3432 L .65054 .32807 L p
1 g
F P
s
P
p
.002 w
.69004 .4278 m .66926 .47048 L .67273 .493 L p
1 g
F P
s
P
p
.002 w
.66926 .47048 m .69004 .4278 L .68124 .40602 L p
1 g
F P
s
P
p
.002 w
.45814 .24549 m .42449 .26055 L .44104 .2661 L p
1 g
F P
s
P
p
.002 w
.44104 .2661 m .46669 .25469 L .45814 .24549 L p
1 g
F P
s
P
p
.002 w
.47552 .61665 m .52811 .61568 L .52904 .60328 L p
1 g
F P
s
P
p
.002 w
.52904 .60328 m .47265 .60431 L .47552 .61665 L p
1 g
F P
s
P
p
.002 w
.58313 .59063 m .52904 .60328 L .52811 .61568 L p
1 g
F P
s
P
p
.002 w
.42522 .60679 m .47552 .61665 L .47265 .60431 L p
1 g
F P
s
P
p
.002 w
.47265 .60431 m .41865 .5936 L .42522 .60679 L p
1 g
F P
s
P
p
.002 w
.56786 .25884 m .59234 .28066 L .61388 .28388 L p
1 g
F P
s
P
p
.002 w
.36138 .29459 m .34303 .33215 L .36291 .3195 L p
1 g
F P
s
P
p
.002 w
.36291 .3195 m .37915 .28681 L .36138 .29459 L p
1 g
F P
s
P
p
.002 w
.56786 .25884 m .53458 .2446 L .52477 .254 L p
1 g
F P
s
P
p
.002 w
.49578 .25048 m .52477 .254 L .53458 .2446 L p
1 g
F P
s
P
p
.002 w
.31473 .36627 m .31448 .41141 L .32622 .39037 L p
1 g
F P
s
P
p
.002 w
.32622 .39037 m .32677 .34783 L .31473 .36627 L p
1 g
F P
s
P
p
.002 w
.30538 .45635 m .32585 .49866 L .32751 .47591 L p
1 g
F P
s
P
p
.002 w
.32751 .47591 m .30741 .43358 L .30538 .45635 L p
1 g
F P
s
P
p
.002 w
.40935 .2594 m .37915 .28681 L .39949 .28305 L p
1 g
F P
s
P
p
.002 w
.39949 .28305 m .42449 .26055 L .40935 .2594 L p
1 g
F P
s
P
p
.002 w
.49643 .23992 m .45814 .24549 L .46669 .25469 L p
1 g
F P
s
P
p
.002 w
.46669 .25469 m .49578 .25048 L .49643 .23992 L p
1 g
F P
s
P
p
.002 w
.58313 .59063 m .63027 .56719 L .63448 .54898 L p
1 g
F P
s
P
p
.002 w
.67168 .51456 m .63448 .54898 L .63027 .56719 L p
1 g
F P
s
P
p
.002 w
.63448 .54898 m .67168 .51456 L .67273 .493 L p
1 g
F P
s
P
p
.002 w
.53458 .2446 m .49643 .23992 L .49578 .25048 L p
1 g
F P
s
P
p
.002 w
.52811 .61568 m .57853 .60398 L .58313 .59063 L p
1 g
F P
s
P
p
.002 w
.63027 .56719 m .58313 .59063 L .57853 .60398 L p
1 g
F P
s
P
p
.002 w
.63306 .29117 m .65054 .32807 L .66825 .3432 L p
1 g
F P
s
P
p
.002 w
.65054 .32807 m .63306 .29117 L .61388 .28388 L p
1 g
F P
s
P
p
.002 w
.38168 .58666 m .42522 .60679 L .41865 .5936 L p
1 g
F P
s
P
p
.002 w
.41865 .5936 m .37177 .57175 L .38168 .58666 L p
1 g
F P
s
P
p
.002 w
.33663 .54015 m .37177 .57175 L .36558 .55364 L p
1 g
F P
s
P
p
.002 w
.36558 .55364 m .32884 .52028 L .33663 .54015 L p
1 g
F P
s
P
p
.002 w
.68193 .36117 m .68124 .40602 L .69004 .4278 L p
1 g
F P
s
P
p
.002 w
.68124 .40602 m .68193 .36117 L .66825 .3432 L p
1 g
F P
s
P
p
.002 w
.69394 .45032 m .67273 .493 L .67168 .51456 L p
1 g
F P
s
P
p
.002 w
.67273 .493 m .69394 .45032 L .69004 .4278 L p
1 g
F P
s
P
p
.002 w
.61388 .28388 m .58437 .2573 L .56786 .25884 L p
1 g
F P
s
P
p
.002 w
.53458 .2446 m .56786 .25884 L .58437 .2573 L p
1 g
F P
s
P
p
.002 w
.3468 .30639 m .32677 .34783 L .34303 .33215 L p
1 g
F P
s
P
p
.002 w
.34303 .33215 m .36138 .29459 L .3468 .30639 L p
1 g
F P
s
P
p
.002 w
.58437 .2573 m .61388 .28388 L .63306 .29117 L p
1 g
F P
s
P
p
.002 w
.45036 .24096 m .40935 .2594 L .42449 .26055 L p
1 g
F P
s
P
p
.002 w
.42449 .26055 m .45814 .24549 L .45036 .24096 L p
1 g
F P
s
P
p
.002 w
.30745 .3871 m .30741 .43358 L .31448 .41141 L p
1 g
F P
s
P
p
.002 w
.31448 .41141 m .31473 .36627 L .30745 .3871 L p
1 g
F P
s
P
p
.002 w
.30871 .47912 m .32884 .52028 L .32585 .49866 L p
1 g
F P
s
P
p
.002 w
.32585 .49866 m .30538 .45635 L .30871 .47912 L p
1 g
F P
s
P
p
.002 w
.47917 .62445 m .52638 .62357 L .52811 .61568 L p
1 g
F P
s
P
p
.002 w
.52811 .61568 m .47552 .61665 L .47917 .62445 L p
1 g
F P
s
P
p
.002 w
.57853 .60398 m .52811 .61568 L .52638 .62357 L p
1 g
F P
s
P
p
.002 w
.4341 .61567 m .47917 .62445 L .47552 .61665 L p
1 g
F P
s
P
p
.002 w
.47552 .61665 m .42522 .60679 L .4341 .61567 L p
1 g
F P
s
P
p
.002 w
.39611 .26291 m .36138 .29459 L .37915 .28681 L p
1 g
F P
s
P
p
.002 w
.37915 .28681 m .40935 .2594 L .39611 .26291 L p
1 g
F P
s
P
p
.002 w
.57853 .60398 m .62237 .58234 L .63027 .56719 L p
1 g
F P
s
P
p
.002 w
.66591 .53453 m .63027 .56719 L .62237 .58234 L p
1 g
F P
s
P
p
.002 w
.63027 .56719 m .66591 .53453 L .67168 .51456 L p
1 g
F P
s
P
p
.002 w
.58437 .2573 m .54386 .23987 L .53458 .2446 L p
1 g
F P
s
P
p
.002 w
.49643 .23992 m .53458 .2446 L .54386 .23987 L p
1 g
F P
s
P
p
.002 w
.64925 .30252 m .66825 .3432 L .68193 .36117 L p
1 g
F P
s
P
p
.002 w
.66825 .3432 m .64925 .30252 L .63306 .29117 L p
1 g
F P
s
P
p
.002 w
.49721 .23412 m .45036 .24096 L .45814 .24549 L p
1 g
F P
s
P
p
.002 w
.45814 .24549 m .49643 .23992 L .49721 .23412 L p
1 g
F P
s
P
p
.002 w
.69102 .38163 m .69004 .4278 L .69394 .45032 L p
1 g
F P
s
P
p
.002 w
.69004 .4278 m .69102 .38163 L .68193 .36117 L p
1 g
F P
s
P
p
.002 w
.52638 .62357 m .5716 .61313 L .57853 .60398 L p
1 g
F P
s
P
p
.002 w
.62237 .58234 m .57853 .60398 L .5716 .61313 L p
1 g
F P
s
P
p
.002 w
.54386 .23987 m .49721 .23412 L .49643 .23992 L p
1 g
F P
s
P
p
.002 w
.34925 .55762 m .38168 .58666 L .37177 .57175 L p
1 g
F P
s
P
p
.002 w
.37177 .57175 m .33663 .54015 L .34925 .55762 L p
1 g
F P
s
P
p
.002 w
.69261 .473 m .67168 .51456 L .66591 .53453 L p
1 g
F P
s
P
p
.002 w
.67168 .51456 m .69261 .473 L .69394 .45032 L p
1 g
F P
s
P
p
.002 w
.39525 .59778 m .4341 .61567 L .42522 .60679 L p
1 g
F P
s
P
p
.002 w
.42522 .60679 m .38168 .58666 L .39525 .59778 L p
1 g
F P
s
P
p
.002 w
.33598 .32212 m .31473 .36627 L .32677 .34783 L p
1 g
F P
s
P
p
.002 w
.32677 .34783 m .3468 .30639 L .33598 .32212 L p
1 g
F P
s
P
p
.002 w
.30537 .40983 m .30538 .45635 L .30741 .43358 L p
1 g
F P
s
P
p
.002 w
.30741 .43358 m .30745 .3871 L .30537 .40983 L p
1 g
F P
s
P
p
.002 w
.63306 .29117 m .59919 .26047 L .58437 .2573 L p
1 g
F P
s
P
p
.002 w
.54386 .23987 m .58437 .2573 L .59919 .26047 L p
1 g
F P
s
P
p
.002 w
.59919 .26047 m .63306 .29117 L .64925 .30252 L p
1 g
F P
s
P
p
.002 w
.31754 .50122 m .33663 .54015 L .32884 .52028 L p
1 g
F P
s
P
p
.002 w
.32884 .52028 m .30871 .47912 L .31754 .50122 L p
1 g
F P
s
P
p
.002 w
.44363 .24152 m .39611 .26291 L .40935 .2594 L p
1 g
F P
s
P
p
.002 w
.40935 .2594 m .45036 .24096 L .44363 .24152 L p
1 g
F P
s
P
p
.002 w
.38526 .27129 m .3468 .30639 L .36138 .29459 L p
1 g
F P
s
P
p
.002 w
.36138 .29459 m .39611 .26291 L .38526 .27129 L p
1 g
F P
s
P
p
.002 w
.68193 .36117 m .66185 .31785 L .64925 .30252 L p
1 g
F P
s
P
p
.002 w
.66185 .31785 m .68193 .36117 L .69102 .38163 L p
1 g
F P
s
P
p
.002 w
.48357 .62721 m .52384 .62645 L .52638 .62357 L p
1 g
F P
s
P
p
.002 w
.52638 .62357 m .47917 .62445 L .48357 .62721 L p
1 g
F P
s
P
p
.002 w
.5716 .61313 m .52638 .62357 L .52384 .62645 L p
1 g
F P
s
P
p
.002 w
.69394 .45032 m .69506 .40411 L .69102 .38163 L p
1 g
F P
s
P
p
.002 w
.69506 .40411 m .69394 .45032 L .69261 .473 L p
1 g
F P
s
P
p
.002 w
.5716 .61313 m .61077 .59387 L .62237 .58234 L p
1 g
F P
s
P
p
.002 w
.65533 .5523 m .62237 .58234 L .61077 .59387 L p
1 g
F P
s
P
p
.002 w
.62237 .58234 m .65533 .5523 L .66591 .53453 L p
1 g
F P
s
P
p
.002 w
.44519 .61974 m .48357 .62721 L .47917 .62445 L p
1 g
F P
s
P
p
.002 w
.47917 .62445 m .4341 .61567 L .44519 .61974 L p
1 g
F P
s
P
p
.002 w
.59919 .26047 m .55232 .24025 L .54386 .23987 L p
1 g
F P
s
P
p
.002 w
.49721 .23412 m .54386 .23987 L .55232 .24025 L p
1 g
F P
s
P
p
.004 w
.5091 .64318 m
.51023 .66975 L
s
P
p
.002 w
.66591 .53453 m .68583 .4952 L .69261 .473 L p
1 g
F P
s
P
p
.002 w
.68583 .4952 m .66591 .53453 L .65533 .5523 L p
1 g
F P
s
P
p
.002 w
.36656 .57207 m .39525 .59778 L .38168 .58666 L p
1 g
F P
s
P
p
.002 w
.38168 .58666 m .34925 .55762 L .36656 .57207 L p
1 g
F P
s
P
p
.002 w
.4981 .23357 m .44363 .24152 L .45036 .24096 L p
1 g
F P
s
P
p
.002 w
.45036 .24096 m .49721 .23412 L .4981 .23357 L p
1 g
F P
s
P
p
.002 w
.32947 .3415 m .30745 .3871 L .31473 .36627 L p
1 g
F P
s
P
p
.002 w
.31473 .36627 m .33598 .32212 L .32947 .3415 L p
1 g
F P
s
P
p
.002 w
.52384 .62645 m .56237 .61757 L .5716 .61313 L p
1 g
F P
s
P
p
.002 w
.61077 .59387 m .5716 .61313 L .56237 .61757 L p
1 g
F P
s
P
p
.002 w
.30879 .43387 m .30871 .47912 L .30538 .45635 L p
1 g
F P
s
P
p
.002 w
.30538 .45635 m .30537 .40983 L .30879 .43387 L p
1 g
F P
s
P
p
.002 w
.55232 .24025 m .4981 .23357 L .49721 .23412 L p
1 g
F P
s
P
p
.002 w
.4123 .60458 m .44519 .61974 L .4341 .61567 L p
1 g
F P
s
P
p
.002 w
.4341 .61567 m .39525 .59778 L .4123 .60458 L p
1 g
F P
s
P
p
.002 w
.64925 .30252 m .61183 .26853 L .59919 .26047 L p
1 g
F P
s
P
p
.002 w
.61183 .26853 m .64925 .30252 L .66185 .31785 L p
1 g
F P
s
P
p
.002 w
.33187 .52197 m .34925 .55762 L .33663 .54015 L p
1 g
F P
s
P
p
.002 w
.33663 .54015 m .31754 .50122 L .33187 .52197 L p
1 g
F P
s
P
p
.002 w
.55232 .24025 m .59919 .26047 L .61183 .26853 L p
1 g
F P
s
P
p
.002 w
.37726 .28457 m .33598 .32212 L .3468 .30639 L p
1 g
F P
s
P
p
.002 w
.3468 .30639 m .38526 .27129 L .37726 .28457 L p
1 g
F P
s
P
p
.002 w
.6703 .33692 m .69102 .38163 L .69506 .40411 L p
1 g
F P
s
P
p
.002 w
.69102 .38163 m .6703 .33692 L .66185 .31785 L p
1 g
F P
s
P
p
.002 w
.43822 .24749 m .38526 .27129 L .39611 .26291 L p
1 g
F P
s
P
p
.002 w
.39611 .26291 m .44363 .24152 L .43822 .24749 L p
1 g
F P
s
P
p
.002 w
.69367 .42805 m .69261 .473 L .68583 .4952 L p
1 g
F P
s
P
p
.002 w
.69261 .473 m .69367 .42805 L .69506 .40411 L p
1 g
F P
s
P
p
.002 w
.56237 .61757 m .59559 .60123 L .61077 .59387 L p
1 g
F P
s
P
p
.002 w
.61077 .59387 m .64001 .56724 L .65533 .5523 L p
1 g
F P
s
P
p
.002 w
.64001 .56724 m .61077 .59387 L .59559 .60123 L p
1 g
F P
s
P
p
.002 w
.67355 .51626 m .65533 .5523 L .64001 .56724 L p
1 g
F P
s
P
p
.002 w
.65533 .5523 m .67355 .51626 L .68583 .4952 L p
1 g
F P
s
P
p
.002 w
.48863 .62449 m .52052 .6239 L .52384 .62645 L p
1 g
F P
s
P
p
.002 w
.52384 .62645 m .48357 .62721 L .48863 .62449 L p
1 g
F P
s
P
p
.002 w
.56237 .61757 m .52384 .62645 L .52052 .6239 L p
1 g
F P
s
P
p
.002 w
.32769 .36414 m .30537 .40983 L .30745 .3871 L p
1 g
F P
s
P
p
.002 w
.30745 .3871 m .32947 .3415 L .32769 .36414 L p
1 g
F P
s
P
p
.002 w
.45831 .61857 m .48863 .62449 L .48357 .62721 L p
1 g
F P
s
P
p
.002 w
.48357 .62721 m .44519 .61974 L .45831 .61857 L p
1 g
F P
s
P
p
.002 w
.31788 .45852 m .31754 .50122 L .30871 .47912 L p
1 g
F P
s
P
p
.002 w
.30871 .47912 m .30879 .43387 L .31788 .45852 L p
1 g
F P
s
P
p
.002 w
.38826 .5829 m .4123 .60458 L .39525 .59778 L p
1 g
F P
s
P
p
.002 w
.39525 .59778 m .36656 .57207 L .38826 .5829 L p
1 g
F P
s
P
p
.002 w
.61183 .26853 m .55965 .24607 L .55232 .24025 L p
1 g
F P
s
P
p
.002 w
.4981 .23357 m .55232 .24025 L .55965 .24607 L p
1 g
F P
s
P
p
.002 w
.49908 .23863 m .43822 .24749 L .44363 .24152 L p
1 g
F P
s
P
p
.002 w
.44363 .24152 m .4981 .23357 L .49908 .23863 L p
1 g
F P
s
P
p
.002 w
.62177 .28154 m .66185 .31785 L .6703 .33692 L p
1 g
F P
s
P
p
.002 w
.66185 .31785 m .62177 .28154 L .61183 .26853 L p
1 g
F P
s
P
p
.002 w
.35148 .54065 m .36656 .57207 L .34925 .55762 L p
1 g
F P
s
P
p
.002 w
.34925 .55762 m .33187 .52197 L .35148 .54065 L p
1 g
F P
s
P
p
.002 w
.52052 .6239 m .55098 .61686 L .56237 .61757 L p
1 g
F P
s
P
p
.002 w
.59559 .60123 m .56237 .61757 L .55098 .61686 L p
1 g
F P
s
P
p
.002 w
.4325 .60661 m .45831 .61857 L .44519 .61974 L p
1 g
F P
s
P
p
.002 w
.44519 .61974 m .4123 .60458 L .4325 .60661 L p
1 g
F P
s
P
p
.002 w
.55965 .24607 m .49908 .23863 L .4981 .23357 L p
1 g
F P
s
P
p
.002 w
.67411 .35934 m .69506 .40411 L .69367 .42805 L p
1 g
F P
s
P
p
.002 w
.69506 .40411 m .67411 .35934 L .6703 .33692 L p
1 g
F P
s
P
p
.002 w
.55965 .24607 m .61183 .26853 L .62177 .28154 L p
1 g
F P
s
P
p
.002 w
.68665 .45278 m .68583 .4952 L .67355 .51626 L p
1 g
F P
s
P
p
.002 w
.68583 .4952 m .68665 .45278 L .69367 .42805 L p
1 g
F P
s
P
p
.002 w
.37254 .30264 m .32947 .3415 L .33598 .32212 L p
1 g
F P
s
P
p
.002 w
.33598 .32212 m .37726 .28457 L .37254 .30264 L p
1 g
F P
s
P
p
.002 w
.43437 .25904 m .37726 .28457 L .38526 .27129 L p
1 g
F P
s
P
p
.002 w
.38526 .27129 m .43822 .24749 L .43437 .25904 L p
1 g
F P
s
P
p
.002 w
.33093 .38945 m .30879 .43387 L .30537 .40983 L p
1 g
F P
s
P
p
.002 w
.30537 .40983 m .32769 .36414 L .33093 .38945 L p
1 g
F P
s
P
p
.002 w
.59559 .60123 m .62016 .57876 L .64001 .56724 L p
1 g
F P
s
P
p
.002 w
.6559 .53546 m .64001 .56724 L .62016 .57876 L p
1 g
F P
s
P
p
.002 w
.64001 .56724 m .6559 .53546 L .67355 .51626 L p
1 g
F P
s
P
p
.004 w
.66253 .53399 m
.66375 .53477 L
s
P
p
.004 w
.5 .43051 m
.6592 .53187 L
s
P
p
.004 w
.66375 .53477 m
.66985 .53865 L
s
P
p
.004 w
.66985 .53865 m
.67274 .54049 L
s
P
p
.004 w
.67274 .54049 m
.75147 .59062 L
s
P
p
.002 w
.33257 .48301 m .33187 .52197 L .31754 .50122 L p
1 g
F P
s
P
p
.002 w
.31754 .50122 m .31788 .45852 L .33257 .48301 L p
1 g
F P
s
P
p
.002 w
.55098 .61686 m .57709 .60396 L .59559 .60123 L p
1 g
F P
s
P
p
.002 w
.62016 .57876 m .59559 .60123 L .57709 .60396 L p
1 g
F P
s
P
p
.002 w
.41388 .5896 m .4325 .60661 L .4123 .60458 L p
1 g
F P
s
P
p
.002 w
.4123 .60458 m .38826 .5829 L .41388 .5896 L p
1 g
F P
s
P
p
.002 w
.37595 .55657 m .38826 .5829 L .36656 .57207 L p
1 g
F P
s
P
p
.002 w
.36656 .57207 m .35148 .54065 L .37595 .55657 L p
1 g
F P
s
P
p
.002 w
.49423 .61603 m .51645 .61562 L .52052 .6239 L p
1 g
F P
s
P
p
.002 w
.52052 .6239 m .48863 .62449 L .49423 .61603 L p
1 g
F P
s
P
p
.002 w
.55098 .61686 m .52052 .6239 L .51645 .61562 L p
1 g
F P
s
P
p
.002 w
.62854 .29938 m .6703 .33692 L .67411 .35934 L p
1 g
F P
s
P
p
.002 w
.6703 .33692 m .62854 .29938 L .62177 .28154 L p
1 g
F P
s
P
p
.002 w
.47317 .61189 m .49423 .61603 L .48863 .62449 L p
1 g
F P
s
P
p
.002 w
.48863 .62449 m .45831 .61857 L .47317 .61189 L p
1 g
F P
s
P
p
.002 w
.62177 .28154 m .56556 .25748 L .55965 .24607 L p
1 g
F P
s
P
p
.002 w
.49908 .23863 m .55965 .24607 L .56556 .25748 L p
1 g
F P
s
P
p
.002 w
.67295 .38456 m .69367 .42805 L .68665 .45278 L p
1 g
F P
s
P
p
.002 w
.69367 .42805 m .67295 .38456 L .67411 .35934 L p
1 g
F P
s
P
p
.002 w
.67398 .47755 m .67355 .51626 L .6559 .53546 L p
1 g
F P
s
P
p
.002 w
.67355 .51626 m .67398 .47755 L .68665 .45278 L p
1 g
F P
s
P
p
.002 w
.51645 .61562 m .53764 .6107 L .55098 .61686 L p
1 g
F P
s
P
p
.002 w
.57709 .60396 m .55098 .61686 L .53764 .6107 L p
1 g
F P
s
P
p
.002 w
.50014 .24951 m .43437 .25904 L .43822 .24749 L p
1 g
F P
s
P
p
.002 w
.43822 .24749 m .49908 .23863 L .50014 .24951 L p
1 g
F P
s
P
p
.002 w
.45538 .60354 m .47317 .61189 L .45831 .61857 L p
1 g
F P
s
P
p
.002 w
.45831 .61857 m .4325 .60661 L .45538 .60354 L p
1 g
F P
s
P
p
.002 w
.56556 .25748 m .62177 .28154 L .62854 .29938 L p
1 g
F P
s
P
p
.002 w
.37145 .32515 m .32769 .36414 L .32947 .3415 L p
1 g
F P
s
P
p
.002 w
.32947 .3415 m .37254 .30264 L .37145 .32515 L p
1 g
F P
s
P
p
.002 w
.56556 .25748 m .50014 .24951 L .49908 .23863 L p
1 g
F P
s
P
p
.002 w
.35258 .50651 m .35148 .54065 L .33187 .52197 L p
1 g
F P
s
P
p
.002 w
.33187 .52197 m .33257 .48301 L .35258 .50651 L p
1 g
F P
s
P
p
.002 w
.33931 .4167 m .31788 .45852 L .30879 .43387 L p
1 g
F P
s
P
p
.002 w
.30879 .43387 m .33093 .38945 L .33931 .4167 L p
1 g
F P
s
P
p
.002 w
.57709 .60396 m .59618 .58632 L .62016 .57876 L p
1 g
F P
s
P
p
.002 w
.63321 .5521 m .62016 .57876 L .59618 .58632 L p
1 g
F P
s
P
p
.002 w
.62016 .57876 m .63321 .5521 L .6559 .53546 L p
1 g
F P
s
P
p
.002 w
.43232 .27615 m .37254 .30264 L .37726 .28457 L p
1 g
F P
s
P
p
.002 w
.37726 .28457 m .43437 .25904 L .43232 .27615 L p
1 g
F P
s
P
p
.002 w
.53764 .6107 m .55567 .60171 L .57709 .60396 L p
1 g
F P
s
P
p
.002 w
.59618 .58632 m .57709 .60396 L .55567 .60171 L p
1 g
F P
s
P
p
.002 w
.40464 .5691 m .41388 .5896 L .38826 .5829 L p
1 g
F P
s
P
p
.002 w
.38826 .5829 m .37595 .55657 L .40464 .5691 L p
1 g
F P
s
P
p
.002 w
.44273 .59177 m .45538 .60354 L .4325 .60661 L p
1 g
F P
s
P
p
.002 w
.4325 .60661 m .41388 .5896 L .44273 .59177 L p
1 g
F P
s
P
p
.002 w
.63175 .32172 m .67411 .35934 L .67295 .38456 L p
1 g
F P
s
P
p
.002 w
.67411 .35934 m .63175 .32172 L .62854 .29938 L p
1 g
F P
s
P
p
.002 w
.66662 .41185 m .68665 .45278 L .67398 .47755 L p
1 g
F P
s
P
p
.002 w
.68665 .45278 m .66662 .41185 L .67295 .38456 L p
1 g
F P
s
P
p
.002 w
.65585 .50152 m .6559 .53546 L .63321 .5521 L p
1 g
F P
s
P
p
.002 w
.6559 .53546 m .65585 .50152 L .67398 .47755 L p
1 g
F P
s
P
p
.002 w
.50024 .60174 m .51173 .60153 L .51645 .61562 L p
1 g
F P
s
P
p
.002 w
.51645 .61562 m .49423 .61603 L .50024 .60174 L p
1 g
F P
s
P
p
.002 w
.53764 .6107 m .51645 .61562 L .51173 .60153 L p
1 g
F P
s
P
p
.002 w
.48938 .59957 m .50024 .60174 L .49423 .61603 L p
1 g
F P
s
P
p
.002 w
.49423 .61603 m .47317 .61189 L .48938 .59957 L p
1 g
F P
s
P
p
.002 w
.62854 .29938 m .56977 .27446 L .56556 .25748 L p
1 g
F P
s
P
p
.002 w
.50014 .24951 m .56556 .25748 L .56977 .27446 L p
1 g
F P
s
P
p
.002 w
.37738 .52816 m .37595 .55657 L .35148 .54065 L p
1 g
F P
s
P
p
.002 w
.35148 .54065 m .35258 .50651 L .37738 .52816 L p
1 g
F P
s
P
p
.002 w
.37419 .35155 m .33093 .38945 L .32769 .36414 L p
1 g
F P
s
P
p
.002 w
.32769 .36414 m .37145 .32515 L .37419 .35155 L p
1 g
F P
s
P
p
.002 w
.35274 .445 m .33257 .48301 L .31788 .45852 L p
1 g
F P
s
P
p
.002 w
.31788 .45852 m .33931 .4167 L .35274 .445 L p
1 g
F P
s
P
p
.002 w
.51173 .60153 m .52266 .59897 L .53764 .6107 L p
1 g
F P
s
P
p
.002 w
.55567 .60171 m .53764 .6107 L .52266 .59897 L p
1 g
F P
s
P
p
.002 w
.56977 .27446 m .62854 .29938 L .63175 .32172 L p
1 g
F P
s
P
p
.002 w
.50123 .26623 m .43232 .27615 L .43437 .25904 L p
1 g
F P
s
P
p
.002 w
.43437 .25904 m .50014 .24951 L .50123 .26623 L p
1 g
F P
s
P
p
.002 w
.48029 .59524 m .48938 .59957 L .47317 .61189 L p
1 g
F P
s
P
p
.002 w
.47317 .61189 m .45538 .60354 L .48029 .59524 L p
1 g
F P
s
P
p
.002 w
.55567 .60171 m .56868 .5895 L .59618 .58632 L p
1 g
F P
s
P
p
.002 w
.60604 .56555 m .59618 .58632 L .56868 .5895 L p
1 g
F P
s
P
p
.002 w
.59618 .58632 m .60604 .56555 L .63321 .5521 L p
1 g
F P
s
P
p
.002 w
.56977 .27446 m .50123 .26623 L .50014 .24951 L p
1 g
F P
s
P
p
.002 w
.43668 .5777 m .44273 .59177 L .41388 .5896 L p
1 g
F P
s
P
p
.002 w
.41388 .5896 m .40464 .5691 L .43668 .5777 L p
1 g
F P
s
P
p
.002 w
.43223 .29854 m .37145 .32515 L .37254 .30264 L p
1 g
F P
s
P
p
.002 w
.37254 .30264 m .43232 .27615 L .43223 .29854 L p
1 g
F P
s
P
p
.002 w
.63271 .52386 m .63321 .5521 L .60604 .56555 L p
1 g
F P
s
P
p
.002 w
.63321 .5521 m .63271 .52386 L .65585 .50152 L p
1 g
F P
s
P
p
.002 w
.65513 .44036 m .67398 .47755 L .65585 .50152 L p
1 g
F P
s
P
p
.002 w
.67398 .47755 m .65513 .44036 L .66662 .41185 L p
1 g
F P
s
P
p
.002 w
.52266 .59897 m .5319 .5943 L .55567 .60171 L p
1 g
F P
s
P
p
.002 w
.56868 .5895 m .55567 .60171 L .5319 .5943 L p
1 g
F P
s
P
p
.002 w
.63111 .34805 m .67295 .38456 L .66662 .41185 L p
1 g
F P
s
P
p
.002 w
.67295 .38456 m .63111 .34805 L .63175 .32172 L p
1 g
F P
s
P
p
.002 w
.47393 .58917 m .48029 .59524 L .45538 .60354 L p
1 g
F P
s
P
p
.002 w
.45538 .60354 m .44273 .59177 L .47393 .58917 L p
1 g
F P
s
P
p
.002 w
.40621 .54717 m .40464 .5691 L .37595 .55657 L p
1 g
F P
s
P
p
.002 w
.37595 .55657 m .37738 .52816 L .40621 .54717 L p
1 g
F P
s
P
p
.002 w
.37089 .47337 m .35258 .50651 L .33257 .48301 L p
1 g
F P
s
P
p
.002 w
.33257 .48301 m .35274 .445 L .37089 .47337 L p
1 g
F P
s
P
p
.002 w
.38085 .38107 m .33931 .4167 L .33093 .38945 L p
1 g
F P
s
P
p
.002 w
.33093 .38945 m .37419 .35155 L .38085 .38107 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50505 .54865 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.5319 .5943 m .53846 .58801 L .56868 .5895 L p
1 g
F P
s
P
p
.002 w
.57519 .57524 m .56868 .5895 L .53846 .58801 L p
1 g
F P
s
P
p
.002 w
.56868 .5895 m .57519 .57524 L .60604 .56555 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.60522 .54374 m .60604 .56555 L .57519 .57524 L p
1 g
F P
s
P
p
.002 w
.60604 .56555 m .60522 .54374 L .63271 .52386 L p
1 g
F P
s
P
p
.002 w
.51173 .60153 m .50024 .60174 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.52266 .59897 m .51173 .60153 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.63873 .46913 m .65585 .50152 L .63271 .52386 L p
1 g
F P
s
P
p
.002 w
.65585 .50152 m .63873 .46913 L .65513 .44036 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50024 .60174 m .48938 .59957 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.47102 .58199 m .47393 .58917 L .44273 .59177 L p
1 g
F P
s
P
p
.002 w
.44273 .59177 m .43668 .5777 L .47102 .58199 L p
1 g
F P
s
P
p
.002 w
.63175 .32172 m .57203 .29676 L .56977 .27446 L p
1 g
F P
s
P
p
.002 w
.50123 .26623 m .56977 .27446 L .57203 .29676 L p
1 g
F P
s
P
p
.002 w
.57203 .29676 m .63175 .32172 L .63111 .34805 L p
1 g
F P
s
P
p
.002 w
.5319 .5943 m .52266 .59897 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.48938 .59957 m .48029 .59524 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50233 .28854 m .43223 .29854 L .43232 .27615 L p
1 g
F P
s
P
p
.002 w
.43232 .27615 m .50123 .26623 L .50233 .28854 L p
1 g
F P
s
P
p
.002 w
.4381 .56279 m .43668 .5777 L .40464 .5691 L p
1 g
F P
s
P
p
.002 w
.40464 .5691 m .40621 .54717 L .4381 .56279 L p
1 g
F P
s
P
p
.002 w
.62646 .37759 m .66662 .41185 L .65513 .44036 L p
1 g
F P
s
P
p
.002 w
.66662 .41185 m .62646 .37759 L .63111 .34805 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54162 .58073 m .50863 .58169 L p
.51148 .58094 L 1 g
F P
s
P
p
.002 w
.47393 .58917 m .47102 .58199 L .49371 .58184 L p
1 g
F P
s
P
p
.002 w
.49371 .58184 m .50647 .58175 L .49969 .5833 L p
1 g
F P
s
P
p
.002 w
.49969 .5833 m .47393 .58917 L p
.49371 .58184 L 1 g
F P
s
P
p
.002 w
.47102 .58199 m .43668 .5777 L p
.46796 .57482 L 1 g
F P
s
P
p
.46796 .57482 m .46822 .57493 L .47102 .58199 L 1 g
F
P
p
.002 w
.4717 .57628 m .4716 .57715 L p
.46822 .57493 L 1 g
F P
s
P
p
.002 w
.4716 .57715 m .47102 .58199 L p
.46822 .57493 L 1 g
F P
s
P
p
.002 w
.46822 .57493 m .46872 .57265 L p
.45913 .56882 L 1 g
F P
s
P
p
.002 w
.46268 .57127 m .45578 .56889 L p
.45299 .56457 L 1 g
F P
s
P
p
.002 w
.45578 .56889 m .4381 .56279 L p
.45199 .56446 L 1 g
F P
s
P
p
.45199 .56446 m .45299 .56457 L .45578 .56889 L 1 g
F
P
p
.002 w
.4381 .56279 m .40621 .54717 L p
.43879 .54837 L 1 g
F P
s
P
p
.002 w
.43841 .54724 m .43925 .54566 L p
.43533 .5379 L 1 g
F P
s
P
p
.002 w
.43586 .53974 m .43216 .53679 L p
.43295 .52966 L 1 g
F P
s
P
p
.002 w
.43216 .53679 m .4189 .5262 L p
.43257 .52956 L 1 g
F P
s
P
p
.43257 .52956 m .43295 .52966 L .43216 .53679 L 1 g
F
P
p
.002 w
.4189 .5262 m .3932 .50078 L p
.43413 .50747 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43413 .50747 m .43395 .50933 L .4189 .5262 L 1 g
F
P
p
.002 w
.4334 .51508 m .43004 .51765 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43004 .51765 m .4189 .5262 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43839 .49999 L 1 g
F P
s
P
p
.4223 .47778 m .44509 .48652 L .44279 .49114 L 1 g
F
P
p
.002 w
.43744 .5019 m .43526 .49844 L p
.44279 .49114 L 1 g
F P
s
P
p
.002 w
.43526 .49844 m .4223 .47778 L p
.44279 .49114 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43395 .50933 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43263 .52855 L p
1 g
F P
s
P
p
.43257 .52956 m .43278 .52908 L .43295 .52966 L 1 g
F
P
p
.002 w
.4189 .5262 m .4334 .51508 L p
.43257 .52956 L 1 g
F P
s
P
p
.43925 .54566 m .43263 .52855 L .43533 .5379 L 1 g
F
P
p
.43346 .52734 m .43395 .50933 L .43313 .51787 L 1 g
F
P
p
.002 w
.43263 .52855 m .43346 .52734 L p
.43317 .51904 L 1 g
F P
s
P
p
.002 w
.4334 .51508 m .4417 .5087 L p
.43257 .52956 L 1 g
F P
s
P
p
.002 w
.43263 .52855 m .43146 .53025 L p
.43533 .5379 L 1 g
F P
s
P
p
.002 w
.4417 .5087 m .46274 .53699 L p
.43295 .52966 L 1 g
F P
s
P
p
.43278 .52908 m .4417 .5087 L .43295 .52966 L 1 g
F
P
p
.43313 .51787 m .4334 .51508 L .43287 .51061 L 1 g
F
P
p
.002 w
.43395 .50933 m .43371 .50962 L p
.4334 .51508 L 1 g
F P
s
P
p
.002 w
.43371 .50962 m .43287 .51061 L p
.4334 .51508 L 1 g
F P
s
P
p
.002 w
.4417 .5087 m .4334 .51508 L p
.43395 .50933 L 1 g
F P
s
P
p
.43413 .50747 m .43477 .50757 L .43395 .50933 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44219 .49177 L p
1 g
F P
s
P
p
.43485 .50826 m .44219 .49177 L .43894 .4987 L 1 g
F
P
p
.43839 .49999 m .43744 .5019 L .43395 .50933 L 1 g
F
P
p
.43477 .50757 m .4417 .5087 L .43395 .50933 L 1 g
F
P
p
.002 w
.44219 .49177 m .44166 .49233 L p
.43894 .4987 L 1 g
F P
s
P
p
.002 w
.44279 .49114 m .44339 .4905 L p
.44826 .48583 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44279 .49114 m .4722 .49692 L .43744 .5019 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45778 .4766 L p
1 g
F P
s
P
p
.44339 .4905 m .45778 .4766 L .44826 .48583 L 1 g
F
P
p
.44509 .48652 m .44686 .4872 L .44279 .49114 L 1 g
F
P
p
.44686 .4872 m .4722 .49692 L .44279 .49114 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45778 .4766 m .45826 .47608 L p
.46764 .47197 L 1 g
F P
s
P
p
.4726 .46954 m .50678 .49241 L .465 .47326 L 1 g
F
P
p
.46764 .47197 m .4706 .47067 L .465 .47326 L 1 g
F
P
p
.46764 .47197 m .465 .47326 L .45778 .4766 L 1 g
F
P
p
.002 w
.50678 .49241 m .4722 .49692 L .465 .47326 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47762 .46707 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.4726 .46954 m .47962 .46678 L .50678 .49241 L 1 g
F
P
p
.002 w
.47762 .46707 m .47786 .46667 L p
.48645 .4658 L 1 g
F P
s
P
p
.47962 .46678 m .5 .46384 L .50678 .49241 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46705 L p
1 g
F P
s
P
p
.51507 .46607 m .54119 .49579 L .50654 .46492 L 1 g
F
P
p
.5 .4634 m .52237 .46705 L .51267 .46575 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.50646 .45627 m .55105 .4608 L .54831 .47053 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56615 .50946 L p
1 g
F P
s
P
p
.002 w
.5712 .50657 m .56735 .51198 L p
.56615 .50946 L 1 g
F P
s
P
p
.002 w
.56347 .50379 m .56573 .5046 L p
.56615 .50946 L 1 g
F P
s
P
p
.002 w
.56573 .5046 m .5712 .50657 L p
.56615 .50946 L 1 g
F P
s
P
p
.002 w
.56615 .50946 m .56515 .50826 L p
.5668 .51894 L 1 g
F P
s
P
p
.002 w
.56648 .5132 m .5712 .50657 L p
.56914 .52202 L 1 g
F P
s
P
p
.56914 .52202 m .5676 .5335 L .56733 .52849 L 1 g
F
P
p
.56914 .52202 m .56733 .52849 L .56648 .5132 L 1 g
F
P
p
.002 w
.56733 .52849 m .56654 .52734 L p
.56446 .53873 L 1 g
F P
s
P
p
.5668 .51894 m .56648 .5132 L .56615 .50946 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56173 .54751 L p
1 g
F P
s
P
p
.002 w
.56585 .54663 m .5608 .55002 L p
.56173 .54751 L 1 g
F P
s
P
p
.002 w
.56286 .54444 m .56367 .54503 L p
.56173 .54751 L 1 g
F P
s
P
p
.002 w
.56367 .54503 m .56585 .54663 L p
.56173 .54751 L 1 g
F P
s
P
p
.002 w
.56173 .54751 m .56075 .54566 L p
.55525 .55564 L 1 g
F P
s
P
p
.002 w
.55863 .55149 m .56585 .54663 L p
.55331 .56001 L 1 g
F P
s
P
p
.55331 .56001 m .54095 .5732 L .5492 .56306 L 1 g
F
P
p
.55331 .56001 m .5492 .56306 L .55863 .55149 L 1 g
F
P
p
.002 w
.54097 .57324 m .54095 .5732 L p
.56585 .54663 L 1 g
F P
s
P
p
.002 w
.5492 .56306 m .54854 .56129 L p
.53841 .57095 L 1 g
F P
s
P
p
.002 w
.54097 .57324 m .52935 .57611 L p
.53174 .57474 L 1 g
F P
s
P
p
.002 w
.53921 .57049 m .54029 .57217 L p
.53174 .57474 L 1 g
F P
s
P
p
.002 w
.54029 .57217 m .54097 .57324 L p
.53174 .57474 L 1 g
F P
s
P
p
.002 w
.53174 .57474 m .53128 .57265 L p
.52075 .57805 L 1 g
F P
s
P
p
.53841 .57095 m .53921 .57049 L .5492 .56306 L 1 g
F
P
p
.002 w
.50647 .58175 m .47102 .58199 L .47127 .57993 L p
1 g
F P
s
P
p
.002 w
.51097 .58099 m .51079 .57862 L p
.4986 .58106 L 1 g
F P
s
P
p
.4986 .58106 m .5043 .58129 L .51097 .58099 L 1 g
F
P
p
.002 w
.50562 .58134 m .50647 .58175 L .5043 .58129 L p
1 g
F P
s
P
p
.5043 .58129 m .5052 .58133 L .50525 .58133 L 1 g
F
P
p
.5043 .58129 m .50525 .58133 L .51097 .58099 L 1 g
F
P
p
.5052 .58133 m .50569 .58134 L .51097 .58099 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46822 .57493 L p
1 g
F P
s
P
p
.002 w
.46822 .57493 m .46812 .57538 L p
.47021 .5757 L 1 g
F P
s
P
p
.48921 .57862 m .46822 .57493 L .47021 .5757 L 1 g
F
P
p
.45913 .56882 m .46268 .57127 L .46822 .57493 L 1 g
F
P
p
.002 w
.4381 .56279 m .47192 .57446 L p
.46796 .57482 L 1 g
F P
s
P
p
.002 w
.43668 .5777 m .43806 .56317 L p
.46796 .57482 L 1 g
F P
s
P
p
.002 w
.43806 .56317 m .4381 .56279 L p
.46796 .57482 L 1 g
F P
s
P
p
.48921 .57862 m .46812 .57538 L .46866 .57551 L 1 g
F
P
p
.002 w
.47127 .57993 m .4717 .57628 L p
.48906 .58066 L 1 g
F P
s
P
p
.48921 .57862 m .46811 .57543 L .4766 .57758 L 1 g
F
P
p
.47127 .57993 m .48906 .58066 L .48998 .5809 L 1 g
F
P
p
.002 w
.48905 .5807 m .48906 .58066 L p
.4761 .57754 L 1 g
F P
s
P
p
.002 w
.48906 .58066 m .48921 .57862 L p
.47699 .57762 L 1 g
F P
s
P
p
.47699 .57762 m .4761 .57754 L .48906 .58066 L 1 g
F
P
p
.002 w
.5043 .58129 m .50647 .58175 L p
.48998 .5809 L 1 g
F P
s
P
p
.48906 .58066 m .5043 .58129 L .48998 .5809 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.47192 .57446 m .5043 .58129 L p
.48906 .58066 L 1 g
F P
s
P
p
.002 w
.4717 .57628 m .47192 .57446 L p
.48906 .58066 L 1 g
F P
s
P
p
.002 w
.46812 .57538 m .46811 .57543 L p
.46866 .57551 L 1 g
F P
s
P
p
.002 w
.46811 .57543 m .4678 .57686 L p
.4766 .57758 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.47192 .57446 m .47661 .5674 L .50562 .58134 L p
1 g
F P
s
P
p
.002 w
.5043 .58129 m .47192 .57446 L p
.50562 .58134 L 1 g
F P
s
P
p
.50562 .58135 m .50597 .58135 L .51097 .58099 L 1 g
F
P
p
.50586 .58136 m .50618 .58135 L .51097 .58099 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.47661 .5674 m .48461 .5616 L .50604 .58135 L p
1 g
F P
s
P
p
.002 w
.50604 .58135 m .50647 .58175 L .50562 .58134 L p
1 g
F P
s
P
p
.002 w
.50562 .58134 m .47661 .5674 L p
.50604 .58135 L 1 g
F P
s
P
p
.5052 .58133 m .50562 .58135 L .50569 .58134 L 1 g
F
P
p
.50562 .58135 m .50586 .58136 L .50597 .58135 L 1 g
F
P
p
.50604 .58136 m .50639 .58135 L .51097 .58099 L 1 g
F
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48461 .5616 m .49505 .55774 L .50628 .58135 L p
1 g
F P
s
P
p
.002 w
.50628 .58135 m .50647 .58175 L .50604 .58135 L p
1 g
F P
s
P
p
.002 w
.50604 .58135 m .48461 .5616 L p
.50628 .58135 L 1 g
F P
s
P
p
.50617 .58137 m .50666 .58134 L .51097 .58099 L 1 g
F
P
p
.002 w
.49505 .55774 m .50678 .55625 L .50647 .58135 L p
1 g
F P
s
P
p
.002 w
.50647 .58135 m .50647 .58175 L .50628 .58135 L p
1 g
F P
s
P
p
.002 w
.50628 .58135 m .49505 .55774 L p
.50647 .58135 L 1 g
F P
s
P
p
.50586 .58136 m .50604 .58136 L .50618 .58135 L 1 g
F
P
p
.50604 .58136 m .50617 .58137 L .50639 .58135 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.50678 .55625 m .51846 .55733 L .50667 .58134 L p
1 g
F P
s
P
p
.002 w
.50667 .58134 m .50647 .58175 L .50647 .58135 L p
1 g
F P
s
P
p
.002 w
.50647 .58135 m .50678 .55625 L p
.50667 .58134 L 1 g
F P
s
P
p
.50628 .58137 m .50659 .58135 L .51097 .58099 L 1 g
F
P
p
.002 w
.50692 .58133 m .50647 .58175 L .50667 .58134 L p
1 g
F P
s
P
p
.49033 .58271 m .50878 .58118 L .51097 .58099 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51846 .55733 m .52876 .56083 L .50692 .58133 L p
1 g
F P
s
P
p
.002 w
.50667 .58134 m .51846 .55733 L p
.50692 .58133 L 1 g
F P
s
P
p
.50617 .58137 m .50628 .58137 L .50666 .58134 L 1 g
F
P
p
.50628 .58137 m .50631 .58138 L .50659 .58135 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58099 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52876 .56083 m .53654 .56634 L .50735 .5813 L p
1 g
F P
s
P
p
.002 w
.50735 .5813 m .50647 .58175 L .50692 .58133 L p
1 g
F P
s
P
p
.002 w
.50692 .58133 m .52876 .56083 L p
.50735 .5813 L 1 g
F P
s
P
p
.4986 .58106 m .49033 .58271 L .50631 .58138 L 1 g
F
P
p
.53128 .57265 m .51097 .58099 L .5116 .5808 L 1 g
F
P
p
.002 w
.52935 .57611 m .51755 .57902 L p
.53174 .57474 L 1 g
F P
s
P
p
.002 w
.51755 .57902 m .52935 .57611 L p
.50863 .58169 L 1 g
F P
s
P
p
.002 w
.52935 .57611 m .54097 .57324 L p
.52878 .57642 L 1 g
F P
s
P
p
.52878 .57642 m .50863 .58169 L .52935 .57611 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53174 .57477 L p
1 g
F P
s
P
p
.002 w
.54097 .57324 m .54141 .57831 L p
.51148 .58094 L 1 g
F P
s
P
p
.002 w
.53174 .57477 m .5322 .57686 L p
.53816 .57118 L 1 g
F P
s
P
p
.54854 .56129 m .53174 .57477 L .53816 .57118 L 1 g
F
P
p
.52075 .57805 m .51097 .58106 L .51942 .57873 L 1 g
F
P
p
.53128 .57265 m .51151 .58083 L .52075 .57805 L 1 g
F
P
p
.51151 .58083 m .51097 .58106 L .52075 .57805 L 1 g
F
P
p
.53921 .57049 m .53174 .57474 L .50878 .58118 L 1 g
F
P
p
.002 w
.51755 .57902 m .50878 .58118 L p
.53174 .57474 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53654 .56634 m .53921 .57049 L p
.50792 .58125 L 1 g
F P
s
P
p
.002 w
.50647 .58175 m .50735 .5813 L p
.50792 .58125 L 1 g
F P
s
P
p
.002 w
.50735 .5813 m .53654 .56634 L p
.50792 .58125 L 1 g
F P
s
P
p
.002 w
.50878 .58118 m .50647 .58175 L p
.50792 .58125 L 1 g
F P
s
P
p
.002 w
.50863 .58169 m .50647 .58175 L .50878 .58118 L p
1 g
F P
s
P
p
.002 w
.50878 .58118 m .51755 .57902 L p
.51097 .58099 L 1 g
F P
s
P
p
.51097 .58099 m .50863 .58169 L .50878 .58118 L 1 g
F
P
p
.002 w
.53846 .58801 m .5319 .5943 L .50718 .5821 L p
1 g
F P
s
P
p
.002 w
.50718 .5821 m .50647 .58175 L .50763 .58198 L p
1 g
F P
s
P
p
.002 w
.50763 .58198 m .53846 .58801 L p
.50718 .5821 L 1 g
F P
s
P
p
.002 w
.48029 .59524 m .47393 .58917 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.54162 .58073 m .53846 .58801 L .50647 .58175 L closepath p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51097 .581 L p
1 g
F P
s
P
p
.002 w
.51097 .581 m .51097 .58099 L p
.5096 .58111 L 1 g
F P
s
P
p
.5096 .58111 m .48889 .583 L .51097 .581 L 1 g
F
P
p
.49033 .58271 m .48949 .58288 L .50878 .58118 L 1 g
F
P
p
.53921 .57049 m .50878 .58118 L .50792 .58125 L 1 g
F
P
p
.002 w
.54141 .57831 m .54162 .58073 L p
.51148 .58094 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53174 .57474 L p
1 g
F P
s
P
p
.52075 .57805 m .51111 .583 L .53174 .57474 L 1 g
F
P
p
.53841 .57095 m .53774 .57158 L .53921 .57049 L 1 g
F
P
p
.55525 .55564 m .55863 .55149 L .56173 .54751 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54933 .56341 L p
1 g
F P
s
P
p
.56075 .54566 m .54933 .56341 L .5549 .55626 L 1 g
F
P
p
.56654 .52734 m .56173 .54751 L .56239 .54573 L 1 g
F
P
p
.56654 .52734 m .56191 .54785 L .56446 .53873 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56286 .54444 m .56173 .54751 L .53654 .56634 L 1 g
F
P
p
.002 w
.5608 .55002 m .55863 .55149 L p
.56173 .54751 L 1 g
F P
s
P
p
.002 w
.55863 .55149 m .53654 .56634 L p
.56173 .54751 L 1 g
F P
s
P
p
.002 w
.56585 .54663 m .57429 .56041 L .54097 .57324 L p
1 g
F P
s
P
p
.002 w
.54933 .56341 m .54998 .56518 L p
.5549 .55626 L 1 g
F P
s
P
p
.002 w
.54095 .5732 m .53654 .56634 L .55863 .55149 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5492 .56306 L p
1 g
F P
s
P
p
.53774 .57158 m .5322 .57686 L .5492 .56306 L 1 g
F
P
p
.55525 .55564 m .5549 .55626 L .55863 .55149 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56173 .54751 L p
1 g
F P
s
P
p
.5549 .55626 m .54998 .56518 L .56173 .54751 L 1 g
F
P
p
.002 w
.56173 .54751 m .56191 .54785 L p
.56239 .54573 L 1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55061 .53549 m .56286 .54444 L p
.53654 .56634 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56787 .52928 L p
1 g
F P
s
P
p
.56515 .50826 m .56787 .52928 L .5672 .52159 L 1 g
F
P
p
.55661 .4905 m .56615 .50946 L .56347 .50379 L 1 g
F
P
p
.002 w
.54785 .47215 m .55105 .4608 L p
.56082 .49464 L 1 g
F P
s
P
p
.56082 .49464 m .56347 .50379 L .55724 .49117 L 1 g
F
P
p
.56082 .49464 m .55724 .49117 L .54785 .47215 L 1 g
F
P
p
.55661 .4905 m .56347 .50379 L .56195 .50072 L 1 g
F
P
p
.002 w
.5712 .50657 m .56347 .50379 L p
.55105 .4608 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55724 .49117 L p
1 g
F P
s
P
p
.54174 .47608 m .55724 .49117 L .55039 .48454 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56347 .50379 m .54119 .49579 L .54565 .47995 L p
1 g
F P
s
P
p
.54174 .47608 m .55039 .48454 L .54938 .48356 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55724 .49117 m .56347 .50379 L .54565 .47995 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54565 .47995 m .54119 .49579 L p
.53524 .47326 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54226 .47665 L p
1 g
F P
s
P
p
.52214 .46667 m .54226 .47665 L .52978 .47062 L 1 g
F
P
p
.53401 .46861 m .54226 .47665 L .53524 .47326 L 1 g
F
P
p
.54226 .47665 m .54565 .47995 L .53524 .47326 L 1 g
F
P
p
.51507 .46607 m .52237 .46705 L .54119 .49579 L 1 g
F
P
p
.002 w
.52237 .46705 m .52214 .46667 L p
.52978 .47062 L 1 g
F P
s
P
p
.52237 .46705 m .53401 .46861 L .53524 .47326 L 1 g
F
P
p
.52237 .46705 m .53524 .47326 L .54119 .49579 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46705 L p
1 g
F P
s
P
p
.52978 .47062 m .54302 .47747 L .52237 .46705 L 1 g
F
P
p
.002 w
.54226 .47665 m .54302 .47747 L p
.52978 .47062 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54565 .47995 m .54785 .47215 L p
.55724 .49117 L 1 g
F P
s
P
p
.54938 .48356 m .55807 .49205 L .55385 .48794 L 1 g
F
P
p
.55039 .48454 m .55807 .49205 L .54938 .48356 L 1 g
F
P
p
.002 w
.55724 .49117 m .55807 .49205 L p
.55039 .48454 L 1 g
F P
s
P
p
.56195 .50072 m .56347 .50379 L .56258 .50193 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56347 .50379 m .56615 .50946 L .55061 .53549 L 1 g
F
P
p
.002 w
.56735 .51198 m .56648 .5132 L p
.56615 .50946 L 1 g
F P
s
P
p
.002 w
.56648 .5132 m .55061 .53549 L p
.56615 .50946 L 1 g
F P
s
P
p
.002 w
.5712 .50657 m .59331 .52326 L .56822 .54461 L p
1 g
F P
s
P
p
.002 w
.56822 .54461 m .56585 .54663 L p
.5676 .5335 L 1 g
F P
s
P
p
.5712 .50657 m .56822 .54461 L .5676 .5335 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56628 .5096 L p
1 g
F P
s
P
p
.002 w
.56628 .5096 m .56615 .50946 L p
.56638 .51142 L 1 g
F P
s
P
p
.56638 .51142 m .56854 .53025 L .56628 .5096 L 1 g
F
P
p
.002 w
.56787 .52928 m .56854 .53025 L p
.5672 .52159 L 1 g
F P
s
P
p
.002 w
.55061 .53549 m .56648 .5132 L p
.56611 .53283 L 1 g
F P
s
P
p
.002 w
.56585 .54663 m .56286 .54444 L p
.56611 .53283 L 1 g
F P
s
P
p
.002 w
.56286 .54444 m .55061 .53549 L p
.56611 .53283 L 1 g
F P
s
P
p
.002 w
.56191 .54785 m .56257 .5491 L p
.56446 .53873 L 1 g
F P
s
P
p
.5676 .5335 m .56585 .54663 L .56648 .5132 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56733 .52849 L p
1 g
F P
s
P
p
.56446 .53873 m .56257 .5491 L .56733 .52849 L 1 g
F
P
p
.5668 .51894 m .5672 .52159 L .56648 .5132 L 1 g
F
P
p
.5672 .52159 m .56854 .53025 L .56615 .50946 L 1 g
F
P
p
.002 w
.56615 .50946 m .56713 .51061 L p
.56258 .50193 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54119 .49579 m .56347 .50379 L p
.55061 .53549 L 1 g
F P
s
P
p
.002 w
.55807 .49205 m .55834 .49233 L p
.55385 .48794 L 1 g
F P
s
P
p
.002 w
.54831 .47053 m .54565 .47995 L p
.53401 .46861 L 1 g
F P
s
P
p
.50646 .45627 m .54831 .47053 L .51507 .46607 L 1 g
F
P
p
.51109 .46553 m .5227 .4676 L .51649 .46657 L 1 g
F
P
p
.5 .4634 m .51267 .46575 L .51109 .46553 L 1 g
F
P
p
.51267 .46575 m .5227 .4676 L .51109 .46553 L 1 g
F
P
p
.002 w
.52237 .46705 m .5227 .4676 L p
.51267 .46575 L 1 g
F P
s
P
p
.002 w
.54119 .49579 m .50678 .49241 L .50654 .46492 L p
1 g
F P
s
P
p
.002 w
.50654 .46492 m .50678 .49241 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46384 L p
1 g
F P
s
P
p
.002 w
.5 .46384 m .5 .4634 L p
.51649 .46657 L 1 g
F P
s
P
p
.51649 .46657 m .52282 .46778 L .5 .46384 L 1 g
F
P
p
.002 w
.50646 .45627 m .50652 .4629 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46384 L p
1 g
F P
s
P
p
.002 w
.5 .46384 m .5 .46442 L p
.48645 .4658 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46384 L .48645 .4658 L 1 g
F
P
p
.47962 .46678 m .49096 .46234 L .5 .46384 L 1 g
F
P
p
.49096 .46234 m .50646 .45627 L .5 .46384 L 1 g
F
P
p
.002 w
.50654 .46492 m .50646 .45627 L p
.51507 .46607 L 1 g
F P
s
P
p
.002 w
.50652 .4629 m .50654 .46492 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.5227 .4676 m .52282 .46778 L p
.51649 .46657 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.49713 .45751 m .50646 .45627 L p
.4726 .46954 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47762 .46707 L p
1 g
F P
s
P
p
.48645 .4658 m .5 .46442 L .47762 .46707 L 1 g
F
P
p
.002 w
.47762 .46707 m .47718 .46778 L p
.46764 .47197 L 1 g
F P
s
P
p
.45826 .47608 m .47762 .46707 L .46764 .47197 L 1 g
F
P
p
.002 w
.46164 .46221 m .49713 .45751 L p
.4726 .46954 L 1 g
F P
s
P
p
.002 w
.465 .47326 m .46164 .46221 L p
.4726 .46954 L 1 g
F P
s
P
p
.002 w
.4223 .47778 m .46164 .46221 L .465 .47326 L p
1 g
F P
s
P
p
.002 w
.465 .47326 m .4722 .49692 L p
.44032 .48469 L 1 g
F P
s
P
p
.4223 .47778 m .465 .47326 L .44032 .48469 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45778 .4766 L p
1 g
F P
s
P
p
.4706 .47067 m .47718 .46778 L .45778 .4766 L 1 g
F
P
p
.002 w
.45778 .4766 m .45698 .47747 L p
.44826 .48583 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44279 .49114 L p
1 g
F P
s
P
p
.44826 .48583 m .45698 .47747 L .44279 .49114 L 1 g
F
P
p
.43839 .49999 m .43894 .4987 L .43744 .5019 L 1 g
F
P
p
.002 w
.4722 .49692 m .4417 .5087 L .43744 .5019 L p
1 g
F P
s
P
p
.002 w
.3932 .50078 m .4223 .47778 L .4417 .5087 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43894 .4987 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43202 .52943 L p
1 g
F P
s
P
p
.002 w
.43202 .52943 m .43263 .52855 L p
.43272 .52219 L 1 g
F P
s
P
p
.43272 .52219 m .43287 .51061 L .43202 .52943 L 1 g
F
P
p
.43317 .51904 m .43287 .51061 L .43263 .52855 L 1 g
F
P
p
.43533 .5379 m .43504 .53733 L .43586 .53974 L 1 g
F
P
p
.43533 .5379 m .43586 .53974 L .43841 .54724 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46274 .53699 m .44705 .54868 L .43586 .53974 L p
1 g
F P
s
P
p
.43295 .52966 m .46274 .53699 L .43586 .53974 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.40621 .54717 m .4189 .5262 L .42979 .53489 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43841 .54724 L p
1 g
F P
s
P
p
.45146 .56129 m .43841 .54724 L .44321 .55412 L 1 g
F
P
p
.002 w
.42979 .53489 m .44705 .54868 L p
.43921 .54839 L 1 g
F P
s
P
p
.40621 .54717 m .42979 .53489 L .43921 .54839 L 1 g
F
P
p
.43879 .54837 m .43921 .54839 L .43913 .54937 L 1 g
F
P
p
.43879 .54837 m .43913 .54937 L .4381 .56279 L 1 g
F
P
p
.002 w
.44341 .55441 m .4381 .56279 L p
.43921 .54839 L 1 g
F P
s
P
p
.002 w
.43841 .54724 m .43743 .5491 L p
.44321 .55412 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43841 .54724 L p
1 g
F P
s
P
p
.43504 .53733 m .43146 .53025 L .43841 .54724 L 1 g
F
P
p
.002 w
.4508 .56306 m .45146 .56129 L p
.44303 .55397 L 1 g
F P
s
P
p
.002 w
.44705 .54868 m .44341 .55441 L p
.43921 .54839 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4508 .56306 L p
1 g
F P
s
P
p
.46872 .57265 m .4508 .56306 L .45913 .56882 L 1 g
F
P
p
.002 w
.44705 .54868 m .47661 .5674 L p
.45299 .56457 L 1 g
F P
s
P
p
.002 w
.4381 .56279 m .44185 .55688 L p
.45299 .56457 L 1 g
F P
s
P
p
.002 w
.44185 .55688 m .44705 .54868 L p
.45299 .56457 L 1 g
F P
s
P
p
.002 w
.4508 .56306 m .45002 .56518 L p
.45913 .56882 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45033 .56433 L p
1 g
F P
s
P
p
.002 w
.45033 .56433 m .4508 .56306 L p
.44582 .55786 L 1 g
F P
s
P
p
.44582 .55786 m .43743 .5491 L .45033 .56433 L 1 g
F
P
p
.44303 .55397 m .43743 .5491 L .4508 .56306 L 1 g
F
P
p
.45913 .56882 m .45868 .56864 L .46268 .57127 L 1 g
F
P
p
.002 w
.47661 .5674 m .47192 .57446 L .46268 .57127 L p
1 g
F P
s
P
p
.45299 .56457 m .47661 .5674 L .46268 .57127 L 1 g
F
P
p
.002 w
.47192 .57446 m .4717 .57628 L p
.46796 .57482 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46822 .57493 L p
1 g
F P
s
P
p
.45868 .56864 m .45002 .56518 L .46822 .57493 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48889 .58298 L p
1 g
F P
s
P
p
.002 w
.48889 .58298 m .48905 .5807 L p
.47785 .57868 L 1 g
F P
s
P
p
.47785 .57868 m .4678 .57686 L .48889 .58298 L 1 g
F
P
p
.4761 .57754 m .4678 .57686 L .48905 .5807 L 1 g
F
P
p
.48949 .58288 m .48889 .583 L .51097 .58099 L 1 g
F
P
p
.002 w
.51097 .58099 m .51097 .58106 L p
.5116 .5808 L 1 g
F P
s
P
p
.002 w
.51097 .58106 m .51111 .583 L p
.51942 .57873 L 1 g
F P
s
P
p
.002 w
.43421 .32568 m .37419 .35155 L .37145 .32515 L p
1 g
F P
s
P
p
.002 w
.37145 .32515 m .43223 .29854 L .43421 .32568 L p
1 g
F P
s
P
p
.002 w
.3932 .50078 m .37738 .52816 L .35258 .50651 L p
1 g
F P
s
P
p
.002 w
.35258 .50651 m .37089 .47337 L .3932 .50078 L p
1 g
F P
s
P
p
.002 w
.57203 .29676 m .50233 .28854 L .50123 .26623 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.53846 .58801 m .54162 .58073 L .57519 .57524 L p
1 g
F P
s
P
p
.002 w
.57429 .56041 m .57519 .57524 L .54162 .58073 L p
1 g
F P
s
P
p
.002 w
.57519 .57524 m .57429 .56041 L .60522 .54374 L p
1 g
F P
s
P
p
.002 w
.6179 .49711 m .63271 .52386 L .60522 .54374 L p
1 g
F P
s
P
p
.002 w
.63271 .52386 m .6179 .49711 L .63873 .46913 L p
1 g
F P
s
P
p
.002 w
.39132 .41272 m .35274 .445 L .33931 .4167 L p
1 g
F P
s
P
p
.002 w
.33931 .4167 m .38085 .38107 L .39132 .41272 L p
1 g
F P
s
P
p
.002 w
.4189 .5262 m .40621 .54717 L .37738 .52816 L p
1 g
F P
s
P
p
.002 w
.37738 .52816 m .3932 .50078 L .4189 .5262 L p
1 g
F P
s
P
p
.002 w
.54162 .58073 m .54097 .57324 L .57429 .56041 L p
1 g
F P
s
P
p
.002 w
.61784 .40938 m .65513 .44036 L .63873 .46913 L p
1 g
F P
s
P
p
.002 w
.65513 .44036 m .61784 .40938 L .62646 .37759 L p
1 g
F P
s
P
p
.002 w
.57216 .32386 m .63111 .34805 L .62646 .37759 L p
1 g
F P
s
P
p
.002 w
.63111 .34805 m .57216 .32386 L .57203 .29676 L p
1 g
F P
s
P
p
.002 w
.59331 .52326 m .60522 .54374 L .57429 .56041 L p
1 g
F P
s
P
p
.002 w
.60522 .54374 m .59331 .52326 L .6179 .49711 L p
1 g
F P
s
P
p
.002 w
.50233 .28854 m .57203 .29676 L .57216 .32386 L p
1 g
F P
s
P
p
.002 w
.57429 .56041 m .56585 .54663 L .59331 .52326 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.43828 .35676 m .38085 .38107 L .37419 .35155 L p
1 g
F P
s
P
p
.002 w
.37419 .35155 m .43421 .32568 L .43828 .35676 L p
1 g
F P
s
P
p
.002 w
.50339 .31593 m .43421 .32568 L .43223 .29854 L p
1 g
F P
s
P
p
.002 w
.43223 .29854 m .50233 .28854 L .50339 .31593 L p
1 g
F P
s
P
p
.002 w
.40529 .44537 m .37089 .47337 L .35274 .445 L p
1 g
F P
s
P
p
.002 w
.35274 .445 m .39132 .41272 L .40529 .44537 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60546 .44229 m .63873 .46913 L .6179 .49711 L p
1 g
F P
s
P
p
.002 w
.63873 .46913 m .60546 .44229 L .61784 .40938 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.57216 .32386 m .50339 .31593 L .50233 .28854 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53654 .56634 m .52876 .56083 L .55061 .53549 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48461 .5616 m .47661 .5674 L .44705 .54868 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57007 .35495 m .62646 .37759 L .61784 .40938 L p
1 g
F P
s
P
p
.002 w
.62646 .37759 m .57007 .35495 L .57216 .32386 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.4223 .47778 m .3932 .50078 L .37089 .47337 L p
1 g
F P
s
P
p
.002 w
.37089 .47337 m .40529 .44537 L .4223 .47778 L p
1 g
F P
s
P
p
.002 w
.58972 .47511 m .6179 .49711 L .59331 .52326 L p
1 g
F P
s
P
p
.002 w
.6179 .49711 m .58972 .47511 L .60546 .44229 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.52876 .56083 m .51846 .55733 L .53018 .52836 L p
1 g
F P
s
P
p
.002 w
.53018 .52836 m .55061 .53549 L .52876 .56083 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.49505 .55774 m .48461 .5616 L .46274 .53699 L p
1 g
F P
s
P
p
.002 w
.44705 .54868 m .46274 .53699 L .48461 .5616 L p
1 g
F P
s
P
p
.002 w
.59331 .52326 m .5712 .50657 L .58972 .47511 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44435 .39074 m .39132 .41272 L .38085 .38107 L p
1 g
F P
s
P
p
.002 w
.38085 .38107 m .43828 .35676 L .44435 .39074 L p
1 g
F P
s
P
p
.002 w
.50339 .31593 m .57216 .32386 L .57007 .35495 L p
1 g
F P
s
P
p
.002 w
.51846 .55733 m .50678 .55625 L .50689 .52615 L p
1 g
F P
s
P
p
.002 w
.50689 .52615 m .53018 .52836 L .51846 .55733 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.50678 .55625 m .49505 .55774 L .48348 .52915 L p
1 g
F P
s
P
p
.002 w
.46274 .53699 m .48348 .52915 L .49505 .55774 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.004 w
.50747 .60524 m
.50751 .60615 L
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48348 .52915 m .50689 .52615 L .50678 .55625 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.50437 .34757 m .43828 .35676 L .43421 .32568 L p
1 g
F P
s
P
p
.002 w
.43421 .32568 m .50339 .31593 L .50437 .34757 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.004 w
.50767 .60976 m
.50771 .61068 L
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.56576 .38899 m .61784 .40938 L .60546 .44229 L p
1 g
F P
s
P
p
.002 w
.61784 .40938 m .56576 .38899 L .57007 .35495 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55061 .53549 m .53018 .52836 L .54119 .49579 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.004 w
.50786 .61431 m
.5079 .61523 L
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57007 .35495 m .50437 .34757 L .50339 .31593 L p
1 g
F P
s
P
p
.002 w
.48348 .52915 m .46274 .53699 L .4417 .5087 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45224 .42634 m .40529 .44537 L .39132 .41272 L p
1 g
F P
s
P
p
.002 w
.39132 .41272 m .44435 .39074 L .45224 .42634 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.004 w
.50806 .61888 m
.5081 .61981 L
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.55934 .42474 m .60546 .44229 L .58972 .47511 L p
1 g
F P
s
P
p
.002 w
.60546 .44229 m .55934 .42474 L .56576 .38899 L p
1 g
F P
s
P
p
.002 w
.55105 .4608 m .58972 .47511 L .5712 .50657 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50437 .34757 m .57007 .35495 L .56576 .38899 L p
1 g
F P
s
P
p
.002 w
.53018 .52836 m .50689 .52615 L .50678 .49241 L p
1 g
F P
s
P
p
.002 w
.50678 .49241 m .54119 .49579 L .53018 .52836 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.004 w
.50825 .62348 m
.50829 .62442 L
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.58972 .47511 m .55105 .4608 L .55934 .42474 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50689 .52615 m .48348 .52915 L .4722 .49692 L p
1 g
F P
s
P
p
.002 w
.4417 .5087 m .4722 .49692 L .48348 .52915 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50523 .3824 m .44435 .39074 L .43828 .35676 L p
1 g
F P
s
P
p
.002 w
.43828 .35676 m .50437 .34757 L .50523 .3824 L p
1 g
F P
s
P
p
.002 w
.4722 .49692 m .50678 .49241 L .50689 .52615 L p
1 g
F P
s
P
p
.002 w
.46164 .46221 m .4223 .47778 L .40529 .44537 L p
1 g
F P
s
P
p
.002 w
.40529 .44537 m .45224 .42634 L .46164 .46221 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.004 w
.50845 .62811 m
.50849 .62905 L
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.50865 .63276 m
.5091 .64318 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56576 .38899 m .50523 .3824 L .50437 .34757 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.50523 .3824 m .56576 .38899 L .55934 .42474 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50594 .41911 m .45224 .42634 L .44435 .39074 L p
1 g
F P
s
P
p
.002 w
.44435 .39074 m .50523 .3824 L .50594 .41911 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.50594 .41911 m .55934 .42474 L .55105 .4608 L p
1 g
F P
s
P
p
.002 w
.55934 .42474 m .50594 .41911 L .50523 .3824 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55105 .4608 m .50646 .45627 L .50594 .41911 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50646 .45627 m .46164 .46221 L .45224 .42634 L p
1 g
F P
s
P
p
.002 w
.45224 .42634 m .50594 .41911 L .50646 .45627 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .75147 .59062 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .51023 .66975 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0184211)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0184211)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.43972 .45346 m .48522 .46685 L .48986 .43884 L p
1 g
F P
s
P
p
.002 w
.48986 .43884 m .45003 .42698 L .43972 .45346 L p
1 g
F P
s
P
p
.002 w
.53167 .44102 m .48986 .43884 L .48522 .46685 L p
1 g
F P
s
P
p
.002 w
.45003 .42698 m .48986 .43884 L .49474 .41069 L p
1 g
F P
s
P
p
.002 w
.48986 .43884 m .53167 .44102 L .52965 .41247 L p
1 g
F P
s
P
p
.002 w
.52965 .41247 m .49474 .41069 L .48986 .43884 L p
1 g
F P
s
P
p
.002 w
.49474 .41069 m .46151 .40069 L .45003 .42698 L p
1 g
F P
s
P
p
.002 w
.46151 .40069 m .49474 .41069 L .49976 .3829 L p
1 g
F P
s
P
p
.002 w
.49474 .41069 m .52965 .41247 L .52691 .38425 L p
1 g
F P
s
P
p
.002 w
.52691 .38425 m .49976 .3829 L .49474 .41069 L p
1 g
F P
s
P
p
.002 w
.48522 .46685 m .53292 .4694 L .53167 .44102 L p
1 g
F P
s
P
p
.002 w
.5717 .43327 m .53167 .44102 L .53292 .4694 L p
1 g
F P
s
P
p
.002 w
.53167 .44102 m .5717 .43327 L .56302 .40581 L p
1 g
F P
s
P
p
.002 w
.56302 .40581 m .52965 .41247 L .53167 .44102 L p
1 g
F P
s
P
p
.002 w
.52965 .41247 m .56302 .40581 L .5528 .37893 L p
1 g
F P
s
P
p
.002 w
.5528 .37893 m .52691 .38425 L .52965 .41247 L p
1 g
F P
s
P
p
.002 w
.43078 .47964 m .48089 .49422 L .48522 .46685 L p
1 g
F P
s
P
p
.002 w
.48522 .46685 m .43972 .45346 L .43078 .47964 L p
1 g
F P
s
P
p
.002 w
.53292 .4694 m .48522 .46685 L .48089 .49422 L p
1 g
F P
s
P
p
.002 w
.49976 .3829 m .47396 .37505 L .46151 .40069 L p
1 g
F P
s
P
p
.002 w
.47396 .37505 m .49976 .3829 L .50484 .35599 L p
1 g
F P
s
P
p
.002 w
.49976 .3829 m .52691 .38425 L .52349 .35689 L p
1 g
F P
s
P
p
.002 w
.52349 .35689 m .50484 .35599 L .49976 .3829 L p
1 g
F P
s
P
p
.002 w
.41583 .40639 m .45003 .42698 L .46151 .40069 L p
1 g
F P
s
P
p
.002 w
.46151 .40069 m .43312 .3833 L .41583 .40639 L p
1 g
F P
s
P
p
.002 w
.43312 .3833 m .46151 .40069 L .47396 .37505 L p
1 g
F P
s
P
p
.002 w
.40048 .43024 m .43972 .45346 L .45003 .42698 L p
1 g
F P
s
P
p
.002 w
.45003 .42698 m .41583 .40639 L .40048 .43024 L p
1 g
F P
s
P
p
.002 w
.48089 .49422 m .53338 .49708 L .53292 .4694 L p
1 g
F P
s
P
p
.002 w
.57867 .46081 m .53292 .4694 L .53338 .49708 L p
1 g
F P
s
P
p
.002 w
.53292 .4694 m .57867 .46081 L .5717 .43327 L p
1 g
F P
s
P
p
.002 w
.52691 .38425 m .5528 .37893 L .54122 .35315 L p
1 g
F P
s
P
p
.002 w
.54122 .35315 m .52349 .35689 L .52691 .38425 L p
1 g
F P
s
P
p
.002 w
.47396 .37505 m .45203 .36138 L .43312 .3833 L p
1 g
F P
s
P
p
.002 w
.45203 .36138 m .47396 .37505 L .48715 .35054 L p
1 g
F P
s
P
p
.002 w
.50484 .35599 m .48715 .35054 L .47396 .37505 L p
1 g
F P
s
P
p
.002 w
.38742 .4544 m .43078 .47964 L .43972 .45346 L p
1 g
F P
s
P
p
.002 w
.43972 .45346 m .40048 .43024 L .38742 .4544 L p
1 g
F P
s
P
p
.002 w
.42342 .50501 m .47698 .52042 L .48089 .49422 L p
1 g
F P
s
P
p
.002 w
.48089 .49422 m .43078 .47964 L .42342 .50501 L p
1 g
F P
s
P
p
.002 w
.53338 .49708 m .48089 .49422 L .47698 .52042 L p
1 g
F P
s
P
p
.002 w
.59163 .39118 m .56302 .40581 L .5717 .43327 L p
1 g
F P
s
P
p
.002 w
.56302 .40581 m .59163 .39118 L .57486 .36737 L p
1 g
F P
s
P
p
.002 w
.57486 .36737 m .5528 .37893 L .56302 .40581 L p
1 g
F P
s
P
p
.002 w
.6062 .41607 m .5717 .43327 L .57867 .46081 L p
1 g
F P
s
P
p
.002 w
.5717 .43327 m .6062 .41607 L .59163 .39118 L p
1 g
F P
s
P
p
.002 w
.5528 .37893 m .57486 .36737 L .55623 .34509 L p
1 g
F P
s
P
p
.002 w
.55623 .34509 m .54122 .35315 L .5528 .37893 L p
1 g
F P
s
P
p
.002 w
.47698 .52042 m .53303 .52355 L .53338 .49708 L p
1 g
F P
s
P
p
.002 w
.58378 .4879 m .53338 .49708 L .53303 .52355 L p
1 g
F P
s
P
p
.002 w
.53338 .49708 m .58378 .4879 L .57867 .46081 L p
1 g
F P
s
P
p
.002 w
.48715 .35054 m .50484 .35599 L .50989 .33046 L p
1 g
F P
s
P
p
.002 w
.50484 .35599 m .52349 .35689 L .51944 .33091 L p
1 g
F P
s
P
p
.002 w
.51944 .33091 m .50989 .33046 L .50484 .35599 L p
1 g
F P
s
P
p
.002 w
.52349 .35689 m .54122 .35315 L .52848 .32895 L p
1 g
F P
s
P
p
.002 w
.52848 .32895 m .51944 .33091 L .52349 .35689 L p
1 g
F P
s
P
p
.002 w
.48715 .35054 m .4722 .34107 L .45203 .36138 L p
1 g
F P
s
P
p
.002 w
.4722 .34107 m .48715 .35054 L .50085 .32765 L p
1 g
F P
s
P
p
.002 w
.50989 .33046 m .50085 .32765 L .48715 .35054 L p
1 g
F P
s
P
p
.002 w
.39064 .37873 m .41583 .40639 L .43312 .3833 L p
1 g
F P
s
P
p
.002 w
.43312 .3833 m .41242 .36001 L .39064 .37873 L p
1 g
F P
s
P
p
.002 w
.41242 .36001 m .43312 .3833 L .45203 .36138 L p
1 g
F P
s
P
p
.002 w
.45203 .36138 m .43621 .34315 L .41242 .36001 L p
1 g
F P
s
P
p
.002 w
.43621 .34315 m .45203 .36138 L .4722 .34107 L p
1 g
F P
s
P
p
.002 w
.61828 .44155 m .57867 .46081 L .58378 .4879 L p
1 g
F P
s
P
p
.002 w
.57867 .46081 m .61828 .44155 L .6062 .41607 L p
1 g
F P
s
P
p
.002 w
.37694 .47838 m .42342 .50501 L .43078 .47964 L p
1 g
F P
s
P
p
.002 w
.43078 .47964 m .38742 .4544 L .37694 .47838 L p
1 g
F P
s
P
p
.002 w
.37135 .39897 m .40048 .43024 L .41583 .40639 L p
1 g
F P
s
P
p
.002 w
.41583 .40639 m .39064 .37873 L .37135 .39897 L p
1 g
F P
s
P
p
.002 w
.54122 .35315 m .55623 .34509 L .53609 .32477 L p
1 g
F P
s
P
p
.002 w
.53609 .32477 m .52848 .32895 L .54122 .35315 L p
1 g
F P
s
P
p
.002 w
.41781 .52906 m .47355 .54494 L .47698 .52042 L p
1 g
F P
s
P
p
.002 w
.47698 .52042 m .42342 .50501 L .41781 .52906 L p
1 g
F P
s
P
p
.002 w
.53303 .52355 m .47698 .52042 L .47355 .54494 L p
1 g
F P
s
P
p
.002 w
.4722 .34107 m .46154 .32849 L .43621 .34315 L p
1 g
F P
s
P
p
.002 w
.46154 .32849 m .4722 .34107 L .49325 .32276 L p
1 g
F P
s
P
p
.002 w
.50085 .32765 m .49325 .32276 L .4722 .34107 L p
1 g
F P
s
P
p
.002 w
.59077 .35057 m .57486 .36737 L .59163 .39118 L p
1 g
F P
s
P
p
.002 w
.57486 .36737 m .59077 .35057 L .56692 .33347 L p
1 g
F P
s
P
p
.002 w
.56692 .33347 m .55623 .34509 L .57486 .36737 L p
1 g
F P
s
P
p
.002 w
.47355 .54494 m .53185 .54825 L .53303 .52355 L p
1 g
F P
s
P
p
.002 w
.58689 .51403 m .53303 .52355 L .53185 .54825 L p
1 g
F P
s
P
p
.002 w
.53303 .52355 m .58689 .51403 L .58378 .4879 L p
1 g
F P
s
P
p
.002 w
.35498 .42035 m .38742 .4544 L .40048 .43024 L p
1 g
F P
s
P
p
.002 w
.40048 .43024 m .37135 .39897 L .35498 .42035 L p
1 g
F P
s
P
p
.002 w
.6125 .36977 m .59163 .39118 L .6062 .41607 L p
1 g
F P
s
P
p
.002 w
.59163 .39118 m .6125 .36977 L .59077 .35057 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .50085 .32765 L .50989 .33046 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .50989 .33046 L .51944 .33091 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .51944 .33091 L .52848 .32895 L closepath p
1 g
F P
s
P
p
.002 w
.62757 .46713 m .58378 .4879 L .58689 .51403 L p
1 g
F P
s
P
p
.002 w
.58378 .4879 m .62757 .46713 L .61828 .44155 L p
1 g
F P
s
P
p
.002 w
.55623 .34509 m .56692 .33347 L .54143 .3188 L p
1 g
F P
s
P
p
.002 w
.54143 .3188 m .53609 .32477 L .55623 .34509 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .49325 .32276 L .50085 .32765 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .52848 .32895 L .53609 .32477 L closepath p
1 g
F P
s
P
p
.002 w
.36934 .50171 m .41781 .52906 L .42342 .50501 L p
1 g
F P
s
P
p
.002 w
.42342 .50501 m .37694 .47838 L .36934 .50171 L p
1 g
F P
s
P
p
.002 w
.63163 .3907 m .6062 .41607 L .61828 .44155 L p
1 g
F P
s
P
p
.002 w
.6062 .41607 m .63163 .3907 L .6125 .36977 L p
1 g
F P
s
P
p
.002 w
.49325 .32276 m .48791 .3163 L .46154 .32849 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .48791 .3163 L .49325 .32276 L closepath p
1 g
F P
s
P
p
.002 w
.4018 .33293 m .41242 .36001 L .43621 .34315 L p
1 g
F P
s
P
p
.002 w
.43621 .34315 m .42832 .32208 L .4018 .33293 L p
1 g
F P
s
P
p
.002 w
.42832 .32208 m .43621 .34315 L .46154 .32849 L p
1 g
F P
s
P
p
.002 w
.46154 .32849 m .45639 .31404 L .42832 .32208 L p
1 g
F P
s
P
p
.002 w
.45639 .31404 m .46154 .32849 L .48791 .3163 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .53609 .32477 L .54143 .3188 L closepath p
1 g
F P
s
P
p
.002 w
.37739 .3464 m .39064 .37873 L .41242 .36001 L p
1 g
F P
s
P
p
.002 w
.41242 .36001 m .4018 .33293 L .37739 .3464 L p
1 g
F P
s
P
p
.002 w
.48791 .3163 m .48542 .30893 L .45639 .31404 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .48542 .30893 L .48791 .3163 L closepath p
1 g
F P
s
P
p
.002 w
.34198 .44244 m .37694 .47838 L .38742 .4544 L p
1 g
F P
s
P
p
.002 w
.38742 .4544 m .35498 .42035 L .34198 .44244 L p
1 g
F P
s
P
p
.002 w
.41413 .55126 m .4707 .56722 L .47355 .54494 L p
1 g
F P
s
P
p
.002 w
.47355 .54494 m .41781 .52906 L .41413 .55126 L p
1 g
F P
s
P
p
.002 w
.53185 .54825 m .47355 .54494 L .4707 .56722 L p
1 g
F P
s
P
p
.002 w
.57206 .31943 m .56692 .33347 L .59077 .35057 L p
1 g
F P
s
P
p
.002 w
.56692 .33347 m .57206 .31943 L .54391 .31164 L p
1 g
F P
s
P
p
.002 w
.54391 .31164 m .54143 .3188 L .56692 .33347 L p
1 g
F P
s
P
p
.002 w
.64772 .41296 m .61828 .44155 L .62757 .46713 L p
1 g
F P
s
P
p
.002 w
.61828 .44155 m .64772 .41296 L .63163 .3907 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .54143 .3188 L .54391 .31164 L closepath p
1 g
F P
s
P
p
.002 w
.53185 .54825 m .58789 .53863 L .58689 .51403 L p
1 g
F P
s
P
p
.002 w
.63381 .49228 m .58689 .51403 L .58789 .53863 L p
1 g
F P
s
P
p
.002 w
.58689 .51403 m .63381 .49228 L .62757 .46713 L p
1 g
F P
s
P
p
.002 w
.59866 .3301 m .59077 .35057 L .6125 .36977 L p
1 g
F P
s
P
p
.002 w
.59077 .35057 m .59866 .3301 L .57206 .31943 L p
1 g
F P
s
P
p
.002 w
.35568 .36227 m .37135 .39897 L .39064 .37873 L p
1 g
F P
s
P
p
.002 w
.39064 .37873 m .37739 .3464 L .35568 .36227 L p
1 g
F P
s
P
p
.002 w
.4707 .56722 m .52983 .57064 L .53185 .54825 L p
1 g
F P
s
P
p
.002 w
.58789 .53863 m .53185 .54825 L .52983 .57064 L p
1 g
F P
s
P
p
.002 w
.45743 .29922 m .45639 .31404 L .48542 .30893 L p
1 g
F P
s
P
p
.002 w
.48542 .30893 m .48607 .30144 L .45743 .29922 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .48607 .30144 L .48542 .30893 L closepath p
1 g
F P
s
P
p
.002 w
.42948 .30031 m .42832 .32208 L .45639 .31404 L p
1 g
F P
s
P
p
.002 w
.45639 .31404 m .45743 .29922 L .42948 .30031 L p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .54391 .31164 L .54323 .30407 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .54323 .30407 L .53941 .29691 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .53941 .29691 L .53285 .29095 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .53285 .29095 L .52425 .28689 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .52425 .28689 L .51458 .28517 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .51458 .28517 L .50492 .28601 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .50492 .28601 L .49636 .28929 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .49636 .28929 L .48984 .29464 L closepath p
1 g
F P
s
P
p
.002 w
.51481 .30685 m .48984 .29464 L .48607 .30144 L closepath p
1 g
F P
s
P
p
.002 w
.54323 .30407 m .54391 .31164 L .57206 .31943 L p
1 g
F P
s
P
p
.002 w
.62314 .34347 m .6125 .36977 L .63163 .3907 L p
1 g
F P
s
P
p
.002 w
.6125 .36977 m .62314 .34347 L .59866 .3301 L p
1 g
F P
s
P
p
.002 w
.36489 .52384 m .41413 .55126 L .41781 .52906 L p
1 g
F P
s
P
p
.002 w
.41781 .52906 m .36934 .50171 L .36489 .52384 L p
1 g
F P
s
P
p
.002 w
.4647 .28566 m .45743 .29922 L .48607 .30144 L p
1 g
F P
s
P
p
.002 w
.48607 .30144 m .48984 .29464 L .4647 .28566 L p
1 g
F P
s
P
p
.002 w
.40284 .30474 m .4018 .33293 L .42832 .32208 L p
1 g
F P
s
P
p
.002 w
.42832 .32208 m .42948 .30031 L .40284 .30474 L p
1 g
F P
s
P
p
.002 w
.33274 .46478 m .36934 .50171 L .37694 .47838 L p
1 g
F P
s
P
p
.002 w
.37694 .47838 m .34198 .44244 L .33274 .46478 L p
1 g
F P
s
P
p
.002 w
.57095 .30445 m .57206 .31943 L .59866 .3301 L p
1 g
F P
s
P
p
.002 w
.57206 .31943 m .57095 .30445 L .54323 .30407 L p
1 g
F P
s
P
p
.002 w
.33724 .38026 m .35498 .42035 L .37135 .39897 L p
1 g
F P
s
P
p
.002 w
.37135 .39897 m .35568 .36227 L .33724 .38026 L p
1 g
F P
s
P
p
.002 w
.66033 .4361 m .62757 .46713 L .63381 .49228 L p
1 g
F P
s
P
p
.002 w
.62757 .46713 m .66033 .4361 L .64772 .41296 L p
1 g
F P
s
P
p
.002 w
.53941 .29691 m .54323 .30407 L .57095 .30445 L p
1 g
F P
s
P
p
.002 w
.47754 .2749 m .4647 .28566 L .48984 .29464 L p
1 g
F P
s
P
p
.002 w
.48984 .29464 m .49636 .28929 L .47754 .2749 L p
1 g
F P
s
P
p
.002 w
.64489 .35931 m .63163 .3907 L .64772 .41296 L p
1 g
F P
s
P
p
.002 w
.63163 .3907 m .64489 .35931 L .62314 .34347 L p
1 g
F P
s
P
p
.002 w
.4399 .2802 m .42948 .30031 L .45743 .29922 L p
1 g
F P
s
P
p
.002 w
.45743 .29922 m .4647 .28566 L .4399 .2802 L p
1 g
F P
s
P
p
.002 w
.37814 .31253 m .37739 .3464 L .4018 .33293 L p
1 g
F P
s
P
p
.002 w
.4018 .33293 m .40284 .30474 L .37814 .31253 L p
1 g
F P
s
P
p
.002 w
.57095 .30445 m .56355 .29015 L .53941 .29691 L p
1 g
F P
s
P
p
.002 w
.53285 .29095 m .53941 .29691 L .56355 .29015 L p
1 g
F P
s
P
p
.002 w
.52983 .57064 m .58666 .56113 L .58789 .53863 L p
1 g
F P
s
P
p
.002 w
.63677 .51646 m .58789 .53863 L .58666 .56113 L p
1 g
F P
s
P
p
.002 w
.58789 .53863 m .63677 .51646 L .63381 .49228 L p
1 g
F P
s
P
p
.002 w
.41255 .57104 m .46851 .5867 L .4707 .56722 L p
1 g
F P
s
P
p
.002 w
.4707 .56722 m .41413 .55126 L .41255 .57104 L p
1 g
F P
s
P
p
.002 w
.52983 .57064 m .4707 .56722 L .46851 .5867 L p
1 g
F P
s
P
p
.002 w
.59737 .30805 m .59866 .3301 L .62314 .34347 L p
1 g
F P
s
P
p
.002 w
.59866 .3301 m .59737 .30805 L .57095 .30445 L p
1 g
F P
s
P
p
.002 w
.49461 .26824 m .47754 .2749 L .49636 .28929 L p
1 g
F P
s
P
p
.002 w
.49636 .28929 m .50492 .28601 L .49461 .26824 L p
1 g
F P
s
P
p
.002 w
.46851 .5867 m .52698 .59013 L .52983 .57064 L p
1 g
F P
s
P
p
.002 w
.58666 .56113 m .52983 .57064 L .52698 .59013 L p
1 g
F P
s
P
p
.002 w
.56355 .29015 m .55056 .27818 L .53285 .29095 L p
1 g
F P
s
P
p
.002 w
.52425 .28689 m .53285 .29095 L .55056 .27818 L p
1 g
F P
s
P
p
.002 w
.51397 .26652 m .49461 .26824 L .50492 .28601 L p
1 g
F P
s
P
p
.002 w
.50492 .28601 m .51458 .28517 L .51397 .26652 L p
1 g
F P
s
P
p
.002 w
.56355 .29015 m .57095 .30445 L .59737 .30805 L p
1 g
F P
s
P
p
.002 w
.3226 .40002 m .34198 .44244 L .35498 .42035 L p
1 g
F P
s
P
p
.002 w
.35498 .42035 m .33724 .38026 L .3226 .40002 L p
1 g
F P
s
P
p
.002 w
.55056 .27818 m .53338 .26997 L .52425 .28689 L p
1 g
F P
s
P
p
.002 w
.51458 .28517 m .52425 .28689 L .53338 .26997 L p
1 g
F P
s
P
p
.002 w
.53338 .26997 m .51397 .26652 L .51458 .28517 L p
1 g
F P
s
P
p
.002 w
.66908 .45965 m .63381 .49228 L .63677 .51646 L p
1 g
F P
s
P
p
.002 w
.63381 .49228 m .66908 .45965 L .66033 .4361 L p
1 g
F P
s
P
p
.002 w
.41603 .27851 m .40284 .30474 L .42948 .30031 L p
1 g
F P
s
P
p
.002 w
.42948 .30031 m .4399 .2802 L .41603 .27851 L p
1 g
F P
s
P
p
.002 w
.36384 .54422 m .41255 .57104 L .41413 .55126 L p
1 g
F P
s
P
p
.002 w
.41413 .55126 m .36489 .52384 L .36384 .54422 L p
1 g
F P
s
P
p
.002 w
.35602 .3236 m .35568 .36227 L .37739 .3464 L p
1 g
F P
s
P
p
.002 w
.37739 .3464 m .37814 .31253 L .35602 .3236 L p
1 g
F P
s
P
p
.002 w
.66337 .37735 m .64772 .41296 L .66033 .4361 L p
1 g
F P
s
P
p
.002 w
.64772 .41296 m .66337 .37735 L .64489 .35931 L p
1 g
F P
s
P
p
.002 w
.32765 .48686 m .36489 .52384 L .36934 .50171 L p
1 g
F P
s
P
p
.002 w
.36934 .50171 m .33274 .46478 L .32765 .48686 L p
1 g
F P
s
P
p
.002 w
.45876 .26413 m .4399 .2802 L .4647 .28566 L p
1 g
F P
s
P
p
.002 w
.4647 .28566 m .47754 .2749 L .45876 .26413 L p
1 g
F P
s
P
p
.002 w
.62187 .31489 m .62314 .34347 L .64489 .35931 L p
1 g
F P
s
P
p
.002 w
.62314 .34347 m .62187 .31489 L .59737 .30805 L p
1 g
F P
s
P
p
.002 w
.59737 .30805 m .58669 .28683 L .56355 .29015 L p
1 g
F P
s
P
p
.002 w
.55056 .27818 m .56355 .29015 L .58669 .28683 L p
1 g
F P
s
P
p
.002 w
.58669 .28683 m .59737 .30805 L .62187 .31489 L p
1 g
F P
s
P
p
.002 w
.52698 .59013 m .58315 .58095 L .58666 .56113 L p
1 g
F P
s
P
p
.002 w
.63625 .53908 m .58666 .56113 L .58315 .58095 L p
1 g
F P
s
P
p
.002 w
.58666 .56113 m .63625 .53908 L .63677 .51646 L p
1 g
F P
s
P
p
.002 w
.48408 .25411 m .45876 .26413 L .47754 .2749 L p
1 g
F P
s
P
p
.002 w
.47754 .2749 m .49461 .26824 L .48408 .25411 L p
1 g
F P
s
P
p
.002 w
.31228 .42115 m .33274 .46478 L .34198 .44244 L p
1 g
F P
s
P
p
.002 w
.34198 .44244 m .3226 .40002 L .31228 .42115 L p
1 g
F P
s
P
p
.002 w
.39368 .28079 m .37814 .31253 L .40284 .30474 L p
1 g
F P
s
P
p
.002 w
.40284 .30474 m .41603 .27851 L .39368 .28079 L p
1 g
F P
s
P
p
.002 w
.41321 .58783 m .46706 .6028 L .46851 .5867 L p
1 g
F P
s
P
p
.002 w
.46851 .5867 m .41255 .57104 L .41321 .58783 L p
1 g
F P
s
P
p
.002 w
.52698 .59013 m .46851 .5867 L .46706 .6028 L p
1 g
F P
s
P
p
.002 w
.33712 .33783 m .33724 .38026 L .35568 .36227 L p
1 g
F P
s
P
p
.002 w
.35568 .36227 m .35602 .3236 L .33712 .33783 L p
1 g
F P
s
P
p
.002 w
.67801 .39724 m .66033 .4361 L .66908 .45965 L p
1 g
F P
s
P
p
.002 w
.66033 .4361 m .67801 .39724 L .66337 .37735 L p
1 g
F P
s
P
p
.002 w
.58669 .28683 m .56753 .26896 L .55056 .27818 L p
1 g
F P
s
P
p
.002 w
.53338 .26997 m .55056 .27818 L .56753 .26896 L p
1 g
F P
s
P
p
.002 w
.64381 .32495 m .64489 .35931 L .66337 .37735 L p
1 g
F P
s
P
p
.002 w
.64489 .35931 m .64381 .32495 L .62187 .31489 L p
1 g
F P
s
P
p
.002 w
.67361 .48305 m .63677 .51646 L .63625 .53908 L p
1 g
F P
s
P
p
.002 w
.63677 .51646 m .67361 .48305 L .66908 .45965 L p
1 g
F P
s
P
p
.002 w
.44044 .25739 m .41603 .27851 L .4399 .2802 L p
1 g
F P
s
P
p
.002 w
.4399 .2802 m .45876 .26413 L .44044 .25739 L p
1 g
F P
s
P
p
.002 w
.46706 .6028 m .52333 .60614 L .52698 .59013 L p
1 g
F P
s
P
p
.002 w
.58315 .58095 m .52698 .59013 L .52333 .60614 L p
1 g
F P
s
P
p
.002 w
.51297 .25149 m .48408 .25411 L .49461 .26824 L p
1 g
F P
s
P
p
.002 w
.49461 .26824 m .51397 .26652 L .51297 .25149 L p
1 g
F P
s
P
p
.002 w
.56753 .26896 m .54196 .25665 L .53338 .26997 L p
1 g
F P
s
P
p
.002 w
.51397 .26652 m .53338 .26997 L .54196 .25665 L p
1 g
F P
s
P
p
.002 w
.327 .50812 m .36384 .54422 L .36489 .52384 L p
1 g
F P
s
P
p
.002 w
.36489 .52384 m .32765 .48686 L .327 .50812 L p
1 g
F P
s
P
p
.002 w
.54196 .25665 m .51297 .25149 L .51397 .26652 L p
1 g
F P
s
P
p
.002 w
.36638 .56229 m .41321 .58783 L .41255 .57104 L p
1 g
F P
s
P
p
.002 w
.41255 .57104 m .36384 .54422 L .36638 .56229 L p
1 g
F P
s
P
p
.002 w
.62187 .31489 m .60825 .28719 L .58669 .28683 L p
1 g
F P
s
P
p
.002 w
.56753 .26896 m .58669 .28683 L .60825 .28719 L p
1 g
F P
s
P
p
.002 w
.60825 .28719 m .62187 .31489 L .64381 .32495 L p
1 g
F P
s
P
p
.002 w
.37347 .28716 m .35602 .3236 L .37814 .31253 L p
1 g
F P
s
P
p
.002 w
.37814 .31253 m .39368 .28079 L .37347 .28716 L p
1 g
F P
s
P
p
.002 w
.32205 .35499 m .3226 .40002 L .33724 .38026 L p
1 g
F P
s
P
p
.002 w
.33724 .38026 m .33712 .33783 L .32205 .35499 L p
1 g
F P
s
P
p
.002 w
.30672 .44317 m .32765 .48686 L .33274 .46478 L p
1 g
F P
s
P
p
.002 w
.33274 .46478 m .31228 .42115 L .30672 .44317 L p
1 g
F P
s
P
p
.002 w
.47358 .24414 m .44044 .25739 L .45876 .26413 L p
1 g
F P
s
P
p
.002 w
.45876 .26413 m .48408 .25411 L .47358 .24414 L p
1 g
F P
s
P
p
.002 w
.68831 .41858 m .66908 .45965 L .67361 .48305 L p
1 g
F P
s
P
p
.002 w
.66908 .45965 m .68831 .41858 L .67801 .39724 L p
1 g
F P
s
P
p
.002 w
.66257 .3381 m .66337 .37735 L .67801 .39724 L p
1 g
F P
s
P
p
.002 w
.66337 .37735 m .66257 .3381 L .64381 .32495 L p
1 g
F P
s
P
p
.002 w
.52333 .60614 m .57732 .59749 L .58315 .58095 L p
1 g
F P
s
P
p
.002 w
.63211 .55953 m .58315 .58095 L .57732 .59749 L p
1 g
F P
s
P
p
.002 w
.58315 .58095 m .63211 .55953 L .63625 .53908 L p
1 g
F P
s
P
p
.002 w
.42307 .25506 m .39368 .28079 L .41603 .27851 L p
1 g
F P
s
P
p
.002 w
.41603 .27851 m .44044 .25739 L .42307 .25506 L p
1 g
F P
s
P
p
.002 w
.67364 .50575 m .63625 .53908 L .63211 .55953 L p
1 g
F P
s
P
p
.002 w
.63625 .53908 m .67364 .50575 L .67361 .48305 L p
1 g
F P
s
P
p
.002 w
.60825 .28719 m .58332 .2637 L .56753 .26896 L p
1 g
F P
s
P
p
.002 w
.54196 .25665 m .56753 .26896 L .58332 .2637 L p
1 g
F P
s
P
p
.002 w
.41622 .60107 m .46643 .61496 L .46706 .6028 L p
1 g
F P
s
P
p
.002 w
.46706 .6028 m .41321 .58783 L .41622 .60107 L p
1 g
F P
s
P
p
.002 w
.52333 .60614 m .46706 .6028 L .46643 .61496 L p
1 g
F P
s
P
p
.002 w
.51159 .24064 m .47358 .24414 L .48408 .25411 L p
1 g
F P
s
P
p
.002 w
.48408 .25411 m .51297 .25149 L .51159 .24064 L p
1 g
F P
s
P
p
.002 w
.46643 .61496 m .51891 .6181 L .52333 .60614 L p
1 g
F P
s
P
p
.002 w
.57732 .59749 m .52333 .60614 L .51891 .6181 L p
1 g
F P
s
P
p
.002 w
.33103 .528 m .36638 .56229 L .36384 .54422 L p
1 g
F P
s
P
p
.002 w
.36384 .54422 m .327 .50812 L .33103 .528 L p
1 g
F P
s
P
p
.002 w
.62763 .29139 m .64381 .32495 L .66257 .3381 L p
1 g
F P
s
P
p
.002 w
.64381 .32495 m .62763 .29139 L .60825 .28719 L p
1 g
F P
s
P
p
.002 w
.58332 .2637 m .54976 .24745 L .54196 .25665 L p
1 g
F P
s
P
p
.002 w
.51297 .25149 m .54196 .25665 L .54976 .24745 L p
1 g
F P
s
P
p
.002 w
.35604 .29765 m .33712 .33783 L .35602 .3236 L p
1 g
F P
s
P
p
.002 w
.35602 .3236 m .37347 .28716 L .35604 .29765 L p
1 g
F P
s
P
p
.002 w
.54976 .24745 m .51159 .24064 L .51297 .25149 L p
1 g
F P
s
P
p
.002 w
.58332 .2637 m .60825 .28719 L .62763 .29139 L p
1 g
F P
s
P
p
.002 w
.37264 .57746 m .41622 .60107 L .41321 .58783 L p
1 g
F P
s
P
p
.002 w
.41321 .58783 m .36638 .56229 L .37264 .57746 L p
1 g
F P
s
P
p
.002 w
.31139 .37476 m .31228 .42115 L .3226 .40002 L p
1 g
F P
s
P
p
.002 w
.3226 .40002 m .32205 .35499 L .31139 .37476 L p
1 g
F P
s
P
p
.002 w
.67752 .35416 m .67801 .39724 L .68831 .41858 L p
1 g
F P
s
P
p
.002 w
.67801 .39724 m .67752 .35416 L .66257 .3381 L p
1 g
F P
s
P
p
.002 w
.3063 .46554 m .327 .50812 L .32765 .48686 L p
1 g
F P
s
P
p
.002 w
.32765 .48686 m .30672 .44317 L .3063 .46554 L p
1 g
F P
s
P
p
.002 w
.69382 .44088 m .67361 .48305 L .67364 .50575 L p
1 g
F P
s
P
p
.002 w
.67361 .48305 m .69382 .44088 L .68831 .41858 L p
1 g
F P
s
P
p
.002 w
.46336 .23883 m .42307 .25506 L .44044 .25739 L p
1 g
F P
s
P
p
.002 w
.44044 .25739 m .47358 .24414 L .46336 .23883 L p
1 g
F P
s
P
p
.002 w
.40714 .25745 m .37347 .28716 L .39368 .28079 L p
1 g
F P
s
P
p
.002 w
.39368 .28079 m .42307 .25506 L .40714 .25745 L p
1 g
F P
s
P
p
.002 w
.51891 .6181 m .56918 .61016 L .57732 .59749 L p
1 g
F P
s
P
p
.002 w
.62427 .57721 m .57732 .59749 L .56918 .61016 L p
1 g
F P
s
P
p
.002 w
.57732 .59749 m .62427 .57721 L .63211 .55953 L p
1 g
F P
s
P
p
.002 w
.66896 .52712 m .63211 .55953 L .62427 .57721 L p
1 g
F P
s
P
p
.002 w
.63211 .55953 m .66896 .52712 L .67364 .50575 L p
1 g
F P
s
P
p
.002 w
.62763 .29139 m .59747 .26275 L .58332 .2637 L p
1 g
F P
s
P
p
.002 w
.54976 .24745 m .58332 .2637 L .59747 .26275 L p
1 g
F P
s
P
p
.002 w
.64424 .29951 m .66257 .3381 L .67752 .35416 L p
1 g
F P
s
P
p
.002 w
.66257 .3381 m .64424 .29951 L .62763 .29139 L p
1 g
F P
s
P
p
.002 w
.342 .31221 m .32205 .35499 L .33712 .33783 L p
1 g
F P
s
P
p
.002 w
.33712 .33783 m .35604 .29765 L .342 .31221 L p
1 g
F P
s
P
p
.002 w
.42164 .61019 m .46669 .62261 L .46643 .61496 L p
1 g
F P
s
P
p
.002 w
.46643 .61496 m .41622 .60107 L .42164 .61019 L p
1 g
F P
s
P
p
.002 w
.51891 .6181 m .46643 .61496 L .46669 .62261 L p
1 g
F P
s
P
p
.002 w
.33989 .54586 m .37264 .57746 L .36638 .56229 L p
1 g
F P
s
P
p
.002 w
.36638 .56229 m .33103 .528 L .33989 .54586 L p
1 g
F P
s
P
p
.002 w
.30565 .39672 m .30672 .44317 L .31228 .42115 L p
1 g
F P
s
P
p
.002 w
.31228 .42115 m .31139 .37476 L .30565 .39672 L p
1 g
F P
s
P
p
.002 w
.50982 .23452 m .46336 .23883 L .47358 .24414 L p
1 g
F P
s
P
p
.002 w
.47358 .24414 m .51159 .24064 L .50982 .23452 L p
1 g
F P
s
P
p
.002 w
.46669 .62261 m .51379 .62545 L .51891 .6181 L p
1 g
F P
s
P
p
.002 w
.56918 .61016 m .51891 .6181 L .51379 .62545 L p
1 g
F P
s
P
p
.002 w
.68808 .37284 m .68831 .41858 L .69382 .44088 L p
1 g
F P
s
P
p
.002 w
.68831 .41858 m .68808 .37284 L .67752 .35416 L p
1 g
F P
s
P
p
.002 w
.59747 .26275 m .62763 .29139 L .64424 .29951 L p
1 g
F P
s
P
p
.002 w
.69417 .46359 m .67364 .50575 L .66896 .52712 L p
1 g
F P
s
P
p
.002 w
.67364 .50575 m .69417 .46359 L .69382 .44088 L p
1 g
F P
s
P
p
.002 w
.31128 .48766 m .33103 .528 L .327 .50812 L p
1 g
F P
s
P
p
.002 w
.327 .50812 m .3063 .46554 L .31128 .48766 L p
1 g
F P
s
P
p
.002 w
.59747 .26275 m .55653 .24287 L .54976 .24745 L p
1 g
F P
s
P
p
.002 w
.51159 .24064 m .54976 .24745 L .55653 .24287 L p
1 g
F P
s
P
p
.002 w
.38266 .58915 m .42164 .61019 L .41622 .60107 L p
1 g
F P
s
P
p
.002 w
.41622 .60107 m .37264 .57746 L .38266 .58915 L p
1 g
F P
s
P
p
.002 w
.55653 .24287 m .50982 .23452 L .51159 .24064 L p
1 g
F P
s
P
p
.002 w
.39319 .26476 m .35604 .29765 L .37347 .28716 L p
1 g
F P
s
P
p
.002 w
.37347 .28716 m .40714 .25745 L .39319 .26476 L p
1 g
F P
s
P
p
.002 w
.45374 .23863 m .40714 .25745 L .42307 .25506 L p
1 g
F P
s
P
p
.002 w
.42307 .25506 m .46336 .23883 L .45374 .23863 L p
1 g
F P
s
P
p
.002 w
.56918 .61016 m .61274 .5915 L .62427 .57721 L p
1 g
F P
s
P
p
.002 w
.65946 .54653 m .62427 .57721 L .61274 .5915 L p
1 g
F P
s
P
p
.002 w
.62427 .57721 m .65946 .54653 L .66896 .52712 L p
1 g
F P
s
P
p
.002 w
.51379 .62545 m .55881 .6184 L .56918 .61016 L p
1 g
F P
s
P
p
.002 w
.61274 .5915 m .56918 .61016 L .55881 .6184 L p
1 g
F P
s
P
p
.002 w
.65746 .31156 m .67752 .35416 L .68808 .37284 L p
1 g
F P
s
P
p
.002 w
.67752 .35416 m .65746 .31156 L .64424 .29951 L p
1 g
F P
s
P
p
.002 w
.33193 .33061 m .31139 .37476 L .32205 .35499 L p
1 g
F P
s
P
p
.002 w
.32205 .35499 m .342 .31221 L .33193 .33061 L p
1 g
F P
s
P
p
.002 w
.30523 .42034 m .3063 .46554 L .30672 .44317 L p
1 g
F P
s
P
p
.002 w
.30672 .44317 m .30565 .39672 L .30523 .42034 L p
1 g
F P
s
P
p
.002 w
.64424 .29951 m .6095 .2664 L .59747 .26275 L p
1 g
F P
s
P
p
.002 w
.55653 .24287 m .59747 .26275 L .6095 .2664 L p
1 g
F P
s
P
p
.002 w
.69375 .39375 m .69382 .44088 L .69417 .46359 L p
1 g
F P
s
P
p
.002 w
.69382 .44088 m .69375 .39375 L .68808 .37284 L p
1 g
F P
s
P
p
.002 w
.35356 .56111 m .38266 .58915 L .37264 .57746 L p
1 g
F P
s
P
p
.002 w
.37264 .57746 m .33989 .54586 L .35356 .56111 L p
1 g
F P
s
P
p
.002 w
.6891 .4861 m .66896 .52712 L .65946 .54653 L p
1 g
F P
s
P
p
.002 w
.66896 .52712 m .6891 .4861 L .69417 .46359 L p
1 g
F P
s
P
p
.002 w
.6095 .2664 m .64424 .29951 L .65746 .31156 L p
1 g
F P
s
P
p
.002 w
.42948 .61469 m .46789 .62526 L .46669 .62261 L p
1 g
F P
s
P
p
.002 w
.46669 .62261 m .42164 .61019 L .42948 .61469 L p
1 g
F P
s
P
p
.002 w
.51379 .62545 m .46669 .62261 L .46789 .62526 L p
1 g
F P
s
P
p
.002 w
.32176 .50885 m .33989 .54586 L .33103 .528 L p
1 g
F P
s
P
p
.002 w
.33103 .528 m .31128 .48766 L .32176 .50885 L p
1 g
F P
s
P
p
.002 w
.50771 .23361 m .45374 .23863 L .46336 .23883 L p
1 g
F P
s
P
p
.002 w
.46336 .23883 m .50982 .23452 L .50771 .23361 L p
1 g
F P
s
P
p
.002 w
.46789 .62526 m .50806 .62769 L .51379 .62545 L p
1 g
F P
s
P
p
.002 w
.55881 .6184 m .51379 .62545 L .50806 .62769 L p
1 g
F P
s
P
p
.004 w
.47168 .66698 m
.47483 .64069 L
s
P
p
.004 w
.64914 .59989 m
.69784 .65519 L
s
P
p
.002 w
.38174 .27708 m .342 .31221 L .35604 .29765 L p
1 g
F P
s
P
p
.002 w
.35604 .29765 m .39319 .26476 L .38174 .27708 L p
1 g
F P
s
P
p
.002 w
.6095 .2664 m .56202 .24332 L .55653 .24287 L p
1 g
F P
s
P
p
.002 w
.50982 .23452 m .55653 .24287 L .56202 .24332 L p
1 g
F P
s
P
p
.002 w
.39638 .59682 m .42948 .61469 L .42164 .61019 L p
1 g
F P
s
P
p
.002 w
.42164 .61019 m .38266 .58915 L .39638 .59682 L p
1 g
F P
s
P
p
.002 w
.56202 .24332 m .50771 .23361 L .50982 .23452 L p
1 g
F P
s
P
p
.002 w
.44501 .24386 m .39319 .26476 L .40714 .25745 L p
1 g
F P
s
P
p
.002 w
.40714 .25745 m .45374 .23863 L .44501 .24386 L p
1 g
F P
s
P
p
.002 w
.55881 .6184 m .59763 .60183 L .61274 .5915 L p
1 g
F P
s
P
p
.002 w
.61274 .5915 m .64517 .56332 L .65946 .54653 L p
1 g
F P
s
P
p
.002 w
.64517 .56332 m .61274 .5915 L .59763 .60183 L p
1 g
F P
s
P
p
.002 w
.32636 .35251 m .30565 .39672 L .31139 .37476 L p
1 g
F P
s
P
p
.002 w
.31139 .37476 m .33193 .33061 L .32636 .35251 L p
1 g
F P
s
P
p
.002 w
.68808 .37284 m .66674 .32741 L .65746 .31156 L p
1 g
F P
s
P
p
.002 w
.66674 .32741 m .68808 .37284 L .69375 .39375 L p
1 g
F P
s
P
p
.002 w
.31039 .44496 m .31128 .48766 L .3063 .46554 L p
1 g
F P
s
P
p
.002 w
.3063 .46554 m .30523 .42034 L .31039 .44496 L p
1 g
F P
s
P
p
.002 w
.50806 .62769 m .54637 .6217 L .55881 .6184 L p
1 g
F P
s
P
p
.002 w
.59763 .60183 m .55881 .6184 L .54637 .6217 L p
1 g
F P
s
P
p
.002 w
.69417 .46359 m .69411 .4164 L .69375 .39375 L p
1 g
F P
s
P
p
.002 w
.69411 .4164 m .69417 .46359 L .6891 .4861 L p
1 g
F P
s
P
p
.002 w
.65946 .54653 m .67851 .50774 L .6891 .4861 L p
1 g
F P
s
P
p
.002 w
.67851 .50774 m .65946 .54653 L .64517 .56332 L p
1 g
F P
s
P
p
.002 w
.65746 .31156 m .61893 .27483 L .6095 .2664 L p
1 g
F P
s
P
p
.002 w
.56202 .24332 m .6095 .2664 L .61893 .27483 L p
1 g
F P
s
P
p
.002 w
.37189 .57314 m .39638 .59682 L .38266 .58915 L p
1 g
F P
s
P
p
.002 w
.38266 .58915 m .35356 .56111 L .37189 .57314 L p
1 g
F P
s
P
p
.002 w
.3377 .52844 m .35356 .56111 L .33989 .54586 L p
1 g
F P
s
P
p
.002 w
.33989 .54586 m .32176 .50885 L .3377 .52844 L p
1 g
F P
s
P
p
.002 w
.61893 .27483 m .65746 .31156 L .66674 .32741 L p
1 g
F P
s
P
p
.002 w
.37328 .29431 m .33193 .33061 L .342 .31221 L p
1 g
F P
s
P
p
.002 w
.342 .31221 m .38174 .27708 L .37328 .29431 L p
1 g
F P
s
P
p
.002 w
.50528 .23828 m .44501 .24386 L .45374 .23863 L p
1 g
F P
s
P
p
.002 w
.45374 .23863 m .50771 .23361 L .50528 .23828 L p
1 g
F P
s
P
p
.002 w
.43966 .61413 m .47005 .6225 L .46789 .62526 L p
1 g
F P
s
P
p
.002 w
.46789 .62526 m .42948 .61469 L .43966 .61413 L p
1 g
F P
s
P
p
.002 w
.50806 .62769 m .46789 .62526 L .47005 .6225 L p
1 g
F P
s
P
p
.002 w
.47005 .6225 m .50186 .62442 L .50806 .62769 L p
1 g
F P
s
P
p
.002 w
.54637 .6217 m .50806 .62769 L .50186 .62442 L p
1 g
F P
s
P
p
.002 w
.32567 .37738 m .30523 .42034 L .30565 .39672 L p
1 g
F P
s
P
p
.002 w
.30565 .39672 m .32636 .35251 L .32567 .37738 L p
1 g
F P
s
P
p
.002 w
.41362 .60002 m .43966 .61413 L .42948 .61469 L p
1 g
F P
s
P
p
.002 w
.42948 .61469 m .39638 .59682 L .41362 .60002 L p
1 g
F P
s
P
p
.002 w
.67157 .3468 m .69375 .39375 L .69411 .4164 L p
1 g
F P
s
P
p
.002 w
.69375 .39375 m .67157 .3468 L .66674 .32741 L p
1 g
F P
s
P
p
.002 w
.61893 .27483 m .56598 .24913 L .56202 .24332 L p
1 g
F P
s
P
p
.002 w
.50771 .23361 m .56202 .24332 L .56598 .24913 L p
1 g
F P
s
P
p
.002 w
.54637 .6217 m .5792 .60766 L .59763 .60183 L p
1 g
F P
s
P
p
.002 w
.62628 .57688 m .59763 .60183 L .5792 .60766 L p
1 g
F P
s
P
p
.002 w
.59763 .60183 m .62628 .57688 L .64517 .56332 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.62787 .57573 L
s
P
p
.004 w
.62881 .5768 m
.62977 .57788 L
s
P
p
.004 w
.62977 .57788 m
.63679 .58586 L
s
P
p
.004 w
.63679 .58586 m
.64914 .59989 L
s
P
p
.002 w
.32123 .46987 m .32176 .50885 L .31128 .48766 L p
1 g
F P
s
P
p
.002 w
.31128 .48766 m .31039 .44496 L .32123 .46987 L p
1 g
F P
s
P
p
.002 w
.43752 .25471 m .38174 .27708 L .39319 .26476 L p
1 g
F P
s
P
p
.002 w
.39319 .26476 m .44501 .24386 L .43752 .25471 L p
1 g
F P
s
P
p
.002 w
.68888 .44017 m .6891 .4861 L .67851 .50774 L p
1 g
F P
s
P
p
.002 w
.6891 .4861 m .68888 .44017 L .69411 .4164 L p
1 g
F P
s
P
p
.002 w
.56598 .24913 m .50528 .23828 L .50771 .23361 L p
1 g
F P
s
P
p
.002 w
.66246 .52779 m .64517 .56332 L .62628 .57688 L p
1 g
F P
s
P
p
.002 w
.64517 .56332 m .66246 .52779 L .67851 .50774 L p
1 g
F P
s
P
p
.002 w
.50186 .62442 m .53209 .61967 L .54637 .6217 L p
1 g
F P
s
P
p
.002 w
.5792 .60766 m .54637 .6217 L .53209 .61967 L p
1 g
F P
s
P
p
.002 w
.35882 .54572 m .37189 .57314 L .35356 .56111 L p
1 g
F P
s
P
p
.002 w
.35356 .56111 m .3377 .52844 L .35882 .54572 L p
1 g
F P
s
P
p
.002 w
.62533 .28809 m .66674 .32741 L .67157 .3468 L p
1 g
F P
s
P
p
.002 w
.66674 .32741 m .62533 .28809 L .61893 .27483 L p
1 g
F P
s
P
p
.002 w
.39455 .58141 m .41362 .60002 L .39638 .59682 L p
1 g
F P
s
P
p
.002 w
.39638 .59682 m .37189 .57314 L .39455 .58141 L p
1 g
F P
s
P
p
.002 w
.56598 .24913 m .61893 .27483 L .62533 .28809 L p
1 g
F P
s
P
p
.002 w
.36825 .31616 m .32636 .35251 L .33193 .33061 L p
1 g
F P
s
P
p
.002 w
.33193 .33061 m .37328 .29431 L .36825 .31616 L p
1 g
F P
s
P
p
.002 w
.33011 .40453 m .31039 .44496 L .30523 .42034 L p
1 g
F P
s
P
p
.002 w
.30523 .42034 m .32567 .37738 L .33011 .40453 L p
1 g
F P
s
P
p
.002 w
.3376 .49425 m .3377 .52844 L .32176 .50885 L p
1 g
F P
s
P
p
.002 w
.32176 .50885 m .32123 .46987 L .3376 .49425 L p
1 g
F P
s
P
p
.002 w
.67157 .3693 m .69411 .4164 L .68888 .44017 L p
1 g
F P
s
P
p
.002 w
.69411 .4164 m .67157 .3693 L .67157 .3468 L p
1 g
F P
s
P
p
.002 w
.50259 .24877 m .43752 .25471 L .44501 .24386 L p
1 g
F P
s
P
p
.002 w
.44501 .24386 m .50528 .23828 L .50259 .24877 L p
1 g
F P
s
P
p
.002 w
.67799 .46437 m .67851 .50774 L .66246 .52779 L p
1 g
F P
s
P
p
.002 w
.67851 .50774 m .67799 .46437 L .68888 .44017 L p
1 g
F P
s
P
p
.002 w
.45203 .6082 m .47317 .61405 L .47005 .6225 L p
1 g
F P
s
P
p
.002 w
.47005 .6225 m .43966 .61413 L .45203 .6082 L p
1 g
F P
s
P
p
.002 w
.50186 .62442 m .47005 .6225 L .47317 .61405 L p
1 g
F P
s
P
p
.002 w
.53209 .61967 m .55782 .60858 L .5792 .60766 L p
1 g
F P
s
P
p
.002 w
.60315 .58663 m .5792 .60766 L .55782 .60858 L p
1 g
F P
s
P
p
.002 w
.5792 .60766 m .60315 .58663 L .62628 .57688 L p
1 g
F P
s
P
p
.002 w
.47317 .61405 m .49533 .61538 L .50186 .62442 L p
1 g
F P
s
P
p
.002 w
.53209 .61967 m .50186 .62442 L .49533 .61538 L p
1 g
F P
s
P
p
.002 w
.43156 .27118 m .37328 .29431 L .38174 .27708 L p
1 g
F P
s
P
p
.002 w
.38174 .27708 m .43752 .25471 L .43156 .27118 L p
1 g
F P
s
P
p
.002 w
.64123 .54557 m .62628 .57688 L .60315 .58663 L p
1 g
F P
s
P
p
.002 w
.62628 .57688 m .64123 .54557 L .66246 .52779 L p
1 g
F P
s
P
p
.002 w
.43401 .59837 m .45203 .6082 L .43966 .61413 L p
1 g
F P
s
P
p
.002 w
.43966 .61413 m .41362 .60002 L .43401 .59837 L p
1 g
F P
s
P
p
.002 w
.62533 .28809 m .56819 .26047 L .56598 .24913 L p
1 g
F P
s
P
p
.002 w
.50528 .23828 m .56598 .24913 L .56819 .26047 L p
1 g
F P
s
P
p
.002 w
.56819 .26047 m .50259 .24877 L .50528 .23828 L p
1 g
F P
s
P
p
.002 w
.49533 .61538 m .51632 .61204 L .53209 .61967 L p
1 g
F P
s
P
p
.002 w
.55782 .60858 m .53209 .61967 L .51632 .61204 L p
1 g
F P
s
P
p
.002 w
.38463 .56005 m .39455 .58141 L .37189 .57314 L p
1 g
F P
s
P
p
.002 w
.37189 .57314 m .35882 .54572 L .38463 .56005 L p
1 g
F P
s
P
p
.002 w
.62831 .30603 m .67157 .3468 L .67157 .3693 L p
1 g
F P
s
P
p
.002 w
.67157 .3468 m .62831 .30603 L .62533 .28809 L p
1 g
F P
s
P
p
.002 w
.36701 .34213 m .32567 .37738 L .32636 .35251 L p
1 g
F P
s
P
p
.002 w
.32636 .35251 m .36825 .31616 L .36701 .34213 L p
1 g
F P
s
P
p
.002 w
.42099 .58549 m .43401 .59837 L .41362 .60002 L p
1 g
F P
s
P
p
.002 w
.41362 .60002 m .39455 .58141 L .42099 .58549 L p
1 g
F P
s
P
p
.002 w
.33974 .43315 m .32123 .46987 L .31039 .44496 L p
1 g
F P
s
P
p
.002 w
.31039 .44496 m .33011 .40453 L .33974 .43315 L p
1 g
F P
s
P
p
.002 w
.56819 .26047 m .62533 .28809 L .62831 .30603 L p
1 g
F P
s
P
p
.002 w
.35916 .51726 m .35882 .54572 L .3377 .52844 L p
1 g
F P
s
P
p
.002 w
.3377 .52844 m .3376 .49425 L .35916 .51726 L p
1 g
F P
s
P
p
.002 w
.66155 .4882 m .66246 .52779 L .64123 .54557 L p
1 g
F P
s
P
p
.002 w
.66246 .52779 m .66155 .4882 L .67799 .46437 L p
1 g
F P
s
P
p
.002 w
.66649 .39433 m .68888 .44017 L .67799 .46437 L p
1 g
F P
s
P
p
.002 w
.68888 .44017 m .66649 .39433 L .67157 .3693 L p
1 g
F P
s
P
p
.002 w
.51632 .61204 m .53403 .6043 L .55782 .60858 L p
1 g
F P
s
P
p
.002 w
.57634 .59207 m .55782 .60858 L .53403 .6043 L p
1 g
F P
s
P
p
.002 w
.55782 .60858 m .57634 .59207 L .60315 .58663 L p
1 g
F P
s
P
p
.002 w
.61531 .56038 m .60315 .58663 L .57634 .59207 L p
1 g
F P
s
P
p
.002 w
.60315 .58663 m .61531 .56038 L .64123 .54557 L p
1 g
F P
s
P
p
.002 w
.49971 .2651 m .43156 .27118 L .43752 .25471 L p
1 g
F P
s
P
p
.002 w
.43752 .25471 m .50259 .24877 L .49971 .2651 L p
1 g
F P
s
P
p
.002 w
.42744 .29304 m .36825 .31616 L .37328 .29431 L p
1 g
F P
s
P
p
.002 w
.37328 .29431 m .43156 .27118 L .42744 .29304 L p
1 g
F P
s
P
p
.002 w
.4663 .59678 m .47722 .59982 L .47317 .61405 L p
1 g
F P
s
P
p
.002 w
.47317 .61405 m .45203 .6082 L .4663 .59678 L p
1 g
F P
s
P
p
.002 w
.49533 .61538 m .47317 .61405 L .47722 .59982 L p
1 g
F P
s
P
p
.002 w
.47722 .59982 m .48867 .6005 L .49533 .61538 L p
1 g
F P
s
P
p
.002 w
.51632 .61204 m .49533 .61538 L .48867 .6005 L p
1 g
F P
s
P
p
.002 w
.41443 .57082 m .42099 .58549 L .39455 .58141 L p
1 g
F P
s
P
p
.002 w
.39455 .58141 m .38463 .56005 L .41443 .57082 L p
1 g
F P
s
P
p
.002 w
.45707 .59169 m .4663 .59678 L .45203 .6082 L p
1 g
F P
s
P
p
.002 w
.45203 .6082 m .43401 .59837 L .45707 .59169 L p
1 g
F P
s
P
p
.002 w
.62831 .30603 m .56846 .27732 L .56819 .26047 L p
1 g
F P
s
P
p
.002 w
.50259 .24877 m .56819 .26047 L .56846 .27732 L p
1 g
F P
s
P
p
.002 w
.3544 .46226 m .3376 .49425 L .32123 .46987 L p
1 g
F P
s
P
p
.002 w
.32123 .46987 m .33974 .43315 L .3544 .46226 L p
1 g
F P
s
P
p
.002 w
.48867 .6005 m .49948 .59874 L .51632 .61204 L p
1 g
F P
s
P
p
.002 w
.53403 .6043 m .51632 .61204 L .49948 .59874 L p
1 g
F P
s
P
p
.002 w
.36975 .37148 m .33011 .40453 L .32567 .37738 L p
1 g
F P
s
P
p
.002 w
.32567 .37738 m .36701 .34213 L .36975 .37148 L p
1 g
F P
s
P
p
.002 w
.38531 .53805 m .38463 .56005 L .35882 .54572 L p
1 g
F P
s
P
p
.002 w
.35882 .54572 m .35916 .51726 L .38531 .53805 L p
1 g
F P
s
P
p
.002 w
.63991 .51085 m .64123 .54557 L .61531 .56038 L p
1 g
F P
s
P
p
.002 w
.64123 .54557 m .63991 .51085 L .66155 .4882 L p
1 g
F P
s
P
p
.002 w
.62757 .32833 m .67157 .3693 L .66649 .39433 L p
1 g
F P
s
P
p
.002 w
.67157 .3693 m .62757 .32833 L .62831 .30603 L p
1 g
F P
s
P
p
.002 w
.56846 .27732 m .49971 .2651 L .50259 .24877 L p
1 g
F P
s
P
p
.002 w
.65627 .42115 m .67799 .46437 L .66155 .4882 L p
1 g
F P
s
P
p
.002 w
.67799 .46437 m .65627 .42115 L .66649 .39433 L p
1 g
F P
s
P
p
.002 w
.45048 .58505 m .45707 .59169 L .43401 .59837 L p
1 g
F P
s
P
p
.002 w
.43401 .59837 m .42099 .58549 L .45048 .58505 L p
1 g
F P
s
P
p
.002 w
.56846 .27732 m .62831 .30603 L .62757 .32833 L p
1 g
F P
s
P
p
.002 w
.53403 .6043 m .54659 .59287 L .57634 .59207 L p
1 g
F P
s
P
p
.002 w
.58544 .57164 m .57634 .59207 L .54659 .59287 L p
1 g
F P
s
P
p
.002 w
.57634 .59207 m .58544 .57164 L .61531 .56038 L p
1 g
F P
s
P
p
.002 w
.49948 .59874 m .50852 .59472 L .53403 .6043 L p
1 g
F P
s
P
p
.002 w
.54659 .59287 m .53403 .6043 L .50852 .59472 L p
1 g
F P
s
P
p
.002 w
.37369 .49084 m .35916 .51726 L .3376 .49425 L p
1 g
F P
s
P
p
.002 w
.3376 .49425 m .3544 .46226 L .37369 .49084 L p
1 g
F P
s
P
p
.002 w
.4254 .31978 m .36701 .34213 L .36825 .31616 L p
1 g
F P
s
P
p
.002 w
.36825 .31616 m .42744 .29304 L .4254 .31978 L p
1 g
F P
s
P
p
.002 w
.44729 .57756 m .45048 .58505 L .42099 .58549 L p
1 g
F P
s
P
p
.002 w
.42099 .58549 m .41443 .57082 L .44729 .57756 L p
1 g
F P
s
P
p
.002 w
.61369 .53148 m .61531 .56038 L .58544 .57164 L p
1 g
F P
s
P
p
.002 w
.61531 .56038 m .61369 .53148 L .63991 .51085 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.48604 .54707 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.41521 .55586 m .41443 .57082 L .38463 .56005 L p
1 g
F P
s
P
p
.002 w
.38463 .56005 m .38531 .53805 L .41521 .55586 L p
1 g
F P
s
P
p
.002 w
.49674 .28704 m .42744 .29304 L .43156 .27118 L p
1 g
F P
s
P
p
.002 w
.43156 .27118 m .49971 .2651 L .49674 .28704 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37654 .40329 m .33974 .43315 L .33011 .40453 L p
1 g
F P
s
P
p
.002 w
.33011 .40453 m .36975 .37148 L .37654 .40329 L p
1 g
F P
s
P
p
.002 w
.64109 .44887 m .66155 .4882 L .63991 .51085 L p
1 g
F P
s
P
p
.002 w
.66155 .4882 m .64109 .44887 L .65627 .42115 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.47722 .59982 m .4663 .59678 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.48867 .6005 m .47722 .59982 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.62295 .35443 m .66649 .39433 L .65627 .42115 L p
1 g
F P
s
P
p
.002 w
.66649 .39433 m .62295 .35443 L .62757 .32833 L p
1 g
F P
s
P
p
.002 w
.49948 .59874 m .48867 .6005 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.4663 .59678 m .45707 .59169 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.50852 .59472 m .51482 .58882 L .54659 .59287 L p
1 g
F P
s
P
p
.002 w
.55252 .57884 m .54659 .59287 L .51482 .58882 L p
1 g
F P
s
P
p
.002 w
.54659 .59287 m .55252 .57884 L .58544 .57164 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50852 .59472 m .49948 .59874 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.62757 .32833 m .56668 .29942 L .56846 .27732 L p
1 g
F P
s
P
p
.002 w
.49971 .2651 m .56846 .27732 L .56668 .29942 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.45707 .59169 m .45048 .58505 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.56668 .29942 m .49674 .28704 L .49971 .2651 L p
1 g
F P
s
P
p
.002 w
.39699 .51784 m .38531 .53805 L .35916 .51726 L p
1 g
F P
s
P
p
.002 w
.35916 .51726 m .37369 .49084 L .39699 .51784 L p
1 g
F P
s
P
p
.002 w
.5837 .54931 m .58544 .57164 L .55252 .57884 L p
1 g
F P
s
P
p
.002 w
.58544 .57164 m .5837 .54931 L .61369 .53148 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.51482 .58882 m .50852 .59472 L .48374 .58086 L p
1 g
F P
s
P
p
.002 w
.48553 .58087 m .51482 .58882 L p
.48374 .58086 L 1 g
F P
s
P
p
.002 w
.51482 .58882 m .48553 .58087 L p
.48949 .58097 L 1 g
F P
s
P
p
.002 w
.44729 .57756 m .44786 .57 L .47224 .57708 L p
1 g
F P
s
P
p
.002 w
.47224 .57708 m .48211 .57994 L .47629 .57954 L p
1 g
F P
s
P
p
.002 w
.47629 .57954 m .44729 .57756 L p
.47224 .57708 L 1 g
F P
s
P
p
.002 w
.44786 .57 m .41521 .55586 L p
.44955 .56267 L 1 g
F P
s
P
p
.44955 .56267 m .45063 .56353 L .44786 .57 L 1 g
F
P
p
.002 w
.45154 .56426 m .45138 .56451 L p
.45063 .56353 L 1 g
F P
s
P
p
.002 w
.45138 .56451 m .44786 .57 L p
.45063 .56353 L 1 g
F P
s
P
p
.002 w
.45063 .56353 m .45146 .56129 L p
.4442 .55499 L 1 g
F P
s
P
p
.002 w
.44801 .56013 m .44126 .55521 L p
.44006 .54938 L 1 g
F P
s
P
p
.002 w
.44126 .55521 m .42349 .54226 L p
.43906 .54895 L 1 g
F P
s
P
p
.43906 .54895 m .44006 .54938 L .44126 .55521 L 1 g
F
P
p
.002 w
.43844 .54719 m .43925 .54566 L p
.43482 .5369 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43844 .54719 L p
1 g
F P
s
P
p
.45146 .56129 m .43844 .54719 L .4442 .55499 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43856 .53159 m .45992 .55792 L p
.44006 .54938 L 1 g
F P
s
P
p
.002 w
.42349 .54226 m .43091 .537 L p
.44006 .54938 L 1 g
F P
s
P
p
.002 w
.42349 .54226 m .39699 .51784 L p
.43243 .52956 L 1 g
F P
s
P
p
.002 w
.43248 .52877 m .43346 .52734 L p
.43317 .51906 L 1 g
F P
s
P
p
.002 w
.43282 .52294 m .42975 .5183 L p
.43393 .51063 L 1 g
F P
s
P
p
.002 w
.42975 .5183 m .41883 .50182 L p
.4335 .51038 L 1 g
F P
s
P
p
.4335 .51038 m .43393 .51063 L .42975 .5183 L 1 g
F
P
p
.002 w
.43406 .5092 m .43485 .50826 L p
.43812 .50061 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43406 .5092 L p
1 g
F P
s
P
p
.43346 .52734 m .43406 .5092 L .43317 .51906 L 1 g
F
P
p
.002 w
.44858 .49207 m .45883 .52517 L p
.43393 .51063 L 1 g
F P
s
P
p
.002 w
.41883 .50182 m .4352 .49645 L p
.43393 .51063 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.41883 .50182 m .4015 .4697 L p
.44342 .48962 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44254 .49141 L p
1 g
F P
s
P
p
.43485 .50826 m .44254 .49141 L .44175 .49301 L 1 g
F
P
p
.43485 .50826 m .44241 .49154 L .43812 .50061 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44858 .49207 m .44099 .49456 L p
.44254 .49141 L 1 g
F P
s
P
p
.44407 .48993 m .44858 .49207 L .44254 .49141 L 1 g
F
P
p
.002 w
.44099 .49456 m .41883 .50182 L p
.44342 .48962 L 1 g
F P
s
P
p
.002 w
.44254 .49141 m .44241 .49154 L p
.44175 .49301 L 1 g
F P
s
P
p
.002 w
.4352 .49645 m .44099 .49456 L p
.43406 .5092 L 1 g
F P
s
P
p
.002 w
.44241 .49154 m .44166 .49233 L p
.43812 .50061 L 1 g
F P
s
P
p
.002 w
.44254 .49141 m .44339 .4905 L p
.45029 .48389 L 1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45782 .47656 m .48281 .48995 L .44728 .48682 L 1 g
F
P
p
.002 w
.45782 .47656 m .45826 .47608 L p
.46509 .47308 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46711 L p
1 g
F P
s
P
p
.45826 .47608 m .47759 .46711 L .46509 .47308 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47759 .46711 m .47786 .46667 L p
.48831 .46561 L 1 g
F P
s
P
p
.49293 .46488 m .51733 .49582 L .48369 .46634 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.54788 .50892 m .51733 .49582 L .52631 .4691 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54217 .47655 L p
1 g
F P
s
P
p
.52214 .46667 m .54217 .47655 L .53269 .47209 L 1 g
F
P
p
.53328 .47237 m .54788 .50892 L .52631 .4691 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56584 .50908 L p
1 g
F P
s
P
p
.56833 .47865 m .57037 .51865 L .56584 .50908 L 1 g
F
P
p
.002 w
.55839 .49336 m .56355 .48572 L p
.56584 .50908 L 1 g
F P
s
P
p
.002 w
.56355 .48572 m .56833 .47865 L p
.56584 .50908 L 1 g
F P
s
P
p
.002 w
.56584 .50908 m .56515 .50826 L p
.56683 .51913 L 1 g
F P
s
P
p
.55661 .4905 m .56584 .50908 L .56156 .50004 L 1 g
F
P
p
.55661 .4905 m .56692 .51037 L .56518 .50689 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56763 .52893 L p
1 g
F P
s
P
p
.002 w
.57083 .52754 m .56769 .52987 L p
.56763 .52893 L 1 g
F P
s
P
p
.002 w
.56738 .52474 m .56857 .52571 L p
.56763 .52893 L 1 g
F P
s
P
p
.002 w
.56857 .52571 m .57083 .52754 L p
.56763 .52893 L 1 g
F P
s
P
p
.002 w
.56763 .52893 m .56654 .52734 L p
.56463 .5378 L 1 g
F P
s
P
p
.57083 .52754 m .56418 .54321 L .56368 .54055 L 1 g
F
P
p
.56418 .54321 m .55654 .56122 L .56146 .54699 L 1 g
F
P
p
.56418 .54321 m .56146 .54699 L .56368 .54055 L 1 g
F
P
p
.002 w
.57083 .52754 m .5837 .54931 L .55654 .56122 L p
1 g
F P
s
P
p
.002 w
.56146 .54699 m .56075 .54566 L p
.55534 .55547 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56146 .54699 L p
1 g
F P
s
P
p
.002 w
.56146 .54699 m .56203 .54807 L p
.56363 .54069 L 1 g
F P
s
P
p
.56654 .52734 m .56146 .54699 L .56363 .54069 L 1 g
F
P
p
.002 w
.56726 .53019 m .57083 .52754 L p
.56368 .54055 L 1 g
F P
s
P
p
.56654 .52734 m .56203 .54807 L .56396 .54145 L 1 g
F
P
p
.56463 .5378 m .56726 .53019 L .56763 .52893 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54937 .56352 L p
1 g
F P
s
P
p
.56075 .54566 m .54937 .56352 L .54989 .56293 L 1 g
F
P
p
.002 w
.55098 .56366 m .54861 .56437 L p
.54937 .56352 L 1 g
F P
s
P
p
.002 w
.55027 .5625 m .55046 .56281 L p
.54937 .56352 L 1 g
F P
s
P
p
.002 w
.55046 .56281 m .55098 .56366 L p
.54937 .56352 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54854 .56129 L p
.54015 .56928 L 1 g
F P
s
P
p
.55098 .56366 m .53338 .57394 L .53727 .57107 L 1 g
F
P
p
.53338 .57394 m .52054 .58143 L .53169 .57453 L 1 g
F
P
p
.53338 .57394 m .53169 .57453 L .53727 .57107 L 1 g
F
P
p
.002 w
.55098 .56366 m .55252 .57884 L .52054 .58143 L p
1 g
F P
s
P
p
.002 w
.53169 .57453 m .53128 .57265 L p
.51897 .57896 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57453 L p
1 g
F P
s
P
p
.002 w
.54758 .56468 m .55098 .56366 L p
.53727 .57107 L 1 g
F P
s
P
p
.002 w
.53169 .57453 m .5322 .57686 L p
.54015 .56928 L 1 g
F P
s
P
p
.54854 .56129 m .53169 .57453 L .54015 .56928 L 1 g
F
P
p
.54015 .56928 m .54758 .56468 L .54937 .56352 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51767 .58166 m .51578 .58641 L p
.5 .58315 L 1 g
F P
s
P
p
.50837 .58143 m .5 .58315 L .48949 .58097 L 1 g
F
P
p
.51767 .58166 m .5 .58315 L .50837 .58143 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58089 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58089 L .51104 .58087 L 1 g
F
P
p
.002 w
.51767 .58166 m .50924 .58125 L p
.51096 .58089 L 1 g
F P
s
P
p
.002 w
.5174 .57951 m .51757 .58088 L p
.51096 .58089 L 1 g
F P
s
P
p
.002 w
.51757 .58088 m .51767 .58166 L p
.51096 .58089 L 1 g
F P
s
P
p
.51079 .57862 m .49944 .58089 L .50174 .58089 L 1 g
F
P
p
.002 w
.51096 .58089 m .51079 .57862 L p
.50174 .58089 L 1 g
F P
s
P
p
.5147 .58009 m .51096 .5809 L .51451 .58018 L 1 g
F
P
p
.53128 .57265 m .51104 .58087 L .5147 .58009 L 1 g
F
P
p
.51104 .58087 m .51096 .5809 L .5147 .58009 L 1 g
F
P
p
.002 w
.50174 .58089 m .51767 .58166 L p
.48553 .58087 L 1 g
F P
s
P
p
.53128 .57265 m .51102 .58174 L .51897 .57896 L 1 g
F
P
p
.002 w
.48904 .58088 m .48921 .57862 L p
.4769 .57761 L 1 g
F P
s
P
p
.002 w
.47961 .57855 m .48211 .57994 L p
.4695 .57538 L 1 g
F P
s
P
p
.44914 .56801 m .46829 .57463 L .4695 .57538 L 1 g
F
P
p
.46829 .57463 m .47961 .57855 L .4695 .57538 L 1 g
F
P
p
.002 w
.46829 .57463 m .46872 .57265 L p
.4585 .56857 L 1 g
F P
s
P
p
.4769 .57761 m .47705 .57766 L .48904 .58088 L 1 g
F
P
p
.47684 .5776 m .47741 .5778 L .48904 .58088 L 1 g
F
P
p
.47661 .57759 m .4777 .57794 L .48904 .58088 L 1 g
F
P
p
.47619 .57755 m .47801 .57811 L .48904 .58088 L 1 g
F
P
p
.002 w
.48126 .57911 m .48211 .57994 L .47961 .57855 L p
1 g
F P
s
P
p
.47556 .5775 m .47848 .57834 L .48904 .58088 L 1 g
F
P
p
.002 w
.41521 .55586 m .42349 .54226 L .42905 .54631 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45063 .56353 L p
1 g
F P
s
P
p
.4442 .55499 m .44801 .56013 L .45063 .56353 L 1 g
F
P
p
.002 w
.42905 .54631 m .45222 .5632 L p
.44955 .56267 L 1 g
F P
s
P
p
.41521 .55586 m .42905 .54631 L .44955 .56267 L 1 g
F
P
p
.002 w
.45063 .56353 m .45058 .56366 L p
.45115 .56394 L 1 g
F P
s
P
p
.46872 .57265 m .45063 .56353 L .45115 .56394 L 1 g
F
P
p
.002 w
.44914 .56801 m .45154 .56426 L p
.46829 .57463 L 1 g
F P
s
P
p
.002 w
.45058 .56366 m .45002 .56518 L p
.4585 .56857 L 1 g
F P
s
P
p
.46872 .57265 m .45058 .56366 L .4585 .56857 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48211 .57994 m .44786 .57 L .44914 .56801 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.45222 .5632 m .47961 .57855 L p
.46829 .57463 L 1 g
F P
s
P
p
.002 w
.45154 .56426 m .45222 .5632 L p
.46829 .57463 L 1 g
F P
s
P
p
.002 w
.46828 .57467 m .46829 .57463 L p
.45778 .56828 L 1 g
F P
s
P
p
.4585 .56857 m .45778 .56828 L .46829 .57463 L 1 g
F
P
p
.4769 .57761 m .47684 .5776 L .47705 .57766 L 1 g
F
P
p
.47471 .57743 m .47925 .57863 L .48904 .58088 L 1 g
F
P
p
.002 w
.48179 .57928 m .48211 .57994 L .48126 .57911 L p
1 g
F P
s
P
p
.47365 .57734 m .4805 .579 L .48904 .58088 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45222 .5632 m .45992 .55792 L .48126 .57911 L p
1 g
F P
s
P
p
.002 w
.47961 .57855 m .45222 .5632 L p
.48126 .57911 L 1 g
F P
s
P
p
.47684 .5776 m .47661 .57759 L .47741 .5778 L 1 g
F
P
p
.47661 .57759 m .47619 .57755 L .4777 .57794 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45992 .55792 m .47016 .55479 L .48179 .57928 L p
1 g
F P
s
P
p
.002 w
.48126 .57911 m .45992 .55792 L p
.48179 .57928 L 1 g
F P
s
P
p
.002 w
.4821 .57937 m .48211 .57994 L .48179 .57928 L p
1 g
F P
s
P
p
.002 w
.48234 .57944 m .48211 .57994 L .4821 .57937 L p
1 g
F P
s
P
p
.47249 .57725 m .48242 .57948 L .48904 .58088 L 1 g
F
P
p
.002 w
.47016 .55479 m .48178 .55416 L .4821 .57937 L p
1 g
F P
s
P
p
.002 w
.48179 .57928 m .47016 .55479 L p
.4821 .57937 L 1 g
F P
s
P
p
.47619 .57755 m .47556 .5775 L .47801 .57811 L 1 g
F
P
p
.47556 .5775 m .47471 .57743 L .47848 .57834 L 1 g
F
P
p
.002 w
.48178 .55416 m .49349 .55612 L .48234 .57944 L p
1 g
F P
s
P
p
.002 w
.4821 .57937 m .48178 .55416 L p
.48234 .57944 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49349 .55612 m .50394 .56045 L .48259 .57951 L p
1 g
F P
s
P
p
.002 w
.48259 .57951 m .48211 .57994 L .48234 .57944 L p
1 g
F P
s
P
p
.002 w
.48234 .57944 m .49349 .55612 L p
.48259 .57951 L 1 g
F P
s
P
p
.47471 .57743 m .47365 .57734 L .47925 .57863 L 1 g
F
P
p
.47365 .57734 m .47249 .57725 L .4805 .579 L 1 g
F
P
p
.002 w
.48291 .57959 m .48211 .57994 L .48259 .57951 L p
1 g
F P
s
P
p
.47146 .57716 m .48527 .5801 L .48904 .58088 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50394 .56045 m .51197 .56665 L .48291 .57959 L p
1 g
F P
s
P
p
.002 w
.48259 .57951 m .50394 .56045 L p
.48291 .57959 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .5809 L p
1 g
F P
s
P
p
.002 w
.51578 .58641 m .51482 .58882 L p
.48949 .58097 L 1 g
F P
s
P
p
.002 w
.48904 .5809 m .48889 .583 L p
.49942 .58089 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .5809 L .49942 .58089 L 1 g
F
P
p
.5174 .57951 m .51096 .58089 L .48527 .5801 L 1 g
F
P
p
.002 w
.50924 .58125 m .50174 .58089 L p
.51096 .58089 L 1 g
F P
s
P
p
.002 w
.50174 .58089 m .48527 .5801 L p
.51096 .58089 L 1 g
F P
s
P
p
.002 w
.51197 .56665 m .5167 .57399 L .48346 .57971 L p
1 g
F P
s
P
p
.002 w
.48346 .57971 m .48211 .57994 L .48291 .57959 L p
1 g
F P
s
P
p
.002 w
.48291 .57959 m .51197 .56665 L p
.48346 .57971 L 1 g
F P
s
P
p
.47249 .57725 m .47146 .57716 L .48242 .57948 L 1 g
F
P
p
.002 w
.5167 .57399 m .5174 .57951 L p
.48442 .57992 L 1 g
F P
s
P
p
.002 w
.48211 .57994 m .48346 .57971 L p
.48442 .57992 L 1 g
F P
s
P
p
.002 w
.48346 .57971 m .5167 .57399 L p
.48442 .57992 L 1 g
F P
s
P
p
.002 w
.48527 .5801 m .48211 .57994 L p
.48442 .57992 L 1 g
F P
s
P
p
.002 w
.48553 .58087 m .48211 .57994 L .48527 .5801 L p
1 g
F P
s
P
p
.002 w
.48527 .5801 m .50174 .58089 L p
.48904 .58088 L 1 g
F P
s
P
p
.48904 .58088 m .48553 .58087 L .48527 .5801 L 1 g
F
P
p
.002 w
.48374 .58086 m .48211 .57994 L .48553 .58087 L p
1 g
F P
s
P
p
.002 w
.45048 .58505 m .44729 .57756 L .48211 .57994 L closepath p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .5809 L p
1 g
F P
s
P
p
.002 w
.48904 .5809 m .48904 .58088 L p
.48818 .58071 L 1 g
F P
s
P
p
.48818 .58071 m .4678 .57686 L .48904 .5809 L 1 g
F
P
p
.47146 .57716 m .47087 .57711 L .48527 .5801 L 1 g
F
P
p
.5174 .57951 m .48527 .5801 L .48442 .57992 L 1 g
F
P
p
.002 w
.51096 .5809 m .51096 .58089 L p
.50174 .58089 L 1 g
F P
s
P
p
.002 w
.51096 .58089 m .51096 .5809 L p
.51104 .58087 L 1 g
F P
s
P
p
.002 w
.51096 .5809 m .51102 .58174 L p
.51451 .58018 L 1 g
F P
s
P
p
.002 w
.51767 .58166 m .5174 .57951 L p
.52793 .57584 L 1 g
F P
s
P
p
.002 w
.51102 .58174 m .51111 .583 L p
.51897 .57896 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.5167 .57399 m .54758 .56468 L p
.52793 .57584 L 1 g
F P
s
P
p
.002 w
.5174 .57951 m .5167 .57399 L p
.52793 .57584 L 1 g
F P
s
P
p
.53727 .57107 m .51767 .58166 L .54758 .56468 L 1 g
F
P
p
.002 w
.52054 .58143 m .51767 .58166 L p
.53727 .57107 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53169 .57453 L p
1 g
F P
s
P
p
.51897 .57896 m .51111 .583 L .53169 .57453 L 1 g
F
P
p
.54015 .56928 m .53937 .57003 L .54758 .56468 L 1 g
F
P
p
.56075 .54566 m .54989 .56293 L .55534 .55547 L 1 g
F
P
p
.54989 .56293 m .54942 .56367 L .55027 .5625 L 1 g
F
P
p
.54989 .56293 m .55027 .5625 L .55534 .55547 L 1 g
F
P
p
.002 w
.54861 .56437 m .5167 .57399 L p
.55027 .5625 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54937 .56352 L p
1 g
F P
s
P
p
.53937 .57003 m .5322 .57686 L .54937 .56352 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54191 .54898 m .55027 .5625 L p
.5167 .57399 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54942 .56367 L p
.54989 .56293 L 1 g
F P
s
P
p
.002 w
.55098 .56366 m .55027 .5625 L p
.55419 .55707 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56368 .54055 m .55098 .56366 L .56726 .53019 L 1 g
F
P
p
.002 w
.54942 .56367 m .54998 .56518 L p
.55534 .55547 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.54191 .54898 m .56726 .53019 L p
.55419 .55707 L 1 g
F P
s
P
p
.002 w
.55027 .5625 m .54191 .54898 L p
.55419 .55707 L 1 g
F P
s
P
p
.56515 .50826 m .56763 .52893 L .56749 .52668 L 1 g
F
P
p
.56515 .50826 m .56781 .52919 L .56683 .51913 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56738 .52474 m .56763 .52893 L .54191 .54898 L 1 g
F
P
p
.002 w
.56769 .52987 m .56726 .53019 L p
.56763 .52893 L 1 g
F P
s
P
p
.002 w
.56726 .53019 m .54191 .54898 L p
.56763 .52893 L 1 g
F P
s
P
p
.002 w
.56203 .54807 m .56257 .5491 L p
.56396 .54145 L 1 g
F P
s
P
p
.002 w
.55654 .56122 m .55098 .56366 L p
.56368 .54055 L 1 g
F P
s
P
p
.002 w
.55252 .57884 m .55098 .56366 L .5837 .54931 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56146 .54699 L p
1 g
F P
s
P
p
.55534 .55547 m .54998 .56518 L .56146 .54699 L 1 g
F
P
p
.56463 .5378 m .56396 .54145 L .56726 .53019 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56763 .52893 L p
1 g
F P
s
P
p
.56396 .54145 m .56257 .5491 L .56763 .52893 L 1 g
F
P
p
.002 w
.56763 .52893 m .56781 .52919 L p
.56749 .52668 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54788 .50892 m .56738 .52474 L p
.54191 .54898 L 1 g
F P
s
P
p
.002 w
.56311 .48638 m .55882 .49272 L p
.55237 .48134 L 1 g
F P
s
P
p
.002 w
.55882 .49272 m .55839 .49336 L p
.55737 .49131 L 1 g
F P
s
P
p
.55237 .48134 m .55882 .49272 L .55737 .49131 L 1 g
F
P
p
.002 w
.55676 .4908 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .55677 .49082 L p
.56713 .51061 L 1 g
F P
s
P
p
.54217 .47655 m .55165 .48576 L .54788 .50892 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55737 .49131 L p
1 g
F P
s
P
p
.54174 .47608 m .55737 .49131 L .54797 .48218 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55839 .49336 m .54788 .50892 L p
.55237 .48134 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54217 .47655 L p
1 g
F P
s
P
p
.002 w
.54217 .47655 m .54174 .47608 L p
.54797 .48218 L 1 g
F P
s
P
p
.54797 .48218 m .55834 .49233 L .54217 .47655 L 1 g
F
P
p
.002 w
.54788 .50892 m .55839 .49336 L p
.56648 .51558 L 1 g
F P
s
P
p
.002 w
.57083 .52754 m .56738 .52474 L p
.56648 .51558 L 1 g
F P
s
P
p
.002 w
.56738 .52474 m .54788 .50892 L p
.56648 .51558 L 1 g
F P
s
P
p
.002 w
.56781 .52919 m .56854 .53025 L p
.56683 .51913 L 1 g
F P
s
P
p
.57037 .51865 m .57083 .52754 L .55839 .49336 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56584 .50908 L p
1 g
F P
s
P
p
.56683 .51913 m .56854 .53025 L .56584 .50908 L 1 g
F
P
p
.002 w
.56584 .50908 m .56692 .51037 L p
.56156 .50004 L 1 g
F P
s
P
p
.002 w
.55737 .49131 m .55834 .49233 L p
.54797 .48218 L 1 g
F P
s
P
p
.53328 .47237 m .54217 .47655 L .54788 .50892 L 1 g
F
P
p
.54217 .47655 m .55237 .48134 L .55165 .48576 L 1 g
F
P
p
.002 w
.56692 .51037 m .56713 .51061 L p
.56518 .50689 L 1 g
F P
s
P
p
.53191 .47173 m .54289 .47734 L .53932 .47556 L 1 g
F
P
p
.52214 .46667 m .53269 .47209 L .53191 .47173 L 1 g
F
P
p
.53269 .47209 m .54289 .47734 L .53191 .47173 L 1 g
F
P
p
.002 w
.5289 .46141 m .56833 .47865 L .56311 .48638 L p
1 g
F P
s
P
p
.5289 .46141 m .56311 .48638 L .53328 .47237 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52631 .4691 m .51733 .49582 L p
.5141 .46591 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46718 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46718 L .50894 .46512 L 1 g
F
P
p
.51378 .46287 m .52245 .46718 L .5141 .46591 L 1 g
F
P
p
.52245 .46718 m .52631 .4691 L .5141 .46591 L 1 g
F
P
p
.49293 .46488 m .50176 .46403 L .51733 .49582 L 1 g
F
P
p
.002 w
.5 .46376 m .5 .4634 L p
.50894 .46512 L 1 g
F P
s
P
p
.50176 .46403 m .51378 .46287 L .5141 .46591 L 1 g
F
P
p
.50176 .46403 m .5141 .46591 L .51733 .49582 L 1 g
F
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.52213 .46026 m .5289 .46141 L p
.49293 .46488 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46376 L p
1 g
F P
s
P
p
.50894 .46512 m .52282 .46778 L .5 .46376 L 1 g
F
P
p
.002 w
.52245 .46718 m .52282 .46778 L p
.50894 .46512 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52631 .4691 m .5289 .46141 L p
.53328 .47237 L 1 g
F P
s
P
p
.002 w
.54217 .47655 m .54289 .47734 L p
.53269 .47209 L 1 g
F P
s
P
p
.002 w
.54289 .47734 m .54302 .47747 L p
.53932 .47556 L 1 g
F P
s
P
p
.002 w
.5289 .46141 m .52631 .4691 L p
.51378 .46287 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.48416 .45375 m .52213 .46026 L p
.49293 .46488 L 1 g
F P
s
P
p
.002 w
.51733 .49582 m .48281 .48995 L .48369 .46634 L p
1 g
F P
s
P
p
.002 w
.48369 .46634 m .48281 .48995 L p
.45672 .46976 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47759 .46711 L p
.48262 .46651 L 1 g
F P
s
P
p
.48262 .46651 m .5 .46442 L .47747 .46732 L 1 g
F
P
p
.48831 .46561 m .49406 .46502 L .48369 .46634 L 1 g
F
P
p
.48831 .46561 m .48369 .46634 L .47759 .46711 L 1 g
F
P
p
.002 w
.48369 .46634 m .48416 .45375 L p
.49293 .46488 L 1 g
F P
s
P
p
.002 w
.43982 .45669 m .48416 .45375 L .48369 .46634 L p
1 g
F P
s
P
p
.43982 .45669 m .48369 .46634 L .45672 .46976 L 1 g
F
P
p
.49406 .46502 m .5 .46442 L .47759 .46711 L 1 g
F
P
p
.002 w
.47759 .46711 m .47718 .46778 L p
.46509 .47308 L 1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4573 .47712 L p
1 g
F P
s
P
p
.44339 .4905 m .4573 .47712 L .45241 .48186 L 1 g
F
P
p
.45029 .48389 m .44728 .48682 L .44254 .49141 L 1 g
F
P
p
.002 w
.4015 .4697 m .43982 .45669 L .44728 .48682 L p
1 g
F P
s
P
p
.002 w
.44728 .48682 m .44858 .49207 L p
.44407 .48993 L 1 g
F P
s
P
p
.4015 .4697 m .44728 .48682 L .44407 .48993 L 1 g
F
P
p
.002 w
.4573 .47712 m .45698 .47747 L p
.45241 .48186 L 1 g
F P
s
P
p
.43982 .45669 m .46122 .47325 L .45782 .47656 L 1 g
F
P
p
.002 w
.44728 .48682 m .44612 .48215 L p
.45782 .47656 L 1 g
F P
s
P
p
.002 w
.44612 .48215 m .43982 .45669 L p
.45782 .47656 L 1 g
F P
s
P
p
.46122 .47325 m .46257 .47429 L .45782 .47656 L 1 g
F
P
p
.46257 .47429 m .48281 .48995 L .45782 .47656 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45782 .47656 L p
1 g
F P
s
P
p
.46509 .47308 m .47718 .46778 L .45782 .47656 L 1 g
F
P
p
.45029 .48389 m .45241 .48186 L .44728 .48682 L 1 g
F
P
p
.002 w
.48281 .48995 m .44858 .49207 L .44728 .48682 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44254 .49141 L p
1 g
F P
s
P
p
.45241 .48186 m .45698 .47747 L .44254 .49141 L 1 g
F
P
p
.44342 .48962 m .44407 .48993 L .44254 .49141 L 1 g
F
P
p
.43406 .5092 m .44858 .49207 L .43393 .51063 L 1 g
F
P
p
.002 w
.44099 .49456 m .44858 .49207 L p
.43406 .5092 L 1 g
F P
s
P
p
.002 w
.43406 .5092 m .43287 .51061 L p
.43317 .51906 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43406 .5092 L p
1 g
F P
s
P
p
.43812 .50061 m .44166 .49233 L .43406 .5092 L 1 g
F
P
p
.43317 .51906 m .43313 .51782 L .43282 .52294 L 1 g
F
P
p
.43317 .51906 m .43282 .52294 L .43248 .52877 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.45883 .52517 m .43856 .53159 L .43282 .52294 L p
1 g
F P
s
P
p
.43393 .51063 m .45883 .52517 L .43282 .52294 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43248 .52877 L p
1 g
F P
s
P
p
.43925 .54566 m .43248 .52877 L .43336 .53207 L 1 g
F
P
p
.002 w
.39699 .51784 m .41883 .50182 L .42966 .51816 L p
1 g
F P
s
P
p
.002 w
.42966 .51816 m .43856 .53159 L p
.43271 .52965 L 1 g
F P
s
P
p
.39699 .51784 m .42966 .51816 L .43271 .52965 L 1 g
F
P
p
.43243 .52956 m .4324 .53008 L .42349 .54226 L 1 g
F
P
p
.002 w
.43407 .53476 m .42349 .54226 L p
.43271 .52965 L 1 g
F P
s
P
p
.002 w
.43091 .537 m .43407 .53476 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.43214 .52927 m .43146 .53025 L p
.43444 .53614 L 1 g
F P
s
P
p
.43482 .5369 m .43407 .53476 L .43444 .53614 L 1 g
F
P
p
.43407 .53476 m .43214 .52927 L .43444 .53614 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43248 .52877 L p
1 g
F P
s
P
p
.43313 .51782 m .43287 .51061 L .43248 .52877 L 1 g
F
P
p
.43243 .52956 m .43271 .52965 L .4324 .53008 L 1 g
F
P
p
.43925 .54566 m .43214 .52927 L .43482 .5369 L 1 g
F
P
p
.002 w
.43856 .53159 m .43407 .53476 L p
.43271 .52965 L 1 g
F P
s
P
p
.002 w
.43248 .52877 m .43214 .52927 L p
.43336 .53207 L 1 g
F P
s
P
p
.43844 .54719 m .43856 .53159 L .44006 .54938 L 1 g
F
P
p
.002 w
.43407 .53476 m .43856 .53159 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.43844 .54719 m .43743 .5491 L p
.4442 .55499 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43844 .54719 L p
1 g
F P
s
P
p
.43482 .5369 m .43146 .53025 L .43844 .54719 L 1 g
F
P
p
.4442 .55499 m .44371 .55456 L .44801 .56013 L 1 g
F
P
p
.002 w
.45992 .55792 m .45222 .5632 L .44801 .56013 L p
1 g
F P
s
P
p
.44006 .54938 m .45992 .55792 L .44801 .56013 L 1 g
F
P
p
.002 w
.45222 .5632 m .45154 .56426 L p
.44955 .56267 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45063 .56353 L p
1 g
F P
s
P
p
.44371 .55456 m .43743 .5491 L .45063 .56353 L 1 g
F
P
p
.002 w
.4678 .57686 m .46828 .57467 L p
.4577 .56917 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .46518 .57514 L p
.4577 .56917 L 1 g
F P
s
P
p
.002 w
.46518 .57514 m .4678 .57686 L p
.4577 .56917 L 1 g
F P
s
P
p
.45778 .56828 m .45002 .56518 L .46828 .57467 L 1 g
F
P
p
.47087 .57711 m .4678 .57686 L .48904 .58088 L 1 g
F
P
p
.002 w
.51098 .58111 m .51096 .5809 L p
.49889 .581 L 1 g
F P
s
P
p
.49944 .58089 m .49889 .581 L .51096 .5809 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58111 L p
1 g
F P
s
P
p
.49889 .581 m .48889 .583 L .51098 .58111 L 1 g
F
P
p
.002 w
.44786 .57 m .44729 .57756 L .41443 .57082 L p
1 g
F P
s
P
p
.002 w
.41443 .57082 m .41521 .55586 L .44786 .57 L p
1 g
F P
s
P
p
.002 w
.56668 .29942 m .62757 .32833 L .62295 .35443 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.62133 .47652 m .63991 .51085 L .61369 .53148 L p
1 g
F P
s
P
p
.002 w
.63991 .51085 m .62133 .47652 L .64109 .44887 L p
1 g
F P
s
P
p
.002 w
.38723 .43644 m .3544 .46226 L .33974 .43315 L p
1 g
F P
s
P
p
.002 w
.33974 .43315 m .37654 .40329 L .38723 .43644 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.42561 .35064 m .36975 .37148 L .36701 .34213 L p
1 g
F P
s
P
p
.002 w
.36701 .34213 m .4254 .31978 L .42561 .35064 L p
1 g
F P
s
P
p
.002 w
.51482 .58882 m .51767 .58166 L .55252 .57884 L p
1 g
F P
s
P
p
.002 w
.42349 .54226 m .41521 .55586 L .38531 .53805 L p
1 g
F P
s
P
p
.002 w
.38531 .53805 m .39699 .51784 L .42349 .54226 L p
1 g
F P
s
P
p
.002 w
.61444 .38357 m .65627 .42115 L .64109 .44887 L p
1 g
F P
s
P
p
.002 w
.65627 .42115 m .61444 .38357 L .62295 .35443 L p
1 g
F P
s
P
p
.002 w
.49377 .31408 m .4254 .31978 L .42744 .29304 L p
1 g
F P
s
P
p
.002 w
.42744 .29304 m .49674 .28704 L .49377 .31408 L p
1 g
F P
s
P
p
.002 w
.59763 .50308 m .61369 .53148 L .5837 .54931 L p
1 g
F P
s
P
p
.002 w
.61369 .53148 m .59763 .50308 L .62133 .47652 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.4015 .4697 m .37369 .49084 L .3544 .46226 L p
1 g
F P
s
P
p
.002 w
.3544 .46226 m .38723 .43644 L .4015 .4697 L p
1 g
F P
s
P
p
.002 w
.62295 .35443 m .5628 .32624 L .56668 .29942 L p
1 g
F P
s
P
p
.002 w
.49674 .28704 m .56668 .29942 L .5628 .32624 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.5837 .54931 m .57083 .52754 L .59763 .50308 L p
1 g
F P
s
P
p
.002 w
.5628 .32624 m .62295 .35443 L .61444 .38357 L p
1 g
F P
s
P
p
.002 w
.5167 .57399 m .51197 .56665 L .54191 .54898 L p
1 g
F P
s
P
p
.002 w
.5628 .32624 m .49377 .31408 L .49674 .28704 L p
1 g
F P
s
P
p
.002 w
.42812 .38459 m .37654 .40329 L .36975 .37148 L p
1 g
F P
s
P
p
.002 w
.36975 .37148 m .42561 .35064 L .42812 .38459 L p
1 g
F P
s
P
p
.002 w
.60223 .41475 m .64109 .44887 L .62133 .47652 L p
1 g
F P
s
P
p
.002 w
.64109 .44887 m .60223 .41475 L .61444 .38357 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41883 .50182 m .39699 .51784 L .37369 .49084 L p
1 g
F P
s
P
p
.002 w
.37369 .49084 m .4015 .4697 L .41883 .50182 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51197 .56665 m .50394 .56045 L .52614 .53652 L p
1 g
F P
s
P
p
.002 w
.52614 .53652 m .54191 .54898 L .51197 .56665 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.47016 .55479 m .45992 .55792 L .43856 .53159 L p
1 g
F P
s
P
p
.002 w
.49091 .34545 m .42561 .35064 L .4254 .31978 L p
1 g
F P
s
P
p
.002 w
.4254 .31978 m .49377 .31408 L .49091 .34545 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.50394 .56045 m .49349 .55612 L .50537 .52777 L p
1 g
F P
s
P
p
.002 w
.50537 .52777 m .52614 .53652 L .50394 .56045 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58667 .44685 m .62133 .47652 L .59763 .50308 L p
1 g
F P
s
P
p
.002 w
.62133 .47652 m .58667 .44685 L .60223 .41475 L p
1 g
F P
s
P
p
.002 w
.48178 .55416 m .47016 .55479 L .45883 .52517 L p
1 g
F P
s
P
p
.002 w
.43856 .53159 m .45883 .52517 L .47016 .55479 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43291 .4204 m .38723 .43644 L .37654 .40329 L p
1 g
F P
s
P
p
.002 w
.37654 .40329 m .42812 .38459 L .43291 .4204 L p
1 g
F P
s
P
p
.002 w
.49349 .55612 m .48178 .55416 L .48201 .52383 L p
1 g
F P
s
P
p
.002 w
.48201 .52383 m .50537 .52777 L .49349 .55612 L p
1 g
F P
s
P
p
.002 w
.54191 .54898 m .52614 .53652 L .54788 .50892 L p
1 g
F P
s
P
p
.002 w
.45883 .52517 m .48201 .52383 L .48178 .55416 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55687 .35698 m .61444 .38357 L .60223 .41475 L p
1 g
F P
s
P
p
.002 w
.61444 .38357 m .55687 .35698 L .5628 .32624 L p
1 g
F P
s
P
p
.002 w
.49377 .31408 m .5628 .32624 L .55687 .35698 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.56833 .47865 m .59763 .50308 L .57083 .52754 L p
1 g
F P
s
P
p
.002 w
.59763 .50308 m .56833 .47865 L .58667 .44685 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55687 .35698 m .49091 .34545 L .49377 .31408 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43982 .45669 m .4015 .4697 L .38723 .43644 L p
1 g
F P
s
P
p
.002 w
.38723 .43644 m .43291 .4204 L .43982 .45669 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.52614 .53652 m .50537 .52777 L .51733 .49582 L p
1 g
F P
s
P
p
.002 w
.51733 .49582 m .54788 .50892 L .52614 .53652 L p
1 g
F P
s
P
p
.002 w
.48829 .38006 m .42812 .38459 L .42561 .35064 L p
1 g
F P
s
P
p
.002 w
.42561 .35064 m .49091 .34545 L .48829 .38006 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54906 .39062 m .60223 .41475 L .58667 .44685 L p
1 g
F P
s
P
p
.002 w
.60223 .41475 m .54906 .39062 L .55687 .35698 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.48201 .52383 m .45883 .52517 L .44858 .49207 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50537 .52777 m .48201 .52383 L .48281 .48995 L p
1 g
F P
s
P
p
.002 w
.48281 .48995 m .51733 .49582 L .50537 .52777 L p
1 g
F P
s
P
p
.002 w
.44858 .49207 m .48281 .48995 L .48201 .52383 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.49091 .34545 m .55687 .35698 L .54906 .39062 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.004 w
.47483 .64069 m
.4761 .63014 L
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53961 .42588 m .58667 .44685 L .56833 .47865 L p
1 g
F P
s
P
p
.002 w
.58667 .44685 m .53961 .42588 L .54906 .39062 L p
1 g
F P
s
P
p
.002 w
.54906 .39062 m .48829 .38006 L .49091 .34545 L p
1 g
F P
s
P
p
.002 w
.48601 .41663 m .43291 .4204 L .42812 .38459 L p
1 g
F P
s
P
p
.002 w
.42812 .38459 m .48829 .38006 L .48601 .41663 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56833 .47865 m .5289 .46141 L .53961 .42588 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48416 .45375 m .43982 .45669 L .43291 .4204 L p
1 g
F P
s
P
p
.002 w
.43291 .4204 m .48601 .41663 L .48416 .45375 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.48829 .38006 m .54906 .39062 L .53961 .42588 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53961 .42588 m .48601 .41663 L .48829 .38006 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.5289 .46141 m .48416 .45375 L .48601 .41663 L p
1 g
F P
s
P
p
.002 w
.48601 .41663 m .53961 .42588 L .5289 .46141 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .69784 .65519 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .47168 .66698 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0221053)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0221053)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46405 .43268 m .50332 .44721 L .50991 .41941 L p
1 g
F P
s
P
p
.002 w
.50991 .41941 m .47715 .40724 L .46405 .43268 L p
1 g
F P
s
P
p
.002 w
.54444 .42314 m .50991 .41941 L .50332 .44721 L p
1 g
F P
s
P
p
.002 w
.47715 .40724 m .50991 .41941 L .51628 .39179 L p
1 g
F P
s
P
p
.002 w
.50991 .41941 m .54444 .42314 L .54312 .39461 L p
1 g
F P
s
P
p
.002 w
.54312 .39461 m .51628 .39179 L .50991 .41941 L p
1 g
F P
s
P
p
.002 w
.45177 .45818 m .49662 .4747 L .50332 .44721 L p
1 g
F P
s
P
p
.002 w
.50332 .44721 m .46405 .43268 L .45177 .45818 L p
1 g
F P
s
P
p
.002 w
.54469 .4518 m .50332 .44721 L .49662 .4747 L p
1 g
F P
s
P
p
.002 w
.50332 .44721 m .54469 .4518 L .54444 .42314 L p
1 g
F P
s
P
p
.002 w
.43046 .40949 m .46405 .43268 L .47715 .40724 L p
1 g
F P
s
P
p
.002 w
.47715 .40724 m .44925 .38774 L .43046 .40949 L p
1 g
F P
s
P
p
.002 w
.44925 .38774 m .47715 .40724 L .49084 .3823 L p
1 g
F P
s
P
p
.002 w
.51628 .39179 m .49084 .3823 L .47715 .40724 L p
1 g
F P
s
P
p
.002 w
.41325 .43189 m .45177 .45818 L .46405 .43268 L p
1 g
F P
s
P
p
.002 w
.46405 .43268 m .43046 .40949 L .41325 .43189 L p
1 g
F P
s
P
p
.002 w
.49084 .3823 m .51628 .39179 L .52231 .36486 L p
1 g
F P
s
P
p
.002 w
.51628 .39179 m .54312 .39461 L .54073 .36675 L p
1 g
F P
s
P
p
.002 w
.54073 .36675 m .52231 .36486 L .51628 .39179 L p
1 g
F P
s
P
p
.002 w
.44053 .48326 m .48994 .50139 L .49662 .4747 L p
1 g
F P
s
P
p
.002 w
.49662 .4747 m .45177 .45818 L .44053 .48326 L p
1 g
F P
s
P
p
.002 w
.54385 .48009 m .49662 .4747 L .48994 .50139 L p
1 g
F P
s
P
p
.002 w
.49662 .4747 m .54385 .48009 L .54469 .4518 L p
1 g
F P
s
P
p
.002 w
.57751 .418 m .54444 .42314 L .54469 .4518 L p
1 g
F P
s
P
p
.002 w
.54444 .42314 m .57751 .418 L .56874 .39044 L p
1 g
F P
s
P
p
.002 w
.56874 .39044 m .54312 .39461 L .54444 .42314 L p
1 g
F P
s
P
p
.002 w
.49084 .3823 m .46926 .36704 L .44925 .38774 L p
1 g
F P
s
P
p
.002 w
.46926 .36704 m .49084 .3823 L .50486 .35833 L p
1 g
F P
s
P
p
.002 w
.52231 .36486 m .50486 .35833 L .49084 .3823 L p
1 g
F P
s
P
p
.002 w
.5844 .44592 m .54469 .4518 L .54385 .48009 L p
1 g
F P
s
P
p
.002 w
.54469 .4518 m .5844 .44592 L .57751 .418 L p
1 g
F P
s
P
p
.002 w
.39797 .45454 m .44053 .48326 L .45177 .45818 L p
1 g
F P
s
P
p
.002 w
.45177 .45818 m .41325 .43189 L .39797 .45454 L p
1 g
F P
s
P
p
.002 w
.54312 .39461 m .56874 .39044 L .55826 .36377 L p
1 g
F P
s
P
p
.002 w
.55826 .36377 m .54073 .36675 L .54312 .39461 L p
1 g
F P
s
P
p
.002 w
.48994 .50139 m .54192 .50746 L .54385 .48009 L p
1 g
F P
s
P
p
.002 w
.58927 .47369 m .54385 .48009 L .54192 .50746 L p
1 g
F P
s
P
p
.002 w
.54385 .48009 m .58927 .47369 L .5844 .44592 L p
1 g
F P
s
P
p
.002 w
.40582 .37958 m .43046 .40949 L .44925 .38774 L p
1 g
F P
s
P
p
.002 w
.44925 .38774 m .42897 .36262 L .40582 .37958 L p
1 g
F P
s
P
p
.002 w
.42897 .36262 m .44925 .38774 L .46926 .36704 L p
1 g
F P
s
P
p
.002 w
.50486 .35833 m .52231 .36486 L .52789 .33913 L p
1 g
F P
s
P
p
.002 w
.52231 .36486 m .54073 .36675 L .53731 .34007 L p
1 g
F P
s
P
p
.002 w
.53731 .34007 m .52789 .33913 L .52231 .36486 L p
1 g
F P
s
P
p
.002 w
.46926 .36704 m .45374 .34743 L .42897 .36262 L p
1 g
F P
s
P
p
.002 w
.45374 .34743 m .46926 .36704 L .49013 .34779 L p
1 g
F P
s
P
p
.002 w
.50486 .35833 m .49013 .34779 L .46926 .36704 L p
1 g
F P
s
P
p
.002 w
.43058 .50745 m .48341 .52676 L .48994 .50139 L p
1 g
F P
s
P
p
.002 w
.48994 .50139 m .44053 .48326 L .43058 .50745 L p
1 g
F P
s
P
p
.002 w
.54192 .50746 m .48994 .50139 L .48341 .52676 L p
1 g
F P
s
P
p
.002 w
.49013 .34779 m .50486 .35833 L .51897 .33578 L p
1 g
F P
s
P
p
.002 w
.52789 .33913 m .51897 .33578 L .50486 .35833 L p
1 g
F P
s
P
p
.002 w
.38476 .39798 m .41325 .43189 L .43046 .40949 L p
1 g
F P
s
P
p
.002 w
.43046 .40949 m .40582 .37958 L .38476 .39798 L p
1 g
F P
s
P
p
.002 w
.54073 .36675 m .55826 .36377 L .54624 .33849 L p
1 g
F P
s
P
p
.002 w
.54624 .33849 m .53731 .34007 L .54073 .36675 L p
1 g
F P
s
P
p
.002 w
.60588 .40426 m .57751 .418 L .5844 .44592 L p
1 g
F P
s
P
p
.002 w
.57751 .418 m .60588 .40426 L .59059 .37956 L p
1 g
F P
s
P
p
.002 w
.59059 .37956 m .56874 .39044 L .57751 .418 L p
1 g
F P
s
P
p
.002 w
.38496 .477 m .43058 .50745 L .44053 .48326 L p
1 g
F P
s
P
p
.002 w
.44053 .48326 m .39797 .45454 L .38496 .477 L p
1 g
F P
s
P
p
.002 w
.56874 .39044 m .59059 .37956 L .57309 .35616 L p
1 g
F P
s
P
p
.002 w
.57309 .35616 m .55826 .36377 L .56874 .39044 L p
1 g
F P
s
P
p
.002 w
.49013 .34779 m .47965 .33428 L .45374 .34743 L p
1 g
F P
s
P
p
.002 w
.47965 .33428 m .49013 .34779 L .51148 .33036 L p
1 g
F P
s
P
p
.002 w
.51897 .33578 m .51148 .33036 L .49013 .34779 L p
1 g
F P
s
P
p
.002 w
.61866 .42981 m .5844 .44592 L .58927 .47369 L p
1 g
F P
s
P
p
.002 w
.5844 .44592 m .61866 .42981 L .60588 .40426 L p
1 g
F P
s
P
p
.002 w
.36626 .41749 m .39797 .45454 L .41325 .43189 L p
1 g
F P
s
P
p
.002 w
.41325 .43189 m .38476 .39798 L .36626 .41749 L p
1 g
F P
s
P
p
.002 w
.48341 .52676 m .53893 .5334 L .54192 .50746 L p
1 g
F P
s
P
p
.002 w
.59199 .50076 m .54192 .50746 L .53893 .5334 L p
1 g
F P
s
P
p
.002 w
.54192 .50746 m .59199 .50076 L .58927 .47369 L p
1 g
F P
s
P
p
.002 w
.55826 .36377 m .57309 .35616 L .55374 .33454 L p
1 g
F P
s
P
p
.002 w
.55374 .33454 m .54624 .33849 L .55826 .36377 L p
1 g
F P
s
P
p
.002 w
.41857 .3342 m .42897 .36262 L .45374 .34743 L p
1 g
F P
s
P
p
.002 w
.45374 .34743 m .446 .32534 L .41857 .3342 L p
1 g
F P
s
P
p
.002 w
.446 .32534 m .45374 .34743 L .47965 .33428 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .51897 .33578 L .52789 .33913 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .52789 .33913 L .53731 .34007 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .51148 .33036 L .51897 .33578 L closepath p
1 g
F P
s
P
p
.002 w
.42215 .53025 m .47714 .55029 L .48341 .52676 L p
1 g
F P
s
P
p
.002 w
.48341 .52676 m .43058 .50745 L .42215 .53025 L p
1 g
F P
s
P
p
.002 w
.53893 .5334 m .48341 .52676 L .47714 .55029 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .53731 .34007 L .54624 .33849 L closepath p
1 g
F P
s
P
p
.002 w
.39286 .34559 m .40582 .37958 L .42897 .36262 L p
1 g
F P
s
P
p
.002 w
.42897 .36262 m .41857 .3342 L .39286 .34559 L p
1 g
F P
s
P
p
.002 w
.47965 .33428 m .47458 .31914 L .446 .32534 L p
1 g
F P
s
P
p
.002 w
.47458 .31914 m .47965 .33428 L .50621 .32343 L p
1 g
F P
s
P
p
.002 w
.51148 .33036 m .50621 .32343 L .47965 .33428 L p
1 g
F P
s
P
p
.002 w
.62863 .45569 m .58927 .47369 L .59199 .50076 L p
1 g
F P
s
P
p
.002 w
.58927 .47369 m .62863 .45569 L .61866 .42981 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .50621 .32343 L .51148 .33036 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .54624 .33849 L .55374 .33454 L closepath p
1 g
F P
s
P
p
.002 w
.37454 .49881 m .42215 .53025 L .43058 .50745 L p
1 g
F P
s
P
p
.002 w
.43058 .50745 m .38496 .477 L .37454 .49881 L p
1 g
F P
s
P
p
.002 w
.60631 .36288 m .59059 .37956 L .60588 .40426 L p
1 g
F P
s
P
p
.002 w
.59059 .37956 m .60631 .36288 L .58364 .34464 L p
1 g
F P
s
P
p
.002 w
.58364 .34464 m .57309 .35616 L .59059 .37956 L p
1 g
F P
s
P
p
.002 w
.57309 .35616 m .58364 .34464 L .559 .32862 L p
1 g
F P
s
P
p
.002 w
.559 .32862 m .55374 .33454 L .57309 .35616 L p
1 g
F P
s
P
p
.002 w
.35076 .43773 m .38496 .477 L .39797 .45454 L p
1 g
F P
s
P
p
.002 w
.39797 .45454 m .36626 .41749 L .35076 .43773 L p
1 g
F P
s
P
p
.002 w
.36946 .35932 m .38476 .39798 L .40582 .37958 L p
1 g
F P
s
P
p
.002 w
.40582 .37958 m .39286 .34559 L .36946 .35932 L p
1 g
F P
s
P
p
.002 w
.50621 .32343 m .50374 .31571 L .47458 .31914 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .50374 .31571 L .50621 .32343 L closepath p
1 g
F P
s
P
p
.002 w
.62653 .38299 m .60588 .40426 L .61866 .42981 L p
1 g
F P
s
P
p
.002 w
.60588 .40426 m .62653 .38299 L .60631 .36288 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .55374 .33454 L .559 .32862 L closepath p
1 g
F P
s
P
p
.002 w
.47714 .55029 m .5349 .55733 L .53893 .5334 L p
1 g
F P
s
P
p
.002 w
.59246 .52658 m .53893 .5334 L .5349 .55733 L p
1 g
F P
s
P
p
.002 w
.53893 .5334 m .59246 .52658 L .59199 .50076 L p
1 g
F P
s
P
p
.002 w
.44709 .303 m .446 .32534 L .47458 .31914 L p
1 g
F P
s
P
p
.002 w
.47458 .31914 m .47557 .30394 L .44709 .303 L p
1 g
F P
s
P
p
.002 w
.47557 .30394 m .47458 .31914 L .50374 .31571 L p
1 g
F P
s
P
p
.002 w
.50374 .31571 m .50436 .30802 L .47557 .30394 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .50436 .30802 L .50374 .31571 L closepath p
1 g
F P
s
P
p
.002 w
.63553 .4814 m .59199 .50076 L .59246 .52658 L p
1 g
F P
s
P
p
.002 w
.59199 .50076 m .63553 .4814 L .62863 .45569 L p
1 g
F P
s
P
p
.002 w
.56143 .32133 m .559 .32862 L .58364 .34464 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .559 .32862 L .56143 .32133 L closepath p
1 g
F P
s
P
p
.002 w
.41954 .30527 m .41857 .3342 L .446 .32534 L p
1 g
F P
s
P
p
.002 w
.446 .32534 m .44709 .303 L .41954 .30527 L p
1 g
F P
s
P
p
.002 w
.64383 .4046 m .61866 .42981 L .62863 .45569 L p
1 g
F P
s
P
p
.002 w
.61866 .42981 m .64383 .4046 L .62653 .38299 L p
1 g
F P
s
P
p
.002 w
.34891 .37516 m .36626 .41749 L .38476 .39798 L p
1 g
F P
s
P
p
.002 w
.38476 .39798 m .36946 .35932 L .34891 .37516 L p
1 g
F P
s
P
p
.002 w
.58866 .33033 m .58364 .34464 L .60631 .36288 L p
1 g
F P
s
P
p
.002 w
.58364 .34464 m .58866 .33033 L .56143 .32133 L p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .56143 .32133 L .56072 .31347 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .56072 .31347 L .55691 .30588 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .55691 .30588 L .55041 .29942 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .55041 .29942 L .54191 .29481 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .54191 .29481 L .53237 .29259 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .53237 .29259 L .52286 .29301 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .52286 .29301 L .51445 .29599 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .51445 .29599 L .50806 .30119 L closepath p
1 g
F P
s
P
p
.002 w
.5329 .31513 m .50806 .30119 L .50436 .30802 L closepath p
1 g
F P
s
P
p
.002 w
.41545 .55116 m .47128 .57143 L .47714 .55029 L p
1 g
F P
s
P
p
.002 w
.47714 .55029 m .42215 .53025 L .41545 .55116 L p
1 g
F P
s
P
p
.002 w
.5349 .55733 m .47714 .55029 L .47128 .57143 L p
1 g
F P
s
P
p
.002 w
.48266 .29032 m .47557 .30394 L .50436 .30802 L p
1 g
F P
s
P
p
.002 w
.50436 .30802 m .50806 .30119 L .48266 .29032 L p
1 g
F P
s
P
p
.002 w
.33871 .4583 m .37454 .49881 L .38496 .477 L p
1 g
F P
s
P
p
.002 w
.38496 .477 m .35076 .43773 L .33871 .4583 L p
1 g
F P
s
P
p
.002 w
.56072 .31347 m .56143 .32133 L .58866 .33033 L p
1 g
F P
s
P
p
.002 w
.61402 .34198 m .60631 .36288 L .62653 .38299 L p
1 g
F P
s
P
p
.002 w
.60631 .36288 m .61402 .34198 L .58866 .33033 L p
1 g
F P
s
P
p
.002 w
.39353 .3108 m .39286 .34559 L .41857 .3342 L p
1 g
F P
s
P
p
.002 w
.41857 .3342 m .41954 .30527 L .39353 .3108 L p
1 g
F P
s
P
p
.002 w
.36705 .51948 m .41545 .55116 L .42215 .53025 L p
1 g
F P
s
P
p
.002 w
.42215 .53025 m .37454 .49881 L .36705 .51948 L p
1 g
F P
s
P
p
.002 w
.45724 .28282 m .44709 .303 L .47557 .30394 L p
1 g
F P
s
P
p
.002 w
.47557 .30394 m .48266 .29032 L .45724 .28282 L p
1 g
F P
s
P
p
.002 w
.49523 .27985 m .48266 .29032 L .50806 .30119 L p
1 g
F P
s
P
p
.002 w
.50806 .30119 m .51445 .29599 L .49523 .27985 L p
1 g
F P
s
P
p
.002 w
.65779 .42727 m .62863 .45569 L .63553 .4814 L p
1 g
F P
s
P
p
.002 w
.62863 .45569 m .65779 .42727 L .64383 .4046 L p
1 g
F P
s
P
p
.002 w
.47128 .57143 m .52987 .57871 L .5349 .55733 L p
1 g
F P
s
P
p
.002 w
.59059 .55058 m .5349 .55733 L .52987 .57871 L p
1 g
F P
s
P
p
.002 w
.5349 .55733 m .59059 .55058 L .59246 .52658 L p
1 g
F P
s
P
p
.002 w
.58866 .33033 m .58748 .31474 L .56072 .31347 L p
1 g
F P
s
P
p
.002 w
.55691 .30588 m .56072 .31347 L .58748 .31474 L p
1 g
F P
s
P
p
.002 w
.63911 .50637 m .59246 .52658 L .59059 .55058 L p
1 g
F P
s
P
p
.002 w
.59246 .52658 m .63911 .50637 L .63553 .4814 L p
1 g
F P
s
P
p
.002 w
.58748 .31474 m .58866 .33033 L .61402 .34198 L p
1 g
F P
s
P
p
.002 w
.33179 .39282 m .35076 .43773 L .36626 .41749 L p
1 g
F P
s
P
p
.002 w
.36626 .41749 m .34891 .37516 L .33179 .39282 L p
1 g
F P
s
P
p
.002 w
.63692 .3561 m .62653 .38299 L .64383 .4046 L p
1 g
F P
s
P
p
.002 w
.62653 .38299 m .63692 .3561 L .61402 .34198 L p
1 g
F P
s
P
p
.002 w
.51196 .27378 m .49523 .27985 L .51445 .29599 L p
1 g
F P
s
P
p
.002 w
.51445 .29599 m .52286 .29301 L .51196 .27378 L p
1 g
F P
s
P
p
.002 w
.36969 .31957 m .36946 .35932 L .39286 .34559 L p
1 g
F P
s
P
p
.002 w
.39286 .34559 m .39353 .3108 L .36969 .31957 L p
1 g
F P
s
P
p
.002 w
.58748 .31474 m .58007 .29958 L .55691 .30588 L p
1 g
F P
s
P
p
.002 w
.55041 .29942 m .55691 .30588 L .58007 .29958 L p
1 g
F P
s
P
p
.002 w
.43234 .27896 m .41954 .30527 L .44709 .303 L p
1 g
F P
s
P
p
.002 w
.44709 .303 m .45724 .28282 L .43234 .27896 L p
1 g
F P
s
P
p
.002 w
.531 .27289 m .51196 .27378 L .52286 .29301 L p
1 g
F P
s
P
p
.002 w
.52286 .29301 m .53237 .29259 L .531 .27289 L p
1 g
F P
s
P
p
.002 w
.58007 .29958 m .56715 .2866 L .55041 .29942 L p
1 g
F P
s
P
p
.002 w
.54191 .29481 m .55041 .29942 L .56715 .2866 L p
1 g
F P
s
P
p
.002 w
.47563 .26717 m .45724 .28282 L .48266 .29032 L p
1 g
F P
s
P
p
.002 w
.48266 .29032 m .49523 .27985 L .47563 .26717 L p
1 g
F P
s
P
p
.002 w
.55014 .27734 m .531 .27289 L .53237 .29259 L p
1 g
F P
s
P
p
.002 w
.53237 .29259 m .54191 .29481 L .55014 .27734 L p
1 g
F P
s
P
p
.002 w
.56715 .2866 m .55014 .27734 L .54191 .29481 L p
1 g
F P
s
P
p
.002 w
.33052 .47875 m .36705 .51948 L .37454 .49881 L p
1 g
F P
s
P
p
.002 w
.37454 .49881 m .33871 .4583 L .33052 .47875 L p
1 g
F P
s
P
p
.002 w
.41071 .56963 m .46597 .58964 L .47128 .57143 L p
1 g
F P
s
P
p
.002 w
.47128 .57143 m .41545 .55116 L .41071 .56963 L p
1 g
F P
s
P
p
.002 w
.52987 .57871 m .47128 .57143 L .46597 .58964 L p
1 g
F P
s
P
p
.002 w
.61258 .319 m .61402 .34198 L .63692 .3561 L p
1 g
F P
s
P
p
.002 w
.61402 .34198 m .61258 .319 L .58748 .31474 L p
1 g
F P
s
P
p
.002 w
.66797 .45054 m .63553 .4814 L .63911 .50637 L p
1 g
F P
s
P
p
.002 w
.63553 .4814 m .66797 .45054 L .65779 .42727 L p
1 g
F P
s
P
p
.002 w
.58007 .29958 m .58748 .31474 L .61258 .319 L p
1 g
F P
s
P
p
.002 w
.65678 .37244 m .64383 .4046 L .65779 .42727 L p
1 g
F P
s
P
p
.002 w
.64383 .4046 m .65678 .37244 L .63692 .3561 L p
1 g
F P
s
P
p
.002 w
.36278 .5385 m .41071 .56963 L .41545 .55116 L p
1 g
F P
s
P
p
.002 w
.41545 .55116 m .36705 .51948 L .36278 .5385 L p
1 g
F P
s
P
p
.002 w
.34865 .33148 m .34891 .37516 L .36946 .35932 L p
1 g
F P
s
P
p
.002 w
.36946 .35932 m .36969 .31957 L .34865 .33148 L p
1 g
F P
s
P
p
.002 w
.40855 .27895 m .39353 .3108 L .41954 .30527 L p
1 g
F P
s
P
p
.002 w
.41954 .30527 m .43234 .27896 L .40855 .27895 L p
1 g
F P
s
P
p
.002 w
.31863 .41197 m .33871 .4583 L .35076 .43773 L p
1 g
F P
s
P
p
.002 w
.35076 .43773 m .33179 .39282 L .31863 .41197 L p
1 g
F P
s
P
p
.002 w
.52987 .57871 m .58633 .57216 L .59059 .55058 L p
1 g
F P
s
P
p
.002 w
.63918 .53002 m .59059 .55058 L .58633 .57216 L p
1 g
F P
s
P
p
.002 w
.59059 .55058 m .63918 .53002 L .63911 .50637 L p
1 g
F P
s
P
p
.002 w
.50041 .25802 m .47563 .26717 L .49523 .27985 L p
1 g
F P
s
P
p
.002 w
.49523 .27985 m .51196 .27378 L .50041 .25802 L p
1 g
F P
s
P
p
.002 w
.46597 .58964 m .5239 .59695 L .52987 .57871 L p
1 g
F P
s
P
p
.002 w
.58633 .57216 m .52987 .57871 L .5239 .59695 L p
1 g
F P
s
P
p
.002 w
.61258 .319 m .60181 .29649 L .58007 .29958 L p
1 g
F P
s
P
p
.002 w
.56715 .2866 m .58007 .29958 L .60181 .29649 L p
1 g
F P
s
P
p
.002 w
.45608 .25838 m .43234 .27896 L .45724 .28282 L p
1 g
F P
s
P
p
.002 w
.45724 .28282 m .47563 .26717 L .45608 .25838 L p
1 g
F P
s
P
p
.002 w
.6354 .32626 m .63692 .3561 L .65678 .37244 L p
1 g
F P
s
P
p
.002 w
.63692 .3561 m .6354 .32626 L .61258 .319 L p
1 g
F P
s
P
p
.002 w
.52877 .25661 m .50041 .25802 L .51196 .27378 L p
1 g
F P
s
P
p
.002 w
.51196 .27378 m .531 .27289 L .52877 .25661 L p
1 g
F P
s
P
p
.002 w
.67304 .39071 m .65779 .42727 L .66797 .45054 L p
1 g
F P
s
P
p
.002 w
.65779 .42727 m .67304 .39071 L .65678 .37244 L p
1 g
F P
s
P
p
.002 w
.67402 .47389 m .63911 .50637 L .63918 .53002 L p
1 g
F P
s
P
p
.002 w
.63911 .50637 m .67402 .47389 L .66797 .45054 L p
1 g
F P
s
P
p
.002 w
.60181 .29649 m .61258 .319 L .6354 .32626 L p
1 g
F P
s
P
p
.002 w
.60181 .29649 m .5827 .2771 L .56715 .2866 L p
1 g
F P
s
P
p
.002 w
.55014 .27734 m .56715 .2866 L .5827 .2771 L p
1 g
F P
s
P
p
.002 w
.32657 .49858 m .36278 .5385 L .36705 .51948 L p
1 g
F P
s
P
p
.002 w
.36705 .51948 m .33052 .47875 L .32657 .49858 L p
1 g
F P
s
P
p
.002 w
.38649 .28297 m .36969 .31957 L .39353 .3108 L p
1 g
F P
s
P
p
.002 w
.39353 .3108 m .40855 .27895 L .38649 .28297 L p
1 g
F P
s
P
p
.002 w
.55735 .26323 m .52877 .25661 L .531 .27289 L p
1 g
F P
s
P
p
.002 w
.531 .27289 m .55014 .27734 L .55735 .26323 L p
1 g
F P
s
P
p
.002 w
.33104 .34637 m .33179 .39282 L .34891 .37516 L p
1 g
F P
s
P
p
.002 w
.34891 .37516 m .34865 .33148 L .33104 .34637 L p
1 g
F P
s
P
p
.002 w
.5827 .2771 m .55735 .26323 L .55014 .27734 L p
1 g
F P
s
P
p
.002 w
.40815 .58513 m .46135 .60435 L .46597 .58964 L p
1 g
F P
s
P
p
.002 w
.46597 .58964 m .41071 .56963 L .40815 .58513 L p
1 g
F P
s
P
p
.002 w
.5239 .59695 m .46597 .58964 L .46135 .60435 L p
1 g
F P
s
P
p
.002 w
.30991 .4322 m .33052 .47875 L .33871 .4583 L p
1 g
F P
s
P
p
.002 w
.33871 .4583 m .31863 .41197 L .30991 .4322 L p
1 g
F P
s
P
p
.002 w
.48842 .24625 m .45608 .25838 L .47563 .26717 L p
1 g
F P
s
P
p
.002 w
.47563 .26717 m .50041 .25802 L .48842 .24625 L p
1 g
F P
s
P
p
.002 w
.362 .55534 m .40815 .58513 L .41071 .56963 L p
1 g
F P
s
P
p
.002 w
.41071 .56963 m .36278 .5385 L .362 .55534 L p
1 g
F P
s
P
p
.002 w
.5239 .59695 m .57967 .59073 L .58633 .57216 L p
1 g
F P
s
P
p
.002 w
.63558 .55176 m .58633 .57216 L .57967 .59073 L p
1 g
F P
s
P
p
.002 w
.58633 .57216 m .63558 .55176 L .63918 .53002 L p
1 g
F P
s
P
p
.002 w
.43705 .25389 m .40855 .27895 L .43234 .27896 L p
1 g
F P
s
P
p
.002 w
.43234 .27896 m .45608 .25838 L .43705 .25389 L p
1 g
F P
s
P
p
.002 w
.65533 .33648 m .65678 .37244 L .67304 .39071 L p
1 g
F P
s
P
p
.002 w
.65678 .37244 m .65533 .33648 L .6354 .32626 L p
1 g
F P
s
P
p
.002 w
.46135 .60435 m .51709 .61147 L .5239 .59695 L p
1 g
F P
s
P
p
.002 w
.57967 .59073 m .5239 .59695 L .51709 .61147 L p
1 g
F P
s
P
p
.002 w
.6354 .32626 m .62159 .29682 L .60181 .29649 L p
1 g
F P
s
P
p
.002 w
.5827 .2771 m .60181 .29649 L .62159 .29682 L p
1 g
F P
s
P
p
.002 w
.68517 .41056 m .66797 .45054 L .67402 .47389 L p
1 g
F P
s
P
p
.002 w
.66797 .45054 m .68517 .41056 L .67304 .39071 L p
1 g
F P
s
P
p
.002 w
.62159 .29682 m .6354 .32626 L .65533 .33648 L p
1 g
F P
s
P
p
.002 w
.6756 .49676 m .63918 .53002 L .63558 .55176 L p
1 g
F P
s
P
p
.002 w
.63918 .53002 m .6756 .49676 L .67402 .47389 L p
1 g
F P
s
P
p
.002 w
.36678 .2911 m .34865 .33148 L .36969 .31957 L p
1 g
F P
s
P
p
.002 w
.36969 .31957 m .38649 .28297 L .36678 .2911 L p
1 g
F P
s
P
p
.002 w
.31747 .36401 m .31863 .41197 L .33179 .39282 L p
1 g
F P
s
P
p
.002 w
.33179 .39282 m .33104 .34637 L .31747 .36401 L p
1 g
F P
s
P
p
.002 w
.52568 .24431 m .48842 .24625 L .50041 .25802 L p
1 g
F P
s
P
p
.002 w
.50041 .25802 m .52877 .25661 L .52568 .24431 L p
1 g
F P
s
P
p
.002 w
.62159 .29682 m .59664 .27132 L .5827 .2771 L p
1 g
F P
s
P
p
.002 w
.55735 .26323 m .5827 .2771 L .59664 .27132 L p
1 g
F P
s
P
p
.002 w
.32716 .51726 m .362 .55534 L .36278 .5385 L p
1 g
F P
s
P
p
.002 w
.36278 .5385 m .32657 .49858 L .32716 .51726 L p
1 g
F P
s
P
p
.002 w
.30609 .45305 m .32657 .49858 L .33052 .47875 L p
1 g
F P
s
P
p
.002 w
.33052 .47875 m .30991 .4322 L .30609 .45305 L p
1 g
F P
s
P
p
.002 w
.56332 .25302 m .52568 .24431 L .52877 .25661 L p
1 g
F P
s
P
p
.002 w
.52877 .25661 m .55735 .26323 L .56332 .25302 L p
1 g
F P
s
P
p
.002 w
.59664 .27132 m .56332 .25302 L .55735 .26323 L p
1 g
F P
s
P
p
.002 w
.41904 .25401 m .38649 .28297 L .40855 .27895 L p
1 g
F P
s
P
p
.002 w
.40855 .27895 m .43705 .25389 L .41904 .25401 L p
1 g
F P
s
P
p
.002 w
.67173 .34954 m .67304 .39071 L .68517 .41056 L p
1 g
F P
s
P
p
.002 w
.67304 .39071 m .67173 .34954 L .65533 .33648 L p
1 g
F P
s
P
p
.002 w
.47628 .23899 m .43705 .25389 L .45608 .25838 L p
1 g
F P
s
P
p
.002 w
.45608 .25838 m .48842 .24625 L .47628 .23899 L p
1 g
F P
s
P
p
.002 w
.40794 .5971 m .45759 .615 L .46135 .60435 L p
1 g
F P
s
P
p
.002 w
.46135 .60435 m .40815 .58513 L .40794 .5971 L p
1 g
F P
s
P
p
.002 w
.51709 .61147 m .46135 .60435 L .45759 .615 L p
1 g
F P
s
P
p
.002 w
.51709 .61147 m .57065 .60569 L .57967 .59073 L p
1 g
F P
s
P
p
.002 w
.62824 .57096 m .57967 .59073 L .57065 .60569 L p
1 g
F P
s
P
p
.002 w
.57967 .59073 m .62824 .57096 L .63558 .55176 L p
1 g
F P
s
P
p
.002 w
.69267 .43156 m .67402 .47389 L .6756 .49676 L p
1 g
F P
s
P
p
.002 w
.67402 .47389 m .69267 .43156 L .68517 .41056 L p
1 g
F P
s
P
p
.002 w
.36492 .56945 m .40794 .5971 L .40815 .58513 L p
1 g
F P
s
P
p
.002 w
.40815 .58513 m .362 .55534 L .36492 .56945 L p
1 g
F P
s
P
p
.002 w
.65533 .33648 m .63881 .30074 L .62159 .29682 L p
1 g
F P
s
P
p
.002 w
.59664 .27132 m .62159 .29682 L .63881 .30074 L p
1 g
F P
s
P
p
.002 w
.35007 .30332 m .33104 .34637 L .34865 .33148 L p
1 g
F P
s
P
p
.002 w
.34865 .33148 m .36678 .2911 L .35007 .30332 L p
1 g
F P
s
P
p
.002 w
.63881 .30074 m .65533 .33648 L .67173 .34954 L p
1 g
F P
s
P
p
.002 w
.45759 .615 m .50955 .6217 L .51709 .61147 L p
1 g
F P
s
P
p
.002 w
.57065 .60569 m .51709 .61147 L .50955 .6217 L p
1 g
F P
s
P
p
.002 w
.67249 .51855 m .63558 .55176 L .62824 .57096 L p
1 g
F P
s
P
p
.002 w
.63558 .55176 m .67249 .51855 L .6756 .49676 L p
1 g
F P
s
P
p
.002 w
.30848 .38405 m .30991 .4322 L .31863 .41197 L p
1 g
F P
s
P
p
.002 w
.31863 .41197 m .31747 .36401 L .30848 .38405 L p
1 g
F P
s
P
p
.002 w
.52177 .23657 m .47628 .23899 L .48842 .24625 L p
1 g
F P
s
P
p
.002 w
.48842 .24625 m .52568 .24431 L .52177 .23657 L p
1 g
F P
s
P
p
.002 w
.33254 .53424 m .36492 .56945 L .362 .55534 L p
1 g
F P
s
P
p
.002 w
.362 .55534 m .32716 .51726 L .33254 .53424 L p
1 g
F P
s
P
p
.002 w
.40259 .25902 m .36678 .2911 L .38649 .28297 L p
1 g
F P
s
P
p
.002 w
.38649 .28297 m .41904 .25401 L .40259 .25902 L p
1 g
F P
s
P
p
.002 w
.63881 .30074 m .60852 .26961 L .59664 .27132 L p
1 g
F P
s
P
p
.002 w
.56332 .25302 m .59664 .27132 L .60852 .26961 L p
1 g
F P
s
P
p
.002 w
.68402 .36525 m .68517 .41056 L .69267 .43156 L p
1 g
F P
s
P
p
.002 w
.68517 .41056 m .68402 .36525 L .67173 .34954 L p
1 g
F P
s
P
p
.002 w
.30751 .47397 m .32716 .51726 L .32657 .49858 L p
1 g
F P
s
P
p
.002 w
.32657 .49858 m .30609 .45305 L .30751 .47397 L p
1 g
F P
s
P
p
.002 w
.46431 .23672 m .41904 .25401 L .43705 .25389 L p
1 g
F P
s
P
p
.002 w
.43705 .25389 m .47628 .23899 L .46431 .23672 L p
1 g
F P
s
P
p
.002 w
.69514 .4532 m .6756 .49676 L .67249 .51855 L p
1 g
F P
s
P
p
.002 w
.6756 .49676 m .69514 .4532 L .69267 .43156 L p
1 g
F P
s
P
p
.002 w
.56782 .24721 m .52177 .23657 L .52568 .24431 L p
1 g
F P
s
P
p
.002 w
.52568 .24431 m .56332 .25302 L .56782 .24721 L p
1 g
F P
s
P
p
.002 w
.60852 .26961 m .56782 .24721 L .56332 .25302 L p
1 g
F P
s
P
p
.002 w
.33696 .31952 m .31747 .36401 L .33104 .34637 L p
1 g
F P
s
P
p
.002 w
.33104 .34637 m .35007 .30332 L .33696 .31952 L p
1 g
F P
s
P
p
.002 w
.50955 .6217 m .55936 .61645 L .57065 .60569 L p
1 g
F P
s
P
p
.002 w
.61714 .58699 m .57065 .60569 L .55936 .61645 L p
1 g
F P
s
P
p
.002 w
.57065 .60569 m .61714 .58699 L .62824 .57096 L p
1 g
F P
s
P
p
.002 w
.41025 .60502 m .45481 .62107 L .45759 .615 L p
1 g
F P
s
P
p
.002 w
.45759 .615 m .40794 .5971 L .41025 .60502 L p
1 g
F P
s
P
p
.002 w
.50955 .6217 m .45759 .615 L .45481 .62107 L p
1 g
F P
s
P
p
.002 w
.6529 .30835 m .67173 .34954 L .68402 .36525 L p
1 g
F P
s
P
p
.002 w
.67173 .34954 m .6529 .30835 L .63881 .30074 L p
1 g
F P
s
P
p
.002 w
.60852 .26961 m .63881 .30074 L .6529 .30835 L p
1 g
F P
s
P
p
.002 w
.30457 .40605 m .30609 .45305 L .30991 .4322 L p
1 g
F P
s
P
p
.002 w
.30991 .4322 m .30848 .38405 L .30457 .40605 L p
1 g
F P
s
P
p
.002 w
.66453 .53864 m .62824 .57096 L .61714 .58699 L p
1 g
F P
s
P
p
.002 w
.62824 .57096 m .66453 .53864 L .67249 .51855 L p
1 g
F P
s
P
p
.002 w
.37169 .5803 m .41025 .60502 L .40794 .5971 L p
1 g
F P
s
P
p
.002 w
.40794 .5971 m .36492 .56945 L .37169 .5803 L p
1 g
F P
s
P
p
.002 w
.45481 .62107 m .50143 .62712 L .50955 .6217 L p
1 g
F P
s
P
p
.002 w
.55936 .61645 m .50955 .6217 L .50143 .62712 L p
1 g
F P
s
P
p
.002 w
.69164 .38332 m .69267 .43156 L .69514 .4532 L p
1 g
F P
s
P
p
.002 w
.69267 .43156 m .69164 .38332 L .68402 .36525 L p
1 g
F P
s
P
p
.002 w
.38826 .26903 m .35007 .30332 L .36678 .2911 L p
1 g
F P
s
P
p
.002 w
.36678 .2911 m .40259 .25902 L .38826 .26903 L p
1 g
F P
s
P
p
.002 w
.51708 .23388 m .46431 .23672 L .47628 .23899 L p
1 g
F P
s
P
p
.002 w
.47628 .23899 m .52177 .23657 L .51708 .23388 L p
1 g
F P
s
P
p
.002 w
.31439 .49439 m .33254 .53424 L .32716 .51726 L p
1 g
F P
s
P
p
.002 w
.32716 .51726 m .30751 .47397 L .31439 .49439 L p
1 g
F P
s
P
p
.002 w
.69226 .47493 m .67249 .51855 L .66453 .53864 L p
1 g
F P
s
P
p
.002 w
.67249 .51855 m .69226 .47493 L .69514 .4532 L p
1 g
F P
s
P
p
.002 w
.34281 .54895 m .37169 .5803 L .36492 .56945 L p
1 g
F P
s
P
p
.002 w
.36492 .56945 m .33254 .53424 L .34281 .54895 L p
1 g
F P
s
P
p
.002 w
.6529 .30835 m .61791 .27229 L .60852 .26961 L p
1 g
F P
s
P
p
.002 w
.56782 .24721 m .60852 .26961 L .61791 .27229 L p
1 g
F P
s
P
p
.002 w
.45284 .2398 m .40259 .25902 L .41904 .25401 L p
1 g
F P
s
P
p
.002 w
.41904 .25401 m .46431 .23672 L .45284 .2398 L p
1 g
F P
s
P
p
.002 w
.32804 .33941 m .30848 .38405 L .31747 .36401 L p
1 g
F P
s
P
p
.002 w
.31747 .36401 m .33696 .31952 L .32804 .33941 L p
1 g
F P
s
P
p
.002 w
.57063 .24626 m .51708 .23388 L .52177 .23657 L p
1 g
F P
s
P
p
.002 w
.52177 .23657 m .56782 .24721 L .57063 .24626 L p
1 g
F P
s
P
p
.002 w
.50143 .62712 m .54597 .62247 L .55936 .61645 L p
1 g
F P
s
P
p
.002 w
.6024 .59925 m .55936 .61645 L .54597 .62247 L p
1 g
F P
s
P
p
.002 w
.55936 .61645 m .6024 .59925 L .61714 .58699 L p
1 g
F P
s
P
p
.002 w
.30608 .42945 m .30751 .47397 L .30609 .45305 L p
1 g
F P
s
P
p
.002 w
.30609 .45305 m .30457 .40605 L .30608 .42945 L p
1 g
F P
s
P
p
.002 w
.68402 .36525 m .66329 .31965 L .6529 .30835 L p
1 g
F P
s
P
p
.002 w
.66329 .31965 m .68402 .36525 L .69164 .38332 L p
1 g
F P
s
P
p
.002 w
.61791 .27229 m .57063 .24626 L .56782 .24721 L p
1 g
F P
s
P
p
.002 w
.61714 .58699 m .65171 .55636 L .66453 .53864 L p
1 g
F P
s
P
p
.002 w
.65171 .55636 m .61714 .58699 L .6024 .59925 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.58251 .60738 L
s
P
p
.004 w
.58254 .60743 m
.58312 .60868 L
s
P
p
.004 w
.58312 .60868 m
.58643 .61577 L
s
P
p
.004 w
.59779 .64012 m
.62609 .70079 L
s
P
p
.002 w
.61791 .27229 m .6529 .30835 L .66329 .31965 L p
1 g
F P
s
P
p
.002 w
.41516 .6084 m .45318 .6221 L .45481 .62107 L p
1 g
F P
s
P
p
.004 w
.4366 .65289 m
.44368 .62805 L
s
P
p
.002 w
.45481 .62107 m .41025 .60502 L .41516 .6084 L p
1 g
F P
s
P
p
.002 w
.50143 .62712 m .45481 .62107 L .45318 .6221 L p
1 g
F P
s
P
p
.002 w
.38235 .58737 m .41516 .6084 L .41025 .60502 L p
1 g
F P
s
P
p
.002 w
.41025 .60502 m .37169 .5803 L .38235 .58737 L p
1 g
F P
s
P
p
.002 w
.69514 .4532 m .69413 .40336 L .69164 .38332 L p
1 g
F P
s
P
p
.002 w
.69413 .40336 m .69514 .4532 L .69226 .47493 L p
1 g
F P
s
P
p
.002 w
.3766 .28405 m .33696 .31952 L .35007 .30332 L p
1 g
F P
s
P
p
.002 w
.35007 .30332 m .38826 .26903 L .3766 .28405 L p
1 g
F P
s
P
p
.002 w
.45318 .6221 m .49293 .62726 L .50143 .62712 L p
1 g
F P
s
P
p
.002 w
.54597 .62247 m .50143 .62712 L .49293 .62726 L p
1 g
F P
s
P
p
.002 w
.66453 .53864 m .68384 .49611 L .69226 .47493 L p
1 g
F P
s
P
p
.002 w
.68384 .49611 m .66453 .53864 L .65171 .55636 L p
1 g
F P
s
P
p
.002 w
.3268 .51365 m .34281 .54895 L .33254 .53424 L p
1 g
F P
s
P
p
.002 w
.33254 .53424 m .31439 .49439 L .3268 .51365 L p
1 g
F P
s
P
p
.002 w
.5117 .23666 m .45284 .2398 L .46431 .23672 L p
1 g
F P
s
P
p
.002 w
.46431 .23672 m .51708 .23388 L .5117 .23666 L p
1 g
F P
s
P
p
.002 w
.32378 .36258 m .30457 .40605 L .30848 .38405 L p
1 g
F P
s
P
p
.002 w
.30848 .38405 m .32804 .33941 L .32378 .36258 L p
1 g
F P
s
P
p
.002 w
.44224 .24848 m .38826 .26903 L .40259 .25902 L p
1 g
F P
s
P
p
.002 w
.40259 .25902 m .45284 .2398 L .44224 .24848 L p
1 g
F P
s
P
p
.002 w
.35794 .56082 m .38235 .58737 L .37169 .5803 L p
1 g
F P
s
P
p
.002 w
.37169 .5803 m .34281 .54895 L .35794 .56082 L p
1 g
F P
s
P
p
.002 w
.66329 .31965 m .62436 .27955 L .61791 .27229 L p
1 g
F P
s
P
p
.002 w
.57063 .24626 m .61791 .27229 L .62436 .27955 L p
1 g
F P
s
P
p
.002 w
.31324 .45361 m .31439 .49439 L .30751 .47397 L p
1 g
F P
s
P
p
.002 w
.30751 .47397 m .30608 .42945 L .31324 .45361 L p
1 g
F P
s
P
p
.002 w
.66945 .33454 m .69164 .38332 L .69413 .40336 L p
1 g
F P
s
P
p
.002 w
.69164 .38332 m .66945 .33454 L .66329 .31965 L p
1 g
F P
s
P
p
.002 w
.54597 .62247 m .58425 .6072 L .6024 .59925 L p
1 g
F P
s
P
p
.004 w
.58643 .61577 m
.59779 .64012 L
s
P
p
.002 w
.63416 .5711 m .6024 .59925 L .58425 .6072 L p
1 g
F P
s
P
p
.002 w
.6024 .59925 m .63416 .5711 L .65171 .55636 L p
1 g
F P
s
P
p
.002 w
.49293 .62726 m .53076 .6233 L .54597 .62247 L p
1 g
F P
s
P
p
.002 w
.58425 .6072 m .54597 .62247 L .53076 .6233 L p
1 g
F P
s
P
p
.002 w
.57156 .2505 m .5117 .23666 L .51708 .23388 L p
1 g
F P
s
P
p
.002 w
.51708 .23388 m .57063 .24626 L .57156 .2505 L p
1 g
F P
s
P
p
.002 w
.62436 .27955 m .66329 .31965 L .66945 .33454 L p
1 g
F P
s
P
p
.002 w
.62436 .27955 m .57156 .2505 L .57063 .24626 L p
1 g
F P
s
P
p
.002 w
.69115 .42488 m .69226 .47493 L .68384 .49611 L p
1 g
F P
s
P
p
.002 w
.69226 .47493 m .69115 .42488 L .69413 .40336 L p
1 g
F P
s
P
p
.002 w
.36812 .30387 m .32804 .33941 L .33696 .31952 L p
1 g
F P
s
P
p
.002 w
.33696 .31952 m .3766 .28405 L .36812 .30387 L p
1 g
F P
s
P
p
.002 w
.42271 .60686 m .45281 .6177 L .45318 .6221 L p
1 g
F P
s
P
p
.002 w
.45318 .6221 m .41516 .6084 L .42271 .60686 L p
1 g
F P
s
P
p
.002 w
.49293 .62726 m .45318 .6221 L .45281 .6177 L p
1 g
F P
s
P
p
.002 w
.66987 .51607 m .65171 .55636 L .63416 .5711 L p
1 g
F P
s
P
p
.002 w
.65171 .55636 m .66987 .51607 L .68384 .49611 L p
1 g
F P
s
P
p
.002 w
.39683 .59023 m .42271 .60686 L .41516 .6084 L p
1 g
F P
s
P
p
.002 w
.41516 .6084 m .38235 .58737 L .39683 .59023 L p
1 g
F P
s
P
p
.002 w
.32453 .38845 m .30608 .42945 L .30457 .40605 L p
1 g
F P
s
P
p
.002 w
.30457 .40605 m .32378 .36258 L .32453 .38845 L p
1 g
F P
s
P
p
.002 w
.45281 .6177 m .48426 .62177 L .49293 .62726 L p
1 g
F P
s
P
p
.002 w
.53076 .6233 m .49293 .62726 L .48426 .62177 L p
1 g
F P
s
P
p
.002 w
.34464 .53111 m .35794 .56082 L .34281 .54895 L p
1 g
F P
s
P
p
.002 w
.34281 .54895 m .3268 .51365 L .34464 .53111 L p
1 g
F P
s
P
p
.002 w
.50575 .24518 m .44224 .24848 L .45284 .2398 L p
1 g
F P
s
P
p
.002 w
.45284 .2398 m .5117 .23666 L .50575 .24518 L p
1 g
F P
s
P
p
.002 w
.43292 .26283 m .3766 .28405 L .38826 .26903 L p
1 g
F P
s
P
p
.002 w
.38826 .26903 m .44224 .24848 L .43292 .26283 L p
1 g
F P
s
P
p
.002 w
.32606 .47777 m .3268 .51365 L .31439 .49439 L p
1 g
F P
s
P
p
.002 w
.31439 .49439 m .31324 .45361 L .32606 .47777 L p
1 g
F P
s
P
p
.002 w
.37774 .56932 m .39683 .59023 L .38235 .58737 L p
1 g
F P
s
P
p
.002 w
.38235 .58737 m .35794 .56082 L .37774 .56932 L p
1 g
F P
s
P
p
.002 w
.67096 .35278 m .69413 .40336 L .69115 .42488 L p
1 g
F P
s
P
p
.002 w
.69413 .40336 m .67096 .35278 L .66945 .33454 L p
1 g
F P
s
P
p
.002 w
.53076 .6233 m .56303 .61034 L .58425 .6072 L p
1 g
F P
s
P
p
.002 w
.61219 .58225 m .58425 .6072 L .56303 .61034 L p
1 g
F P
s
P
p
.002 w
.58425 .6072 m .61219 .58225 L .63416 .5711 L p
1 g
F P
s
P
p
.002 w
.66945 .33454 m .6275 .29147 L .62436 .27955 L p
1 g
F P
s
P
p
.002 w
.57156 .2505 m .62436 .27955 L .6275 .29147 L p
1 g
F P
s
P
p
.002 w
.48426 .62177 m .51406 .61861 L .53076 .6233 L p
1 g
F P
s
P
p
.002 w
.56303 .61034 m .53076 .6233 L .51406 .61861 L p
1 g
F P
s
P
p
.002 w
.6825 .44726 m .68384 .49611 L .66987 .51607 L p
1 g
F P
s
P
p
.002 w
.68384 .49611 m .6825 .44726 L .69115 .42488 L p
1 g
F P
s
P
p
.002 w
.6275 .29147 m .66945 .33454 L .67096 .35278 L p
1 g
F P
s
P
p
.002 w
.36325 .32809 m .32378 .36258 L .32804 .33941 L p
1 g
F P
s
P
p
.002 w
.32804 .33941 m .36812 .30387 L .36325 .32809 L p
1 g
F P
s
P
p
.002 w
.65053 .53413 m .63416 .5711 L .61219 .58225 L p
1 g
F P
s
P
p
.002 w
.63416 .5711 m .65053 .53413 L .66987 .51607 L p
1 g
F P
s
P
p
.002 w
.57044 .26016 m .50575 .24518 L .5117 .23666 L p
1 g
F P
s
P
p
.002 w
.5117 .23666 m .57156 .2505 L .57044 .26016 L p
1 g
F P
s
P
p
.002 w
.33051 .41627 m .31324 .45361 L .30608 .42945 L p
1 g
F P
s
P
p
.002 w
.30608 .42945 m .32453 .38845 L .33051 .41627 L p
1 g
F P
s
P
p
.002 w
.6275 .29147 m .57044 .26016 L .57156 .2505 L p
1 g
F P
s
P
p
.002 w
.43284 .6001 m .4538 .60767 L .45281 .6177 L p
1 g
F P
s
P
p
.002 w
.45281 .6177 m .42271 .60686 L .43284 .6001 L p
1 g
F P
s
P
p
.002 w
.48426 .62177 m .45281 .6177 L .4538 .60767 L p
1 g
F P
s
P
p
.002 w
.36755 .54611 m .37774 .56932 L .35794 .56082 L p
1 g
F P
s
P
p
.002 w
.35794 .56082 m .34464 .53111 L .36755 .54611 L p
1 g
F P
s
P
p
.002 w
.41489 .58852 m .43284 .6001 L .42271 .60686 L p
1 g
F P
s
P
p
.002 w
.42271 .60686 m .39683 .59023 L .41489 .58852 L p
1 g
F P
s
P
p
.002 w
.34435 .50114 m .34464 .53111 L .3268 .51365 L p
1 g
F P
s
P
p
.002 w
.3268 .51365 m .32606 .47777 L .34435 .50114 L p
1 g
F P
s
P
p
.002 w
.4538 .60767 m .47568 .61047 L .48426 .62177 L p
1 g
F P
s
P
p
.002 w
.51406 .61861 m .48426 .62177 L .47568 .61047 L p
1 g
F P
s
P
p
.002 w
.42524 .28269 m .36812 .30387 L .3766 .28405 L p
1 g
F P
s
P
p
.002 w
.3766 .28405 m .43292 .26283 L .42524 .28269 L p
1 g
F P
s
P
p
.002 w
.66749 .37395 m .69115 .42488 L .6825 .44726 L p
1 g
F P
s
P
p
.002 w
.69115 .42488 m .66749 .37395 L .67096 .35278 L p
1 g
F P
s
P
p
.002 w
.49938 .25954 m .43292 .26283 L .44224 .24848 L p
1 g
F P
s
P
p
.002 w
.44224 .24848 m .50575 .24518 L .49938 .25954 L p
1 g
F P
s
P
p
.002 w
.51406 .61861 m .53928 .60835 L .56303 .61034 L p
1 g
F P
s
P
p
.002 w
.5863 .58928 m .56303 .61034 L .53928 .60835 L p
1 g
F P
s
P
p
.002 w
.56303 .61034 m .5863 .58928 L .61219 .58225 L p
1 g
F P
s
P
p
.002 w
.6682 .46983 m .66987 .51607 L .65053 .53413 L p
1 g
F P
s
P
p
.002 w
.66987 .51607 m .6682 .46983 L .6825 .44726 L p
1 g
F P
s
P
p
.002 w
.4018 .57402 m .41489 .58852 L .39683 .59023 L p
1 g
F P
s
P
p
.002 w
.39683 .59023 m .37774 .56932 L .4018 .57402 L p
1 g
F P
s
P
p
.002 w
.36235 .35609 m .32453 .38845 L .32378 .36258 L p
1 g
F P
s
P
p
.002 w
.32378 .36258 m .36325 .32809 L .36235 .35609 L p
1 g
F P
s
P
p
.002 w
.62625 .54962 m .61219 .58225 L .5863 .58928 L p
1 g
F P
s
P
p
.002 w
.61219 .58225 m .62625 .54962 L .65053 .53413 L p
1 g
F P
s
P
p
.002 w
.67096 .35278 m .62701 .30795 L .6275 .29147 L p
1 g
F P
s
P
p
.002 w
.57044 .26016 m .6275 .29147 L .62701 .30795 L p
1 g
F P
s
P
p
.002 w
.47568 .61047 m .49633 .60822 L .51406 .61861 L p
1 g
F P
s
P
p
.002 w
.53928 .60835 m .51406 .61861 L .49633 .60822 L p
1 g
F P
s
P
p
.002 w
.3417 .44517 m .32606 .47777 L .31324 .45361 L p
1 g
F P
s
P
p
.002 w
.31324 .45361 m .33051 .41627 L .3417 .44517 L p
1 g
F P
s
P
p
.002 w
.62701 .30795 m .67096 .35278 L .66749 .37395 L p
1 g
F P
s
P
p
.002 w
.56719 .27527 m .49938 .25954 L .50575 .24518 L p
1 g
F P
s
P
p
.002 w
.50575 .24518 m .57044 .26016 L .56719 .27527 L p
1 g
F P
s
P
p
.002 w
.36768 .52289 m .36755 .54611 L .34464 .53111 L p
1 g
F P
s
P
p
.002 w
.34464 .53111 m .34435 .50114 L .36768 .52289 L p
1 g
F P
s
P
p
.002 w
.39499 .55804 m .4018 .57402 L .37774 .56932 L p
1 g
F P
s
P
p
.002 w
.37774 .56932 m .36755 .54611 L .39499 .55804 L p
1 g
F P
s
P
p
.002 w
.62701 .30795 m .56719 .27527 L .57044 .26016 L p
1 g
F P
s
P
p
.002 w
.65892 .39752 m .6825 .44726 L .6682 .46983 L p
1 g
F P
s
P
p
.002 w
.6825 .44726 m .65892 .39752 L .66749 .37395 L p
1 g
F P
s
P
p
.002 w
.44537 .58804 m .4562 .59195 L .4538 .60767 L p
1 g
F P
s
P
p
.002 w
.4538 .60767 m .43284 .6001 L .44537 .58804 L p
1 g
F P
s
P
p
.002 w
.47568 .61047 m .4538 .60767 L .4562 .59195 L p
1 g
F P
s
P
p
.002 w
.41957 .30767 m .36325 .32809 L .36812 .30387 L p
1 g
F P
s
P
p
.002 w
.36812 .30387 m .42524 .28269 L .41957 .30767 L p
1 g
F P
s
P
p
.002 w
.6485 .49181 m .65053 .53413 L .62625 .54962 L p
1 g
F P
s
P
p
.002 w
.65053 .53413 m .6485 .49181 L .6682 .46983 L p
1 g
F P
s
P
p
.002 w
.43615 .58204 m .44537 .58804 L .43284 .6001 L p
1 g
F P
s
P
p
.002 w
.43284 .6001 m .41489 .58852 L .43615 .58204 L p
1 g
F P
s
P
p
.002 w
.49633 .60822 m .51364 .60104 L .53928 .60835 L p
1 g
F P
s
P
p
.002 w
.55719 .59181 m .53928 .60835 L .51364 .60104 L p
1 g
F P
s
P
p
.002 w
.53928 .60835 m .55719 .59181 L .5863 .58928 L p
1 g
F P
s
P
p
.002 w
.4562 .59195 m .4675 .59339 L .47568 .61047 L p
1 g
F P
s
P
p
.002 w
.49633 .60822 m .47568 .61047 L .4675 .59339 L p
1 g
F P
s
P
p
.002 w
.59765 .5619 m .5863 .58928 L .55719 .59181 L p
1 g
F P
s
P
p
.002 w
.5863 .58928 m .59765 .5619 L .62625 .54962 L p
1 g
F P
s
P
p
.002 w
.49279 .27959 m .42524 .28269 L .43292 .26283 L p
1 g
F P
s
P
p
.002 w
.43292 .26283 m .49938 .25954 L .49279 .27959 L p
1 g
F P
s
P
p
.002 w
.36559 .38702 m .33051 .41627 L .32453 .38845 L p
1 g
F P
s
P
p
.002 w
.32453 .38845 m .36235 .35609 L .36559 .38702 L p
1 g
F P
s
P
p
.002 w
.35787 .47417 m .34435 .50114 L .32606 .47777 L p
1 g
F P
s
P
p
.002 w
.32606 .47777 m .3417 .44517 L .35787 .47417 L p
1 g
F P
s
P
p
.002 w
.42949 .57457 m .43615 .58204 L .41489 .58852 L p
1 g
F P
s
P
p
.002 w
.41489 .58852 m .4018 .57402 L .42949 .57457 L p
1 g
F P
s
P
p
.002 w
.4675 .59339 m .47811 .59217 L .49633 .60822 L p
1 g
F P
s
P
p
.002 w
.51364 .60104 m .49633 .60822 L .47811 .59217 L p
1 g
F P
s
P
p
.002 w
.62271 .32872 m .66749 .37395 L .65892 .39752 L p
1 g
F P
s
P
p
.002 w
.66749 .37395 m .62271 .32872 L .62701 .30795 L p
1 g
F P
s
P
p
.002 w
.56719 .27527 m .62701 .30795 L .62271 .32872 L p
1 g
F P
s
P
p
.002 w
.39536 .54222 m .39499 .55804 L .36755 .54611 L p
1 g
F P
s
P
p
.002 w
.36755 .54611 m .36768 .52289 L .39536 .54222 L p
1 g
F P
s
P
p
.002 w
.42614 .5664 m .42949 .57457 L .4018 .57402 L p
1 g
F P
s
P
p
.002 w
.4018 .57402 m .39499 .55804 L .42614 .5664 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.6239 .51242 m .62625 .54962 L .59765 .5619 L p
1 g
F P
s
P
p
.002 w
.62625 .54962 m .6239 .51242 L .6485 .49181 L p
1 g
F P
s
P
p
.002 w
.6453 .42276 m .6682 .46983 L .6485 .49181 L p
1 g
F P
s
P
p
.002 w
.6682 .46983 m .6453 .42276 L .65892 .39752 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.46887 .53971 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.51364 .60104 m .52573 .58957 L .55719 .59181 L p
1 g
F P
s
P
p
.002 w
.56561 .57047 m .55719 .59181 L .52573 .58957 L p
1 g
F P
s
P
p
.002 w
.55719 .59181 m .56561 .57047 L .59765 .5619 L p
1 g
F P
s
P
p
.002 w
.47811 .59217 m .48692 .58843 L .51364 .60104 L p
1 g
F P
s
P
p
.002 w
.52573 .58957 m .51364 .60104 L .48692 .58843 L p
1 g
F P
s
P
p
.002 w
.5618 .29564 m .49279 .27959 L .49938 .25954 L p
1 g
F P
s
P
p
.002 w
.49938 .25954 m .56719 .27527 L .5618 .29564 L p
1 g
F P
s
P
p
.002 w
.37855 .50221 m .36768 .52289 L .34435 .50114 L p
1 g
F P
s
P
p
.002 w
.34435 .50114 m .35787 .47417 L .37855 .50221 L p
1 g
F P
s
P
p
.002 w
.4162 .33711 m .36235 .35609 L .36325 .32809 L p
1 g
F P
s
P
p
.002 w
.36325 .32809 m .41957 .30767 L .4162 .33711 L p
1 g
F P
s
P
p
.002 w
.373 .41987 m .3417 .44517 L .33051 .41627 L p
1 g
F P
s
P
p
.002 w
.33051 .41627 m .36559 .38702 L .373 .41987 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.62271 .32872 m .5618 .29564 L .56719 .27527 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.4562 .59195 m .44537 .58804 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.002 w
.4675 .59339 m .4562 .59195 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44537 .58804 m .43615 .58204 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47811 .59217 m .4675 .59339 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.4862 .30491 m .41957 .30767 L .42524 .28269 L p
1 g
F P
s
P
p
.002 w
.42524 .28269 m .49279 .27959 L .4862 .30491 L p
1 g
F P
s
P
p
.002 w
.42649 .55839 m .42614 .5664 L .39499 .55804 L p
1 g
F P
s
P
p
.002 w
.39499 .55804 m .39536 .54222 L .42649 .55839 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.43615 .58204 m .42949 .57457 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.59513 .53088 m .59765 .5619 L .56561 .57047 L p
1 g
F P
s
P
p
.002 w
.59765 .5619 m .59513 .53088 L .6239 .51242 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.48692 .58843 m .47811 .59217 L .46166 .57272 L p
1 g
F P
s
P
p
.002 w
.46417 .5735 m .48692 .58843 L p
.46166 .57272 L 1 g
F P
s
P
p
.002 w
.49296 .58251 m .48692 .58843 L .4735 .57963 L p
1 g
F P
s
P
p
.002 w
.52573 .58957 m .49296 .58251 L p
.50043 .58102 L 1 g
F P
s
P
p
.002 w
.51093 .58054 m .51079 .57862 L p
.49827 .58112 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58054 L p
1 g
F P
s
P
p
.002 w
.53098 .57542 m .5294 .5797 L p
.51093 .58054 L 1 g
F P
s
P
p
.002 w
.5294 .5797 m .52573 .58957 L p
.50043 .58102 L 1 g
F P
s
P
p
.002 w
.51093 .58054 m .51111 .583 L p
.52081 .57802 L 1 g
F P
s
P
p
.53128 .57265 m .51093 .58054 L .52081 .57802 L 1 g
F
P
p
.002 w
.52573 .58957 m .53088 .57569 L p
.56561 .57047 L 1 g
F P
s
P
p
.002 w
.53088 .57569 m .53098 .57542 L p
.53141 .57536 L 1 g
F P
s
P
p
.56561 .57047 m .53088 .57569 L .53141 .57536 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53182 .57511 L p
1 g
F P
s
P
p
.54854 .56129 m .53182 .57511 L .53238 .57476 L 1 g
F
P
p
.002 w
.56376 .55228 m .56561 .57047 L .53991 .57379 L p
1 g
F P
s
P
p
.002 w
.53991 .57379 m .53238 .57476 L p
.5491 .56279 L 1 g
F P
s
P
p
.56376 .55228 m .53991 .57379 L .5491 .56279 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5491 .56279 L p
1 g
F P
s
P
p
.56075 .54566 m .5491 .56279 L .55559 .55502 L 1 g
F
P
p
.54854 .56129 m .53238 .57476 L .54054 .56891 L 1 g
F
P
p
.002 w
.53182 .57511 m .53128 .57265 L p
.51189 .5826 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.53295 .57468 m .56561 .57047 L p
.53098 .57542 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56178 .54761 L p
1 g
F P
s
P
p
.002 w
.56317 .54646 m .56376 .55228 L p
.55827 .5561 L 1 g
F P
s
P
p
.56317 .54646 m .55827 .5561 L .56141 .54851 L 1 g
F
P
p
.56317 .54646 m .54973 .56203 L .56147 .54798 L 1 g
F
P
p
.56654 .52734 m .56178 .54761 L .5621 .54685 L 1 g
F
P
p
.002 w
.56258 .5454 m .56317 .54646 L .5621 .54685 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56722 .52833 L p
1 g
F P
s
P
p
.57826 .49964 m .5675 .53304 L .5674 .53134 L 1 g
F
P
p
.56515 .50826 m .56722 .52833 L .56657 .51744 L 1 g
F
P
p
.002 w
.57411 .50296 m .57826 .49964 L p
.5674 .53134 L 1 g
F P
s
P
p
.5674 .53134 m .56258 .5454 L .56722 .52833 L 1 g
F
P
p
.5674 .53134 m .56722 .52833 L .57411 .50296 L 1 g
F
P
p
.002 w
.56608 .50937 m .56515 .50826 L p
.56657 .51744 L 1 g
F P
s
P
p
.56654 .52734 m .5621 .54685 L .56258 .5454 L 1 g
F
P
p
.5646 .53797 m .56258 .5454 L .56404 .54104 L 1 g
F
P
p
.56654 .52734 m .56258 .5454 L .5646 .53797 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56258 .5454 m .5497 .52246 L .56608 .50937 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56608 .50937 L p
1 g
F P
s
P
p
.002 w
.56608 .50937 m .57411 .50296 L p
.57001 .51804 L 1 g
F P
s
P
p
.002 w
.57154 .50501 m .56608 .50937 L p
.55769 .4916 L 1 g
F P
s
P
p
.54843 .472 m .55769 .4916 L .54846 .47322 L 1 g
F
P
p
.55769 .4916 m .56608 .50937 L .55719 .49111 L 1 g
F
P
p
.55769 .4916 m .55719 .49111 L .54846 .47322 L 1 g
F
P
p
.55661 .4905 m .55675 .49079 L .55677 .4908 L 1 g
F
P
p
.55675 .49079 m .56608 .50937 L .55677 .4908 L 1 g
F
P
p
.55677 .4908 m .56608 .50937 L .56354 .50376 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.54174 .47608 m .54923 .48342 L .5438 .47816 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5438 .47816 m .52639 .5013 L p
.52535 .4685 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54236 .47676 L p
1 g
F P
s
P
p
.52214 .46667 m .54236 .47676 L .53048 .47099 L 1 g
F
P
p
.54236 .47676 m .5438 .47816 L .52535 .4685 L 1 g
F
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.51398 .46589 m .52535 .4685 L .52639 .5013 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46705 L p
1 g
F P
s
P
p
.5 .4634 m .52237 .46705 L .51025 .46537 L 1 g
F
P
p
.51275 .46238 m .52237 .46705 L .51398 .46589 L 1 g
F
P
p
.52237 .46705 m .52535 .4685 L .51398 .46589 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.52639 .5013 m .49583 .48566 L .50398 .4645 L p
1 g
F P
s
P
p
.5 .4634 m .51025 .46537 L .50398 .4645 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50398 .4645 m .49583 .48566 L p
.48238 .46636 L 1 g
F P
s
P
p
.002 w
.47763 .46705 m .47786 .46667 L p
.48603 .46584 L 1 g
F P
s
P
p
.5 .46383 m .50398 .4645 L .48238 .46636 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46383 L p
1 g
F P
s
P
p
.002 w
.5 .46383 m .5 .46442 L p
.48603 .46584 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46383 L .48603 .46584 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.46475 .44108 m .5023 .4635 L .47801 .4601 L 1 g
F
P
p
.002 w
.5 .46383 m .5 .4634 L p
.50398 .4645 L 1 g
F P
s
P
p
.5023 .4635 m .50398 .4645 L .5 .46383 L 1 g
F
P
p
.5023 .4635 m .5 .46383 L .47801 .4601 L 1 g
F
P
p
.47801 .4601 m .5 .46383 L .48238 .46636 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49583 .48566 m .46171 .47752 L .46194 .47478 L p
1 g
F P
s
P
p
.45826 .47608 m .46773 .47193 L .46194 .47478 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46171 .47752 m .45681 .47757 L p
.45977 .4758 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45757 .47683 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.41751 .51785 m .39942 .48652 L p
.43377 .50988 L 1 g
F P
s
P
p
.002 w
.43341 .51328 m .41751 .51785 L p
.43377 .50988 L 1 g
F P
s
P
p
.002 w
.39942 .48652 m .42822 .47787 L .43457 .50221 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43381 .5095 L p
1 g
F P
s
P
p
.43346 .52734 m .43381 .5095 L .43359 .5116 L 1 g
F
P
p
.43485 .50826 m .4382 .50044 L .43553 .50588 L 1 g
F
P
p
.002 w
.43457 .50221 m .43553 .50588 L p
.43381 .5095 L 1 g
F P
s
P
p
.39942 .48652 m .43457 .50221 L .43381 .5095 L 1 g
F
P
p
.43366 .50981 m .43381 .5095 L .43377 .50988 L 1 g
F
P
p
.39942 .48652 m .43381 .5095 L .43366 .50981 L 1 g
F
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44272 .49122 L p
1 g
F P
s
P
p
.43485 .50826 m .44272 .49122 L .4382 .50044 L 1 g
F
P
p
.002 w
.45989 .5121 m .43718 .5122 L .43553 .50588 L p
1 g
F P
s
P
p
.002 w
.43553 .50588 m .42822 .47787 L p
.44197 .49273 L 1 g
F P
s
P
p
.44197 .49273 m .45989 .5121 L .43553 .50588 L 1 g
F
P
p
.44158 .49231 m .44251 .49163 L .44197 .49273 L 1 g
F
P
p
.002 w
.45681 .47757 m .46171 .47752 L p
.44158 .49231 L 1 g
F P
s
P
p
.002 w
.44272 .49122 m .44166 .49233 L p
.4382 .50044 L 1 g
F P
s
P
p
.43553 .50588 m .44166 .49233 L .43367 .50966 L 1 g
F
P
p
.4382 .50044 m .43895 .49867 L .43553 .50588 L 1 g
F
P
p
.43895 .49867 m .44166 .49233 L .43553 .50588 L 1 g
F
P
p
.002 w
.43367 .50966 m .43381 .5095 L p
.43553 .50588 L 1 g
F P
s
P
p
.002 w
.43381 .5095 m .43485 .50826 L p
.43553 .50588 L 1 g
F P
s
P
p
.43377 .50988 m .43381 .5095 L .43718 .5122 L 1 g
F
P
p
.002 w
.43553 .50588 m .43718 .5122 L p
.43381 .5095 L 1 g
F P
s
P
p
.002 w
.43381 .5095 m .4336 .50974 L p
.43359 .5116 L 1 g
F P
s
P
p
.002 w
.41751 .51785 m .42857 .51467 L p
.43248 .53049 L 1 g
F P
s
P
p
.002 w
.42857 .51467 m .43341 .51328 L p
.43258 .52862 L 1 g
F P
s
P
p
.42857 .51467 m .43258 .52862 L .43248 .53049 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43258 .52862 L p
1 g
F P
s
P
p
.43925 .54566 m .43258 .52862 L .43515 .53755 L 1 g
F
P
p
.43346 .52734 m .4336 .50974 L .43314 .51825 L 1 g
F
P
p
.002 w
.43207 .53807 m .41751 .51785 L p
.43248 .53049 L 1 g
F P
s
P
p
.002 w
.43167 .52995 m .43258 .52862 L p
.43308 .51645 L 1 g
F P
s
P
p
.002 w
.43258 .52862 m .43346 .52734 L p
.43314 .51825 L 1 g
F P
s
P
p
.43314 .51825 m .43308 .51645 L .43258 .52862 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4382 .54764 L p
1 g
F P
s
P
p
.002 w
.45344 .56645 m .43057 .55142 L .43281 .54985 L p
1 g
F P
s
P
p
.43925 .54566 m .43515 .53755 L .43548 .53871 L 1 g
F
P
p
.002 w
.43744 .54553 m .43207 .53807 L p
.43565 .5393 L 1 g
F P
s
P
p
.002 w
.4382 .54764 m .43925 .54566 L p
.43548 .53871 L 1 g
F P
s
P
p
.43248 .53049 m .43333 .5312 L .43207 .53807 L 1 g
F
P
p
.43333 .5312 m .43565 .5393 L .43207 .53807 L 1 g
F
P
p
.002 w
.43057 .55142 m .40308 .52829 L p
.43761 .54608 L 1 g
F P
s
P
p
.002 w
.43772 .54643 m .43057 .55142 L p
.43761 .54608 L 1 g
F P
s
P
p
.43548 .53871 m .43744 .54553 L .4382 .54764 L 1 g
F
P
p
.43744 .54553 m .43766 .54629 L .43772 .54643 L 1 g
F
P
p
.43744 .54553 m .43772 .54643 L .4382 .54764 L 1 g
F
P
p
.002 w
.40308 .52829 m .41751 .51785 L .43744 .54553 L p
1 g
F P
s
P
p
.002 w
.43744 .54553 m .43797 .54626 L p
.43761 .54608 L 1 g
F P
s
P
p
.40308 .52829 m .43744 .54553 L .43761 .54608 L 1 g
F
P
p
.002 w
.43797 .54626 m .43772 .54643 L p
.43761 .54608 L 1 g
F P
s
P
p
.43744 .54553 m .43225 .53273 L .43766 .54629 L 1 g
F
P
p
.43548 .53871 m .43521 .53821 L .43744 .54553 L 1 g
F
P
p
.43521 .53821 m .43225 .53273 L .43744 .54553 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43333 .5312 m .44792 .54352 L .43565 .5393 L 1 g
F
P
p
.002 w
.44792 .54352 m .43797 .54626 L .43744 .54553 L p
1 g
F P
s
P
p
.43565 .5393 m .44792 .54352 L .43744 .54553 L 1 g
F
P
p
.002 w
.43146 .53025 m .43225 .53273 L p
.43548 .53871 L 1 g
F P
s
P
p
.43515 .53755 m .43146 .53025 L .43548 .53871 L 1 g
F
P
p
.002 w
.43281 .54985 m .4374 .54665 L p
.4382 .54764 L 1 g
F P
s
P
p
.43281 .54985 m .4382 .54764 L .44172 .55645 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56315 L p
1 g
F P
s
P
p
.46872 .57265 m .45077 .56315 L .45758 .5682 L 1 g
F
P
p
.45146 .56129 m .4382 .54764 L .44403 .55483 L 1 g
F
P
p
.44172 .55645 m .4382 .54764 L .45077 .56315 L 1 g
F
P
p
.43281 .54985 m .45077 .56315 L .45344 .56645 L 1 g
F
P
p
.002 w
.42649 .55839 m .43057 .55142 L .45344 .56645 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45076 .56319 L p
1 g
F P
s
P
p
.002 w
.45076 .56319 m .45146 .56129 L p
.44353 .5544 L 1 g
F P
s
P
p
.44353 .5544 m .43743 .5491 L .45076 .56319 L 1 g
F
P
p
.002 w
.45344 .56645 m .46001 .57077 L .45568 .56917 L p
1 g
F P
s
P
p
.002 w
.45568 .56917 m .42649 .55839 L p
.45344 .56645 L 1 g
F P
s
P
p
.002 w
.4374 .54665 m .43797 .54626 L p
.45344 .56645 L 1 g
F P
s
P
p
.002 w
.43225 .53273 m .43743 .5491 L .4382 .54764 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46001 .57077 m .45344 .56645 L p
.4511 .5634 L 1 g
F P
s
P
p
.46872 .57265 m .45758 .5682 L .45793 .56846 L 1 g
F
P
p
.002 w
.45949 .5696 m .46001 .57077 L .45793 .56846 L p
1 g
F P
s
P
p
.45902 .56926 m .45793 .56846 L .459 .56925 L 1 g
F
P
p
.46872 .57265 m .45793 .56846 L .45902 .56926 L 1 g
F
P
p
.46872 .57265 m .459 .56925 L .45952 .56962 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43797 .54626 m .44792 .54352 L .45949 .5696 L p
1 g
F P
s
P
p
.002 w
.45793 .56846 m .43797 .54626 L p
.45949 .5696 L 1 g
F P
s
P
p
.46872 .57265 m .45949 .56961 L .45982 .56984 L 1 g
F
P
p
.46872 .57265 m .45978 .56983 L .46003 .56999 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44792 .54352 m .45933 .54354 L .45999 .56996 L p
1 g
F P
s
P
p
.002 w
.45999 .56996 m .46001 .57077 L .45949 .5696 L p
1 g
F P
s
P
p
.002 w
.45949 .5696 m .44792 .54352 L p
.45999 .56996 L 1 g
F P
s
P
p
.45952 .56962 m .459 .56925 L .45949 .56961 L 1 g
F
P
p
.45982 .56984 m .45949 .56961 L .45978 .56983 L 1 g
F
P
p
.46872 .57265 m .45999 .56998 L .46019 .57011 L 1 g
F
P
p
.46872 .57265 m .46014 .5701 L .46033 .57021 L 1 g
F
P
p
.002 w
.45933 .54354 m .4709 .54632 L .46028 .57016 L p
1 g
F P
s
P
p
.002 w
.46028 .57016 m .46001 .57077 L .45999 .56996 L p
1 g
F P
s
P
p
.002 w
.45999 .56996 m .45933 .54354 L p
.46028 .57016 L 1 g
F P
s
P
p
.46872 .57265 m .46027 .57019 L .46045 .5703 L 1 g
F
P
p
.46872 .57265 m .46039 .57028 L .46057 .57038 L 1 g
F
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.4709 .54632 m .48133 .55156 L .46052 .57032 L p
1 g
F P
s
P
p
.002 w
.46052 .57032 m .46001 .57077 L .46028 .57016 L p
1 g
F P
s
P
p
.002 w
.46028 .57016 m .4709 .54632 L p
.46052 .57032 L 1 g
F P
s
P
p
.46003 .56999 m .45978 .56983 L .45999 .56998 L 1 g
F
P
p
.46019 .57011 m .45999 .56998 L .46014 .5701 L 1 g
F
P
p
.002 w
.46826 .57474 m .46872 .57265 L p
.4605 .57036 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48133 .55156 m .48945 .55864 L .46075 .57047 L p
1 g
F P
s
P
p
.002 w
.46075 .57047 m .46001 .57077 L .46052 .57032 L p
1 g
F P
s
P
p
.002 w
.46052 .57032 m .48133 .55156 L p
.46075 .57047 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48945 .55864 m .49435 .56677 L .46105 .57065 L p
1 g
F P
s
P
p
.002 w
.46105 .57065 m .46001 .57077 L .46075 .57047 L p
1 g
F P
s
P
p
.002 w
.46075 .57047 m .48945 .55864 L p
.46105 .57065 L 1 g
F P
s
P
p
.46033 .57021 m .46014 .5701 L .46027 .57019 L 1 g
F
P
p
.46045 .5703 m .46027 .57019 L .46039 .57028 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49435 .56677 m .49555 .57503 L .46158 .57096 L p
1 g
F P
s
P
p
.002 w
.46158 .57096 m .46001 .57077 L .46105 .57065 L p
1 g
F P
s
P
p
.002 w
.46105 .57065 m .49435 .56677 L p
.46158 .57096 L 1 g
F P
s
P
p
.48921 .57862 m .47811 .57771 L .48705 .5804 L 1 g
F
P
p
.002 w
.49306 .58221 m .49296 .58251 L .48863 .58097 L p
1 g
F P
s
P
p
.002 w
.48863 .58097 m .48705 .5804 L p
.48903 .581 L 1 g
F P
s
P
p
.49306 .58221 m .48863 .58097 L .48903 .581 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .581 L p
1 g
F P
s
P
p
.51079 .57862 m .48903 .581 L .49336 .58135 L 1 g
F
P
p
.002 w
.49296 .58251 m .49336 .58135 L p
.50043 .58102 L 1 g
F P
s
P
p
.49827 .58112 m .49336 .58135 L .49605 .58157 L 1 g
F
P
p
.51079 .57862 m .49336 .58135 L .49827 .58112 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49555 .57503 m .53117 .57491 L p
.50043 .58102 L 1 g
F P
s
P
p
.002 w
.49336 .58135 m .49555 .57503 L p
.50043 .58102 L 1 g
F P
s
P
p
.002 w
.48903 .581 m .48921 .57862 L p
.48705 .5804 L 1 g
F P
s
P
p
.002 w
.4735 .57963 m .46417 .5735 L p
.46845 .57484 L 1 g
F P
s
P
p
.48779 .58089 m .47759 .57999 L .46845 .57484 L 1 g
F
P
p
.47759 .57999 m .4735 .57963 L .46845 .57484 L 1 g
F
P
p
.002 w
.48705 .5804 m .48863 .58097 L p
.46417 .5735 L 1 g
F P
s
P
p
.002 w
.48863 .58097 m .49296 .58251 L p
.48779 .58089 L 1 g
F P
s
P
p
.48779 .58089 m .46417 .5735 L .48863 .58097 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46826 .57477 L p
1 g
F P
s
P
p
.002 w
.46826 .57477 m .4678 .57686 L p
.47805 .5777 L 1 g
F P
s
P
p
.48921 .57862 m .46826 .57477 L .47805 .5777 L 1 g
F
P
p
.002 w
.49555 .57503 m .49336 .58135 L p
.46332 .57195 L 1 g
F P
s
P
p
.002 w
.49336 .58135 m .49306 .58221 L p
.48972 .58106 L 1 g
F P
s
P
p
.49336 .58135 m .48972 .58106 L .46332 .57195 L 1 g
F
P
p
.002 w
.48705 .5804 m .46332 .57195 L p
.49306 .58221 L 1 g
F P
s
P
p
.002 w
.48903 .581 m .48903 .581 L p
.49605 .58157 L 1 g
F P
s
P
p
.49296 .58251 m .4735 .57963 L .48779 .58089 L 1 g
F
P
p
.002 w
.48903 .581 m .48889 .583 L p
.49584 .58161 L 1 g
F P
s
P
p
.49605 .58157 m .48903 .581 L .49584 .58161 L 1 g
F
P
p
.002 w
.48903 .581 m .48903 .581 L p
.48705 .5804 L 1 g
F P
s
P
p
.002 w
.46332 .57195 m .46001 .57077 L .46158 .57096 L p
1 g
F P
s
P
p
.002 w
.46158 .57096 m .49555 .57503 L p
.46332 .57195 L 1 g
F P
s
P
p
.46057 .57038 m .46039 .57028 L .4605 .57036 L 1 g
F
P
p
.002 w
.46417 .5735 m .46001 .57077 L .46332 .57195 L p
1 g
F P
s
P
p
.002 w
.46332 .57195 m .48705 .5804 L p
.46826 .57474 L 1 g
F P
s
P
p
.46826 .57474 m .46417 .5735 L .46332 .57195 L 1 g
F
P
p
.002 w
.45793 .56846 m .46001 .57077 L p
.4511 .5634 L 1 g
F P
s
P
p
.002 w
.46166 .57272 m .46001 .57077 L .46417 .5735 L p
1 g
F P
s
P
p
.002 w
.42949 .57457 m .42614 .5664 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.002 w
.42614 .5664 m .42649 .55839 L .46001 .57077 L closepath p
1 g
F P
s
P
p
.4605 .57036 m .45002 .56518 L .468 .57592 L 1 g
F
P
p
.45758 .5682 m .45442 .56694 L .4605 .57036 L 1 g
F
P
p
.45442 .56694 m .45002 .56518 L .4605 .57036 L 1 g
F
P
p
.002 w
.468 .57592 m .46826 .57474 L p
.4605 .57036 L 1 g
F P
s
P
p
.002 w
.43797 .54626 m .45793 .56846 L p
.4511 .5634 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .468 .57592 L p
1 g
F P
s
P
p
.002 w
.45077 .56315 m .45002 .56518 L p
.45758 .5682 L 1 g
F P
s
P
p
.002 w
.4382 .54764 m .43743 .5491 L p
.44403 .55483 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43718 .5122 m .44792 .54352 L p
.43248 .53049 L 1 g
F P
s
P
p
.002 w
.43341 .51328 m .43718 .5122 L p
.43248 .53049 L 1 g
F P
s
P
p
.002 w
.43258 .52862 m .43146 .53025 L p
.43515 .53755 L 1 g
F P
s
P
p
.002 w
.4336 .50974 m .43287 .51061 L p
.43314 .51825 L 1 g
F P
s
P
p
.002 w
.43718 .5122 m .43341 .51328 L p
.43377 .50988 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43167 .52995 L p
1 g
F P
s
P
p
.43308 .51645 m .43287 .51061 L .43167 .52995 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43367 .50966 L p
1 g
F P
s
P
p
.002 w
.46171 .47752 m .45989 .5121 L p
.44197 .49273 L 1 g
F P
s
P
p
.44251 .49163 m .46171 .47752 L .44197 .49273 L 1 g
F
P
p
.44339 .4905 m .45757 .47683 L .45195 .48229 L 1 g
F
P
p
.002 w
.42822 .47787 m .45681 .47757 L p
.44158 .49231 L 1 g
F P
s
P
p
.45195 .48229 m .45681 .47757 L .45698 .47747 L 1 g
F
P
p
.45977 .4758 m .45681 .47757 L .45757 .47683 L 1 g
F
P
p
.002 w
.45757 .47683 m .45755 .47686 L p
.45681 .47757 L 1 g
F P
s
P
p
.002 w
.45755 .47686 m .45698 .47747 L p
.45681 .47757 L 1 g
F P
s
P
p
.002 w
.45597 .47758 m .42822 .47787 L p
.45855 .47588 L 1 g
F P
s
P
p
.002 w
.45757 .47683 m .45826 .47608 L p
.46194 .47478 L 1 g
F P
s
P
p
.48152 .46513 m .49583 .48566 L .46194 .47478 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47732 .46757 L p
1 g
F P
s
P
p
.002 w
.47732 .46757 m .47718 .46778 L p
.47219 .46997 L 1 g
F P
s
P
p
.45826 .47608 m .47732 .46757 L .47219 .46997 L 1 g
F
P
p
.002 w
.42144 .44182 m .46475 .44108 L .46194 .47478 L p
1 g
F P
s
P
p
.002 w
.46194 .47478 m .46171 .47752 L p
.45977 .4758 L 1 g
F P
s
P
p
.42144 .44182 m .46194 .47478 L .45977 .4758 L 1 g
F
P
p
.45977 .4758 m .45757 .47683 L .45855 .47588 L 1 g
F
P
p
.45757 .47683 m .45597 .47758 L .45855 .47588 L 1 g
F
P
p
.002 w
.45681 .47757 m .45597 .47758 L p
.45757 .47683 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44201 .49196 L p
1 g
F P
s
P
p
.002 w
.44201 .49196 m .44339 .4905 L p
.45195 .48229 L 1 g
F P
s
P
p
.45195 .48229 m .45698 .47747 L .44201 .49196 L 1 g
F
P
p
.002 w
.4574 .47702 m .45757 .47683 L p
.46194 .47478 L 1 g
F P
s
P
p
.002 w
.42822 .47787 m .42144 .44182 L p
.45977 .4758 L 1 g
F P
s
P
p
.002 w
.46194 .47478 m .46475 .44108 L p
.48152 .46513 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4574 .47702 L p
1 g
F P
s
P
p
.46773 .47193 m .47718 .46778 L .4574 .47702 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47763 .46705 L p
1 g
F P
s
P
p
.48603 .46584 m .5 .46442 L .47763 .46705 L 1 g
F
P
p
.002 w
.5 .46395 m .5 .46383 L p
.50398 .4645 L 1 g
F P
s
P
p
.002 w
.46475 .44108 m .50896 .45157 L .50398 .4645 L p
1 g
F P
s
P
p
.002 w
.50398 .4645 m .50896 .45157 L p
.51398 .46589 L 1 g
F P
s
P
p
.51398 .46589 m .52639 .5013 L .50398 .4645 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.51025 .46537 m .52282 .46778 L .5 .46395 L 1 g
F
P
p
.002 w
.52237 .46705 m .52282 .46778 L p
.51025 .46537 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46705 L p
1 g
F P
s
P
p
.002 w
.52237 .46705 m .52214 .46667 L p
.53048 .47099 L 1 g
F P
s
P
p
.53048 .47099 m .54302 .47747 L .52237 .46705 L 1 g
F
P
p
.002 w
.50896 .45157 m .52508 .45992 L p
.52535 .4685 L 1 g
F P
s
P
p
.50896 .45157 m .52535 .4685 L .51275 .46238 L 1 g
F
P
p
.52508 .45992 m .54236 .47676 L .52535 .4685 L 1 g
F
P
p
.002 w
.54236 .47676 m .54302 .47747 L p
.53048 .47099 L 1 g
F P
s
P
p
.002 w
.54244 .47685 m .54236 .47676 L p
.5438 .47816 L 1 g
F P
s
P
p
.002 w
.54236 .47676 m .54174 .47608 L p
.5438 .47816 L 1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55719 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55719 .49111 L .54923 .48342 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52508 .45992 m .54843 .472 L .5438 .47816 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56608 .50937 m .5497 .52246 L p
.54846 .47322 L 1 g
F P
s
P
p
.002 w
.5497 .52246 m .52639 .5013 L .54843 .472 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54244 .47685 L p
1 g
F P
s
P
p
.54923 .48342 m .55834 .49233 L .54244 .47685 L 1 g
F
P
p
.002 w
.55719 .49111 m .55834 .49233 L p
.54923 .48342 L 1 g
F P
s
P
p
.002 w
.54843 .472 m .57826 .49964 L .57154 .50501 L p
1 g
F P
s
P
p
.54843 .472 m .57154 .50501 L .55769 .4916 L 1 g
F
P
p
.002 w
.56608 .50937 m .56713 .51061 L p
.56354 .50376 L 1 g
F P
s
P
p
.57001 .51804 m .56722 .52833 L .56608 .50937 L 1 g
F
P
p
.57001 .51804 m .56608 .50937 L .56608 .50937 L 1 g
F
P
p
.002 w
.56317 .54646 m .56258 .5454 L p
.5674 .53134 L 1 g
F P
s
P
p
.5675 .53304 m .56317 .54646 L .5674 .53134 L 1 g
F
P
p
.002 w
.56178 .54761 m .56075 .54566 L p
.55559 .55502 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.53117 .57491 m .52916 .55858 L .5621 .54685 L p
1 g
F P
s
P
p
.002 w
.5621 .54685 m .56317 .54646 L p
.56172 .54776 L 1 g
F P
s
P
p
.56172 .54776 m .53117 .57491 L .5621 .54685 L 1 g
F
P
p
.002 w
.57826 .49964 m .59513 .53088 L .56317 .54646 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56654 .52734 L p
.56368 .54303 L 1 g
F P
s
P
p
.002 w
.56561 .57047 m .56317 .54646 L .59513 .53088 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56716 .53461 L p
.56368 .54303 L 1 g
F P
s
P
p
.002 w
.56716 .53461 m .56854 .53025 L p
.56368 .54303 L 1 g
F P
s
P
p
.56722 .52833 m .56258 .5454 L .56608 .50937 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56608 .50937 L p
1 g
F P
s
P
p
.56657 .51744 m .56854 .53025 L .56608 .50937 L 1 g
F
P
p
.002 w
.56722 .52833 m .56854 .53025 L p
.56657 .51744 L 1 g
F P
s
P
p
.56404 .54104 m .56258 .5454 L .56368 .54303 L 1 g
F
P
p
.56258 .5454 m .5621 .54685 L .56236 .54621 L 1 g
F
P
p
.56258 .5454 m .56236 .54621 L .56368 .54303 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5497 .52246 m .56258 .5454 L p
.52916 .55858 L 1 g
F P
s
P
p
.002 w
.5621 .54685 m .52916 .55858 L p
.56258 .5454 L 1 g
F P
s
P
p
.002 w
.56178 .54761 m .56257 .5491 L p
.56368 .54303 L 1 g
F P
s
P
p
.56141 .54851 m .55827 .5561 L .54973 .56203 L 1 g
F
P
p
.56147 .54798 m .54973 .56203 L .53117 .57491 L 1 g
F
P
p
.002 w
.53238 .57476 m .53117 .57491 L p
.56376 .55228 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56178 .54761 L p
1 g
F P
s
P
p
.55559 .55502 m .54998 .56518 L .56178 .54761 L 1 g
F
P
p
.002 w
.5491 .56279 m .54998 .56518 L p
.55559 .55502 L 1 g
F P
s
P
p
.54054 .56891 m .53238 .57476 L .53825 .57109 L 1 g
F
P
p
.002 w
.53098 .57542 m .53117 .57491 L .53295 .57468 L p
1 g
F P
s
P
p
.002 w
.53182 .57511 m .5322 .57686 L p
.53825 .57109 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53182 .57511 L p
1 g
F P
s
P
p
.51189 .5826 m .51111 .583 L .53182 .57511 L 1 g
F
P
p
.002 w
.53117 .57491 m .53098 .57542 L p
.50043 .58102 L 1 g
F P
s
P
p
.53098 .57542 m .51093 .58054 L .50043 .58102 L 1 g
F
P
p
.002 w
.51111 .58296 m .51093 .58054 L p
.49584 .58161 L 1 g
F P
s
P
p
.49827 .58112 m .49584 .58161 L .51093 .58054 L 1 g
F
P
p
.002 w
.48692 .58843 m .49296 .58251 L .52573 .58957 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51111 .58296 L p
1 g
F P
s
P
p
.49584 .58161 m .48889 .583 L .51111 .58296 L 1 g
F
P
p
.002 w
.48902 .58122 m .48903 .581 L p
.47756 .57766 L 1 g
F P
s
P
p
.47811 .57771 m .47756 .57766 L .48903 .581 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58122 L p
1 g
F P
s
P
p
.47756 .57766 m .4678 .57686 L .48902 .58122 L 1 g
F
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.61455 .35327 m .65892 .39752 L .6453 .42276 L p
1 g
F P
s
P
p
.002 w
.65892 .39752 m .61455 .35327 L .62271 .32872 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.40308 .52829 m .39536 .54222 L .36768 .52289 L p
1 g
F P
s
P
p
.002 w
.36768 .52289 m .37855 .50221 L .40308 .52829 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.62692 .44882 m .6485 .49181 L .6239 .51242 L p
1 g
F P
s
P
p
.002 w
.6485 .49181 m .62692 .44882 L .6453 .42276 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.5618 .29564 m .62271 .32872 L .61455 .35327 L p
1 g
F P
s
P
p
.002 w
.3844 .45345 m .35787 .47417 L .3417 .44517 L p
1 g
F P
s
P
p
.002 w
.3417 .44517 m .373 .41987 L .3844 .45345 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.41534 .37008 m .36559 .38702 L .36235 .35609 L p
1 g
F P
s
P
p
.002 w
.36235 .35609 m .4162 .33711 L .41534 .37008 L p
1 g
F P
s
P
p
.002 w
.43057 .55142 m .42649 .55839 L .39536 .54222 L p
1 g
F P
s
P
p
.002 w
.39536 .54222 m .40308 .52829 L .43057 .55142 L p
1 g
F P
s
P
p
.002 w
.55433 .32081 m .4862 .30491 L .49279 .27959 L p
1 g
F P
s
P
p
.002 w
.49279 .27959 m .5618 .29564 L .55433 .32081 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39942 .48652 m .37855 .50221 L .35787 .47417 L p
1 g
F P
s
P
p
.002 w
.35787 .47417 m .3844 .45345 L .39942 .48652 L p
1 g
F P
s
P
p
.002 w
.60432 .47478 m .6239 .51242 L .59513 .53088 L p
1 g
F P
s
P
p
.002 w
.6239 .51242 m .60432 .47478 L .62692 .44882 L p
1 g
F P
s
P
p
.002 w
.61455 .35327 m .55433 .32081 L .5618 .29564 L p
1 g
F P
s
P
p
.002 w
.52916 .55858 m .53117 .57491 L .49555 .57503 L p
1 g
F P
s
P
p
.002 w
.47986 .33481 m .4162 .33711 L .41957 .30767 L p
1 g
F P
s
P
p
.002 w
.41957 .30767 m .4862 .30491 L .47986 .33481 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60263 .38087 m .6453 .42276 L .62692 .44882 L p
1 g
F P
s
P
p
.002 w
.6453 .42276 m .60263 .38087 L .61455 .35327 L p
1 g
F P
s
P
p
.002 w
.49555 .57503 m .49435 .56677 L .52916 .55858 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41709 .40542 m .373 .41987 L .36559 .38702 L p
1 g
F P
s
P
p
.002 w
.36559 .38702 m .41534 .37008 L .41709 .40542 L p
1 g
F P
s
P
p
.002 w
.41751 .51785 m .40308 .52829 L .37855 .50221 L p
1 g
F P
s
P
p
.002 w
.37855 .50221 m .39942 .48652 L .41751 .51785 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59513 .53088 m .57826 .49964 L .60432 .47478 L p
1 g
F P
s
P
p
.002 w
.55433 .32081 m .61455 .35327 L .60263 .38087 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49435 .56677 m .48945 .55864 L .51972 .54236 L p
1 g
F P
s
P
p
.002 w
.51972 .54236 m .52916 .55858 L .49435 .56677 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.52916 .55858 m .51972 .54236 L .5497 .52246 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48945 .55864 m .48133 .55156 L .50373 .52814 L p
1 g
F P
s
P
p
.002 w
.50373 .52814 m .51972 .54236 L .48945 .55864 L p
1 g
F P
s
P
p
.002 w
.58728 .4106 m .62692 .44882 L .60432 .47478 L p
1 g
F P
s
P
p
.002 w
.62692 .44882 m .58728 .4106 L .60263 .38087 L p
1 g
F P
s
P
p
.002 w
.42144 .44182 m .3844 .45345 L .373 .41987 L p
1 g
F P
s
P
p
.002 w
.373 .41987 m .41709 .40542 L .42144 .44182 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.54497 .35007 m .47986 .33481 L .4862 .30491 L p
1 g
F P
s
P
p
.002 w
.4862 .30491 m .55433 .32081 L .54497 .35007 L p
1 g
F P
s
P
p
.002 w
.47401 .36831 m .41534 .37008 L .4162 .33711 L p
1 g
F P
s
P
p
.002 w
.4162 .33711 m .47986 .33481 L .47401 .36831 L p
1 g
F P
s
P
p
.002 w
.45933 .54354 m .44792 .54352 L .43718 .5122 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48133 .55156 m .4709 .54632 L .48298 .51763 L p
1 g
F P
s
P
p
.002 w
.48298 .51763 m .50373 .52814 L .48133 .55156 L p
1 g
F P
s
P
p
.002 w
.60263 .38087 m .54497 .35007 L .55433 .32081 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4709 .54632 m .45933 .54354 L .45989 .5121 L p
1 g
F P
s
P
p
.002 w
.43718 .5122 m .45989 .5121 L .45933 .54354 L p
1 g
F P
s
P
p
.002 w
.45989 .5121 m .48298 .51763 L .4709 .54632 L p
1 g
F P
s
P
p
.002 w
.42822 .47787 m .39942 .48652 L .3844 .45345 L p
1 g
F P
s
P
p
.002 w
.3844 .45345 m .42144 .44182 L .42822 .47787 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54497 .35007 m .60263 .38087 L .58728 .4106 L p
1 g
F P
s
P
p
.002 w
.51972 .54236 m .50373 .52814 L .52639 .5013 L p
1 g
F P
s
P
p
.002 w
.52639 .5013 m .5497 .52246 L .51972 .54236 L p
1 g
F P
s
P
p
.002 w
.56899 .44137 m .60432 .47478 L .57826 .49964 L p
1 g
F P
s
P
p
.002 w
.60432 .47478 m .56899 .44137 L .58728 .4106 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57826 .49964 m .54843 .472 L .56899 .44137 L p
1 g
F P
s
P
p
.002 w
.46891 .40419 m .41709 .40542 L .41534 .37008 L p
1 g
F P
s
P
p
.002 w
.41534 .37008 m .47401 .36831 L .46891 .40419 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53402 .38243 m .47401 .36831 L .47986 .33481 L p
1 g
F P
s
P
p
.002 w
.47986 .33481 m .54497 .35007 L .53402 .38243 L p
1 g
F P
s
P
p
.002 w
.50373 .52814 m .48298 .51763 L .49583 .48566 L p
1 g
F P
s
P
p
.002 w
.49583 .48566 m .52639 .5013 L .50373 .52814 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.58728 .4106 m .53402 .38243 L .54497 .35007 L p
1 g
F P
s
P
p
.002 w
.48298 .51763 m .45989 .5121 L .46171 .47752 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.53402 .38243 m .58728 .4106 L .56899 .44137 L p
1 g
F P
s
P
p
.002 w
.46171 .47752 m .49583 .48566 L .48298 .51763 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.46475 .44108 m .42144 .44182 L .41709 .40542 L p
1 g
F P
s
P
p
.002 w
.41709 .40542 m .46891 .40419 L .46475 .44108 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.004 w
.44368 .62805 m
.44658 .61788 L
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.52186 .41671 m .56899 .44137 L .54843 .472 L p
1 g
F P
s
P
p
.002 w
.56899 .44137 m .52186 .41671 L .53402 .38243 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52186 .41671 m .46891 .40419 L .47401 .36831 L p
1 g
F P
s
P
p
.002 w
.47401 .36831 m .53402 .38243 L .52186 .41671 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.54843 .472 m .50896 .45157 L .52186 .41671 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50896 .45157 m .46475 .44108 L .46891 .40419 L p
1 g
F P
s
P
p
.002 w
.46891 .40419 m .52186 .41671 L .50896 .45157 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .62609 .70079 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4366 .65289 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0257895)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0257895)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44125 .41967 m .47393 .44522 L .48838 .42061 L p
1 g
F P
s
P
p
.002 w
.48838 .42061 m .46122 .39921 L .44125 .41967 L p
1 g
F P
s
P
p
.002 w
.5205 .43446 m .48838 .42061 L .47393 .44522 L p
1 g
F P
s
P
p
.002 w
.46122 .39921 m .48838 .42061 L .50312 .39622 L p
1 g
F P
s
P
p
.002 w
.48838 .42061 m .5205 .43446 L .52806 .40697 L p
1 g
F P
s
P
p
.002 w
.52806 .40697 m .50312 .39622 L .48838 .42061 L p
1 g
F P
s
P
p
.002 w
.47393 .44522 m .51245 .46185 L .5205 .43446 L p
1 g
F P
s
P
p
.002 w
.55456 .43947 m .5205 .43446 L .51245 .46185 L p
1 g
F P
s
P
p
.002 w
.5205 .43446 m .55456 .43947 L .5545 .41074 L p
1 g
F P
s
P
p
.002 w
.5545 .41074 m .52806 .40697 L .5205 .43446 L p
1 g
F P
s
P
p
.002 w
.42256 .44054 m .46003 .46962 L .47393 .44522 L p
1 g
F P
s
P
p
.002 w
.47393 .44522 m .44125 .41967 L .42256 .44054 L p
1 g
F P
s
P
p
.002 w
.51245 .46185 m .47393 .44522 L .46003 .46962 L p
1 g
F P
s
P
p
.002 w
.46003 .46962 m .50405 .48864 L .51245 .46185 L p
1 g
F P
s
P
p
.002 w
.55329 .46803 m .51245 .46185 L .50405 .48864 L p
1 g
F P
s
P
p
.002 w
.51245 .46185 m .55329 .46803 L .55456 .43947 L p
1 g
F P
s
P
p
.002 w
.50312 .39622 m .48211 .37954 L .46122 .39921 L p
1 g
F P
s
P
p
.002 w
.48211 .37954 m .50312 .39622 L .51788 .37249 L p
1 g
F P
s
P
p
.002 w
.50312 .39622 m .52806 .40697 L .53499 .37986 L p
1 g
F P
s
P
p
.002 w
.53499 .37986 m .51788 .37249 L .50312 .39622 L p
1 g
F P
s
P
p
.002 w
.52806 .40697 m .5545 .41074 L .55311 .38236 L p
1 g
F P
s
P
p
.002 w
.55311 .38236 m .53499 .37986 L .52806 .40697 L p
1 g
F P
s
P
p
.002 w
.41754 .38743 m .44125 .41967 L .46122 .39921 L p
1 g
F P
s
P
p
.002 w
.46122 .39921 m .44169 .37222 L .41754 .38743 L p
1 g
F P
s
P
p
.002 w
.44169 .37222 m .46122 .39921 L .48211 .37954 L p
1 g
F P
s
P
p
.002 w
.48211 .37954 m .46713 .35852 L .44169 .37222 L p
1 g
F P
s
P
p
.002 w
.46713 .35852 m .48211 .37954 L .50353 .36102 L p
1 g
F P
s
P
p
.002 w
.51788 .37249 m .50353 .36102 L .48211 .37954 L p
1 g
F P
s
P
p
.002 w
.58731 .435 m .55456 .43947 L .55329 .46803 L p
1 g
F P
s
P
p
.002 w
.55456 .43947 m .58731 .435 L .57983 .40707 L p
1 g
F P
s
P
p
.002 w
.57983 .40707 m .5545 .41074 L .55456 .43947 L p
1 g
F P
s
P
p
.002 w
.40553 .46144 m .44694 .49335 L .46003 .46962 L p
1 g
F P
s
P
p
.002 w
.46003 .46962 m .42256 .44054 L .40553 .46144 L p
1 g
F P
s
P
p
.002 w
.50405 .48864 m .46003 .46962 L .44694 .49335 L p
1 g
F P
s
P
p
.002 w
.5545 .41074 m .57983 .40707 L .57041 .37972 L p
1 g
F P
s
P
p
.002 w
.57041 .37972 m .55311 .38236 L .5545 .41074 L p
1 g
F P
s
P
p
.002 w
.44694 .49335 m .49545 .51434 L .50405 .48864 L p
1 g
F P
s
P
p
.002 w
.55072 .4959 m .50405 .48864 L .49545 .51434 L p
1 g
F P
s
P
p
.002 w
.50405 .48864 m .55072 .4959 L .55329 .46803 L p
1 g
F P
s
P
p
.002 w
.39518 .40387 m .42256 .44054 L .44125 .41967 L p
1 g
F P
s
P
p
.002 w
.44125 .41967 m .41754 .38743 L .39518 .40387 L p
1 g
F P
s
P
p
.002 w
.50353 .36102 m .51788 .37249 L .53241 .34988 L p
1 g
F P
s
P
p
.002 w
.51788 .37249 m .53499 .37986 L .54115 .35364 L p
1 g
F P
s
P
p
.002 w
.54115 .35364 m .53241 .34988 L .51788 .37249 L p
1 g
F P
s
P
p
.002 w
.53499 .37986 m .55311 .38236 L .5504 .35488 L p
1 g
F P
s
P
p
.002 w
.5504 .35488 m .54115 .35364 L .53499 .37986 L p
1 g
F P
s
P
p
.002 w
.59268 .46299 m .55329 .46803 L .55072 .4959 L p
1 g
F P
s
P
p
.002 w
.55329 .46803 m .59268 .46299 L .58731 .435 L p
1 g
F P
s
P
p
.002 w
.50353 .36102 m .49339 .34656 L .46713 .35852 L p
1 g
F P
s
P
p
.002 w
.49339 .34656 m .50353 .36102 L .5251 .34399 L p
1 g
F P
s
P
p
.002 w
.53241 .34988 m .5251 .34399 L .50353 .36102 L p
1 g
F P
s
P
p
.002 w
.55311 .38236 m .57041 .37972 L .5592 .35346 L p
1 g
F P
s
P
p
.002 w
.5592 .35346 m .5504 .35488 L .55311 .38236 L p
1 g
F P
s
P
p
.002 w
.37506 .42123 m .40553 .46144 L .42256 .44054 L p
1 g
F P
s
P
p
.002 w
.42256 .44054 m .39518 .40387 L .37506 .42123 L p
1 g
F P
s
P
p
.002 w
.43189 .34216 m .44169 .37222 L .46713 .35852 L p
1 g
F P
s
P
p
.002 w
.46713 .35852 m .45982 .33518 L .43189 .34216 L p
1 g
F P
s
P
p
.002 w
.45982 .33518 m .46713 .35852 L .49339 .34656 L p
1 g
F P
s
P
p
.002 w
.39052 .48198 m .43492 .51596 L .44694 .49335 L p
1 g
F P
s
P
p
.002 w
.44694 .49335 m .40553 .46144 L .39052 .48198 L p
1 g
F P
s
P
p
.002 w
.49545 .51434 m .44694 .49335 L .43492 .51596 L p
1 g
F P
s
P
p
.002 w
.40537 .35141 m .41754 .38743 L .44169 .37222 L p
1 g
F P
s
P
p
.002 w
.44169 .37222 m .43189 .34216 L .40537 .35141 L p
1 g
F P
s
P
p
.002 w
.49545 .51434 m .54685 .52255 L .55072 .4959 L p
1 g
F P
s
P
p
.002 w
.59582 .49049 m .55072 .4959 L .54685 .52255 L p
1 g
F P
s
P
p
.002 w
.55072 .4959 m .59582 .49049 L .59268 .46299 L p
1 g
F P
s
P
p
.002 w
.60149 .39617 m .57983 .40707 L .58731 .435 L p
1 g
F P
s
P
p
.002 w
.57983 .40707 m .60149 .39617 L .58509 .37211 L p
1 g
F P
s
P
p
.002 w
.58509 .37211 m .57041 .37972 L .57983 .40707 L p
1 g
F P
s
P
p
.002 w
.43492 .51596 m .48681 .53843 L .49545 .51434 L p
1 g
F P
s
P
p
.002 w
.54685 .52255 m .49545 .51434 L .48681 .53843 L p
1 g
F P
s
P
p
.002 w
.49339 .34656 m .48858 .33058 L .45982 .33518 L p
1 g
F P
s
P
p
.002 w
.48858 .33058 m .49339 .34656 L .51999 .33659 L p
1 g
F P
s
P
p
.002 w
.5251 .34399 m .51999 .33659 L .49339 .34656 L p
1 g
F P
s
P
p
.002 w
.57041 .37972 m .58509 .37211 L .56661 .34951 L p
1 g
F P
s
P
p
.002 w
.56661 .34951 m .5592 .35346 L .57041 .37972 L p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .5251 .34399 L .53241 .34988 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .53241 .34988 L .54115 .35364 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .54115 .35364 L .5504 .35488 L closepath p
1 g
F P
s
P
p
.002 w
.61548 .42124 m .58731 .435 L .59268 .46299 L p
1 g
F P
s
P
p
.002 w
.58731 .435 m .61548 .42124 L .60149 .39617 L p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .51999 .33659 L .5251 .34399 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .5504 .35488 L .5592 .35346 L closepath p
1 g
F P
s
P
p
.002 w
.38082 .3628 m .39518 .40387 L .41754 .38743 L p
1 g
F P
s
P
p
.002 w
.41754 .38743 m .40537 .35141 L .38082 .3628 L p
1 g
F P
s
P
p
.002 w
.51999 .33659 m .51763 .32845 L .48858 .33058 L p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .51763 .32845 L .51999 .33659 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .5592 .35346 L .56661 .34951 L closepath p
1 g
F P
s
P
p
.002 w
.62675 .44683 m .59268 .46299 L .59582 .49049 L p
1 g
F P
s
P
p
.002 w
.59268 .46299 m .62675 .44683 L .61548 .42124 L p
1 g
F P
s
P
p
.002 w
.35767 .43921 m .39052 .48198 L .40553 .46144 L p
1 g
F P
s
P
p
.002 w
.40553 .46144 m .37506 .42123 L .35767 .43921 L p
1 g
F P
s
P
p
.002 w
.46114 .31187 m .45982 .33518 L .48858 .33058 L p
1 g
F P
s
P
p
.002 w
.48858 .33058 m .48971 .31472 L .46114 .31187 L p
1 g
F P
s
P
p
.002 w
.48971 .31472 m .48858 .33058 L .51763 .32845 L p
1 g
F P
s
P
p
.002 w
.59556 .36025 m .58509 .37211 L .60149 .39617 L p
1 g
F P
s
P
p
.002 w
.58509 .37211 m .59556 .36025 L .57183 .34343 L p
1 g
F P
s
P
p
.002 w
.57183 .34343 m .56661 .34951 L .58509 .37211 L p
1 g
F P
s
P
p
.002 w
.48681 .53843 m .54175 .54742 L .54685 .52255 L p
1 g
F P
s
P
p
.002 w
.59661 .51696 m .54685 .52255 L .54175 .54742 L p
1 g
F P
s
P
p
.002 w
.54685 .52255 m .59661 .51696 L .59582 .49049 L p
1 g
F P
s
P
p
.002 w
.4332 .31196 m .43189 .34216 L .45982 .33518 L p
1 g
F P
s
P
p
.002 w
.45982 .33518 m .46114 .31187 L .4332 .31196 L p
1 g
F P
s
P
p
.002 w
.51763 .32845 m .51832 .32042 L .48971 .31472 L p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .51832 .32042 L .51763 .32845 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .56661 .34951 L .57183 .34343 L closepath p
1 g
F P
s
P
p
.002 w
.61711 .37898 m .60149 .39617 L .61548 .42124 L p
1 g
F P
s
P
p
.002 w
.60149 .39617 m .61711 .37898 L .59556 .36025 L p
1 g
F P
s
P
p
.002 w
.3779 .50173 m .42424 .53698 L .43492 .51596 L p
1 g
F P
s
P
p
.002 w
.43492 .51596 m .39052 .48198 L .3779 .50173 L p
1 g
F P
s
P
p
.002 w
.48681 .53843 m .43492 .51596 L .42424 .53698 L p
1 g
F P
s
P
p
.002 w
.35879 .37613 m .37506 .42123 L .39518 .40387 L p
1 g
F P
s
P
p
.002 w
.39518 .40387 m .38082 .3628 L .35879 .37613 L p
1 g
F P
s
P
p
.002 w
.42424 .53698 m .47829 .56039 L .48681 .53843 L p
1 g
F P
s
P
p
.002 w
.54175 .54742 m .48681 .53843 L .47829 .56039 L p
1 g
F P
s
P
p
.002 w
.40648 .31506 m .40537 .35141 L .43189 .34216 L p
1 g
F P
s
P
p
.002 w
.43189 .34216 m .4332 .31196 L .40648 .31506 L p
1 g
F P
s
P
p
.002 w
.49677 .3007 m .48971 .31472 L .51832 .32042 L p
1 g
F P
s
P
p
.002 w
.51832 .32042 m .52199 .31338 L .49677 .3007 L p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .52199 .31338 L .51832 .32042 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .57183 .34343 L .57426 .33585 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .57426 .33585 L .5736 .32758 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .5736 .32758 L .56991 .31953 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .56991 .31953 L .56355 .3126 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .56355 .3126 L .55523 .30757 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .55523 .30757 L .54589 .30501 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .54589 .30501 L .53656 .3052 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .53656 .3052 L .5283 .30811 L closepath p
1 g
F P
s
P
p
.002 w
.5464 .32883 m .5283 .30811 L .52199 .31338 L closepath p
1 g
F P
s
P
p
.002 w
.57426 .33585 m .57183 .34343 L .59556 .36025 L p
1 g
F P
s
P
p
.002 w
.635 .47242 m .59582 .49049 L .59661 .51696 L p
1 g
F P
s
P
p
.002 w
.59582 .49049 m .635 .47242 L .62675 .44683 L p
1 g
F P
s
P
p
.002 w
.636 .39925 m .61548 .42124 L .62675 .44683 L p
1 g
F P
s
P
p
.002 w
.61548 .42124 m .636 .39925 L .61711 .37898 L p
1 g
F P
s
P
p
.002 w
.47125 .2911 m .46114 .31187 L .48971 .31472 L p
1 g
F P
s
P
p
.002 w
.48971 .31472 m .49677 .3007 L .47125 .2911 L p
1 g
F P
s
P
p
.002 w
.60058 .34533 m .59556 .36025 L .61711 .37898 L p
1 g
F P
s
P
p
.002 w
.59556 .36025 m .60058 .34533 L .57426 .33585 L p
1 g
F P
s
P
p
.002 w
.50915 .29009 m .49677 .3007 L .52199 .31338 L p
1 g
F P
s
P
p
.002 w
.52199 .31338 m .5283 .30811 L .50915 .29009 L p
1 g
F P
s
P
p
.002 w
.5736 .32758 m .57426 .33585 L .60058 .34533 L p
1 g
F P
s
P
p
.002 w
.34346 .45743 m .3779 .50173 L .39052 .48198 L p
1 g
F P
s
P
p
.002 w
.39052 .48198 m .35767 .43921 L .34346 .45743 L p
1 g
F P
s
P
p
.002 w
.38158 .32119 m .38082 .3628 L .40537 .35141 L p
1 g
F P
s
P
p
.002 w
.40537 .35141 m .40648 .31506 L .38158 .32119 L p
1 g
F P
s
P
p
.002 w
.47829 .56039 m .53546 .56995 L .54175 .54742 L p
1 g
F P
s
P
p
.002 w
.59498 .54181 m .54175 .54742 L .53546 .56995 L p
1 g
F P
s
P
p
.002 w
.54175 .54742 m .59498 .54181 L .59661 .51696 L p
1 g
F P
s
P
p
.002 w
.44595 .28486 m .4332 .31196 L .46114 .31187 L p
1 g
F P
s
P
p
.002 w
.46114 .31187 m .47125 .2911 L .44595 .28486 L p
1 g
F P
s
P
p
.002 w
.33986 .3912 m .35767 .43921 L .37506 .42123 L p
1 g
F P
s
P
p
.002 w
.37506 .42123 m .35879 .37613 L .33986 .3912 L p
1 g
F P
s
P
p
.002 w
.52556 .28417 m .50915 .29009 L .5283 .30811 L p
1 g
F P
s
P
p
.002 w
.5283 .30811 m .53656 .3052 L .52556 .28417 L p
1 g
F P
s
P
p
.002 w
.60058 .34533 m .59947 .32891 L .5736 .32758 L p
1 g
F P
s
P
p
.002 w
.56991 .31953 m .5736 .32758 L .59947 .32891 L p
1 g
F P
s
P
p
.002 w
.65178 .42068 m .62675 .44683 L .635 .47242 L p
1 g
F P
s
P
p
.002 w
.62675 .44683 m .65178 .42068 L .636 .39925 L p
1 g
F P
s
P
p
.002 w
.6248 .35711 m .61711 .37898 L .636 .39925 L p
1 g
F P
s
P
p
.002 w
.61711 .37898 m .6248 .35711 L .60058 .34533 L p
1 g
F P
s
P
p
.002 w
.63998 .49749 m .59661 .51696 L .59498 .54181 L p
1 g
F P
s
P
p
.002 w
.59661 .51696 m .63998 .49749 L .635 .47242 L p
1 g
F P
s
P
p
.002 w
.48933 .27525 m .47125 .2911 L .49677 .3007 L p
1 g
F P
s
P
p
.002 w
.49677 .3007 m .50915 .29009 L .48933 .27525 L p
1 g
F P
s
P
p
.002 w
.54419 .2837 m .52556 .28417 L .53656 .3052 L p
1 g
F P
s
P
p
.002 w
.53656 .3052 m .54589 .30501 L .54419 .2837 L p
1 g
F P
s
P
p
.002 w
.36804 .52023 m .41518 .5559 L .42424 .53698 L p
1 g
F P
s
P
p
.002 w
.42424 .53698 m .3779 .50173 L .36804 .52023 L p
1 g
F P
s
P
p
.002 w
.47829 .56039 m .42424 .53698 L .41518 .5559 L p
1 g
F P
s
P
p
.002 w
.59947 .32891 m .59223 .31281 L .56991 .31953 L p
1 g
F P
s
P
p
.002 w
.56355 .3126 m .56991 .31953 L .59223 .31281 L p
1 g
F P
s
P
p
.002 w
.41518 .5559 m .47007 .57969 L .47829 .56039 L p
1 g
F P
s
P
p
.002 w
.53546 .56995 m .47829 .56039 L .47007 .57969 L p
1 g
F P
s
P
p
.002 w
.59947 .32891 m .60058 .34533 L .6248 .35711 L p
1 g
F P
s
P
p
.002 w
.56293 .2888 m .54419 .2837 L .54589 .30501 L p
1 g
F P
s
P
p
.002 w
.54589 .30501 m .55523 .30757 L .56293 .2888 L p
1 g
F P
s
P
p
.002 w
.59223 .31281 m .57958 .2989 L .56355 .3126 L p
1 g
F P
s
P
p
.002 w
.55523 .30757 m .56355 .3126 L .57958 .2989 L p
1 g
F P
s
P
p
.002 w
.57958 .2989 m .56293 .2888 L .55523 .30757 L p
1 g
F P
s
P
p
.002 w
.42144 .28224 m .40648 .31506 L .4332 .31196 L p
1 g
F P
s
P
p
.002 w
.4332 .31196 m .44595 .28486 L .42144 .28224 L p
1 g
F P
s
P
p
.002 w
.35914 .33031 m .35879 .37613 L .38082 .3628 L p
1 g
F P
s
P
p
.002 w
.38082 .3628 m .38158 .32119 L .35914 .33031 L p
1 g
F P
s
P
p
.002 w
.64633 .37102 m .636 .39925 L .65178 .42068 L p
1 g
F P
s
P
p
.002 w
.636 .39925 m .64633 .37102 L .6248 .35711 L p
1 g
F P
s
P
p
.002 w
.51357 .2663 m .48933 .27525 L .50915 .29009 L p
1 g
F P
s
P
p
.002 w
.50915 .29009 m .52556 .28417 L .51357 .2663 L p
1 g
F P
s
P
p
.002 w
.33289 .47551 m .36804 .52023 L .3779 .50173 L p
1 g
F P
s
P
p
.002 w
.3779 .50173 m .34346 .45743 L .33289 .47551 L p
1 g
F P
s
P
p
.002 w
.66401 .44285 m .635 .47242 L .63998 .49749 L p
1 g
F P
s
P
p
.002 w
.635 .47242 m .66401 .44285 L .65178 .42068 L p
1 g
F P
s
P
p
.002 w
.6248 .35711 m .62342 .33286 L .59947 .32891 L p
1 g
F P
s
P
p
.002 w
.59223 .31281 m .59947 .32891 L .62342 .33286 L p
1 g
F P
s
P
p
.002 w
.46925 .26402 m .44595 .28486 L .47125 .2911 L p
1 g
F P
s
P
p
.002 w
.47125 .2911 m .48933 .27525 L .46925 .26402 L p
1 g
F P
s
P
p
.002 w
.32457 .40772 m .34346 .45743 L .35767 .43921 L p
1 g
F P
s
P
p
.002 w
.35767 .43921 m .33986 .3912 L .32457 .40772 L p
1 g
F P
s
P
p
.002 w
.47007 .57969 m .52808 .58958 L .53546 .56995 L p
1 g
F P
s
P
p
.002 w
.59086 .56447 m .53546 .56995 L .52808 .58958 L p
1 g
F P
s
P
p
.002 w
.53546 .56995 m .59086 .56447 L .59498 .54181 L p
1 g
F P
s
P
p
.002 w
.62342 .33286 m .6248 .35711 L .64633 .37102 L p
1 g
F P
s
P
p
.002 w
.64148 .52146 m .59498 .54181 L .59086 .56447 L p
1 g
F P
s
P
p
.002 w
.59498 .54181 m .64148 .52146 L .63998 .49749 L p
1 g
F P
s
P
p
.002 w
.54129 .26549 m .51357 .2663 L .52556 .28417 L p
1 g
F P
s
P
p
.002 w
.52556 .28417 m .54419 .2837 L .54129 .26549 L p
1 g
F P
s
P
p
.002 w
.39832 .28343 m .38158 .32119 L .40648 .31506 L p
1 g
F P
s
P
p
.002 w
.40648 .31506 m .42144 .28224 L .39832 .28343 L p
1 g
F P
s
P
p
.002 w
.62342 .33286 m .61284 .30893 L .59223 .31281 L p
1 g
F P
s
P
p
.002 w
.57958 .2989 m .59223 .31281 L .61284 .30893 L p
1 g
F P
s
P
p
.002 w
.33977 .34234 m .33986 .3912 L .35879 .37613 L p
1 g
F P
s
P
p
.002 w
.35879 .37613 m .35914 .33031 L .33977 .34234 L p
1 g
F P
s
P
p
.002 w
.36128 .53703 m .40801 .57222 L .41518 .5559 L p
1 g
F P
s
P
p
.002 w
.41518 .5559 m .36804 .52023 L .36128 .53703 L p
1 g
F P
s
P
p
.002 w
.47007 .57969 m .41518 .5559 L .40801 .57222 L p
1 g
F P
s
P
p
.002 w
.66462 .38683 m .65178 .42068 L .66401 .44285 L p
1 g
F P
s
P
p
.002 w
.65178 .42068 m .66462 .38683 L .64633 .37102 L p
1 g
F P
s
P
p
.002 w
.40801 .57222 m .46235 .59579 L .47007 .57969 L p
1 g
F P
s
P
p
.002 w
.52808 .58958 m .47007 .57969 L .46235 .59579 L p
1 g
F P
s
P
p
.002 w
.56925 .27306 m .54129 .26549 L .54419 .2837 L p
1 g
F P
s
P
p
.002 w
.54419 .2837 m .56293 .2888 L .56925 .27306 L p
1 g
F P
s
P
p
.002 w
.61284 .30893 m .59409 .28815 L .57958 .2989 L p
1 g
F P
s
P
p
.002 w
.56293 .2888 m .57958 .2989 L .59409 .28815 L p
1 g
F P
s
P
p
.002 w
.59409 .28815 m .56925 .27306 L .56293 .2888 L p
1 g
F P
s
P
p
.002 w
.67227 .46528 m .63998 .49749 L .64148 .52146 L p
1 g
F P
s
P
p
.002 w
.63998 .49749 m .67227 .46528 L .66401 .44285 L p
1 g
F P
s
P
p
.002 w
.44936 .25683 m .42144 .28224 L .44595 .28486 L p
1 g
F P
s
P
p
.002 w
.44595 .28486 m .46925 .26402 L .44936 .25683 L p
1 g
F P
s
P
p
.002 w
.50083 .25214 m .46925 .26402 L .48933 .27525 L p
1 g
F P
s
P
p
.002 w
.48933 .27525 m .51357 .2663 L .50083 .25214 L p
1 g
F P
s
P
p
.002 w
.64633 .37102 m .64484 .33946 L .62342 .33286 L p
1 g
F P
s
P
p
.002 w
.61284 .30893 m .62342 .33286 L .64484 .33946 L p
1 g
F P
s
P
p
.002 w
.64484 .33946 m .64633 .37102 L .66462 .38683 L p
1 g
F P
s
P
p
.002 w
.31346 .42538 m .33289 .47551 L .34346 .45743 L p
1 g
F P
s
P
p
.002 w
.34346 .45743 m .32457 .40772 L .31346 .42538 L p
1 g
F P
s
P
p
.002 w
.32638 .49301 m .36128 .53703 L .36804 .52023 L p
1 g
F P
s
P
p
.002 w
.36804 .52023 m .33289 .47551 L .32638 .49301 L p
1 g
F P
s
P
p
.002 w
.37719 .28857 m .35914 .33031 L .38158 .32119 L p
1 g
F P
s
P
p
.002 w
.38158 .32119 m .39832 .28343 L .37719 .28857 L p
1 g
F P
s
P
p
.002 w
.46235 .59579 m .51971 .60572 L .52808 .58958 L p
1 g
F P
s
P
p
.002 w
.58425 .58433 m .52808 .58958 L .51971 .60572 L p
1 g
F P
s
P
p
.002 w
.52808 .58958 m .58425 .58433 L .59086 .56447 L p
1 g
F P
s
P
p
.002 w
.6393 .54373 m .59086 .56447 L .58425 .58433 L p
1 g
F P
s
P
p
.002 w
.59086 .56447 m .6393 .54373 L .64148 .52146 L p
1 g
F P
s
P
p
.002 w
.6791 .40423 m .66401 .44285 L .67227 .46528 L p
1 g
F P
s
P
p
.002 w
.66401 .44285 m .6791 .40423 L .66462 .38683 L p
1 g
F P
s
P
p
.002 w
.5372 .25096 m .50083 .25214 L .51357 .2663 L p
1 g
F P
s
P
p
.002 w
.51357 .2663 m .54129 .26549 L .5372 .25096 L p
1 g
F P
s
P
p
.002 w
.32408 .35711 m .32457 .40772 L .33986 .3912 L p
1 g
F P
s
P
p
.002 w
.33986 .3912 m .33977 .34234 L .32408 .35711 L p
1 g
F P
s
P
p
.002 w
.64484 .33946 m .6312 .30811 L .61284 .30893 L p
1 g
F P
s
P
p
.002 w
.59409 .28815 m .61284 .30893 L .6312 .30811 L p
1 g
F P
s
P
p
.002 w
.43015 .25404 m .39832 .28343 L .42144 .28224 L p
1 g
F P
s
P
p
.002 w
.42144 .28224 m .44936 .25683 L .43015 .25404 L p
1 g
F P
s
P
p
.002 w
.67622 .48744 m .64148 .52146 L .6393 .54373 L p
1 g
F P
s
P
p
.002 w
.64148 .52146 m .67622 .48744 L .67227 .46528 L p
1 g
F P
s
P
p
.002 w
.35795 .55162 m .40299 .58542 L .40801 .57222 L p
1 g
F P
s
P
p
.002 w
.40801 .57222 m .36128 .53703 L .35795 .55162 L p
1 g
F P
s
P
p
.002 w
.46235 .59579 m .40801 .57222 L .40299 .58542 L p
1 g
F P
s
P
p
.002 w
.48761 .24222 m .44936 .25683 L .46925 .26402 L p
1 g
F P
s
P
p
.002 w
.46925 .26402 m .50083 .25214 L .48761 .24222 L p
1 g
F P
s
P
p
.002 w
.40299 .58542 m .45533 .60813 L .46235 .59579 L p
1 g
F P
s
P
p
.002 w
.51971 .60572 m .46235 .59579 L .45533 .60813 L p
1 g
F P
s
P
p
.002 w
.57399 .26087 m .5372 .25096 L .54129 .26549 L p
1 g
F P
s
P
p
.002 w
.54129 .26549 m .56925 .27306 L .57399 .26087 L p
1 g
F P
s
P
p
.002 w
.66312 .34867 m .66462 .38683 L .6791 .40423 L p
1 g
F P
s
P
p
.002 w
.66462 .38683 m .66312 .34867 L .64484 .33946 L p
1 g
F P
s
P
p
.002 w
.6312 .30811 m .60665 .28076 L .59409 .28815 L p
1 g
F P
s
P
p
.002 w
.56925 .27306 m .59409 .28815 L .60665 .28076 L p
1 g
F P
s
P
p
.002 w
.6312 .30811 m .64484 .33946 L .66312 .34867 L p
1 g
F P
s
P
p
.002 w
.60665 .28076 m .57399 .26087 L .56925 .27306 L p
1 g
F P
s
P
p
.002 w
.35868 .29773 m .33977 .34234 L .35914 .33031 L p
1 g
F P
s
P
p
.002 w
.35914 .33031 m .37719 .28857 L .35868 .29773 L p
1 g
F P
s
P
p
.002 w
.30701 .44377 m .32638 .49301 L .33289 .47551 L p
1 g
F P
s
P
p
.002 w
.33289 .47551 m .31346 .42538 L .30701 .44377 L p
1 g
F P
s
P
p
.002 w
.32431 .50947 m .35795 .55162 L .36128 .53703 L p
1 g
F P
s
P
p
.002 w
.36128 .53703 m .32638 .49301 L .32431 .50947 L p
1 g
F P
s
P
p
.002 w
.51971 .60572 m .57518 .60079 L .58425 .58433 L p
1 g
F P
s
P
p
.002 w
.63334 .5637 m .58425 .58433 L .57518 .60079 L p
1 g
F P
s
P
p
.002 w
.58425 .58433 m .63334 .5637 L .6393 .54373 L p
1 g
F P
s
P
p
.002 w
.68926 .42289 m .67227 .46528 L .67622 .48744 L p
1 g
F P
s
P
p
.002 w
.67227 .46528 m .68926 .42289 L .6791 .40423 L p
1 g
F P
s
P
p
.002 w
.45533 .60813 m .51051 .6178 L .51971 .60572 L p
1 g
F P
s
P
p
.002 w
.57518 .60079 m .51971 .60572 L .51051 .6178 L p
1 g
F P
s
P
p
.002 w
.31267 .37437 m .31346 .42538 L .32457 .40772 L p
1 g
F P
s
P
p
.002 w
.32457 .40772 m .32408 .35711 L .31267 .37437 L p
1 g
F P
s
P
p
.002 w
.53193 .24068 m .48761 .24222 L .50083 .25214 L p
1 g
F P
s
P
p
.002 w
.50083 .25214 m .5372 .25096 L .53193 .24068 L p
1 g
F P
s
P
p
.002 w
.41216 .25595 m .37719 .28857 L .39832 .28343 L p
1 g
F P
s
P
p
.002 w
.39832 .28343 m .43015 .25404 L .41216 .25595 L p
1 g
F P
s
P
p
.002 w
.66312 .34867 m .64673 .31052 L .6312 .30811 L p
1 g
F P
s
P
p
.002 w
.60665 .28076 m .6312 .30811 L .64673 .31052 L p
1 g
F P
s
P
p
.002 w
.67554 .50878 m .6393 .54373 L .63334 .5637 L p
1 g
F P
s
P
p
.002 w
.6393 .54373 m .67554 .50878 L .67622 .48744 L p
1 g
F P
s
P
p
.002 w
.47421 .23704 m .43015 .25404 L .44936 .25683 L p
1 g
F P
s
P
p
.002 w
.44936 .25683 m .48761 .24222 L .47421 .23704 L p
1 g
F P
s
P
p
.002 w
.67766 .36039 m .6791 .40423 L .68926 .42289 L p
1 g
F P
s
P
p
.002 w
.6791 .40423 m .67766 .36039 L .66312 .34867 L p
1 g
F P
s
P
p
.002 w
.64673 .31052 m .66312 .34867 L .67766 .36039 L p
1 g
F P
s
P
p
.002 w
.35834 .56353 m .40037 .59498 L .40299 .58542 L p
1 g
F P
s
P
p
.002 w
.40299 .58542 m .35795 .55162 L .35834 .56353 L p
1 g
F P
s
P
p
.002 w
.45533 .60813 m .40299 .58542 L .40037 .59498 L p
1 g
F P
s
P
p
.002 w
.34344 .31086 m .32408 .35711 L .33977 .34234 L p
1 g
F P
s
P
p
.002 w
.33977 .34234 m .35868 .29773 L .34344 .31086 L p
1 g
F P
s
P
p
.002 w
.40037 .59498 m .44922 .61619 L .45533 .60813 L p
1 g
F P
s
P
p
.002 w
.51051 .6178 m .45533 .60813 L .44922 .61619 L p
1 g
F P
s
P
p
.002 w
.57692 .25277 m .53193 .24068 L .5372 .25096 L p
1 g
F P
s
P
p
.002 w
.5372 .25096 m .57399 .26087 L .57692 .25277 L p
1 g
F P
s
P
p
.002 w
.64673 .31052 m .61685 .27711 L .60665 .28076 L p
1 g
F P
s
P
p
.002 w
.57399 .26087 m .60665 .28076 L .61685 .27711 L p
1 g
F P
s
P
p
.002 w
.30565 .46246 m .32431 .50947 L .32638 .49301 L p
1 g
F P
s
P
p
.002 w
.32638 .49301 m .30701 .44377 L .30565 .46246 L p
1 g
F P
s
P
p
.002 w
.61685 .27711 m .57692 .25277 L .57399 .26087 L p
1 g
F P
s
P
p
.002 w
.6946 .44238 m .67622 .48744 L .67554 .50878 L p
1 g
F P
s
P
p
.002 w
.67622 .48744 m .6946 .44238 L .68926 .42289 L p
1 g
F P
s
P
p
.002 w
.51051 .6178 m .56374 .61324 L .57518 .60079 L p
1 g
F P
s
P
p
.002 w
.62356 .58074 m .57518 .60079 L .56374 .61324 L p
1 g
F P
s
P
p
.002 w
.57518 .60079 m .62356 .58074 L .63334 .5637 L p
1 g
F P
s
P
p
.002 w
.30607 .39378 m .30701 .44377 L .31346 .42538 L p
1 g
F P
s
P
p
.002 w
.31346 .42538 m .31267 .37437 L .30607 .39378 L p
1 g
F P
s
P
p
.002 w
.32699 .5244 m .35834 .56353 L .35795 .55162 L p
1 g
F P
s
P
p
.002 w
.35795 .55162 m .32431 .50947 L .32699 .5244 L p
1 g
F P
s
P
p
.002 w
.44922 .61619 m .50065 .62527 L .51051 .6178 L p
1 g
F P
s
P
p
.002 w
.56374 .61324 m .51051 .6178 L .50065 .62527 L p
1 g
F P
s
P
p
.002 w
.39593 .26279 m .35868 .29773 L .37719 .28857 L p
1 g
F P
s
P
p
.002 w
.37719 .28857 m .41216 .25595 L .39593 .26279 L p
1 g
F P
s
P
p
.002 w
.67004 .52868 m .63334 .5637 L .62356 .58074 L p
1 g
F P
s
P
p
.002 w
.63334 .5637 m .67004 .52868 L .67554 .50878 L p
1 g
F P
s
P
p
.002 w
.52557 .23519 m .47421 .23704 L .48761 .24222 L p
1 g
F P
s
P
p
.002 w
.48761 .24222 m .53193 .24068 L .52557 .23519 L p
1 g
F P
s
P
p
.002 w
.68788 .37446 m .68926 .42289 L .6946 .44238 L p
1 g
F P
s
P
p
.002 w
.68926 .42289 m .68788 .37446 L .67766 .36039 L p
1 g
F P
s
P
p
.002 w
.67766 .36039 m .65887 .31631 L .64673 .31052 L p
1 g
F P
s
P
p
.002 w
.61685 .27711 m .64673 .31052 L .65887 .31631 L p
1 g
F P
s
P
p
.002 w
.46098 .23702 m .41216 .25595 L .43015 .25404 L p
1 g
F P
s
P
p
.002 w
.43015 .25404 m .47421 .23704 L .46098 .23702 L p
1 g
F P
s
P
p
.002 w
.33204 .3278 m .31267 .37437 L .32408 .35711 L p
1 g
F P
s
P
p
.002 w
.32408 .35711 m .34344 .31086 L .33204 .3278 L p
1 g
F P
s
P
p
.002 w
.65887 .31631 m .67766 .36039 L .68788 .37446 L p
1 g
F P
s
P
p
.002 w
.69476 .46223 m .67554 .50878 L .67004 .52868 L p
1 g
F P
s
P
p
.002 w
.67554 .50878 m .69476 .46223 L .6946 .44238 L p
1 g
F P
s
P
p
.002 w
.36267 .57224 m .40039 .60044 L .40037 .59498 L p
1 g
F P
s
P
p
.002 w
.40037 .59498 m .35834 .56353 L .36267 .57224 L p
1 g
F P
s
P
p
.002 w
.44922 .61619 m .40037 .59498 L .40039 .60044 L p
1 g
F P
s
P
p
.002 w
.40039 .60044 m .44425 .61949 L .44922 .61619 L p
1 g
F P
s
P
p
.002 w
.50065 .62527 m .44922 .61619 L .44425 .61949 L p
1 g
F P
s
P
p
.002 w
.57786 .24922 m .52557 .23519 L .53193 .24068 L p
1 g
F P
s
P
p
.002 w
.53193 .24068 m .57692 .25277 L .57786 .24922 L p
1 g
F P
s
P
p
.002 w
.30967 .48094 m .32699 .5244 L .32431 .50947 L p
1 g
F P
s
P
p
.002 w
.32431 .50947 m .30565 .46246 L .30967 .48094 L p
1 g
F P
s
P
p
.002 w
.65887 .31631 m .62427 .27752 L .61685 .27711 L p
1 g
F P
s
P
p
.002 w
.57692 .25277 m .61685 .27711 L .62427 .27752 L p
1 g
F P
s
P
p
.002 w
.3047 .4149 m .30565 .46246 L .30701 .44377 L p
1 g
F P
s
P
p
.002 w
.30701 .44377 m .30607 .39378 L .3047 .4149 L p
1 g
F P
s
P
p
.002 w
.50065 .62527 m .55011 .62114 L .56374 .61324 L p
1 g
F P
s
P
p
.002 w
.61001 .59423 m .56374 .61324 L .55011 .62114 L p
1 g
F P
s
P
p
.002 w
.56374 .61324 m .61001 .59423 L .62356 .58074 L p
1 g
F P
s
P
p
.002 w
.62427 .27752 m .57786 .24922 L .57692 .25277 L p
1 g
F P
s
P
p
.002 w
.38204 .27461 m .34344 .31086 L .35868 .29773 L p
1 g
F P
s
P
p
.002 w
.35868 .29773 m .39593 .26279 L .38204 .27461 L p
1 g
F P
s
P
p
.002 w
.33463 .53729 m .36267 .57224 L .35834 .56353 L p
1 g
F P
s
P
p
.002 w
.35834 .56353 m .32699 .5244 L .33463 .53729 L p
1 g
F P
s
P
p
.002 w
.65961 .54654 m .62356 .58074 L .61001 .59423 L p
1 g
F P
s
P
p
.002 w
.62356 .58074 m .65961 .54654 L .67004 .52868 L p
1 g
F P
s
P
p
.002 w
.44425 .61949 m .49036 .62766 L .50065 .62527 L p
1 g
F P
s
P
p
.002 w
.55011 .62114 m .50065 .62527 L .49036 .62766 L p
1 g
F P
s
P
p
.002 w
.6946 .44238 m .69325 .39063 L .68788 .37446 L p
1 g
F P
s
P
p
.002 w
.69325 .39063 m .6946 .44238 L .69476 .46223 L p
1 g
F P
s
P
p
.002 w
.5182 .23495 m .46098 .23702 L .47421 .23704 L p
1 g
F P
s
P
p
.002 w
.47421 .23704 m .52557 .23519 L .5182 .23495 L p
1 g
F P
s
P
p
.002 w
.44832 .24248 m .39593 .26279 L .41216 .25595 L p
1 g
F P
s
P
p
.002 w
.41216 .25595 m .46098 .23702 L .44832 .24248 L p
1 g
F P
s
P
p
.002 w
.32505 .34825 m .30607 .39378 L .31267 .37437 L p
1 g
F P
s
P
p
.002 w
.31267 .37437 m .33204 .3278 L .32505 .34825 L p
1 g
F P
s
P
p
.002 w
.68788 .37446 m .66709 .32551 L .65887 .31631 L p
1 g
F P
s
P
p
.002 w
.62427 .27752 m .65887 .31631 L .66709 .32551 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52866 .62333 L
s
P
p
.004 w
.53002 .63244 m
.5437 .7245 L
s
P
p
.002 w
.66709 .32551 m .68788 .37446 L .69325 .39063 L p
1 g
F P
s
P
p
.002 w
.67004 .52868 m .68943 .48188 L .69476 .46223 L p
1 g
F P
s
P
p
.002 w
.68943 .48188 m .67004 .52868 L .65961 .54654 L p
1 g
F P
s
P
p
.002 w
.31927 .49864 m .33463 .53729 L .32699 .5244 L p
1 g
F P
s
P
p
.002 w
.32699 .5244 m .30967 .48094 L .31927 .49864 L p
1 g
F P
s
P
p
.002 w
.30889 .43717 m .30967 .48094 L .30565 .46246 L p
1 g
F P
s
P
p
.002 w
.30565 .46246 m .3047 .4149 L .30889 .43717 L p
1 g
F P
s
P
p
.002 w
.37106 .57733 m .40321 .60136 L .40039 .60044 L p
1 g
F P
s
P
p
.002 w
.40039 .60044 m .36267 .57224 L .37106 .57733 L p
1 g
F P
s
P
p
.002 w
.44425 .61949 m .40039 .60044 L .40321 .60136 L p
1 g
F P
s
P
p
.002 w
.57663 .25064 m .5182 .23495 L .52557 .23519 L p
1 g
F P
s
P
p
.002 w
.52557 .23519 m .57786 .24922 L .57663 .25064 L p
1 g
F P
s
P
p
.002 w
.40321 .60136 m .44063 .61761 L .44425 .61949 L p
1 g
F P
s
P
p
.002 w
.49036 .62766 m .44425 .61949 L .44063 .61761 L p
1 g
F P
s
P
p
.002 w
.37103 .29136 m .33204 .3278 L .34344 .31086 L p
1 g
F P
s
P
p
.002 w
.34344 .31086 m .38204 .27461 L .37103 .29136 L p
1 g
F P
s
P
p
.002 w
.66709 .32551 m .62851 .28227 L .62427 .27752 L p
1 g
F P
s
P
p
.002 w
.57786 .24922 m .62427 .27752 L .62851 .28227 L p
1 g
F P
s
P
p
.002 w
.49036 .62766 m .53453 .62399 L .55011 .62114 L p
1 g
F P
s
P
p
.004 w
.52887 .62475 m
.53002 .63244 L
s
P
p
.004 w
.52883 .62446 m
.52887 .62475 L
s
P
p
.002 w
.55011 .62114 m .59289 .60361 L .61001 .59423 L p
1 g
F P
s
P
p
.002 w
.59289 .60361 m .55011 .62114 L .53453 .62399 L p
1 g
F P
s
P
p
.002 w
.61001 .59423 m .6443 .56172 L .65961 .54654 L p
1 g
F P
s
P
p
.002 w
.6443 .56172 m .61001 .59423 L .59289 .60361 L p
1 g
F P
s
P
p
.002 w
.62851 .28227 m .57663 .25064 L .57786 .24922 L p
1 g
F P
s
P
p
.002 w
.69334 .40854 m .69476 .46223 L .68943 .48188 L p
1 g
F P
s
P
p
.002 w
.69476 .46223 m .69334 .40854 L .69325 .39063 L p
1 g
F P
s
P
p
.002 w
.34729 .54764 m .37106 .57733 L .36267 .57224 L p
1 g
F P
s
P
p
.002 w
.36267 .57224 m .33463 .53729 L .34729 .54764 L p
1 g
F P
s
P
p
.002 w
.32288 .37176 m .3047 .4149 L .30607 .39378 L p
1 g
F P
s
P
p
.002 w
.30607 .39378 m .32505 .34825 L .32288 .37176 L p
1 g
F P
s
P
p
.002 w
.44063 .61761 m .4799 .62457 L .49036 .62766 L p
1 g
F P
s
P
p
.002 w
.53453 .62399 m .49036 .62766 L .4799 .62457 L p
1 g
F P
s
P
p
.002 w
.43664 .25359 m .38204 .27461 L .39593 .26279 L p
1 g
F P
s
P
p
.002 w
.39593 .26279 m .44832 .24248 L .43664 .25359 L p
1 g
F P
s
P
p
.002 w
.51 .24032 m .44832 .24248 L .46098 .23702 L p
1 g
F P
s
P
p
.002 w
.46098 .23702 m .5182 .23495 L .51 .24032 L p
1 g
F P
s
P
p
.002 w
.69325 .39063 m .6709 .33807 L .66709 .32551 L p
1 g
F P
s
P
p
.002 w
.62851 .28227 m .66709 .32551 L .6709 .33807 L p
1 g
F P
s
P
p
.002 w
.6785 .50074 m .65961 .54654 L .6443 .56172 L p
1 g
F P
s
P
p
.002 w
.65961 .54654 m .6785 .50074 L .68943 .48188 L p
1 g
F P
s
P
p
.002 w
.6709 .33807 m .69325 .39063 L .69334 .40854 L p
1 g
F P
s
P
p
.002 w
.31877 .45996 m .31927 .49864 L .30967 .48094 L p
1 g
F P
s
P
p
.002 w
.30967 .48094 m .30889 .43717 L .31877 .45996 L p
1 g
F P
s
P
p
.002 w
.36342 .31275 m .32505 .34825 L .33204 .3278 L p
1 g
F P
s
P
p
.002 w
.33204 .3278 m .37103 .29136 L .36342 .31275 L p
1 g
F P
s
P
p
.002 w
.33444 .51498 m .34729 .54764 L .33463 .53729 L p
1 g
F P
s
P
p
.002 w
.33463 .53729 m .31927 .49864 L .33444 .51498 L p
1 g
F P
s
P
p
.002 w
.4799 .62457 m .51737 .62141 L .53453 .62399 L p
1 g
F P
s
P
p
.002 w
.5725 .60837 m .53453 .62399 L .51737 .62141 L p
1 g
F P
s
P
p
.002 w
.53453 .62399 m .5725 .60837 L .59289 .60361 L p
1 g
F P
s
P
p
.002 w
.62433 .57363 m .59289 .60361 L .5725 .60837 L p
1 g
F P
s
P
p
.002 w
.59289 .60361 m .62433 .57363 L .6443 .56172 L p
1 g
F P
s
P
p
.002 w
.57314 .25732 m .51 .24032 L .5182 .23495 L p
1 g
F P
s
P
p
.002 w
.5182 .23495 m .57663 .25064 L .57314 .25732 L p
1 g
F P
s
P
p
.002 w
.38353 .57839 m .40893 .59741 L .40321 .60136 L p
1 g
F P
s
P
p
.002 w
.40321 .60136 m .37106 .57733 L .38353 .57839 L p
1 g
F P
s
P
p
.002 w
.44063 .61761 m .40321 .60136 L .40893 .59741 L p
1 g
F P
s
P
p
.002 w
.40893 .59741 m .43856 .61027 L .44063 .61761 L p
1 g
F P
s
P
p
.002 w
.4799 .62457 m .44063 .61761 L .43856 .61027 L p
1 g
F P
s
P
p
.002 w
.68785 .42774 m .68943 .48188 L .6785 .50074 L p
1 g
F P
s
P
p
.002 w
.68943 .48188 m .68785 .42774 L .69334 .40854 L p
1 g
F P
s
P
p
.002 w
.6709 .33807 m .62924 .29148 L .62851 .28227 L p
1 g
F P
s
P
p
.002 w
.57663 .25064 m .62851 .28227 L .62924 .29148 L p
1 g
F P
s
P
p
.002 w
.32585 .39771 m .30889 .43717 L .3047 .4149 L p
1 g
F P
s
P
p
.002 w
.3047 .4149 m .32288 .37176 L .32585 .39771 L p
1 g
F P
s
P
p
.002 w
.62924 .29148 m .57314 .25732 L .57663 .25064 L p
1 g
F P
s
P
p
.002 w
.42638 .27032 m .37103 .29136 L .38204 .27461 L p
1 g
F P
s
P
p
.002 w
.38204 .27461 m .43664 .25359 L .42638 .27032 L p
1 g
F P
s
P
p
.002 w
.36488 .55497 m .38353 .57839 L .37106 .57733 L p
1 g
F P
s
P
p
.002 w
.37106 .57733 m .34729 .54764 L .36488 .55497 L p
1 g
F P
s
P
p
.002 w
.43856 .61027 m .4696 .61574 L .4799 .62457 L p
1 g
F P
s
P
p
.002 w
.51737 .62141 m .4799 .62457 L .4696 .61574 L p
1 g
F P
s
P
p
.002 w
.66203 .51818 m .6443 .56172 L .62433 .57363 L p
1 g
F P
s
P
p
.002 w
.6443 .56172 m .66203 .51818 L .6785 .50074 L p
1 g
F P
s
P
p
.002 w
.50116 .25148 m .43664 .25359 L .44832 .24248 L p
1 g
F P
s
P
p
.002 w
.44832 .24248 m .51 .24032 L .50116 .25148 L p
1 g
F P
s
P
p
.002 w
.66992 .35382 m .69334 .40854 L .68785 .42774 L p
1 g
F P
s
P
p
.002 w
.69334 .40854 m .66992 .35382 L .6709 .33807 L p
1 g
F P
s
P
p
.002 w
.62924 .29148 m .6709 .33807 L .66992 .35382 L p
1 g
F P
s
P
p
.002 w
.35961 .33832 m .32288 .37176 L .32505 .34825 L p
1 g
F P
s
P
p
.002 w
.32505 .34825 m .36342 .31275 L .35961 .33832 L p
1 g
F P
s
P
p
.002 w
.33428 .48254 m .33444 .51498 L .31927 .49864 L p
1 g
F P
s
P
p
.002 w
.31927 .49864 m .31877 .45996 L .33428 .48254 L p
1 g
F P
s
P
p
.002 w
.35497 .52936 m .36488 .55497 L .34729 .54764 L p
1 g
F P
s
P
p
.002 w
.34729 .54764 m .33444 .51498 L .35497 .52936 L p
1 g
F P
s
P
p
.002 w
.51737 .62141 m .54932 .60812 L .5725 .60837 L p
1 g
F P
s
P
p
.002 w
.60011 .58173 m .5725 .60837 L .54932 .60812 L p
1 g
F P
s
P
p
.002 w
.5725 .60837 m .60011 .58173 L .62433 .57363 L p
1 g
F P
s
P
p
.002 w
.67666 .44769 m .6785 .50074 L .66203 .51818 L p
1 g
F P
s
P
p
.002 w
.6785 .50074 m .67666 .44769 L .68785 .42774 L p
1 g
F P
s
P
p
.002 w
.4696 .61574 m .49906 .61317 L .51737 .62141 L p
1 g
F P
s
P
p
.002 w
.54932 .60812 m .51737 .62141 L .49906 .61317 L p
1 g
F P
s
P
p
.002 w
.33408 .42535 m .31877 .45996 L .30889 .43717 L p
1 g
F P
s
P
p
.002 w
.30889 .43717 m .32585 .39771 L .33408 .42535 L p
1 g
F P
s
P
p
.002 w
.56735 .26938 m .50116 .25148 L .51 .24032 L p
1 g
F P
s
P
p
.002 w
.51 .24032 m .57314 .25732 L .56735 .26938 L p
1 g
F P
s
P
p
.002 w
.39993 .57515 m .41757 .5884 L .40893 .59741 L p
1 g
F P
s
P
p
.002 w
.40893 .59741 m .38353 .57839 L .39993 .57515 L p
1 g
F P
s
P
p
.002 w
.43856 .61027 m .40893 .59741 L .41757 .5884 L p
1 g
F P
s
P
p
.002 w
.41757 .5884 m .4382 .59735 L .43856 .61027 L p
1 g
F P
s
P
p
.002 w
.4696 .61574 m .43856 .61027 L .4382 .59735 L p
1 g
F P
s
P
p
.002 w
.66992 .35382 m .62621 .30516 L .62924 .29148 L p
1 g
F P
s
P
p
.002 w
.57314 .25732 m .62924 .29148 L .62621 .30516 L p
1 g
F P
s
P
p
.002 w
.41797 .29242 m .36342 .31275 L .37103 .29136 L p
1 g
F P
s
P
p
.002 w
.37103 .29136 m .42638 .27032 L .41797 .29242 L p
1 g
F P
s
P
p
.002 w
.64028 .53355 m .62433 .57363 L .60011 .58173 L p
1 g
F P
s
P
p
.002 w
.62433 .57363 m .64028 .53355 L .66203 .51818 L p
1 g
F P
s
P
p
.002 w
.38709 .55888 m .39993 .57515 L .38353 .57839 L p
1 g
F P
s
P
p
.002 w
.38353 .57839 m .36488 .55497 L .38709 .55888 L p
1 g
F P
s
P
p
.002 w
.62621 .30516 m .56735 .26938 L .57314 .25732 L p
1 g
F P
s
P
p
.002 w
.49195 .26842 m .42638 .27032 L .43664 .25359 L p
1 g
F P
s
P
p
.002 w
.43664 .25359 m .50116 .25148 L .49195 .26842 L p
1 g
F P
s
P
p
.002 w
.66389 .37243 m .68785 .42774 L .67666 .44769 L p
1 g
F P
s
P
p
.002 w
.68785 .42774 m .66389 .37243 L .66992 .35382 L p
1 g
F P
s
P
p
.002 w
.4382 .59735 m .45978 .60111 L .4696 .61574 L p
1 g
F P
s
P
p
.002 w
.49906 .61317 m .4696 .61574 L .45978 .60111 L p
1 g
F P
s
P
p
.002 w
.35992 .36736 m .32585 .39771 L .32288 .37176 L p
1 g
F P
s
P
p
.002 w
.32288 .37176 m .35961 .33832 L .35992 .36736 L p
1 g
F P
s
P
p
.002 w
.62621 .30516 m .66992 .35382 L .66389 .37243 L p
1 g
F P
s
P
p
.002 w
.35512 .50413 m .35497 .52936 L .33444 .51498 L p
1 g
F P
s
P
p
.002 w
.33444 .51498 m .33428 .48254 L .35512 .50413 L p
1 g
F P
s
P
p
.002 w
.49906 .61317 m .52396 .60262 L .54932 .60812 L p
1 g
F P
s
P
p
.002 w
.57226 .58559 m .54932 .60812 L .52396 .60262 L p
1 g
F P
s
P
p
.002 w
.54932 .60812 m .57226 .58559 L .60011 .58173 L p
1 g
F P
s
P
p
.002 w
.65985 .46776 m .66203 .51818 L .64028 .53355 L p
1 g
F P
s
P
p
.002 w
.66203 .51818 m .65985 .46776 L .67666 .44769 L p
1 g
F P
s
P
p
.002 w
.38041 .54121 m .38709 .55888 L .36488 .55497 L p
1 g
F P
s
P
p
.002 w
.36488 .55497 m .35497 .52936 L .38041 .54121 L p
1 g
F P
s
P
p
.002 w
.34747 .45376 m .33428 .48254 L .31877 .45996 L p
1 g
F P
s
P
p
.002 w
.31877 .45996 m .33408 .42535 L .34747 .45376 L p
1 g
F P
s
P
p
.002 w
.45978 .60111 m .48014 .59924 L .49906 .61317 L p
1 g
F P
s
P
p
.002 w
.52396 .60262 m .49906 .61317 L .48014 .59924 L p
1 g
F P
s
P
p
.002 w
.61377 .54626 m .60011 .58173 L .57226 .58559 L p
1 g
F P
s
P
p
.002 w
.60011 .58173 m .61377 .54626 L .64028 .53355 L p
1 g
F P
s
P
p
.002 w
.41178 .31938 m .35961 .33832 L .36342 .31275 L p
1 g
F P
s
P
p
.002 w
.36342 .31275 m .41797 .29242 L .41178 .31938 L p
1 g
F P
s
P
p
.002 w
.55931 .28675 m .49195 .26842 L .50116 .25148 L p
1 g
F P
s
P
p
.002 w
.50116 .25148 m .56735 .26938 L .55931 .28675 L p
1 g
F P
s
P
p
.002 w
.41994 .56745 m .42902 .57431 L .41757 .5884 L p
1 g
F P
s
P
p
.002 w
.41757 .5884 m .39993 .57515 L .41994 .56745 L p
1 g
F P
s
P
p
.002 w
.4382 .59735 m .41757 .5884 L .42902 .57431 L p
1 g
F P
s
P
p
.002 w
.42902 .57431 m .43967 .57893 L .4382 .59735 L p
1 g
F P
s
P
p
.002 w
.45978 .60111 m .4382 .59735 L .43967 .57893 L p
1 g
F P
s
P
p
.002 w
.66389 .37243 m .61929 .32312 L .62621 .30516 L p
1 g
F P
s
P
p
.002 w
.56735 .26938 m .62621 .30516 L .61929 .32312 L p
1 g
F P
s
P
p
.002 w
.65274 .39342 m .67666 .44769 L .65985 .46776 L p
1 g
F P
s
P
p
.002 w
.67666 .44769 m .65274 .39342 L .66389 .37243 L p
1 g
F P
s
P
p
.002 w
.36448 .39898 m .33408 .42535 L .32585 .39771 L p
1 g
F P
s
P
p
.002 w
.32585 .39771 m .35992 .36736 L .36448 .39898 L p
1 g
F P
s
P
p
.002 w
.48265 .29087 m .41797 .29242 L .42638 .27032 L p
1 g
F P
s
P
p
.002 w
.42638 .27032 m .49195 .26842 L .48265 .29087 L p
1 g
F P
s
P
p
.002 w
.41339 .55906 m .41994 .56745 L .39993 .57515 L p
1 g
F P
s
P
p
.002 w
.39993 .57515 m .38709 .55888 L .41339 .55906 L p
1 g
F P
s
P
p
.002 w
.38076 .52395 m .38041 .54121 L .35497 .52936 L p
1 g
F P
s
P
p
.002 w
.35497 .52936 m .35512 .50413 L .38076 .52395 L p
1 g
F P
s
P
p
.002 w
.43967 .57893 m .4508 .58083 L .45978 .60111 L p
1 g
F P
s
P
p
.002 w
.48014 .59924 m .45978 .60111 L .4508 .58083 L p
1 g
F P
s
P
p
.002 w
.61929 .32312 m .55931 .28675 L .56735 .26938 L p
1 g
F P
s
P
p
.002 w
.63777 .48725 m .64028 .53355 L .61377 .54626 L p
1 g
F P
s
P
p
.002 w
.64028 .53355 m .63777 .48725 L .65985 .46776 L p
1 g
F P
s
P
p
.002 w
.61929 .32312 m .66389 .37243 L .65274 .39342 L p
1 g
F P
s
P
p
.002 w
.54158 .5849 m .52396 .60262 L .49719 .59183 L p
1 g
F P
s
P
p
.002 w
.48014 .59924 m .49719 .59183 L .52396 .60262 L p
1 g
F P
s
P
p
.002 w
.52396 .60262 m .54158 .5849 L .57226 .58559 L p
1 g
F P
s
P
p
.002 w
.36572 .48198 m .35512 .50413 L .33428 .48254 L p
1 g
F P
s
P
p
.002 w
.33428 .48254 m .34747 .45376 L .36572 .48198 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.58326 .55576 m .57226 .58559 L .54158 .5849 L p
1 g
F P
s
P
p
.002 w
.57226 .58559 m .58326 .55576 L .61377 .54626 L p
1 g
F P
s
P
p
.002 w
.41008 .55001 m .41339 .55906 L .38709 .55888 L p
1 g
F P
s
P
p
.002 w
.38709 .55888 m .38041 .54121 L .41008 .55001 L p
1 g
F P
s
P
p
.002 w
.4508 .58083 m .46124 .57981 L .48014 .59924 L p
1 g
F P
s
P
p
.002 w
.49719 .59183 m .48014 .59924 L .46124 .57981 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45576 .52746 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.40814 .35042 m .35992 .36736 L .35961 .33832 L p
1 g
F P
s
P
p
.002 w
.35961 .33832 m .41178 .31938 L .40814 .35042 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.37327 .43209 m .34747 .45376 L .33408 .42535 L p
1 g
F P
s
P
p
.002 w
.33408 .42535 m .36448 .39898 L .37327 .43209 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.63661 .41619 m .65985 .46776 L .63777 .48725 L p
1 g
F P
s
P
p
.002 w
.65985 .46776 m .63661 .41619 L .65274 .39342 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.41039 .54125 m .41008 .55001 L .38041 .54121 L p
1 g
F P
s
P
p
.002 w
.38041 .54121 m .38076 .52395 L .41039 .54125 L p
1 g
F P
s
P
p
.002 w
.38827 .50897 m .38076 .52395 L .35512 .50413 L p
1 g
F P
s
P
p
.002 w
.35512 .50413 m .36572 .48198 L .38827 .50897 L p
1 g
F P
s
P
p
.002 w
.61101 .50543 m .61377 .54626 L .58326 .55576 L p
1 g
F P
s
P
p
.002 w
.61377 .54626 m .61101 .50543 L .63777 .48725 L p
1 g
F P
s
P
p
.002 w
.54918 .30911 m .48265 .29087 L .49195 .26842 L p
1 g
F P
s
P
p
.002 w
.49195 .26842 m .55931 .28675 L .54918 .30911 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49719 .59183 m .46989 .57594 L p
.47108 .57605 L 1 g
F P
s
P
p
.002 w
.50439 .58437 m .49719 .59183 L p
.47779 .5801 L 1 g
F P
s
P
p
.48907 .58054 m .47779 .5801 L .47108 .57605 L 1 g
F
P
p
.50439 .58437 m .47779 .5801 L .48907 .58054 L 1 g
F
P
p
.51079 .57862 m .49922 .58093 L .5074 .58125 L 1 g
F
P
p
.002 w
.51575 .58064 m .54158 .5849 L p
.50924 .58144 L 1 g
F P
s
P
p
.50924 .58144 m .5074 .58125 L .51097 .58099 L 1 g
F
P
p
.50924 .58144 m .51097 .58099 L .51575 .58064 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58099 L p
1 g
F P
s
P
p
.002 w
.49719 .59183 m .5074 .58125 L p
.54158 .5849 L 1 g
F P
s
P
p
.53128 .57265 m .51097 .58099 L .51363 .58029 L 1 g
F
P
p
.002 w
.54709 .56913 m .54158 .5849 L .52002 .58135 L p
1 g
F P
s
P
p
.002 w
.52002 .58135 m .51363 .58029 L p
.53164 .57428 L 1 g
F P
s
P
p
.54709 .56913 m .52002 .58135 L .53164 .57428 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53164 .57428 L p
1 g
F P
s
P
p
.54854 .56129 m .53164 .57428 L .54067 .56879 L 1 g
F
P
p
.53128 .57265 m .51363 .58029 L .52151 .57766 L 1 g
F
P
p
.002 w
.51097 .58099 m .51079 .57862 L p
.5074 .58125 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.5074 .58125 m .50905 .57954 L .51363 .58029 L p
1 g
F P
s
P
p
.002 w
.51363 .58029 m .51575 .58064 L p
.51097 .58099 L 1 g
F P
s
P
p
.51097 .58099 m .5074 .58125 L .51363 .58029 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5319 .57551 L p
1 g
F P
s
P
p
.002 w
.5319 .57551 m .53128 .57265 L p
.51925 .57882 L 1 g
F P
s
P
p
.51925 .57882 m .51111 .583 L .5319 .57551 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54854 .56129 m .54067 .56879 L .54897 .56374 L 1 g
F
P
p
.002 w
.55259 .56112 m .58326 .55576 L p
.54915 .5637 L 1 g
F P
s
P
p
.54915 .5637 m .54897 .56374 L .54935 .56347 L 1 g
F
P
p
.54915 .5637 m .54935 .56347 L .55259 .56112 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54935 .56347 L p
1 g
F P
s
P
p
.002 w
.54158 .5849 m .54897 .56374 L p
.58326 .55576 L 1 g
F P
s
P
p
.56075 .54566 m .54935 .56347 L .55118 .56136 L 1 g
F
P
p
.002 w
.58042 .52162 m .58326 .55576 L .55684 .56037 L p
1 g
F P
s
P
p
.002 w
.55684 .56037 m .55118 .56136 L p
.56092 .54812 L 1 g
F P
s
P
p
.58042 .52162 m .55684 .56037 L .56092 .54812 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56136 .54681 L p
1 g
F P
s
P
p
.56654 .52734 m .56136 .54681 L .56495 .53605 L 1 g
F
P
p
.56075 .54566 m .55118 .56136 L .55547 .55523 L 1 g
F
P
p
.58042 .52162 m .56092 .54812 L .56422 .54273 L 1 g
F
P
p
.56092 .54812 m .55118 .56136 L .56136 .54681 L 1 g
F
P
p
.56092 .54812 m .56136 .54681 L .56422 .54273 L 1 g
F
P
p
.002 w
.54935 .56347 m .54854 .56129 L p
.54897 .56374 L 1 g
F P
s
P
p
.002 w
.54897 .56374 m .54972 .56162 L .55118 .56136 L p
1 g
F P
s
P
p
.002 w
.55118 .56136 m .55259 .56112 L p
.54935 .56347 L 1 g
F P
s
P
p
.54935 .56347 m .54897 .56374 L .55118 .56136 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5623 .5486 L p
1 g
F P
s
P
p
.002 w
.5623 .5486 m .56136 .54681 L p
.55521 .55674 L 1 g
F P
s
P
p
.55521 .55674 m .54998 .56518 L .5623 .5486 L 1 g
F
P
p
.002 w
.56136 .54681 m .56075 .54566 L p
.55547 .55523 L 1 g
F P
s
P
p
.55547 .55523 m .54998 .56518 L .56136 .54681 L 1 g
F
P
p
.002 w
.55118 .56136 m .54972 .56162 L p
.56158 .54617 L 1 g
F P
s
P
p
.56422 .54273 m .56136 .54681 L .56158 .54617 L 1 g
F
P
p
.56136 .54681 m .55118 .56136 L .56158 .54617 L 1 g
F
P
p
.002 w
.56742 .52863 m .56654 .52734 L p
.56495 .53605 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56742 .52863 L p
1 g
F P
s
P
p
.56515 .50826 m .56742 .52863 L .56739 .52691 L 1 g
F
P
p
.002 w
.56398 .48819 m .58042 .52162 L .57315 .52457 L p
1 g
F P
s
P
p
.002 w
.57315 .52457 m .56739 .52691 L p
.56582 .50905 L 1 g
F P
s
P
p
.56398 .48819 m .57315 .52457 L .56582 .50905 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56582 .50905 L p
1 g
F P
s
P
p
.55661 .4905 m .56582 .50905 L .5612 .49928 L 1 g
F
P
p
.56515 .50826 m .56739 .52691 L .56654 .51727 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56739 .52691 m .58042 .52162 L p
.56762 .53829 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55749 .49144 m .55661 .4905 L p
.5612 .49928 L 1 g
F P
s
P
p
.002 w
.56739 .52691 m .54707 .53516 L p
.56051 .49782 L 1 g
F P
s
P
p
.56398 .48819 m .56582 .50905 L .56051 .49782 L 1 g
F
P
p
.56582 .50905 m .56739 .52691 L .56051 .49782 L 1 g
F
P
p
.002 w
.56339 .487 m .56398 .48819 L p
.54707 .53516 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54707 .53516 m .53352 .50848 L .55738 .49133 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55749 .49144 L p
1 g
F P
s
P
p
.54174 .47608 m .55749 .49144 L .55738 .49133 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55738 .49133 m .53352 .50848 L p
.53365 .47252 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54217 .47654 L p
1 g
F P
s
P
p
.52214 .46667 m .54217 .47654 L .53109 .4713 L 1 g
F
P
p
.53367 .46828 m .54217 .47654 L .53365 .47252 L 1 g
F
P
p
.54217 .47654 m .55738 .49133 L .53365 .47252 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53352 .50848 m .51036 .48476 L .52406 .46798 L p
1 g
F P
s
P
p
.52214 .46667 m .53109 .4713 L .52406 .46798 L 1 g
F
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52406 .46798 m .51036 .48476 L p
.50423 .46439 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .50871 .46508 L 1 g
F
P
p
.52244 .46717 m .52406 .46798 L .50423 .46439 L 1 g
F
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.50423 .46439 m .51036 .48476 L .48807 .46568 L 1 g
F
P
p
.47786 .46667 m .48888 .46555 L .48023 .46695 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.50423 .46439 m .48807 .46568 L .5 .46375 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .46442 L p
.48888 .46555 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .48888 .46555 L 1 g
F
P
p
.002 w
.51036 .48476 m .48023 .46695 L .48023 .46695 L p
1 g
F P
s
P
p
.002 w
.48023 .46695 m .48273 .46112 L p
.48807 .46568 L 1 g
F P
s
P
p
.48807 .46568 m .51036 .48476 L .48023 .46695 L 1 g
F
P
p
.002 w
.44677 .45728 m .45148 .42065 L p
.48023 .46695 L 1 g
F P
s
P
p
.002 w
.48023 .46695 m .48022 .46695 L p
.48023 .46695 L 1 g
F P
s
P
p
.002 w
.48022 .46695 m .44677 .45728 L p
.48023 .46695 L 1 g
F P
s
P
p
.47786 .46667 m .48023 .46695 L .48023 .46695 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.45148 .42065 m .49478 .43303 L .48023 .46695 L p
1 g
F P
s
P
p
.002 w
.48023 .46695 m .48023 .46695 L p
.48023 .46695 L 1 g
F P
s
P
p
.45148 .42065 m .48023 .46695 L .48023 .46695 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.48023 .46695 m .46642 .49943 L p
.4564 .47794 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.45777 .47662 m .48023 .46695 L .4564 .47794 L 1 g
F
P
p
.002 w
.45777 .47662 m .45826 .47608 L p
.46705 .47223 L 1 g
F P
s
P
p
.47748 .46729 m .48023 .46695 L .45777 .47662 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47749 .46729 L p
1 g
F P
s
P
p
.45826 .47608 m .47749 .46729 L .46705 .47223 L 1 g
F
P
p
.002 w
.48022 .46695 m .48023 .46695 L p
.45285 .47032 L 1 g
F P
s
P
p
.002 w
.47749 .46729 m .47718 .46778 L p
.46705 .47223 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45777 .47662 L p
1 g
F P
s
P
p
.44339 .4905 m .45777 .47662 L .45009 .48408 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42153 .49233 m .41408 .45684 L p
.44252 .49132 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44241 .49154 L p
1 g
F P
s
P
p
.43485 .50826 m .44241 .49154 L .44207 .49222 L 1 g
F
P
p
.43485 .50826 m .44235 .49161 L .43843 .49989 L 1 g
F
P
p
.44339 .4905 m .45009 .48408 L .44399 .49001 L 1 g
F
P
p
.002 w
.44241 .49154 m .44339 .4905 L p
.44399 .49001 L 1 g
F P
s
P
p
.002 w
.41408 .45684 m .44677 .45728 L .44399 .49001 L p
1 g
F P
s
P
p
.002 w
.44399 .49001 m .44375 .49281 L p
.44257 .49138 L 1 g
F P
s
P
p
.41408 .45684 m .44399 .49001 L .44257 .49138 L 1 g
F
P
p
.002 w
.44375 .49281 m .4418 .49276 L p
.44241 .49154 L 1 g
F P
s
P
p
.44257 .49138 m .44375 .49281 L .44241 .49154 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.46642 .49943 m .44375 .49281 L .44399 .49001 L p
1 g
F P
s
P
p
.002 w
.44399 .49001 m .44677 .45728 L p
.4564 .47794 L 1 g
F P
s
P
p
.4564 .47794 m .46642 .49943 L .44399 .49001 L 1 g
F
P
p
.44399 .49001 m .45698 .47747 L .44235 .49161 L 1 g
F
P
p
.45009 .48408 m .45208 .48218 L .44399 .49001 L 1 g
F
P
p
.45208 .48218 m .45698 .47747 L .44399 .49001 L 1 g
F
P
p
.002 w
.44235 .49161 m .44241 .49154 L p
.44399 .49001 L 1 g
F P
s
P
p
.44252 .49132 m .44257 .49138 L .44241 .49154 L 1 g
F
P
p
.002 w
.4418 .49276 m .42153 .49233 L p
.44252 .49132 L 1 g
F P
s
P
p
.002 w
.44241 .49154 m .44235 .49161 L p
.44207 .49222 L 1 g
F P
s
P
p
.002 w
.42153 .49233 m .43553 .49263 L p
.43319 .51098 L 1 g
F P
s
P
p
.002 w
.43553 .49263 m .4418 .49276 L p
.43398 .50929 L 1 g
F P
s
P
p
.43553 .49263 m .43398 .50929 L .43319 .51098 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43398 .50929 L p
1 g
F P
s
P
p
.43346 .52734 m .43398 .50929 L .43315 .51832 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42939 .519 m .42153 .49233 L p
.43319 .51098 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43398 .50929 L p
1 g
F P
s
P
p
.002 w
.43398 .50929 m .43485 .50826 L p
.43843 .49989 L 1 g
F P
s
P
p
.43843 .49989 m .44166 .49233 L .43398 .50929 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43132 .52556 m .42939 .519 L p
.43291 .52085 L 1 g
F P
s
P
p
.002 w
.43247 .5256 m .43132 .52556 L p
.43291 .52085 L 1 g
F P
s
P
p
.43346 .52734 m .43315 .51832 L .43247 .5256 L 1 g
F
P
p
.002 w
.43239 .52826 m .43132 .52556 L .43247 .5256 L p
1 g
F P
s
P
p
.002 w
.42159 .52829 m .43132 .52556 L .43239 .52826 L p
1 g
F P
s
P
p
.002 w
.43236 .52894 m .43346 .52734 L p
.43247 .5256 L 1 g
F P
s
P
p
.002 w
.42902 .57431 m .41994 .56745 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.002 w
.43967 .57893 m .42902 .57431 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.002 w
.4508 .58083 m .43967 .57893 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.002 w
.41994 .56745 m .41339 .55906 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.002 w
.46124 .57981 m .4508 .58083 L .444 .5585 L p
1 g
F P
s
P
p
.002 w
.444 .5585 m .44303 .55534 L .44687 .5605 L p
1 g
F P
s
P
p
.002 w
.44687 .5605 m .46124 .57981 L p
.444 .5585 L 1 g
F P
s
P
p
.002 w
.46819 .57506 m .46872 .57265 L p
.45895 .56875 L 1 g
F P
s
P
p
.45146 .56129 m .4428 .55376 L .44301 .55407 L 1 g
F
P
p
.002 w
.44336 .55456 m .44303 .55534 L .44301 .55407 L p
1 g
F P
s
P
p
.44323 .55437 m .44301 .55407 L .44321 .55436 L 1 g
F
P
p
.45146 .56129 m .44301 .55407 L .44323 .55437 L 1 g
F
P
p
.45146 .56129 m .44321 .55436 L .44338 .55458 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44301 .55407 m .44303 .55534 L .44192 .5525 L p
1 g
F P
s
P
p
.43202 .54145 m .4321 .53833 L .43881 .54877 L 1 g
F
P
p
.002 w
.44303 .55534 m .4395 .55088 L p
.43881 .54877 L 1 g
F P
s
P
p
.002 w
.4395 .55088 m .43202 .54145 L p
.43881 .54877 L 1 g
F P
s
P
p
.002 w
.43835 .54735 m .43925 .54566 L p
.4352 .53765 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43835 .54735 L p
1 g
F P
s
P
p
.002 w
.44192 .5525 m .44303 .55534 L p
.4321 .53833 L 1 g
F P
s
P
p
.002 w
.41436 .53373 m .42159 .52829 L .4395 .55088 L p
1 g
F P
s
P
p
.002 w
.4395 .55088 m .44303 .55534 L .44029 .55328 L p
1 g
F P
s
P
p
.002 w
.44029 .55328 m .41436 .53373 L p
.4395 .55088 L 1 g
F P
s
P
p
.45146 .56129 m .43835 .54735 L .44278 .55374 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43237 .52893 L p
1 g
F P
s
P
p
.43925 .54566 m .43237 .52893 L .4352 .53765 L 1 g
F
P
p
.002 w
.43239 .52826 m .44192 .5525 L p
.43835 .54735 L 1 g
F P
s
P
p
.4321 .53833 m .43237 .52893 L .43835 .54735 L 1 g
F
P
p
.43237 .52893 m .43239 .52826 L .43835 .54735 L 1 g
F
P
p
.002 w
.43202 .54145 m .42159 .52829 L p
.43239 .52826 L 1 g
F P
s
P
p
.002 w
.43237 .52893 m .43146 .53025 L p
.4352 .53765 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43834 .54738 L p
1 g
F P
s
P
p
.002 w
.43834 .54738 m .43835 .54735 L p
.43822 .54703 L 1 g
F P
s
P
p
.43822 .54703 m .43146 .53025 L .43834 .54738 L 1 g
F
P
p
.002 w
.43835 .54735 m .43743 .5491 L p
.44278 .55374 L 1 g
F P
s
P
p
.4352 .53765 m .43146 .53025 L .43835 .54735 L 1 g
F
P
p
.002 w
.4425 .52588 m .45388 .52924 L .44336 .55456 L p
1 g
F P
s
P
p
.002 w
.44301 .55407 m .4425 .52588 L p
.44336 .55456 L 1 g
F P
s
P
p
.45146 .56129 m .44336 .55456 L .44349 .55474 L 1 g
F
P
p
.45146 .56129 m .44347 .55472 L .44359 .55488 L 1 g
F
P
p
.002 w
.45388 .52924 m .46416 .53526 L .44356 .55484 L p
1 g
F P
s
P
p
.002 w
.44356 .55484 m .44303 .55534 L .44336 .55456 L p
1 g
F P
s
P
p
.002 w
.44336 .55456 m .45388 .52924 L p
.44356 .55484 L 1 g
F P
s
P
p
.44338 .55458 m .44321 .55436 L .44336 .55456 L 1 g
F
P
p
.44349 .55474 m .44336 .55456 L .44347 .55472 L 1 g
F
P
p
.45146 .56129 m .44356 .55485 L .44368 .555 L 1 g
F
P
p
.45146 .56129 m .44364 .55497 L .44377 .55512 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46416 .53526 m .47218 .54326 L .44373 .55505 L p
1 g
F P
s
P
p
.002 w
.44373 .55505 m .44303 .55534 L .44356 .55484 L p
1 g
F P
s
P
p
.002 w
.44356 .55484 m .46416 .53526 L p
.44373 .55505 L 1 g
F P
s
P
p
.45146 .56129 m .44372 .55508 L .44377 .55515 L 1 g
F
P
p
.002 w
.4439 .55527 m .44303 .55534 L .44373 .55505 L p
1 g
F P
s
P
p
.002 w
.44411 .55553 m .44303 .55534 L .4439 .55527 L p
1 g
F P
s
P
p
.002 w
.44449 .55598 m .44303 .55534 L .44411 .55553 L p
1 g
F P
s
P
p
.002 w
.45077 .56316 m .45146 .56129 L p
.44371 .55509 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47218 .54326 m .47707 .55232 L .4439 .55527 L p
1 g
F P
s
P
p
.002 w
.44373 .55505 m .47218 .54326 L p
.4439 .55527 L 1 g
F P
s
P
p
.44359 .55488 m .44347 .55472 L .44356 .55485 L 1 g
F
P
p
.44368 .555 m .44356 .55485 L .44364 .55497 L 1 g
F
P
p
.002 w
.47707 .55232 m .4783 .56143 L .44411 .55553 L p
1 g
F P
s
P
p
.002 w
.4439 .55527 m .47707 .55232 L p
.44411 .55553 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.4783 .56143 m .47581 .56959 L .44449 .55598 L p
1 g
F P
s
P
p
.002 w
.44411 .55553 m .4783 .56143 L p
.44449 .55598 L 1 g
F P
s
P
p
.44377 .55512 m .44364 .55497 L .44372 .55508 L 1 g
F
P
p
.44377 .55515 m .44372 .55508 L .44375 .55513 L 1 g
F
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46989 .57594 m .46964 .57605 L p
.46855 .5752 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46819 .57506 L p
1 g
F P
s
P
p
.48921 .57862 m .46819 .57506 L .46824 .57508 L 1 g
F
P
p
.48921 .57862 m .46824 .57508 L .47008 .5758 L 1 g
F
P
p
.48921 .57862 m .47008 .5758 L .47756 .57766 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58054 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58054 L .49922 .58093 L 1 g
F
P
p
.002 w
.48907 .58054 m .48921 .57862 L p
.47756 .57766 L 1 g
F P
s
P
p
.002 w
.50905 .57954 m .5074 .58125 L p
.47108 .57605 L 1 g
F P
s
P
p
.002 w
.5074 .58125 m .50439 .58437 L p
.48907 .58054 L 1 g
F P
s
P
p
.5074 .58125 m .48907 .58054 L .47108 .57605 L 1 g
F
P
p
.002 w
.48907 .58054 m .48889 .583 L p
.49922 .58093 L 1 g
F P
s
P
p
.002 w
.47581 .56959 m .50905 .57954 L p
.47108 .57605 L 1 g
F P
s
P
p
.002 w
.46989 .57594 m .47003 .57578 L p
.47108 .57605 L 1 g
F P
s
P
p
.46824 .57508 m .46935 .57552 L .47417 .57738 L 1 g
F
P
p
.002 w
.47003 .57578 m .47581 .56959 L p
.47108 .57605 L 1 g
F P
s
P
p
.47756 .57766 m .47008 .5758 L .47417 .57738 L 1 g
F
P
p
.46989 .57594 m .46855 .5752 L .46934 .57552 L 1 g
F
P
p
.002 w
.46964 .57605 m .46124 .57981 L .45333 .56917 L p
1 g
F P
s
P
p
.002 w
.45333 .56917 m .44687 .5605 L p
.46819 .57506 L 1 g
F P
s
P
p
.46964 .57605 m .45333 .56917 L .46819 .57506 L 1 g
F
P
p
.002 w
.46935 .57552 m .46989 .57594 L p
.46934 .57552 L 1 g
F P
s
P
p
.002 w
.47003 .57578 m .46989 .57594 L .46935 .57552 L p
1 g
F P
s
P
p
.002 w
.44687 .5605 m .44303 .55534 L p
.44583 .55752 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.46964 .57605 m .45077 .56316 L .44583 .55752 L 1 g
F
P
p
.45077 .56316 m .44687 .5605 L .44583 .55752 L 1 g
F
P
p
.002 w
.44575 .55742 m .44303 .55534 L .44449 .55598 L p
1 g
F P
s
P
p
.002 w
.44303 .55534 m .44575 .55742 L p
.44583 .55752 L 1 g
F P
s
P
p
.002 w
.41339 .55906 m .41008 .55001 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.002 w
.41008 .55001 m .41039 .54125 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.002 w
.41039 .54125 m .41436 .53373 L .44303 .55534 L closepath p
1 g
F P
s
P
p
.44371 .55509 m .43743 .5491 L .45025 .56454 L 1 g
F
P
p
.44278 .55374 m .44174 .55285 L .44371 .55509 L 1 g
F
P
p
.44174 .55285 m .43743 .5491 L .44371 .55509 L 1 g
F
P
p
.002 w
.46124 .57981 m .46989 .57594 L .49719 .59183 L p
1 g
F P
s
P
p
.002 w
.46819 .57507 m .4678 .57686 L p
.47403 .57737 L 1 g
F P
s
P
p
.47417 .57738 m .46935 .57552 L .47403 .57737 L 1 g
F
P
p
.46935 .57552 m .46819 .57507 L .47403 .57737 L 1 g
F
P
p
.46824 .57508 m .46819 .57507 L .46935 .57552 L 1 g
F
P
p
.002 w
.44575 .55742 m .46935 .57552 L p
.44583 .55752 L 1 g
F P
s
P
p
.46934 .57552 m .44583 .55752 L .46935 .57552 L 1 g
F
P
p
.46934 .57552 m .46855 .5752 L .44583 .55752 L 1 g
F
P
p
.002 w
.46819 .57506 m .46819 .57507 L p
.46824 .57508 L 1 g
F P
s
P
p
.002 w
.47581 .56959 m .47003 .57578 L p
.44575 .55742 L 1 g
F P
s
P
p
.002 w
.46935 .57552 m .44575 .55742 L p
.47003 .57578 L 1 g
F P
s
P
p
.002 w
.44449 .55598 m .47581 .56959 L p
.44575 .55742 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.4425 .52588 m .44301 .55407 L p
.43239 .52826 L 1 g
F P
s
P
p
.002 w
.44192 .5525 m .43239 .52826 L p
.44301 .55407 L 1 g
F P
s
P
p
.44375 .55513 m .44278 .55374 L .44371 .55509 L 1 g
F
P
p
.4428 .55376 m .44278 .55374 L .44375 .55513 L 1 g
F
P
p
.002 w
.45025 .56454 m .45077 .56316 L p
.44371 .55509 L 1 g
F P
s
P
p
.002 w
.46815 .57528 m .46819 .57506 L p
.45847 .56856 L 1 g
F P
s
P
p
.45895 .56875 m .45847 .56856 L .46819 .57506 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46815 .57528 L p
1 g
F P
s
P
p
.45847 .56856 m .45002 .56518 L .46815 .57528 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45025 .56454 L p
1 g
F P
s
P
p
.002 w
.43213 .52928 m .43236 .52894 L p
.43239 .52826 L 1 g
F P
s
P
p
.43239 .52826 m .43247 .5256 L .43246 .52577 L 1 g
F
P
p
.43239 .52826 m .43246 .52577 L .43213 .52928 L 1 g
F
P
p
.002 w
.43247 .5256 m .4425 .52588 L p
.43239 .52826 L 1 g
F P
s
P
p
.43319 .51098 m .4425 .52588 L .42939 .519 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43213 .52928 L p
1 g
F P
s
P
p
.43315 .51832 m .43287 .51061 L .43213 .52928 L 1 g
F
P
p
.002 w
.4425 .52588 m .43247 .5256 L p
.43291 .52085 L 1 g
F P
s
P
p
.002 w
.44375 .49281 m .4425 .52588 L p
.43319 .51098 L 1 g
F P
s
P
p
.002 w
.4418 .49276 m .44375 .49281 L p
.43319 .51098 L 1 g
F P
s
P
p
.002 w
.43398 .50929 m .43287 .51061 L p
.43315 .51832 L 1 g
F P
s
P
p
.002 w
.44235 .49161 m .44166 .49233 L p
.43843 .49989 L 1 g
F P
s
P
p
.002 w
.45777 .47662 m .45698 .47747 L p
.45009 .48408 L 1 g
F P
s
P
p
.45285 .47032 m .4659 .46871 L .45777 .47662 L 1 g
F
P
p
.45614 .47739 m .45777 .47662 L .4564 .47794 L 1 g
F
P
p
.45285 .47032 m .45777 .47662 L .45614 .47739 L 1 g
F
P
p
.4659 .46871 m .47748 .46729 L .45777 .47662 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45777 .47662 L p
1 g
F P
s
P
p
.46705 .47223 m .47718 .46778 L .45777 .47662 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44235 .49161 L p
1 g
F P
s
P
p
.002 w
.47742 .46741 m .47747 .46732 L p
.48023 .46695 L 1 g
F P
s
P
p
.002 w
.47747 .46732 m .47749 .46729 L p
.48022 .46695 L 1 g
F P
s
P
p
.48022 .46695 m .48023 .46695 L .47747 .46732 L 1 g
F
P
p
.48023 .46695 m .48023 .46695 L .48023 .46695 L 1 g
F
P
p
.002 w
.47749 .46729 m .47786 .46667 L p
.48023 .46695 L 1 g
F P
s
P
p
.002 w
.44677 .45728 m .48022 .46695 L p
.45285 .47032 L 1 g
F P
s
P
p
.5 .46375 m .48807 .46568 L .48273 .46112 L 1 g
F
P
p
.002 w
.48688 .51146 m .46642 .49943 L .48023 .46695 L p
1 g
F P
s
P
p
.002 w
.48023 .46695 m .51036 .48476 L .48688 .51146 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47742 .46741 L p
1 g
F P
s
P
p
.48888 .46555 m .5 .46442 L .47742 .46741 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .4634 L p
.50871 .46508 L 1 g
F P
s
P
p
.50871 .46508 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.48273 .46112 m .49478 .43303 L p
.50423 .46439 L 1 g
F P
s
P
p
.50198 .45694 m .52244 .46717 L .50423 .46439 L 1 g
F
P
p
.002 w
.52244 .46717 m .52282 .46778 L p
.50871 .46508 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52244 .46717 L p
.52406 .46798 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.52406 .46798 L 1 g
F P
s
P
p
.002 w
.49478 .43303 m .53371 .45615 L .52406 .46798 L p
1 g
F P
s
P
p
.49478 .43303 m .52406 .46798 L .50198 .45694 L 1 g
F
P
p
.002 w
.52406 .46798 m .53371 .45615 L p
.53365 .47252 L 1 g
F P
s
P
p
.53365 .47252 m .53352 .50848 L .52406 .46798 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52248 .46723 L p
1 g
F P
s
P
p
.53109 .4713 m .54302 .47747 L .52248 .46723 L 1 g
F
P
p
.002 w
.54217 .47654 m .54302 .47747 L p
.53109 .4713 L 1 g
F P
s
P
p
.54858 .48278 m .55738 .49133 L .55297 .48708 L 1 g
F
P
p
.54174 .47608 m .55738 .49133 L .54858 .48278 L 1 g
F
P
p
.002 w
.53371 .45615 m .56339 .487 L .55738 .49133 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.56081 .49463 m .54707 .53516 L .55738 .49133 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55749 .49144 L p
1 g
F P
s
P
p
.5612 .49928 m .56713 .51061 L .55749 .49144 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.53371 .45615 m .55738 .49133 L .53367 .46828 L 1 g
F
P
p
.002 w
.55738 .49133 m .56339 .487 L p
.56081 .49463 L 1 g
F P
s
P
p
.002 w
.55749 .49144 m .55834 .49233 L p
.55297 .48708 L 1 g
F P
s
P
p
.002 w
.56582 .50905 m .56713 .51061 L p
.5612 .49928 L 1 g
F P
s
P
p
.56654 .51727 m .56739 .52691 L .56729 .52216 L 1 g
F
P
p
.002 w
.54972 .56162 m .54707 .53516 L .56739 .52691 L p
1 g
F P
s
P
p
.56762 .53829 m .54972 .56162 L .56739 .52691 L 1 g
F
P
p
.002 w
.56742 .52863 m .56854 .53025 L p
.56729 .52216 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56742 .52863 L p
1 g
F P
s
P
p
.56495 .53605 m .56257 .5491 L .56742 .52863 L 1 g
F
P
p
.002 w
.56136 .54681 m .56257 .5491 L p
.56495 .53605 L 1 g
F P
s
P
p
.55547 .55523 m .55118 .56136 L .55365 .55853 L 1 g
F
P
p
.002 w
.54935 .56347 m .54998 .56518 L p
.55365 .55853 L 1 g
F P
s
P
p
.002 w
.54936 .5635 m .54935 .56347 L p
.54897 .56374 L 1 g
F P
s
P
p
.002 w
.54972 .56162 m .54897 .56374 L p
.50905 .57954 L 1 g
F P
s
P
p
.002 w
.54897 .56374 m .54709 .56913 L p
.53441 .5726 L 1 g
F P
s
P
p
.54897 .56374 m .53441 .5726 L .50905 .57954 L 1 g
F
P
p
.002 w
.51363 .58029 m .50905 .57954 L p
.54709 .56913 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54936 .5635 L p
1 g
F P
s
P
p
.54067 .56879 m .5322 .57686 L .54936 .5635 L 1 g
F
P
p
.002 w
.53164 .57428 m .5322 .57686 L p
.54067 .56879 L 1 g
F P
s
P
p
.52151 .57766 m .51363 .58029 L .51925 .57882 L 1 g
F
P
p
.002 w
.51097 .58099 m .51111 .583 L p
.51925 .57882 L 1 g
F P
s
P
p
.002 w
.51099 .58139 m .51097 .58099 L p
.5074 .58125 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51099 .58139 L p
1 g
F P
s
P
p
.49922 .58093 m .48889 .583 L .51099 .58139 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58054 L p
1 g
F P
s
P
p
.47756 .57766 m .4678 .57686 L .48907 .58054 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.47361 .31827 m .41178 .31938 L .41797 .29242 L p
1 g
F P
s
P
p
.002 w
.41797 .29242 m .48265 .29087 L .47361 .31827 L p
1 g
F P
s
P
p
.002 w
.65274 .39342 m .60851 .34497 L .61929 .32312 L p
1 g
F P
s
P
p
.002 w
.55931 .28675 m .61929 .32312 L .60851 .34497 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.60851 .34497 m .65274 .39342 L .63661 .41619 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.60851 .34497 m .54918 .30911 L .55931 .28675 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.38603 .46551 m .36572 .48198 L .34747 .45376 L p
1 g
F P
s
P
p
.002 w
.34747 .45376 m .37327 .43209 L .38603 .46551 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.40727 .38451 m .36448 .39898 L .35992 .36736 L p
1 g
F P
s
P
p
.002 w
.35992 .36736 m .40814 .35042 L .40727 .38451 L p
1 g
F P
s
P
p
.002 w
.41436 .53373 m .41039 .54125 L .38076 .52395 L p
1 g
F P
s
P
p
.002 w
.38076 .52395 m .38827 .50897 L .41436 .53373 L p
1 g
F P
s
P
p
.002 w
.58326 .55576 m .58042 .52162 L .61101 .50543 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51431 .56355 m .50905 .57954 L .47581 .56959 L p
1 g
F P
s
P
p
.002 w
.50905 .57954 m .51431 .56355 L .54972 .56162 L p
1 g
F P
s
P
p
.002 w
.61588 .43995 m .63777 .48725 L .61101 .50543 L p
1 g
F P
s
P
p
.002 w
.63777 .48725 m .61588 .43995 L .63661 .41619 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40234 .49798 m .38827 .50897 L .36572 .48198 L p
1 g
F P
s
P
p
.002 w
.36572 .48198 m .38603 .46551 L .40234 .49798 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46518 .3498 m .40814 .35042 L .41178 .31938 L p
1 g
F P
s
P
p
.002 w
.41178 .31938 m .47361 .31827 L .46518 .3498 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.47581 .56959 m .4783 .56143 L .51431 .56355 L p
1 g
F P
s
P
p
.002 w
.53723 .33587 m .47361 .31827 L .48265 .29087 L p
1 g
F P
s
P
p
.002 w
.48265 .29087 m .54918 .30911 L .53723 .33587 L p
1 g
F P
s
P
p
.002 w
.54707 .53516 m .54972 .56162 L .51431 .56355 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40926 .42044 m .37327 .43209 L .36448 .39898 L p
1 g
F P
s
P
p
.002 w
.36448 .39898 m .40727 .38451 L .40926 .42044 L p
1 g
F P
s
P
p
.002 w
.63661 .41619 m .59407 .3701 L .60851 .34497 L p
1 g
F P
s
P
p
.002 w
.54918 .30911 m .60851 .34497 L .59407 .3701 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59407 .3701 m .63661 .41619 L .61588 .43995 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.42159 .52829 m .41436 .53373 L .38827 .50897 L p
1 g
F P
s
P
p
.002 w
.38827 .50897 m .40234 .49798 L .42159 .52829 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.59119 .46386 m .61101 .50543 L .58042 .52162 L p
1 g
F P
s
P
p
.002 w
.61101 .50543 m .59119 .46386 L .61588 .43995 L p
1 g
F P
s
P
p
.002 w
.51218 .54552 m .51431 .56355 L .4783 .56143 L p
1 g
F P
s
P
p
.002 w
.51431 .56355 m .51218 .54552 L .54707 .53516 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.4783 .56143 m .47707 .55232 L .51218 .54552 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59407 .3701 m .53723 .33587 L .54918 .30911 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41408 .45684 m .38603 .46551 L .37327 .43209 L p
1 g
F P
s
P
p
.002 w
.37327 .43209 m .40926 .42044 L .41408 .45684 L p
1 g
F P
s
P
p
.002 w
.43132 .52556 m .42159 .52829 L .40234 .49798 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.47707 .55232 m .47218 .54326 L .50272 .52746 L p
1 g
F P
s
P
p
.002 w
.50272 .52746 m .51218 .54552 L .47707 .55232 L p
1 g
F P
s
P
p
.002 w
.4577 .38435 m .40727 .38451 L .40814 .35042 L p
1 g
F P
s
P
p
.002 w
.40814 .35042 m .46518 .3498 L .4577 .38435 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.58042 .52162 m .56339 .487 L .59119 .46386 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42153 .49233 m .40234 .49798 L .38603 .46551 L p
1 g
F P
s
P
p
.002 w
.38603 .46551 m .41408 .45684 L .42153 .49233 L p
1 g
F P
s
P
p
.002 w
.40234 .49798 m .42153 .49233 L .43132 .52556 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57637 .39768 m .61588 .43995 L .59119 .46386 L p
1 g
F P
s
P
p
.002 w
.61588 .43995 m .57637 .39768 L .59407 .3701 L p
1 g
F P
s
P
p
.002 w
.47218 .54326 m .46416 .53526 L .48688 .51146 L p
1 g
F P
s
P
p
.002 w
.48688 .51146 m .50272 .52746 L .47218 .54326 L p
1 g
F P
s
P
p
.002 w
.51218 .54552 m .50272 .52746 L .53352 .50848 L p
1 g
F P
s
P
p
.002 w
.53352 .50848 m .54707 .53516 L .51218 .54552 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.52385 .3662 m .46518 .3498 L .47361 .31827 L p
1 g
F P
s
P
p
.002 w
.47361 .31827 m .53723 .33587 L .52385 .3662 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53723 .33587 m .59407 .3701 L .57637 .39768 L p
1 g
F P
s
P
p
.002 w
.45388 .52924 m .4425 .52588 L .44375 .49281 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.46416 .53526 m .45388 .52924 L .46642 .49943 L p
1 g
F P
s
P
p
.002 w
.46642 .49943 m .48688 .51146 L .46416 .53526 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.44375 .49281 m .46642 .49943 L .45388 .52924 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45148 .42065 m .40926 .42044 L .40727 .38451 L p
1 g
F P
s
P
p
.002 w
.40727 .38451 m .4577 .38435 L .45148 .42065 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57637 .39768 m .52385 .3662 L .53723 .33587 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.556 .42674 m .59119 .46386 L .56339 .487 L p
1 g
F P
s
P
p
.002 w
.59119 .46386 m .556 .42674 L .57637 .39768 L p
1 g
F P
s
P
p
.002 w
.50272 .52746 m .48688 .51146 L .51036 .48476 L p
1 g
F P
s
P
p
.002 w
.51036 .48476 m .53352 .50848 L .50272 .52746 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.44677 .45728 m .41408 .45684 L .40926 .42044 L p
1 g
F P
s
P
p
.002 w
.40926 .42044 m .45148 .42065 L .44677 .45728 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.50952 .399 m .4577 .38435 L .46518 .3498 L p
1 g
F P
s
P
p
.002 w
.46518 .3498 m .52385 .3662 L .50952 .399 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56339 .487 m .53371 .45615 L .556 .42674 L p
1 g
F P
s
P
p
.002 w
.52385 .3662 m .57637 .39768 L .556 .42674 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.556 .42674 m .50952 .399 L .52385 .3662 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.49478 .43303 m .45148 .42065 L .4577 .38435 L p
1 g
F P
s
P
p
.002 w
.4577 .38435 m .50952 .399 L .49478 .43303 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.004 w
.40939 .62906 m
.41959 .60671 L
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.004 w
.41959 .60671 m
.42386 .59736 L
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.50952 .399 m .556 .42674 L .53371 .45615 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53371 .45615 m .49478 .43303 L .50952 .399 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .5437 .7245 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40939 .62906 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0294737)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0294737)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44622 .43498 m .47803 .46225 L .49344 .43842 L p
1 g
F P
s
P
p
.002 w
.49344 .43842 m .46701 .41566 L .44622 .43498 L p
1 g
F P
s
P
p
.002 w
.52504 .45325 m .49344 .43842 L .47803 .46225 L p
1 g
F P
s
P
p
.002 w
.46701 .41566 m .49344 .43842 L .50897 .41444 L p
1 g
F P
s
P
p
.002 w
.49344 .43842 m .52504 .45325 L .53348 .4259 L p
1 g
F P
s
P
p
.002 w
.53348 .4259 m .50897 .41444 L .49344 .43842 L p
1 g
F P
s
P
p
.002 w
.50897 .41444 m .48852 .39677 L .46701 .41566 L p
1 g
F P
s
P
p
.002 w
.48852 .39677 m .50897 .41444 L .52435 .39076 L p
1 g
F P
s
P
p
.002 w
.50897 .41444 m .53348 .4259 L .54114 .39858 L p
1 g
F P
s
P
p
.002 w
.54114 .39858 m .52435 .39076 L .50897 .41444 L p
1 g
F P
s
P
p
.002 w
.55965 .42997 m .53348 .4259 L .52504 .45325 L p
1 g
F P
s
P
p
.002 w
.53348 .4259 m .55965 .42997 L .55905 .40127 L p
1 g
F P
s
P
p
.002 w
.55905 .40127 m .54114 .39858 L .53348 .4259 L p
1 g
F P
s
P
p
.002 w
.47803 .46225 m .51596 .48013 L .52504 .45325 L p
1 g
F P
s
P
p
.002 w
.5588 .45868 m .52504 .45325 L .51596 .48013 L p
1 g
F P
s
P
p
.002 w
.52504 .45325 m .5588 .45868 L .55965 .42997 L p
1 g
F P
s
P
p
.002 w
.44833 .38712 m .46701 .41566 L .48852 .39677 L p
1 g
F P
s
P
p
.002 w
.48852 .39677 m .47418 .37459 L .44833 .38712 L p
1 g
F P
s
P
p
.002 w
.47418 .37459 m .48852 .39677 L .51038 .37864 L p
1 g
F P
s
P
p
.002 w
.52435 .39076 m .51038 .37864 L .48852 .39677 L p
1 g
F P
s
P
p
.002 w
.42358 .40078 m .44622 .43498 L .46701 .41566 L p
1 g
F P
s
P
p
.002 w
.46701 .41566 m .44833 .38712 L .42358 .40078 L p
1 g
F P
s
P
p
.002 w
.42655 .45436 m .46302 .48552 L .47803 .46225 L p
1 g
F P
s
P
p
.002 w
.47803 .46225 m .44622 .43498 L .42655 .45436 L p
1 g
F P
s
P
p
.002 w
.51596 .48013 m .47803 .46225 L .46302 .48552 L p
1 g
F P
s
P
p
.002 w
.51038 .37864 m .52435 .39076 L .5393 .3678 L p
1 g
F P
s
P
p
.002 w
.52435 .39076 m .54114 .39858 L .54787 .37178 L p
1 g
F P
s
P
p
.002 w
.54787 .37178 m .5393 .3678 L .52435 .39076 L p
1 g
F P
s
P
p
.002 w
.54114 .39858 m .55905 .40127 L .557 .3731 L p
1 g
F P
s
P
p
.002 w
.557 .3731 m .54787 .37178 L .54114 .39858 L p
1 g
F P
s
P
p
.002 w
.46302 .48552 m .50641 .50606 L .51596 .48013 L p
1 g
F P
s
P
p
.002 w
.5565 .48687 m .51596 .48013 L .50641 .50606 L p
1 g
F P
s
P
p
.002 w
.51596 .48013 m .5565 .48687 L .5588 .45868 L p
1 g
F P
s
P
p
.002 w
.51038 .37864 m .50066 .36342 L .47418 .37459 L p
1 g
F P
s
P
p
.002 w
.50066 .36342 m .51038 .37864 L .53218 .3616 L p
1 g
F P
s
P
p
.002 w
.5393 .3678 m .53218 .3616 L .51038 .37864 L p
1 g
F P
s
P
p
.002 w
.40042 .41534 m .42655 .45436 L .44622 .43498 L p
1 g
F P
s
P
p
.002 w
.44622 .43498 m .42358 .40078 L .40042 .41534 L p
1 g
F P
s
P
p
.002 w
.58486 .42614 m .55965 .42997 L .5588 .45868 L p
1 g
F P
s
P
p
.002 w
.55965 .42997 m .58486 .42614 L .57623 .39851 L p
1 g
F P
s
P
p
.002 w
.57623 .39851 m .55905 .40127 L .55965 .42997 L p
1 g
F P
s
P
p
.002 w
.43938 .35548 m .44833 .38712 L .47418 .37459 L p
1 g
F P
s
P
p
.002 w
.47418 .37459 m .46747 .35007 L .43938 .35548 L p
1 g
F P
s
P
p
.002 w
.46747 .35007 m .47418 .37459 L .50066 .36342 L p
1 g
F P
s
P
p
.002 w
.59144 .45401 m .5588 .45868 L .5565 .48687 L p
1 g
F P
s
P
p
.002 w
.5588 .45868 m .59144 .45401 L .58486 .42614 L p
1 g
F P
s
P
p
.002 w
.55905 .40127 m .57623 .39851 L .56572 .37163 L p
1 g
F P
s
P
p
.002 w
.56572 .37163 m .557 .3731 L .55905 .40127 L p
1 g
F P
s
P
p
.002 w
.40839 .47347 m .44869 .50779 L .46302 .48552 L p
1 g
F P
s
P
p
.002 w
.46302 .48552 m .42655 .45436 L .40839 .47347 L p
1 g
F P
s
P
p
.002 w
.50641 .50606 m .46302 .48552 L .44869 .50779 L p
1 g
F P
s
P
p
.002 w
.50066 .36342 m .49623 .34665 L .46747 .35007 L p
1 g
F P
s
P
p
.002 w
.49623 .34665 m .50066 .36342 L .52727 .35383 L p
1 g
F P
s
P
p
.002 w
.53218 .3616 m .52727 .35383 L .50066 .36342 L p
1 g
F P
s
P
p
.002 w
.4125 .3628 m .42358 .40078 L .44833 .38712 L p
1 g
F P
s
P
p
.002 w
.44833 .38712 m .43938 .35548 L .4125 .3628 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .53218 .3616 L .5393 .3678 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .5393 .3678 L .54787 .37178 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .54787 .37178 L .557 .3731 L closepath p
1 g
F P
s
P
p
.002 w
.44869 .50779 m .49655 .53053 L .50641 .50606 L p
1 g
F P
s
P
p
.002 w
.5528 .51401 m .50641 .50606 L .49655 .53053 L p
1 g
F P
s
P
p
.002 w
.50641 .50606 m .5528 .51401 L .5565 .48687 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .52727 .35383 L .53218 .3616 L closepath p
1 g
F P
s
P
p
.002 w
.37933 .43054 m .40839 .47347 L .42655 .45436 L p
1 g
F P
s
P
p
.002 w
.42655 .45436 m .40042 .41534 L .37933 .43054 L p
1 g
F P
s
P
p
.002 w
.59583 .48157 m .5565 .48687 L .5528 .51401 L p
1 g
F P
s
P
p
.002 w
.5565 .48687 m .59583 .48157 L .59144 .45401 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .557 .3731 L .56572 .37163 L closepath p
1 g
F P
s
P
p
.002 w
.52727 .35383 m .52509 .34528 L .49623 .34665 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .52509 .34528 L .52727 .35383 L closepath p
1 g
F P
s
P
p
.002 w
.38737 .37193 m .40042 .41534 L .42358 .40078 L p
1 g
F P
s
P
p
.002 w
.42358 .40078 m .4125 .3628 L .38737 .37193 L p
1 g
F P
s
P
p
.002 w
.59088 .39051 m .57623 .39851 L .58486 .42614 L p
1 g
F P
s
P
p
.002 w
.57623 .39851 m .59088 .39051 L .57311 .36749 L p
1 g
F P
s
P
p
.002 w
.57311 .36749 m .56572 .37163 L .57623 .39851 L p
1 g
F P
s
P
p
.002 w
.46927 .32568 m .46747 .35007 L .49623 .34665 L p
1 g
F P
s
P
p
.002 w
.49623 .34665 m .49764 .33006 L .46927 .32568 L p
1 g
F P
s
P
p
.002 w
.49764 .33006 m .49623 .34665 L .52509 .34528 L p
1 g
F P
s
P
p
.002 w
.60651 .41464 m .58486 .42614 L .59144 .45401 L p
1 g
F P
s
P
p
.002 w
.58486 .42614 m .60651 .41464 L .59088 .39051 L p
1 g
F P
s
P
p
.002 w
.44136 .32386 m .43938 .35548 L .46747 .35007 L p
1 g
F P
s
P
p
.002 w
.46747 .35007 m .46927 .32568 L .44136 .32386 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .56572 .37163 L .57311 .36749 L closepath p
1 g
F P
s
P
p
.002 w
.52509 .34528 m .52591 .33688 L .49764 .33006 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .52591 .33688 L .52509 .34528 L closepath p
1 g
F P
s
P
p
.002 w
.39211 .49191 m .43535 .5286 L .44869 .50779 L p
1 g
F P
s
P
p
.002 w
.44869 .50779 m .40839 .47347 L .39211 .49191 L p
1 g
F P
s
P
p
.002 w
.49655 .53053 m .44869 .50779 L .43535 .5286 L p
1 g
F P
s
P
p
.002 w
.61964 .43941 m .59144 .45401 L .59583 .48157 L p
1 g
F P
s
P
p
.002 w
.59144 .45401 m .61964 .43941 L .60651 .41464 L p
1 g
F P
s
P
p
.002 w
.41448 .32469 m .4125 .3628 L .43938 .35548 L p
1 g
F P
s
P
p
.002 w
.43938 .35548 m .44136 .32386 L .41448 .32469 L p
1 g
F P
s
P
p
.002 w
.57835 .3611 m .57311 .36749 L .59088 .39051 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .57311 .36749 L .57835 .3611 L closepath p
1 g
F P
s
P
p
.002 w
.50486 .31542 m .49764 .33006 L .52591 .33688 L p
1 g
F P
s
P
p
.002 w
.52591 .33688 m .52965 .32952 L .50486 .31542 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .52965 .32952 L .52591 .33688 L closepath p
1 g
F P
s
P
p
.002 w
.49655 .53053 m .54771 .53954 L .5528 .51401 L p
1 g
F P
s
P
p
.002 w
.5979 .50829 m .5528 .51401 L .54771 .53954 L p
1 g
F P
s
P
p
.002 w
.5528 .51401 m .5979 .50829 L .59583 .48157 L p
1 g
F P
s
P
p
.002 w
.6014 .37802 m .59088 .39051 L .60651 .41464 L p
1 g
F P
s
P
p
.002 w
.59088 .39051 m .6014 .37802 L .57835 .3611 L p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .57835 .3611 L .58086 .35314 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .58086 .35314 L .58032 .34446 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .58032 .34446 L .57678 .33602 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .53595 .32402 L .52965 .32952 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .57678 .33602 L .57061 .32876 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .57061 .32876 L .56249 .32349 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .56249 .32349 L .55332 .3208 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .55332 .3208 L .54413 .32099 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .34601 m .54413 .32099 L .53595 .32402 L closepath p
1 g
F P
s
P
p
.002 w
.43535 .5286 m .48656 .55302 L .49655 .53053 L p
1 g
F P
s
P
p
.002 w
.54771 .53954 m .49655 .53053 L .48656 .55302 L p
1 g
F P
s
P
p
.002 w
.47963 .30401 m .46927 .32568 L .49764 .33006 L p
1 g
F P
s
P
p
.002 w
.49764 .33006 m .50486 .31542 L .47963 .30401 L p
1 g
F P
s
P
p
.002 w
.36455 .38273 m .37933 .43054 L .40042 .41534 L p
1 g
F P
s
P
p
.002 w
.40042 .41534 m .38737 .37193 L .36455 .38273 L p
1 g
F P
s
P
p
.002 w
.36079 .44608 m .39211 .49191 L .40839 .47347 L p
1 g
F P
s
P
p
.002 w
.40839 .47347 m .37933 .43054 L .36079 .44608 L p
1 g
F P
s
P
p
.002 w
.58086 .35314 m .57835 .3611 L .6014 .37802 L p
1 g
F P
s
P
p
.002 w
.51721 .30437 m .50486 .31542 L .52965 .32952 L p
1 g
F P
s
P
p
.002 w
.52965 .32952 m .53595 .32402 L .51721 .30437 L p
1 g
F P
s
P
p
.002 w
.6222 .39646 m .60651 .41464 L .61964 .43941 L p
1 g
F P
s
P
p
.002 w
.60651 .41464 m .6222 .39646 L .6014 .37802 L p
1 g
F P
s
P
p
.002 w
.62998 .46435 m .59583 .48157 L .5979 .50829 L p
1 g
F P
s
P
p
.002 w
.59583 .48157 m .62998 .46435 L .61964 .43941 L p
1 g
F P
s
P
p
.002 w
.45447 .29559 m .44136 .32386 L .46927 .32568 L p
1 g
F P
s
P
p
.002 w
.46927 .32568 m .47963 .30401 L .45447 .29559 L p
1 g
F P
s
P
p
.002 w
.38921 .32823 m .38737 .37193 L .4125 .3628 L p
1 g
F P
s
P
p
.002 w
.4125 .3628 m .41448 .32469 L .38921 .32823 L p
1 g
F P
s
P
p
.002 w
.6014 .37802 m .60655 .36231 L .58086 .35314 L p
1 g
F P
s
P
p
.002 w
.58032 .34446 m .58086 .35314 L .60655 .36231 L p
1 g
F P
s
P
p
.002 w
.53343 .29821 m .51721 .30437 L .53595 .32402 L p
1 g
F P
s
P
p
.002 w
.53595 .32402 m .54413 .32099 L .53343 .29821 L p
1 g
F P
s
P
p
.002 w
.60655 .36231 m .6014 .37802 L .6222 .39646 L p
1 g
F P
s
P
p
.002 w
.49767 .28751 m .47963 .30401 L .50486 .31542 L p
1 g
F P
s
P
p
.002 w
.50486 .31542 m .51721 .30437 L .49767 .28751 L p
1 g
F P
s
P
p
.002 w
.37813 .50929 m .42327 .54748 L .43535 .5286 L p
1 g
F P
s
P
p
.002 w
.43535 .5286 m .39211 .49191 L .37813 .50929 L p
1 g
F P
s
P
p
.002 w
.48656 .55302 m .43535 .5286 L .42327 .54748 L p
1 g
F P
s
P
p
.002 w
.60655 .36231 m .60565 .34505 L .58032 .34446 L p
1 g
F P
s
P
p
.002 w
.57678 .33602 m .58032 .34446 L .60565 .34505 L p
1 g
F P
s
P
p
.002 w
.55176 .29773 m .53343 .29821 L .54413 .32099 L p
1 g
F P
s
P
p
.002 w
.54413 .32099 m .55332 .3208 L .55176 .29773 L p
1 g
F P
s
P
p
.002 w
.48656 .55302 m .54131 .56291 L .54771 .53954 L p
1 g
F P
s
P
p
.002 w
.59754 .53361 m .54771 .53954 L .54131 .56291 L p
1 g
F P
s
P
p
.002 w
.54771 .53954 m .59754 .53361 L .5979 .50829 L p
1 g
F P
s
P
p
.002 w
.64028 .41606 m .61964 .43941 L .62998 .46435 L p
1 g
F P
s
P
p
.002 w
.61964 .43941 m .64028 .41606 L .6222 .39646 L p
1 g
F P
s
P
p
.002 w
.34462 .39503 m .36079 .44608 L .37933 .43054 L p
1 g
F P
s
P
p
.002 w
.37933 .43054 m .36455 .38273 L .34462 .39503 L p
1 g
F P
s
P
p
.002 w
.42992 .29043 m .41448 .32469 L .44136 .32386 L p
1 g
F P
s
P
p
.002 w
.44136 .32386 m .45447 .29559 L .42992 .29043 L p
1 g
F P
s
P
p
.002 w
.60565 .34505 m .59868 .32817 L .57678 .33602 L p
1 g
F P
s
P
p
.002 w
.57061 .32876 m .57678 .33602 L .59868 .32817 L p
1 g
F P
s
P
p
.002 w
.57011 .30305 m .55176 .29773 L .55332 .3208 L p
1 g
F P
s
P
p
.002 w
.55332 .3208 m .56249 .32349 L .57011 .30305 L p
1 g
F P
s
P
p
.002 w
.42327 .54748 m .47665 .57303 L .48656 .55302 L p
1 g
F P
s
P
p
.002 w
.54131 .56291 m .48656 .55302 L .47665 .57303 L p
1 g
F P
s
P
p
.002 w
.59868 .32817 m .58638 .3136 L .57061 .32876 L p
1 g
F P
s
P
p
.002 w
.56249 .32349 m .57061 .32876 L .58638 .3136 L p
1 g
F P
s
P
p
.002 w
.58638 .3136 m .57011 .30305 L .56249 .32349 L p
1 g
F P
s
P
p
.002 w
.34529 .46166 m .37813 .50929 L .39211 .49191 L p
1 g
F P
s
P
p
.002 w
.39211 .49191 m .36079 .44608 L .34529 .46166 L p
1 g
F P
s
P
p
.002 w
.63724 .48894 m .5979 .50829 L .59754 .53361 L p
1 g
F P
s
P
p
.002 w
.5979 .50829 m .63724 .48894 L .62998 .46435 L p
1 g
F P
s
P
p
.002 w
.6222 .39646 m .63005 .37337 L .60655 .36231 L p
1 g
F P
s
P
p
.002 w
.60565 .34505 m .60655 .36231 L .63005 .37337 L p
1 g
F P
s
P
p
.002 w
.63005 .37337 m .6222 .39646 L .64028 .41606 L p
1 g
F P
s
P
p
.002 w
.36615 .33448 m .36455 .38273 L .38737 .37193 L p
1 g
F P
s
P
p
.002 w
.38737 .37193 m .38921 .32823 L .36615 .33448 L p
1 g
F P
s
P
p
.002 w
.52161 .27821 m .49767 .28751 L .51721 .30437 L p
1 g
F P
s
P
p
.002 w
.51721 .30437 m .53343 .29821 L .52161 .27821 L p
1 g
F P
s
P
p
.002 w
.47772 .27391 m .45447 .29559 L .47963 .30401 L p
1 g
F P
s
P
p
.002 w
.47963 .30401 m .49767 .28751 L .47772 .27391 L p
1 g
F P
s
P
p
.002 w
.65517 .43647 m .62998 .46435 L .63724 .48894 L p
1 g
F P
s
P
p
.002 w
.62998 .46435 m .65517 .43647 L .64028 .41606 L p
1 g
F P
s
P
p
.002 w
.63005 .37337 m .62892 .34782 L .60565 .34505 L p
1 g
F P
s
P
p
.002 w
.59868 .32817 m .60565 .34505 L .62892 .34782 L p
1 g
F P
s
P
p
.002 w
.40653 .28876 m .38921 .32823 L .41448 .32469 L p
1 g
F P
s
P
p
.002 w
.41448 .32469 m .42992 .29043 L .40653 .28876 L p
1 g
F P
s
P
p
.002 w
.54882 .27736 m .52161 .27821 L .53343 .29821 L p
1 g
F P
s
P
p
.002 w
.53343 .29821 m .55176 .29773 L .54882 .27736 L p
1 g
F P
s
P
p
.002 w
.47665 .57303 m .53368 .58356 L .54131 .56291 L p
1 g
F P
s
P
p
.002 w
.59468 .55693 m .54131 .56291 L .53368 .58356 L p
1 g
F P
s
P
p
.002 w
.54131 .56291 m .59468 .55693 L .59754 .53361 L p
1 g
F P
s
P
p
.002 w
.36684 .5252 m .41279 .56397 L .42327 .54748 L p
1 g
F P
s
P
p
.002 w
.42327 .54748 m .37813 .50929 L .36684 .5252 L p
1 g
F P
s
P
p
.002 w
.47665 .57303 m .42327 .54748 L .41279 .56397 L p
1 g
F P
s
P
p
.002 w
.32814 .40862 m .34529 .46166 L .36079 .44608 L p
1 g
F P
s
P
p
.002 w
.36079 .44608 m .34462 .39503 L .32814 .40862 L p
1 g
F P
s
P
p
.002 w
.65078 .38615 m .64028 .41606 L .65517 .43647 L p
1 g
F P
s
P
p
.002 w
.64028 .41606 m .65078 .38615 L .63005 .37337 L p
1 g
F P
s
P
p
.002 w
.64114 .51264 m .59754 .53361 L .59468 .55693 L p
1 g
F P
s
P
p
.002 w
.59754 .53361 m .64114 .51264 L .63724 .48894 L p
1 g
F P
s
P
p
.002 w
.62892 .34782 m .63005 .37337 L .65078 .38615 L p
1 g
F P
s
P
p
.002 w
.62892 .34782 m .61871 .3227 L .59868 .32817 L p
1 g
F P
s
P
p
.002 w
.58638 .3136 m .59868 .32817 L .61871 .3227 L p
1 g
F P
s
P
p
.002 w
.45778 .26398 m .42992 .29043 L .45447 .29559 L p
1 g
F P
s
P
p
.002 w
.45447 .29559 m .47772 .27391 L .45778 .26398 L p
1 g
F P
s
P
p
.002 w
.57618 .28523 m .54882 .27736 L .55176 .29773 L p
1 g
F P
s
P
p
.002 w
.55176 .29773 m .57011 .30305 L .57618 .28523 L p
1 g
F P
s
P
p
.002 w
.50887 .26155 m .47772 .27391 L .49767 .28751 L p
1 g
F P
s
P
p
.002 w
.49767 .28751 m .52161 .27821 L .50887 .26155 L p
1 g
F P
s
P
p
.002 w
.34592 .34344 m .34462 .39503 L .36455 .38273 L p
1 g
F P
s
P
p
.002 w
.36455 .38273 m .36615 .33448 L .34592 .34344 L p
1 g
F P
s
P
p
.002 w
.41279 .56397 m .46703 .59 L .47665 .57303 L p
1 g
F P
s
P
p
.002 w
.53368 .58356 m .47665 .57303 L .46703 .59 L p
1 g
F P
s
P
p
.002 w
.33331 .47694 m .36684 .5252 L .37813 .50929 L p
1 g
F P
s
P
p
.002 w
.37813 .50929 m .34529 .46166 L .33331 .47694 L p
1 g
F P
s
P
p
.002 w
.61871 .3227 m .60044 .30097 L .58638 .3136 L p
1 g
F P
s
P
p
.002 w
.57011 .30305 m .58638 .3136 L .60044 .30097 L p
1 g
F P
s
P
p
.002 w
.60044 .30097 m .57618 .28523 L .57011 .30305 L p
1 g
F P
s
P
p
.002 w
.66643 .45724 m .63724 .48894 L .64114 .51264 L p
1 g
F P
s
P
p
.002 w
.63724 .48894 m .66643 .45724 L .65517 .43647 L p
1 g
F P
s
P
p
.002 w
.3849 .29078 m .36615 .33448 L .38921 .32823 L p
1 g
F P
s
P
p
.002 w
.38921 .32823 m .40653 .28876 L .3849 .29078 L p
1 g
F P
s
P
p
.002 w
.65078 .38615 m .64955 .35282 L .62892 .34782 L p
1 g
F P
s
P
p
.002 w
.61871 .3227 m .62892 .34782 L .64955 .35282 L p
1 g
F P
s
P
p
.002 w
.54451 .26029 m .50887 .26155 L .52161 .27821 L p
1 g
F P
s
P
p
.002 w
.52161 .27821 m .54882 .27736 L .54451 .26029 L p
1 g
F P
s
P
p
.002 w
.66818 .40045 m .65517 .43647 L .66643 .45724 L p
1 g
F P
s
P
p
.002 w
.65517 .43647 m .66818 .40045 L .65078 .38615 L p
1 g
F P
s
P
p
.002 w
.43831 .25814 m .40653 .28876 L .42992 .29043 L p
1 g
F P
s
P
p
.002 w
.42992 .29043 m .45778 .26398 L .43831 .25814 L p
1 g
F P
s
P
p
.002 w
.46703 .59 m .52492 .6009 L .53368 .58356 L p
1 g
F P
s
P
p
.002 w
.58928 .57766 m .53368 .58356 L .52492 .6009 L p
1 g
F P
s
P
p
.002 w
.53368 .58356 m .58928 .57766 L .59468 .55693 L p
1 g
F P
s
P
p
.002 w
.64955 .35282 m .65078 .38615 L .66818 .40045 L p
1 g
F P
s
P
p
.002 w
.31565 .42325 m .33331 .47694 L .34529 .46166 L p
1 g
F P
s
P
p
.002 w
.34529 .46166 m .32814 .40862 L .31565 .42325 L p
1 g
F P
s
P
p
.002 w
.64148 .53487 m .59468 .55693 L .58928 .57766 L p
1 g
F P
s
P
p
.002 w
.59468 .55693 m .64148 .53487 L .64114 .51264 L p
1 g
F P
s
P
p
.002 w
.49546 .24877 m .45778 .26398 L .47772 .27391 L p
1 g
F P
s
P
p
.002 w
.47772 .27391 m .50887 .26155 L .49546 .24877 L p
1 g
F P
s
P
p
.002 w
.32913 .35499 m .32814 .40862 L .34462 .39503 L p
1 g
F P
s
P
p
.002 w
.34462 .39503 m .34592 .34344 L .32913 .35499 L p
1 g
F P
s
P
p
.002 w
.35863 .5392 m .4042 .57757 L .41279 .56397 L p
1 g
F P
s
P
p
.002 w
.41279 .56397 m .36684 .5252 L .35863 .5392 L p
1 g
F P
s
P
p
.002 w
.46703 .59 m .41279 .56397 L .4042 .57757 L p
1 g
F P
s
P
p
.002 w
.64955 .35282 m .63632 .31986 L .61871 .3227 L p
1 g
F P
s
P
p
.002 w
.60044 .30097 m .61871 .3227 L .63632 .31986 L p
1 g
F P
s
P
p
.002 w
.58048 .27056 m .54451 .26029 L .54882 .27736 L p
1 g
F P
s
P
p
.002 w
.54882 .27736 m .57618 .28523 L .58048 .27056 L p
1 g
F P
s
P
p
.002 w
.4042 .57757 m .45792 .60341 L .46703 .59 L p
1 g
F P
s
P
p
.002 w
.52492 .6009 m .46703 .59 L .45792 .60341 L p
1 g
F P
s
P
p
.002 w
.67366 .47794 m .64114 .51264 L .64148 .53487 L p
1 g
F P
s
P
p
.002 w
.64114 .51264 m .67366 .47794 L .66643 .45724 L p
1 g
F P
s
P
p
.002 w
.32531 .49154 m .35863 .5392 L .36684 .5252 L p
1 g
F P
s
P
p
.002 w
.36684 .5252 m .33331 .47694 L .32531 .49154 L p
1 g
F P
s
P
p
.002 w
.63632 .31986 m .61238 .29126 L .60044 .30097 L p
1 g
F P
s
P
p
.002 w
.57618 .28523 m .60044 .30097 L .61238 .29126 L p
1 g
F P
s
P
p
.002 w
.61238 .29126 m .58048 .27056 L .57618 .28523 L p
1 g
F P
s
P
p
.002 w
.36563 .29659 m .34592 .34344 L .36615 .33448 L p
1 g
F P
s
P
p
.002 w
.36615 .33448 m .3849 .29078 L .36563 .29659 L p
1 g
F P
s
P
p
.002 w
.66818 .40045 m .66694 .36003 L .64955 .35282 L p
1 g
F P
s
P
p
.002 w
.63632 .31986 m .64955 .35282 L .66694 .36003 L p
1 g
F P
s
P
p
.002 w
.6817 .41598 m .66643 .45724 L .67366 .47794 L p
1 g
F P
s
P
p
.002 w
.66643 .45724 m .6817 .41598 L .66818 .40045 L p
1 g
F P
s
P
p
.002 w
.53885 .2471 m .49546 .24877 L .50887 .26155 L p
1 g
F P
s
P
p
.002 w
.50887 .26155 m .54451 .26029 L .53885 .2471 L p
1 g
F P
s
P
p
.002 w
.41983 .25671 m .3849 .29078 L .40653 .28876 L p
1 g
F P
s
P
p
.002 w
.40653 .28876 m .43831 .25814 L .41983 .25671 L p
1 g
F P
s
P
p
.002 w
.66694 .36003 m .66818 .40045 L .6817 .41598 L p
1 g
F P
s
P
p
.002 w
.48168 .2404 m .43831 .25814 L .45778 .26398 L p
1 g
F P
s
P
p
.002 w
.45778 .26398 m .49546 .24877 L .48168 .2404 L p
1 g
F P
s
P
p
.002 w
.52492 .6009 m .58134 .59519 L .58928 .57766 L p
1 g
F P
s
P
p
.002 w
.63807 .55506 m .58928 .57766 L .58134 .59519 L p
1 g
F P
s
P
p
.002 w
.58928 .57766 m .63807 .55506 L .64148 .53487 L p
1 g
F P
s
P
p
.002 w
.45792 .60341 m .51519 .61435 L .52492 .6009 L p
1 g
F P
s
P
p
.002 w
.58134 .59519 m .52492 .6009 L .51519 .61435 L p
1 g
F P
s
P
p
.002 w
.30768 .4386 m .32531 .49154 L .33331 .47694 L p
1 g
F P
s
P
p
.002 w
.33331 .47694 m .31565 .42325 L .30768 .4386 L p
1 g
F P
s
P
p
.002 w
.31638 .36899 m .31565 .42325 L .32814 .40862 L p
1 g
F P
s
P
p
.002 w
.32814 .40862 m .32913 .35499 L .31638 .36899 L p
1 g
F P
s
P
p
.002 w
.35387 .55085 m .39782 .58779 L .4042 .57757 L p
1 g
F P
s
P
p
.002 w
.4042 .57757 m .35863 .5392 L .35387 .55085 L p
1 g
F P
s
P
p
.002 w
.45792 .60341 m .4042 .57757 L .39782 .58779 L p
1 g
F P
s
P
p
.002 w
.66694 .36003 m .65098 .31986 L .63632 .31986 L p
1 g
F P
s
P
p
.002 w
.61238 .29126 m .63632 .31986 L .65098 .31986 L p
1 g
F P
s
P
p
.002 w
.67649 .49804 m .64148 .53487 L .63807 .55506 L p
1 g
F P
s
P
p
.002 w
.64148 .53487 m .67649 .49804 L .67366 .47794 L p
1 g
F P
s
P
p
.002 w
.58279 .25958 m .53885 .2471 L .54451 .26029 L p
1 g
F P
s
P
p
.002 w
.54451 .26029 m .58048 .27056 L .58279 .25958 L p
1 g
F P
s
P
p
.002 w
.34935 .30625 m .32913 .35499 L .34592 .34344 L p
1 g
F P
s
P
p
.002 w
.34592 .34344 m .36563 .29659 L .34935 .30625 L p
1 g
F P
s
P
p
.002 w
.39782 .58779 m .44958 .61273 L .45792 .60341 L p
1 g
F P
s
P
p
.002 w
.51519 .61435 m .45792 .60341 L .44958 .61273 L p
1 g
F P
s
P
p
.002 w
.32172 .50506 m .35387 .55085 L .35863 .5392 L p
1 g
F P
s
P
p
.002 w
.35863 .5392 m .32531 .49154 L .32172 .50506 L p
1 g
F P
s
P
p
.002 w
.65098 .31986 m .62179 .28489 L .61238 .29126 L p
1 g
F P
s
P
p
.002 w
.58048 .27056 m .61238 .29126 L .62179 .28489 L p
1 g
F P
s
P
p
.002 w
.62179 .28489 m .58279 .25958 L .58048 .27056 L p
1 g
F P
s
P
p
.002 w
.69082 .43245 m .67366 .47794 L .67649 .49804 L p
1 g
F P
s
P
p
.002 w
.67366 .47794 m .69082 .43245 L .6817 .41598 L p
1 g
F P
s
P
p
.002 w
.40285 .26 m .36563 .29659 L .3849 .29078 L p
1 g
F P
s
P
p
.002 w
.3849 .29078 m .41983 .25671 L .40285 .26 L p
1 g
F P
s
P
p
.002 w
.6817 .41598 m .6805 .36939 L .66694 .36003 L p
1 g
F P
s
P
p
.002 w
.65098 .31986 m .66694 .36003 L .6805 .36939 L p
1 g
F P
s
P
p
.002 w
.53191 .23835 m .48168 .2404 L .49546 .24877 L p
1 g
F P
s
P
p
.002 w
.49546 .24877 m .53885 .2471 L .53191 .23835 L p
1 g
F P
s
P
p
.002 w
.6805 .36939 m .6817 .41598 L .69082 .43245 L p
1 g
F P
s
P
p
.002 w
.46785 .2369 m .41983 .25671 L .43831 .25814 L p
1 g
F P
s
P
p
.002 w
.43831 .25814 m .48168 .2404 L .46785 .2369 L p
1 g
F P
s
P
p
.002 w
.51519 .61435 m .57092 .60893 L .58134 .59519 L p
1 g
F P
s
P
p
.002 w
.63082 .57258 m .58134 .59519 L .57092 .60893 L p
1 g
F P
s
P
p
.002 w
.58134 .59519 m .63082 .57258 L .63807 .55506 L p
1 g
F P
s
P
p
.002 w
.44958 .61273 m .50467 .62337 L .51519 .61435 L p
1 g
F P
s
P
p
.002 w
.57092 .60893 m .51519 .61435 L .50467 .62337 L p
1 g
F P
s
P
p
.002 w
.30823 .3852 m .30768 .4386 L .31565 .42325 L p
1 g
F P
s
P
p
.002 w
.31565 .42325 m .31638 .36899 L .30823 .3852 L p
1 g
F P
s
P
p
.002 w
.30468 .45431 m .32172 .50506 L .32531 .49154 L p
1 g
F P
s
P
p
.002 w
.32531 .49154 m .30768 .4386 L .30468 .45431 L p
1 g
F P
s
P
p
.002 w
.67462 .51701 m .63807 .55506 L .63082 .57258 L p
1 g
F P
s
P
p
.002 w
.63807 .55506 m .67462 .51701 L .67649 .49804 L p
1 g
F P
s
P
p
.002 w
.33665 .31972 m .31638 .36899 L .32913 .35499 L p
1 g
F P
s
P
p
.002 w
.32913 .35499 m .34935 .30625 L .33665 .31972 L p
1 g
F P
s
P
p
.002 w
.6805 .36939 m .66213 .32286 L .65098 .31986 L p
1 g
F P
s
P
p
.002 w
.62179 .28489 m .65098 .31986 L .66213 .32286 L p
1 g
F P
s
P
p
.002 w
.58294 .25281 m .53191 .23835 L .53885 .2471 L p
1 g
F P
s
P
p
.002 w
.53885 .2471 m .58279 .25958 L .58294 .25281 L p
1 g
F P
s
P
p
.002 w
.35291 .55971 m .39395 .59417 L .39782 .58779 L p
1 g
F P
s
P
p
.002 w
.39782 .58779 m .35387 .55085 L .35291 .55971 L p
1 g
F P
s
P
p
.002 w
.44958 .61273 m .39782 .58779 L .39395 .59417 L p
1 g
F P
s
P
p
.002 w
.69505 .44946 m .67649 .49804 L .67462 .51701 L p
1 g
F P
s
P
p
.002 w
.67649 .49804 m .69505 .44946 L .69082 .43245 L p
1 g
F P
s
P
p
.002 w
.39395 .59417 m .44226 .61748 L .44958 .61273 L p
1 g
F P
s
P
p
.002 w
.50467 .62337 m .44958 .61273 L .44226 .61748 L p
1 g
F P
s
P
p
.002 w
.3229 .51707 m .35291 .55971 L .35387 .55085 L p
1 g
F P
s
P
p
.002 w
.35387 .55085 m .32172 .50506 L .3229 .51707 L p
1 g
F P
s
P
p
.002 w
.38794 .26816 m .34935 .30625 L .36563 .29659 L p
1 g
F P
s
P
p
.002 w
.36563 .29659 m .40285 .26 L .38794 .26816 L p
1 g
F P
s
P
p
.002 w
.66213 .32286 m .62828 .28223 L .62179 .28489 L p
1 g
F P
s
P
p
.002 w
.58279 .25958 m .62179 .28489 L .62828 .28223 L p
1 g
F P
s
P
p
.002 w
.62828 .28223 m .58294 .25281 L .58279 .25958 L p
1 g
F P
s
P
p
.002 w
.69082 .43245 m .68964 .38079 L .6805 .36939 L p
1 g
F P
s
P
p
.002 w
.66213 .32286 m .6805 .36939 L .68964 .38079 L p
1 g
F P
s
P
p
.002 w
.68964 .38079 m .69082 .43245 L .69505 .44946 L p
1 g
F P
s
P
p
.002 w
.52378 .23456 m .46785 .2369 L .48168 .2404 L p
1 g
F P
s
P
p
.002 w
.48168 .2404 m .53191 .23835 L .52378 .23456 L p
1 g
F P
s
P
p
.002 w
.45437 .23867 m .40285 .26 L .41983 .25671 L p
1 g
F P
s
P
p
.002 w
.41983 .25671 m .46785 .2369 L .45437 .23867 L p
1 g
F P
s
P
p
.002 w
.50467 .62337 m .55816 .6183 L .57092 .60893 L p
1 g
F P
s
P
p
.002 w
.6197 .58683 m .57092 .60893 L .55816 .6183 L p
1 g
F P
s
P
p
.002 w
.57092 .60893 m .6197 .58683 L .63082 .57258 L p
1 g
F P
s
P
p
.002 w
.30515 .40327 m .30468 .45431 L .30768 .4386 L p
1 g
F P
s
P
p
.002 w
.30768 .4386 m .30823 .3852 L .30515 .40327 L p
1 g
F P
s
P
p
.002 w
.44226 .61748 m .49359 .62745 L .50467 .62337 L p
1 g
F P
s
P
p
.002 w
.55816 .6183 m .50467 .62337 L .49359 .62745 L p
1 g
F P
s
P
p
.002 w
.66785 .53427 m .63082 .57258 L .6197 .58683 L p
1 g
F P
s
P
p
.002 w
.63082 .57258 m .66785 .53427 L .67462 .51701 L p
1 g
F P
s
P
p
.002 w
.30704 .46997 m .3229 .51707 L .32172 .50506 L p
1 g
F P
s
P
p
.002 w
.32172 .50506 m .30468 .45431 L .30704 .46997 L p
1 g
F P
s
P
p
.002 w
.3281 .3368 m .30823 .3852 L .31638 .36899 L p
1 g
F P
s
P
p
.002 w
.31638 .36899 m .33665 .31972 L .3281 .3368 L p
1 g
F P
s
P
p
.002 w
.68964 .38079 m .66926 .32897 L .66213 .32286 L p
1 g
F P
s
P
p
.002 w
.62828 .28223 m .66213 .32286 L .66926 .32897 L p
1 g
F P
s
P
p
.002 w
.58078 .2507 m .52378 .23456 L .53191 .23835 L p
1 g
F P
s
P
p
.002 w
.53191 .23835 m .58294 .25281 L .58078 .2507 L p
1 g
F P
s
P
p
.002 w
.67462 .51701 m .69402 .46658 L .69505 .44946 L p
1 g
F P
s
P
p
.002 w
.69402 .46658 m .67462 .51701 L .66785 .53427 L p
1 g
F P
s
P
p
.002 w
.356 .56534 m .39285 .59628 L .39395 .59417 L p
1 g
F P
s
P
p
.002 w
.39395 .59417 m .35291 .55971 L .356 .56534 L p
1 g
F P
s
P
p
.002 w
.44226 .61748 m .39395 .59417 L .39285 .59628 L p
1 g
F P
s
P
p
.002 w
.37565 .28124 m .33665 .31972 L .34935 .30625 L p
1 g
F P
s
P
p
.002 w
.34935 .30625 m .38794 .26816 L .37565 .28124 L p
1 g
F P
s
P
p
.002 w
.39285 .59628 m .43624 .61721 L .44226 .61748 L p
1 g
F P
s
P
p
.002 w
.49359 .62745 m .44226 .61748 L .43624 .61721 L p
1 g
F P
s
P
p
.002 w
.32911 .52715 m .356 .56534 L .35291 .55971 L p
1 g
F P
s
P
p
.002 w
.35291 .55971 m .3229 .51707 L .32911 .52715 L p
1 g
F P
s
P
p
.002 w
.69505 .44946 m .69387 .39403 L .68964 .38079 L p
1 g
F P
s
P
p
.002 w
.69387 .39403 m .69505 .44946 L .69402 .46658 L p
1 g
F P
s
P
p
.002 w
.66926 .32897 m .68964 .38079 L .69387 .39403 L p
1 g
F P
s
P
p
.002 w
.66926 .32897 m .63146 .2836 L .62828 .28223 L p
1 g
F P
s
P
p
.002 w
.58294 .25281 m .62828 .28223 L .63146 .2836 L p
1 g
F P
s
P
p
.002 w
.63146 .2836 m .58078 .2507 L .58294 .25281 L p
1 g
F P
s
P
p
.002 w
.44164 .24597 m .38794 .26816 L .40285 .26 L p
1 g
F P
s
P
p
.002 w
.40285 .26 m .45437 .23867 L .44164 .24597 L p
1 g
F P
s
P
p
.002 w
.51463 .23616 m .45437 .23867 L .46785 .2369 L p
1 g
F P
s
P
p
.002 w
.46785 .2369 m .52378 .23456 L .51463 .23616 L p
1 g
F P
s
P
p
.002 w
.49359 .62745 m .54327 .62278 L .55816 .6183 L p
1 g
F P
s
P
p
.002 w
.55816 .6183 m .60482 .59723 L .6197 .58683 L p
1 g
F P
s
P
p
.002 w
.60482 .59723 m .55816 .6183 L .54327 .62278 L p
1 g
F P
s
P
p
.002 w
.30752 .42278 m .30704 .46997 L .30468 .45431 L p
1 g
F P
s
P
p
.002 w
.30468 .45431 m .30515 .40327 L .30752 .42278 L p
1 g
F P
s
P
p
.002 w
.6197 .58683 m .6561 .54924 L .66785 .53427 L p
1 g
F P
s
P
p
.002 w
.6561 .54924 m .6197 .58683 L .60482 .59723 L p
1 g
F P
s
P
p
.002 w
.43624 .61721 m .48223 .62616 L .49359 .62745 L p
1 g
F P
s
P
p
.004 w
.47243 .62503 m
.47254 .62427 L
s
P
p
.004 w
.45824 .72514 m
.47243 .62503 L
s
P
p
.002 w
.54327 .62278 m .49359 .62745 L .48223 .62616 L p
1 g
F P
s
P
p
.004 w
.47263 .62361 m
.5 .43051 L
s
P
p
.002 w
.32418 .35718 m .30515 .40327 L .30823 .3852 L p
1 g
F P
s
P
p
.002 w
.30823 .3852 m .3281 .3368 L .32418 .35718 L p
1 g
F P
s
P
p
.002 w
.31499 .48511 m .32911 .52715 L .3229 .51707 L p
1 g
F P
s
P
p
.002 w
.3229 .51707 m .30704 .46997 L .31499 .48511 L p
1 g
F P
s
P
p
.002 w
.68744 .48334 m .66785 .53427 L .6561 .54924 L p
1 g
F P
s
P
p
.002 w
.66785 .53427 m .68744 .48334 L .69402 .46658 L p
1 g
F P
s
P
p
.002 w
.3665 .29912 m .3281 .3368 L .33665 .31972 L p
1 g
F P
s
P
p
.002 w
.33665 .31972 m .37565 .28124 L .3665 .29912 L p
1 g
F P
s
P
p
.002 w
.69387 .39403 m .6719 .33822 L .66926 .32897 L p
1 g
F P
s
P
p
.002 w
.63146 .2836 m .66926 .32897 L .6719 .33822 L p
1 g
F P
s
P
p
.002 w
.57622 .25363 m .51463 .23616 L .52378 .23456 L p
1 g
F P
s
P
p
.002 w
.52378 .23456 m .58078 .2507 L .57622 .25363 L p
1 g
F P
s
P
p
.002 w
.36333 .56738 m .39475 .59377 L .39285 .59628 L p
1 g
F P
s
P
p
.002 w
.39285 .59628 m .356 .56534 L .36333 .56738 L p
1 g
F P
s
P
p
.002 w
.43624 .61721 m .39285 .59628 L .39475 .59377 L p
1 g
F P
s
P
p
.002 w
.69276 .40884 m .69402 .46658 L .68744 .48334 L p
1 g
F P
s
P
p
.002 w
.69402 .46658 m .69276 .40884 L .69387 .39403 L p
1 g
F P
s
P
p
.002 w
.39475 .59377 m .43176 .61162 L .43624 .61721 L p
1 g
F P
s
P
p
.002 w
.48223 .62616 m .43624 .61721 L .43176 .61162 L p
1 g
F P
s
P
p
.002 w
.6719 .33822 m .69387 .39403 L .69276 .40884 L p
1 g
F P
s
P
p
.002 w
.43011 .25891 m .37565 .28124 L .38794 .26816 L p
1 g
F P
s
P
p
.002 w
.38794 .26816 m .44164 .24597 L .43011 .25891 L p
1 g
F P
s
P
p
.002 w
.34049 .53487 m .36333 .56738 L .356 .56534 L p
1 g
F P
s
P
p
.002 w
.356 .56534 m .32911 .52715 L .34049 .53487 L p
1 g
F P
s
P
p
.002 w
.50467 .24346 m .44164 .24597 L .45437 .23867 L p
1 g
F P
s
P
p
.002 w
.45437 .23867 m .51463 .23616 L .50467 .24346 L p
1 g
F P
s
P
p
.002 w
.6719 .33822 m .63104 .28921 L .63146 .2836 L p
1 g
F P
s
P
p
.002 w
.58078 .2507 m .63146 .2836 L .63104 .28921 L p
1 g
F P
s
P
p
.002 w
.63104 .28921 m .57622 .25363 L .58078 .2507 L p
1 g
F P
s
P
p
.002 w
.48223 .62616 m .52657 .62196 L .54327 .62278 L p
1 g
F P
s
P
p
.002 w
.58641 .60326 m .54327 .62278 L .52657 .62196 L p
1 g
F P
s
P
p
.002 w
.54327 .62278 m .58641 .60326 L .60482 .59723 L p
1 g
F P
s
P
p
.002 w
.31557 .44321 m .31499 .48511 L .30704 .46997 L p
1 g
F P
s
P
p
.002 w
.30704 .46997 m .30752 .42278 L .31557 .44321 L p
1 g
F P
s
P
p
.002 w
.63946 .56135 m .60482 .59723 L .58641 .60326 L p
1 g
F P
s
P
p
.002 w
.60482 .59723 m .63946 .56135 L .6561 .54924 L p
1 g
F P
s
P
p
.002 w
.32525 .38039 m .30752 .42278 L .30515 .40327 L p
1 g
F P
s
P
p
.002 w
.30515 .40327 m .32418 .35718 L .32525 .38039 L p
1 g
F P
s
P
p
.002 w
.43176 .61162 m .4709 .6192 L .48223 .62616 L p
1 g
F P
s
P
p
.002 w
.52657 .62196 m .48223 .62616 L .4709 .6192 L p
1 g
F P
s
P
p
.002 w
.32862 .49923 m .34049 .53487 L .32911 .52715 L p
1 g
F P
s
P
p
.002 w
.32911 .52715 m .31499 .48511 L .32862 .49923 L p
1 g
F P
s
P
p
.002 w
.67522 .49918 m .6561 .54924 L .63946 .56135 L p
1 g
F P
s
P
p
.002 w
.6561 .54924 m .67522 .49918 L .68744 .48334 L p
1 g
F P
s
P
p
.002 w
.36096 .32147 m .32418 .35718 L .3281 .3368 L p
1 g
F P
s
P
p
.002 w
.3281 .3368 m .3665 .29912 L .36096 .32147 L p
1 g
F P
s
P
p
.002 w
.69276 .40884 m .66969 .35053 L .6719 .33822 L p
1 g
F P
s
P
p
.002 w
.63104 .28921 m .6719 .33822 L .66969 .35053 L p
1 g
F P
s
P
p
.002 w
.56923 .26185 m .50467 .24346 L .51463 .23616 L p
1 g
F P
s
P
p
.002 w
.51463 .23616 m .57622 .25363 L .56923 .26185 L p
1 g
F P
s
P
p
.002 w
.68601 .42486 m .68744 .48334 L .67522 .49918 L p
1 g
F P
s
P
p
.002 w
.68744 .48334 m .68601 .42486 L .69276 .40884 L p
1 g
F P
s
P
p
.002 w
.42021 .2774 m .3665 .29912 L .37565 .28124 L p
1 g
F P
s
P
p
.002 w
.37565 .28124 m .43011 .25891 L .42021 .2774 L p
1 g
F P
s
P
p
.002 w
.37495 .56553 m .39979 .58642 L .39475 .59377 L p
1 g
F P
s
P
p
.002 w
.39475 .59377 m .36333 .56738 L .37495 .56553 L p
1 g
F P
s
P
p
.002 w
.43176 .61162 m .39475 .59377 L .39979 .58642 L p
1 g
F P
s
P
p
.002 w
.66969 .35053 m .69276 .40884 L .68601 .42486 L p
1 g
F P
s
P
p
.002 w
.49417 .25656 m .43011 .25891 L .44164 .24597 L p
1 g
F P
s
P
p
.002 w
.44164 .24597 m .50467 .24346 L .49417 .25656 L p
1 g
F P
s
P
p
.002 w
.39979 .58642 m .42908 .60053 L .43176 .61162 L p
1 g
F P
s
P
p
.002 w
.4709 .6192 m .43176 .61162 L .42908 .60053 L p
1 g
F P
s
P
p
.002 w
.35698 .53984 m .37495 .56553 L .36333 .56738 L p
1 g
F P
s
P
p
.002 w
.36333 .56738 m .34049 .53487 L .35698 .53984 L p
1 g
F P
s
P
p
.002 w
.56484 .6045 m .52657 .62196 L .50846 .61555 L p
1 g
F P
s
P
p
.002 w
.4709 .6192 m .50846 .61555 L .52657 .62196 L p
1 g
F P
s
P
p
.002 w
.52657 .62196 m .56484 .6045 L .58641 .60326 L p
1 g
F P
s
P
p
.002 w
.61819 .57005 m .58641 .60326 L .56484 .6045 L p
1 g
F P
s
P
p
.002 w
.58641 .60326 m .61819 .57005 L .63946 .56135 L p
1 g
F P
s
P
p
.002 w
.32931 .46392 m .32862 .49923 L .31499 .48511 L p
1 g
F P
s
P
p
.002 w
.31499 .48511 m .31557 .44321 L .32931 .46392 L p
1 g
F P
s
P
p
.002 w
.66969 .35053 m .62678 .2992 L .63104 .28921 L p
1 g
F P
s
P
p
.002 w
.57622 .25363 m .63104 .28921 L .62678 .2992 L p
1 g
F P
s
P
p
.002 w
.33153 .40581 m .31557 .44321 L .30752 .42278 L p
1 g
F P
s
P
p
.002 w
.30752 .42278 m .32525 .38039 L .33153 .40581 L p
1 g
F P
s
P
p
.002 w
.62678 .2992 m .56923 .26185 L .57622 .25363 L p
1 g
F P
s
P
p
.002 w
.65743 .51355 m .63946 .56135 L .61819 .57005 L p
1 g
F P
s
P
p
.002 w
.63946 .56135 m .65743 .51355 L .67522 .49918 L p
1 g
F P
s
P
p
.002 w
.42908 .60053 m .45998 .60645 L .4709 .6192 L p
1 g
F P
s
P
p
.002 w
.50846 .61555 m .4709 .6192 L .45998 .60645 L p
1 g
F P
s
P
p
.002 w
.34779 .51182 m .35698 .53984 L .34049 .53487 L p
1 g
F P
s
P
p
.002 w
.34049 .53487 m .32862 .49923 L .34779 .51182 L p
1 g
F P
s
P
p
.002 w
.35939 .34778 m .32525 .38039 L .32418 .35718 L p
1 g
F P
s
P
p
.002 w
.32418 .35718 m .36096 .32147 L .35939 .34778 L p
1 g
F P
s
P
p
.002 w
.67354 .44164 m .67522 .49918 L .65743 .51355 L p
1 g
F P
s
P
p
.002 w
.67522 .49918 m .67354 .44164 L .68601 .42486 L p
1 g
F P
s
P
p
.002 w
.68601 .42486 m .66239 .36568 L .66969 .35053 L p
1 g
F P
s
P
p
.002 w
.62678 .2992 m .66969 .35053 L .66239 .36568 L p
1 g
F P
s
P
p
.002 w
.41238 .30109 m .36096 .32147 L .3665 .29912 L p
1 g
F P
s
P
p
.002 w
.3665 .29912 m .42021 .2774 L .41238 .30109 L p
1 g
F P
s
P
p
.002 w
.55991 .27542 m .49417 .25656 L .50467 .24346 L p
1 g
F P
s
P
p
.002 w
.50467 .24346 m .56923 .26185 L .55991 .27542 L p
1 g
F P
s
P
p
.002 w
.66239 .36568 m .68601 .42486 L .67354 .44164 L p
1 g
F P
s
P
p
.002 w
.50846 .61555 m .54064 .60065 L .56484 .6045 L p
1 g
F P
s
P
p
.002 w
.59276 .57491 m .56484 .6045 L .54064 .60065 L p
1 g
F P
s
P
p
.002 w
.56484 .6045 m .59276 .57491 L .61819 .57005 L p
1 g
F P
s
P
p
.002 w
.39074 .5596 m .40801 .57415 L .39979 .58642 L p
1 g
F P
s
P
p
.002 w
.39979 .58642 m .37495 .56553 L .39074 .5596 L p
1 g
F P
s
P
p
.002 w
.42908 .60053 m .39979 .58642 L .40801 .57415 L p
1 g
F P
s
P
p
.004 w
.39373 .59828 m
.40581 .57921 L
s
P
p
.002 w
.48346 .27536 m .42021 .2774 L .43011 .25891 L p
1 g
F P
s
P
p
.002 w
.43011 .25891 m .49417 .25656 L .48346 .27536 L p
1 g
F P
s
P
p
.002 w
.54064 .60065 m .50846 .61555 L .48947 .60346 L p
1 g
F P
s
P
p
.002 w
.45998 .60645 m .48947 .60346 L .50846 .61555 L p
1 g
F P
s
P
p
.002 w
.34303 .43266 m .32931 .46392 L .31557 .44321 L p
1 g
F P
s
P
p
.002 w
.31557 .44321 m .33153 .40581 L .34303 .43266 L p
1 g
F P
s
P
p
.002 w
.34855 .48424 m .34779 .51182 L .32862 .49923 L p
1 g
F P
s
P
p
.002 w
.32862 .49923 m .32931 .46392 L .34855 .48424 L p
1 g
F P
s
P
p
.002 w
.40801 .57415 m .42838 .58395 L .42908 .60053 L p
1 g
F P
s
P
p
.002 w
.45998 .60645 m .42908 .60053 L .42838 .58395 L p
1 g
F P
s
P
p
.002 w
.37833 .54175 m .39074 .5596 L .37495 .56553 L p
1 g
F P
s
P
p
.002 w
.37495 .56553 m .35698 .53984 L .37833 .54175 L p
1 g
F P
s
P
p
.002 w
.63439 .52591 m .61819 .57005 L .59276 .57491 L p
1 g
F P
s
P
p
.002 w
.61819 .57005 m .63439 .52591 L .65743 .51355 L p
1 g
F P
s
P
p
.002 w
.66239 .36568 m .61858 .31349 L .62678 .2992 L p
1 g
F P
s
P
p
.002 w
.56923 .26185 m .62678 .2992 L .61858 .31349 L p
1 g
F P
s
P
p
.002 w
.61858 .31349 m .55991 .27542 L .56923 .26185 L p
1 g
F P
s
P
p
.002 w
.36202 .37729 m .33153 .40581 L .32525 .38039 L p
1 g
F P
s
P
p
.002 w
.32525 .38039 m .35939 .34778 L .36202 .37729 L p
1 g
F P
s
P
p
.002 w
.42838 .58395 m .44983 .58799 L .45998 .60645 L p
1 g
F P
s
P
p
.002 w
.48947 .60346 m .45998 .60645 L .44983 .58799 L p
1 g
F P
s
P
p
.002 w
.37211 .52236 m .37833 .54175 L .35698 .53984 L p
1 g
F P
s
P
p
.002 w
.35698 .53984 m .34779 .51182 L .37211 .52236 L p
1 g
F P
s
P
p
.002 w
.65544 .45865 m .65743 .51355 L .63439 .52591 L p
1 g
F P
s
P
p
.002 w
.65743 .51355 m .65544 .45865 L .67354 .44164 L p
1 g
F P
s
P
p
.002 w
.40698 .32941 m .35939 .34778 L .36096 .32147 L p
1 g
F P
s
P
p
.002 w
.36096 .32147 m .41238 .30109 L .40698 .32941 L p
1 g
F P
s
P
p
.002 w
.48947 .60346 m .51452 .59161 L .54064 .60065 L p
1 g
F P
s
P
p
.002 w
.56385 .57557 m .54064 .60065 L .51452 .59161 L p
1 g
F P
s
P
p
.002 w
.54064 .60065 m .56385 .57557 L .59276 .57491 L p
1 g
F P
s
P
p
.002 w
.67354 .44164 m .64995 .38334 L .66239 .36568 L p
1 g
F P
s
P
p
.002 w
.61858 .31349 m .66239 .36568 L .64995 .38334 L p
1 g
F P
s
P
p
.002 w
.54842 .29418 m .48346 .27536 L .49417 .25656 L p
1 g
F P
s
P
p
.002 w
.49417 .25656 m .55991 .27542 L .54842 .29418 L p
1 g
F P
s
P
p
.002 w
.35954 .46004 m .34855 .48424 L .32931 .46392 L p
1 g
F P
s
P
p
.002 w
.32931 .46392 m .34303 .43266 L .35954 .46004 L p
1 g
F P
s
P
p
.002 w
.64995 .38334 m .67354 .44164 L .65544 .45865 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.44983 .58799 m .47019 .5858 L .48947 .60346 L p
1 g
F P
s
P
p
.002 w
.51452 .59161 m .48947 .60346 L .47019 .5858 L p
1 g
F P
s
P
p
.002 w
.4729 .2995 m .41238 .30109 L .42021 .2774 L p
1 g
F P
s
P
p
.002 w
.42021 .2774 m .48346 .27536 L .4729 .2995 L p
1 g
F P
s
P
p
.002 w
.37284 .50343 m .37211 .52236 L .34779 .51182 L p
1 g
F P
s
P
p
.002 w
.34779 .51182 m .34855 .48424 L .37284 .50343 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.60668 .53573 m .59276 .57491 L .56385 .57557 L p
1 g
F P
s
P
p
.002 w
.59276 .57491 m .60668 .53573 L .63439 .52591 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.41041 .54956 m .41931 .55708 L .40801 .57415 L p
1 g
F P
s
P
p
.002 w
.40801 .57415 m .39074 .5596 L .41041 .54956 L p
1 g
F P
s
P
p
.002 w
.42838 .58395 m .40801 .57415 L .41931 .55708 L p
1 g
F P
s
P
p
.002 w
.36891 .40906 m .34303 .43266 L .33153 .40581 L p
1 g
F P
s
P
p
.002 w
.33153 .40581 m .36202 .37729 L .36891 .40906 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.41931 .55708 m .42982 .56212 L .42838 .58395 L p
1 g
F P
s
P
p
.002 w
.44983 .58799 m .42838 .58395 L .42982 .56212 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.40407 .54035 m .41041 .54956 L .39074 .5596 L p
1 g
F P
s
P
p
.002 w
.39074 .5596 m .37833 .54175 L .40407 .54035 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.64995 .38334 m .60649 .33185 L .61858 .31349 L p
1 g
F P
s
P
p
.002 w
.55991 .27542 m .61858 .31349 L .60649 .33185 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.60649 .33185 m .54842 .29418 L .55991 .27542 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.42982 .56212 m .44087 .56415 L .44983 .58799 L p
1 g
F P
s
P
p
.002 w
.47019 .5858 m .44983 .58799 L .44087 .56415 L p
1 g
F P
s
P
p
.002 w
.40097 .5304 m .40407 .54035 L .37833 .54175 L p
1 g
F P
s
P
p
.002 w
.37833 .54175 m .37211 .52236 L .40097 .5304 L p
1 g
F P
s
P
p
.002 w
.63211 .4753 m .63439 .52591 L .60668 .53573 L p
1 g
F P
s
P
p
.002 w
.63439 .52591 m .63211 .4753 L .65544 .45865 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.004 w
.44848 .51185 m
.5 .43051 L
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.4043 .36148 m .36202 .37729 L .35939 .34778 L p
1 g
F P
s
P
p
.002 w
.35939 .34778 m .40698 .32941 L .4043 .36148 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47019 .5858 m .48093 .58059 L p
.51452 .59161 L 1 g
F P
s
P
p
.002 w
.48093 .58059 m .48312 .57953 L p
.48628 .58074 L 1 g
F P
s
P
p
.51452 .59161 m .48093 .58059 L .48628 .58074 L 1 g
F
P
p
.002 w
.48905 .58083 m .48921 .57862 L p
.47763 .57767 L 1 g
F P
s
P
p
.002 w
.47019 .5858 m .45795 .57101 L p
.46831 .57451 L 1 g
F P
s
P
p
.002 w
.48312 .57953 m .4794 .58133 L p
.46831 .57451 L 1 g
F P
s
P
p
.002 w
.4794 .58133 m .47019 .5858 L p
.46831 .57451 L 1 g
F P
s
P
p
.002 w
.46831 .57451 m .46872 .57265 L p
.45889 .56872 L 1 g
F P
s
P
p
.47763 .57767 m .48312 .57953 L .48905 .58083 L 1 g
F
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45062 .56356 L p
1 g
F P
s
P
p
.47019 .5858 m .44992 .56311 L .45062 .56356 L 1 g
F
P
p
.002 w
.45313 .56518 m .46021 .57374 L p
.45062 .56356 L 1 g
F P
s
P
p
.002 w
.46021 .57374 m .47019 .5858 L p
.45062 .56356 L 1 g
F P
s
P
p
.45146 .56129 m .44401 .55481 L .44502 .55617 L 1 g
F
P
p
.002 w
.44087 .56415 m .43548 .54337 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.45017 .56308 m .44431 .56376 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.44431 .56376 m .44087 .56415 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.43839 .54728 m .43925 .54566 L p
.43434 .53596 L 1 g
F P
s
P
p
.002 w
.43436 .536 m .43346 .53556 L .43427 .53572 L p
1 g
F P
s
P
p
.43434 .53596 m .43434 .53595 L .43435 .53598 L 1 g
F
P
p
.43434 .53596 m .43435 .53598 L .43839 .54728 L 1 g
F
P
p
.43434 .53595 m .43447 .53634 L .43839 .54728 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.4225 .50338 m .42586 .50346 L p
.43231 .53069 L 1 g
F P
s
P
p
.002 w
.43222 .53191 m .4225 .50338 L p
.43231 .53069 L 1 g
F P
s
P
p
.002 w
.43244 .52883 m .43346 .52734 L p
.43316 .5187 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52883 L p
1 g
F P
s
P
p
.43925 .54566 m .43244 .52883 L .43247 .52894 L 1 g
F
P
p
.002 w
.43347 .53281 m .43346 .53556 L p
.42586 .50346 L 1 g
F P
s
P
p
.43925 .54566 m .43243 .52884 L .43252 .52921 L 1 g
F
P
p
.43925 .54566 m .43239 .52889 L .43255 .52948 L 1 g
F
P
p
.43925 .54566 m .43234 .52897 L .43256 .52975 L 1 g
F
P
p
.43925 .54566 m .43228 .52907 L .43255 .52998 L 1 g
F
P
p
.43925 .54566 m .4322 .52917 L .433 .5317 L 1 g
F
P
p
.002 w
.4339 .53445 m .43346 .53556 L .43347 .53281 L p
1 g
F P
s
P
p
.002 w
.43404 .53497 m .43346 .53556 L .4339 .53445 L p
1 g
F P
s
P
p
.002 w
.43413 .53526 m .43346 .53556 L .43404 .53497 L p
1 g
F P
s
P
p
.002 w
.43419 .53549 m .43346 .53556 L .43413 .53526 L p
1 g
F P
s
P
p
.43925 .54566 m .432 .52947 L .43429 .53585 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.42586 .50346 m .43358 .50365 L .43355 .51006 L p
1 g
F P
s
P
p
.42586 .50346 m .43355 .51006 L .4326 .51214 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43382 .50949 L p
1 g
F P
s
P
p
.43346 .52734 m .43382 .50949 L .43381 .50954 L 1 g
F
P
p
.002 w
.43382 .50949 m .43485 .50826 L p
.43864 .4994 L 1 g
F P
s
P
p
.002 w
.43614 .50447 m .43358 .50365 L p
.44156 .49348 L 1 g
F P
s
P
p
.43864 .4994 m .44052 .495 L .43614 .50447 L 1 g
F
P
p
.43864 .4994 m .43614 .50447 L .43382 .50949 L 1 g
F
P
p
.002 w
.43358 .50365 m .43576 .46889 L p
.44156 .49348 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44263 .49131 L p
1 g
F P
s
P
p
.002 w
.43576 .46889 m .45126 .47379 L p
.44263 .49131 L 1 g
F P
s
P
p
.44134 .49256 m .44263 .49131 L .44156 .49348 L 1 g
F
P
p
.43576 .46889 m .44263 .49131 L .44134 .49256 L 1 g
F
P
p
.002 w
.44263 .49131 m .44166 .49233 L p
.43864 .4994 L 1 g
F P
s
P
p
.43485 .50826 m .44263 .49131 L .43864 .4994 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44156 .49348 m .45396 .48033 L .4448 .50725 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45752 .47689 L p
1 g
F P
s
P
p
.44339 .4905 m .45752 .47689 L .45038 .4838 L 1 g
F
P
p
.002 w
.45809 .47595 m .45782 .4766 L p
.45396 .48033 L 1 g
F P
s
P
p
.002 w
.47819 .48896 m .4549 .51379 L p
.45804 .47665 L 1 g
F P
s
P
p
.002 w
.45869 .47634 m .47819 .48896 L p
.45804 .47665 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47819 .48896 m .45869 .47634 L p
.47578 .46799 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .4671 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47578 .46799 m .48327 .46631 L .47819 .48896 L 1 g
F
P
p
.002 w
.4776 .4671 m .47786 .46667 L p
.48814 .46562 L 1 g
F P
s
P
p
.48327 .46631 m .5 .46396 L .47819 .48896 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.50247 .46199 m .52678 .43389 L p
.52577 .46751 L 1 g
F P
s
P
p
.002 w
.53836 .51694 m .52517 .48775 L .54196 .47656 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .5421 .47662 L 1 g
F
P
p
.52214 .46667 m .54235 .47674 L .5305 .471 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5661 .50939 L p
1 g
F P
s
P
p
.57255 .50503 m .56724 .51188 L .5661 .50939 L 1 g
F
P
p
.002 w
.56527 .50757 m .56598 .50732 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56598 .50732 m .57255 .50503 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.5661 .50939 m .56515 .50826 L p
.56658 .51756 L 1 g
F P
s
P
p
.55661 .4905 m .5661 .50939 L .56527 .50757 L 1 g
F
P
p
.55591 .46727 m .56268 .49644 L .55154 .47963 L 1 g
F
P
p
.56268 .49644 m .56527 .50757 L .55718 .49111 L 1 g
F
P
p
.56268 .49644 m .55718 .49111 L .55154 .47963 L 1 g
F
P
p
.55661 .4905 m .56527 .50757 L .56114 .49916 L 1 g
F
P
p
.002 w
.55591 .46727 m .57255 .50503 L .56527 .50757 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55718 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55718 .49111 L .54855 .48275 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56527 .50757 m .53836 .51694 L p
.55154 .47963 L 1 g
F P
s
P
p
.002 w
.54233 .47673 m .54174 .47608 L p
.54855 .48275 L 1 g
F P
s
P
p
.55114 .48078 m .53836 .51694 L .54196 .47656 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54233 .47673 L p
1 g
F P
s
P
p
.54855 .48275 m .55834 .49233 L .54233 .47673 L 1 g
F
P
p
.56114 .49916 m .56527 .50757 L .5634 .50349 L 1 g
F
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56722 .52834 L p
1 g
F P
s
P
p
.56515 .50826 m .56722 .52834 L .56658 .51756 L 1 g
F
P
p
.5661 .50939 m .54073 .54608 L .56527 .50757 L 1 g
F
P
p
.56724 .51188 m .56632 .51307 L .5661 .50939 L 1 g
F
P
p
.56632 .51307 m .54073 .54608 L .5661 .50939 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.57255 .50503 m .5728 .50873 L p
.54073 .54608 L 1 g
F P
s
P
p
.002 w
.5728 .50873 m .57511 .54256 L .56282 .54382 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56151 .54709 L p
1 g
F P
s
P
p
.57511 .54256 m .55887 .55369 L .56151 .54709 L 1 g
F
P
p
.002 w
.56282 .54382 m .56426 .54367 L p
.56151 .54709 L 1 g
F P
s
P
p
.002 w
.56426 .54367 m .57511 .54256 L p
.56151 .54709 L 1 g
F P
s
P
p
.002 w
.56151 .54709 m .56075 .54566 L p
.55659 .55319 L 1 g
F P
s
P
p
.56654 .52734 m .56151 .54709 L .56238 .54492 L 1 g
F
P
p
.56654 .52734 m .56175 .54755 L .56481 .53683 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54902 .56259 L p
1 g
F P
s
P
p
.56075 .54566 m .54902 .56259 L .55659 .55319 L 1 g
F
P
p
.56151 .54709 m .53235 .57187 L .56282 .54382 L 1 g
F
P
p
.55887 .55369 m .55289 .55779 L .56151 .54709 L 1 g
F
P
p
.55289 .55779 m .53235 .57187 L .56151 .54709 L 1 g
F
P
p
.002 w
.57511 .54256 m .57489 .54321 L p
.53235 .57187 L 1 g
F P
s
P
p
.002 w
.57489 .54321 m .56385 .57557 L .53607 .57231 L p
1 g
F P
s
P
p
.002 w
.51452 .59161 m .52741 .57735 L p
.56385 .57557 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53175 .57482 L p
1 g
F P
s
P
p
.54854 .56129 m .53175 .57482 L .53301 .57409 L 1 g
F
P
p
.56385 .57557 m .52741 .57735 L .53175 .57482 L 1 g
F
P
p
.002 w
.53607 .57231 m .5383 .57257 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.5383 .57257 m .56385 .57557 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.53175 .57482 m .53128 .57265 L p
.52146 .57769 L 1 g
F P
s
P
p
.002 w
.52876 .57584 m .52741 .57735 L p
.52275 .57736 L 1 g
F P
s
P
p
.52146 .57769 m .52876 .57584 L .53175 .57482 L 1 g
F
P
p
.002 w
.50717 .5878 m .49876 .58343 L p
.51373 .58025 L 1 g
F P
s
P
p
.002 w
.51092 .58035 m .51079 .57862 L p
.50013 .58075 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58083 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58083 L .4913 .58089 L 1 g
F
P
p
.002 w
.49403 .58098 m .49719 .58261 L p
.48905 .58083 L 1 g
F P
s
P
p
.51079 .57862 m .4913 .58089 L .50013 .58075 L 1 g
F
P
p
.48628 .58074 m .48905 .58083 L .49719 .58261 L 1 g
F
P
p
.4913 .58089 m .48902 .58116 L .49403 .58098 L 1 g
F
P
p
.4913 .58089 m .49403 .58098 L .50013 .58075 L 1 g
F
P
p
.002 w
.49719 .58261 m .51452 .59161 L p
.48628 .58074 L 1 g
F P
s
P
p
.48628 .58074 m .48312 .57953 L .48905 .58083 L 1 g
F
P
p
.002 w
.48312 .57953 m .48732 .57749 L .49403 .58098 L p
1 g
F P
s
P
p
.48905 .58083 m .48312 .57953 L .49403 .58098 L 1 g
F
P
p
.002 w
.48905 .58083 m .48902 .58116 L p
.4913 .58089 L 1 g
F P
s
P
p
.52741 .57735 m .5224 .57993 L .51373 .58025 L 1 g
F
P
p
.5224 .57993 m .50717 .5878 L .51373 .58025 L 1 g
F
P
p
.52741 .57735 m .49876 .58343 L .52275 .57736 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.52275 .57736 m .51092 .58035 L .48732 .57749 L 1 g
F
P
p
.002 w
.49876 .58343 m .49403 .58098 L p
.51092 .58035 L 1 g
F P
s
P
p
.002 w
.49403 .58098 m .48732 .57749 L p
.51092 .58035 L 1 g
F P
s
P
p
.002 w
.48902 .58116 m .48889 .583 L p
.50013 .58075 L 1 g
F P
s
P
p
.002 w
.511 .58148 m .51092 .58035 L p
.49836 .5811 L 1 g
F P
s
P
p
.50013 .58075 m .49836 .5811 L .51092 .58035 L 1 g
F
P
p
.53451 .57321 m .53181 .57507 L .53311 .5744 L 1 g
F
P
p
.54854 .56129 m .53301 .57409 L .53451 .57321 L 1 g
F
P
p
.53301 .57409 m .53181 .57507 L .53451 .57321 L 1 g
F
P
p
.54854 .56129 m .53189 .57544 L .54035 .56909 L 1 g
F
P
p
.002 w
.53235 .57187 m .53607 .57231 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.52741 .57735 m .52876 .57584 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.52876 .57584 m .53235 .57187 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.52741 .57735 m .51452 .59161 L .50717 .5878 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53181 .57507 L p
1 g
F P
s
P
p
.002 w
.53181 .57507 m .53175 .57482 L p
.52987 .57556 L 1 g
F P
s
P
p
.52987 .57556 m .51111 .583 L .53181 .57507 L 1 g
F
P
p
.52146 .57769 m .51756 .57969 L .52876 .57584 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53235 .57187 m .52876 .57584 L p
.48732 .57749 L 1 g
F P
s
P
p
.52876 .57584 m .52275 .57736 L .48732 .57749 L 1 g
F
P
p
.51756 .57969 m .51111 .583 L .53175 .57482 L 1 g
F
P
p
.002 w
.53175 .57482 m .53181 .57507 L p
.53301 .57409 L 1 g
F P
s
P
p
.002 w
.53181 .57507 m .53189 .57544 L p
.53311 .5744 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.53607 .57231 m .53235 .57187 L p
.57489 .54321 L 1 g
F P
s
P
p
.002 w
.53189 .57544 m .5322 .57686 L p
.54035 .56909 L 1 g
F P
s
P
p
.002 w
.54902 .56259 m .54998 .56518 L p
.55659 .55319 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56151 .54709 L p
1 g
F P
s
P
p
.55659 .55319 m .54998 .56518 L .56151 .54709 L 1 g
F
P
p
.002 w
.56151 .54709 m .56175 .54755 L p
.56238 .54492 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.53235 .57187 m .54073 .54608 L .56282 .54382 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56282 .54382 m .54073 .54608 L p
.5728 .50873 L 1 g
F P
s
P
p
.002 w
.56175 .54755 m .56257 .5491 L p
.56481 .53683 L 1 g
F P
s
P
p
.002 w
.56722 .52834 m .56854 .53025 L p
.56658 .51756 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5661 .50939 L p
1 g
F P
s
P
p
.56658 .51756 m .56854 .53025 L .5661 .50939 L 1 g
F
P
p
.002 w
.5661 .50939 m .56713 .51061 L p
.5634 .50349 L 1 g
F P
s
P
p
.002 w
.54073 .54608 m .53836 .51694 L .56527 .50757 L p
1 g
F P
s
P
p
.002 w
.55718 .49111 m .55834 .49233 L p
.54855 .48275 L 1 g
F P
s
P
p
.55591 .46727 m .55114 .48078 L .54233 .47673 L 1 g
F
P
p
.002 w
.54196 .47656 m .54208 .47648 L p
.54233 .47673 L 1 g
F P
s
P
p
.002 w
.54208 .47648 m .55591 .46727 L p
.54233 .47673 L 1 g
F P
s
P
p
.002 w
.54233 .47673 m .54235 .47674 L p
.5421 .47662 L 1 g
F P
s
P
p
.002 w
.52678 .43389 m .55591 .46727 L .54196 .47656 L p
1 g
F P
s
P
p
.002 w
.54196 .47656 m .52517 .48775 L p
.52574 .46869 L 1 g
F P
s
P
p
.002 w
.52237 .46706 m .52214 .46667 L p
.5305 .471 L 1 g
F P
s
P
p
.52678 .43389 m .54196 .47656 L .52574 .46869 L 1 g
F
P
p
.52574 .46869 m .52517 .48775 L .52237 .46706 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46706 L p
1 g
F P
s
P
p
.5305 .471 m .54302 .47747 L .52237 .46706 L 1 g
F
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.5305 .471 L 1 g
F P
s
P
p
.002 w
.52517 .48775 m .50487 .46472 L p
.52237 .46706 L 1 g
F P
s
P
p
.52577 .46751 m .52574 .46869 L .52237 .46706 L 1 g
F
P
p
.002 w
.5 .46396 m .5 .4634 L p
.5096 .46535 L 1 g
F P
s
P
p
.5096 .46535 m .50521 .46476 L .5 .46396 L 1 g
F
P
p
.51137 .46571 m .5006 .46407 L .5 .46396 L 1 g
F
P
p
.002 w
.52282 .46778 m .51833 .46712 L p
.51137 .46571 L 1 g
F P
s
P
p
.5 .4634 m .5145 .46619 L .51137 .46571 L 1 g
F
P
p
.5145 .46619 m .52282 .46778 L .51137 .46571 L 1 g
F
P
p
.002 w
.52517 .48775 m .4937 .5064 L p
.50201 .46428 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.50247 .46199 m .50487 .46472 L p
.50201 .46428 L 1 g
F P
s
P
p
.002 w
.50487 .46472 m .52517 .48775 L p
.50201 .46428 L 1 g
F P
s
P
p
.002 w
.50487 .46472 m .50247 .46199 L p
.52577 .46751 L 1 g
F P
s
P
p
.5096 .46535 m .51137 .46571 L .50521 .46476 L 1 g
F
P
p
.50201 .46428 m .4937 .5064 L .5006 .46407 L 1 g
F
P
p
.51137 .46571 m .51833 .46712 L .5006 .46407 L 1 g
F
P
p
.002 w
.4937 .5064 m .47819 .48896 L .5006 .46407 L p
1 g
F P
s
P
p
.002 w
.5006 .46407 m .50247 .46199 L p
.50201 .46428 L 1 g
F P
s
P
p
.002 w
.50079 .46385 m .5006 .46407 L p
.5 .46396 L 1 g
F P
s
P
p
.002 w
.5006 .46407 m .47819 .48896 L p
.5 .46396 L 1 g
F P
s
P
p
.002 w
.51833 .46712 m .5 .46442 L .5 .46396 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46396 L p
1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .46442 L p
.48814 .46562 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46396 L .48814 .46562 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47288 .44283 m .49627 .45798 L p
.4776 .4671 L 1 g
F P
s
P
p
.45826 .47608 m .4776 .4671 L .46771 .47194 L 1 g
F
P
p
.4757 .46737 m .4776 .4671 L .47578 .46799 L 1 g
F
P
p
.47288 .44283 m .4776 .4671 L .4757 .46737 L 1 g
F
P
p
.002 w
.50247 .46199 m .50079 .46385 L p
.48327 .46631 L 1 g
F P
s
P
p
.002 w
.49627 .45798 m .50247 .46199 L p
.47578 .46799 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .4671 L p
1 g
F P
s
P
p
.48814 .46562 m .5 .46442 L .4776 .4671 L 1 g
F
P
p
.002 w
.4776 .4671 m .47718 .46778 L p
.46771 .47194 L 1 g
F P
s
P
p
.002 w
.45809 .47595 m .47288 .44283 L p
.47578 .46799 L 1 g
F P
s
P
p
.002 w
.45752 .47689 m .45826 .47608 L p
.46583 .47285 L 1 g
F P
s
P
p
.46583 .47285 m .45877 .47631 L .45752 .47689 L 1 g
F
P
p
.45826 .47608 m .47477 .46884 L .46971 .4712 L 1 g
F
P
p
.002 w
.45869 .47634 m .45809 .47595 L p
.47578 .46799 L 1 g
F P
s
P
p
.46583 .47285 m .46971 .4712 L .45877 .47631 L 1 g
F
P
p
.45804 .47665 m .4549 .51379 L .45774 .47679 L 1 g
F
P
p
.46971 .4712 m .4728 .46989 L .45774 .47679 L 1 g
F
P
p
.46971 .4712 m .45774 .47679 L .45752 .47689 L 1 g
F
P
p
.002 w
.4549 .51379 m .4448 .50725 L .45774 .47679 L p
1 g
F P
s
P
p
.002 w
.45774 .47679 m .45809 .47595 L p
.45804 .47665 L 1 g
F P
s
P
p
.002 w
.45809 .47595 m .45869 .47634 L p
.45804 .47665 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .4728 .46989 L p
.46971 .4712 L 1 g
F P
s
P
p
.47477 .46884 m .47718 .46778 L .46971 .4712 L 1 g
F
P
p
.45396 .48033 m .45752 .47689 L .4448 .50725 L 1 g
F
P
p
.002 w
.45774 .47679 m .4448 .50725 L p
.45752 .47689 L 1 g
F P
s
P
p
.002 w
.4728 .46989 m .45698 .47747 L .45752 .47689 L p
1 g
F P
s
P
p
.002 w
.45782 .4766 m .45774 .47679 L p
.45752 .47689 L 1 g
F P
s
P
p
.002 w
.44263 .49131 m .44339 .4905 L p
.45038 .4838 L 1 g
F P
s
P
p
.002 w
.45126 .47379 m .45809 .47595 L p
.44156 .49348 L 1 g
F P
s
P
p
.002 w
.45752 .47689 m .45698 .47747 L p
.45038 .4838 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44263 .49131 L p
1 g
F P
s
P
p
.45038 .4838 m .45698 .47747 L .44263 .49131 L 1 g
F
P
p
.002 w
.4448 .50725 m .43614 .50447 L p
.44156 .49348 L 1 g
F P
s
P
p
.43346 .52734 m .43381 .50954 L .43316 .5187 L 1 g
F
P
p
.43364 .50987 m .43379 .50983 L .43366 .51167 L 1 g
F
P
p
.43381 .50954 m .43382 .50949 L .43354 .51335 L 1 g
F
P
p
.43381 .50954 m .43354 .51335 L .43316 .5187 L 1 g
F
P
p
.002 w
.43347 .53281 m .43354 .51335 L p
.4339 .53445 L 1 g
F P
s
P
p
.002 w
.43354 .51335 m .43358 .50365 L p
.43366 .51167 L 1 g
F P
s
P
p
.43366 .51167 m .4339 .53445 L .43354 .51335 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43614 .50447 m .4448 .50725 L p
.43379 .50983 L 1 g
F P
s
P
p
.43382 .50949 m .43379 .50983 L .43364 .50987 L 1 g
F
P
p
.43614 .50447 m .43379 .50983 L .43382 .50949 L 1 g
F
P
p
.002 w
.43355 .51006 m .43354 .51335 L p
.4326 .51214 L 1 g
F P
s
P
p
.42586 .50346 m .43354 .51335 L .43244 .52883 L 1 g
F
P
p
.002 w
.43382 .50949 m .43287 .51061 L p
.43316 .51867 L 1 g
F P
s
P
p
.43316 .5187 m .43354 .51335 L .43316 .51867 L 1 g
F
P
p
.43354 .51335 m .43382 .50949 L .43316 .51867 L 1 g
F
P
p
.002 w
.43382 .50949 m .43382 .50949 L p
.43381 .50954 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.4448 .50725 m .4339 .53445 L p
.43366 .51167 L 1 g
F P
s
P
p
.43379 .50983 m .4448 .50725 L .43366 .51167 L 1 g
F
P
p
.002 w
.43358 .50365 m .43614 .50447 L p
.43364 .50987 L 1 g
F P
s
P
p
.002 w
.43382 .50949 m .43382 .50949 L p
.44092 .49406 L 1 g
F P
s
P
p
.44052 .495 m .44092 .49406 L .43382 .50949 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43382 .50949 L p
1 g
F P
s
P
p
.44092 .49406 m .44166 .49233 L .43382 .50949 L 1 g
F
P
p
.002 w
.43354 .51335 m .43347 .53281 L p
.43244 .52883 L 1 g
F P
s
P
p
.002 w
.4128 .50644 m .4225 .50338 L .43222 .53191 L p
1 g
F P
s
P
p
.002 w
.43222 .53191 m .43346 .53556 L .4321 .53365 L p
1 g
F P
s
P
p
.002 w
.4321 .53365 m .4128 .50644 L p
.43222 .53191 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43242 .52885 L p
1 g
F P
s
P
p
.002 w
.43242 .52885 m .43244 .52883 L p
.43244 .52856 L 1 g
F P
s
P
p
.43244 .52856 m .43287 .51061 L .43242 .52885 L 1 g
F
P
p
.43316 .5187 m .43287 .51061 L .43244 .52883 L 1 g
F
P
p
.002 w
.43346 .53556 m .43222 .53191 L p
.43231 .53069 L 1 g
F P
s
P
p
.002 w
.43244 .52883 m .43243 .52884 L p
.43247 .52894 L 1 g
F P
s
P
p
.002 w
.43243 .52884 m .43239 .52889 L p
.43252 .52921 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.4448 .50725 m .4549 .51379 L .43404 .53497 L p
1 g
F P
s
P
p
.002 w
.4339 .53445 m .4448 .50725 L p
.43404 .53497 L 1 g
F P
s
P
p
.002 w
.43239 .52889 m .43234 .52897 L p
.43255 .52948 L 1 g
F P
s
P
p
.002 w
.43234 .52897 m .43228 .52907 L p
.43256 .52975 L 1 g
F P
s
P
p
.002 w
.4549 .51379 m .46275 .52253 L .43413 .53526 L p
1 g
F P
s
P
p
.002 w
.43404 .53497 m .4549 .51379 L p
.43413 .53526 L 1 g
F P
s
P
p
.002 w
.46275 .52253 m .46747 .53248 L .43419 .53549 L p
1 g
F P
s
P
p
.002 w
.43413 .53526 m .46275 .52253 L p
.43419 .53549 L 1 g
F P
s
P
p
.002 w
.43228 .52907 m .4322 .52917 L p
.43255 .52998 L 1 g
F P
s
P
p
.002 w
.4322 .52917 m .432 .52947 L p
.433 .5317 L 1 g
F P
s
P
p
.002 w
.46747 .53248 m .46856 .54252 L .43427 .53572 L p
1 g
F P
s
P
p
.002 w
.43427 .53572 m .43346 .53556 L .43419 .53549 L p
1 g
F P
s
P
p
.002 w
.43419 .53549 m .46747 .53248 L p
.43427 .53572 L 1 g
F P
s
P
p
.43432 .53592 m .43508 .53805 L .43839 .54728 L 1 g
F
P
p
.002 w
.45062 .56356 m .45146 .56129 L p
.44502 .55617 L 1 g
F P
s
P
p
.44502 .55617 m .43958 .55185 L .45017 .56308 L 1 g
F
P
p
.44502 .55617 m .45017 .56308 L .45062 .56356 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.45128 .56295 m .45017 .56308 L p
.43524 .53849 L 1 g
F P
s
P
p
.002 w
.43346 .53556 m .43508 .53805 L p
.43524 .53849 L 1 g
F P
s
P
p
.002 w
.43508 .53805 m .45128 .56295 L p
.43524 .53849 L 1 g
F P
s
P
p
.002 w
.432 .52947 m .43146 .53025 L p
.43429 .53585 L 1 g
F P
s
P
p
.002 w
.46856 .54252 m .46595 .55156 L .43436 .536 L p
1 g
F P
s
P
p
.002 w
.43427 .53572 m .46856 .54252 L p
.43436 .536 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46595 .55156 m .45996 .55861 L .43453 .53649 L p
1 g
F P
s
P
p
.002 w
.43453 .53649 m .43346 .53556 L .43436 .536 L p
1 g
F P
s
P
p
.002 w
.43436 .536 m .46595 .55156 L p
.43453 .53649 L 1 g
F P
s
P
p
.43434 .53595 m .43432 .53592 L .43447 .53634 L 1 g
F
P
p
.002 w
.43508 .53805 m .43346 .53556 L .43453 .53649 L p
1 g
F P
s
P
p
.43432 .53592 m .43429 .53585 L .43508 .53805 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45996 .55861 m .45128 .56295 L .43508 .53805 L p
1 g
F P
s
P
p
.002 w
.43453 .53649 m .45996 .55861 L p
.43508 .53805 L 1 g
F P
s
P
p
.002 w
.43548 .54337 m .43346 .53556 L p
.45017 .56308 L 1 g
F P
s
P
p
.002 w
.41931 .55708 m .41041 .54956 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.42982 .56212 m .41931 .55708 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.44087 .56415 m .42982 .56212 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.41041 .54956 m .40407 .54035 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.40407 .54035 m .40097 .5304 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.40097 .5304 m .40146 .52076 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.40146 .52076 m .40553 .51247 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.40553 .51247 m .4128 .50644 L .43346 .53556 L closepath p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43839 .54728 L p
1 g
F P
s
P
p
.43429 .53585 m .43146 .53025 L .43839 .54728 L 1 g
F
P
p
.002 w
.43743 .5491 m .43958 .55185 L p
.44502 .55617 L 1 g
F P
s
P
p
.44401 .55481 m .43743 .5491 L .44502 .55617 L 1 g
F
P
p
.002 w
.44087 .56415 m .44992 .56311 L p
.47019 .5858 L 1 g
F P
s
P
p
.46872 .57265 m .45062 .56356 L .45114 .5639 L 1 g
F
P
p
.46872 .57265 m .45059 .56362 L .45889 .56872 L 1 g
F
P
p
.002 w
.44992 .56311 m .45128 .56295 L .45313 .56518 L p
1 g
F P
s
P
p
.002 w
.43958 .55185 m .45002 .56518 L .45062 .56356 L p
1 g
F P
s
P
p
.002 w
.45062 .56356 m .45059 .56362 L p
.45114 .5639 L 1 g
F P
s
P
p
.48312 .57953 m .46831 .57451 L .45128 .56295 L 1 g
F
P
p
.002 w
.45795 .57101 m .45313 .56518 L p
.46831 .57451 L 1 g
F P
s
P
p
.002 w
.45313 .56518 m .45128 .56295 L p
.46831 .57451 L 1 g
F P
s
P
p
.002 w
.45059 .56362 m .45002 .56518 L p
.45889 .56872 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46831 .57451 L p
1 g
F P
s
P
p
.45889 .56872 m .45002 .56518 L .46831 .57451 L 1 g
F
P
p
.47763 .57767 m .47287 .57728 L .48312 .57953 L 1 g
F
P
p
.002 w
.48732 .57749 m .48312 .57953 L p
.45128 .56295 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58148 L p
1 g
F P
s
P
p
.49836 .5811 m .48889 .583 L .511 .58148 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58083 L p
1 g
F P
s
P
p
.47287 .57728 m .4678 .57686 L .48905 .58083 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.3806 .48698 m .37284 .50343 L .34855 .48424 L p
1 g
F P
s
P
p
.002 w
.34855 .48424 m .35954 .46004 L .3806 .48698 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.56385 .57557 m .57511 .54256 L .60668 .53573 L p
1 g
F P
s
P
p
.002 w
.63254 .40302 m .65544 .45865 L .63211 .4753 L p
1 g
F P
s
P
p
.002 w
.65544 .45865 m .63254 .40302 L .64995 .38334 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.40146 .52076 m .40097 .5304 L .37211 .52236 L p
1 g
F P
s
P
p
.002 w
.37211 .52236 m .37284 .50343 L .40146 .52076 L p
1 g
F P
s
P
p
.002 w
.60649 .33185 m .64995 .38334 L .63254 .40302 L p
1 g
F P
s
P
p
.002 w
.37992 .44199 m .35954 .46004 L .34303 .43266 L p
1 g
F P
s
P
p
.002 w
.34303 .43266 m .36891 .40906 L .37992 .44199 L p
1 g
F P
s
P
p
.002 w
.46289 .32833 m .40698 .32941 L .41238 .30109 L p
1 g
F P
s
P
p
.002 w
.41238 .30109 m .4729 .2995 L .46289 .32833 L p
1 g
F P
s
P
p
.002 w
.53508 .31773 m .4729 .2995 L .48346 .27536 L p
1 g
F P
s
P
p
.002 w
.48346 .27536 m .54842 .29418 L .53508 .31773 L p
1 g
F P
s
P
p
.002 w
.60418 .49096 m .60668 .53573 L .57511 .54256 L p
1 g
F P
s
P
p
.002 w
.60668 .53573 m .60418 .49096 L .63211 .4753 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40454 .39622 m .36891 .40906 L .36202 .37729 L p
1 g
F P
s
P
p
.002 w
.36202 .37729 m .4043 .36148 L .40454 .39622 L p
1 g
F P
s
P
p
.002 w
.45128 .56295 m .45996 .55861 L .48732 .57749 L p
1 g
F P
s
P
p
.002 w
.49932 .5638 m .48732 .57749 L .45996 .55861 L p
1 g
F P
s
P
p
.002 w
.48732 .57749 m .49932 .5638 L .53235 .57187 L p
1 g
F P
s
P
p
.002 w
.40553 .51247 m .40146 .52076 L .37284 .50343 L p
1 g
F P
s
P
p
.002 w
.37284 .50343 m .3806 .48698 L .40553 .51247 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.63254 .40302 m .59074 .35383 L .60649 .33185 L p
1 g
F P
s
P
p
.002 w
.54842 .29418 m .60649 .33185 L .59074 .35383 L p
1 g
F P
s
P
p
.002 w
.54073 .54608 m .53235 .57187 L .49932 .5638 L p
1 g
F P
s
P
p
.002 w
.59074 .35383 m .53508 .31773 L .54842 .29418 L p
1 g
F P
s
P
p
.002 w
.39473 .47486 m .3806 .48698 L .35954 .46004 L p
1 g
F P
s
P
p
.002 w
.35954 .46004 m .37992 .44199 L .39473 .47486 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.61059 .42407 m .63211 .4753 L .60418 .49096 L p
1 g
F P
s
P
p
.002 w
.63211 .4753 m .61059 .42407 L .63254 .40302 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45382 .36092 m .4043 .36148 L .40698 .32941 L p
1 g
F P
s
P
p
.002 w
.40698 .32941 m .46289 .32833 L .45382 .36092 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59074 .35383 m .63254 .40302 L .61059 .42407 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.57511 .54256 m .57255 .50503 L .60418 .49096 L p
1 g
F P
s
P
p
.002 w
.45996 .55861 m .46595 .55156 L .49932 .5638 L p
1 g
F P
s
P
p
.002 w
.5203 .34539 m .46289 .32833 L .4729 .2995 L p
1 g
F P
s
P
p
.002 w
.4729 .2995 m .53508 .31773 L .5203 .34539 L p
1 g
F P
s
P
p
.002 w
.50477 .54607 m .49932 .5638 L .46595 .55156 L p
1 g
F P
s
P
p
.002 w
.49932 .5638 m .50477 .54607 L .54073 .54608 L p
1 g
F P
s
P
p
.002 w
.40774 .43237 m .37992 .44199 L .36891 .40906 L p
1 g
F P
s
P
p
.002 w
.36891 .40906 m .40454 .39622 L .40774 .43237 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.4128 .50644 m .40553 .51247 L .3806 .48698 L p
1 g
F P
s
P
p
.002 w
.3806 .48698 m .39473 .47486 L .4128 .50644 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.46595 .55156 m .46856 .54252 L .50477 .54607 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53836 .51694 m .54073 .54608 L .50477 .54607 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.41381 .46855 m .39473 .47486 L .37992 .44199 L p
1 g
F P
s
P
p
.002 w
.37992 .44199 m .40774 .43237 L .41381 .46855 L p
1 g
F P
s
P
p
.002 w
.58474 .44576 m .60418 .49096 L .57255 .50503 L p
1 g
F P
s
P
p
.002 w
.60418 .49096 m .58474 .44576 L .61059 .42407 L p
1 g
F P
s
P
p
.002 w
.61059 .42407 m .57176 .37876 L .59074 .35383 L p
1 g
F P
s
P
p
.002 w
.53508 .31773 m .59074 .35383 L .57176 .37876 L p
1 g
F P
s
P
p
.002 w
.57176 .37876 m .5203 .34539 L .53508 .31773 L p
1 g
F P
s
P
p
.002 w
.44608 .39612 m .40454 .39622 L .4043 .36148 L p
1 g
F P
s
P
p
.002 w
.4043 .36148 m .45382 .36092 L .44608 .39612 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46856 .54252 m .46747 .53248 L .50288 .5262 L p
1 g
F P
s
P
p
.002 w
.50288 .5262 m .50477 .54607 L .46856 .54252 L p
1 g
F P
s
P
p
.002 w
.50477 .54607 m .50288 .5262 L .53836 .51694 L p
1 g
F P
s
P
p
.002 w
.4225 .50338 m .4128 .50644 L .39473 .47486 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.39473 .47486 m .41381 .46855 L .4225 .50338 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.57176 .37876 m .61059 .42407 L .58474 .44576 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.5046 .37624 m .45382 .36092 L .46289 .32833 L p
1 g
F P
s
P
p
.002 w
.46289 .32833 m .5203 .34539 L .5046 .37624 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46747 .53248 m .46275 .52253 L .4937 .5064 L p
1 g
F P
s
P
p
.002 w
.4937 .5064 m .50288 .5262 L .46747 .53248 L p
1 g
F P
s
P
p
.002 w
.43358 .50365 m .4225 .50338 L .41381 .46855 L p
1 g
F P
s
P
p
.002 w
.57255 .50503 m .55591 .46727 L .58474 .44576 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43998 .43258 m .40774 .43237 L .40454 .39622 L p
1 g
F P
s
P
p
.002 w
.40454 .39622 m .44608 .39612 L .43998 .43258 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46275 .52253 m .4549 .51379 L .47819 .48896 L p
1 g
F P
s
P
p
.002 w
.47819 .48896 m .4937 .5064 L .46275 .52253 L p
1 g
F P
s
P
p
.002 w
.41381 .46855 m .43576 .46889 L .43358 .50365 L p
1 g
F P
s
P
p
.002 w
.50288 .5262 m .4937 .5064 L .52517 .48775 L p
1 g
F P
s
P
p
.002 w
.52517 .48775 m .53836 .51694 L .50288 .5262 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.43576 .46889 m .41381 .46855 L .40774 .43237 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.40774 .43237 m .43998 .43258 L .43576 .46889 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.58474 .44576 m .55018 .40578 L .57176 .37876 L p
1 g
F P
s
P
p
.002 w
.5203 .34539 m .57176 .37876 L .55018 .40578 L p
1 g
F P
s
P
p
.002 w
.55018 .40578 m .5046 .37624 L .5203 .34539 L p
1 g
F P
s
P
p
.002 w
.55018 .40578 m .58474 .44576 L .55591 .46727 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48859 .40915 m .44608 .39612 L .45382 .36092 L p
1 g
F P
s
P
p
.002 w
.45382 .36092 m .5046 .37624 L .48859 .40915 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.45809 .47595 m .43576 .46889 L .43998 .43258 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55591 .46727 m .52678 .43389 L .55018 .40578 L p
1 g
F P
s
P
p
.002 w
.47288 .44283 m .43998 .43258 L .44608 .39612 L p
1 g
F P
s
P
p
.002 w
.44608 .39612 m .48859 .40915 L .47288 .44283 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43998 .43258 m .47288 .44283 L .45809 .47595 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.5046 .37624 m .55018 .40578 L .52678 .43389 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.52678 .43389 m .48859 .40915 L .5046 .37624 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50247 .46199 m .47288 .44283 L .48859 .40915 L p
1 g
F P
s
P
p
.002 w
.48859 .40915 m .52678 .43389 L .50247 .46199 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.004 w
.40581 .57921 m
.41098 .57105 L
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .45824 .72514 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39373 .59828 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0331579)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0331579)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46588 .43429 m .49188 .45774 L .50782 .43409 L p
1 g
F P
s
P
p
.002 w
.50782 .43409 m .48772 .41593 L .46588 .43429 L p
1 g
F P
s
P
p
.002 w
.53217 .44567 m .50782 .43409 L .49188 .45774 L p
1 g
F P
s
P
p
.002 w
.48772 .41593 m .50782 .43409 L .52358 .41034 L p
1 g
F P
s
P
p
.002 w
.50782 .43409 m .53217 .44567 L .54023 .41821 L p
1 g
F P
s
P
p
.002 w
.54023 .41821 m .52358 .41034 L .50782 .43409 L p
1 g
F P
s
P
p
.002 w
.44786 .40469 m .46588 .43429 L .48772 .41593 L p
1 g
F P
s
P
p
.002 w
.48772 .41593 m .47386 .393 L .44786 .40469 L p
1 g
F P
s
P
p
.002 w
.47386 .393 m .48772 .41593 L .50985 .39793 L p
1 g
F P
s
P
p
.002 w
.52358 .41034 m .50985 .39793 L .48772 .41593 L p
1 g
F P
s
P
p
.002 w
.44473 .45267 m .47604 .48088 L .49188 .45774 L p
1 g
F P
s
P
p
.002 w
.49188 .45774 m .46588 .43429 L .44473 .45267 L p
1 g
F P
s
P
p
.002 w
.52332 .47279 m .49188 .45774 L .47604 .48088 L p
1 g
F P
s
P
p
.002 w
.49188 .45774 m .52332 .47279 L .53217 .44567 L p
1 g
F P
s
P
p
.002 w
.50985 .39793 m .52358 .41034 L .53887 .38693 L p
1 g
F P
s
P
p
.002 w
.52358 .41034 m .54023 .41821 L .54736 .39092 L p
1 g
F P
s
P
p
.002 w
.54736 .39092 m .53887 .38693 L .52358 .41034 L p
1 g
F P
s
P
p
.002 w
.50985 .39793 m .50045 .38223 L .47386 .393 L p
1 g
F P
s
P
p
.002 w
.50045 .38223 m .50985 .39793 L .53188 .3806 L p
1 g
F P
s
P
p
.002 w
.53887 .38693 m .53188 .3806 L .50985 .39793 L p
1 g
F P
s
P
p
.002 w
.42292 .41712 m .44473 .45267 L .46588 .43429 L p
1 g
F P
s
P
p
.002 w
.46588 .43429 m .44786 .40469 L .42292 .41712 L p
1 g
F P
s
P
p
.002 w
.55833 .44946 m .53217 .44567 L .52332 .47279 L p
1 g
F P
s
P
p
.002 w
.53217 .44567 m .55833 .44946 L .55809 .4207 L p
1 g
F P
s
P
p
.002 w
.55809 .4207 m .54023 .41821 L .53217 .44567 L p
1 g
F P
s
P
p
.002 w
.54023 .41821 m .55809 .4207 L .55645 .39213 L p
1 g
F P
s
P
p
.002 w
.55645 .39213 m .54736 .39092 L .54023 .41821 L p
1 g
F P
s
P
p
.002 w
.43972 .37182 m .44786 .40469 L .47386 .393 L p
1 g
F P
s
P
p
.002 w
.47386 .393 m .46773 .36756 L .43972 .37182 L p
1 g
F P
s
P
p
.002 w
.46773 .36756 m .47386 .393 L .50045 .38223 L p
1 g
F P
s
P
p
.002 w
.50045 .38223 m .49638 .36486 L .46773 .36756 L p
1 g
F P
s
P
p
.002 w
.49638 .36486 m .50045 .38223 L .52712 .3726 L p
1 g
F P
s
P
p
.002 w
.53188 .3806 m .52712 .3726 L .50045 .38223 L p
1 g
F P
s
P
p
.002 w
.47604 .48088 m .51383 .49908 L .52332 .47279 L p
1 g
F P
s
P
p
.002 w
.55714 .47787 m .52332 .47279 L .51383 .49908 L p
1 g
F P
s
P
p
.002 w
.52332 .47279 m .55714 .47787 L .55833 .44946 L p
1 g
F P
s
P
p
.002 w
.42467 .47074 m .46059 .50307 L .47604 .48088 L p
1 g
F P
s
P
p
.002 w
.47604 .48088 m .44473 .45267 L .42467 .47074 L p
1 g
F P
s
P
p
.002 w
.51383 .49908 m .47604 .48088 L .46059 .50307 L p
1 g
F P
s
P
p
.002 w
.41286 .37757 m .42292 .41712 L .44786 .40469 L p
1 g
F P
s
P
p
.002 w
.44786 .40469 m .43972 .37182 L .41286 .37757 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .53188 .3806 L .53887 .38693 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .53887 .38693 L .54736 .39092 L closepath p
1 g
F P
s
P
p
.002 w
.57532 .4175 m .55809 .4207 L .55833 .44946 L p
1 g
F P
s
P
p
.002 w
.55809 .4207 m .57532 .4175 L .56518 .39044 L p
1 g
F P
s
P
p
.002 w
.56518 .39044 m .55645 .39213 L .55809 .4207 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .52712 .3726 L .53188 .3806 L closepath p
1 g
F P
s
P
p
.002 w
.39951 .43005 m .42467 .47074 L .44473 .45267 L p
1 g
F P
s
P
p
.002 w
.44473 .45267 m .42292 .41712 L .39951 .43005 L p
1 g
F P
s
P
p
.002 w
.58365 .44495 m .55833 .44946 L .55714 .47787 L p
1 g
F P
s
P
p
.002 w
.55833 .44946 m .58365 .44495 L .57532 .4175 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .54736 .39092 L .55645 .39213 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .3726 m .52511 .36376 L .49638 .36486 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .52511 .36376 L .52712 .3726 L closepath p
1 g
F P
s
P
p
.002 w
.47009 .3422 m .46773 .36756 L .49638 .36486 L p
1 g
F P
s
P
p
.002 w
.49638 .36486 m .49813 .34761 L .47009 .3422 L p
1 g
F P
s
P
p
.002 w
.49813 .34761 m .49638 .36486 L .52511 .36376 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .55645 .39213 L .56518 .39044 L closepath p
1 g
F P
s
P
p
.002 w
.46059 .50307 m .50388 .52404 L .51383 .49908 L p
1 g
F P
s
P
p
.002 w
.55454 .50541 m .51383 .49908 L .50388 .52404 L p
1 g
F P
s
P
p
.002 w
.51383 .49908 m .55454 .50541 L .55714 .47787 L p
1 g
F P
s
P
p
.002 w
.44249 .33891 m .43972 .37182 L .46773 .36756 L p
1 g
F P
s
P
p
.002 w
.46773 .36756 m .47009 .3422 L .44249 .33891 L p
1 g
F P
s
P
p
.002 w
.52511 .36376 m .52608 .35502 L .49813 .34761 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .52608 .35502 L .52511 .36376 L closepath p
1 g
F P
s
P
p
.002 w
.59 .47229 m .55714 .47787 L .55454 .50541 L p
1 g
F P
s
P
p
.002 w
.55714 .47787 m .59 .47229 L .58365 .44495 L p
1 g
F P
s
P
p
.002 w
.59008 .40885 m .57532 .4175 L .58365 .44495 L p
1 g
F P
s
P
p
.002 w
.57532 .4175 m .59008 .40885 L .57261 .38599 L p
1 g
F P
s
P
p
.002 w
.57261 .38599 m .56518 .39044 L .57532 .4175 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .56518 .39044 L .57261 .38599 L closepath p
1 g
F P
s
P
p
.002 w
.38771 .38474 m .39951 .43005 L .42292 .41712 L p
1 g
F P
s
P
p
.002 w
.42292 .41712 m .41286 .37757 L .38771 .38474 L p
1 g
F P
s
P
p
.002 w
.50561 .33232 m .49813 .34761 L .52608 .35502 L p
1 g
F P
s
P
p
.002 w
.52608 .35502 m .52994 .34732 L .50561 .33232 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .52994 .34732 L .52608 .35502 L closepath p
1 g
F P
s
P
p
.002 w
.4061 .48815 m .44583 .52387 L .46059 .50307 L p
1 g
F P
s
P
p
.002 w
.46059 .50307 m .42467 .47074 L .4061 .48815 L p
1 g
F P
s
P
p
.002 w
.50388 .52404 m .46059 .50307 L .44583 .52387 L p
1 g
F P
s
P
p
.002 w
.48087 .31959 m .47009 .3422 L .49813 .34761 L p
1 g
F P
s
P
p
.002 w
.49813 .34761 m .50561 .33232 L .48087 .31959 L p
1 g
F P
s
P
p
.002 w
.41588 .33786 m .41286 .37757 L .43972 .37182 L p
1 g
F P
s
P
p
.002 w
.43972 .37182 m .44249 .33891 L .41588 .33786 L p
1 g
F P
s
P
p
.002 w
.60549 .43245 m .58365 .44495 L .59 .47229 L p
1 g
F P
s
P
p
.002 w
.58365 .44495 m .60549 .43245 L .59008 .40885 L p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .57261 .38599 L .57793 .37925 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .57793 .37925 L .58054 .37092 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .58054 .37092 L .58014 .36191 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .58014 .36191 L .57674 .35322 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .57674 .35322 L .5707 .3458 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .5707 .3458 L .5627 .34049 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .5627 .34049 L .55363 .33787 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .55363 .33787 L .5445 .33823 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .5445 .33823 L .5363 .34151 L closepath p
1 g
F P
s
P
p
.002 w
.55341 .36428 m .5363 .34151 L .52994 .34732 L closepath p
1 g
F P
s
P
p
.002 w
.57793 .37925 m .57261 .38599 L .59008 .40885 L p
1 g
F P
s
P
p
.002 w
.37814 .44325 m .4061 .48815 L .42467 .47074 L p
1 g
F P
s
P
p
.002 w
.42467 .47074 m .39951 .43005 L .37814 .44325 L p
1 g
F P
s
P
p
.002 w
.5181 .32068 m .50561 .33232 L .52994 .34732 L p
1 g
F P
s
P
p
.002 w
.52994 .34732 m .5363 .34151 L .5181 .32068 L p
1 g
F P
s
P
p
.002 w
.5942 .49897 m .55454 .50541 L .55054 .53153 L p
1 g
F P
s
P
p
.002 w
.50388 .52404 m .55054 .53153 L .55454 .50541 L p
1 g
F P
s
P
p
.002 w
.55454 .50541 m .5942 .49897 L .59 .47229 L p
1 g
F P
s
P
p
.002 w
.60075 .39561 m .59008 .40885 L .60549 .43245 L p
1 g
F P
s
P
p
.002 w
.59008 .40885 m .60075 .39561 L .57793 .37925 L p
1 g
F P
s
P
p
.002 w
.45622 .30942 m .44249 .33891 L .47009 .3422 L p
1 g
F P
s
P
p
.002 w
.47009 .3422 m .48087 .31959 L .45622 .30942 L p
1 g
F P
s
P
p
.002 w
.58054 .37092 m .57793 .37925 L .60075 .39561 L p
1 g
F P
s
P
p
.002 w
.44583 .52387 m .49364 .54716 L .50388 .52404 L p
1 g
F P
s
P
p
.002 w
.55054 .53153 m .50388 .52404 L .49364 .54716 L p
1 g
F P
s
P
p
.002 w
.53433 .31404 m .5181 .32068 L .5363 .34151 L p
1 g
F P
s
P
p
.002 w
.5363 .34151 m .5445 .33823 L .53433 .31404 L p
1 g
F P
s
P
p
.002 w
.49914 .30225 m .48087 .31959 L .50561 .33232 L p
1 g
F P
s
P
p
.002 w
.50561 .33232 m .5181 .32068 L .49914 .30225 L p
1 g
F P
s
P
p
.002 w
.61848 .45632 m .59 .47229 L .5942 .49897 L p
1 g
F P
s
P
p
.002 w
.59 .47229 m .61848 .45632 L .60549 .43245 L p
1 g
F P
s
P
p
.002 w
.60075 .39561 m .60609 .37914 L .58054 .37092 L p
1 g
F P
s
P
p
.002 w
.58014 .36191 m .58054 .37092 L .60609 .37914 L p
1 g
F P
s
P
p
.002 w
.36481 .39322 m .37814 .44325 L .39951 .43005 L p
1 g
F P
s
P
p
.002 w
.39951 .43005 m .38771 .38474 L .36481 .39322 L p
1 g
F P
s
P
p
.002 w
.39083 .33912 m .38771 .38474 L .41286 .37757 L p
1 g
F P
s
P
p
.002 w
.41286 .37757 m .41588 .33786 L .39083 .33912 L p
1 g
F P
s
P
p
.002 w
.55252 .31322 m .53433 .31404 L .5445 .33823 L p
1 g
F P
s
P
p
.002 w
.5445 .33823 m .55363 .33787 L .55252 .31322 L p
1 g
F P
s
P
p
.002 w
.60609 .37914 m .6054 .36121 L .58014 .36191 L p
1 g
F P
s
P
p
.002 w
.57674 .35322 m .58014 .36191 L .6054 .36121 L p
1 g
F P
s
P
p
.002 w
.6214 .41309 m .60549 .43245 L .61848 .45632 L p
1 g
F P
s
P
p
.002 w
.60549 .43245 m .6214 .41309 L .60075 .39561 L p
1 g
F P
s
P
p
.002 w
.60609 .37914 m .60075 .39561 L .6214 .41309 L p
1 g
F P
s
P
p
.002 w
.57065 .31838 m .55252 .31322 L .55363 .33787 L p
1 g
F P
s
P
p
.002 w
.55363 .33787 m .5627 .34049 L .57065 .31838 L p
1 g
F P
s
P
p
.002 w
.38943 .50454 m .43207 .54284 L .44583 .52387 L p
1 g
F P
s
P
p
.002 w
.44583 .52387 m .4061 .48815 L .38943 .50454 L p
1 g
F P
s
P
p
.002 w
.49364 .54716 m .44583 .52387 L .43207 .54284 L p
1 g
F P
s
P
p
.002 w
.43215 .3021 m .41588 .33786 L .44249 .33891 L p
1 g
F P
s
P
p
.002 w
.44249 .33891 m .45622 .30942 L .43215 .3021 L p
1 g
F P
s
P
p
.002 w
.6054 .36121 m .59869 .34383 L .57674 .35322 L p
1 g
F P
s
P
p
.002 w
.5707 .3458 m .57674 .35322 L .59869 .34383 L p
1 g
F P
s
P
p
.002 w
.58665 .32899 m .57065 .31838 L .5627 .34049 L p
1 g
F P
s
P
p
.002 w
.5627 .34049 m .5707 .3458 L .58665 .32899 L p
1 g
F P
s
P
p
.002 w
.3593 .45647 m .38943 .50454 L .4061 .48815 L p
1 g
F P
s
P
p
.002 w
.4061 .48815 m .37814 .44325 L .3593 .45647 L p
1 g
F P
s
P
p
.002 w
.59869 .34383 m .58665 .32899 L .5707 .3458 L p
1 g
F P
s
P
p
.002 w
.52306 .29224 m .49914 .30225 L .5181 .32068 L p
1 g
F P
s
P
p
.002 w
.5181 .32068 m .53433 .31404 L .52306 .29224 L p
1 g
F P
s
P
p
.002 w
.47979 .28665 m .45622 .30942 L .48087 .31959 L p
1 g
F P
s
P
p
.002 w
.48087 .31959 m .49914 .30225 L .47979 .28665 L p
1 g
F P
s
P
p
.002 w
.59613 .52447 m .55054 .53153 L .5452 .55569 L p
1 g
F P
s
P
p
.002 w
.49364 .54716 m .5452 .55569 L .55054 .53153 L p
1 g
F P
s
P
p
.002 w
.55054 .53153 m .59613 .52447 L .5942 .49897 L p
1 g
F P
s
P
p
.002 w
.62874 .48001 m .5942 .49897 L .59613 .52447 L p
1 g
F P
s
P
p
.002 w
.5942 .49897 m .62874 .48001 L .61848 .45632 L p
1 g
F P
s
P
p
.002 w
.43207 .54284 m .48331 .56793 L .49364 .54716 L p
1 g
F P
s
P
p
.002 w
.5452 .55569 m .49364 .54716 L .48331 .56793 L p
1 g
F P
s
P
p
.002 w
.6214 .41309 m .62948 .38882 L .60609 .37914 L p
1 g
F P
s
P
p
.002 w
.6054 .36121 m .60609 .37914 L .62948 .38882 L p
1 g
F P
s
P
p
.002 w
.6394 .43135 m .61848 .45632 L .62874 .48001 L p
1 g
F P
s
P
p
.002 w
.61848 .45632 m .6394 .43135 L .6214 .41309 L p
1 g
F P
s
P
p
.002 w
.36792 .34275 m .36481 .39322 L .38771 .38474 L p
1 g
F P
s
P
p
.002 w
.38771 .38474 m .39083 .33912 L .36792 .34275 L p
1 g
F P
s
P
p
.002 w
.55005 .29088 m .52306 .29224 L .53433 .31404 L p
1 g
F P
s
P
p
.002 w
.53433 .31404 m .55252 .31322 L .55005 .29088 L p
1 g
F P
s
P
p
.002 w
.34475 .40289 m .3593 .45647 L .37814 .44325 L p
1 g
F P
s
P
p
.002 w
.37814 .44325 m .36481 .39322 L .34475 .40289 L p
1 g
F P
s
P
p
.002 w
.62948 .38882 m .6214 .41309 L .6394 .43135 L p
1 g
F P
s
P
p
.002 w
.40919 .29788 m .39083 .33912 L .41588 .33786 L p
1 g
F P
s
P
p
.002 w
.41588 .33786 m .43215 .3021 L .40919 .29788 L p
1 g
F P
s
P
p
.002 w
.62948 .38882 m .62863 .36225 L .6054 .36121 L p
1 g
F P
s
P
p
.002 w
.59869 .34383 m .6054 .36121 L .62863 .36225 L p
1 g
F P
s
P
p
.002 w
.5109 .27338 m .47979 .28665 L .49914 .30225 L p
1 g
F P
s
P
p
.002 w
.49914 .30225 m .52306 .29224 L .5109 .27338 L p
1 g
F P
s
P
p
.002 w
.57704 .29848 m .55005 .29088 L .55252 .31322 L p
1 g
F P
s
P
p
.002 w
.55252 .31322 m .57065 .31838 L .57704 .29848 L p
1 g
F P
s
P
p
.002 w
.46044 .27433 m .43215 .3021 L .45622 .30942 L p
1 g
F P
s
P
p
.002 w
.45622 .30942 m .47979 .28665 L .46044 .27433 L p
1 g
F P
s
P
p
.002 w
.37509 .51954 m .41963 .55951 L .43207 .54284 L p
1 g
F P
s
P
p
.002 w
.43207 .54284 m .38943 .50454 L .37509 .51954 L p
1 g
F P
s
P
p
.002 w
.48331 .56793 m .43207 .54284 L .41963 .55951 L p
1 g
F P
s
P
p
.002 w
.62863 .36225 m .61875 .33639 L .59869 .34383 L p
1 g
F P
s
P
p
.002 w
.58665 .32899 m .59869 .34383 L .61875 .33639 L p
1 g
F P
s
P
p
.002 w
.60088 .31426 m .57704 .29848 L .57065 .31838 L p
1 g
F P
s
P
p
.002 w
.57065 .31838 m .58665 .32899 L .60088 .31426 L p
1 g
F P
s
P
p
.002 w
.3435 .46943 m .37509 .51954 L .38943 .50454 L p
1 g
F P
s
P
p
.002 w
.38943 .50454 m .3593 .45647 L .3435 .46943 L p
1 g
F P
s
P
p
.002 w
.48331 .56793 m .53856 .5773 L .5452 .55569 L p
1 g
F P
s
P
p
.002 w
.59565 .5482 m .5452 .55569 L .53856 .5773 L p
1 g
F P
s
P
p
.002 w
.5452 .55569 m .59565 .5482 L .59613 .52447 L p
1 g
F P
s
P
p
.002 w
.61875 .33639 m .60088 .31426 L .58665 .32899 L p
1 g
F P
s
P
p
.002 w
.63597 .503 m .59613 .52447 L .59565 .5482 L p
1 g
F P
s
P
p
.002 w
.59613 .52447 m .63597 .503 L .62874 .48001 L p
1 g
F P
s
P
p
.002 w
.6394 .43135 m .65018 .3998 L .62948 .38882 L p
1 g
F P
s
P
p
.002 w
.62863 .36225 m .62948 .38882 L .65018 .3998 L p
1 g
F P
s
P
p
.002 w
.65428 .45003 m .62874 .48001 L .63597 .503 L p
1 g
F P
s
P
p
.002 w
.62874 .48001 m .65428 .45003 L .6394 .43135 L p
1 g
F P
s
P
p
.002 w
.41963 .55951 m .47309 .5858 L .48331 .56793 L p
1 g
F P
s
P
p
.002 w
.53856 .5773 m .48331 .56793 L .47309 .5858 L p
1 g
F P
s
P
p
.002 w
.65018 .3998 m .6394 .43135 L .65428 .45003 L p
1 g
F P
s
P
p
.002 w
.54621 .27143 m .5109 .27338 L .52306 .29224 L p
1 g
F P
s
P
p
.002 w
.52306 .29224 m .55005 .29088 L .54621 .27143 L p
1 g
F P
s
P
p
.002 w
.34775 .34877 m .34475 .40289 L .36481 .39322 L p
1 g
F P
s
P
p
.002 w
.36481 .39322 m .36792 .34275 L .34775 .34877 L p
1 g
F P
s
P
p
.002 w
.38791 .29699 m .36792 .34275 L .39083 .33912 L p
1 g
F P
s
P
p
.002 w
.39083 .33912 m .40919 .29788 L .38791 .29699 L p
1 g
F P
s
P
p
.002 w
.32807 .41358 m .3435 .46943 L .3593 .45647 L p
1 g
F P
s
P
p
.002 w
.3593 .45647 m .34475 .40289 L .32807 .41358 L p
1 g
F P
s
P
p
.002 w
.44152 .2657 m .40919 .29788 L .43215 .3021 L p
1 g
F P
s
P
p
.002 w
.43215 .3021 m .46044 .27433 L .44152 .2657 L p
1 g
F P
s
P
p
.002 w
.49808 .258 m .46044 .27433 L .47979 .28665 L p
1 g
F P
s
P
p
.002 w
.47979 .28665 m .5109 .27338 L .49808 .258 L p
1 g
F P
s
P
p
.002 w
.65018 .3998 m .64925 .36507 L .62863 .36225 L p
1 g
F P
s
P
p
.002 w
.61875 .33639 m .62863 .36225 L .64925 .36507 L p
1 g
F P
s
P
p
.002 w
.58165 .28132 m .54621 .27143 L .55005 .29088 L p
1 g
F P
s
P
p
.002 w
.55005 .29088 m .57704 .29848 L .58165 .28132 L p
1 g
F P
s
P
p
.002 w
.64925 .36507 m .63642 .33112 L .61875 .33639 L p
1 g
F P
s
P
p
.002 w
.60088 .31426 m .61875 .33639 L .63642 .33112 L p
1 g
F P
s
P
p
.002 w
.53856 .5773 m .5927 .56959 L .59565 .5482 L p
1 g
F P
s
P
p
.002 w
.63989 .52478 m .59565 .5482 L .5927 .56959 L p
1 g
F P
s
P
p
.002 w
.59565 .5482 m .63989 .52478 L .63597 .503 L p
1 g
F P
s
P
p
.002 w
.5927 .56959 m .53856 .5773 L .53072 .5958 L p
1 g
F P
s
P
p
.002 w
.47309 .5858 m .53072 .5958 L .53856 .5773 L p
1 g
F P
s
P
p
.002 w
.36348 .53273 m .40885 .57341 L .41963 .55951 L p
1 g
F P
s
P
p
.002 w
.41963 .55951 m .37509 .51954 L .36348 .53273 L p
1 g
F P
s
P
p
.002 w
.47309 .5858 m .41963 .55951 L .40885 .57341 L p
1 g
F P
s
P
p
.002 w
.61297 .30203 m .58165 .28132 L .57704 .29848 L p
1 g
F P
s
P
p
.002 w
.57704 .29848 m .60088 .31426 L .61297 .30203 L p
1 g
F P
s
P
p
.002 w
.65428 .45003 m .6676 .4119 L .65018 .3998 L p
1 g
F P
s
P
p
.002 w
.64925 .36507 m .65018 .3998 L .6676 .4119 L p
1 g
F P
s
P
p
.002 w
.33123 .48181 m .36348 .53273 L .37509 .51954 L p
1 g
F P
s
P
p
.002 w
.37509 .51954 m .3435 .46943 L .33123 .48181 L p
1 g
F P
s
P
p
.002 w
.63642 .33112 m .61297 .30203 L .60088 .31426 L p
1 g
F P
s
P
p
.002 w
.6656 .46875 m .63597 .503 L .63989 .52478 L p
1 g
F P
s
P
p
.002 w
.63597 .503 m .6656 .46875 L .65428 .45003 L p
1 g
F P
s
P
p
.002 w
.6676 .4119 m .65428 .45003 L .6656 .46875 L p
1 g
F P
s
P
p
.002 w
.54102 .25547 m .49808 .258 L .5109 .27338 L p
1 g
F P
s
P
p
.002 w
.5109 .27338 m .54621 .27143 L .54102 .25547 L p
1 g
F P
s
P
p
.002 w
.40885 .57341 m .46322 .60025 L .47309 .5858 L p
1 g
F P
s
P
p
.002 w
.53072 .5958 m .47309 .5858 L .46322 .60025 L p
1 g
F P
s
P
p
.002 w
.33092 .35716 m .32807 .41358 L .34475 .40289 L p
1 g
F P
s
P
p
.002 w
.34475 .40289 m .34775 .34877 L .33092 .35716 L p
1 g
F P
s
P
p
.002 w
.36888 .29961 m .34775 .34877 L .36792 .34275 L p
1 g
F P
s
P
p
.002 w
.36792 .34275 m .38791 .29699 L .36888 .29961 L p
1 g
F P
s
P
p
.002 w
.42351 .26114 m .38791 .29699 L .40919 .29788 L p
1 g
F P
s
P
p
.002 w
.40919 .29788 m .44152 .2657 L .42351 .26114 L p
1 g
F P
s
P
p
.002 w
.48485 .24665 m .44152 .2657 L .46044 .27433 L p
1 g
F P
s
P
p
.002 w
.46044 .27433 m .49808 .258 L .48485 .24665 L p
1 g
F P
s
P
p
.002 w
.31536 .42511 m .33123 .48181 L .3435 .46943 L p
1 g
F P
s
P
p
.002 w
.3435 .46943 m .32807 .41358 L .31536 .42511 L p
1 g
F P
s
P
p
.002 w
.6676 .4119 m .66668 .36969 L .64925 .36507 L p
1 g
F P
s
P
p
.002 w
.63642 .33112 m .64925 .36507 L .66668 .36969 L p
1 g
F P
s
P
p
.002 w
.58427 .26745 m .54102 .25547 L .54621 .27143 L p
1 g
F P
s
P
p
.002 w
.54621 .27143 m .58165 .28132 L .58427 .26745 L p
1 g
F P
s
P
p
.002 w
.53072 .5958 m .58721 .58803 L .5927 .56959 L p
1 g
F P
s
P
p
.002 w
.64026 .54477 m .5927 .56959 L .58721 .58803 L p
1 g
F P
s
P
p
.002 w
.5927 .56959 m .64026 .54477 L .63989 .52478 L p
1 g
F P
s
P
p
.002 w
.46322 .60025 m .52179 .6106 L .53072 .5958 L p
1 g
F P
s
P
p
.002 w
.58721 .58803 m .53072 .5958 L .52179 .6106 L p
1 g
F P
s
P
p
.002 w
.6656 .46875 m .6812 .42491 L .6676 .4119 L p
1 g
F P
s
P
p
.002 w
.66668 .36969 m .6676 .4119 L .6812 .42491 L p
1 g
F P
s
P
p
.002 w
.67293 .48708 m .63989 .52478 L .64026 .54477 L p
1 g
F P
s
P
p
.002 w
.63989 .52478 m .67293 .48708 L .6656 .46875 L p
1 g
F P
s
P
p
.002 w
.66668 .36969 m .65114 .32829 L .63642 .33112 L p
1 g
F P
s
P
p
.002 w
.61297 .30203 m .63642 .33112 L .65114 .32829 L p
1 g
F P
s
P
p
.002 w
.35505 .54373 m .40006 .58407 L .40885 .57341 L p
1 g
F P
s
P
p
.002 w
.40885 .57341 m .36348 .53273 L .35505 .54373 L p
1 g
F P
s
P
p
.002 w
.46322 .60025 m .40885 .57341 L .40006 .58407 L p
1 g
F P
s
P
p
.002 w
.6812 .42491 m .6656 .46875 L .67293 .48708 L p
1 g
F P
s
P
p
.002 w
.62255 .29273 m .58427 .26745 L .58165 .28132 L p
1 g
F P
s
P
p
.002 w
.58165 .28132 m .61297 .30203 L .62255 .29273 L p
1 g
F P
s
P
p
.002 w
.32299 .49331 m .35505 .54373 L .36348 .53273 L p
1 g
F P
s
P
p
.002 w
.36348 .53273 m .33123 .48181 L .32299 .49331 L p
1 g
F P
s
P
p
.002 w
.65114 .32829 m .62255 .29273 L .61297 .30203 L p
1 g
F P
s
P
p
.002 w
.53453 .24358 m .48485 .24665 L .49808 .258 L p
1 g
F P
s
P
p
.002 w
.49808 .258 m .54102 .25547 L .53453 .24358 L p
1 g
F P
s
P
p
.002 w
.31803 .36783 m .31536 .42511 L .32807 .41358 L p
1 g
F P
s
P
p
.002 w
.32807 .41358 m .33092 .35716 L .31803 .36783 L p
1 g
F P
s
P
p
.002 w
.35271 .30586 m .33092 .35716 L .34775 .34877 L p
1 g
F P
s
P
p
.002 w
.34775 .34877 m .36888 .29961 L .35271 .30586 L p
1 g
F P
s
P
p
.002 w
.40006 .58407 m .45395 .61075 L .46322 .60025 L p
1 g
F P
s
P
p
.002 w
.52179 .6106 m .46322 .60025 L .45395 .61075 L p
1 g
F P
s
P
p
.002 w
.4069 .261 m .36888 .29961 L .38791 .29699 L p
1 g
F P
s
P
p
.002 w
.38791 .29699 m .42351 .26114 L .4069 .261 L p
1 g
F P
s
P
p
.002 w
.47153 .23983 m .42351 .26114 L .44152 .2657 L p
1 g
F P
s
P
p
.002 w
.44152 .2657 m .48485 .24665 L .47153 .23983 L p
1 g
F P
s
P
p
.002 w
.30714 .43722 m .32299 .49331 L .33123 .48181 L p
1 g
F P
s
P
p
.002 w
.33123 .48181 m .31536 .42511 L .30714 .43722 L p
1 g
F P
s
P
p
.002 w
.6812 .42491 m .68032 .37612 L .66668 .36969 L p
1 g
F P
s
P
p
.002 w
.65114 .32829 m .66668 .36969 L .68032 .37612 L p
1 g
F P
s
P
p
.002 w
.58473 .2574 m .53453 .24358 L .54102 .25547 L p
1 g
F P
s
P
p
.002 w
.54102 .25547 m .58427 .26745 L .58473 .2574 L p
1 g
F P
s
P
p
.002 w
.52179 .6106 m .57919 .60293 L .58721 .58803 L p
1 g
F P
s
P
p
.002 w
.63689 .56242 m .58721 .58803 L .57919 .60293 L p
1 g
F P
s
P
p
.002 w
.58721 .58803 m .63689 .56242 L .64026 .54477 L p
1 g
F P
s
P
p
.002 w
.67587 .50454 m .64026 .54477 L .63689 .56242 L p
1 g
F P
s
P
p
.002 w
.64026 .54477 m .67587 .50454 L .67293 .48708 L p
1 g
F P
s
P
p
.002 w
.67293 .48708 m .69045 .43854 L .6812 .42491 L p
1 g
F P
s
P
p
.002 w
.68032 .37612 m .6812 .42491 L .69045 .43854 L p
1 g
F P
s
P
p
.002 w
.57919 .60293 m .52179 .6106 L .51194 .62113 L p
1 g
F P
s
P
p
.002 w
.45395 .61075 m .51194 .62113 L .52179 .6106 L p
1 g
F P
s
P
p
.002 w
.69045 .43854 m .67293 .48708 L .67587 .50454 L p
1 g
F P
s
P
p
.002 w
.68032 .37612 m .6624 .32809 L .65114 .32829 L p
1 g
F P
s
P
p
.002 w
.62255 .29273 m .65114 .32829 L .6624 .32809 L p
1 g
F P
s
P
p
.002 w
.35018 .55213 m .3936 .59103 L .40006 .58407 L p
1 g
F P
s
P
p
.002 w
.40006 .58407 m .35505 .54373 L .35018 .55213 L p
1 g
F P
s
P
p
.002 w
.45395 .61075 m .40006 .58407 L .3936 .59103 L p
1 g
F P
s
P
p
.002 w
.62921 .28677 m .58473 .2574 L .58427 .26745 L p
1 g
F P
s
P
p
.002 w
.58427 .26745 m .62255 .29273 L .62921 .28677 L p
1 g
F P
s
P
p
.002 w
.31923 .50357 m .35018 .55213 L .35505 .54373 L p
1 g
F P
s
P
p
.002 w
.35505 .54373 m .32299 .49331 L .31923 .50357 L p
1 g
F P
s
P
p
.002 w
.33997 .31577 m .31803 .36783 L .33092 .35716 L p
1 g
F P
s
P
p
.002 w
.33092 .35716 m .35271 .30586 L .33997 .31577 L p
1 g
F P
s
P
p
.002 w
.6624 .32809 m .62921 .28677 L .62255 .29273 L p
1 g
F P
s
P
p
.002 w
.52683 .2363 m .47153 .23983 L .48485 .24665 L p
1 g
F P
s
P
p
.002 w
.48485 .24665 m .53453 .24358 L .52683 .2363 L p
1 g
F P
s
P
p
.002 w
.30964 .38064 m .30714 .43722 L .31536 .42511 L p
1 g
F P
s
P
p
.002 w
.31536 .42511 m .31803 .36783 L .30964 .38064 L p
1 g
F P
s
P
p
.002 w
.39222 .26552 m .35271 .30586 L .36888 .29961 L p
1 g
F P
s
P
p
.002 w
.36888 .29961 m .4069 .261 L .39222 .26552 L p
1 g
F P
s
P
p
.002 w
.45845 .23797 m .4069 .261 L .42351 .26114 L p
1 g
F P
s
P
p
.002 w
.42351 .26114 m .47153 .23983 L .45845 .23797 L p
1 g
F P
s
P
p
.002 w
.3936 .59103 m .44554 .6168 L .45395 .61075 L p
1 g
F P
s
P
p
.002 w
.51194 .62113 m .45395 .61075 L .44554 .6168 L p
1 g
F P
s
P
p
.002 w
.3039 .44964 m .31923 .50357 L .32299 .49331 L p
1 g
F P
s
P
p
.002 w
.32299 .49331 m .30714 .43722 L .3039 .44964 L p
1 g
F P
s
P
p
.002 w
.69045 .43854 m .68959 .38428 L .68032 .37612 L p
1 g
F P
s
P
p
.002 w
.6624 .32809 m .68032 .37612 L .68959 .38428 L p
1 g
F P
s
P
p
.002 w
.51194 .62113 m .5687 .6137 L .57919 .60293 L p
1 g
F P
s
P
p
.002 w
.62965 .57712 m .57919 .60293 L .5687 .6137 L p
1 g
F P
s
P
p
.002 w
.57919 .60293 m .62965 .57712 L .63689 .56242 L p
1 g
F P
s
P
p
.002 w
.58288 .2517 m .52683 .2363 L .53453 .24358 L p
1 g
F P
s
P
p
.002 w
.53453 .24358 m .58473 .2574 L .58288 .2517 L p
1 g
F P
s
P
p
.002 w
.67413 .52063 m .63689 .56242 L .62965 .57712 L p
1 g
F P
s
P
p
.002 w
.63689 .56242 m .67413 .52063 L .67587 .50454 L p
1 g
F P
s
P
p
.002 w
.67587 .50454 m .69484 .45248 L .69045 .43854 L p
1 g
F P
s
P
p
.002 w
.68959 .38428 m .69045 .43854 L .69484 .45248 L p
1 g
F P
s
P
p
.002 w
.69484 .45248 m .67587 .50454 L .67413 .52063 L p
1 g
F P
s
P
p
.002 w
.44554 .6168 m .50136 .62687 L .51194 .62113 L p
1 g
F P
s
P
p
.002 w
.5687 .6137 m .51194 .62113 L .50136 .62687 L p
1 g
F P
s
P
p
.002 w
.68959 .38428 m .66967 .33069 L .6624 .32809 L p
1 g
F P
s
P
p
.002 w
.62921 .28677 m .6624 .32809 L .66967 .33069 L p
1 g
F P
s
P
p
.002 w
.33122 .32928 m .30964 .38064 L .31803 .36783 L p
1 g
F P
s
P
p
.002 w
.31803 .36783 m .33997 .31577 L .33122 .32928 L p
1 g
F P
s
P
p
.002 w
.34923 .55754 m .38979 .59388 L .3936 .59103 L p
1 g
F P
s
P
p
.002 w
.3936 .59103 m .35018 .55213 L .34923 .55754 L p
1 g
F P
s
P
p
.002 w
.44554 .6168 m .3936 .59103 L .38979 .59388 L p
1 g
F P
s
P
p
.002 w
.6326 .28451 m .58288 .2517 L .58473 .2574 L p
1 g
F P
s
P
p
.002 w
.58473 .2574 m .62921 .28677 L .6326 .28451 L p
1 g
F P
s
P
p
.002 w
.51806 .23414 m .45845 .23797 L .47153 .23983 L p
1 g
F P
s
P
p
.002 w
.47153 .23983 m .52683 .2363 L .51806 .23414 L p
1 g
F P
s
P
p
.002 w
.37998 .27485 m .33997 .31577 L .35271 .30586 L p
1 g
F P
s
P
p
.002 w
.35271 .30586 m .39222 .26552 L .37998 .27485 L p
1 g
F P
s
P
p
.002 w
.32032 .51223 m .34923 .55754 L .35018 .55213 L p
1 g
F P
s
P
p
.002 w
.35018 .55213 m .31923 .50357 L .32032 .51223 L p
1 g
F P
s
P
p
.002 w
.30626 .39535 m .3039 .44964 L .30714 .43722 L p
1 g
F P
s
P
p
.002 w
.30714 .43722 m .30964 .38064 L .30626 .39535 L p
1 g
F P
s
P
p
.002 w
.66967 .33069 m .6326 .28451 L .62921 .28677 L p
1 g
F P
s
P
p
.002 w
.44601 .24145 m .39222 .26552 L .4069 .261 L p
1 g
F P
s
P
p
.002 w
.4069 .261 m .45845 .23797 L .44601 .24145 L p
1 g
F P
s
P
p
.002 w
.38979 .59388 m .43828 .61795 L .44554 .6168 L p
1 g
F P
s
P
p
.002 w
.50136 .62687 m .44554 .6168 L .43828 .61795 L p
1 g
F P
s
P
p
.002 w
.30604 .46203 m .32032 .51223 L .31923 .50357 L p
1 g
F P
s
P
p
.002 w
.31923 .50357 m .3039 .44964 L .30604 .46203 L p
1 g
F P
s
P
p
.002 w
.69484 .45248 m .69399 .39407 L .68959 .38428 L p
1 g
F P
s
P
p
.002 w
.66967 .33069 m .68959 .38428 L .69399 .39407 L p
1 g
F P
s
P
p
.002 w
.50136 .62687 m .55588 .6198 L .5687 .6137 L p
1 g
F P
s
P
p
.002 w
.5687 .6137 m .61853 .58832 L .62965 .57712 L p
1 g
F P
s
P
p
.002 w
.61853 .58832 m .5687 .6137 L .55588 .6198 L p
1 g
F P
s
P
p
.004 w
.37719 .70301 m
.41352 .62241 L
s
P
p
.002 w
.62965 .57712 m .66746 .53484 L .67413 .52063 L p
1 g
F P
s
P
p
.002 w
.66746 .53484 m .62965 .57712 L .61853 .58832 L p
1 g
F P
s
P
p
.002 w
.57861 .25077 m .51806 .23414 L .52683 .2363 L p
1 g
F P
s
P
p
.002 w
.52683 .2363 m .58288 .2517 L .57861 .25077 L p
1 g
F P
s
P
p
.002 w
.67413 .52063 m .69398 .46636 L .69484 .45248 L p
1 g
F P
s
P
p
.002 w
.69398 .46636 m .67413 .52063 L .66746 .53484 L p
1 g
F P
s
P
p
.002 w
.69399 .39407 m .69484 .45248 L .69398 .46636 L p
1 g
F P
s
P
p
.002 w
.43828 .61795 m .4903 .62736 L .50136 .62687 L p
1 g
F P
s
P
p
.002 w
.55588 .6198 m .50136 .62687 L .4903 .62736 L p
1 g
F P
s
P
p
.002 w
.32696 .3462 m .30626 .39535 L .30964 .38064 L p
1 g
F P
s
P
p
.002 w
.30964 .38064 m .33122 .32928 L .32696 .3462 L p
1 g
F P
s
P
p
.002 w
.69399 .39407 m .67249 .33621 L .66967 .33069 L p
1 g
F P
s
P
p
.002 w
.6326 .28451 m .66967 .33069 L .67249 .33621 L p
1 g
F P
s
P
p
.002 w
.3707 .28901 m .33122 .32928 L .33997 .31577 L p
1 g
F P
s
P
p
.002 w
.33997 .31577 m .37998 .27485 L .3707 .28901 L p
1 g
F P
s
P
p
.002 w
.50839 .23748 m .44601 .24145 L .45845 .23797 L p
1 g
F P
s
P
p
.002 w
.45845 .23797 m .51806 .23414 L .50839 .23748 L p
1 g
F P
s
P
p
.002 w
.30827 .41164 m .30604 .46203 L .3039 .44964 L p
1 g
F P
s
P
p
.002 w
.3039 .44964 m .30626 .39535 L .30827 .41164 L p
1 g
F P
s
P
p
.002 w
.35248 .5596 m .38892 .59224 L .38979 .59388 L p
1 g
F P
s
P
p
.002 w
.38979 .59388 m .34923 .55754 L .35248 .5596 L p
1 g
F P
s
P
p
.002 w
.43828 .61795 m .38979 .59388 L .38892 .59224 L p
1 g
F P
s
P
p
.002 w
.4346 .25049 m .37998 .27485 L .39222 .26552 L p
1 g
F P
s
P
p
.002 w
.39222 .26552 m .44601 .24145 L .4346 .25049 L p
1 g
F P
s
P
p
.002 w
.6324 .28628 m .57861 .25077 L .58288 .2517 L p
1 g
F P
s
P
p
.002 w
.58288 .2517 m .6326 .28451 L .6324 .28628 L p
1 g
F P
s
P
p
.002 w
.32656 .51896 m .35248 .5596 L .34923 .55754 L p
1 g
F P
s
P
p
.002 w
.34923 .55754 m .32032 .51223 L .32656 .51896 L p
1 g
F P
s
P
p
.002 w
.67249 .33621 m .6324 .28628 L .6326 .28451 L p
1 g
F P
s
P
p
.002 w
.38892 .59224 m .43245 .61385 L .43828 .61795 L p
1 g
F P
s
P
p
.004 w
.42013 .60774 m
.5 .43051 L
s
P
p
.004 w
.41921 .60978 m
.4198 .60846 L
s
P
p
.004 w
.41352 .62241 m
.41921 .60978 L
s
P
p
.002 w
.4903 .62736 m .43828 .61795 L .43245 .61385 L p
1 g
F P
s
P
p
.002 w
.31382 .47402 m .32656 .51896 L .32032 .51223 L p
1 g
F P
s
P
p
.002 w
.32032 .51223 m .30604 .46203 L .31382 .47402 L p
1 g
F P
s
P
p
.002 w
.69398 .46636 m .69307 .4053 L .69399 .39407 L p
1 g
F P
s
P
p
.002 w
.67249 .33621 m .69399 .39407 L .69307 .4053 L p
1 g
F P
s
P
p
.002 w
.55588 .6198 m .60361 .59548 L .61853 .58832 L p
1 g
F P
s
P
p
.002 w
.65577 .54664 m .61853 .58832 L .60361 .59548 L p
1 g
F P
s
P
p
.002 w
.61853 .58832 m .65577 .54664 L .66746 .53484 L p
1 g
F P
s
P
p
.002 w
.4903 .62736 m .54096 .62078 L .55588 .6198 L p
1 g
F P
s
P
p
.002 w
.60361 .59548 m .55588 .6198 L .54096 .62078 L p
1 g
F P
s
P
p
.002 w
.68757 .47979 m .66746 .53484 L .65577 .54664 L p
1 g
F P
s
P
p
.002 w
.66746 .53484 m .68757 .47979 L .69398 .46636 L p
1 g
F P
s
P
p
.002 w
.69307 .4053 m .69398 .46636 L .68757 .47979 L p
1 g
F P
s
P
p
.002 w
.57189 .25498 m .50839 .23748 L .51806 .23414 L p
1 g
F P
s
P
p
.002 w
.51806 .23414 m .57861 .25077 L .57189 .25498 L p
1 g
F P
s
P
p
.002 w
.54096 .62078 m .4903 .62736 L .47905 .62226 L p
1 g
F P
s
P
p
.002 w
.43245 .61385 m .47905 .62226 L .4903 .62736 L p
1 g
F P
s
P
p
.002 w
.32757 .36621 m .30827 .41164 L .30626 .39535 L p
1 g
F P
s
P
p
.002 w
.30626 .39535 m .32696 .3462 L .32757 .36621 L p
1 g
F P
s
P
p
.002 w
.36484 .30782 m .32696 .3462 L .33122 .32928 L p
1 g
F P
s
P
p
.002 w
.33122 .32928 m .3707 .28901 L .36484 .30782 L p
1 g
F P
s
P
p
.002 w
.49807 .24657 m .4346 .25049 L .44601 .24145 L p
1 g
F P
s
P
p
.002 w
.44601 .24145 m .50839 .23748 L .49807 .24657 L p
1 g
F P
s
P
p
.002 w
.69307 .4053 m .67049 .34468 L .67249 .33621 L p
1 g
F P
s
P
p
.002 w
.6324 .28628 m .67249 .33621 L .67049 .34468 L p
1 g
F P
s
P
p
.002 w
.42466 .26513 m .3707 .28901 L .37998 .27485 L p
1 g
F P
s
P
p
.002 w
.37998 .27485 m .4346 .25049 L .42466 .26513 L p
1 g
F P
s
P
p
.002 w
.31593 .4291 m .31382 .47402 L .30604 .46203 L p
1 g
F P
s
P
p
.002 w
.30604 .46203 m .30827 .41164 L .31593 .4291 L p
1 g
F P
s
P
p
.002 w
.36013 .55805 m .3912 .58589 L .38892 .59224 L p
1 g
F P
s
P
p
.002 w
.38892 .59224 m .35248 .5596 L .36013 .55805 L p
1 g
F P
s
P
p
.002 w
.43245 .61385 m .38892 .59224 L .3912 .58589 L p
1 g
F P
s
P
p
.002 w
.62837 .29228 m .57189 .25498 L .57861 .25077 L p
1 g
F P
s
P
p
.002 w
.57861 .25077 m .6324 .28628 L .62837 .29228 L p
1 g
F P
s
P
p
.002 w
.33808 .5234 m .36013 .55805 L .35248 .5596 L p
1 g
F P
s
P
p
.002 w
.35248 .5596 m .32656 .51896 L .33808 .5234 L p
1 g
F P
s
P
p
.002 w
.67049 .34468 m .62837 .29228 L .6324 .28628 L p
1 g
F P
s
P
p
.002 w
.3912 .58589 m .42832 .60429 L .43245 .61385 L p
1 g
F P
s
P
p
.002 w
.47905 .62226 m .43245 .61385 L .42832 .60429 L p
1 g
F P
s
P
p
.002 w
.54096 .62078 m .58514 .59816 L .60361 .59548 L p
1 g
F P
s
P
p
.002 w
.63914 .55553 m .60361 .59548 L .58514 .59816 L p
1 g
F P
s
P
p
.002 w
.60361 .59548 m .63914 .55553 L .65577 .54664 L p
1 g
F P
s
P
p
.002 w
.68757 .47979 m .68653 .41773 L .69307 .4053 L p
1 g
F P
s
P
p
.002 w
.67049 .34468 m .69307 .4053 L .68653 .41773 L p
1 g
F P
s
P
p
.002 w
.32735 .48522 m .33808 .5234 L .32656 .51896 L p
1 g
F P
s
P
p
.002 w
.32656 .51896 m .31382 .47402 L .32735 .48522 L p
1 g
F P
s
P
p
.002 w
.47905 .62226 m .52428 .61629 L .54096 .62078 L p
1 g
F P
s
P
p
.002 w
.58514 .59816 m .54096 .62078 L .52428 .61629 L p
1 g
F P
s
P
p
.002 w
.67547 .49231 m .65577 .54664 L .63914 .55553 L p
1 g
F P
s
P
p
.002 w
.65577 .54664 m .67547 .49231 L .68757 .47979 L p
1 g
F P
s
P
p
.002 w
.68653 .41773 m .68757 .47979 L .67547 .49231 L p
1 g
F P
s
P
p
.002 w
.56277 .26452 m .49807 .24657 L .50839 .23748 L p
1 g
F P
s
P
p
.002 w
.50839 .23748 m .57189 .25498 L .56277 .26452 L p
1 g
F P
s
P
p
.002 w
.52428 .61629 m .47905 .62226 L .46795 .61137 L p
1 g
F P
s
P
p
.002 w
.42832 .60429 m .46795 .61137 L .47905 .62226 L p
1 g
F P
s
P
p
.002 w
.33329 .38881 m .31593 .4291 L .30827 .41164 L p
1 g
F P
s
P
p
.002 w
.30827 .41164 m .32757 .36621 L .33329 .38881 L p
1 g
F P
s
P
p
.002 w
.36278 .33092 m .32757 .36621 L .32696 .3462 L p
1 g
F P
s
P
p
.002 w
.32696 .3462 m .36484 .30782 L .36278 .33092 L p
1 g
F P
s
P
p
.002 w
.41659 .28522 m .36484 .30782 L .3707 .28901 L p
1 g
F P
s
P
p
.002 w
.3707 .28901 m .42466 .26513 L .41659 .28522 L p
1 g
F P
s
P
p
.002 w
.48741 .26147 m .42466 .26513 L .4346 .25049 L p
1 g
F P
s
P
p
.002 w
.4346 .25049 m .49807 .24657 L .48741 .26147 L p
1 g
F P
s
P
p
.002 w
.3293 .44722 m .32735 .48522 L .31382 .47402 L p
1 g
F P
s
P
p
.002 w
.31382 .47402 m .31593 .4291 L .3293 .44722 L p
1 g
F P
s
P
p
.002 w
.68653 .41773 m .66341 .35602 L .67049 .34468 L p
1 g
F P
s
P
p
.002 w
.62837 .29228 m .67049 .34468 L .66341 .35602 L p
1 g
F P
s
P
p
.002 w
.62039 .3026 m .56277 .26452 L .57189 .25498 L p
1 g
F P
s
P
p
.002 w
.57189 .25498 m .62837 .29228 L .62039 .3026 L p
1 g
F P
s
P
p
.002 w
.37221 .55267 m .39678 .5747 L .3912 .58589 L p
1 g
F P
s
P
p
.002 w
.3912 .58589 m .36013 .55805 L .37221 .55267 L p
1 g
F P
s
P
p
.002 w
.42832 .60429 m .3912 .58589 L .39678 .5747 L p
1 g
F P
s
P
p
.002 w
.35485 .52529 m .37221 .55267 L .36013 .55805 L p
1 g
F P
s
P
p
.002 w
.36013 .55805 m .33808 .5234 L .35485 .52529 L p
1 g
F P
s
P
p
.002 w
.66341 .35602 m .62039 .3026 L .62837 .29228 L p
1 g
F P
s
P
p
.002 w
.52428 .61629 m .5635 .596 L .58514 .59816 L p
1 g
F P
s
P
p
.002 w
.61782 .56106 m .58514 .59816 L .5635 .596 L p
1 g
F P
s
P
p
.002 w
.58514 .59816 m .61782 .56106 L .63914 .55553 L p
1 g
F P
s
P
p
.002 w
.39678 .5747 m .42612 .5892 L .42832 .60429 L p
1 g
F P
s
P
p
.002 w
.46795 .61137 m .42832 .60429 L .42612 .5892 L p
1 g
F P
s
P
p
.002 w
.46795 .61137 m .50626 .60617 L .52428 .61629 L p
1 g
F P
s
P
p
.002 w
.5635 .596 m .52428 .61629 L .50626 .60617 L p
1 g
F P
s
P
p
.002 w
.65775 .50348 m .63914 .55553 L .61782 .56106 L p
1 g
F P
s
P
p
.002 w
.63914 .55553 m .65775 .50348 L .67547 .49231 L p
1 g
F P
s
P
p
.002 w
.67547 .49231 m .67424 .43102 L .68653 .41773 L p
1 g
F P
s
P
p
.002 w
.66341 .35602 m .68653 .41773 L .67424 .43102 L p
1 g
F P
s
P
p
.002 w
.34651 .4952 m .35485 .52529 L .33808 .5234 L p
1 g
F P
s
P
p
.002 w
.33808 .5234 m .32735 .48522 L .34651 .4952 L p
1 g
F P
s
P
p
.002 w
.67424 .43102 m .67547 .49231 L .65775 .50348 L p
1 g
F P
s
P
p
.002 w
.3442 .41335 m .3293 .44722 L .31593 .4291 L p
1 g
F P
s
P
p
.002 w
.31593 .4291 m .33329 .38881 L .3442 .41335 L p
1 g
F P
s
P
p
.002 w
.36478 .35773 m .33329 .38881 L .32757 .36621 L p
1 g
F P
s
P
p
.002 w
.32757 .36621 m .36278 .33092 L .36478 .35773 L p
1 g
F P
s
P
p
.002 w
.55142 .27939 m .48741 .26147 L .49807 .24657 L p
1 g
F P
s
P
p
.002 w
.49807 .24657 m .56277 .26452 L .55142 .27939 L p
1 g
F P
s
P
p
.002 w
.50626 .60617 m .46795 .61137 L .45738 .5947 L p
1 g
F P
s
P
p
.002 w
.42612 .5892 m .45738 .5947 L .46795 .61137 L p
1 g
F P
s
P
p
.002 w
.41077 .31035 m .36278 .33092 L .36484 .30782 L p
1 g
F P
s
P
p
.002 w
.36484 .30782 m .41659 .28522 L .41077 .31035 L p
1 g
F P
s
P
p
.002 w
.47674 .282 m .41659 .28522 L .42466 .26513 L p
1 g
F P
s
P
p
.002 w
.42466 .26513 m .48741 .26147 L .47674 .282 L p
1 g
F P
s
P
p
.002 w
.34823 .46542 m .34651 .4952 L .32735 .48522 L p
1 g
F P
s
P
p
.002 w
.32735 .48522 m .3293 .44722 L .34823 .46542 L p
1 g
F P
s
P
p
.002 w
.67424 .43102 m .65118 .37003 L .66341 .35602 L p
1 g
F P
s
P
p
.002 w
.62039 .3026 m .66341 .35602 L .65118 .37003 L p
1 g
F P
s
P
p
.002 w
.60849 .31717 m .55142 .27939 L .56277 .26452 L p
1 g
F P
s
P
p
.002 w
.56277 .26452 m .62039 .3026 L .60849 .31717 L p
1 g
F P
s
P
p
.002 w
.38859 .54343 m .40566 .55875 L .39678 .5747 L p
1 g
F P
s
P
p
.002 w
.39678 .5747 m .37221 .55267 L .38859 .54343 L p
1 g
F P
s
P
p
.002 w
.42612 .5892 m .39678 .5747 L .40566 .55875 L p
1 g
F P
s
P
p
.002 w
.50626 .60617 m .53926 .58884 L .5635 .596 L p
1 g
F P
s
P
p
.002 w
.59229 .56287 m .5635 .596 L .53926 .58884 L p
1 g
F P
s
P
p
.002 w
.5635 .596 m .59229 .56287 L .61782 .56106 L p
1 g
F P
s
P
p
.002 w
.37659 .5244 m .38859 .54343 L .37221 .55267 L p
1 g
F P
s
P
p
.002 w
.37221 .55267 m .35485 .52529 L .37659 .5244 L p
1 g
F P
s
P
p
.002 w
.63472 .51283 m .61782 .56106 L .59229 .56287 L p
1 g
F P
s
P
p
.002 w
.61782 .56106 m .63472 .51283 L .65775 .50348 L p
1 g
F P
s
P
p
.002 w
.45738 .5947 m .48744 .59047 L .50626 .60617 L p
1 g
F P
s
P
p
.002 w
.53926 .58884 m .50626 .60617 L .48744 .59047 L p
1 g
F P
s
P
p
.002 w
.65118 .37003 m .60849 .31717 L .62039 .3026 L p
1 g
F P
s
P
p
.002 w
.40566 .55875 m .42606 .56879 L .42612 .5892 L p
1 g
F P
s
P
p
.002 w
.45738 .5947 m .42612 .5892 L .42606 .56879 L p
1 g
F P
s
P
p
.002 w
.65775 .50348 m .65628 .44478 L .67424 .43102 L p
1 g
F P
s
P
p
.002 w
.65118 .37003 m .67424 .43102 L .65628 .44478 L p
1 g
F P
s
P
p
.002 w
.65628 .44478 m .65775 .50348 L .63472 .51283 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.37092 .50356 m .37659 .5244 L .35485 .52529 L p
1 g
F P
s
P
p
.002 w
.35485 .52529 m .34651 .4952 L .37092 .50356 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37094 .38745 m .3442 .41335 L .33329 .38881 L p
1 g
F P
s
P
p
.002 w
.33329 .38881 m .36478 .35773 L .37094 .38745 L p
1 g
F P
s
P
p
.002 w
.36011 .43906 m .34823 .46542 L .3293 .44722 L p
1 g
F P
s
P
p
.002 w
.3293 .44722 m .3442 .41335 L .36011 .43906 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.48744 .59047 m .45738 .5947 L .44773 .57251 L p
1 g
F P
s
P
p
.002 w
.42606 .56879 m .44773 .57251 L .45738 .5947 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.40751 .33984 m .36478 .35773 L .36278 .33092 L p
1 g
F P
s
P
p
.002 w
.36278 .33092 m .41077 .31035 L .40751 .33984 L p
1 g
F P
s
P
p
.002 w
.5381 .29939 m .47674 .282 L .48741 .26147 L p
1 g
F P
s
P
p
.002 w
.48741 .26147 m .55142 .27939 L .5381 .29939 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.46645 .3077 m .41077 .31035 L .41659 .28522 L p
1 g
F P
s
P
p
.002 w
.41659 .28522 m .47674 .282 L .46645 .3077 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.37227 .48305 m .37092 .50356 L .34651 .4952 L p
1 g
F P
s
P
p
.002 w
.34651 .4952 m .34823 .46542 L .37227 .48305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48744 .59047 m .50157 .5829 L p
.53926 .58884 L 1 g
F P
s
P
p
.002 w
.50157 .5829 m .50516 .58098 L p
.50748 .58151 L 1 g
F P
s
P
p
.53926 .58884 m .50157 .5829 L .50748 .58151 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .5807 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .5807 L .51813 .57901 L 1 g
F
P
p
.002 w
.56107 .5633 m .53926 .58884 L .52149 .58057 L p
1 g
F P
s
P
p
.002 w
.52149 .58057 m .51813 .57901 L p
.53159 .57408 L 1 g
F P
s
P
p
.56107 .5633 m .52149 .58057 L .53159 .57408 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53159 .57408 L p
1 g
F P
s
P
p
.54854 .56129 m .53159 .57408 L .54242 .56712 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56326 .56073 m .56107 .5633 L p
.53859 .56958 L 1 g
F P
s
P
p
.54166 .56761 m .53859 .56958 L .51315 .5767 L 1 g
F
P
p
.56326 .56073 m .53859 .56958 L .54166 .56761 L 1 g
F
P
p
.53128 .57265 m .51813 .57901 L .52078 .57804 L 1 g
F
P
p
.002 w
.51094 .5807 m .51079 .57862 L p
.49993 .58079 L 1 g
F P
s
P
p
.002 w
.48744 .59047 m .478 .58002 L p
.48908 .58041 L 1 g
F P
s
P
p
.002 w
.50516 .58098 m .5007 .58336 L p
.48908 .58041 L 1 g
F P
s
P
p
.002 w
.5007 .58336 m .48744 .59047 L p
.48908 .58041 L 1 g
F P
s
P
p
.002 w
.48908 .58041 m .48921 .57862 L p
.4786 .57775 L 1 g
F P
s
P
p
.49993 .58079 m .50516 .58098 L .51094 .5807 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46829 .57464 L p
1 g
F P
s
P
p
.48744 .59047 m .45739 .57109 L .46829 .57464 L 1 g
F
P
p
.002 w
.47516 .57688 m .47835 .5804 L p
.46829 .57464 L 1 g
F P
s
P
p
.002 w
.47835 .5804 m .48744 .59047 L p
.46829 .57464 L 1 g
F P
s
P
p
.002 w
.46829 .57464 m .46872 .57265 L p
.45831 .56849 L 1 g
F P
s
P
p
.002 w
.44773 .57251 m .44311 .55747 L p
.45081 .56305 L 1 g
F P
s
P
p
.002 w
.46113 .57053 m .45738 .57109 L p
.45081 .56305 L 1 g
F P
s
P
p
.002 w
.45738 .57109 m .44773 .57251 L p
.45081 .56305 L 1 g
F P
s
P
p
.002 w
.45081 .56305 m .45146 .56129 L p
.44423 .555 L 1 g
F P
s
P
p
.45831 .56849 m .46113 .57053 L .46829 .57464 L 1 g
F
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45033 .56434 L p
1 g
F P
s
P
p
.46872 .57265 m .45033 .56434 L .45585 .56751 L 1 g
F
P
p
.48921 .57862 m .46829 .57464 L .47135 .57563 L 1 g
F
P
p
.48921 .57862 m .46818 .5751 L .4786 .57775 L 1 g
F
P
p
.002 w
.46845 .56945 m .47516 .57688 L p
.46829 .57464 L 1 g
F P
s
P
p
.002 w
.45739 .57109 m .46113 .57053 L p
.46829 .57464 L 1 g
F P
s
P
p
.002 w
.46113 .57053 m .46845 .56945 L p
.46829 .57464 L 1 g
F P
s
P
p
.002 w
.45033 .56434 m .45002 .56518 L p
.45585 .56751 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43825 .54754 L p
1 g
F P
s
P
p
.44773 .57251 m .4361 .54478 L .43825 .54754 L 1 g
F
P
p
.002 w
.44123 .55134 m .44645 .56833 L p
.43825 .54754 L 1 g
F P
s
P
p
.002 w
.44645 .56833 m .44773 .57251 L p
.43825 .54754 L 1 g
F P
s
P
p
.43925 .54566 m .43502 .53728 L .43505 .53742 L 1 g
F
P
p
.002 w
.42825 .54348 m .43118 .52405 L p
.43253 .5287 L 1 g
F P
s
P
p
.002 w
.43724 .54498 m .43173 .54406 L p
.43253 .5287 L 1 g
F P
s
P
p
.002 w
.43173 .54406 m .42825 .54348 L p
.43253 .5287 L 1 g
F P
s
P
p
.002 w
.43825 .54754 m .43925 .54566 L p
.43505 .53742 L 1 g
F P
s
P
p
.43505 .53742 m .43155 .53053 L .43724 .54498 L 1 g
F
P
p
.43505 .53742 m .43724 .54498 L .43825 .54754 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43367 .47988 m .43694 .48091 L p
.43309 .51097 L 1 g
F P
s
P
p
.002 w
.43277 .51163 m .43367 .47988 L p
.43309 .51097 L 1 g
F P
s
P
p
.002 w
.43379 .50952 m .43485 .50826 L p
.43837 .50002 L 1 g
F P
s
P
p
.002 w
.43777 .50126 m .4449 .48341 L p
.43893 .49887 L 1 g
F P
s
P
p
.43837 .50002 m .43838 .50001 L .43777 .50126 L 1 g
F
P
p
.43837 .50002 m .43777 .50126 L .43379 .50952 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43379 .50952 L p
1 g
F P
s
P
p
.43346 .52734 m .43379 .50952 L .43378 .50959 L 1 g
F
P
p
.002 w
.43353 .51191 m .43271 .51396 L p
.43694 .48091 L 1 g
F P
s
P
p
.43346 .52734 m .43378 .50953 L .43376 .50975 L 1 g
F
P
p
.43346 .52734 m .43376 .50955 L .43372 .50993 L 1 g
F
P
p
.43346 .52734 m .43373 .50959 L .43368 .5101 L 1 g
F
P
p
.43346 .52734 m .43369 .50964 L .43363 .51025 L 1 g
F
P
p
.43346 .52734 m .43364 .5097 L .43359 .51036 L 1 g
F
P
p
.43346 .52734 m .43359 .50976 L .43355 .5104 L 1 g
F
P
p
.002 w
.43338 .51324 m .43271 .51396 L .43353 .51191 L p
1 g
F P
s
P
p
.43346 .52734 m .43355 .5098 L .43352 .51034 L 1 g
F
P
p
.43346 .52734 m .43352 .50984 L .4335 .51017 L 1 g
F
P
p
.002 w
.43334 .51365 m .43271 .51396 L .43338 .51324 L p
1 g
F P
s
P
p
.002 w
.43332 .51389 m .43271 .51396 L .43334 .51365 L p
1 g
F P
s
P
p
.43346 .52734 m .43351 .50986 L .43311 .51741 L 1 g
F
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43694 .48091 m .4449 .48341 L .43777 .50126 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44253 .49142 L p
1 g
F P
s
P
p
.002 w
.4449 .48341 m .44603 .48417 L p
.44253 .49142 L 1 g
F P
s
P
p
.44138 .49253 m .44253 .49142 L .43893 .49887 L 1 g
F
P
p
.4449 .48341 m .44253 .49142 L .44138 .49253 L 1 g
F
P
p
.002 w
.44253 .49142 m .44252 .49142 L p
.44247 .49154 L 1 g
F P
s
P
p
.43485 .50826 m .44253 .49142 L .44247 .49154 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44253 .49142 m .44339 .4905 L p
.45124 .48298 L 1 g
F P
s
P
p
.002 w
.45492 .49016 m .44838 .48576 L p
.45616 .47819 L 1 g
F P
s
P
p
.45124 .48298 m .45361 .48071 L .44838 .48576 L 1 g
F
P
p
.45124 .48298 m .44838 .48576 L .44253 .49142 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43485 .50826 m .44252 .49142 L .43838 .50001 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.44253 .49142 m .45492 .49016 L .43893 .49887 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45768 .47671 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45616 .47819 m .4614 .47494 L .45492 .49016 L 1 g
F
P
p
.002 w
.45768 .47671 m .45826 .47608 L p
.4679 .47185 L 1 g
F P
s
P
p
.002 w
.47477 .46859 m .45492 .49016 L p
.4614 .47494 L 1 g
F P
s
P
p
.002 w
.46262 .49936 m .45492 .49016 L .47477 .46859 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47749 .46728 L p
1 g
F P
s
P
p
.45826 .47608 m .47749 .46728 L .47695 .46754 L 1 g
F
P
p
.47742 .46731 m .46262 .49936 L .47477 .46859 L 1 g
F
P
p
.45826 .47608 m .47695 .46754 L .4679 .47185 L 1 g
F
P
p
.002 w
.49414 .4824 m .46262 .49936 L p
.47742 .46731 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47749 .46728 m .49414 .4824 L .47742 .46731 L 1 g
F
P
p
.002 w
.47749 .46728 m .47786 .46667 L p
.48916 .46552 L 1 g
F P
s
P
p
.002 w
.49414 .4824 m .48116 .46679 L p
.498 .46412 L 1 g
F P
s
P
p
.48916 .46552 m .49554 .46487 L .48116 .46679 L 1 g
F
P
p
.48916 .46552 m .48116 .46679 L .47749 .46728 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50295 .50352 m .49414 .4824 L .52046 .46697 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46726 L p
1 g
F P
s
P
p
.5 .4634 m .52249 .46726 L .52157 .46713 L 1 g
F
P
p
.5 .4634 m .52251 .46729 L .51071 .46546 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52606 .46369 m .55713 .44396 L p
.54489 .47784 L 1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56581 .50904 L p
1 g
F P
s
P
p
.57324 .48403 m .57322 .52461 L .56581 .50904 L 1 g
F
P
p
.5645 .49534 m .56581 .50904 L .56127 .49951 L 1 g
F
P
p
.57324 .48403 m .56581 .50904 L .5645 .49534 L 1 g
F
P
p
.002 w
.56581 .50904 m .56515 .50826 L p
.56669 .51826 L 1 g
F P
s
P
p
.55661 .4905 m .56581 .50904 L .56076 .49844 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52865 L p
1 g
F P
s
P
p
.5752 .52451 m .56747 .52984 L .56744 .52865 L 1 g
F
P
p
.002 w
.56733 .5249 m .56871 .52483 L p
.56744 .52865 L 1 g
F P
s
P
p
.002 w
.56871 .52483 m .5752 .52451 L p
.56744 .52865 L 1 g
F P
s
P
p
.002 w
.56744 .52865 m .56654 .52734 L p
.56491 .53629 L 1 g
F P
s
P
p
.56515 .50826 m .56744 .52865 L .56737 .52614 L 1 g
F
P
p
.56515 .50826 m .56773 .52907 L .56669 .51826 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56139 .54687 L p
1 g
F P
s
P
p
.56654 .52734 m .56139 .54687 L .56491 .53629 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56744 .52865 m .53164 .55456 L .56733 .5249 L 1 g
F
P
p
.56747 .52984 m .56692 .53022 L .56744 .52865 L 1 g
F
P
p
.56692 .53022 m .53164 .55456 L .56744 .52865 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.5752 .52451 m .57332 .53022 L p
.53164 .55456 L 1 g
F P
s
P
p
.002 w
.57332 .53022 m .56326 .56073 L .55291 .55871 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56282 L p
1 g
F P
s
P
p
.002 w
.55291 .55871 m .56326 .56073 L p
.54595 .56624 L 1 g
F P
s
P
p
.002 w
.54911 .56282 m .5494 .56361 L p
.55161 .56012 L 1 g
F P
s
P
p
.56075 .54566 m .54911 .56282 L .55161 .56012 L 1 g
F
P
p
.56075 .54566 m .5494 .56361 L .55569 .55483 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.51315 .5767 m .53164 .55456 L .55291 .55871 L p
1 g
F P
s
P
p
.002 w
.54911 .56282 m .54854 .56129 L p
.54242 .56712 L 1 g
F P
s
P
p
.54595 .56624 m .51315 .5767 L .55291 .55871 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55291 .55871 m .53164 .55456 L p
.57332 .53022 L 1 g
F P
s
P
p
.002 w
.5494 .56361 m .54998 .56518 L p
.55569 .55483 L 1 g
F P
s
P
p
.002 w
.56139 .54687 m .56257 .5491 L p
.56491 .53629 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56744 .52865 L p
1 g
F P
s
P
p
.56491 .53629 m .56257 .5491 L .56744 .52865 L 1 g
F
P
p
.002 w
.56744 .52865 m .56773 .52907 L p
.56737 .52614 L 1 g
F P
s
P
p
.002 w
.53164 .55456 m .54062 .52624 L .56733 .5249 L p
1 g
F P
s
P
p
.56127 .49951 m .56581 .50904 L .54062 .52624 L 1 g
F
P
p
.002 w
.57322 .52461 m .56733 .5249 L p
.56581 .50904 L 1 g
F P
s
P
p
.002 w
.56733 .5249 m .54062 .52624 L p
.56581 .50904 L 1 g
F P
s
P
p
.002 w
.56773 .52907 m .56854 .53025 L p
.56669 .51826 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56581 .50904 L p
1 g
F P
s
P
p
.56669 .51826 m .56854 .53025 L .56581 .50904 L 1 g
F
P
p
.002 w
.54062 .52624 m .53878 .49475 L .55554 .48954 L p
1 g
F P
s
P
p
.002 w
.55736 .49129 m .55661 .4905 L p
.56076 .49844 L 1 g
F P
s
P
p
.56324 .49697 m .54062 .52624 L .55554 .48954 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55736 .49129 L p
1 g
F P
s
P
p
.56076 .49844 m .56713 .51061 L .55736 .49129 L 1 g
F
P
p
.57324 .48403 m .56324 .49697 L .55736 .49129 L 1 g
F
P
p
.002 w
.55559 .48952 m .55661 .4905 L .55736 .49129 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55559 .48952 L p
.55736 .49129 L 1 g
F P
s
P
p
.54174 .47608 m .55736 .49129 L .55622 .4902 L 1 g
F
P
p
.54174 .47608 m .55749 .49144 L .54881 .483 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55554 .48954 m .55639 .48927 L p
.55736 .49129 L 1 g
F P
s
P
p
.002 w
.55639 .48927 m .57324 .48403 L p
.55736 .49129 L 1 g
F P
s
P
p
.002 w
.55736 .49129 m .55749 .49144 L p
.55622 .4902 L 1 g
F P
s
P
p
.002 w
.56581 .50904 m .56713 .51061 L p
.56076 .49844 L 1 g
F P
s
P
p
.002 w
.57324 .48403 m .5752 .52451 L .57322 .52461 L p
1 g
F P
s
P
p
.002 w
.55713 .44396 m .57324 .48403 L .55554 .48954 L p
1 g
F P
s
P
p
.002 w
.55554 .48954 m .53878 .49475 L p
.54453 .47884 L 1 g
F P
s
P
p
.002 w
.5422 .47658 m .54174 .47608 L p
.54881 .483 L 1 g
F P
s
P
p
.55713 .44396 m .55554 .48954 L .54453 .47884 L 1 g
F
P
p
.54453 .47884 m .53878 .49475 L .5422 .47658 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5422 .47658 L p
1 g
F P
s
P
p
.54881 .483 m .55834 .49233 L .5422 .47658 L 1 g
F
P
p
.002 w
.55749 .49144 m .55834 .49233 L p
.54881 .483 L 1 g
F P
s
P
p
.002 w
.53878 .49475 m .52877 .4703 L p
.5422 .47658 L 1 g
F P
s
P
p
.54489 .47784 m .54453 .47884 L .5422 .47658 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5422 .47658 L p
1 g
F P
s
P
p
.52214 .46667 m .5422 .47658 L .53631 .47383 L 1 g
F
P
p
.52214 .46667 m .54257 .47698 L .53467 .47315 L 1 g
F
P
p
.52366 .46782 m .50295 .50352 L .52249 .46726 L 1 g
F
P
p
.002 w
.52249 .46726 m .52214 .46667 L p
.53467 .47315 L 1 g
F P
s
P
p
.002 w
.52606 .46369 m .53878 .49475 L .50295 .50352 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46726 L p
1 g
F P
s
P
p
.53467 .47315 m .54302 .47747 L .52249 .46726 L 1 g
F
P
p
.52606 .46369 m .52388 .46745 L .52249 .46726 L 1 g
F
P
p
.002 w
.52046 .46697 m .52111 .46659 L p
.52249 .46726 L 1 g
F P
s
P
p
.002 w
.52111 .46659 m .52606 .46369 L p
.52249 .46726 L 1 g
F P
s
P
p
.002 w
.52877 .4703 m .52606 .46369 L p
.54489 .47784 L 1 g
F P
s
P
p
.002 w
.5422 .47658 m .54257 .47698 L p
.53631 .47383 L 1 g
F P
s
P
p
.002 w
.54257 .47698 m .54302 .47747 L p
.53467 .47315 L 1 g
F P
s
P
p
.52249 .46726 m .50295 .50352 L .52046 .46697 L 1 g
F
P
p
.52388 .46745 m .52366 .46782 L .52249 .46726 L 1 g
F
P
p
.002 w
.52249 .46726 m .52251 .46729 L p
.52157 .46713 L 1 g
F P
s
P
p
.002 w
.52046 .46697 m .49414 .4824 L p
.50169 .46406 L 1 g
F P
s
P
p
.002 w
.52251 .46729 m .52282 .46778 L p
.51071 .46546 L 1 g
F P
s
P
p
.498 .46412 m .50169 .46406 L .49414 .4824 L 1 g
F
P
p
.002 w
.5 .4638 m .5 .4634 L p
.51071 .46546 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.52312 .46013 m .52606 .46369 L p
.498 .46412 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4638 L p
1 g
F P
s
P
p
.51071 .46546 m .52282 .46778 L .5 .4638 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.50377 .43674 m .52312 .46013 L p
.5 .4638 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .49059 .46529 L 1 g
F
P
p
.49812 .46351 m .5 .4638 L .498 .46412 L 1 g
F
P
p
.50377 .43674 m .5 .4638 L .49812 .46351 L 1 g
F
P
p
.002 w
.52606 .46369 m .52046 .46697 L p
.50169 .46406 L 1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .46428 L p
.49059 .46529 L 1 g
F P
s
P
p
.002 w
.5 .46428 m .5 .46442 L p
.49554 .46487 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46428 L .49554 .46487 L 1 g
F
P
p
.002 w
.47891 .46409 m .48041 .46588 L p
.47749 .46728 L 1 g
F P
s
P
p
.47743 .46729 m .47749 .46728 L .47742 .46731 L 1 g
F
P
p
.47891 .46409 m .47749 .46728 L .47743 .46729 L 1 g
F
P
p
.002 w
.47891 .46409 m .50377 .43674 L p
.498 .46412 L 1 g
F P
s
P
p
.002 w
.48116 .46679 m .47891 .46409 L p
.498 .46412 L 1 g
F P
s
P
p
.002 w
.48041 .46588 m .48116 .46679 L p
.47749 .46728 L 1 g
F P
s
P
p
.002 w
.48116 .46679 m .49414 .4824 L p
.47749 .46728 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47749 .46728 L p
1 g
F P
s
P
p
.49554 .46487 m .5 .46442 L .47749 .46728 L 1 g
F
P
p
.47695 .46754 m .47748 .4673 L .47477 .46859 L 1 g
F
P
p
.47695 .46754 m .47477 .46859 L .4679 .47185 L 1 g
F
P
p
.002 w
.47477 .46859 m .47891 .46409 L p
.47742 .46731 L 1 g
F P
s
P
p
.002 w
.47749 .46728 m .47748 .4673 L p
.47695 .46754 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47718 .46778 L p
.4679 .47185 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.459 .45072 m .47403 .46081 L p
.45768 .47671 L 1 g
F P
s
P
p
.44339 .4905 m .45768 .47671 L .45254 .48172 L 1 g
F
P
p
.45624 .4774 m .45768 .47671 L .45616 .47819 L 1 g
F
P
p
.459 .45072 m .45768 .47671 L .45624 .4774 L 1 g
F
P
p
.002 w
.47891 .46409 m .47477 .46859 L p
.4614 .47494 L 1 g
F P
s
P
p
.002 w
.47403 .46081 m .47891 .46409 L p
.45616 .47819 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45768 .47671 L p
1 g
F P
s
P
p
.4679 .47185 m .47718 .46778 L .45768 .47671 L 1 g
F
P
p
.002 w
.45768 .47671 m .4572 .47724 L p
.45254 .48172 L 1 g
F P
s
P
p
.44339 .4905 m .4572 .47724 L .45361 .48071 L 1 g
F
P
p
.002 w
.44603 .48417 m .44838 .48576 L p
.44253 .49142 L 1 g
F P
s
P
p
.002 w
.44838 .48576 m .45492 .49016 L p
.44253 .49142 L 1 g
F P
s
P
p
.002 w
.4572 .47724 m .45698 .47747 L p
.45361 .48071 L 1 g
F P
s
P
p
.002 w
.4449 .48341 m .459 .45072 L p
.45616 .47819 L 1 g
F P
s
P
p
.002 w
.44838 .48576 m .4449 .48341 L p
.45616 .47819 L 1 g
F P
s
P
p
.002 w
.44252 .49142 m .44166 .49233 L p
.43838 .50001 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44253 .49142 L p
1 g
F P
s
P
p
.45361 .48071 m .45698 .47747 L .44253 .49142 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.45492 .49016 m .43338 .51324 L p
.43893 .49887 L 1 g
F P
s
P
p
.002 w
.43777 .50126 m .43353 .51191 L p
.43379 .50952 L 1 g
F P
s
P
p
.43694 .48091 m .43777 .50126 L .43379 .50952 L 1 g
F
P
p
.002 w
.43353 .51191 m .43777 .50126 L p
.43338 .51324 L 1 g
F P
s
P
p
.43893 .49887 m .43338 .51324 L .43777 .50126 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43379 .50952 L p
1 g
F P
s
P
p
.43838 .50001 m .44166 .49233 L .43379 .50952 L 1 g
F
P
p
.002 w
.43271 .51396 m .43277 .51163 L p
.43309 .51097 L 1 g
F P
s
P
p
.002 w
.43379 .50952 m .43378 .50953 L p
.43378 .50959 L 1 g
F P
s
P
p
.002 w
.43378 .50953 m .43376 .50955 L p
.43376 .50975 L 1 g
F P
s
P
p
.002 w
.45492 .49016 m .46262 .49936 L .43334 .51365 L p
1 g
F P
s
P
p
.002 w
.43338 .51324 m .45492 .49016 L p
.43334 .51365 L 1 g
F P
s
P
p
.002 w
.43376 .50955 m .43373 .50959 L p
.43372 .50993 L 1 g
F P
s
P
p
.002 w
.43373 .50959 m .43369 .50964 L p
.43368 .5101 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.46262 .49936 m .46714 .51 L .43332 .51389 L p
1 g
F P
s
P
p
.002 w
.43334 .51365 m .46262 .49936 L p
.43332 .51389 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.46714 .51 m .46799 .52088 L .4333 .51408 L p
1 g
F P
s
P
p
.002 w
.4333 .51408 m .43271 .51396 L .43332 .51389 L p
1 g
F P
s
P
p
.002 w
.43332 .51389 m .46714 .51 L p
.4333 .51408 L 1 g
F P
s
P
p
.002 w
.43369 .50964 m .43364 .5097 L p
.43363 .51025 L 1 g
F P
s
P
p
.002 w
.43364 .5097 m .43359 .50976 L p
.43359 .51036 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.46799 .52088 m .46512 .53079 L .43329 .51426 L p
1 g
F P
s
P
p
.002 w
.43329 .51426 m .43271 .51396 L .4333 .51408 L p
1 g
F P
s
P
p
.002 w
.4333 .51408 m .46799 .52088 L p
.43329 .51426 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.46512 .53079 m .45888 .53866 L .43327 .51449 L p
1 g
F P
s
P
p
.002 w
.43327 .51449 m .43271 .51396 L .43329 .51426 L p
1 g
F P
s
P
p
.002 w
.43329 .51426 m .46512 .53079 L p
.43327 .51449 L 1 g
F P
s
P
p
.002 w
.43359 .50976 m .43355 .5098 L p
.43355 .5104 L 1 g
F P
s
P
p
.002 w
.43355 .5098 m .43352 .50984 L p
.43352 .51034 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45888 .53866 m .44997 .54368 L .43325 .51489 L p
1 g
F P
s
P
p
.002 w
.43325 .51489 m .43271 .51396 L .43327 .51449 L p
1 g
F P
s
P
p
.002 w
.43327 .51449 m .45888 .53866 L p
.43325 .51489 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44997 .54368 m .43939 .54533 L .43318 .51617 L p
1 g
F P
s
P
p
.002 w
.43318 .51617 m .43271 .51396 L .43325 .51489 L p
1 g
F P
s
P
p
.002 w
.43325 .51489 m .44997 .54368 L p
.43318 .51617 L 1 g
F P
s
P
p
.002 w
.43352 .50984 m .43351 .50986 L p
.4335 .51017 L 1 g
F P
s
P
p
.002 w
.43271 .51396 m .43318 .51617 L p
.43314 .51692 L 1 g
F P
s
P
p
.002 w
.43253 .5287 m .43346 .52734 L p
.43311 .51741 L 1 g
F P
s
P
p
.002 w
.43118 .52405 m .43271 .51396 L p
.43724 .54498 L 1 g
F P
s
P
p
.002 w
.43351 .50986 m .43287 .51061 L p
.43311 .51741 L 1 g
F P
s
P
p
.002 w
.43939 .54533 m .43724 .54498 L p
.43314 .51692 L 1 g
F P
s
P
p
.002 w
.43318 .51617 m .43939 .54533 L p
.43314 .51692 L 1 g
F P
s
P
p
.002 w
.41773 .53833 m .40894 .53043 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.42825 .54348 m .41773 .53833 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.40894 .53043 m .4028 .52062 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.4028 .52062 m .39996 .50991 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.39996 .50991 m .40075 .49944 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.40075 .49944 m .40511 .49033 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.40511 .49033 m .41263 .48358 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.42251 .47995 m .43367 .47988 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.41263 .48358 m .42251 .47995 L .43271 .51396 L closepath p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43253 .5287 L p
1 g
F P
s
P
p
.43311 .51741 m .43287 .51061 L .43253 .5287 L 1 g
F
P
p
.002 w
.43146 .53025 m .43155 .53053 L p
.43505 .53742 L 1 g
F P
s
P
p
.43502 .53728 m .43146 .53025 L .43505 .53742 L 1 g
F
P
p
.002 w
.42825 .54348 m .4361 .54478 L p
.44773 .57251 L 1 g
F P
s
P
p
.45146 .56129 m .43825 .54754 L .43887 .54832 L 1 g
F
P
p
.45146 .56129 m .4382 .54764 L .44423 .555 L 1 g
F
P
p
.002 w
.4361 .54478 m .43939 .54533 L .44123 .55134 L p
1 g
F P
s
P
p
.002 w
.43155 .53053 m .43743 .5491 L .43825 .54754 L p
1 g
F P
s
P
p
.002 w
.43825 .54754 m .4382 .54764 L p
.43887 .54832 L 1 g
F P
s
P
p
.46113 .57053 m .45081 .56305 L .43939 .54533 L 1 g
F
P
p
.002 w
.44311 .55747 m .44123 .55134 L p
.45081 .56305 L 1 g
F P
s
P
p
.002 w
.44123 .55134 m .43939 .54533 L p
.45081 .56305 L 1 g
F P
s
P
p
.002 w
.4382 .54764 m .43743 .5491 L p
.44423 .555 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45081 .56305 L p
1 g
F P
s
P
p
.44423 .555 m .43743 .5491 L .45081 .56305 L 1 g
F
P
p
.45831 .56849 m .45585 .56751 L .46113 .57053 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46845 .56945 m .46113 .57053 L p
.43939 .54533 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57464 L p
1 g
F P
s
P
p
.45585 .56751 m .45002 .56518 L .46829 .57464 L 1 g
F
P
p
.002 w
.46829 .57464 m .46818 .5751 L p
.47135 .57563 L 1 g
F P
s
P
p
.002 w
.44773 .57251 m .45739 .57109 L p
.48744 .59047 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.50516 .58098 m .48908 .58041 L .46845 .56945 L 1 g
F
P
p
.002 w
.478 .58002 m .47516 .57688 L p
.48908 .58041 L 1 g
F P
s
P
p
.002 w
.47516 .57688 m .46845 .56945 L p
.48908 .58041 L 1 g
F P
s
P
p
.002 w
.46818 .5751 m .4678 .57686 L p
.4786 .57775 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58041 L p
1 g
F P
s
P
p
.4786 .57775 m .4678 .57686 L .48908 .58041 L 1 g
F
P
p
.49993 .58079 m .49704 .58137 L .50516 .58098 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51315 .5767 m .50516 .58098 L p
.46845 .56945 L 1 g
F P
s
P
p
.002 w
.50516 .58098 m .51315 .5767 L .51813 .57901 L p
1 g
F P
s
P
p
.002 w
.51813 .57901 m .52073 .58022 L p
.51094 .5807 L 1 g
F P
s
P
p
.51094 .5807 m .50516 .58098 L .51813 .57901 L 1 g
F
P
p
.002 w
.52073 .58022 m .53926 .58884 L p
.50516 .58098 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53196 .57576 L p
1 g
F P
s
P
p
.002 w
.53196 .57576 m .53128 .57265 L p
.51953 .57868 L 1 g
F P
s
P
p
.51953 .57868 m .51111 .583 L .53196 .57576 L 1 g
F
P
p
.002 w
.51813 .57901 m .51315 .5767 L p
.56107 .5633 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56282 L p
1 g
F P
s
P
p
.54242 .56712 m .5322 .57686 L .54911 .56282 L 1 g
F
P
p
.002 w
.53159 .57408 m .5322 .57686 L p
.54242 .56712 L 1 g
F P
s
P
p
.52078 .57804 m .51813 .57901 L .51953 .57868 L 1 g
F
P
p
.002 w
.51094 .5807 m .51111 .583 L p
.51953 .57868 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .5807 L p
1 g
F P
s
P
p
.49704 .58137 m .48889 .583 L .51094 .5807 L 1 g
F
P
p
.002 w
.53926 .58884 m .56326 .56073 L .59229 .56287 L p
1 g
F P
s
P
p
.002 w
.65628 .44478 m .63393 .38637 L .65118 .37003 L p
1 g
F P
s
P
p
.002 w
.60849 .31717 m .65118 .37003 L .63393 .38637 L p
1 g
F P
s
P
p
.004 w
.47503 .46148 m
.5 .43051 L
s
P
p
.002 w
.60692 .51996 m .59229 .56287 L .56326 .56073 L p
1 g
F P
s
P
p
.002 w
.59229 .56287 m .60692 .51996 L .63472 .51283 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.59286 .3357 m .5381 .29939 L .55142 .27939 L p
1 g
F P
s
P
p
.002 w
.55142 .27939 m .60849 .31717 L .59286 .3357 L p
1 g
F P
s
P
p
.002 w
.40894 .53043 m .41773 .53833 L .40566 .55875 L p
1 g
F P
s
P
p
.002 w
.40566 .55875 m .38859 .54343 L .40894 .53043 L p
1 g
F P
s
P
p
.002 w
.42606 .56879 m .40566 .55875 L .41773 .53833 L p
1 g
F P
s
P
p
.002 w
.4028 .52062 m .40894 .53043 L .38859 .54343 L p
1 g
F P
s
P
p
.002 w
.38859 .54343 m .37659 .5244 L .4028 .52062 L p
1 g
F P
s
P
p
.002 w
.633 .45854 m .63472 .51283 L .60692 .51996 L p
1 g
F P
s
P
p
.002 w
.63472 .51283 m .633 .45854 L .65628 .44478 L p
1 g
F P
s
P
p
.002 w
.63393 .38637 m .65628 .44478 L .633 .45854 L p
1 g
F P
s
P
p
.002 w
.63393 .38637 m .59286 .3357 L .60849 .31717 L p
1 g
F P
s
P
p
.002 w
.41773 .53833 m .42825 .54348 L .42606 .56879 L p
1 g
F P
s
P
p
.002 w
.44773 .57251 m .42606 .56879 L .42825 .54348 L p
1 g
F P
s
P
p
.002 w
.38119 .41911 m .36011 .43906 L .3442 .41335 L p
1 g
F P
s
P
p
.002 w
.3442 .41335 m .37094 .38745 L .38119 .41911 L p
1 g
F P
s
P
p
.002 w
.38063 .46504 m .37227 .48305 L .34823 .46542 L p
1 g
F P
s
P
p
.002 w
.34823 .46542 m .36011 .43906 L .38063 .46504 L p
1 g
F P
s
P
p
.002 w
.39996 .50991 m .4028 .52062 L .37659 .5244 L p
1 g
F P
s
P
p
.002 w
.37659 .5244 m .37092 .50356 L .39996 .50991 L p
1 g
F P
s
P
p
.002 w
.40703 .37276 m .37094 .38745 L .36478 .35773 L p
1 g
F P
s
P
p
.002 w
.36478 .35773 m .40751 .33984 L .40703 .37276 L p
1 g
F P
s
P
p
.002 w
.52321 .32403 m .46645 .3077 L .47674 .282 L p
1 g
F P
s
P
p
.002 w
.47674 .282 m .5381 .29939 L .52321 .32403 L p
1 g
F P
s
P
p
.002 w
.45694 .33784 m .40751 .33984 L .41077 .31035 L p
1 g
F P
s
P
p
.002 w
.41077 .31035 m .46645 .3077 L .45694 .33784 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40075 .49944 m .39996 .50991 L .37092 .50356 L p
1 g
F P
s
P
p
.002 w
.37092 .50356 m .37227 .48305 L .40075 .49944 L p
1 g
F P
s
P
p
.002 w
.46845 .56945 m .48603 .55981 L .51315 .5767 L p
1 g
F P
s
P
p
.002 w
.53164 .55456 m .51315 .5767 L .48603 .55981 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.56326 .56073 m .5752 .52451 L .60692 .51996 L p
1 g
F P
s
P
p
.002 w
.43939 .54533 m .44997 .54368 L .46845 .56945 L p
1 g
F P
s
P
p
.002 w
.48603 .55981 m .46845 .56945 L .44997 .54368 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.633 .45854 m .61204 .40456 L .63393 .38637 L p
1 g
F P
s
P
p
.002 w
.59286 .3357 m .63393 .38637 L .61204 .40456 L p
1 g
F P
s
P
p
.002 w
.39524 .45155 m .38063 .46504 L .36011 .43906 L p
1 g
F P
s
P
p
.002 w
.36011 .43906 m .38119 .41911 L .39524 .45155 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60502 .47179 m .60692 .51996 L .5752 .52451 L p
1 g
F P
s
P
p
.002 w
.60692 .51996 m .60502 .47179 L .633 .45854 L p
1 g
F P
s
P
p
.002 w
.40511 .49033 m .40075 .49944 L .37227 .48305 L p
1 g
F P
s
P
p
.002 w
.37227 .48305 m .38063 .46504 L .40511 .49033 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.57391 .35771 m .52321 .32403 L .5381 .29939 L p
1 g
F P
s
P
p
.002 w
.5381 .29939 m .59286 .3357 L .57391 .35771 L p
1 g
F P
s
P
p
.002 w
.40942 .40798 m .38119 .41911 L .37094 .38745 L p
1 g
F P
s
P
p
.002 w
.37094 .38745 m .40703 .37276 L .40942 .40798 L p
1 g
F P
s
P
p
.002 w
.61204 .40456 m .633 .45854 L .60502 .47179 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.61204 .40456 m .57391 .35771 L .59286 .3357 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44997 .54368 m .45888 .53866 L .48603 .55981 L p
1 g
F P
s
P
p
.002 w
.49852 .54448 m .48603 .55981 L .45888 .53866 L p
1 g
F P
s
P
p
.002 w
.48603 .55981 m .49852 .54448 L .53164 .55456 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44859 .37142 m .40703 .37276 L .40751 .33984 L p
1 g
F P
s
P
p
.002 w
.40751 .33984 m .45694 .33784 L .44859 .37142 L p
1 g
F P
s
P
p
.002 w
.54062 .52624 m .53164 .55456 L .49852 .54448 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.50725 .35256 m .45694 .33784 L .46645 .3077 L p
1 g
F P
s
P
p
.002 w
.46645 .3077 m .52321 .32403 L .50725 .35256 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41263 .48358 m .40511 .49033 L .38063 .46504 L p
1 g
F P
s
P
p
.002 w
.38063 .46504 m .39524 .45155 L .41263 .48358 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5752 .52451 m .57324 .48403 L .60502 .47179 L p
1 g
F P
s
P
p
.002 w
.41464 .44417 m .39524 .45155 L .38119 .41911 L p
1 g
F P
s
P
p
.002 w
.38119 .41911 m .40942 .40798 L .41464 .44417 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45888 .53866 m .46512 .53079 L .49852 .54448 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.60502 .47179 m .58615 .424 L .61204 .40456 L p
1 g
F P
s
P
p
.002 w
.57391 .35771 m .61204 .40456 L .58615 .424 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.50442 .52502 m .49852 .54448 L .46512 .53079 L p
1 g
F P
s
P
p
.002 w
.49852 .54448 m .50442 .52502 L .54062 .52624 L p
1 g
F P
s
P
p
.002 w
.58615 .424 m .60502 .47179 L .57324 .48403 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.44176 .40721 m .40942 .40798 L .40703 .37276 L p
1 g
F P
s
P
p
.002 w
.40703 .37276 m .44859 .37142 L .44176 .40721 L p
1 g
F P
s
P
p
.002 w
.55221 .3825 m .50725 .35256 L .52321 .32403 L p
1 g
F P
s
P
p
.002 w
.52321 .32403 m .57391 .35771 L .55221 .3825 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.42251 .47995 m .41263 .48358 L .39524 .45155 L p
1 g
F P
s
P
p
.002 w
.39524 .45155 m .41464 .44417 L .42251 .47995 L p
1 g
F P
s
P
p
.002 w
.46512 .53079 m .46799 .52088 L .50442 .52502 L p
1 g
F P
s
P
p
.002 w
.53878 .49475 m .54062 .52624 L .50442 .52502 L p
1 g
F P
s
P
p
.002 w
.58615 .424 m .55221 .3825 L .57391 .35771 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.4908 .38399 m .44859 .37142 L .45694 .33784 L p
1 g
F P
s
P
p
.002 w
.45694 .33784 m .50725 .35256 L .4908 .38399 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46799 .52088 m .46714 .51 L .50295 .50352 L p
1 g
F P
s
P
p
.002 w
.50295 .50352 m .50442 .52502 L .46799 .52088 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50442 .52502 m .50295 .50352 L .53878 .49475 L p
1 g
F P
s
P
p
.002 w
.43672 .44384 m .41464 .44417 L .40942 .40798 L p
1 g
F P
s
P
p
.002 w
.40942 .40798 m .44176 .40721 L .43672 .44384 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43367 .47988 m .42251 .47995 L .41464 .44417 L p
1 g
F P
s
P
p
.002 w
.57324 .48403 m .55713 .44396 L .58615 .424 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.41464 .44417 m .43672 .44384 L .43367 .47988 L p
1 g
F P
s
P
p
.002 w
.55221 .3825 m .58615 .424 L .55713 .44396 L p
1 g
F P
s
P
p
.002 w
.46714 .51 m .46262 .49936 L .49414 .4824 L p
1 g
F P
s
P
p
.002 w
.49414 .4824 m .50295 .50352 L .46714 .51 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.4449 .48341 m .43367 .47988 L .43672 .44384 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47451 .41714 m .44176 .40721 L .44859 .37142 L p
1 g
F P
s
P
p
.002 w
.44859 .37142 m .4908 .38399 L .47451 .41714 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52853 .40918 m .4908 .38399 L .50725 .35256 L p
1 g
F P
s
P
p
.002 w
.50725 .35256 m .55221 .3825 L .52853 .40918 L p
1 g
F P
s
P
p
.002 w
.43672 .44384 m .459 .45072 L .4449 .48341 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55713 .44396 m .52853 .40918 L .55221 .3825 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.459 .45072 m .43672 .44384 L .44176 .40721 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.44176 .40721 m .47451 .41714 L .459 .45072 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52853 .40918 m .55713 .44396 L .52606 .46369 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50377 .43674 m .47451 .41714 L .4908 .38399 L p
1 g
F P
s
P
p
.002 w
.4908 .38399 m .52853 .40918 L .50377 .43674 L p
1 g
F P
s
P
p
.002 w
.47891 .46409 m .459 .45072 L .47451 .41714 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52606 .46369 m .50377 .43674 L .52853 .40918 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.47451 .41714 m .50377 .43674 L .47891 .46409 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.39204 .56439 m
.40992 .54222 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .37719 .70301 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39204 .56439 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0368421)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0368421)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4665 .41089 m .48018 .43416 L .50232 .4161 L p
1 g
F P
s
P
p
.002 w
.50232 .4161 m .49303 .40021 L .4665 .41089 L p
1 g
F P
s
P
p
.002 w
.51604 .42849 m .50232 .4161 L .48018 .43416 L p
1 g
F P
s
P
p
.002 w
.49303 .40021 m .50232 .4161 L .52445 .39833 L p
1 g
F P
s
P
p
.002 w
.50232 .4161 m .51604 .42849 L .53143 .40463 L p
1 g
F P
s
P
p
.002 w
.53143 .40463 m .52445 .39833 L .50232 .4161 L p
1 g
F P
s
P
p
.002 w
.48018 .43416 m .5003 .45234 L .51604 .42849 L p
1 g
F P
s
P
p
.002 w
.53277 .4361 m .51604 .42849 L .5003 .45234 L p
1 g
F P
s
P
p
.002 w
.51604 .42849 m .53277 .4361 L .53994 .40848 L p
1 g
F P
s
P
p
.002 w
.53994 .40848 m .53143 .40463 L .51604 .42849 L p
1 g
F P
s
P
p
.002 w
.44065 .42211 m .45844 .45222 L .48018 .43416 L p
1 g
F P
s
P
p
.002 w
.48018 .43416 m .4665 .41089 L .44065 .42211 L p
1 g
F P
s
P
p
.002 w
.5003 .45234 m .48018 .43416 L .45844 .45222 L p
1 g
F P
s
P
p
.002 w
.45844 .45222 m .4845 .47576 L .5003 .45234 L p
1 g
F P
s
P
p
.002 w
.52482 .46357 m .5003 .45234 L .4845 .47576 L p
1 g
F P
s
P
p
.002 w
.5003 .45234 m .52482 .46357 L .53277 .4361 L p
1 g
F P
s
P
p
.002 w
.4607 .38487 m .4665 .41089 L .49303 .40021 L p
1 g
F P
s
P
p
.002 w
.49303 .40021 m .48915 .38247 L .4607 .38487 L p
1 g
F P
s
P
p
.002 w
.48915 .38247 m .49303 .40021 L .51975 .39025 L p
1 g
F P
s
P
p
.002 w
.52445 .39833 m .51975 .39025 L .49303 .40021 L p
1 g
F P
s
P
p
.002 w
.55078 .43811 m .53277 .4361 L .52482 .46357 L p
1 g
F P
s
P
p
.002 w
.53277 .4361 m .55078 .43811 L .54908 .40945 L p
1 g
F P
s
P
p
.002 w
.54908 .40945 m .53994 .40848 L .53277 .4361 L p
1 g
F P
s
P
p
.002 w
.43298 .38841 m .44065 .42211 L .4665 .41089 L p
1 g
F P
s
P
p
.002 w
.4665 .41089 m .4607 .38487 L .43298 .38841 L p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .51975 .39025 L .52445 .39833 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .52445 .39833 L .53143 .40463 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .53143 .40463 L .53994 .40848 L closepath p
1 g
F P
s
P
p
.002 w
.55125 .46665 m .52482 .46357 L .51622 .49039 L p
1 g
F P
s
P
p
.002 w
.4845 .47576 m .51622 .49039 L .52482 .46357 L p
1 g
F P
s
P
p
.002 w
.52482 .46357 m .55125 .46665 L .55078 .43811 L p
1 g
F P
s
P
p
.002 w
.51975 .39025 m .51782 .38124 L .48915 .38247 L p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .51782 .38124 L .51975 .39025 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .53994 .40848 L .54908 .40945 L closepath p
1 g
F P
s
P
p
.002 w
.41595 .43366 m .43749 .46992 L .45844 .45222 L p
1 g
F P
s
P
p
.002 w
.45844 .45222 m .44065 .42211 L .41595 .43366 L p
1 g
F P
s
P
p
.002 w
.4845 .47576 m .45844 .45222 L .43749 .46992 L p
1 g
F P
s
P
p
.002 w
.43749 .46992 m .46891 .49832 L .4845 .47576 L p
1 g
F P
s
P
p
.002 w
.51622 .49039 m .4845 .47576 L .46891 .49832 L p
1 g
F P
s
P
p
.002 w
.46348 .35877 m .4607 .38487 L .48915 .38247 L p
1 g
F P
s
P
p
.002 w
.48915 .38247 m .49116 .36473 L .46348 .35877 L p
1 g
F P
s
P
p
.002 w
.49116 .36473 m .48915 .38247 L .51782 .38124 L p
1 g
F P
s
P
p
.002 w
.56818 .43427 m .55078 .43811 L .55125 .46665 L p
1 g
F P
s
P
p
.002 w
.55078 .43811 m .56818 .43427 L .55788 .40745 L p
1 g
F P
s
P
p
.002 w
.55788 .40745 m .54908 .40945 L .55078 .43811 L p
1 g
F P
s
P
p
.002 w
.51782 .38124 m .51889 .37225 L .49116 .36473 L p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .51889 .37225 L .51782 .38124 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .54908 .40945 L .55788 .40745 L closepath p
1 g
F P
s
P
p
.002 w
.40652 .39303 m .41595 .43366 L .44065 .42211 L p
1 g
F P
s
P
p
.002 w
.44065 .42211 m .43298 .38841 L .40652 .39303 L p
1 g
F P
s
P
p
.002 w
.43638 .35451 m .43298 .38841 L .4607 .38487 L p
1 g
F P
s
P
p
.002 w
.4607 .38487 m .46348 .35877 L .43638 .35451 L p
1 g
F P
s
P
p
.002 w
.49889 .34887 m .49116 .36473 L .51889 .37225 L p
1 g
F P
s
P
p
.002 w
.51889 .37225 m .52286 .36426 L .49889 .34887 L p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .52286 .36426 L .51889 .37225 L closepath p
1 g
F P
s
P
p
.002 w
.55048 .49454 m .51622 .49039 L .50713 .51605 L p
1 g
F P
s
P
p
.002 w
.46891 .49832 m .50713 .51605 L .51622 .49039 L p
1 g
F P
s
P
p
.002 w
.51622 .49039 m .55048 .49454 L .55125 .46665 L p
1 g
F P
s
P
p
.002 w
.5654 .40265 m .55788 .40745 L .56818 .43427 L p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .55788 .40745 L .5654 .40265 L closepath p
1 g
F P
s
P
p
.002 w
.57688 .46116 m .55125 .46665 L .55048 .49454 L p
1 g
F P
s
P
p
.002 w
.55125 .46665 m .57688 .46116 L .56818 .43427 L p
1 g
F P
s
P
p
.002 w
.47469 .33534 m .46348 .35877 L .49116 .36473 L p
1 g
F P
s
P
p
.002 w
.49116 .36473 m .49889 .34887 L .47469 .33534 L p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .5708 .39557 L .57349 .38696 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .57349 .38696 L .57315 .37774 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .57315 .37774 L .5698 .36895 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .5698 .36895 L .56381 .36154 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .56381 .36154 L .55583 .35634 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .55583 .35634 L .54676 .35393 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .54676 .35393 L .53759 .35456 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .53759 .35456 L .52932 .35814 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .52932 .35814 L .52286 .36426 L closepath p
1 g
F P
s
P
p
.002 w
.54618 .38119 m .5654 .40265 L .5708 .39557 L closepath p
1 g
F P
s
P
p
.002 w
.58311 .4249 m .56818 .43427 L .57688 .46116 L p
1 g
F P
s
P
p
.002 w
.56818 .43427 m .58311 .4249 L .5654 .40265 L p
1 g
F P
s
P
p
.002 w
.51159 .33664 m .49889 .34887 L .52286 .36426 L p
1 g
F P
s
P
p
.002 w
.52286 .36426 m .52932 .35814 L .51159 .33664 L p
1 g
F P
s
P
p
.002 w
.5708 .39557 m .5654 .40265 L .58311 .4249 L p
1 g
F P
s
P
p
.002 w
.3929 .44533 m .41773 .48695 L .43749 .46992 L p
1 g
F P
s
P
p
.002 w
.43749 .46992 m .41595 .43366 L .3929 .44533 L p
1 g
F P
s
P
p
.002 w
.46891 .49832 m .43749 .46992 L .41773 .48695 L p
1 g
F P
s
P
p
.002 w
.41773 .48695 m .45382 .51958 L .46891 .49832 L p
1 g
F P
s
P
p
.002 w
.50713 .51605 m .46891 .49832 L .45382 .51958 L p
1 g
F P
s
P
p
.002 w
.52794 .32942 m .51159 .33664 L .52932 .35814 L p
1 g
F P
s
P
p
.002 w
.52932 .35814 m .53759 .35456 L .52794 .32942 L p
1 g
F P
s
P
p
.002 w
.58311 .4249 m .59392 .41095 L .5708 .39557 L p
1 g
F P
s
P
p
.002 w
.57349 .38696 m .5708 .39557 L .59392 .41095 L p
1 g
F P
s
P
p
.002 w
.41039 .35206 m .40652 .39303 L .43298 .38841 L p
1 g
F P
s
P
p
.002 w
.43298 .38841 m .43638 .35451 L .41039 .35206 L p
1 g
F P
s
P
p
.002 w
.45074 .32395 m .43638 .35451 L .46348 .35877 L p
1 g
F P
s
P
p
.002 w
.46348 .35877 m .47469 .33534 L .45074 .32395 L p
1 g
F P
s
P
p
.002 w
.50713 .51605 m .54844 .52125 L .55048 .49454 L p
1 g
F P
s
P
p
.002 w
.58378 .48762 m .55048 .49454 L .54844 .52125 L p
1 g
F P
s
P
p
.002 w
.55048 .49454 m .58378 .48762 L .57688 .46116 L p
1 g
F P
s
P
p
.002 w
.4933 .31715 m .47469 .33534 L .49889 .34887 L p
1 g
F P
s
P
p
.002 w
.49889 .34887 m .51159 .33664 L .4933 .31715 L p
1 g
F P
s
P
p
.002 w
.59897 .44752 m .57688 .46116 L .58378 .48762 L p
1 g
F P
s
P
p
.002 w
.57688 .46116 m .59897 .44752 L .58311 .4249 L p
1 g
F P
s
P
p
.002 w
.59392 .41095 m .58311 .4249 L .59897 .44752 L p
1 g
F P
s
P
p
.002 w
.38188 .39867 m .3929 .44533 L .41595 .43366 L p
1 g
F P
s
P
p
.002 w
.41595 .43366 m .40652 .39303 L .38188 .39867 L p
1 g
F P
s
P
p
.002 w
.54619 .32808 m .52794 .32942 L .53759 .35456 L p
1 g
F P
s
P
p
.002 w
.53759 .35456 m .54676 .35393 L .54619 .32808 L p
1 g
F P
s
P
p
.002 w
.59392 .41095 m .59937 .39387 L .57349 .38696 L p
1 g
F P
s
P
p
.002 w
.57315 .37774 m .57349 .38696 L .59937 .39387 L p
1 g
F P
s
P
p
.002 w
.54844 .52125 m .50713 .51605 L .4977 .54006 L p
1 g
F P
s
P
p
.002 w
.45382 .51958 m .4977 .54006 L .50713 .51605 L p
1 g
F P
s
P
p
.002 w
.5643 .33283 m .54619 .32808 L .54676 .35393 L p
1 g
F P
s
P
p
.002 w
.54676 .35393 m .55583 .35634 L .5643 .33283 L p
1 g
F P
s
P
p
.002 w
.59937 .39387 m .59879 .37554 L .57315 .37774 L p
1 g
F P
s
P
p
.002 w
.5698 .36895 m .57315 .37774 L .59879 .37554 L p
1 g
F P
s
P
p
.002 w
.58023 .34318 m .5643 .33283 L .55583 .35634 L p
1 g
F P
s
P
p
.002 w
.55583 .35634 m .56381 .36154 L .58023 .34318 L p
1 g
F P
s
P
p
.002 w
.59879 .37554 m .59217 .35798 L .5698 .36895 L p
1 g
F P
s
P
p
.002 w
.56381 .36154 m .5698 .36895 L .59217 .35798 L p
1 g
F P
s
P
p
.002 w
.59217 .35798 m .58023 .34318 L .56381 .36154 L p
1 g
F P
s
P
p
.002 w
.51742 .30632 m .4933 .31715 L .51159 .33664 L p
1 g
F P
s
P
p
.002 w
.51159 .33664 m .52794 .32942 L .51742 .30632 L p
1 g
F P
s
P
p
.002 w
.59897 .44752 m .61508 .42705 L .59392 .41095 L p
1 g
F P
s
P
p
.002 w
.59937 .39387 m .59392 .41095 L .61508 .42705 L p
1 g
F P
s
P
p
.002 w
.4748 .3001 m .45074 .32395 L .47469 .33534 L p
1 g
F P
s
P
p
.002 w
.47469 .33534 m .4933 .31715 L .4748 .3001 L p
1 g
F P
s
P
p
.002 w
.42751 .31499 m .41039 .35206 L .43638 .35451 L p
1 g
F P
s
P
p
.002 w
.43638 .35451 m .45074 .32395 L .42751 .31499 L p
1 g
F P
s
P
p
.002 w
.372 .4569 m .39959 .50295 L .41773 .48695 L p
1 g
F P
s
P
p
.002 w
.41773 .48695 m .3929 .44533 L .372 .4569 L p
1 g
F P
s
P
p
.002 w
.45382 .51958 m .41773 .48695 L .39959 .50295 L p
1 g
F P
s
P
p
.002 w
.39959 .50295 m .43955 .53909 L .45382 .51958 L p
1 g
F P
s
P
p
.002 w
.4977 .54006 m .45382 .51958 L .43955 .53909 L p
1 g
F P
s
P
p
.002 w
.58378 .48762 m .61263 .4701 L .59897 .44752 L p
1 g
F P
s
P
p
.002 w
.61508 .42705 m .59897 .44752 L .61263 .4701 L p
1 g
F P
s
P
p
.002 w
.38607 .35153 m .38188 .39867 L .40652 .39303 L p
1 g
F P
s
P
p
.002 w
.40652 .39303 m .41039 .35206 L .38607 .35153 L p
1 g
F P
s
P
p
.002 w
.54844 .52125 m .58873 .51313 L .58378 .48762 L p
1 g
F P
s
P
p
.002 w
.61263 .4701 m .58378 .48762 L .58873 .51313 L p
1 g
F P
s
P
p
.002 w
.4977 .54006 m .54516 .54623 L .54844 .52125 L p
1 g
F P
s
P
p
.002 w
.58873 .51313 m .54844 .52125 L .54516 .54623 L p
1 g
F P
s
P
p
.002 w
.54445 .3042 m .51742 .30632 L .52794 .32942 L p
1 g
F P
s
P
p
.002 w
.52794 .32942 m .54619 .32808 L .54445 .3042 L p
1 g
F P
s
P
p
.002 w
.61508 .42705 m .6233 .40185 L .59937 .39387 L p
1 g
F P
s
P
p
.002 w
.59879 .37554 m .59937 .39387 L .6233 .40185 L p
1 g
F P
s
P
p
.002 w
.35959 .40526 m .372 .4569 L .3929 .44533 L p
1 g
F P
s
P
p
.002 w
.3929 .44533 m .38188 .39867 L .35959 .40526 L p
1 g
F P
s
P
p
.002 w
.54516 .54623 m .4977 .54006 L .4881 .56188 L p
1 g
F P
s
P
p
.002 w
.43955 .53909 m .4881 .56188 L .4977 .54006 L p
1 g
F P
s
P
p
.002 w
.57136 .31118 m .54445 .3042 L .54619 .32808 L p
1 g
F P
s
P
p
.002 w
.54619 .32808 m .5643 .33283 L .57136 .31118 L p
1 g
F P
s
P
p
.002 w
.6233 .40185 m .62256 .37466 L .59879 .37554 L p
1 g
F P
s
P
p
.002 w
.59217 .35798 m .59879 .37554 L .62256 .37466 L p
1 g
F P
s
P
p
.002 w
.50619 .28578 m .4748 .3001 L .4933 .31715 L p
1 g
F P
s
P
p
.002 w
.4933 .31715 m .51742 .30632 L .50619 .28578 L p
1 g
F P
s
P
p
.002 w
.61263 .4701 m .63379 .44357 L .61508 .42705 L p
1 g
F P
s
P
p
.002 w
.6233 .40185 m .61508 .42705 L .63379 .44357 L p
1 g
F P
s
P
p
.002 w
.59506 .32654 m .57136 .31118 L .5643 .33283 L p
1 g
F P
s
P
p
.002 w
.5643 .33283 m .58023 .34318 L .59506 .32654 L p
1 g
F P
s
P
p
.002 w
.62256 .37466 m .6128 .34855 L .59217 .35798 L p
1 g
F P
s
P
p
.002 w
.58023 .34318 m .59217 .35798 L .6128 .34855 L p
1 g
F P
s
P
p
.002 w
.45648 .28592 m .42751 .31499 L .45074 .32395 L p
1 g
F P
s
P
p
.002 w
.45074 .32395 m .4748 .3001 L .45648 .28592 L p
1 g
F P
s
P
p
.002 w
.6128 .34855 m .59506 .32654 L .58023 .34318 L p
1 g
F P
s
P
p
.002 w
.40552 .30874 m .38607 .35153 L .41039 .35206 L p
1 g
F P
s
P
p
.002 w
.41039 .35206 m .42751 .31499 L .40552 .30874 L p
1 g
F P
s
P
p
.002 w
.58873 .51313 m .62376 .49217 L .61263 .4701 L p
1 g
F P
s
P
p
.002 w
.63379 .44357 m .61263 .4701 L .62376 .49217 L p
1 g
F P
s
P
p
.002 w
.54516 .54623 m .59155 .53715 L .58873 .51313 L p
1 g
F P
s
P
p
.002 w
.62376 .49217 m .58873 .51313 L .59155 .53715 L p
1 g
F P
s
P
p
.002 w
.36398 .353 m .35959 .40526 L .38188 .39867 L p
1 g
F P
s
P
p
.002 w
.38188 .39867 m .38607 .35153 L .36398 .353 L p
1 g
F P
s
P
p
.002 w
.35375 .46813 m .38348 .51756 L .39959 .50295 L p
1 g
F P
s
P
p
.002 w
.39959 .50295 m .372 .4569 L .35375 .46813 L p
1 g
F P
s
P
p
.002 w
.43955 .53909 m .39959 .50295 L .38348 .51756 L p
1 g
F P
s
P
p
.002 w
.4881 .56188 m .54066 .56892 L .54516 .54623 L p
1 g
F P
s
P
p
.002 w
.59155 .53715 m .54516 .54623 L .54066 .56892 L p
1 g
F P
s
P
p
.002 w
.38348 .51756 m .42642 .5564 L .43955 .53909 L p
1 g
F P
s
P
p
.002 w
.4881 .56188 m .43955 .53909 L .42642 .5564 L p
1 g
F P
s
P
p
.002 w
.54152 .28286 m .50619 .28578 L .51742 .30632 L p
1 g
F P
s
P
p
.002 w
.51742 .30632 m .54445 .3042 L .54152 .28286 L p
1 g
F P
s
P
p
.002 w
.63379 .44357 m .64471 .41074 L .6233 .40185 L p
1 g
F P
s
P
p
.002 w
.62256 .37466 m .6233 .40185 L .64471 .41074 L p
1 g
F P
s
P
p
.002 w
.34024 .4127 m .35375 .46813 L .372 .4569 L p
1 g
F P
s
P
p
.002 w
.372 .4569 m .35959 .40526 L .34024 .4127 L p
1 g
F P
s
P
p
.002 w
.54066 .56892 m .4881 .56188 L .47853 .58098 L p
1 g
F P
s
P
p
.002 w
.42642 .5564 m .47853 .58098 L .4881 .56188 L p
1 g
F P
s
P
p
.002 w
.49447 .26835 m .45648 .28592 L .4748 .3001 L p
1 g
F P
s
P
p
.002 w
.4748 .3001 m .50619 .28578 L .49447 .26835 L p
1 g
F P
s
P
p
.002 w
.57681 .29191 m .54152 .28286 L .54445 .3042 L p
1 g
F P
s
P
p
.002 w
.54445 .3042 m .57136 .31118 L .57681 .29191 L p
1 g
F P
s
P
p
.002 w
.62376 .49217 m .64959 .4602 L .63379 .44357 L p
1 g
F P
s
P
p
.002 w
.64471 .41074 m .63379 .44357 L .64959 .4602 L p
1 g
F P
s
P
p
.002 w
.64471 .41074 m .64389 .37518 L .62256 .37466 L p
1 g
F P
s
P
p
.002 w
.6128 .34855 m .62256 .37466 L .64389 .37518 L p
1 g
F P
s
P
p
.002 w
.43872 .27505 m .40552 .30874 L .42751 .31499 L p
1 g
F P
s
P
p
.002 w
.42751 .31499 m .45648 .28592 L .43872 .27505 L p
1 g
F P
s
P
p
.002 w
.59155 .53715 m .63203 .51326 L .62376 .49217 L p
1 g
F P
s
P
p
.002 w
.64959 .4602 m .62376 .49217 L .63203 .51326 L p
1 g
F P
s
P
p
.002 w
.3853 .30545 m .36398 .353 L .38607 .35153 L p
1 g
F P
s
P
p
.002 w
.38607 .35153 m .40552 .30874 L .3853 .30545 L p
1 g
F P
s
P
p
.002 w
.60792 .31203 m .57681 .29191 L .57136 .31118 L p
1 g
F P
s
P
p
.002 w
.57136 .31118 m .59506 .32654 L .60792 .31203 L p
1 g
F P
s
P
p
.002 w
.64389 .37518 m .63118 .34093 L .6128 .34855 L p
1 g
F P
s
P
p
.002 w
.59506 .32654 m .6128 .34855 L .63118 .34093 L p
1 g
F P
s
P
p
.002 w
.54066 .56892 m .59211 .55911 L .59155 .53715 L p
1 g
F P
s
P
p
.002 w
.63203 .51326 m .59155 .53715 L .59211 .55911 L p
1 g
F P
s
P
p
.002 w
.63118 .34093 m .60792 .31203 L .59506 .32654 L p
1 g
F P
s
P
p
.002 w
.34472 .35653 m .34024 .4127 L .35959 .40526 L p
1 g
F P
s
P
p
.002 w
.35959 .40526 m .36398 .353 L .34472 .35653 L p
1 g
F P
s
P
p
.002 w
.47853 .58098 m .53497 .58875 L .54066 .56892 L p
1 g
F P
s
P
p
.002 w
.59211 .55911 m .54066 .56892 L .53497 .58875 L p
1 g
F P
s
P
p
.002 w
.53743 .26463 m .49447 .26835 L .50619 .28578 L p
1 g
F P
s
P
p
.002 w
.50619 .28578 m .54152 .28286 L .53743 .26463 L p
1 g
F P
s
P
p
.002 w
.33867 .47877 m .36984 .53041 L .38348 .51756 L p
1 g
F P
s
P
p
.002 w
.38348 .51756 m .35375 .46813 L .33867 .47877 L p
1 g
F P
s
P
p
.002 w
.42642 .5564 m .38348 .51756 L .36984 .53041 L p
1 g
F P
s
P
p
.002 w
.36984 .53041 m .41475 .57103 L .42642 .5564 L p
1 g
F P
s
P
p
.002 w
.47853 .58098 m .42642 .5564 L .41475 .57103 L p
1 g
F P
s
P
p
.002 w
.64959 .4602 m .66305 .42042 L .64471 .41074 L p
1 g
F P
s
P
p
.002 w
.64389 .37518 m .64471 .41074 L .66305 .42042 L p
1 g
F P
s
P
p
.002 w
.48249 .25456 m .43872 .27505 L .45648 .28592 L p
1 g
F P
s
P
p
.002 w
.45648 .28592 m .49447 .26835 L .48249 .25456 L p
1 g
F P
s
P
p
.002 w
.32439 .42085 m .33867 .47877 L .35375 .46813 L p
1 g
F P
s
P
p
.002 w
.35375 .46813 m .34024 .4127 L .32439 .42085 L p
1 g
F P
s
P
p
.002 w
.41475 .57103 m .4692 .59683 L .47853 .58098 L p
1 g
F P
s
P
p
.002 w
.53497 .58875 m .47853 .58098 L .4692 .59683 L p
1 g
F P
s
P
p
.002 w
.63203 .51326 m .66201 .47657 L .64959 .4602 L p
1 g
F P
s
P
p
.002 w
.66305 .42042 m .64959 .4602 L .66201 .47657 L p
1 g
F P
s
P
p
.002 w
.58046 .27557 m .53743 .26463 L .54152 .28286 L p
1 g
F P
s
P
p
.002 w
.54152 .28286 m .57681 .29191 L .58046 .27557 L p
1 g
F P
s
P
p
.002 w
.42196 .26789 m .3853 .30545 L .40552 .30874 L p
1 g
F P
s
P
p
.002 w
.40552 .30874 m .43872 .27505 L .42196 .26789 L p
1 g
F P
s
P
p
.002 w
.66305 .42042 m .6622 .37715 L .64389 .37518 L p
1 g
F P
s
P
p
.002 w
.63118 .34093 m .64389 .37518 L .6622 .37715 L p
1 g
F P
s
P
p
.002 w
.59211 .55911 m .63713 .53286 L .63203 .51326 L p
1 g
F P
s
P
p
.002 w
.66201 .47657 m .63203 .51326 L .63713 .53286 L p
1 g
F P
s
P
p
.002 w
.3674 .30534 m .34472 .35653 L .36398 .353 L p
1 g
F P
s
P
p
.002 w
.36398 .353 m .3853 .30545 L .3674 .30534 L p
1 g
F P
s
P
p
.002 w
.53497 .58875 m .5903 .57845 L .59211 .55911 L p
1 g
F P
s
P
p
.002 w
.63713 .53286 m .59211 .55911 L .5903 .57845 L p
1 g
F P
s
P
p
.002 w
.61844 .3001 m .58046 .27557 L .57681 .29191 L p
1 g
F P
s
P
p
.002 w
.57681 .29191 m .60792 .31203 L .61844 .3001 L p
1 g
F P
s
P
p
.002 w
.6622 .37715 m .64679 .33537 L .63118 .34093 L p
1 g
F P
s
P
p
.002 w
.60792 .31203 m .63118 .34093 L .64679 .33537 L p
1 g
F P
s
P
p
.002 w
.64679 .33537 m .61844 .3001 L .60792 .31203 L p
1 g
F P
s
P
p
.002 w
.32887 .36215 m .32439 .42085 L .34024 .4127 L p
1 g
F P
s
P
p
.002 w
.34024 .4127 m .34472 .35653 L .32887 .36215 L p
1 g
F P
s
P
p
.002 w
.4692 .59683 m .52818 .60512 L .53497 .58875 L p
1 g
F P
s
P
p
.002 w
.5903 .57845 m .53497 .58875 L .52818 .60512 L p
1 g
F P
s
P
p
.002 w
.5322 .25011 m .48249 .25456 L .49447 .26835 L p
1 g
F P
s
P
p
.002 w
.49447 .26835 m .53743 .26463 L .5322 .25011 L p
1 g
F P
s
P
p
.002 w
.66201 .47657 m .67775 .43069 L .66305 .42042 L p
1 g
F P
s
P
p
.002 w
.6622 .37715 m .66305 .42042 L .67775 .43069 L p
1 g
F P
s
P
p
.002 w
.32729 .48852 m .35911 .54111 L .36984 .53041 L p
1 g
F P
s
P
p
.002 w
.36984 .53041 m .33867 .47877 L .32729 .48852 L p
1 g
F P
s
P
p
.002 w
.41475 .57103 m .36984 .53041 L .35911 .54111 L p
1 g
F P
s
P
p
.002 w
.35911 .54111 m .40488 .58252 L .41475 .57103 L p
1 g
F P
s
P
p
.002 w
.4692 .59683 m .41475 .57103 L .40488 .58252 L p
1 g
F P
s
P
p
.002 w
.47054 .24495 m .42196 .26789 L .43872 .27505 L p
1 g
F P
s
P
p
.002 w
.43872 .27505 m .48249 .25456 L .47054 .24495 L p
1 g
F P
s
P
p
.002 w
.31262 .42957 m .32729 .48852 L .33867 .47877 L p
1 g
F P
s
P
p
.002 w
.33867 .47877 m .32439 .42085 L .31262 .42957 L p
1 g
F P
s
P
p
.002 w
.63713 .53286 m .67059 .49229 L .66201 .47657 L p
1 g
F P
s
P
p
.002 w
.67775 .43069 m .66201 .47657 L .67059 .49229 L p
1 g
F P
s
P
p
.002 w
.52818 .60512 m .4692 .59683 L .46034 .60888 L p
1 g
F P
s
P
p
.002 w
.40488 .58252 m .46034 .60888 L .4692 .59683 L p
1 g
F P
s
P
p
.002 w
.40666 .26482 m .3674 .30534 L .3853 .30545 L p
1 g
F P
s
P
p
.002 w
.3853 .30545 m .42196 .26789 L .40666 .26482 L p
1 g
F P
s
P
p
.002 w
.58211 .26271 m .5322 .25011 L .53743 .26463 L p
1 g
F P
s
P
p
.002 w
.53743 .26463 m .58046 .27557 L .58211 .26271 L p
1 g
F P
s
P
p
.002 w
.67775 .43069 m .6769 .3806 L .6622 .37715 L p
1 g
F P
s
P
p
.002 w
.64679 .33537 m .6622 .37715 L .6769 .3806 L p
1 g
F P
s
P
p
.002 w
.5903 .57845 m .63879 .55044 L .63713 .53286 L p
1 g
F P
s
P
p
.002 w
.67059 .49229 m .63713 .53286 L .63879 .55044 L p
1 g
F P
s
P
p
.002 w
.35238 .30859 m .32887 .36215 L .34472 .35653 L p
1 g
F P
s
P
p
.002 w
.34472 .35653 m .3674 .30534 L .35238 .30859 L p
1 g
F P
s
P
p
.002 w
.52818 .60512 m .58602 .59455 L .5903 .57845 L p
1 g
F P
s
P
p
.002 w
.63879 .55044 m .5903 .57845 L .58602 .59455 L p
1 g
F P
s
P
p
.002 w
.62621 .29116 m .58211 .26271 L .58046 .27557 L p
1 g
F P
s
P
p
.002 w
.58046 .27557 m .61844 .3001 L .62621 .29116 L p
1 g
F P
s
P
p
.002 w
.6769 .3806 m .65911 .33213 L .64679 .33537 L p
1 g
F P
s
P
p
.002 w
.61844 .3001 m .64679 .33537 L .65911 .33213 L p
1 g
F P
s
P
p
.002 w
.31702 .36982 m .31262 .42957 L .32439 .42085 L p
1 g
F P
s
P
p
.002 w
.32439 .42085 m .32887 .36215 L .31702 .36982 L p
1 g
F P
s
P
p
.002 w
.65911 .33213 m .62621 .29116 L .61844 .3001 L p
1 g
F P
s
P
p
.002 w
.52588 .23987 m .47054 .24495 L .48249 .25456 L p
1 g
F P
s
P
p
.002 w
.48249 .25456 m .5322 .25011 L .52588 .23987 L p
1 g
F P
s
P
p
.002 w
.46034 .60888 m .52038 .61745 L .52818 .60512 L p
1 g
F P
s
P
p
.002 w
.58602 .59455 m .52818 .60512 L .52038 .61745 L p
1 g
F P
s
P
p
.002 w
.67059 .49229 m .68826 .44134 L .67775 .43069 L p
1 g
F P
s
P
p
.002 w
.6769 .3806 m .67775 .43069 L .68826 .44134 L p
1 g
F P
s
P
p
.002 w
.32009 .49712 m .35172 .54929 L .35911 .54111 L p
1 g
F P
s
P
p
.002 w
.35911 .54111 m .32729 .48852 L .32009 .49712 L p
1 g
F P
s
P
p
.002 w
.40488 .58252 m .35911 .54111 L .35172 .54929 L p
1 g
F P
s
P
p
.002 w
.35172 .54929 m .39716 .59041 L .40488 .58252 L p
1 g
F P
s
P
p
.002 w
.46034 .60888 m .40488 .58252 L .39716 .59041 L p
1 g
F P
s
P
p
.002 w
.45891 .23999 m .40666 .26482 L .42196 .26789 L p
1 g
F P
s
P
p
.002 w
.42196 .26789 m .47054 .24495 L .45891 .23999 L p
1 g
F P
s
P
p
.002 w
.63879 .55044 m .67492 .50695 L .67059 .49229 L p
1 g
F P
s
P
p
.002 w
.68826 .44134 m .67059 .49229 L .67492 .50695 L p
1 g
F P
s
P
p
.002 w
.30546 .43867 m .32009 .49712 L .32729 .48852 L p
1 g
F P
s
P
p
.002 w
.32729 .48852 m .31262 .42957 L .30546 .43867 L p
1 g
F P
s
P
p
.002 w
.39331 .26615 m .35238 .30859 L .3674 .30534 L p
1 g
F P
s
P
p
.002 w
.3674 .30534 m .40666 .26482 L .39331 .26615 L p
1 g
F P
s
P
p
.002 w
.39716 .59041 m .45218 .61662 L .46034 .60888 L p
1 g
F P
s
P
p
.002 w
.52038 .61745 m .46034 .60888 L .45218 .61662 L p
1 g
F P
s
P
p
.002 w
.5816 .25386 m .52588 .23987 L .5322 .25011 L p
1 g
F P
s
P
p
.002 w
.5322 .25011 m .58211 .26271 L .5816 .25386 L p
1 g
F P
s
P
p
.002 w
.58602 .59455 m .63677 .56547 L .63879 .55044 L p
1 g
F P
s
P
p
.002 w
.67492 .50695 m .63879 .55044 L .63677 .56547 L p
1 g
F P
s
P
p
.002 w
.68826 .44134 m .68743 .38554 L .6769 .3806 L p
1 g
F P
s
P
p
.002 w
.65911 .33213 m .6769 .3806 L .68743 .38554 L p
1 g
F P
s
P
p
.002 w
.34082 .31532 m .31702 .36982 L .32887 .36215 L p
1 g
F P
s
P
p
.002 w
.32887 .36215 m .35238 .30859 L .34082 .31532 L p
1 g
F P
s
P
p
.002 w
.52038 .61745 m .57926 .60686 L .58602 .59455 L p
1 g
F P
s
P
p
.002 w
.63677 .56547 m .58602 .59455 L .57926 .60686 L p
1 g
F P
s
P
p
.002 w
.63088 .28563 m .5816 .25386 L .58211 .26271 L p
1 g
F P
s
P
p
.002 w
.58211 .26271 m .62621 .29116 L .63088 .28563 L p
1 g
F P
s
P
p
.002 w
.68743 .38554 m .66763 .33142 L .65911 .33213 L p
1 g
F P
s
P
p
.002 w
.62621 .29116 m .65911 .33213 L .66763 .33142 L p
1 g
F P
s
P
p
.002 w
.30973 .37948 m .30546 .43867 L .31262 .42957 L p
1 g
F P
s
P
p
.002 w
.31262 .42957 m .31702 .36982 L .30973 .37948 L p
1 g
F P
s
P
p
.002 w
.51859 .23444 m .45891 .23999 L .47054 .24495 L p
1 g
F P
s
P
p
.002 w
.47054 .24495 m .52588 .23987 L .51859 .23444 L p
1 g
F P
s
P
p
.002 w
.66763 .33142 m .63088 .28563 L .62621 .29116 L p
1 g
F P
s
P
p
.002 w
.45218 .61662 m .5117 .62521 L .52038 .61745 L p
1 g
F P
s
P
p
.002 w
.57926 .60686 m .52038 .61745 L .5117 .62521 L p
1 g
F P
s
P
p
.002 w
.67492 .50695 m .69407 .45213 L .68826 .44134 L p
1 g
F P
s
P
p
.002 w
.68743 .38554 m .68826 .44134 L .69407 .45213 L p
1 g
F P
s
P
p
.002 w
.31753 .50424 m .34807 .55456 L .35172 .54929 L p
1 g
F P
s
P
p
.002 w
.35172 .54929 m .32009 .49712 L .31753 .50424 L p
1 g
F P
s
P
p
.002 w
.39716 .59041 m .35172 .54929 L .34807 .55456 L p
1 g
F P
s
P
p
.002 w
.34807 .55456 m .39193 .59425 L .39716 .59041 L p
1 g
F P
s
P
p
.002 w
.45218 .61662 m .39716 .59041 L .39193 .59425 L p
1 g
F P
s
P
p
.002 w
.44793 .24012 m .39331 .26615 L .40666 .26482 L p
1 g
F P
s
P
p
.002 w
.40666 .26482 m .45891 .23999 L .44793 .24012 L p
1 g
F P
s
P
p
.002 w
.63677 .56547 m .67464 .5201 L .67492 .50695 L p
1 g
F P
s
P
p
.002 w
.69407 .45213 m .67492 .50695 L .67464 .5201 L p
1 g
F P
s
P
p
.002 w
.38239 .27212 m .34082 .31532 L .35238 .30859 L p
1 g
F P
s
P
p
.002 w
.35238 .30859 m .39331 .26615 L .38239 .27212 L p
1 g
F P
s
P
p
.002 w
.30339 .44793 m .31753 .50424 L .32009 .49712 L p
1 g
F P
s
P
p
.002 w
.32009 .49712 m .30546 .43867 L .30339 .44793 L p
1 g
F P
s
P
p
.002 w
.57926 .60686 m .63092 .57738 L .63677 .56547 L p
1 g
F P
s
P
p
.002 w
.67464 .5201 m .63677 .56547 L .63092 .57738 L p
1 g
F P
s
P
p
.002 w
.39193 .59425 m .44499 .61957 L .45218 .61662 L p
1 g
F P
s
P
p
.002 w
.5117 .62521 m .45218 .61662 L .44499 .61957 L p
1 g
F P
s
P
p
.002 w
.5788 .24954 m .51859 .23444 L .52588 .23987 L p
1 g
F P
s
P
p
.002 w
.52588 .23987 m .5816 .25386 L .5788 .24954 L p
1 g
F P
s
P
p
.002 w
.69407 .45213 m .69324 .39193 L .68743 .38554 L p
1 g
F P
s
P
p
.002 w
.66763 .33142 m .68743 .38554 L .69324 .39193 L p
1 g
F P
s
P
p
.002 w
.33323 .32554 m .30973 .37948 L .31702 .36982 L p
1 g
F P
s
P
p
.002 w
.31702 .36982 m .34082 .31532 L .33323 .32554 L p
1 g
F P
s
P
p
.002 w
.5117 .62521 m .57003 .6148 L .57926 .60686 L p
1 g
F P
s
P
p
.002 w
.63092 .57738 m .57926 .60686 L .57003 .6148 L p
1 g
F P
s
P
p
.002 w
.63211 .2839 m .5788 .24954 L .5816 .25386 L p
1 g
F P
s
P
p
.002 w
.5816 .25386 m .63088 .28563 L .63211 .2839 L p
1 g
F P
s
P
p
.002 w
.30748 .39098 m .30339 .44793 L .30546 .43867 L p
1 g
F P
s
P
p
.002 w
.30546 .43867 m .30973 .37948 L .30748 .39098 L p
1 g
F P
s
P
p
.002 w
.69324 .39193 m .67186 .33343 L .66763 .33142 L p
1 g
F P
s
P
p
.002 w
.63088 .28563 m .66763 .33142 L .67186 .33343 L p
1 g
F P
s
P
p
.002 w
.51047 .23429 m .44793 .24012 L .45891 .23999 L p
1 g
F P
s
P
p
.002 w
.45891 .23999 m .51859 .23444 L .51047 .23429 L p
1 g
F P
s
P
p
.002 w
.44499 .61957 m .50234 .62788 L .5117 .62521 L p
1 g
F P
s
P
p
.002 w
.57003 .6148 m .5117 .62521 L .50234 .62788 L p
1 g
F P
s
P
p
.002 w
.67186 .33343 m .63211 .2839 L .63088 .28563 L p
1 g
F P
s
P
p
.002 w
.67464 .5201 m .69472 .46277 L .69407 .45213 L p
1 g
F P
s
P
p
.002 w
.69324 .39193 m .69407 .45213 L .69472 .46277 L p
1 g
F P
s
P
p
.004 w
.3079 .65993 m
.36182 .59554 L
s
P
p
.002 w
.43797 .24564 m .38239 .27212 L .39331 .26615 L p
1 g
F P
s
P
p
.002 w
.39331 .26615 m .44793 .24012 L .43797 .24564 L p
1 g
F P
s
P
p
.002 w
.31998 .50961 m .34851 .55661 L .34807 .55456 L p
1 g
F P
s
P
p
.002 w
.34807 .55456 m .31753 .50424 L .31998 .50961 L p
1 g
F P
s
P
p
.002 w
.39193 .59425 m .34807 .55456 L .34851 .55661 L p
1 g
F P
s
P
p
.002 w
.34851 .55661 m .38948 .59369 L .39193 .59425 L p
1 g
F P
s
P
p
.002 w
.44499 .61957 m .39193 .59425 L .38948 .59369 L p
1 g
F P
s
P
p
.002 w
.63092 .57738 m .66946 .53129 L .67464 .5201 L p
1 g
F P
s
P
p
.002 w
.69472 .46277 m .67464 .5201 L .66946 .53129 L p
1 g
F P
s
P
p
.002 w
.37436 .28284 m .33323 .32554 L .34082 .31532 L p
1 g
F P
s
P
p
.002 w
.34082 .31532 m .38239 .27212 L .37436 .28284 L p
1 g
F P
s
P
p
.002 w
.57003 .6148 m .62116 .58567 L .63092 .57738 L p
1 g
F P
s
P
p
.002 w
.66946 .53129 m .63092 .57738 L .62116 .58567 L p
1 g
F P
s
P
p
.002 w
.3068 .45709 m .31998 .50961 L .31753 .50424 L p
1 g
F P
s
P
p
.002 w
.31753 .50424 m .30339 .44793 L .3068 .45709 L p
1 g
F P
s
P
p
.002 w
.38948 .59369 m .43903 .61734 L .44499 .61957 L p
1 g
F P
s
P
p
.002 w
.50234 .62788 m .44499 .61957 L .43903 .61734 L p
1 g
F P
s
P
p
.002 w
.57365 .25015 m .51047 .23429 L .51859 .23444 L p
1 g
F P
s
P
p
.002 w
.51859 .23444 m .5788 .24954 L .57365 .25015 L p
1 g
F P
s
P
p
.002 w
.33009 .33917 m .30748 .39098 L .30973 .37948 L p
1 g
F P
s
P
p
.002 w
.30973 .37948 m .33323 .32554 L .33009 .33917 L p
1 g
F P
s
P
p
.002 w
.69472 .46277 m .69387 .39968 L .69324 .39193 L p
1 g
F P
s
P
p
.002 w
.67186 .33343 m .69324 .39193 L .69387 .39968 L p
1 g
F P
s
P
p
.002 w
.50234 .62788 m .55845 .61788 L .57003 .6148 L p
1 g
F P
s
P
p
.002 w
.62116 .58567 m .57003 .6148 L .55845 .61788 L p
1 g
F P
s
P
p
.002 w
.31066 .40409 m .3068 .45709 L .30339 .44793 L p
1 g
F P
s
P
p
.002 w
.30339 .44793 m .30748 .39098 L .31066 .40409 L p
1 g
F P
s
P
p
.002 w
.62965 .28625 m .57365 .25015 L .5788 .24954 L p
1 g
F P
s
P
p
.002 w
.5788 .24954 m .63211 .2839 L .62965 .28625 L p
1 g
F P
s
P
p
.002 w
.50169 .23977 m .43797 .24564 L .44793 .24012 L p
1 g
F P
s
P
p
.002 w
.44793 .24012 m .51047 .23429 L .50169 .23977 L p
1 g
F P
s
P
p
.002 w
.69387 .39968 m .67141 .33828 L .67186 .33343 L p
1 g
F P
s
P
p
.002 w
.63211 .2839 m .67186 .33343 L .67141 .33828 L p
1 g
F P
s
P
p
.002 w
.43903 .61734 m .49251 .62508 L .50234 .62788 L p
1 g
F P
s
P
p
.002 w
.55845 .61788 m .50234 .62788 L .49251 .62508 L p
1 g
F P
s
P
p
.002 w
.66946 .53129 m .68989 .47294 L .69472 .46277 L p
1 g
F P
s
P
p
.002 w
.69387 .39968 m .69472 .46277 L .68989 .47294 L p
1 g
F P
s
P
p
.002 w
.67141 .33828 m .62965 .28625 L .63211 .2839 L p
1 g
F P
s
P
p
.002 w
.42938 .25673 m .37436 .28284 L .38239 .27212 L p
1 g
F P
s
P
p
.002 w
.38239 .27212 m .43797 .24564 L .42938 .25673 L p
1 g
F P
s
P
p
.002 w
.62116 .58567 m .65924 .54007 L .66946 .53129 L p
1 g
F P
s
P
p
.002 w
.68989 .47294 m .66946 .53129 L .65924 .54007 L p
1 g
F P
s
P
p
.002 w
.32769 .51295 m .35329 .55514 L .34851 .55661 L p
1 g
F P
s
P
p
.002 w
.34851 .55661 m .31998 .50961 L .32769 .51295 L p
1 g
F P
s
P
p
.002 w
.38948 .59369 m .34851 .55661 L .35329 .55514 L p
1 g
F P
s
P
p
.002 w
.35329 .55514 m .39009 .58844 L .38948 .59369 L p
1 g
F P
s
P
p
.004 w
.36977 .58604 m
.37441 .5805 L
s
P
p
.004 w
.37738 .57695 m
.5 .43051 L
s
P
p
.004 w
.37441 .5805 m
.37534 .57939 L
s
P
p
.004 w
.36182 .59554 m
.36977 .58604 L
s
P
p
.002 w
.43903 .61734 m .38948 .59369 L .39009 .58844 L p
1 g
F P
s
P
p
.002 w
.36965 .29827 m .33009 .33917 L .33323 .32554 L p
1 g
F P
s
P
p
.002 w
.33323 .32554 m .37436 .28284 L .36965 .29827 L p
1 g
F P
s
P
p
.002 w
.55845 .61788 m .60753 .58987 L .62116 .58567 L p
1 g
F P
s
P
p
.002 w
.65924 .54007 m .62116 .58567 L .60753 .58987 L p
1 g
F P
s
P
p
.002 w
.31593 .46587 m .32769 .51295 L .31998 .50961 L p
1 g
F P
s
P
p
.002 w
.31998 .50961 m .3068 .45709 L .31593 .46587 L p
1 g
F P
s
P
p
.002 w
.33177 .356 m .31066 .40409 L .30748 .39098 L p
1 g
F P
s
P
p
.002 w
.30748 .39098 m .33009 .33917 L .33177 .356 L p
1 g
F P
s
P
p
.002 w
.39009 .58844 m .43456 .60965 L .43903 .61734 L p
1 g
F P
s
P
p
.002 w
.49251 .62508 m .43903 .61734 L .43456 .60965 L p
1 g
F P
s
P
p
.002 w
.56614 .25601 m .50169 .23977 L .51047 .23429 L p
1 g
F P
s
P
p
.002 w
.51047 .23429 m .57365 .25015 L .56614 .25601 L p
1 g
F P
s
P
p
.002 w
.68989 .47294 m .68895 .40865 L .69387 .39968 L p
1 g
F P
s
P
p
.002 w
.67141 .33828 m .69387 .39968 L .68895 .40865 L p
1 g
F P
s
P
p
.002 w
.49251 .62508 m .54471 .61571 L .55845 .61788 L p
1 g
F P
s
P
p
.002 w
.60753 .58987 m .55845 .61788 L .54471 .61571 L p
1 g
F P
s
P
p
.002 w
.31949 .41849 m .31593 .46587 L .3068 .45709 L p
1 g
F P
s
P
p
.002 w
.3068 .45709 m .31066 .40409 L .31949 .41849 L p
1 g
F P
s
P
p
.002 w
.4925 .25105 m .42938 .25673 L .43797 .24564 L p
1 g
F P
s
P
p
.002 w
.43797 .24564 m .50169 .23977 L .4925 .25105 L p
1 g
F P
s
P
p
.002 w
.62331 .2929 m .56614 .25601 L .57365 .25015 L p
1 g
F P
s
P
p
.002 w
.57365 .25015 m .62965 .28625 L .62331 .2929 L p
1 g
F P
s
P
p
.002 w
.43456 .60965 m .48248 .61652 L .49251 .62508 L p
1 g
F P
s
P
p
.002 w
.54471 .61571 m .49251 .62508 L .48248 .61652 L p
1 g
F P
s
P
p
.002 w
.68895 .40865 m .66598 .34602 L .67141 .33828 L p
1 g
F P
s
P
p
.002 w
.62965 .28625 m .67141 .33828 L .66598 .34602 L p
1 g
F P
s
P
p
.002 w
.65924 .54007 m .67935 .48231 L .68989 .47294 L p
1 g
F P
s
P
p
.002 w
.68895 .40865 m .68989 .47294 L .67935 .48231 L p
1 g
F P
s
P
p
.002 w
.66598 .34602 m .62331 .2929 L .62965 .28625 L p
1 g
F P
s
P
p
.002 w
.42254 .27338 m .36965 .29827 L .37436 .28284 L p
1 g
F P
s
P
p
.002 w
.37436 .28284 m .42938 .25673 L .42254 .27338 L p
1 g
F P
s
P
p
.002 w
.60753 .58987 m .64399 .54602 L .65924 .54007 L p
1 g
F P
s
P
p
.002 w
.67935 .48231 m .65924 .54007 L .64399 .54602 L p
1 g
F P
s
P
p
.002 w
.36862 .31819 m .33177 .356 L .33009 .33917 L p
1 g
F P
s
P
p
.002 w
.33009 .33917 m .36965 .29827 L .36862 .31819 L p
1 g
F P
s
P
p
.002 w
.34078 .51401 m .36255 .54998 L .35329 .55514 L p
1 g
F P
s
P
p
.002 w
.35329 .55514 m .32769 .51295 L .34078 .51401 L p
1 g
F P
s
P
p
.002 w
.39009 .58844 m .35329 .55514 L .36255 .54998 L p
1 g
F P
s
P
p
.002 w
.36255 .54998 m .39392 .57836 L .39009 .58844 L p
1 g
F P
s
P
p
.002 w
.43456 .60965 m .39009 .58844 L .39392 .57836 L p
1 g
F P
s
P
p
.002 w
.54471 .61571 m .59024 .58958 L .60753 .58987 L p
1 g
F P
s
P
p
.002 w
.64399 .54602 m .60753 .58987 L .59024 .58958 L p
1 g
F P
s
P
p
.002 w
.33849 .37567 m .31949 .41849 L .31066 .40409 L p
1 g
F P
s
P
p
.002 w
.31066 .40409 m .33177 .356 L .33849 .37567 L p
1 g
F P
s
P
p
.002 w
.33086 .47396 m .34078 .51401 L .32769 .51295 L p
1 g
F P
s
P
p
.002 w
.32769 .51295 m .31593 .46587 L .33086 .47396 L p
1 g
F P
s
P
p
.002 w
.55636 .26726 m .4925 .25105 L .50169 .23977 L p
1 g
F P
s
P
p
.002 w
.50169 .23977 m .56614 .25601 L .55636 .26726 L p
1 g
F P
s
P
p
.002 w
.48248 .61652 m .43456 .60965 L .43182 .59638 L p
1 g
F P
s
P
p
.002 w
.39392 .57836 m .43182 .59638 L .43456 .60965 L p
1 g
F P
s
P
p
.002 w
.48248 .61652 m .52913 .60804 L .54471 .61571 L p
1 g
F P
s
P
p
.002 w
.59024 .58958 m .54471 .61571 L .52913 .60804 L p
1 g
F P
s
P
p
.002 w
.67935 .48231 m .67829 .41863 L .68895 .40865 L p
1 g
F P
s
P
p
.002 w
.66598 .34602 m .68895 .40865 L .67829 .41863 L p
1 g
F P
s
P
p
.002 w
.48318 .26812 m .42254 .27338 L .42938 .25673 L p
1 g
F P
s
P
p
.002 w
.42938 .25673 m .4925 .25105 L .48318 .26812 L p
1 g
F P
s
P
p
.002 w
.33402 .43378 m .33086 .47396 L .31593 .46587 L p
1 g
F P
s
P
p
.002 w
.31593 .46587 m .31949 .41849 L .33402 .43378 L p
1 g
F P
s
P
p
.002 w
.43182 .59638 m .47257 .60214 L .48248 .61652 L p
1 g
F P
s
P
p
.002 w
.52913 .60804 m .48248 .61652 L .47257 .60214 L p
1 g
F P
s
P
p
.002 w
.64399 .54602 m .66311 .49051 L .67935 .48231 L p
1 g
F P
s
P
p
.002 w
.67829 .41863 m .67935 .48231 L .66311 .49051 L p
1 g
F P
s
P
p
.002 w
.61305 .3039 m .55636 .26726 L .56614 .25601 L p
1 g
F P
s
P
p
.002 w
.56614 .25601 m .62331 .2929 L .61305 .3039 L p
1 g
F P
s
P
p
.002 w
.67829 .41863 m .65541 .35658 L .66598 .34602 L p
1 g
F P
s
P
p
.002 w
.62331 .2929 m .66598 .34602 L .65541 .35658 L p
1 g
F P
s
P
p
.002 w
.41777 .29533 m .36862 .31819 L .36965 .29827 L p
1 g
F P
s
P
p
.002 w
.36965 .29827 m .42254 .27338 L .41777 .29533 L p
1 g
F P
s
P
p
.002 w
.65541 .35658 m .61305 .3039 L .62331 .2929 L p
1 g
F P
s
P
p
.002 w
.59024 .58958 m .6239 .54877 L .64399 .54602 L p
1 g
F P
s
P
p
.002 w
.66311 .49051 m .64399 .54602 L .6239 .54877 L p
1 g
F P
s
P
p
.002 w
.37148 .34217 m .33849 .37567 L .33177 .356 L p
1 g
F P
s
P
p
.002 w
.33177 .356 m .36862 .31819 L .37148 .34217 L p
1 g
F P
s
P
p
.002 w
.52913 .60804 m .56963 .58457 L .59024 .58958 L p
1 g
F P
s
P
p
.002 w
.6239 .54877 m .59024 .58958 L .56963 .58457 L p
1 g
F P
s
P
p
.002 w
.35914 .51263 m .37629 .54105 L .36255 .54998 L p
1 g
F P
s
P
p
.002 w
.36255 .54998 m .34078 .51401 L .35914 .51263 L p
1 g
F P
s
P
p
.002 w
.39392 .57836 m .36255 .54998 L .37629 .54105 L p
1 g
F P
s
P
p
.002 w
.37629 .54105 m .40107 .56347 L .39392 .57836 L p
1 g
F P
s
P
p
.002 w
.43182 .59638 m .39392 .57836 L .40107 .56347 L p
1 g
F P
s
P
p
.002 w
.35029 .39764 m .33402 .43378 L .31949 .41849 L p
1 g
F P
s
P
p
.002 w
.31949 .41849 m .33849 .37567 L .35029 .39764 L p
1 g
F P
s
P
p
.002 w
.47257 .60214 m .5121 .5948 L .52913 .60804 L p
1 g
F P
s
P
p
.002 w
.56963 .58457 m .52913 .60804 L .5121 .5948 L p
1 g
F P
s
P
p
.002 w
.35141 .48105 m .35914 .51263 L .34078 .51401 L p
1 g
F P
s
P
p
.002 w
.34078 .51401 m .33086 .47396 L .35141 .48105 L p
1 g
F P
s
P
p
.002 w
.54451 .28385 m .48318 .26812 L .4925 .25105 L p
1 g
F P
s
P
p
.002 w
.4925 .25105 m .55636 .26726 L .54451 .28385 L p
1 g
F P
s
P
p
.002 w
.47257 .60214 m .43182 .59638 L .43101 .57765 L p
1 g
F P
s
P
p
.002 w
.40107 .56347 m .43101 .57765 L .43182 .59638 L p
1 g
F P
s
P
p
.002 w
.66311 .49051 m .6619 .42936 L .67829 .41863 L p
1 g
F P
s
P
p
.002 w
.65541 .35658 m .67829 .41863 L .6619 .42936 L p
1 g
F P
s
P
p
.002 w
.47404 .29071 m .41777 .29533 L .42254 .27338 L p
1 g
F P
s
P
p
.002 w
.42254 .27338 m .48318 .26812 L .47404 .29071 L p
1 g
F P
s
P
p
.002 w
.35405 .44948 m .35141 .48105 L .33086 .47396 L p
1 g
F P
s
P
p
.002 w
.33086 .47396 m .33402 .43378 L .35405 .44948 L p
1 g
F P
s
P
p
.002 w
.43101 .57765 m .46312 .58208 L .47257 .60214 L p
1 g
F P
s
P
p
.002 w
.5121 .5948 m .47257 .60214 L .46312 .58208 L p
1 g
F P
s
P
p
.002 w
.6239 .54877 m .6414 .49721 L .66311 .49051 L p
1 g
F P
s
P
p
.002 w
.6619 .42936 m .66311 .49051 L .6414 .49721 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.41535 .32209 m .37148 .34217 L .36862 .31819 L p
1 g
F P
s
P
p
.002 w
.36862 .31819 m .41777 .29533 L .41535 .32209 L p
1 g
F P
s
P
p
.002 w
.59899 .31914 m .54451 .28385 L .55636 .26726 L p
1 g
F P
s
P
p
.002 w
.55636 .26726 m .61305 .3039 L .59899 .31914 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.6619 .42936 m .63977 .36976 L .65541 .35658 L p
1 g
F P
s
P
p
.002 w
.61305 .3039 m .65541 .35658 L .63977 .36976 L p
1 g
F P
s
P
p
.002 w
.56963 .58457 m .59941 .54807 L .6239 .54877 L p
1 g
F P
s
P
p
.002 w
.6414 .49721 m .6239 .54877 L .59941 .54807 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37834 .36955 m .35029 .39764 L .33849 .37567 L p
1 g
F P
s
P
p
.002 w
.33849 .37567 m .37148 .34217 L .37834 .36955 L p
1 g
F P
s
P
p
.002 w
.63977 .36976 m .59899 .31914 L .61305 .3039 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.5121 .5948 m .54624 .57476 L .56963 .58457 L p
1 g
F P
s
P
p
.002 w
.59941 .54807 m .56963 .58457 L .54624 .57476 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.36699 .42125 m .35405 .44948 L .33402 .43378 L p
1 g
F P
s
P
p
.002 w
.33402 .43378 m .35029 .39764 L .36699 .42125 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.38241 .50871 m .39427 .52844 L .37629 .54105 L p
1 g
F P
s
P
p
.002 w
.37629 .54105 m .35914 .51263 L .38241 .50871 L p
1 g
F P
s
P
p
.002 w
.40107 .56347 m .37629 .54105 L .39427 .52844 L p
1 g
F P
s
P
p
.002 w
.39427 .52844 m .41148 .544 L .40107 .56347 L p
1 g
F P
s
P
p
.002 w
.43101 .57765 m .40107 .56347 L .41148 .544 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46312 .58208 m .47486 .57984 L p
.5121 .5948 L 1 g
F P
s
P
p
.002 w
.47486 .57984 m .48112 .57864 L p
.48431 .58031 L 1 g
F P
s
P
p
.5121 .5948 m .47486 .57984 L .48431 .58031 L 1 g
F
P
p
.51079 .57862 m .49879 .58102 L .49883 .58102 L 1 g
F
P
p
.002 w
.54072 .578 m .5121 .5948 L .50077 .58304 L p
1 g
F P
s
P
p
.002 w
.50077 .58304 m .49883 .58102 L p
.5109 .58015 L 1 g
F P
s
P
p
.54072 .578 m .50077 .58304 L .5109 .58015 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58015 L p
1 g
F P
s
P
p
.53128 .57265 m .5109 .58015 L .52388 .57644 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54624 .57476 m .54072 .578 L p
.52115 .57723 L 1 g
F P
s
P
p
.002 w
.53162 .57423 m .53128 .57265 L p
.52388 .57644 L 1 g
F P
s
P
p
.52808 .57525 m .52115 .57723 L .49414 .57616 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53162 .57423 L p
1 g
F P
s
P
p
.54624 .57476 m .52725 .57663 L .52986 .5752 L 1 g
F
P
p
.54854 .56129 m .53162 .57423 L .53861 .57041 L 1 g
F
P
p
.002 w
.5659 .55031 m .54624 .57476 L .54157 .5721 L p
1 g
F P
s
P
p
.002 w
.54157 .5721 m .53861 .57041 L p
.54907 .56271 L 1 g
F P
s
P
p
.5659 .55031 m .54157 .5721 L .54907 .56271 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54907 .56271 L p
1 g
F P
s
P
p
.56075 .54566 m .54907 .56271 L .55643 .55349 L 1 g
F
P
p
.54854 .56129 m .53861 .57041 L .54018 .56926 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49414 .57616 m .52078 .56027 L .53861 .57041 L p
1 g
F P
s
P
p
.002 w
.53861 .57041 m .54624 .57476 L p
.52986 .5752 L 1 g
F P
s
P
p
.52986 .5752 m .49414 .57616 L .53861 .57041 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54968 .56436 L p
1 g
F P
s
P
p
.002 w
.54968 .56436 m .54854 .56129 L p
.53945 .56996 L 1 g
F P
s
P
p
.53945 .56996 m .5322 .57686 L .54968 .56436 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56152 .54712 m .56075 .54566 L p
.55643 .55349 L 1 g
F P
s
P
p
.002 w
.53861 .57041 m .52078 .56027 L p
.55749 .55217 L 1 g
F P
s
P
p
.5659 .55031 m .54907 .56271 L .55749 .55217 L 1 g
F
P
p
.54907 .56271 m .53861 .57041 L .55749 .55217 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.57117 .54377 m .5659 .55031 L p
.55978 .55166 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56152 .54712 L p
1 g
F P
s
P
p
.56654 .52734 m .56152 .54712 L .56354 .54183 L 1 g
F
P
p
.58378 .50491 m .56761 .53441 L .57114 .51386 L 1 g
F
P
p
.56761 .53441 m .56354 .54183 L .56721 .52832 L 1 g
F
P
p
.56761 .53441 m .56721 .52832 L .57114 .51386 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56721 .52832 L p
1 g
F P
s
P
p
.56515 .50826 m .56721 .52832 L .56644 .51664 L 1 g
F
P
p
.56654 .52734 m .56354 .54183 L .56461 .53791 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.58378 .50491 m .57117 .54377 L .56354 .54183 L p
1 g
F P
s
P
p
.57117 .54377 m .55978 .55166 L .56161 .5469 L 1 g
F
P
p
.002 w
.56354 .54183 m .57117 .54377 L p
.56161 .5469 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56818 .52972 L p
1 g
F P
s
P
p
.002 w
.56818 .52972 m .56654 .52734 L p
.56421 .54009 L 1 g
F P
s
P
p
.56421 .54009 m .56257 .5491 L .56818 .52972 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52078 .56027 m .54007 .53588 L .56354 .54183 L p
1 g
F P
s
P
p
.56161 .5469 m .52078 .56027 L .56354 .54183 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56354 .54183 m .54007 .53588 L p
.56648 .51717 L 1 g
F P
s
P
p
.57114 .51386 m .56721 .52832 L .56648 .51717 L 1 g
F
P
p
.56721 .52832 m .56354 .54183 L .56648 .51717 L 1 g
F
P
p
.002 w
.56595 .50922 m .56515 .50826 L p
.56644 .51664 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50922 L p
1 g
F P
s
P
p
.55661 .4905 m .56595 .50922 L .56412 .50523 L 1 g
F
P
p
.58226 .46239 m .56412 .50523 L .55852 .49376 L 1 g
F
P
p
.56142 .4997 m .56412 .50523 L .56276 .50226 L 1 g
F
P
p
.55661 .4905 m .56412 .50523 L .56142 .4997 L 1 g
F
P
p
.002 w
.58226 .46239 m .58378 .50491 L .56412 .50523 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56412 .50523 m .58378 .50491 L p
.56884 .51549 L 1 g
F P
s
P
p
.002 w
.54825 .47232 m .58226 .46239 L p
.55911 .49298 L 1 g
F P
s
P
p
.55911 .49298 m .55852 .49376 L .55731 .49124 L 1 g
F
P
p
.55911 .49298 m .55731 .49124 L .54825 .47232 L 1 g
F
P
p
.002 w
.55726 .49119 m .55661 .4905 L p
.56142 .4997 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55726 .49119 L p
1 g
F P
s
P
p
.002 w
.54827 .47281 m .54825 .47232 L p
.55731 .49124 L 1 g
F P
s
P
p
.55852 .49376 m .55726 .49119 L .55731 .49124 L 1 g
F
P
p
.55726 .49119 m .54827 .47281 L .55731 .49124 L 1 g
F
P
p
.002 w
.55735 .49137 m .55834 .49233 L .55726 .49119 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .55736 .49138 L p
.56713 .51061 L 1 g
F P
s
P
p
.56142 .4997 m .56713 .51061 L .55726 .49119 L 1 g
F
P
p
.54174 .47608 m .55029 .48445 L .5487 .48292 L 1 g
F
P
p
.002 w
.54966 .50546 m .51358 .50369 L p
.54284 .47722 L 1 g
F P
s
P
p
.002 w
.5487 .48292 m .54966 .50546 L p
.54284 .47722 L 1 g
F P
s
P
p
.002 w
.54237 .47676 m .54174 .47608 L p
.5487 .48292 L 1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47676 L p
1 g
F P
s
P
p
.002 w
.51358 .50369 m .51245 .48103 L .53816 .47477 L p
1 g
F P
s
P
p
.53911 .47522 m .51358 .50369 L .53816 .47477 L 1 g
F
P
p
.52214 .46667 m .54237 .47676 L .53816 .47477 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53816 .47477 m .51245 .48103 L p
.52055 .46687 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46712 L .512 .46571 L 1 g
F
P
p
.52084 .46636 m .52241 .46712 L .52055 .46687 L 1 g
F
P
p
.52241 .46712 m .53816 .47477 L .52055 .46687 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50384 .45914 m .53579 .44023 L p
.52055 .46687 L 1 g
F P
s
P
p
.002 w
.51245 .48103 m .50611 .46491 L p
.52055 .46687 L 1 g
F P
s
P
p
.5 .4634 m .512 .46571 L .50611 .46491 L 1 g
F
P
p
.002 w
.50611 .46491 m .51245 .48103 L p
.49951 .464 L 1 g
F P
s
P
p
.50611 .46491 m .49951 .464 L .5 .46393 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46393 L p
1 g
F P
s
P
p
.002 w
.51245 .48103 m .47626 .48815 L p
.49917 .46405 L 1 g
F P
s
P
p
.49951 .464 m .51245 .48103 L .49917 .46405 L 1 g
F
P
p
.47786 .46667 m .5 .46393 L .49362 .46488 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.49362 .46488 m .47185 .47711 L p
.47608 .46792 L 1 g
F P
s
P
p
.47755 .46719 m .49362 .46488 L .47608 .46792 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47755 .46719 L p
1 g
F P
s
P
p
.45826 .47608 m .47755 .46719 L .46964 .47109 L 1 g
F
P
p
.45826 .47608 m .46964 .47109 L .46771 .47204 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46771 .47204 m .47185 .47711 L p
.45641 .47795 L 1 g
F P
s
P
p
.46771 .47204 m .45641 .47795 L .45764 .47675 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45764 .47675 L p
1 g
F P
s
P
p
.45641 .47795 m .47185 .47711 L .44528 .48875 L 1 g
F
P
p
.002 w
.45764 .47675 m .45698 .47747 L p
.45048 .4837 L 1 g
F P
s
P
p
.44339 .4905 m .45764 .47675 L .45048 .4837 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42493 .52042 m .44107 .49344 L .44086 .4947 L p
1 g
F P
s
P
p
.002 w
.43393 .50936 m .43485 .50826 L p
.43868 .49931 L 1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43258 .524 m .42801 .52186 L p
.43393 .50936 L 1 g
F P
s
P
p
.002 w
.42801 .52186 m .42493 .52042 L p
.4343 .50529 L 1 g
F P
s
P
p
.43393 .50936 m .4343 .50529 L .44086 .4947 L 1 g
F
P
p
.42801 .52186 m .4343 .50529 L .43393 .50936 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43393 .50936 L p
1 g
F P
s
P
p
.002 w
.43393 .50936 m .43287 .51061 L p
.43313 .51799 L 1 g
F P
s
P
p
.43346 .52734 m .43393 .50936 L .43313 .51799 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.43226 .55379 m .43172 .55135 L .43424 .53464 L 1 g
F
P
p
.002 w
.43445 .53533 m .43226 .55379 L p
.43424 .53464 L 1 g
F P
s
P
p
.002 w
.42493 .52042 m .43064 .52309 L p
.43172 .55135 L 1 g
F P
s
P
p
.002 w
.43064 .52309 m .43258 .524 L p
.43243 .52884 L 1 g
F P
s
P
p
.43172 .55135 m .43064 .52309 L .43243 .52884 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43243 .52884 L p
1 g
F P
s
P
p
.43925 .54566 m .43243 .52884 L .43445 .53533 L 1 g
F
P
p
.002 w
.44094 .55496 m .43226 .55379 L .4338 .5408 L p
1 g
F P
s
P
p
.002 w
.4338 .5408 m .43445 .53533 L p
.4384 .54726 L 1 g
F P
s
P
p
.44094 .55496 m .4338 .5408 L .4384 .54726 L 1 g
F
P
p
.45146 .56129 m .44339 .55427 L .44418 .55539 L 1 g
F
P
p
.002 w
.46036 .57399 m .46312 .58208 L p
.44837 .56129 L 1 g
F P
s
P
p
.44837 .56129 m .44418 .55539 L .45082 .56302 L 1 g
F
P
p
.44837 .56129 m .45082 .56302 L .46036 .57399 L 1 g
F
P
p
.002 w
.43226 .55379 m .43901 .5547 L p
.46312 .58208 L 1 g
F P
s
P
p
.002 w
.43901 .5547 m .44418 .55539 L p
.44837 .56129 L 1 g
F P
s
P
p
.46312 .58208 m .43901 .5547 L .44837 .56129 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45082 .56302 L p
1 g
F P
s
P
p
.46872 .57265 m .45082 .56302 L .45846 .5684 L 1 g
F
P
p
.002 w
.4766 .57951 m .46312 .58208 L .45953 .57156 L p
1 g
F P
s
P
p
.002 w
.45953 .57156 m .45846 .5684 L p
.46833 .57445 L 1 g
F P
s
P
p
.4766 .57951 m .45953 .57156 L .46833 .57445 L 1 g
F
P
p
.002 w
.48907 .58054 m .48921 .57862 L p
.47832 .57773 L 1 g
F P
s
P
p
.47832 .57773 m .48112 .57864 L .48907 .58054 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48112 .57864 m .4766 .57951 L p
.47324 .57606 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46833 .57445 L p
1 g
F P
s
P
p
.4766 .57951 m .46833 .57445 L .47324 .57606 L 1 g
F
P
p
.002 w
.46833 .57445 m .4678 .57686 L p
.47832 .57773 L 1 g
F P
s
P
p
.48921 .57862 m .46833 .57445 L .47832 .57773 L 1 g
F
P
p
.46872 .57265 m .45846 .5684 L .45916 .56883 L 1 g
F
P
p
.002 w
.46816 .57523 m .46872 .57265 L p
.45895 .56875 L 1 g
F P
s
P
p
.002 w
.45846 .5684 m .45449 .55677 L p
.47324 .57606 L 1 g
F P
s
P
p
.46833 .57445 m .45846 .5684 L .47324 .57606 L 1 g
F
P
p
.002 w
.49414 .57616 m .48112 .57864 L p
.45449 .55677 L 1 g
F P
s
P
p
.48112 .57864 m .47324 .57606 L .45449 .55677 L 1 g
F
P
p
.47832 .57773 m .47672 .57759 L .48112 .57864 L 1 g
F
P
p
.002 w
.50114 .58342 m .5121 .5948 L p
.48431 .58031 L 1 g
F P
s
P
p
.48431 .58031 m .48112 .57864 L .48907 .58054 L 1 g
F
P
p
.48431 .58031 m .48907 .58054 L .50114 .58342 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58054 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58054 L .49879 .58102 L 1 g
F
P
p
.002 w
.48112 .57864 m .49414 .57616 L .49883 .58102 L p
1 g
F P
s
P
p
.002 w
.49883 .58102 m .50114 .58342 L p
.48907 .58054 L 1 g
F P
s
P
p
.48907 .58054 m .48112 .57864 L .49883 .58102 L 1 g
F
P
p
.002 w
.48907 .58054 m .48889 .583 L p
.49879 .58102 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58123 L p
1 g
F P
s
P
p
.002 w
.48902 .58123 m .48907 .58054 L p
.48448 .57975 L 1 g
F P
s
P
p
.48448 .57975 m .4678 .57686 L .48902 .58123 L 1 g
F
P
p
.45916 .56883 m .45846 .5684 L .45895 .56875 L 1 g
F
P
p
.002 w
.45082 .56302 m .45146 .56129 L p
.44418 .55539 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4384 .54726 L p
1 g
F P
s
P
p
.45146 .56129 m .4384 .54726 L .44339 .55427 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45449 .55677 m .44418 .55539 L p
.43563 .52543 L 1 g
F P
s
P
p
.002 w
.44418 .55539 m .44094 .55496 L p
.43995 .54944 L 1 g
F P
s
P
p
.44418 .55539 m .43995 .54944 L .43563 .52543 L 1 g
F
P
p
.43925 .54566 m .43445 .53533 L .43526 .53776 L 1 g
F
P
p
.002 w
.43826 .54753 m .43925 .54566 L p
.43514 .53752 L 1 g
F P
s
P
p
.002 w
.43445 .53533 m .43563 .52543 L p
.44094 .55496 L 1 g
F P
s
P
p
.002 w
.4384 .54726 m .43743 .5491 L p
.44339 .55427 L 1 g
F P
s
P
p
.002 w
.44418 .55539 m .45449 .55677 L .46036 .57399 L p
1 g
F P
s
P
p
.002 w
.45082 .56302 m .45002 .56518 L p
.45895 .56875 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46816 .57523 L p
1 g
F P
s
P
p
.45895 .56875 m .45002 .56518 L .46816 .57523 L 1 g
F
P
p
.002 w
.4504 .56414 m .45082 .56302 L p
.44418 .55539 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4504 .56414 L p
1 g
F P
s
P
p
.44339 .55427 m .43743 .5491 L .4504 .56414 L 1 g
F
P
p
.43526 .53776 m .43445 .53533 L .43514 .53752 L 1 g
F
P
p
.43346 .52734 m .43313 .51799 L .43258 .524 L 1 g
F
P
p
.002 w
.43243 .52884 m .43346 .52734 L p
.43258 .524 L 1 g
F P
s
P
p
.002 w
.43258 .524 m .43563 .52543 L p
.43172 .55135 L 1 g
F P
s
P
p
.002 w
.43243 .52884 m .43146 .53025 L p
.43514 .53752 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43826 .54753 L p
1 g
F P
s
P
p
.43514 .53752 m .43146 .53025 L .43826 .54753 L 1 g
F
P
p
.002 w
.43563 .52543 m .43445 .53533 L p
.43424 .53464 L 1 g
F P
s
P
p
.002 w
.43209 .52933 m .43243 .52884 L p
.43258 .524 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43209 .52933 L p
1 g
F P
s
P
p
.43313 .51799 m .43287 .51061 L .43209 .52933 L 1 g
F
P
p
.002 w
.4416 .49316 m .44107 .49344 L .44195 .49247 L p
1 g
F P
s
P
p
.002 w
.44107 .49344 m .45407 .46103 L .45682 .46285 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44241 .49154 L p
1 g
F P
s
P
p
.43485 .50826 m .44241 .49154 L .44236 .49165 L 1 g
F
P
p
.002 w
.44195 .49247 m .44107 .49344 L p
.44169 .49224 L 1 g
F P
s
P
p
.45682 .46285 m .44241 .49154 L .44169 .49224 L 1 g
F
P
p
.44241 .49154 m .44195 .49247 L .44169 .49224 L 1 g
F
P
p
.44339 .4905 m .45048 .4837 L .44528 .48875 L 1 g
F
P
p
.002 w
.44241 .49154 m .44339 .4905 L p
.44528 .48875 L 1 g
F P
s
P
p
.44228 .4918 m .4424 .49155 L .44233 .49171 L 1 g
F
P
p
.43485 .50826 m .44236 .49165 L .44228 .4918 L 1 g
F
P
p
.44236 .49165 m .4424 .49155 L .44228 .4918 L 1 g
F
P
p
.43485 .50826 m .44239 .49156 L .44228 .49178 L 1 g
F
P
p
.43485 .50826 m .44237 .49158 L .44224 .49185 L 1 g
F
P
p
.43485 .50826 m .44235 .4916 L .44221 .4919 L 1 g
F
P
p
.43485 .50826 m .44233 .49163 L .44219 .49192 L 1 g
F
P
p
.002 w
.44528 .48875 m .44195 .49247 L p
.44241 .49154 L 1 g
F P
s
P
p
.43485 .50826 m .44231 .49164 L .44219 .49189 L 1 g
F
P
p
.43485 .50826 m .4423 .49166 L .43873 .49918 L 1 g
F
P
p
.002 w
.47185 .47711 m .4416 .49316 L p
.44528 .48875 L 1 g
F P
s
P
p
.002 w
.44195 .49247 m .44528 .48875 L p
.4416 .49316 L 1 g
F P
s
P
p
.44528 .48875 m .45698 .47747 L .44241 .49154 L 1 g
F
P
p
.45048 .4837 m .45051 .48368 L .44528 .48875 L 1 g
F
P
p
.45051 .48368 m .45698 .47747 L .44528 .48875 L 1 g
F
P
p
.002 w
.45682 .46285 m .46417 .46772 L .44528 .48875 L p
1 g
F P
s
P
p
.45682 .46285 m .44528 .48875 L .44241 .49154 L 1 g
F
P
p
.002 w
.44241 .49154 m .44241 .49154 L p
.44528 .48875 L 1 g
F P
s
P
p
.002 w
.44241 .49154 m .4424 .49155 L p
.44236 .49165 L 1 g
F P
s
P
p
.002 w
.4424 .49155 m .44239 .49156 L p
.44233 .49171 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.47185 .47711 m .47626 .48815 L .44149 .49338 L p
1 g
F P
s
P
p
.002 w
.44149 .49338 m .44107 .49344 L .4416 .49316 L p
1 g
F P
s
P
p
.002 w
.4416 .49316 m .47185 .47711 L p
.44149 .49338 L 1 g
F P
s
P
p
.002 w
.47626 .48815 m .47691 .49963 L .44143 .4935 L p
1 g
F P
s
P
p
.002 w
.44143 .4935 m .44107 .49344 L .44149 .49338 L p
1 g
F P
s
P
p
.002 w
.44149 .49338 m .47626 .48815 L p
.44143 .4935 L 1 g
F P
s
P
p
.002 w
.44239 .49156 m .44237 .49158 L p
.44228 .49178 L 1 g
F P
s
P
p
.002 w
.44237 .49158 m .44235 .4916 L p
.44224 .49185 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.47691 .49963 m .47377 .51027 L .44138 .4936 L p
1 g
F P
s
P
p
.002 w
.44138 .4936 m .44107 .49344 L .44143 .4935 L p
1 g
F P
s
P
p
.002 w
.44143 .4935 m .47691 .49963 L p
.44138 .4936 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.47377 .51027 m .4672 .51892 L .44134 .4937 L p
1 g
F P
s
P
p
.002 w
.44134 .4937 m .44107 .49344 L .44138 .4936 L p
1 g
F P
s
P
p
.002 w
.44138 .4936 m .47377 .51027 L p
.44134 .4937 L 1 g
F P
s
P
p
.002 w
.44235 .4916 m .44233 .49163 L p
.44221 .4919 L 1 g
F P
s
P
p
.002 w
.44233 .49163 m .44231 .49164 L p
.44219 .49192 L 1 g
F P
s
P
p
.002 w
.4672 .51892 m .45795 .52466 L .44128 .49382 L p
1 g
F P
s
P
p
.002 w
.44128 .49382 m .44107 .49344 L .44134 .4937 L p
1 g
F P
s
P
p
.002 w
.44134 .4937 m .4672 .51892 L p
.44128 .49382 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45795 .52466 m .44703 .5269 L .44118 .49403 L p
1 g
F P
s
P
p
.002 w
.44118 .49403 m .44107 .49344 L .44128 .49382 L p
1 g
F P
s
P
p
.002 w
.44128 .49382 m .45795 .52466 L p
.44118 .49403 L 1 g
F P
s
P
p
.002 w
.44231 .49164 m .4423 .49166 L p
.44219 .49189 L 1 g
F P
s
P
p
.002 w
.44086 .4947 m .44107 .49344 L .44118 .49403 L p
1 g
F P
s
P
p
.002 w
.4423 .49166 m .44166 .49233 L p
.43873 .49918 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44703 .5269 m .43563 .52543 L .44086 .4947 L p
1 g
F P
s
P
p
.002 w
.44118 .49403 m .44703 .5269 L p
.44086 .4947 L 1 g
F P
s
P
p
.002 w
.44086 .4947 m .43563 .52543 L .43258 .524 L p
1 g
F P
s
P
p
.43258 .524 m .43393 .50936 L .44086 .4947 L 1 g
F
P
p
.002 w
.43287 .51061 m .43393 .50936 L p
.43961 .49713 L 1 g
F P
s
P
p
.43868 .49931 m .43961 .49713 L .43393 .50936 L 1 g
F
P
p
.002 w
.44166 .49233 m .43332 .50968 L p
.43961 .49713 L 1 g
F P
s
P
p
.002 w
.43332 .50968 m .43287 .51061 L p
.43961 .49713 L 1 g
F P
s
P
p
.002 w
.44528 .48875 m .45491 .47803 L p
.45641 .47795 L 1 g
F P
s
P
p
.45764 .47675 m .45641 .47795 L .45491 .47803 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44241 .49154 L p
1 g
F P
s
P
p
.002 w
.45722 .47721 m .45764 .47675 L p
.46771 .47204 L 1 g
F P
s
P
p
.002 w
.45764 .47675 m .45826 .47608 L p
.46771 .47204 L 1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45491 .47803 m .46417 .46772 L .46771 .47204 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.47185 .47711 m .46417 .46772 L .48866 .44053 L p
1 g
F P
s
P
p
.002 w
.47755 .46719 m .47718 .46778 L p
.46964 .47109 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.48866 .44053 m .49258 .45978 L .47633 .46737 L 1 g
F
P
p
.47786 .46667 m .49362 .46488 L .48915 .46552 L 1 g
F
P
p
.002 w
.47749 .46728 m .47786 .46667 L p
.48964 .46547 L 1 g
F P
s
P
p
.49258 .45978 m .49362 .46488 L .47755 .46719 L 1 g
F
P
p
.49258 .45978 m .47755 .46719 L .47633 .46737 L 1 g
F
P
p
.47633 .46737 m .47755 .46719 L .47608 .46792 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45722 .47721 L p
1 g
F P
s
P
p
.46964 .47109 m .47718 .46778 L .45722 .47721 L 1 g
F
P
p
.48915 .46552 m .49362 .46488 L .48964 .46547 L 1 g
F
P
p
.002 w
.48866 .44053 m .50384 .45914 L .49362 .46488 L p
1 g
F P
s
P
p
.002 w
.47626 .48815 m .47185 .47711 L .50384 .45914 L p
1 g
F P
s
P
p
.002 w
.5 .46393 m .5 .46442 L p
.48964 .46547 L 1 g
F P
s
P
p
.49938 .46383 m .49951 .464 L .49917 .46405 L 1 g
F
P
p
.5 .46393 m .49951 .464 L .49938 .46383 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47749 .46728 L p
1 g
F P
s
P
p
.48964 .46547 m .5 .46442 L .47749 .46728 L 1 g
F
P
p
.002 w
.5 .46408 m .5 .46393 L p
.50611 .46491 L 1 g
F P
s
P
p
.002 w
.5 .46393 m .5 .4634 L p
.50611 .46491 L 1 g
F P
s
P
p
.002 w
.50384 .45914 m .50611 .46491 L p
.49938 .46383 L 1 g
F P
s
P
p
.002 w
.50611 .46491 m .50384 .45914 L p
.52055 .46687 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46408 L p
1 g
F P
s
P
p
.512 .46571 m .52282 .46778 L .5 .46408 L 1 g
F
P
p
.002 w
.52241 .46712 m .52282 .46778 L p
.512 .46571 L 1 g
F P
s
P
p
.53216 .47186 m .53816 .47477 L .53392 .47277 L 1 g
F
P
p
.52214 .46667 m .53816 .47477 L .53216 .47186 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53579 .44023 m .54825 .47232 L .53816 .47477 L p
1 g
F P
s
P
p
.54284 .47722 m .51358 .50369 L .53911 .47522 L 1 g
F
P
p
.54237 .47676 m .53911 .47522 L .53989 .47436 L 1 g
F
P
p
.54284 .47722 m .53911 .47522 L .54237 .47676 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52259 .46741 L p
1 g
F P
s
P
p
.002 w
.52259 .46741 m .52214 .46667 L p
.53392 .47277 L 1 g
F P
s
P
p
.53392 .47277 m .54302 .47747 L .52259 .46741 L 1 g
F
P
p
.53579 .44023 m .53816 .47477 L .52084 .46636 L 1 g
F
P
p
.002 w
.54237 .47676 m .54302 .47747 L p
.53392 .47277 L 1 g
F P
s
P
p
.002 w
.53816 .47477 m .53989 .47436 L p
.53911 .47522 L 1 g
F P
s
P
p
.54174 .47608 m .55726 .49119 L .55029 .48445 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53989 .47436 m .54825 .47232 L p
.54284 .47722 L 1 g
F P
s
P
p
.002 w
.54966 .50546 m .5487 .48292 L p
.55852 .49376 L 1 g
F P
s
P
p
.002 w
.5487 .48292 m .54827 .47281 L p
.55726 .49119 L 1 g
F P
s
P
p
.55852 .49376 m .5487 .48292 L .55726 .49119 L 1 g
F
P
p
.5487 .48292 m .55834 .49233 L .54259 .47701 L 1 g
F
P
p
.55029 .48445 m .55116 .48531 L .5487 .48292 L 1 g
F
P
p
.55116 .48531 m .55834 .49233 L .5487 .48292 L 1 g
F
P
p
.002 w
.54259 .47701 m .54237 .47676 L p
.5487 .48292 L 1 g
F P
s
P
p
.002 w
.54825 .47232 m .5487 .48292 L p
.54284 .47722 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54259 .47701 L p
1 g
F P
s
P
p
.002 w
.55726 .49119 m .55834 .49233 L p
.55029 .48445 L 1 g
F P
s
P
p
.002 w
.56412 .50523 m .54966 .50546 L p
.55852 .49376 L 1 g
F P
s
P
p
.002 w
.54007 .53588 m .54966 .50546 L .56412 .50523 L p
1 g
F P
s
P
p
.56884 .51549 m .54007 .53588 L .56412 .50523 L 1 g
F
P
p
.002 w
.56595 .50922 m .56713 .51061 L p
.56276 .50226 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50922 L p
1 g
F P
s
P
p
.56644 .51664 m .56854 .53025 L .56595 .50922 L 1 g
F
P
p
.002 w
.56721 .52832 m .56854 .53025 L p
.56644 .51664 L 1 g
F P
s
P
p
.56461 .53791 m .56354 .54183 L .56421 .54009 L 1 g
F
P
p
.56161 .5469 m .55978 .55166 L .52078 .56027 L 1 g
F
P
p
.002 w
.56152 .54712 m .56257 .5491 L p
.56421 .54009 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56152 .54712 L p
1 g
F P
s
P
p
.55643 .55349 m .54998 .56518 L .56152 .54712 L 1 g
F
P
p
.002 w
.54907 .56271 m .54998 .56518 L p
.55643 .55349 L 1 g
F P
s
P
p
.54018 .56926 m .53861 .57041 L .53945 .56996 L 1 g
F
P
p
.002 w
.53162 .57423 m .5322 .57686 L p
.53945 .56996 L 1 g
F P
s
P
p
.52986 .5752 m .52115 .57723 L .52808 .57525 L 1 g
F
P
p
.52725 .57663 m .52115 .57723 L .52986 .5752 L 1 g
F
P
p
.002 w
.5109 .58015 m .51079 .57862 L p
.49883 .58102 L 1 g
F P
s
P
p
.002 w
.49883 .58102 m .49414 .57616 L p
.54072 .578 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53162 .57423 L p
1 g
F P
s
P
p
.52388 .57644 m .51111 .583 L .53162 .57423 L 1 g
F
P
p
.002 w
.5109 .58015 m .51111 .583 L p
.52388 .57644 L 1 g
F P
s
P
p
.002 w
.51101 .58162 m .5109 .58015 L p
.49883 .58102 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51101 .58162 L p
1 g
F P
s
P
p
.49879 .58102 m .48889 .583 L .51101 .58162 L 1 g
F
P
p
.47672 .57759 m .4678 .57686 L .48907 .58054 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.53091 .30549 m .47404 .29071 L .48318 .26812 L p
1 g
F P
s
P
p
.002 w
.48318 .26812 m .54451 .28385 L .53091 .30549 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.37715 .48683 m .38241 .50871 L .35914 .51263 L p
1 g
F P
s
P
p
.002 w
.35914 .51263 m .35141 .48105 L .37715 .48683 L p
1 g
F P
s
P
p
.002 w
.46312 .58208 m .43101 .57765 L .43226 .55379 L p
1 g
F P
s
P
p
.002 w
.41148 .544 m .43226 .55379 L .43101 .57765 L p
1 g
F P
s
P
p
.002 w
.6414 .49721 m .64002 .44049 L .6619 .42936 L p
1 g
F P
s
P
p
.002 w
.63977 .36976 m .6619 .42936 L .64002 .44049 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.004 w
.48957 .44164 m
.5 .43051 L
s
P
p
.002 w
.46543 .31825 m .41535 .32209 L .41777 .29533 L p
1 g
F P
s
P
p
.002 w
.41777 .29533 m .47404 .29071 L .46543 .31825 L p
1 g
F P
s
P
p
.002 w
.3791 .46505 m .37715 .48683 L .35141 .48105 L p
1 g
F P
s
P
p
.002 w
.35141 .48105 m .35405 .44948 L .3791 .46505 L p
1 g
F P
s
P
p
.002 w
.59941 .54807 m .6147 .5021 L .6414 .49721 L p
1 g
F P
s
P
p
.002 w
.64002 .44049 m .6414 .49721 L .6147 .5021 L p
1 g
F P
s
P
p
.002 w
.41546 .35289 m .37834 .36955 L .37148 .34217 L p
1 g
F P
s
P
p
.002 w
.37148 .34217 m .41535 .32209 L .41546 .35289 L p
1 g
F P
s
P
p
.002 w
.54624 .57476 m .57117 .54377 L .59941 .54807 L p
1 g
F P
s
P
p
.002 w
.6147 .5021 m .59941 .54807 L .57117 .54377 L p
1 g
F P
s
P
p
.002 w
.38911 .39946 m .36699 .42125 L .35029 .39764 L p
1 g
F P
s
P
p
.002 w
.35029 .39764 m .37834 .36955 L .38911 .39946 L p
1 g
F P
s
P
p
.002 w
.58143 .3383 m .53091 .30549 L .54451 .28385 L p
1 g
F P
s
P
p
.002 w
.54451 .28385 m .59899 .31914 L .58143 .3383 L p
1 g
F P
s
P
p
.002 w
.64002 .44049 m .61932 .38525 L .63977 .36976 L p
1 g
F P
s
P
p
.002 w
.59899 .31914 m .63977 .36976 L .61932 .38525 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61932 .38525 m .58143 .3383 L .59899 .31914 L p
1 g
F P
s
P
p
.002 w
.38817 .44569 m .3791 .46505 L .35405 .44948 L p
1 g
F P
s
P
p
.002 w
.35405 .44948 m .36699 .42125 L .38817 .44569 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.45449 .55677 m .47587 .55255 L .49414 .57616 L p
1 g
F P
s
P
p
.002 w
.52078 .56027 m .49414 .57616 L .47587 .55255 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41001 .50227 m .41609 .51242 L .39427 .52844 L p
1 g
F P
s
P
p
.002 w
.39427 .52844 m .38241 .50871 L .41001 .50227 L p
1 g
F P
s
P
p
.002 w
.41148 .544 m .39427 .52844 L .41609 .51242 L p
1 g
F P
s
P
p
.002 w
.41609 .51242 m .42493 .52042 L .41148 .544 L p
1 g
F P
s
P
p
.002 w
.43226 .55379 m .41148 .544 L .42493 .52042 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.51597 .33159 m .46543 .31825 L .47404 .29071 L p
1 g
F P
s
P
p
.002 w
.47404 .29071 m .53091 .30549 L .51597 .33159 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40736 .49103 m .41001 .50227 L .38241 .50871 L p
1 g
F P
s
P
p
.002 w
.38241 .50871 m .37715 .48683 L .40736 .49103 L p
1 g
F P
s
P
p
.002 w
.6147 .5021 m .61321 .45164 L .64002 .44049 L p
1 g
F P
s
P
p
.002 w
.61932 .38525 m .64002 .44049 L .61321 .45164 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45769 .34992 m .41546 .35289 L .41535 .32209 L p
1 g
F P
s
P
p
.002 w
.41535 .32209 m .46543 .31825 L .45769 .34992 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41819 .3867 m .38911 .39946 L .37834 .36955 L p
1 g
F P
s
P
p
.002 w
.37834 .36955 m .41546 .35289 L .41819 .3867 L p
1 g
F P
s
P
p
.002 w
.57117 .54377 m .58378 .50491 L .6147 .5021 L p
1 g
F P
s
P
p
.002 w
.61321 .45164 m .6147 .5021 L .58378 .50491 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40844 .4799 m .40736 .49103 L .37715 .48683 L p
1 g
F P
s
P
p
.002 w
.37715 .48683 m .3791 .46505 L .40844 .4799 L p
1 g
F P
s
P
p
.002 w
.43563 .52543 m .44703 .5269 L .45449 .55677 L p
1 g
F P
s
P
p
.002 w
.47587 .55255 m .45449 .55677 L .44703 .5269 L p
1 g
F P
s
P
p
.002 w
.40349 .43087 m .38817 .44569 L .36699 .42125 L p
1 g
F P
s
P
p
.002 w
.36699 .42125 m .38911 .39946 L .40349 .43087 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.47587 .55255 m .49411 .54146 L .52078 .56027 L p
1 g
F P
s
P
p
.002 w
.54007 .53588 m .52078 .56027 L .49411 .54146 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.56087 .36084 m .51597 .33159 L .53091 .30549 L p
1 g
F P
s
P
p
.002 w
.53091 .30549 m .58143 .3383 L .56087 .36084 L p
1 g
F P
s
P
p
.002 w
.61321 .45164 m .59462 .40256 L .61932 .38525 L p
1 g
F P
s
P
p
.002 w
.58143 .3383 m .61932 .38525 L .59462 .40256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41315 .47006 m .40844 .4799 L .3791 .46505 L p
1 g
F P
s
P
p
.002 w
.3791 .46505 m .38817 .44569 L .41315 .47006 L p
1 g
F P
s
P
p
.002 w
.44703 .5269 m .45795 .52466 L .47587 .55255 L p
1 g
F P
s
P
p
.002 w
.49411 .54146 m .47587 .55255 L .45795 .52466 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59462 .40256 m .56087 .36084 L .58143 .3383 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.50021 .36133 m .45769 .34992 L .46543 .31825 L p
1 g
F P
s
P
p
.002 w
.46543 .31825 m .51597 .33159 L .50021 .36133 L p
1 g
F P
s
P
p
.002 w
.41609 .51242 m .41001 .50227 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.42493 .52042 m .41609 .51242 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.58378 .50491 m .58226 .46239 L .61321 .45164 L p
1 g
F P
s
P
p
.002 w
.59462 .40256 m .61321 .45164 L .58226 .46239 L p
1 g
F P
s
P
p
.002 w
.42351 .4223 m .40349 .43087 L .38911 .39946 L p
1 g
F P
s
P
p
.002 w
.38911 .39946 m .41819 .3867 L .42351 .4223 L p
1 g
F P
s
P
p
.002 w
.41001 .50227 m .40736 .49103 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45114 .38461 m .41819 .3867 L .41546 .35289 L p
1 g
F P
s
P
p
.002 w
.41546 .35289 m .45769 .34992 L .45114 .38461 L p
1 g
F P
s
P
p
.002 w
.42103 .4626 m .41315 .47006 L .38817 .44569 L p
1 g
F P
s
P
p
.002 w
.38817 .44569 m .40349 .43087 L .42103 .4626 L p
1 g
F P
s
P
p
.002 w
.49411 .54146 m .50719 .52459 L .54007 .53588 L p
1 g
F P
s
P
p
.002 w
.54966 .50546 m .54007 .53588 L .50719 .52459 L p
1 g
F P
s
P
p
.002 w
.45795 .52466 m .4672 .51892 L .49411 .54146 L p
1 g
F P
s
P
p
.002 w
.50719 .52459 m .49411 .54146 L .4672 .51892 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.40736 .49103 m .40844 .4799 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.40844 .4799 m .41315 .47006 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.53797 .38603 m .50021 .36133 L .51597 .33159 L p
1 g
F P
s
P
p
.002 w
.51597 .33159 m .56087 .36084 L .53797 .38603 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.41315 .47006 m .42103 .4626 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .4578 m .45407 .46103 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.43123 .45835 m .44267 .4578 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.42103 .4626 m .43123 .45835 L .44107 .49344 L closepath p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58226 .46239 m .56644 .42112 L .59462 .40256 L p
1 g
F P
s
P
p
.002 w
.56087 .36084 m .59462 .40256 L .56644 .42112 L p
1 g
F P
s
P
p
.002 w
.43123 .45835 m .42103 .4626 L .40349 .43087 L p
1 g
F P
s
P
p
.002 w
.40349 .43087 m .42351 .4223 L .43123 .45835 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.4672 .51892 m .47377 .51027 L .50719 .52459 L p
1 g
F P
s
P
p
.002 w
.51358 .50369 m .50719 .52459 L .47377 .51027 L p
1 g
F P
s
P
p
.002 w
.50719 .52459 m .51358 .50369 L .54966 .50546 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.44606 .42104 m .42351 .4223 L .41819 .3867 L p
1 g
F P
s
P
p
.002 w
.41819 .3867 m .45114 .38461 L .44606 .42104 L p
1 g
F P
s
P
p
.002 w
.56644 .42112 m .53797 .38603 L .56087 .36084 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.48422 .39366 m .45114 .38461 L .45769 .34992 L p
1 g
F P
s
P
p
.002 w
.45769 .34992 m .50021 .36133 L .48422 .39366 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56644 .42112 m .58226 .46239 L .54825 .47232 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.47377 .51027 m .47691 .49963 L .51358 .50369 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.44267 .4578 m .43123 .45835 L .42351 .4223 L p
1 g
F P
s
P
p
.002 w
.42351 .4223 m .44606 .42104 L .44267 .4578 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51245 .48103 m .51358 .50369 L .47691 .49963 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.47691 .49963 m .47626 .48815 L .51245 .48103 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.51359 .41293 m .48422 .39366 L .50021 .36133 L p
1 g
F P
s
P
p
.002 w
.50021 .36133 m .53797 .38603 L .51359 .41293 L p
1 g
F P
s
P
p
.002 w
.54825 .47232 m .53579 .44023 L .56644 .42112 L p
1 g
F P
s
P
p
.002 w
.53797 .38603 m .56644 .42112 L .53579 .44023 L p
1 g
F P
s
P
p
.002 w
.46864 .42733 m .44606 .42104 L .45114 .38461 L p
1 g
F P
s
P
p
.002 w
.45114 .38461 m .48422 .39366 L .46864 .42733 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45407 .46103 m .44267 .4578 L .44606 .42104 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.53579 .44023 m .51359 .41293 L .53797 .38603 L p
1 g
F P
s
P
p
.002 w
.46417 .46772 m .45407 .46103 L .46864 .42733 L p
1 g
F P
s
P
p
.002 w
.44606 .42104 m .46864 .42733 L .45407 .46103 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46864 .42733 m .48866 .44053 L .46417 .46772 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.48866 .44053 m .46864 .42733 L .48422 .39366 L p
1 g
F P
s
P
p
.002 w
.48422 .39366 m .51359 .41293 L .48866 .44053 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51359 .41293 m .53579 .44023 L .50384 .45914 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.50384 .45914 m .48866 .44053 L .51359 .41293 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.40506 .5319 m
.42119 .51468 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .3079 .65993 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40506 .5319 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0405263)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0405263)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45354 .42577 m .46744 .44905 L .48917 .43075 L p
1 g
F P
s
P
p
.002 w
.48917 .43075 m .47974 .4149 L .45354 .42577 L p
1 g
F P
s
P
p
.002 w
.50311 .4429 m .48917 .43075 L .46744 .44905 L p
1 g
F P
s
P
p
.002 w
.47974 .4149 m .48917 .43075 L .51113 .41248 L p
1 g
F P
s
P
p
.002 w
.48917 .43075 m .50311 .4429 L .5182 .41864 L p
1 g
F P
s
P
p
.002 w
.5182 .41864 m .51113 .41248 L .48917 .43075 L p
1 g
F P
s
P
p
.002 w
.5201 .45005 m .50311 .4429 L .48792 .4669 L p
1 g
F P
s
P
p
.002 w
.46744 .44905 m .48792 .4669 L .50311 .4429 L p
1 g
F P
s
P
p
.002 w
.50311 .4429 m .5201 .45005 L .52682 .42225 L p
1 g
F P
s
P
p
.002 w
.52682 .42225 m .5182 .41864 L .50311 .4429 L p
1 g
F P
s
P
p
.002 w
.51113 .41248 m .50636 .40443 L .47974 .4149 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .50636 .40443 L .51113 .41248 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .51113 .41248 L .5182 .41864 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .5182 .41864 L .52682 .42225 L closepath p
1 g
F P
s
P
p
.002 w
.4477 .39946 m .45354 .42577 L .47974 .4149 L p
1 g
F P
s
P
p
.002 w
.47974 .4149 m .47583 .39699 L .4477 .39946 L p
1 g
F P
s
P
p
.002 w
.47583 .39699 m .47974 .4149 L .50636 .40443 L p
1 g
F P
s
P
p
.002 w
.50636 .40443 m .5044 .39535 L .47583 .39699 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .5044 .39535 L .50636 .40443 L closepath p
1 g
F P
s
P
p
.002 w
.48792 .4669 m .51287 .47747 L .5201 .45005 L p
1 g
F P
s
P
p
.002 w
.53835 .45145 m .5201 .45005 L .51287 .47747 L p
1 g
F P
s
P
p
.002 w
.5201 .45005 m .53835 .45145 L .53607 .42293 L p
1 g
F P
s
P
p
.002 w
.53607 .42293 m .52682 .42225 L .5201 .45005 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .52682 .42225 L .53607 .42293 L closepath p
1 g
F P
s
P
p
.002 w
.47788 .37892 m .47583 .39699 L .5044 .39535 L p
1 g
F P
s
P
p
.002 w
.5044 .39535 m .50548 .38621 L .47788 .37892 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .50548 .38621 L .5044 .39535 L closepath p
1 g
F P
s
P
p
.002 w
.54495 .42058 m .53607 .42293 L .53835 .45145 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .53607 .42293 L .54495 .42058 L closepath p
1 g
F P
s
P
p
.002 w
.42823 .43686 m .44632 .46706 L .46744 .44905 L p
1 g
F P
s
P
p
.002 w
.46744 .44905 m .45354 .42577 L .42823 .43686 L p
1 g
F P
s
P
p
.002 w
.48792 .4669 m .46744 .44905 L .44632 .46706 L p
1 g
F P
s
P
p
.002 w
.51287 .47747 m .48792 .4669 L .4729 .49023 L p
1 g
F P
s
P
p
.002 w
.44632 .46706 m .4729 .49023 L .48792 .4669 L p
1 g
F P
s
P
p
.002 w
.45061 .37284 m .4477 .39946 L .47583 .39699 L p
1 g
F P
s
P
p
.002 w
.47583 .39699 m .47788 .37892 L .45061 .37284 L p
1 g
F P
s
P
p
.002 w
.51287 .47747 m .53971 .47962 L .53835 .45145 L p
1 g
F P
s
P
p
.002 w
.55594 .4469 m .53835 .45145 L .53971 .47962 L p
1 g
F P
s
P
p
.002 w
.53835 .45145 m .55594 .4469 L .54495 .42058 L p
1 g
F P
s
P
p
.002 w
.48573 .36262 m .47788 .37892 L .50548 .38621 L p
1 g
F P
s
P
p
.002 w
.50548 .38621 m .50949 .37799 L .48573 .36262 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .50949 .37799 L .50548 .38621 L closepath p
1 g
F P
s
P
p
.002 w
.55252 .41546 m .54495 .42058 L .55594 .4469 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .54495 .42058 L .55252 .41546 L closepath p
1 g
F P
s
P
p
.002 w
.42055 .40271 m .42823 .43686 L .45354 .42577 L p
1 g
F P
s
P
p
.002 w
.45354 .42577 m .4477 .39946 L .42055 .40271 L p
1 g
F P
s
P
p
.002 w
.4729 .49023 m .50526 .504 L .51287 .47747 L p
1 g
F P
s
P
p
.002 w
.53971 .47962 m .51287 .47747 L .50526 .504 L p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .55252 .41546 L .55795 .4081 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .55795 .4081 L .56062 .39929 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .56062 .39929 L .56025 .38999 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .56025 .38999 L .55685 .38121 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .55685 .38121 L .5508 .37392 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .5508 .37392 L .54275 .36893 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .54275 .36893 L .5336 .36679 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .5336 .36679 L .52435 .36771 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .52435 .36771 L .51602 .37159 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .39456 m .51602 .37159 L .50949 .37799 L closepath p
1 g
F P
s
P
p
.002 w
.49859 .34987 m .48573 .36262 L .50949 .37799 L p
1 g
F P
s
P
p
.002 w
.50949 .37799 m .51602 .37159 L .49859 .34987 L p
1 g
F P
s
P
p
.002 w
.55594 .4469 m .57097 .43685 L .55252 .41546 L p
1 g
F P
s
P
p
.002 w
.55795 .4081 m .55252 .41546 L .57097 .43685 L p
1 g
F P
s
P
p
.002 w
.46206 .34875 m .45061 .37284 L .47788 .37892 L p
1 g
F P
s
P
p
.002 w
.47788 .37892 m .48573 .36262 L .46206 .34875 L p
1 g
F P
s
P
p
.002 w
.53971 .47962 m .56564 .47304 L .55594 .4469 L p
1 g
F P
s
P
p
.002 w
.57097 .43685 m .55594 .4469 L .56564 .47304 L p
1 g
F P
s
P
p
.002 w
.42418 .36809 m .42055 .40271 L .4477 .39946 L p
1 g
F P
s
P
p
.002 w
.4477 .39946 m .45061 .37284 L .42418 .36809 L p
1 g
F P
s
P
p
.002 w
.5151 .34208 m .49859 .34987 L .51602 .37159 L p
1 g
F P
s
P
p
.002 w
.51602 .37159 m .52435 .36771 L .5151 .34208 L p
1 g
F P
s
P
p
.002 w
.57097 .43685 m .5818 .42231 L .55795 .4081 L p
1 g
F P
s
P
p
.002 w
.56062 .39929 m .55795 .4081 L .5818 .42231 L p
1 g
F P
s
P
p
.002 w
.50526 .504 m .54012 .50691 L .53971 .47962 L p
1 g
F P
s
P
p
.002 w
.56564 .47304 m .53971 .47962 L .54012 .50691 L p
1 g
F P
s
P
p
.002 w
.4043 .44797 m .42621 .48442 L .44632 .46706 L p
1 g
F P
s
P
p
.002 w
.44632 .46706 m .42823 .43686 L .4043 .44797 L p
1 g
F P
s
P
p
.002 w
.4729 .49023 m .44632 .46706 L .42621 .48442 L p
1 g
F P
s
P
p
.002 w
.50526 .504 m .4729 .49023 L .45833 .51242 L p
1 g
F P
s
P
p
.002 w
.42621 .48442 m .45833 .51242 L .4729 .49023 L p
1 g
F P
s
P
p
.002 w
.53348 .34018 m .5151 .34208 L .52435 .36771 L p
1 g
F P
s
P
p
.002 w
.52435 .36771 m .5336 .36679 L .53348 .34018 L p
1 g
F P
s
P
p
.002 w
.5818 .42231 m .5872 .40484 L .56062 .39929 L p
1 g
F P
s
P
p
.002 w
.56025 .38999 m .56062 .39929 L .5872 .40484 L p
1 g
F P
s
P
p
.002 w
.48095 .32981 m .46206 .34875 L .48573 .36262 L p
1 g
F P
s
P
p
.002 w
.48573 .36262 m .49859 .34987 L .48095 .32981 L p
1 g
F P
s
P
p
.002 w
.56564 .47304 m .58789 .45832 L .57097 .43685 L p
1 g
F P
s
P
p
.002 w
.5818 .42231 m .57097 .43685 L .58789 .45832 L p
1 g
F P
s
P
p
.002 w
.5517 .34441 m .53348 .34018 L .5336 .36679 L p
1 g
F P
s
P
p
.002 w
.5336 .36679 m .54275 .36893 L .5517 .34441 L p
1 g
F P
s
P
p
.002 w
.39489 .4067 m .4043 .44797 L .42823 .43686 L p
1 g
F P
s
P
p
.002 w
.42823 .43686 m .42055 .40271 L .39489 .4067 L p
1 g
F P
s
P
p
.002 w
.5872 .40484 m .58652 .38634 L .56025 .38999 L p
1 g
F P
s
P
p
.002 w
.55685 .38121 m .56025 .38999 L .58652 .38634 L p
1 g
F P
s
P
p
.002 w
.45833 .51242 m .49741 .52914 L .50526 .504 L p
1 g
F P
s
P
p
.002 w
.54012 .50691 m .50526 .504 L .49741 .52914 L p
1 g
F P
s
P
p
.002 w
.56774 .35433 m .5517 .34441 L .54275 .36893 L p
1 g
F P
s
P
p
.002 w
.54275 .36893 m .5508 .37392 L .56774 .35433 L p
1 g
F P
s
P
p
.002 w
.58652 .38634 m .57979 .36885 L .55685 .38121 L p
1 g
F P
s
P
p
.002 w
.5508 .37392 m .55685 .38121 L .57979 .36885 L p
1 g
F P
s
P
p
.002 w
.43893 .33666 m .42418 .36809 L .45061 .37284 L p
1 g
F P
s
P
p
.002 w
.45061 .37284 m .46206 .34875 L .43893 .33666 L p
1 g
F P
s
P
p
.002 w
.57979 .36885 m .56774 .35433 L .5508 .37392 L p
1 g
F P
s
P
p
.002 w
.54012 .50691 m .57387 .4985 L .56564 .47304 L p
1 g
F P
s
P
p
.002 w
.58789 .45832 m .56564 .47304 L .57387 .4985 L p
1 g
F P
s
P
p
.002 w
.50531 .31819 m .48095 .32981 L .49859 .34987 L p
1 g
F P
s
P
p
.002 w
.49859 .34987 m .5151 .34208 L .50531 .31819 L p
1 g
F P
s
P
p
.002 w
.58789 .45832 m .60399 .43694 L .5818 .42231 L p
1 g
F P
s
P
p
.002 w
.5872 .40484 m .5818 .42231 L .60399 .43694 L p
1 g
F P
s
P
p
.002 w
.39912 .3648 m .39489 .4067 L .42055 .40271 L p
1 g
F P
s
P
p
.002 w
.42055 .40271 m .42418 .36809 L .39912 .3648 L p
1 g
F P
s
P
p
.002 w
.49741 .52914 m .53954 .53278 L .54012 .50691 L p
1 g
F P
s
P
p
.002 w
.57387 .4985 m .54012 .50691 L .53954 .53278 L p
1 g
F P
s
P
p
.002 w
.53252 .31527 m .50531 .31819 L .5151 .34208 L p
1 g
F P
s
P
p
.002 w
.5151 .34208 m .53348 .34018 L .53252 .31527 L p
1 g
F P
s
P
p
.002 w
.46342 .31186 m .43893 .33666 L .46206 .34875 L p
1 g
F P
s
P
p
.002 w
.46206 .34875 m .48095 .32981 L .46342 .31186 L p
1 g
F P
s
P
p
.002 w
.60399 .43694 m .61209 .41114 L .5872 .40484 L p
1 g
F P
s
P
p
.002 w
.58652 .38634 m .5872 .40484 L .61209 .41114 L p
1 g
F P
s
P
p
.002 w
.38224 .45887 m .40752 .5008 L .42621 .48442 L p
1 g
F P
s
P
p
.002 w
.42621 .48442 m .4043 .44797 L .38224 .45887 L p
1 g
F P
s
P
p
.002 w
.45833 .51242 m .42621 .48442 L .40752 .5008 L p
1 g
F P
s
P
p
.002 w
.49741 .52914 m .45833 .51242 L .44449 .53304 L p
1 g
F P
s
P
p
.002 w
.40752 .5008 m .44449 .53304 L .45833 .51242 L p
1 g
F P
s
P
p
.002 w
.57387 .4985 m .60292 .47949 L .58789 .45832 L p
1 g
F P
s
P
p
.002 w
.60399 .43694 m .58789 .45832 L .60292 .47949 L p
1 g
F P
s
P
p
.002 w
.55957 .32148 m .53252 .31527 L .53348 .34018 L p
1 g
F P
s
P
p
.002 w
.53348 .34018 m .5517 .34441 L .55957 .32148 L p
1 g
F P
s
P
p
.002 w
.61209 .41114 m .61118 .38372 L .58652 .38634 L p
1 g
F P
s
P
p
.002 w
.57979 .36885 m .58652 .38634 L .61118 .38372 L p
1 g
F P
s
P
p
.002 w
.37127 .41138 m .38224 .45887 L .4043 .44797 L p
1 g
F P
s
P
p
.002 w
.4043 .44797 m .39489 .4067 L .37127 .41138 L p
1 g
F P
s
P
p
.002 w
.41681 .32665 m .39912 .3648 L .42418 .36809 L p
1 g
F P
s
P
p
.002 w
.42418 .36809 m .43893 .33666 L .41681 .32665 L p
1 g
F P
s
P
p
.002 w
.44449 .53304 m .48945 .55236 L .49741 .52914 L p
1 g
F P
s
P
p
.002 w
.53954 .53278 m .49741 .52914 L .48945 .55236 L p
1 g
F P
s
P
p
.002 w
.53954 .53278 m .58043 .52278 L .57387 .4985 L p
1 g
F P
s
P
p
.002 w
.60292 .47949 m .57387 .4985 L .58043 .52278 L p
1 g
F P
s
P
p
.002 w
.58338 .33619 m .55957 .32148 L .5517 .34441 L p
1 g
F P
s
P
p
.002 w
.5517 .34441 m .56774 .35433 L .58338 .33619 L p
1 g
F P
s
P
p
.002 w
.61118 .38372 m .60125 .35776 L .57979 .36885 L p
1 g
F P
s
P
p
.002 w
.56774 .35433 m .57979 .36885 L .60125 .35776 L p
1 g
F P
s
P
p
.002 w
.60125 .35776 m .58338 .33619 L .56774 .35433 L p
1 g
F P
s
P
p
.002 w
.49516 .29656 m .46342 .31186 L .48095 .32981 L p
1 g
F P
s
P
p
.002 w
.48095 .32981 m .50531 .31819 L .49516 .29656 L p
1 g
F P
s
P
p
.002 w
.60292 .47949 m .62405 .45171 L .60399 .43694 L p
1 g
F P
s
P
p
.002 w
.61209 .41114 m .60399 .43694 L .62405 .45171 L p
1 g
F P
s
P
p
.002 w
.37597 .36308 m .37127 .41138 L .39489 .4067 L p
1 g
F P
s
P
p
.002 w
.39489 .4067 m .39912 .3648 L .37597 .36308 L p
1 g
F P
s
P
p
.002 w
.48945 .55236 m .53796 .55669 L .53954 .53278 L p
1 g
F P
s
P
p
.002 w
.58043 .52278 m .53954 .53278 L .53796 .55669 L p
1 g
F P
s
P
p
.002 w
.44637 .29645 m .41681 .32665 L .43893 .33666 L p
1 g
F P
s
P
p
.002 w
.43893 .33666 m .46342 .31186 L .44637 .29645 L p
1 g
F P
s
P
p
.002 w
.53072 .29262 m .49516 .29656 L .50531 .31819 L p
1 g
F P
s
P
p
.002 w
.50531 .31819 m .53252 .31527 L .53072 .29262 L p
1 g
F P
s
P
p
.002 w
.62405 .45171 m .63476 .41806 L .61209 .41114 L p
1 g
F P
s
P
p
.002 w
.61118 .38372 m .61209 .41114 L .63476 .41806 L p
1 g
F P
s
P
p
.002 w
.58043 .52278 m .61572 .4999 L .60292 .47949 L p
1 g
F P
s
P
p
.002 w
.62405 .45171 m .60292 .47949 L .61572 .4999 L p
1 g
F P
s
P
p
.002 w
.36257 .46935 m .39068 .51584 L .40752 .5008 L p
1 g
F P
s
P
p
.002 w
.40752 .5008 m .38224 .45887 L .36257 .46935 L p
1 g
F P
s
P
p
.002 w
.44449 .53304 m .40752 .5008 L .39068 .51584 L p
1 g
F P
s
P
p
.002 w
.48945 .55236 m .44449 .53304 L .43168 .55161 L p
1 g
F P
s
P
p
.002 w
.39068 .51584 m .43168 .55161 L .44449 .53304 L p
1 g
F P
s
P
p
.002 w
.56614 .30068 m .53072 .29262 L .53252 .31527 L p
1 g
F P
s
P
p
.002 w
.53252 .31527 m .55957 .32148 L .56614 .30068 L p
1 g
F P
s
P
p
.002 w
.39619 .31901 m .37597 .36308 L .39912 .3648 L p
1 g
F P
s
P
p
.002 w
.39912 .3648 m .41681 .32665 L .39619 .31901 L p
1 g
F P
s
P
p
.002 w
.63476 .41806 m .63368 .38221 L .61118 .38372 L p
1 g
F P
s
P
p
.002 w
.60125 .35776 m .61118 .38372 L .63368 .38221 L p
1 g
F P
s
P
p
.002 w
.35026 .41667 m .36257 .46935 L .38224 .45887 L p
1 g
F P
s
P
p
.002 w
.38224 .45887 m .37127 .41138 L .35026 .41667 L p
1 g
F P
s
P
p
.002 w
.43168 .55161 m .48154 .57312 L .48945 .55236 L p
1 g
F P
s
P
p
.002 w
.53796 .55669 m .48945 .55236 L .48154 .57312 L p
1 g
F P
s
P
p
.002 w
.53796 .55669 m .58512 .54534 L .58043 .52278 L p
1 g
F P
s
P
p
.002 w
.61572 .4999 m .58043 .52278 L .58512 .54534 L p
1 g
F P
s
P
p
.002 w
.48484 .27772 m .44637 .29645 L .46342 .31186 L p
1 g
F P
s
P
p
.002 w
.46342 .31186 m .49516 .29656 L .48484 .27772 L p
1 g
F P
s
P
p
.002 w
.59735 .31993 m .56614 .30068 L .55957 .32148 L p
1 g
F P
s
P
p
.002 w
.55957 .32148 m .58338 .33619 L .59735 .31993 L p
1 g
F P
s
P
p
.002 w
.63368 .38221 m .62075 .34819 L .60125 .35776 L p
1 g
F P
s
P
p
.002 w
.58338 .33619 m .60125 .35776 L .62075 .34819 L p
1 g
F P
s
P
p
.002 w
.61572 .4999 m .64149 .46633 L .62405 .45171 L p
1 g
F P
s
P
p
.002 w
.63476 .41806 m .62405 .45171 L .64149 .46633 L p
1 g
F P
s
P
p
.002 w
.62075 .34819 m .59735 .31993 L .58338 .33619 L p
1 g
F P
s
P
p
.002 w
.3553 .36304 m .35026 .41667 L .37127 .41138 L p
1 g
F P
s
P
p
.002 w
.37127 .41138 m .37597 .36308 L .3553 .36304 L p
1 g
F P
s
P
p
.002 w
.48154 .57312 m .53537 .57807 L .53796 .55669 L p
1 g
F P
s
P
p
.002 w
.58512 .54534 m .53796 .55669 L .53537 .57807 L p
1 g
F P
s
P
p
.002 w
.43018 .28402 m .39619 .31901 L .41681 .32665 L p
1 g
F P
s
P
p
.002 w
.41681 .32665 m .44637 .29645 L .43018 .28402 L p
1 g
F P
s
P
p
.002 w
.52808 .27281 m .48484 .27772 L .49516 .29656 L p
1 g
F P
s
P
p
.002 w
.49516 .29656 m .53072 .29262 L .52808 .27281 L p
1 g
F P
s
P
p
.002 w
.58512 .54534 m .62593 .51913 L .61572 .4999 L p
1 g
F P
s
P
p
.002 w
.64149 .46633 m .61572 .4999 L .62593 .51913 L p
1 g
F P
s
P
p
.002 w
.64149 .46633 m .65466 .42551 L .63476 .41806 L p
1 g
F P
s
P
p
.002 w
.63368 .38221 m .63476 .41806 L .65466 .42551 L p
1 g
F P
s
P
p
.002 w
.34579 .47917 m .3761 .52917 L .39068 .51584 L p
1 g
F P
s
P
p
.002 w
.39068 .51584 m .36257 .46935 L .34579 .47917 L p
1 g
F P
s
P
p
.002 w
.43168 .55161 m .39068 .51584 L .3761 .52917 L p
1 g
F P
s
P
p
.002 w
.48154 .57312 m .43168 .55161 L .42023 .56767 L p
1 g
F P
s
P
p
.002 w
.3761 .52917 m .42023 .56767 L .43168 .55161 L p
1 g
F P
s
P
p
.002 w
.37759 .31401 m .3553 .36304 L .37597 .36308 L p
1 g
F P
s
P
p
.002 w
.37597 .36308 m .39619 .31901 L .37759 .31401 L p
1 g
F P
s
P
p
.002 w
.57122 .28254 m .52808 .27281 L .53072 .29262 L p
1 g
F P
s
P
p
.002 w
.53072 .29262 m .56614 .30068 L .57122 .28254 L p
1 g
F P
s
P
p
.002 w
.65466 .42551 m .65346 .38189 L .63368 .38221 L p
1 g
F P
s
P
p
.002 w
.62075 .34819 m .63368 .38221 L .65346 .38189 L p
1 g
F P
s
P
p
.002 w
.33243 .4225 m .34579 .47917 L .36257 .46935 L p
1 g
F P
s
P
p
.002 w
.36257 .46935 m .35026 .41667 L .33243 .4225 L p
1 g
F P
s
P
p
.002 w
.53537 .57807 m .58777 .56565 L .58512 .54534 L p
1 g
F P
s
P
p
.002 w
.62593 .51913 m .58512 .54534 L .58777 .56565 L p
1 g
F P
s
P
p
.002 w
.42023 .56767 m .47386 .59089 L .48154 .57312 L p
1 g
F P
s
P
p
.002 w
.53537 .57807 m .48154 .57312 L .47386 .59089 L p
1 g
F P
s
P
p
.002 w
.47457 .26221 m .43018 .28402 L .44637 .29645 L p
1 g
F P
s
P
p
.002 w
.44637 .29645 m .48484 .27772 L .47457 .26221 L p
1 g
F P
s
P
p
.002 w
.60927 .30597 m .57122 .28254 L .56614 .30068 L p
1 g
F P
s
P
p
.002 w
.56614 .30068 m .59735 .31993 L .60927 .30597 L p
1 g
F P
s
P
p
.002 w
.62593 .51913 m .65584 .48048 L .64149 .46633 L p
1 g
F P
s
P
p
.002 w
.65466 .42551 m .64149 .46633 L .65584 .48048 L p
1 g
F P
s
P
p
.002 w
.65346 .38189 m .63778 .34043 L .62075 .34819 L p
1 g
F P
s
P
p
.002 w
.59735 .31993 m .62075 .34819 L .63778 .34043 L p
1 g
F P
s
P
p
.002 w
.63778 .34043 m .60927 .30597 L .59735 .31993 L p
1 g
F P
s
P
p
.002 w
.33769 .36475 m .33243 .4225 L .35026 .41667 L p
1 g
F P
s
P
p
.002 w
.35026 .41667 m .3553 .36304 L .33769 .36475 L p
1 g
F P
s
P
p
.002 w
.47386 .59089 m .53178 .59634 L .53537 .57807 L p
1 g
F P
s
P
p
.002 w
.58777 .56565 m .53537 .57807 L .53178 .59634 L p
1 g
F P
s
P
p
.002 w
.41525 .27498 m .37759 .31401 L .39619 .31901 L p
1 g
F P
s
P
p
.002 w
.39619 .31901 m .43018 .28402 L .41525 .27498 L p
1 g
F P
s
P
p
.002 w
.52461 .25641 m .47457 .26221 L .48484 .27772 L p
1 g
F P
s
P
p
.002 w
.48484 .27772 m .52808 .27281 L .52461 .25641 L p
1 g
F P
s
P
p
.002 w
.58777 .56565 m .63321 .53669 L .62593 .51913 L p
1 g
F P
s
P
p
.002 w
.65584 .48048 m .62593 .51913 L .63321 .53669 L p
1 g
F P
s
P
p
.002 w
.65584 .48048 m .67121 .43333 L .65466 .42551 L p
1 g
F P
s
P
p
.002 w
.65346 .38189 m .65466 .42551 L .67121 .43333 L p
1 g
F P
s
P
p
.002 w
.33245 .48807 m .36424 .5404 L .3761 .52917 L p
1 g
F P
s
P
p
.002 w
.3761 .52917 m .34579 .47917 L .33245 .48807 L p
1 g
F P
s
P
p
.002 w
.42023 .56767 m .3761 .52917 L .36424 .5404 L p
1 g
F P
s
P
p
.002 w
.36424 .5404 m .41044 .58072 L .42023 .56767 L p
1 g
F P
s
P
p
.002 w
.47386 .59089 m .42023 .56767 L .41044 .58072 L p
1 g
F P
s
P
p
.002 w
.36154 .31189 m .33769 .36475 L .3553 .36304 L p
1 g
F P
s
P
p
.002 w
.3553 .36304 m .37759 .31401 L .36154 .31189 L p
1 g
F P
s
P
p
.002 w
.57463 .26762 m .52461 .25641 L .52808 .27281 L p
1 g
F P
s
P
p
.002 w
.52808 .27281 m .57122 .28254 L .57463 .26762 L p
1 g
F P
s
P
p
.002 w
.67121 .43333 m .66993 .38283 L .65346 .38189 L p
1 g
F P
s
P
p
.002 w
.63778 .34043 m .65346 .38189 L .66993 .38283 L p
1 g
F P
s
P
p
.002 w
.53178 .59634 m .58822 .58313 L .58777 .56565 L p
1 g
F P
s
P
p
.002 w
.63321 .53669 m .58777 .56565 L .58822 .58313 L p
1 g
F P
s
P
p
.002 w
.31836 .42875 m .33245 .48807 L .34579 .47917 L p
1 g
F P
s
P
p
.002 w
.34579 .47917 m .33243 .4225 L .31836 .42875 L p
1 g
F P
s
P
p
.002 w
.46459 .25058 m .41525 .27498 L .43018 .28402 L p
1 g
F P
s
P
p
.002 w
.43018 .28402 m .47457 .26221 L .46459 .25058 L p
1 g
F P
s
P
p
.002 w
.41044 .58072 m .46658 .6051 L .47386 .59089 L p
1 g
F P
s
P
p
.002 w
.53178 .59634 m .47386 .59089 L .46658 .6051 L p
1 g
F P
s
P
p
.002 w
.63321 .53669 m .6666 .49382 L .65584 .48048 L p
1 g
F P
s
P
p
.002 w
.67121 .43333 m .65584 .48048 L .6666 .49382 L p
1 g
F P
s
P
p
.002 w
.61877 .29477 m .57463 .26762 L .57122 .28254 L p
1 g
F P
s
P
p
.002 w
.57122 .28254 m .60927 .30597 L .61877 .29477 L p
1 g
F P
s
P
p
.002 w
.66993 .38283 m .65182 .33475 L .63778 .34043 L p
1 g
F P
s
P
p
.002 w
.60927 .30597 m .63778 .34043 L .65182 .33475 L p
1 g
F P
s
P
p
.002 w
.65182 .33475 m .61877 .29477 L .60927 .30597 L p
1 g
F P
s
P
p
.002 w
.32374 .36828 m .31836 .42875 L .33243 .4225 L p
1 g
F P
s
P
p
.002 w
.33243 .4225 m .33769 .36475 L .32374 .36828 L p
1 g
F P
s
P
p
.002 w
.46658 .6051 m .52722 .61092 L .53178 .59634 L p
1 g
F P
s
P
p
.002 w
.58822 .58313 m .53178 .59634 L .52722 .61092 L p
1 g
F P
s
P
p
.002 w
.40201 .26974 m .36154 .31189 L .37759 .31401 L p
1 g
F P
s
P
p
.002 w
.37759 .31401 m .41525 .27498 L .40201 .26974 L p
1 g
F P
s
P
p
.002 w
.52035 .24401 m .46459 .25058 L .47457 .26221 L p
1 g
F P
s
P
p
.002 w
.47457 .26221 m .52461 .25641 L .52035 .24401 L p
1 g
F P
s
P
p
.002 w
.58822 .58313 m .63724 .55208 L .63321 .53669 L p
1 g
F P
s
P
p
.002 w
.6666 .49382 m .63321 .53669 L .63724 .55208 L p
1 g
F P
s
P
p
.002 w
.6666 .49382 m .68385 .44138 L .67121 .43333 L p
1 g
F P
s
P
p
.002 w
.66993 .38283 m .67121 .43333 L .68385 .44138 L p
1 g
F P
s
P
p
.002 w
.32304 .49578 m .35551 .54915 L .36424 .5404 L p
1 g
F P
s
P
p
.002 w
.36424 .5404 m .33245 .48807 L .32304 .49578 L p
1 g
F P
s
P
p
.002 w
.41044 .58072 m .36424 .5404 L .35551 .54915 L p
1 g
F P
s
P
p
.002 w
.46658 .6051 m .41044 .58072 L .40266 .5903 L p
1 g
F P
s
P
p
.002 w
.35551 .54915 m .40266 .5903 L .41044 .58072 L p
1 g
F P
s
P
p
.002 w
.34858 .31289 m .32374 .36828 L .33769 .36475 L p
1 g
F P
s
P
p
.002 w
.33769 .36475 m .36154 .31189 L .34858 .31289 L p
1 g
F P
s
P
p
.002 w
.57617 .25646 m .52035 .24401 L .52461 .25641 L p
1 g
F P
s
P
p
.002 w
.52461 .25641 m .57463 .26762 L .57617 .25646 L p
1 g
F P
s
P
p
.002 w
.52722 .61092 m .58634 .59721 L .58822 .58313 L p
1 g
F P
s
P
p
.002 w
.63724 .55208 m .58822 .58313 L .58634 .59721 L p
1 g
F P
s
P
p
.002 w
.68385 .44138 m .68252 .38508 L .66993 .38283 L p
1 g
F P
s
P
p
.002 w
.65182 .33475 m .66993 .38283 L .68252 .38508 L p
1 g
F P
s
P
p
.002 w
.45517 .24332 m .40201 .26974 L .41525 .27498 L p
1 g
F P
s
P
p
.002 w
.41525 .27498 m .46459 .25058 L .45517 .24332 L p
1 g
F P
s
P
p
.002 w
.30859 .43531 m .32304 .49578 L .33245 .48807 L p
1 g
F P
s
P
p
.002 w
.33245 .48807 m .31836 .42875 L .30859 .43531 L p
1 g
F P
s
P
p
.002 w
.40266 .5903 m .45991 .61521 L .46658 .6051 L p
1 g
F P
s
P
p
.002 w
.52722 .61092 m .46658 .6051 L .45991 .61521 L p
1 g
F P
s
P
p
.002 w
.63724 .55208 m .67333 .50598 L .6666 .49382 L p
1 g
F P
s
P
p
.002 w
.68385 .44138 m .6666 .49382 L .67333 .50598 L p
1 g
F P
s
P
p
.002 w
.62547 .28675 m .57617 .25646 L .57463 .26762 L p
1 g
F P
s
P
p
.002 w
.57463 .26762 m .61877 .29477 L .62547 .28675 L p
1 g
F P
s
P
p
.002 w
.68252 .38508 m .66236 .33141 L .65182 .33475 L p
1 g
F P
s
P
p
.002 w
.61877 .29477 m .65182 .33475 L .66236 .33141 L p
1 g
F P
s
P
p
.002 w
.66236 .33141 m .62547 .28675 L .61877 .29477 L p
1 g
F P
s
P
p
.002 w
.31399 .37365 m .30859 .43531 L .31836 .42875 L p
1 g
F P
s
P
p
.002 w
.31836 .42875 m .32374 .36828 L .31399 .37365 L p
1 g
F P
s
P
p
.002 w
.39089 .26866 m .34858 .31289 L .36154 .31189 L p
1 g
F P
s
P
p
.002 w
.36154 .31189 m .40201 .26974 L .39089 .26866 L p
1 g
F P
s
P
p
.002 w
.45991 .61521 m .52174 .62123 L .52722 .61092 L p
1 g
F P
s
P
p
.002 w
.58634 .59721 m .52722 .61092 L .52174 .62123 L p
1 g
F P
s
P
p
.002 w
.58634 .59721 m .63773 .56481 L .63724 .55208 L p
1 g
F P
s
P
p
.002 w
.67333 .50598 m .63724 .55208 L .63773 .56481 L p
1 g
F P
s
P
p
.002 w
.51536 .23616 m .45517 .24332 L .46459 .25058 L p
1 g
F P
s
P
p
.002 w
.46459 .25058 m .52035 .24401 L .51536 .23616 L p
1 g
F P
s
P
p
.002 w
.67333 .50598 m .69204 .44945 L .68385 .44138 L p
1 g
F P
s
P
p
.002 w
.68252 .38508 m .68385 .44138 L .69204 .44945 L p
1 g
F P
s
P
p
.002 w
.33924 .31715 m .31399 .37365 L .32374 .36828 L p
1 g
F P
s
P
p
.002 w
.32374 .36828 m .34858 .31289 L .33924 .31715 L p
1 g
F P
s
P
p
.002 w
.31806 .50204 m .35034 .55505 L .35551 .54915 L p
1 g
F P
s
P
p
.002 w
.35551 .54915 m .32304 .49578 L .31806 .50204 L p
1 g
F P
s
P
p
.002 w
.40266 .5903 m .35551 .54915 L .35034 .55505 L p
1 g
F P
s
P
p
.002 w
.35034 .55505 m .39718 .59594 L .40266 .5903 L p
1 g
F P
s
P
p
.002 w
.45991 .61521 m .40266 .5903 L .39718 .59594 L p
1 g
F P
s
P
p
.002 w
.5757 .24957 m .51536 .23616 L .52035 .24401 L p
1 g
F P
s
P
p
.002 w
.52035 .24401 m .57617 .25646 L .5757 .24957 L p
1 g
F P
s
P
p
.002 w
.52174 .62123 m .58203 .60734 L .58634 .59721 L p
1 g
F P
s
P
p
.002 w
.63773 .56481 m .58634 .59721 L .58203 .60734 L p
1 g
F P
s
P
p
.002 w
.69204 .44945 m .69067 .38866 L .68252 .38508 L p
1 g
F P
s
P
p
.002 w
.66236 .33141 m .68252 .38508 L .69067 .38866 L p
1 g
F P
s
P
p
.002 w
.44658 .24092 m .39089 .26866 L .40201 .26974 L p
1 g
F P
s
P
p
.002 w
.40201 .26974 m .45517 .24332 L .44658 .24092 L p
1 g
F P
s
P
p
.002 w
.30367 .442 m .31806 .50204 L .32304 .49578 L p
1 g
F P
s
P
p
.002 w
.32304 .49578 m .30859 .43531 L .30367 .442 L p
1 g
F P
s
P
p
.002 w
.39718 .59594 m .45404 .62071 L .45991 .61521 L p
1 g
F P
s
P
p
.002 w
.52174 .62123 m .45991 .61521 L .45404 .62071 L p
1 g
F P
s
P
p
.002 w
.63773 .56481 m .67562 .51659 L .67333 .50598 L p
1 g
F P
s
P
p
.002 w
.69204 .44945 m .67333 .50598 L .67562 .51659 L p
1 g
F P
s
P
p
.002 w
.62902 .28233 m .5757 .24957 L .57617 .25646 L p
1 g
F P
s
P
p
.002 w
.57617 .25646 m .62547 .28675 L .62902 .28233 L p
1 g
F P
s
P
p
.002 w
.69067 .38866 m .66891 .33063 L .66236 .33141 L p
1 g
F P
s
P
p
.002 w
.62547 .28675 m .66236 .33141 L .66891 .33063 L p
1 g
F P
s
P
p
.002 w
.66891 .33063 m .62902 .28233 L .62547 .28675 L p
1 g
F P
s
P
p
.002 w
.30898 .38081 m .30367 .442 L .30859 .43531 L p
1 g
F P
s
P
p
.002 w
.30859 .43531 m .31399 .37365 L .30898 .38081 L p
1 g
F P
s
P
p
.002 w
.38234 .27204 m .33924 .31715 L .34858 .31289 L p
1 g
F P
s
P
p
.002 w
.34858 .31289 m .39089 .26866 L .38234 .27204 L p
1 g
F P
s
P
p
.002 w
.45404 .62071 m .51543 .62673 L .52174 .62123 L p
1 g
F P
s
P
p
.002 w
.58203 .60734 m .52174 .62123 L .51543 .62673 L p
1 g
F P
s
P
p
.002 w
.58203 .60734 m .63446 .57438 L .63773 .56481 L p
1 g
F P
s
P
p
.002 w
.67562 .51659 m .63773 .56481 L .63446 .57438 L p
1 g
F P
s
P
p
.002 w
.50972 .23337 m .44658 .24092 L .45517 .24332 L p
1 g
F P
s
P
p
.002 w
.45517 .24332 m .51536 .23616 L .50972 .23337 L p
1 g
F P
s
P
p
.002 w
.67562 .51659 m .69528 .45735 L .69204 .44945 L p
1 g
F P
s
P
p
.002 w
.69067 .38866 m .69204 .44945 L .69528 .45735 L p
1 g
F P
s
P
p
.002 w
.33401 .32477 m .30898 .38081 L .31399 .37365 L p
1 g
F P
s
P
p
.002 w
.31399 .37365 m .33924 .31715 L .33401 .32477 L p
1 g
F P
s
P
p
.002 w
.31793 .50659 m .3491 .55775 L .35034 .55505 L p
1 g
F P
s
P
p
.002 w
.35034 .55505 m .31806 .50204 L .31793 .50659 L p
1 g
F P
s
P
p
.002 w
.39718 .59594 m .35034 .55505 L .3491 .55775 L p
1 g
F P
s
P
p
.002 w
.45404 .62071 m .39718 .59594 L .39432 .59723 L p
1 g
F P
s
P
p
.002 w
.3491 .55775 m .39432 .59723 L .39718 .59594 L p
1 g
F P
s
P
p
.002 w
.51543 .62673 m .57526 .61299 L .58203 .60734 L p
1 g
F P
s
P
p
.002 w
.63446 .57438 m .58203 .60734 L .57526 .61299 L p
1 g
F P
s
P
p
.002 w
.57309 .24745 m .50972 .23337 L .51536 .23616 L p
1 g
F P
s
P
p
.002 w
.51536 .23616 m .5757 .24957 L .57309 .24745 L p
1 g
F P
s
P
p
.002 w
.43913 .24373 m .38234 .27204 L .39089 .26866 L p
1 g
F P
s
P
p
.002 w
.39089 .26866 m .44658 .24092 L .43913 .24373 L p
1 g
F P
s
P
p
.002 w
.69528 .45735 m .69388 .39356 L .69067 .38866 L p
1 g
F P
s
P
p
.002 w
.66891 .33063 m .69067 .38866 L .69388 .39356 L p
1 g
F P
s
P
p
.002 w
.30404 .44867 m .31793 .50659 L .31806 .50204 L p
1 g
F P
s
P
p
.002 w
.31806 .50204 m .30367 .442 L .30404 .44867 L p
1 g
F P
s
P
p
.002 w
.63446 .57438 m .67311 .52524 L .67562 .51659 L p
1 g
F P
s
P
p
.002 w
.69528 .45735 m .67562 .51659 L .67311 .52524 L p
1 g
F P
s
P
p
.002 w
.39432 .59723 m .4492 .62115 L .45404 .62071 L p
1 g
F P
s
P
p
.002 w
.51543 .62673 m .45404 .62071 L .4492 .62115 L p
1 g
F P
s
P
p
.004 w
.25735 .59938 m
.313 .56065 L
s
P
p
.002 w
.62912 .28186 m .57309 .24745 L .5757 .24957 L p
1 g
F P
s
P
p
.002 w
.5757 .24957 m .62902 .28233 L .62912 .28186 L p
1 g
F P
s
P
p
.002 w
.69388 .39356 m .67103 .33261 L .66891 .33063 L p
1 g
F P
s
P
p
.002 w
.62902 .28233 m .66891 .33063 L .67103 .33261 L p
1 g
F P
s
P
p
.002 w
.67103 .33261 m .62912 .28186 L .62902 .28233 L p
1 g
F P
s
P
p
.002 w
.30917 .38969 m .30404 .44867 L .30367 .442 L p
1 g
F P
s
P
p
.002 w
.30367 .442 m .30898 .38081 L .30917 .38969 L p
1 g
F P
s
P
p
.002 w
.37676 .28006 m .33401 .32477 L .33924 .31715 L p
1 g
F P
s
P
p
.002 w
.33924 .31715 m .38234 .27204 L .37676 .28006 L p
1 g
F P
s
P
p
.002 w
.4492 .62115 m .50842 .62696 L .51543 .62673 L p
1 g
F P
s
P
p
.002 w
.57526 .61299 m .51543 .62673 L .50842 .62696 L p
1 g
F P
s
P
p
.002 w
.57526 .61299 m .62727 .58032 L .63446 .57438 L p
1 g
F P
s
P
p
.002 w
.67311 .52524 m .63446 .57438 L .62727 .58032 L p
1 g
F P
s
P
p
.002 w
.50356 .23605 m .43913 .24373 L .44658 .24092 L p
1 g
F P
s
P
p
.002 w
.44658 .24092 m .50972 .23337 L .50356 .23605 L p
1 g
F P
s
P
p
.002 w
.67311 .52524 m .69317 .46483 L .69528 .45735 L p
1 g
F P
s
P
p
.002 w
.69388 .39356 m .69528 .45735 L .69317 .46483 L p
1 g
F P
s
P
p
.002 w
.33331 .33574 m .30917 .38969 L .30898 .38081 L p
1 g
F P
s
P
p
.002 w
.30898 .38081 m .33401 .32477 L .33331 .33574 L p
1 g
F P
s
P
p
.002 w
.32298 .50917 m .35208 .55697 L .3491 .55775 L p
1 g
F P
s
P
p
.002 w
.3491 .55775 m .31793 .50659 L .32298 .50917 L p
1 g
F P
s
P
p
.002 w
.39432 .59723 m .3491 .55775 L .35208 .55697 L p
1 g
F P
s
P
p
.002 w
.50842 .62696 m .56607 .61371 L .57526 .61299 L p
1 g
F P
s
P
p
.002 w
.62727 .58032 m .57526 .61299 L .56607 .61371 L p
1 g
F P
s
P
p
.002 w
.4492 .62115 m .39432 .59723 L .39434 .59385 L p
1 g
F P
s
P
p
.002 w
.35208 .55697 m .39434 .59385 L .39432 .59723 L p
1 g
F P
s
P
p
.002 w
.56827 .25045 m .50356 .23605 L .50972 .23337 L p
1 g
F P
s
P
p
.002 w
.50972 .23337 m .57309 .24745 L .56827 .25045 L p
1 g
F P
s
P
p
.002 w
.4331 .25203 m .37676 .28006 L .38234 .27204 L p
1 g
F P
s
P
p
.002 w
.38234 .27204 m .43913 .24373 L .4331 .25203 L p
1 g
F P
s
P
p
.002 w
.69317 .46483 m .69171 .39972 L .69388 .39356 L p
1 g
F P
s
P
p
.002 w
.67103 .33261 m .69388 .39356 L .69171 .39972 L p
1 g
F P
s
P
p
.002 w
.62727 .58032 m .66557 .53158 L .67311 .52524 L p
1 g
F P
s
P
p
.002 w
.69317 .46483 m .67311 .52524 L .66557 .53158 L p
1 g
F P
s
P
p
.002 w
.31004 .45511 m .32298 .50917 L .31793 .50659 L p
1 g
F P
s
P
p
.002 w
.31793 .50659 m .30404 .44867 L .31004 .45511 L p
1 g
F P
s
P
p
.002 w
.39434 .59385 m .4456 .61618 L .4492 .62115 L p
1 g
F P
s
P
p
.002 w
.50842 .62696 m .4492 .62115 L .4456 .61618 L p
1 g
F P
s
P
p
.002 w
.62552 .28563 m .56827 .25045 L .57309 .24745 L p
1 g
F P
s
P
p
.002 w
.57309 .24745 m .62912 .28186 L .62552 .28563 L p
1 g
F P
s
P
p
.002 w
.69171 .39972 m .66835 .33748 L .67103 .33261 L p
1 g
F P
s
P
p
.002 w
.62912 .28186 m .67103 .33261 L .66835 .33748 L p
1 g
F P
s
P
p
.002 w
.66835 .33748 m .62552 .28563 L .62912 .28186 L p
1 g
F P
s
P
p
.002 w
.37451 .29277 m .33331 .33574 L .33401 .32477 L p
1 g
F P
s
P
p
.002 w
.33401 .32477 m .37676 .28006 L .37451 .29277 L p
1 g
F P
s
P
p
.002 w
.31488 .40013 m .31004 .45511 L .30404 .44867 L p
1 g
F P
s
P
p
.002 w
.30404 .44867 m .30917 .38969 L .31488 .40013 L p
1 g
F P
s
P
p
.002 w
.4456 .61618 m .50086 .62157 L .50842 .62696 L p
1 g
F P
s
P
p
.002 w
.56607 .61371 m .50842 .62696 L .50086 .62157 L p
1 g
F P
s
P
p
.002 w
.56607 .61371 m .61612 .58221 L .62727 .58032 L p
1 g
F P
s
P
p
.002 w
.66557 .53158 m .62727 .58032 L .61612 .58221 L p
1 g
F P
s
P
p
.002 w
.49704 .24448 m .4331 .25203 L .43913 .24373 L p
1 g
F P
s
P
p
.002 w
.43913 .24373 m .50356 .23605 L .49704 .24448 L p
1 g
F P
s
P
p
.002 w
.66557 .53158 m .6854 .47165 L .69317 .46483 L p
1 g
F P
s
P
p
.002 w
.69171 .39972 m .69317 .46483 L .6854 .47165 L p
1 g
F P
s
P
p
.002 w
.33745 .34994 m .31488 .40013 L .30917 .38969 L p
1 g
F P
s
P
p
.002 w
.30917 .38969 m .33331 .33574 L .33745 .34994 L p
1 g
F P
s
P
p
.002 w
.50086 .62157 m .55458 .60916 L .56607 .61371 L p
1 g
F P
s
P
p
.002 w
.61612 .58221 m .56607 .61371 L .55458 .60916 L p
1 g
F P
s
P
p
.002 w
.33339 .50958 m .35948 .55248 L .35208 .55697 L p
1 g
F P
s
P
p
.002 w
.35208 .55697 m .32298 .50917 L .33339 .50958 L p
1 g
F P
s
P
p
.004 w
.34915 .53549 m
.5 .43051 L
s
P
p
.004 w
.34269 .53999 m
.34388 .53916 L
s
P
p
.004 w
.33679 .5441 m
.34269 .53999 L
s
P
p
.004 w
.313 .56065 m
.33679 .5441 L
s
P
p
.002 w
.39434 .59385 m .35208 .55697 L .35948 .55248 L p
1 g
F P
s
P
p
.002 w
.4456 .61618 m .39434 .59385 L .39741 .58558 L p
1 g
F P
s
P
p
.002 w
.35948 .55248 m .39741 .58558 L .39434 .59385 L p
1 g
F P
s
P
p
.002 w
.56126 .25884 m .49704 .24448 L .50356 .23605 L p
1 g
F P
s
P
p
.002 w
.50356 .23605 m .56827 .25045 L .56126 .25884 L p
1 g
F P
s
P
p
.002 w
.42877 .26591 m .37451 .29277 L .37676 .28006 L p
1 g
F P
s
P
p
.002 w
.37676 .28006 m .4331 .25203 L .42877 .26591 L p
1 g
F P
s
P
p
.002 w
.6854 .47165 m .68389 .40704 L .69171 .39972 L p
1 g
F P
s
P
p
.002 w
.66835 .33748 m .69171 .39972 L .68389 .40704 L p
1 g
F P
s
P
p
.002 w
.61612 .58221 m .65291 .53525 L .66557 .53158 L p
1 g
F P
s
P
p
.002 w
.6854 .47165 m .66557 .53158 L .65291 .53525 L p
1 g
F P
s
P
p
.002 w
.32184 .4611 m .33339 .50958 L .32298 .50917 L p
1 g
F P
s
P
p
.002 w
.32298 .50917 m .31004 .45511 L .32184 .4611 L p
1 g
F P
s
P
p
.002 w
.39741 .58558 m .44342 .60559 L .4456 .61618 L p
1 g
F P
s
P
p
.002 w
.50086 .62157 m .4456 .61618 L .44342 .60559 L p
1 g
F P
s
P
p
.002 w
.6181 .29379 m .56126 .25884 L .56827 .25045 L p
1 g
F P
s
P
p
.002 w
.56827 .25045 m .62552 .28563 L .6181 .29379 L p
1 g
F P
s
P
p
.002 w
.68389 .40704 m .66065 .34528 L .66835 .33748 L p
1 g
F P
s
P
p
.002 w
.62552 .28563 m .66835 .33748 L .66065 .34528 L p
1 g
F P
s
P
p
.002 w
.37587 .31005 m .33745 .34994 L .33331 .33574 L p
1 g
F P
s
P
p
.002 w
.33331 .33574 m .37451 .29277 L .37587 .31005 L p
1 g
F P
s
P
p
.002 w
.66065 .34528 m .6181 .29379 L .62552 .28563 L p
1 g
F P
s
P
p
.002 w
.32627 .41189 m .32184 .4611 L .31004 .45511 L p
1 g
F P
s
P
p
.002 w
.31004 .45511 m .31488 .40013 L .32627 .41189 L p
1 g
F P
s
P
p
.002 w
.44342 .60559 m .49295 .61037 L .50086 .62157 L p
1 g
F P
s
P
p
.002 w
.55458 .60916 m .50086 .62157 L .49295 .61037 L p
1 g
F P
s
P
p
.002 w
.55458 .60916 m .60111 .57974 L .61612 .58221 L p
1 g
F P
s
P
p
.002 w
.65291 .53525 m .61612 .58221 L .60111 .57974 L p
1 g
F P
s
P
p
.002 w
.49033 .25875 m .42877 .26591 L .4331 .25203 L p
1 g
F P
s
P
p
.002 w
.4331 .25203 m .49704 .24448 L .49033 .25875 L p
1 g
F P
s
P
p
.002 w
.65291 .53525 m .67188 .47754 L .6854 .47165 L p
1 g
F P
s
P
p
.002 w
.68389 .40704 m .6854 .47165 L .67188 .47754 L p
1 g
F P
s
P
p
.002 w
.34658 .36708 m .32627 .41189 L .31488 .40013 L p
1 g
F P
s
P
p
.002 w
.31488 .40013 m .33745 .34994 L .34658 .36708 L p
1 g
F P
s
P
p
.002 w
.49295 .61037 m .54101 .59915 L .55458 .60916 L p
1 g
F P
s
P
p
.002 w
.60111 .57974 m .55458 .60916 L .54101 .59915 L p
1 g
F P
s
P
p
.002 w
.42641 .28523 m .37587 .31005 L .37451 .29277 L p
1 g
F P
s
P
p
.002 w
.37451 .29277 m .42877 .26591 L .42641 .28523 L p
1 g
F P
s
P
p
.002 w
.34916 .50766 m .37134 .5442 L .35948 .55248 L p
1 g
F P
s
P
p
.002 w
.35948 .55248 m .33339 .50958 L .34916 .50766 L p
1 g
F P
s
P
p
.002 w
.39741 .58558 m .35948 .55248 L .37134 .5442 L p
1 g
F P
s
P
p
.002 w
.55214 .27267 m .49033 .25875 L .49704 .24448 L p
1 g
F P
s
P
p
.002 w
.49704 .24448 m .56126 .25884 L .55214 .27267 L p
1 g
F P
s
P
p
.002 w
.44342 .60559 m .39741 .58558 L .40365 .57239 L p
1 g
F P
s
P
p
.002 w
.37134 .5442 m .40365 .57239 L .39741 .58558 L p
1 g
F P
s
P
p
.002 w
.67188 .47754 m .67031 .41536 L .68389 .40704 L p
1 g
F P
s
P
p
.002 w
.66065 .34528 m .68389 .40704 L .67031 .41536 L p
1 g
F P
s
P
p
.002 w
.60111 .57974 m .63522 .53597 L .65291 .53525 L p
1 g
F P
s
P
p
.002 w
.67188 .47754 m .65291 .53525 L .63522 .53597 L p
1 g
F P
s
P
p
.002 w
.33942 .46641 m .34916 .50766 L .33339 .50958 L p
1 g
F P
s
P
p
.002 w
.33339 .50958 m .32184 .4611 L .33942 .46641 L p
1 g
F P
s
P
p
.002 w
.40365 .57239 m .44283 .58938 L .44342 .60559 L p
1 g
F P
s
P
p
.002 w
.49295 .61037 m .44342 .60559 L .44283 .58938 L p
1 g
F P
s
P
p
.002 w
.60685 .30636 m .55214 .27267 L .56126 .25884 L p
1 g
F P
s
P
p
.002 w
.56126 .25884 m .6181 .29379 L .60685 .30636 L p
1 g
F P
s
P
p
.002 w
.67031 .41536 m .64785 .35592 L .66065 .34528 L p
1 g
F P
s
P
p
.002 w
.6181 .29379 m .66065 .34528 L .64785 .35592 L p
1 g
F P
s
P
p
.002 w
.38102 .33159 m .34658 .36708 L .33745 .34994 L p
1 g
F P
s
P
p
.002 w
.33745 .34994 m .37587 .31005 L .38102 .33159 L p
1 g
F P
s
P
p
.002 w
.3433 .42465 m .33942 .46641 L .32184 .4611 L p
1 g
F P
s
P
p
.002 w
.32184 .4611 m .32627 .41189 L .3433 .42465 L p
1 g
F P
s
P
p
.002 w
.64785 .35592 m .60685 .30636 L .6181 .29379 L p
1 g
F P
s
P
p
.002 w
.54101 .59915 m .58252 .57273 L .60111 .57974 L p
1 g
F P
s
P
p
.002 w
.63522 .53597 m .60111 .57974 L .58252 .57273 L p
1 g
F P
s
P
p
.002 w
.44283 .58938 m .48495 .59336 L .49295 .61037 L p
1 g
F P
s
P
p
.002 w
.54101 .59915 m .49295 .61037 L .48495 .59336 L p
1 g
F P
s
P
p
.002 w
.48366 .27873 m .42641 .28523 L .42877 .26591 L p
1 g
F P
s
P
p
.002 w
.42877 .26591 m .49033 .25875 L .48366 .27873 L p
1 g
F P
s
P
p
.002 w
.63522 .53597 m .65271 .48226 L .67188 .47754 L p
1 g
F P
s
P
p
.002 w
.67031 .41536 m .67188 .47754 L .65271 .48226 L p
1 g
F P
s
P
p
.002 w
.36066 .38673 m .3433 .42465 L .32627 .41189 L p
1 g
F P
s
P
p
.002 w
.32627 .41189 m .34658 .36708 L .36066 .38673 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.48495 .59336 m .52571 .58371 L .54101 .59915 L p
1 g
F P
s
P
p
.002 w
.58252 .57273 m .54101 .59915 L .52571 .58371 L p
1 g
F P
s
P
p
.002 w
.42619 .30962 m .38102 .33159 L .37587 .31005 L p
1 g
F P
s
P
p
.002 w
.37587 .31005 m .42641 .28523 L .42619 .30962 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54111 .29179 m .48366 .27873 L .49033 .25875 L p
1 g
F P
s
P
p
.002 w
.49033 .25875 m .55214 .27267 L .54111 .29179 L p
1 g
F P
s
P
p
.002 w
.37007 .50334 m .38754 .53218 L .37134 .5442 L p
1 g
F P
s
P
p
.002 w
.37134 .5442 m .34916 .50766 L .37007 .50334 L p
1 g
F P
s
P
p
.002 w
.40365 .57239 m .37134 .5442 L .38754 .53218 L p
1 g
F P
s
P
p
.002 w
.38754 .53218 m .41303 .55442 L .40365 .57239 L p
1 g
F P
s
P
p
.002 w
.44283 .58938 m .40365 .57239 L .41303 .55442 L p
1 g
F P
s
P
p
.002 w
.58252 .57273 m .61283 .53355 L .63522 .53597 L p
1 g
F P
s
P
p
.002 w
.65271 .48226 m .63522 .53597 L .61283 .53355 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.65271 .48226 m .65109 .42445 L .67031 .41536 L p
1 g
F P
s
P
p
.002 w
.64785 .35592 m .67031 .41536 L .65109 .42445 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.36248 .47083 m .37007 .50334 L .34916 .50766 L p
1 g
F P
s
P
p
.002 w
.34916 .50766 m .33942 .46641 L .36248 .47083 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.41303 .55442 m .44394 .56778 L .44283 .58938 L p
1 g
F P
s
P
p
.002 w
.48495 .59336 m .44283 .58938 L .44394 .56778 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.59195 .32316 m .54111 .29179 L .55214 .27267 L p
1 g
F P
s
P
p
.002 w
.55214 .27267 m .60685 .30636 L .59195 .32316 L p
1 g
F P
s
P
p
.002 w
.38995 .35684 m .36066 .38673 L .34658 .36708 L p
1 g
F P
s
P
p
.002 w
.34658 .36708 m .38102 .33159 L .38995 .35684 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.65109 .42445 m .6301 .36922 L .64785 .35592 L p
1 g
F P
s
P
p
.002 w
.60685 .30636 m .64785 .35592 L .6301 .36922 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.36566 .438 m .36248 .47083 L .33942 .46641 L p
1 g
F P
s
P
p
.002 w
.33942 .46641 m .3433 .42465 L .36566 .438 L p
1 g
F P
s
P
p
.002 w
.52571 .58371 m .5608 .56119 L .58252 .57273 L p
1 g
F P
s
P
p
.002 w
.61283 .53355 m .58252 .57273 L .5608 .56119 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.6301 .36922 m .59195 .32316 L .60685 .30636 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.48495 .59336 m .45085 .56841 L .46835 .57437 L 1 g
F
P
p
.002 w
.47969 .57824 m .48093 .58179 L p
.46835 .57437 L 1 g
F P
s
P
p
.002 w
.48093 .58179 m .48495 .59336 L p
.46835 .57437 L 1 g
F P
s
P
p
.002 w
.46835 .57437 m .46872 .57265 L p
.45891 .56873 L 1 g
F P
s
P
p
.002 w
.44394 .56778 m .4449 .55888 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.4596 .56921 m .45563 .56885 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.45563 .56885 m .44394 .56778 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.45081 .56304 m .45146 .56129 L p
.44435 .55512 L 1 g
F P
s
P
p
.44394 .56778 m .42837 .53333 L .43848 .54711 L 1 g
F
P
p
.002 w
.44518 .55624 m .4444 .56352 L p
.43848 .54711 L 1 g
F P
s
P
p
.002 w
.4444 .56352 m .44394 .56778 L p
.43848 .54711 L 1 g
F P
s
P
p
.002 w
.43848 .54711 m .43925 .54566 L p
.43474 .53675 L 1 g
F P
s
P
p
.44435 .55512 m .44518 .55624 L .45081 .56304 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43814 .54775 L p
1 g
F P
s
P
p
.45146 .56129 m .43814 .54775 L .44397 .55478 L 1 g
F
P
p
.45891 .56873 m .4596 .56921 L .46835 .57437 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.48921 .57862 m .47815 .57771 L .47969 .57824 L 1 g
F
P
p
.002 w
.51633 .58594 m .48495 .59336 L .48038 .58022 L p
1 g
F P
s
P
p
.002 w
.48038 .58022 m .47969 .57824 L p
.48909 .58021 L 1 g
F P
s
P
p
.51633 .58594 m .48038 .58022 L .48909 .58021 L 1 g
F
P
p
.002 w
.51091 .5802 m .51079 .57862 L p
.50287 .5802 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .5802 L p
1 g
F P
s
P
p
.002 w
.52571 .58371 m .51633 .58594 L p
.5048 .58149 L 1 g
F P
s
P
p
.52571 .58371 m .5048 .58149 L .50705 .58101 L 1 g
F
P
p
.53128 .57265 m .51091 .5802 L .52052 .57817 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58021 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .58021 L .50287 .5802 L 1 g
F
P
p
.51247 .5802 m .50146 .58021 L .47712 .57082 L 1 g
F
P
p
.52571 .58371 m .50146 .58021 L .51247 .5802 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.53128 .57265 m .52052 .57817 L .52115 .57804 L 1 g
F
P
p
.002 w
.55171 .56702 m .52571 .58371 L .52276 .58005 L p
1 g
F P
s
P
p
.002 w
.52276 .58005 m .52115 .57804 L p
.53163 .57426 L 1 g
F P
s
P
p
.55171 .56702 m .52276 .58005 L .53163 .57426 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53163 .57426 L p
1 g
F P
s
P
p
.54854 .56129 m .53163 .57426 L .5421 .56743 L 1 g
F
P
p
.002 w
.53163 .57426 m .53128 .57265 L p
.52115 .57804 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54912 .56285 m .54854 .56129 L p
.5421 .56743 L 1 g
F P
s
P
p
.002 w
.52115 .57804 m .50913 .56311 L p
.54384 .5663 L 1 g
F P
s
P
p
.55171 .56702 m .53163 .57426 L .54384 .5663 L 1 g
F
P
p
.53163 .57426 m .52115 .57804 L .54384 .5663 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.5608 .56119 m .55171 .56702 L p
.54588 .56648 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54912 .56285 L p
1 g
F P
s
P
p
.56075 .54566 m .54912 .56285 L .55437 .55697 L 1 g
F
P
p
.58628 .5279 m .55968 .55213 L .57075 .53334 L 1 g
F
P
p
.55968 .55213 m .55437 .55697 L .56138 .54685 L 1 g
F
P
p
.55968 .55213 m .56138 .54685 L .57075 .53334 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56138 .54685 L p
1 g
F P
s
P
p
.56654 .52734 m .56138 .54685 L .56506 .53541 L 1 g
F
P
p
.56075 .54566 m .55437 .55697 L .55509 .55591 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.58628 .5279 m .5608 .56119 L .55437 .55697 L p
1 g
F P
s
P
p
.5608 .56119 m .54588 .56648 L .55025 .56158 L 1 g
F
P
p
.002 w
.55437 .55697 m .5608 .56119 L p
.55025 .56158 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56213 .54826 L p
1 g
F P
s
P
p
.002 w
.56213 .54826 m .56075 .54566 L p
.55476 .55653 L 1 g
F P
s
P
p
.55476 .55653 m .54998 .56518 L .56213 .54826 L 1 g
F
P
p
.002 w
.50913 .56311 m .53657 .54529 L .55437 .55697 L p
1 g
F P
s
P
p
.55025 .56158 m .50913 .56311 L .55437 .55697 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56731 .52846 m .56654 .52734 L p
.56506 .53541 L 1 g
F P
s
P
p
.002 w
.55437 .55697 m .53657 .54529 L p
.5651 .53531 L 1 g
F P
s
P
p
.57075 .53334 m .56138 .54685 L .5651 .53531 L 1 g
F
P
p
.56138 .54685 m .55437 .55697 L .5651 .53531 L 1 g
F
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56731 .52846 L p
1 g
F P
s
P
p
.56515 .50826 m .56731 .52846 L .56711 .52226 L 1 g
F
P
p
.59911 .48728 m .56711 .52226 L .56617 .51181 L 1 g
F
P
p
.56683 .51917 m .56711 .52226 L .56706 .52063 L 1 g
F
P
p
.56515 .50826 m .56711 .52226 L .56683 .51917 L 1 g
F
P
p
.002 w
.59911 .48728 m .58628 .5279 L .56711 .52226 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56711 .52226 m .58628 .5279 L p
.5675 .53447 L 1 g
F P
s
P
p
.002 w
.56625 .48727 m .59911 .48728 L p
.56691 .51127 L 1 g
F P
s
P
p
.56691 .51127 m .56617 .51181 L .56618 .50971 L 1 g
F
P
p
.56691 .51127 m .56618 .50971 L .56625 .48727 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56594 .5092 L p
1 g
F P
s
P
p
.55661 .4905 m .56594 .5092 L .56219 .50117 L 1 g
F
P
p
.002 w
.56594 .5092 m .56515 .50826 L p
.56683 .51917 L 1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.55661 .4905 m .56219 .50117 L .56204 .50085 L 1 g
F
P
p
.55751 .49145 m .56204 .50085 L .55746 .49147 L 1 g
F
P
p
.002 w
.56625 .48727 m .56324 .49699 L p
.55751 .49145 L 1 g
F P
s
P
p
.002 w
.56324 .49699 m .56204 .50085 L p
.55751 .49145 L 1 g
F P
s
P
p
.002 w
.5574 .49135 m .55661 .4905 L p
.56204 .50085 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5574 .49135 L p
1 g
F P
s
P
p
.54174 .47608 m .5574 .49135 L .55248 .48658 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55248 .48658 m .5308 .48549 L p
.54084 .47599 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54227 .47666 L p
1 g
F P
s
P
p
.52214 .46667 m .54227 .47666 L .53353 .47257 L 1 g
F
P
p
.54122 .47564 m .54227 .47666 L .54084 .47599 L 1 g
F
P
p
.54227 .47666 m .55248 .48658 L .54084 .47599 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52975 .46217 m .56488 .45326 L p
.54084 .47599 L 1 g
F P
s
P
p
.002 w
.5308 .48549 m .53014 .47098 L p
.54084 .47599 L 1 g
F P
s
P
p
.52214 .46667 m .53353 .47257 L .53014 .47098 L 1 g
F
P
p
.002 w
.53014 .47098 m .5308 .48549 L p
.52169 .4671 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.5 .4634 m .52247 .46722 L .51303 .46585 L 1 g
F
P
p
.002 w
.51303 .46585 m .49351 .47015 L p
.49908 .46405 L 1 g
F P
s
P
p
.5 .4639 m .51303 .46585 L .49908 .46405 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4639 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .4639 L .49177 .46526 L 1 g
F
P
p
.47786 .46667 m .49177 .46526 L .49158 .46529 L 1 g
F
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49158 .46529 m .49351 .47015 L p
.47587 .46801 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.49351 .47015 m .45765 .47684 L p
.47587 .46801 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46831 .47167 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46831 .47167 L 1 g
F
P
p
.002 w
.47442 .50877 m .46315 .51161 L .45759 .47687 L p
1 g
F P
s
P
p
.002 w
.4575 .47691 m .45826 .47608 L p
.45759 .47687 L 1 g
F P
s
P
p
.002 w
.45759 .47687 m .45758 .47685 L .45759 .47687 L p
1 g
F P
s
P
p
.002 w
.45759 .47687 m .47442 .50877 L p
.45759 .47687 L 1 g
F P
s
P
p
.002 w
.4908 .49313 m .48398 .50239 L .4576 .47687 L p
1 g
F P
s
P
p
.002 w
.4576 .47687 m .45758 .47685 L .4576 .47686 L p
1 g
F P
s
P
p
.002 w
.4576 .47686 m .4908 .49313 L p
.4576 .47687 L 1 g
F P
s
P
p
.002 w
.49351 .47015 m .4941 .48198 L .45761 .47686 L p
1 g
F P
s
P
p
.45826 .47608 m .45761 .47686 L .4576 .47686 L 1 g
F
P
p
.002 w
.45761 .47686 m .45758 .47685 L .45765 .47684 L p
1 g
F P
s
P
p
.002 w
.45765 .47684 m .49351 .47015 L p
.45761 .47686 L 1 g
F P
s
P
p
.45826 .47608 m .46831 .47167 L .45765 .47684 L 1 g
F
P
p
.45761 .47686 m .45765 .47684 L .45761 .47686 L 1 g
F
P
p
.45826 .47608 m .45765 .47684 L .45761 .47686 L 1 g
F
P
p
.002 w
.4941 .48198 m .4908 .49313 L .4576 .47686 L p
1 g
F P
s
P
p
.002 w
.4576 .47686 m .45758 .47685 L .45761 .47686 L p
1 g
F P
s
P
p
.002 w
.45761 .47686 m .4941 .48198 L p
.4576 .47686 L 1 g
F P
s
P
p
.4576 .47686 m .45761 .47686 L .4576 .47686 L 1 g
F
P
p
.002 w
.48398 .50239 m .47442 .50877 L .45759 .47687 L p
1 g
F P
s
P
p
.002 w
.45759 .47687 m .45758 .47685 L .4576 .47687 L p
1 g
F P
s
P
p
.002 w
.4576 .47687 m .48398 .50239 L p
.45759 .47687 L 1 g
F P
s
P
p
.45759 .47687 m .4576 .47686 L .45759 .47687 L 1 g
F
P
p
.45826 .47608 m .4576 .47686 L .45759 .47687 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43133 .498 m .44455 .48735 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.43691 .50287 m .43364 .50002 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.43364 .50002 m .43133 .498 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4419 .49209 L p
1 g
F P
s
P
p
.002 w
.4419 .49209 m .44166 .49233 L p
.4402 .49575 L 1 g
F P
s
P
p
.43485 .50826 m .4419 .49209 L .4402 .49575 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.42538 .53205 m .42658 .5252 L .43339 .51568 L 1 g
F
P
p
.002 w
.43317 .51847 m .42538 .53205 L p
.43339 .51568 L 1 g
F P
s
P
p
.002 w
.43133 .498 m .43455 .50081 L p
.42658 .5252 L 1 g
F P
s
P
p
.002 w
.43455 .50081 m .43691 .50287 L p
.43388 .50941 L 1 g
F P
s
P
p
.42658 .5252 m .43455 .50081 L .43388 .50941 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50941 L p
1 g
F P
s
P
p
.43346 .52734 m .43388 .50941 L .43317 .51847 L 1 g
F
P
p
.002 w
.43207 .53493 m .42538 .53205 L .4308 .5226 L p
1 g
F P
s
P
p
.002 w
.4308 .5226 m .43317 .51847 L p
.43249 .52876 L 1 g
F P
s
P
p
.43207 .53493 m .4308 .5226 L .43249 .52876 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43446 .53595 m .43207 .53493 L p
.43315 .53118 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43249 .52876 L p
1 g
F P
s
P
p
.43207 .53493 m .43249 .52876 L .43315 .53118 L 1 g
F
P
p
.002 w
.4468 .54126 m .44518 .55624 L p
.43848 .54711 L 1 g
F P
s
P
p
.002 w
.42837 .53333 m .43446 .53595 L p
.43848 .54711 L 1 g
F P
s
P
p
.43925 .54566 m .43249 .52876 L .43459 .53645 L 1 g
F
P
p
.002 w
.43446 .53595 m .4468 .54126 L p
.43848 .54711 L 1 g
F P
s
P
p
.43459 .53645 m .43446 .53595 L .43146 .53025 L 1 g
F
P
p
.002 w
.43249 .52876 m .43208 .52935 L p
.43446 .53595 L 1 g
F P
s
P
p
.002 w
.43208 .52935 m .43146 .53025 L p
.43446 .53595 L 1 g
F P
s
P
p
.43346 .52734 m .43317 .51847 L .43316 .51871 L 1 g
F
P
p
.002 w
.43236 .52894 m .43346 .52734 L p
.43316 .51868 L 1 g
F P
s
P
p
.002 w
.43317 .51847 m .44039 .50591 L p
.43315 .53118 L 1 g
F P
s
P
p
.43249 .52876 m .43317 .51847 L .43315 .53118 L 1 g
F
P
p
.002 w
.4468 .54126 m .43446 .53595 L p
.44039 .50591 L 1 g
F P
s
P
p
.43446 .53595 m .43315 .53118 L .44039 .50591 L 1 g
F
P
p
.43474 .53675 m .43459 .53645 L .43848 .54711 L 1 g
F
P
p
.43459 .53645 m .43146 .53025 L .43565 .54032 L 1 g
F
P
p
.43459 .53645 m .43565 .54032 L .43848 .54711 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43784 .54832 L p
1 g
F P
s
P
p
.002 w
.43784 .54832 m .43848 .54711 L p
.43565 .54032 L 1 g
F P
s
P
p
.43565 .54032 m .43146 .53025 L .43784 .54832 L 1 g
F
P
p
.43316 .51871 m .43317 .51847 L .43316 .51868 L 1 g
F
P
p
.002 w
.4334 .50998 m .43485 .50826 L p
.43879 .49905 L 1 g
F P
s
P
p
.002 w
.43691 .50287 m .44039 .50591 L p
.42658 .5252 L 1 g
F P
s
P
p
.002 w
.43388 .50941 m .43287 .51061 L p
.43316 .51868 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43236 .52894 L p
1 g
F P
s
P
p
.43316 .51868 m .43287 .51061 L .43236 .52894 L 1 g
F
P
p
.002 w
.44039 .50591 m .43317 .51847 L p
.43339 .51568 L 1 g
F P
s
P
p
.002 w
.44257 .49137 m .44339 .4905 L p
.45073 .48347 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43691 .50287 m .44257 .49137 L .45753 .4769 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4575 .47691 L p
1 g
F P
s
P
p
.002 w
.45758 .47685 m .45753 .4769 L p
.4575 .47691 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.42516 .48774 m .45754 .47687 L p
.4575 .47691 L 1 g
F P
s
P
p
.002 w
.45754 .47687 m .45758 .47685 L p
.4575 .47691 L 1 g
F P
s
P
p
.44339 .4905 m .4575 .47691 L .45073 .48347 L 1 g
F
P
p
.4575 .47691 m .4575 .47691 L .45743 .47698 L 1 g
F
P
p
.4575 .47691 m .45743 .47698 L .45073 .48347 L 1 g
F
P
p
.002 w
.43133 .498 m .42705 .49088 L p
.4575 .47691 L 1 g
F P
s
P
p
.002 w
.45753 .4769 m .45743 .47698 L p
.4575 .47691 L 1 g
F P
s
P
p
.002 w
.45743 .47698 m .43133 .498 L p
.4575 .47691 L 1 g
F P
s
P
p
.002 w
.44455 .48735 m .45743 .47698 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.45743 .47698 m .45753 .4769 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.4575 .47691 m .45698 .47747 L p
.45073 .48347 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44257 .49137 L p
1 g
F P
s
P
p
.45073 .48347 m .45698 .47747 L .44257 .49137 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .4334 .50998 L p
1 g
F P
s
P
p
.43879 .49905 m .44166 .49233 L .4334 .50998 L 1 g
F
P
p
.002 w
.44039 .50591 m .43691 .50287 L p
.45753 .4769 L 1 g
F P
s
P
p
.002 w
.45753 .4769 m .45758 .47685 L .45757 .47688 L p
1 g
F P
s
P
p
.002 w
.45757 .47688 m .44039 .50591 L p
.45753 .4769 L 1 g
F P
s
P
p
.002 w
.45749 .47692 m .4575 .47691 L p
.45759 .47687 L 1 g
F P
s
P
p
.002 w
.4575 .47691 m .4575 .47691 L p
.45753 .4769 L 1 g
F P
s
P
p
.45753 .4769 m .45759 .47687 L .4575 .47691 L 1 g
F
P
p
.002 w
.42705 .49088 m .42516 .48774 L p
.45753 .4769 L 1 g
F P
s
P
p
.002 w
.45758 .47685 m .47361 .46773 L p
.47587 .46801 L 1 g
F P
s
P
p
.002 w
.45765 .47684 m .45758 .47685 L p
.47587 .46801 L 1 g
F P
s
P
p
.47754 .4672 m .47587 .46801 L .47361 .46773 L 1 g
F
P
p
.49158 .46529 m .47587 .46801 L .47754 .4672 L 1 g
F
P
p
.002 w
.45139 .51061 m .44039 .50591 L .45757 .47688 L p
1 g
F P
s
P
p
.002 w
.45757 .47688 m .45758 .47685 L .45758 .47687 L p
1 g
F P
s
P
p
.002 w
.45758 .47687 m .45139 .51061 L p
.45757 .47688 L 1 g
F P
s
P
p
.002 w
.46315 .51161 m .45139 .51061 L .45758 .47687 L p
1 g
F P
s
P
p
.002 w
.45758 .47687 m .45758 .47685 L .45759 .47687 L p
1 g
F P
s
P
p
.002 w
.45759 .47687 m .46315 .51161 L p
.45758 .47687 L 1 g
F P
s
P
p
.4576 .47687 m .47718 .46778 L .45749 .47692 L 1 g
F
P
p
.46831 .47167 m .4759 .46834 L .4576 .47687 L 1 g
F
P
p
.4759 .46834 m .47718 .46778 L .4576 .47687 L 1 g
F
P
p
.002 w
.45698 .47747 m .45749 .47692 L p
.45881 .47631 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .47533 .46867 L p
.45881 .47631 L 1 g
F P
s
P
p
.002 w
.47533 .46867 m .45698 .47747 L p
.45881 .47631 L 1 g
F P
s
P
p
.002 w
.47727 .46764 m .47754 .4672 L p
.49158 .46529 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.49158 .46529 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47361 .46773 m .48906 .45894 L .49158 .46529 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49351 .47015 m .48906 .45894 L .52105 .44003 L p
1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .46442 L p
.49177 .46526 L 1 g
F P
s
P
p
.5 .4634 m .51303 .46585 L .51176 .46566 L 1 g
F
P
p
.002 w
.5308 .48549 m .4941 .48198 L p
.52104 .46701 L 1 g
F P
s
P
p
.52169 .4671 m .5308 .48549 L .52104 .46701 L 1 g
F
P
p
.002 w
.4941 .48198 m .49351 .47015 L .52975 .46217 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46397 L p
1 g
F P
s
P
p
.002 w
.5 .46397 m .5 .4634 L p
.5119 .46569 L 1 g
F P
s
P
p
.5119 .46569 m .52282 .46778 L .5 .46397 L 1 g
F
P
p
.52151 .46675 m .52169 .4671 L .52104 .46701 L 1 g
F
P
p
.52105 .44003 m .51437 .46153 L .49931 .4638 L 1 g
F
P
p
.51437 .46153 m .51303 .46585 L .5 .4639 L 1 g
F
P
p
.51437 .46153 m .5 .4639 L .49931 .4638 L 1 g
F
P
p
.49931 .4638 m .5 .4639 L .49908 .46405 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47727 .46764 L p
1 g
F P
s
P
p
.49177 .46526 m .5 .46442 L .47727 .46764 L 1 g
F
P
p
.51176 .46566 m .51303 .46585 L .5119 .46569 L 1 g
F
P
p
.002 w
.52105 .44003 m .52975 .46217 L .51303 .46585 L p
1 g
F P
s
P
p
.52247 .46722 m .52169 .4671 L .52151 .46675 L 1 g
F
P
p
.53014 .47098 m .52169 .4671 L .52247 .46722 L 1 g
F
P
p
.002 w
.52247 .46722 m .52282 .46778 L p
.5119 .46569 L 1 g
F P
s
P
p
.002 w
.52261 .46745 m .52247 .46722 L p
.53014 .47098 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.53014 .47098 L 1 g
F P
s
P
p
.002 w
.52975 .46217 m .53014 .47098 L p
.52151 .46675 L 1 g
F P
s
P
p
.002 w
.53014 .47098 m .52975 .46217 L p
.54084 .47599 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52261 .46745 L p
1 g
F P
s
P
p
.53353 .47257 m .54302 .47747 L .52261 .46745 L 1 g
F
P
p
.002 w
.54227 .47666 m .54302 .47747 L p
.53353 .47257 L 1 g
F P
s
P
p
.54996 .48413 m .55248 .48658 L .55072 .48488 L 1 g
F
P
p
.54174 .47608 m .55248 .48658 L .54996 .48413 L 1 g
F
P
p
.002 w
.56488 .45326 m .56625 .48727 L .55248 .48658 L p
1 g
F P
s
P
p
.56488 .45326 m .55248 .48658 L .54122 .47564 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.52416 .50738 m .5308 .48549 L .55248 .48658 L p
1 g
F P
s
P
p
.002 w
.55248 .48658 m .56625 .48727 L p
.55751 .49145 L 1 g
F P
s
P
p
.55751 .49145 m .52416 .50738 L .55248 .48658 L 1 g
F
P
p
.55748 .4915 m .56204 .50085 L .55783 .49184 L 1 g
F
P
p
.55748 .4915 m .55783 .49184 L .55778 .49175 L 1 g
F
P
p
.002 w
.55778 .49175 m .5574 .49135 L p
.55748 .4915 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55638 .5191 m .52416 .50738 L p
.55746 .49147 L 1 g
F P
s
P
p
.002 w
.56204 .50085 m .55638 .5191 L p
.55746 .49147 L 1 g
F P
s
P
p
.002 w
.56204 .50085 m .56448 .49296 L p
.56594 .5092 L 1 g
F P
s
P
p
.002 w
.56448 .49296 m .56625 .48727 L p
.56617 .51181 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55778 .49175 L p
1 g
F P
s
P
p
.56219 .50117 m .56713 .51061 L .55778 .49175 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54255 .47697 L p
1 g
F P
s
P
p
.002 w
.54255 .47697 m .54174 .47608 L p
.55072 .48488 L 1 g
F P
s
P
p
.55072 .48488 m .55834 .49233 L .54255 .47697 L 1 g
F
P
p
.002 w
.5574 .49135 m .55834 .49233 L p
.55072 .48488 L 1 g
F P
s
P
p
.002 w
.55638 .5191 m .56204 .50085 L p
.56617 .51181 L 1 g
F P
s
P
p
.56617 .51181 m .56204 .50085 L .56594 .5092 L 1 g
F
P
p
.002 w
.56594 .5092 m .56713 .51061 L p
.56219 .50117 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56594 .5092 L p
1 g
F P
s
P
p
.56683 .51917 m .56854 .53025 L .56594 .5092 L 1 g
F
P
p
.002 w
.56711 .52226 m .55638 .5191 L p
.56617 .51181 L 1 g
F P
s
P
p
.002 w
.53657 .54529 m .55638 .5191 L .56711 .52226 L p
1 g
F P
s
P
p
.5675 .53447 m .53657 .54529 L .56711 .52226 L 1 g
F
P
p
.002 w
.56731 .52846 m .56854 .53025 L p
.56706 .52063 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56731 .52846 L p
1 g
F P
s
P
p
.56506 .53541 m .56257 .5491 L .56731 .52846 L 1 g
F
P
p
.002 w
.56138 .54685 m .56257 .5491 L p
.56506 .53541 L 1 g
F P
s
P
p
.55509 .55591 m .55437 .55697 L .55476 .55653 L 1 g
F
P
p
.55025 .56158 m .54588 .56648 L .50913 .56311 L 1 g
F
P
p
.002 w
.54912 .56285 m .54998 .56518 L p
.55476 .55653 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54912 .56285 L p
1 g
F P
s
P
p
.5421 .56743 m .5322 .57686 L .54912 .56285 L 1 g
F
P
p
.002 w
.53163 .57426 m .5322 .57686 L p
.5421 .56743 L 1 g
F P
s
P
p
.002 w
.53196 .57575 m .53163 .57426 L p
.52115 .57804 L 1 g
F P
s
P
p
.002 w
.47712 .57082 m .50913 .56311 L .52115 .57804 L p
1 g
F P
s
P
p
.002 w
.52115 .57804 m .52571 .58371 L p
.51178 .58002 L 1 g
F P
s
P
p
.51178 .58002 m .47712 .57082 L .52115 .57804 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53196 .57575 L p
1 g
F P
s
P
p
.52052 .57817 m .51111 .583 L .53196 .57575 L 1 g
F
P
p
.002 w
.51091 .5802 m .51111 .583 L p
.52052 .57817 L 1 g
F P
s
P
p
.50705 .58101 m .5048 .58149 L .50146 .58021 L 1 g
F
P
p
.002 w
.48909 .58021 m .48921 .57862 L p
.47969 .57824 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.47969 .57824 m .47712 .57082 L p
.51633 .58594 L 1 g
F P
s
P
p
.002 w
.48909 .58021 m .48889 .583 L p
.50287 .5802 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .5802 L p
1 g
F P
s
P
p
.50287 .5802 m .48889 .583 L .51091 .5802 L 1 g
F
P
p
.002 w
.489 .58141 m .48909 .58021 L p
.47969 .57824 L 1 g
F P
s
P
p
.002 w
.47712 .57082 m .47969 .57824 L p
.46835 .57437 L 1 g
F P
s
P
p
.002 w
.45085 .56841 m .4596 .56921 L p
.46835 .57437 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45051 .56385 L p
1 g
F P
s
P
p
.46872 .57265 m .45051 .56385 L .4585 .56857 L 1 g
F
P
p
.002 w
.4596 .56921 m .47712 .57082 L p
.46835 .57437 L 1 g
F P
s
P
p
.002 w
.45051 .56385 m .45002 .56518 L p
.4585 .56857 L 1 g
F P
s
P
p
.4596 .56921 m .45081 .56304 L .4468 .54126 L 1 g
F
P
p
.002 w
.4449 .55888 m .44518 .55624 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.44518 .55624 m .4468 .54126 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.43814 .54775 m .43743 .5491 L p
.44397 .55478 L 1 g
F P
s
P
p
.44435 .55512 m .44397 .55478 L .44518 .55624 L 1 g
F
P
p
.002 w
.42538 .53205 m .42837 .53333 L p
.44394 .56778 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45081 .56304 L p
1 g
F P
s
P
p
.44397 .55478 m .43743 .5491 L .45081 .56304 L 1 g
F
P
p
.45891 .56873 m .4585 .56857 L .4596 .56921 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47712 .57082 m .4596 .56921 L p
.4468 .54126 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46835 .57437 L p
1 g
F P
s
P
p
.4585 .56857 m .45002 .56518 L .46835 .57437 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .489 .58141 L p
1 g
F P
s
P
p
.47815 .57771 m .4678 .57686 L .489 .58141 L 1 g
F
P
p
.002 w
.44394 .56778 m .45085 .56841 L p
.48495 .59336 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47727 .30401 m .42619 .30962 L .42641 .28523 L p
1 g
F P
s
P
p
.002 w
.42641 .28523 m .48366 .27873 L .47727 .30401 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.61283 .53355 m .62824 .48556 L .65271 .48226 L p
1 g
F P
s
P
p
.002 w
.65109 .42445 m .65271 .48226 L .62824 .48556 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.37943 .40831 m .36566 .438 L .3433 .42465 L p
1 g
F P
s
P
p
.002 w
.3433 .42465 m .36066 .38673 L .37943 .40831 L p
1 g
F P
s
P
p
.002 w
.42823 .33844 m .38995 .35684 L .38102 .33159 L p
1 g
F P
s
P
p
.002 w
.38102 .33159 m .42619 .30962 L .42823 .33844 L p
1 g
F P
s
P
p
.002 w
.5608 .56119 m .58628 .5279 L .61283 .53355 L p
1 g
F P
s
P
p
.002 w
.62824 .48556 m .61283 .53355 L .58628 .5279 L p
1 g
F P
s
P
p
.002 w
.52846 .31578 m .47727 .30401 L .48366 .27873 L p
1 g
F P
s
P
p
.002 w
.48366 .27873 m .54111 .29179 L .52846 .31578 L p
1 g
F P
s
P
p
.002 w
.39565 .49665 m .40772 .51664 L .38754 .53218 L p
1 g
F P
s
P
p
.002 w
.38754 .53218 m .37007 .50334 L .39565 .49665 L p
1 g
F P
s
P
p
.002 w
.41303 .55442 m .38754 .53218 L .40772 .51664 L p
1 g
F P
s
P
p
.002 w
.44394 .56778 m .41303 .55442 L .42538 .53205 L p
1 g
F P
s
P
p
.002 w
.40772 .51664 m .42538 .53205 L .41303 .55442 L p
1 g
F P
s
P
p
.002 w
.62824 .48556 m .62662 .43402 L .65109 .42445 L p
1 g
F P
s
P
p
.002 w
.6301 .36922 m .65109 .42445 L .62662 .43402 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39047 .47415 m .39565 .49665 L .37007 .50334 L p
1 g
F P
s
P
p
.002 w
.37007 .50334 m .36248 .47083 L .39047 .47415 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.40251 .38502 m .37943 .40831 L .36066 .38673 L p
1 g
F P
s
P
p
.002 w
.36066 .38673 m .38995 .35684 L .40251 .38502 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.57376 .34378 m .52846 .31578 L .54111 .29179 L p
1 g
F P
s
P
p
.002 w
.54111 .29179 m .59195 .32316 L .57376 .34378 L p
1 g
F P
s
P
p
.002 w
.62662 .43402 m .6078 .38482 L .6301 .36922 L p
1 g
F P
s
P
p
.002 w
.59195 .32316 m .6301 .36922 L .6078 .38482 L p
1 g
F P
s
P
p
.002 w
.39277 .45149 m .39047 .47415 L .36248 .47083 L p
1 g
F P
s
P
p
.002 w
.36248 .47083 m .36566 .438 L .39277 .45149 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.4468 .54126 m .46975 .54329 L .47712 .57082 L p
1 g
F P
s
P
p
.002 w
.50913 .56311 m .47712 .57082 L .46975 .54329 L p
1 g
F P
s
P
p
.002 w
.4714 .33389 m .42823 .33844 L .42619 .30962 L p
1 g
F P
s
P
p
.002 w
.42619 .30962 m .47727 .30401 L .4714 .33389 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.6078 .38482 m .57376 .34378 L .59195 .32316 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58628 .5279 m .59911 .48728 L .62824 .48556 L p
1 g
F P
s
P
p
.002 w
.62662 .43402 m .62824 .48556 L .59911 .48728 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40237 .43109 m .39277 .45149 L .36566 .438 L p
1 g
F P
s
P
p
.002 w
.36566 .438 m .37943 .40831 L .40237 .43109 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46975 .54329 m .49182 .53786 L .50913 .56311 L p
1 g
F P
s
P
p
.002 w
.53657 .54529 m .50913 .56311 L .49182 .53786 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.43255 .3708 m .40251 .38502 L .38995 .35684 L p
1 g
F P
s
P
p
.002 w
.38995 .35684 m .42823 .33844 L .43255 .3708 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51459 .34395 m .4714 .33389 L .47727 .30401 L p
1 g
F P
s
P
p
.002 w
.47727 .30401 m .52846 .31578 L .51459 .34395 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59911 .48728 m .59757 .44375 L .62662 .43402 L p
1 g
F P
s
P
p
.002 w
.6078 .38482 m .62662 .43402 L .59757 .44375 L p
1 g
F P
s
P
p
.002 w
.42516 .48774 m .43133 .498 L .40772 .51664 L p
1 g
F P
s
P
p
.002 w
.40772 .51664 m .39565 .49665 L .42516 .48774 L p
1 g
F P
s
P
p
.002 w
.42538 .53205 m .40772 .51664 L .43133 .498 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42254 .4762 m .42516 .48774 L .39565 .49665 L p
1 g
F P
s
P
p
.002 w
.39565 .49665 m .39047 .47415 L .42254 .4762 L p
1 g
F P
s
P
p
.002 w
.44039 .50591 m .45139 .51061 L .4468 .54126 L p
1 g
F P
s
P
p
.002 w
.46975 .54329 m .4468 .54126 L .45139 .51061 L p
1 g
F P
s
P
p
.002 w
.41835 .41517 m .40237 .43109 L .37943 .40831 L p
1 g
F P
s
P
p
.002 w
.37943 .40831 m .40251 .38502 L .41835 .41517 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.49182 .53786 m .51065 .52548 L .53657 .54529 L p
1 g
F P
s
P
p
.002 w
.55638 .5191 m .53657 .54529 L .51065 .52548 L p
1 g
F P
s
P
p
.002 w
.55281 .36763 m .51459 .34395 L .52846 .31578 L p
1 g
F P
s
P
p
.002 w
.52846 .31578 m .57376 .34378 L .55281 .36763 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.42377 .46462 m .42254 .4762 L .39047 .47415 L p
1 g
F P
s
P
p
.002 w
.39047 .47415 m .39277 .45149 L .42377 .46462 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59757 .44375 m .58157 .40225 L .6078 .38482 L p
1 g
F P
s
P
p
.002 w
.57376 .34378 m .6078 .38482 L .58157 .40225 L p
1 g
F P
s
P
p
.002 w
.45139 .51061 m .46315 .51161 L .46975 .54329 L p
1 g
F P
s
P
p
.002 w
.49182 .53786 m .46975 .54329 L .46315 .51161 L p
1 g
F P
s
P
p
.002 w
.4663 .3674 m .43255 .3708 L .42823 .33844 L p
1 g
F P
s
P
p
.002 w
.42823 .33844 m .4714 .33389 L .4663 .3674 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59757 .44375 m .59911 .48728 L .56625 .48727 L p
1 g
F P
s
P
p
.002 w
.58157 .40225 m .55281 .36763 L .57376 .34378 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.42874 .45424 m .42377 .46462 L .39277 .45149 L p
1 g
F P
s
P
p
.002 w
.39277 .45149 m .40237 .43109 L .42874 .45424 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46315 .51161 m .47442 .50877 L .49182 .53786 L p
1 g
F P
s
P
p
.002 w
.51065 .52548 m .49182 .53786 L .47442 .50877 L p
1 g
F P
s
P
p
.002 w
.43904 .40554 m .41835 .41517 L .40251 .38502 L p
1 g
F P
s
P
p
.002 w
.40251 .38502 m .43255 .3708 L .43904 .40554 L p
1 g
F P
s
P
p
.002 w
.51065 .52548 m .52416 .50738 L .55638 .5191 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.50001 .37536 m .4663 .3674 L .4714 .33389 L p
1 g
F P
s
P
p
.002 w
.4714 .33389 m .51459 .34395 L .50001 .37536 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56625 .48727 m .56488 .45326 L .59757 .44375 L p
1 g
F P
s
P
p
.002 w
.58157 .40225 m .59757 .44375 L .56488 .45326 L p
1 g
F P
s
P
p
.002 w
.43694 .44618 m .42874 .45424 L .40237 .43109 L p
1 g
F P
s
P
p
.002 w
.40237 .43109 m .41835 .41517 L .43694 .44618 L p
1 g
F P
s
P
p
.002 w
.47442 .50877 m .48398 .50239 L .51065 .52548 L p
1 g
F P
s
P
p
.002 w
.52416 .50738 m .51065 .52548 L .48398 .50239 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.42516 .48774 m .42254 .4762 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.4622 .40332 m .43904 .40554 L .43255 .3708 L p
1 g
F P
s
P
p
.002 w
.43255 .3708 m .4663 .3674 L .4622 .40332 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.42254 .4762 m .42377 .46462 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52982 .39389 m .50001 .37536 L .51459 .34395 L p
1 g
F P
s
P
p
.002 w
.51459 .34395 m .55281 .36763 L .52982 .39389 L p
1 g
F P
s
P
p
.002 w
.56488 .45326 m .55229 .42089 L .58157 .40225 L p
1 g
F P
s
P
p
.002 w
.55281 .36763 m .58157 .40225 L .55229 .42089 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.42377 .46462 m .42874 .45424 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.44749 .44135 m .43694 .44618 L .41835 .41517 L p
1 g
F P
s
P
p
.002 w
.41835 .41517 m .43904 .40554 L .44749 .44135 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55229 .42089 m .52982 .39389 L .55281 .36763 L p
1 g
F P
s
P
p
.002 w
.48398 .50239 m .4908 .49313 L .52416 .50738 L p
1 g
F P
s
P
p
.002 w
.5308 .48549 m .52416 .50738 L .4908 .49313 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42874 .45424 m .43694 .44618 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.48527 .40886 m .4622 .40332 L .4663 .3674 L p
1 g
F P
s
P
p
.002 w
.4663 .3674 m .50001 .37536 L .48527 .40886 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55229 .42089 m .56488 .45326 L .52975 .46217 L p
1 g
F P
s
P
p
.002 w
.45925 .44029 m .44749 .44135 L .43904 .40554 L p
1 g
F P
s
P
p
.002 w
.43904 .40554 m .4622 .40332 L .45925 .44029 L p
1 g
F P
s
P
p
.002 w
.43694 .44618 m .44749 .44135 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.4908 .49313 m .4941 .48198 L .5308 .48549 L p
1 g
F P
s
P
p
.002 w
.48125 .44959 m .48906 .45894 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.004 w
.48187 .45032 m
.5 .43051 L
s
P
p
.002 w
.47093 .44314 m .48125 .44959 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.45925 .44029 m .47093 .44314 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.44749 .44135 m .45925 .44029 L .45758 .47685 L closepath p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.50565 .42157 m .48527 .40886 L .50001 .37536 L p
1 g
F P
s
P
p
.002 w
.50001 .37536 m .52982 .39389 L .50565 .42157 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.004 w
.45622 .47835 m
.45758 .47685 L
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52975 .46217 m .52105 .44003 L .55229 .42089 L p
1 g
F P
s
P
p
.002 w
.52982 .39389 m .55229 .42089 L .52105 .44003 L p
1 g
F P
s
P
p
.002 w
.52105 .44003 m .50565 .42157 L .52982 .39389 L p
1 g
F P
s
P
p
.002 w
.47093 .44314 m .45925 .44029 L .4622 .40332 L p
1 g
F P
s
P
p
.002 w
.4622 .40332 m .48527 .40886 L .47093 .44314 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.48125 .44959 m .47093 .44314 L .48527 .40886 L p
1 g
F P
s
P
p
.002 w
.48906 .45894 m .48125 .44959 L .50565 .42157 L p
1 g
F P
s
P
p
.002 w
.50565 .42157 m .52105 .44003 L .48906 .45894 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.48527 .40886 m .50565 .42157 L .48125 .44959 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.43142 .50544 m
.45622 .47835 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .25735 .59938 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .43142 .50544 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0442105)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0442105)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47242 .4402 m .4867 .45196 L .50105 .42729 L p
1 g
F P
s
P
p
.002 w
.50105 .42729 m .49382 .42133 L .47242 .4402 L p
1 g
F P
s
P
p
.002 w
.5098 .43063 m .50105 .42729 L .4867 .45196 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .49382 .42133 L .50105 .42729 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .50105 .42729 L .5098 .43063 L closepath p
1 g
F P
s
P
p
.002 w
.4867 .45196 m .50399 .45856 L .5098 .43063 L p
1 g
F P
s
P
p
.002 w
.51914 .43099 m .5098 .43063 L .50399 .45856 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .5098 .43063 L .51914 .43099 L closepath p
1 g
F P
s
P
p
.002 w
.46267 .42452 m .47242 .4402 L .49382 .42133 L p
1 g
F P
s
P
p
.002 w
.49382 .42133 m .4889 .41339 L .46267 .42452 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .4889 .41339 L .49382 .42133 L closepath p
1 g
F P
s
P
p
.002 w
.50399 .45856 m .52245 .4593 L .51914 .43099 L p
1 g
F P
s
P
p
.002 w
.52807 .42832 m .51914 .43099 L .52245 .4593 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .51914 .43099 L .52807 .42832 L closepath p
1 g
F P
s
P
p
.002 w
.4585 .40658 m .46267 .42452 L .4889 .41339 L p
1 g
F P
s
P
p
.002 w
.4889 .41339 m .48682 .40431 L .4585 .40658 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .48682 .40431 L .4889 .41339 L closepath p
1 g
F P
s
P
p
.002 w
.45156 .45894 m .4726 .47624 L .4867 .45196 L p
1 g
F P
s
P
p
.002 w
.4867 .45196 m .47242 .4402 L .45156 .45894 L p
1 g
F P
s
P
p
.002 w
.50399 .45856 m .4867 .45196 L .4726 .47624 L p
1 g
F P
s
P
p
.002 w
.52245 .4593 m .54011 .45407 L .52807 .42832 L p
1 g
F P
s
P
p
.002 w
.53562 .42291 m .52807 .42832 L .54011 .45407 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .52807 .42832 L .53562 .42291 L closepath p
1 g
F P
s
P
p
.002 w
.4726 .47624 m .49805 .48598 L .50399 .45856 L p
1 g
F P
s
P
p
.002 w
.52245 .4593 m .50399 .45856 L .49805 .48598 L p
1 g
F P
s
P
p
.002 w
.43716 .43587 m .45156 .45894 L .47242 .4402 L p
1 g
F P
s
P
p
.002 w
.47242 .4402 m .46267 .42452 L .43716 .43587 L p
1 g
F P
s
P
p
.002 w
.46039 .3883 m .4585 .40658 L .48682 .40431 L p
1 g
F P
s
P
p
.002 w
.48682 .40431 m .4878 .39508 L .46039 .3883 L p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .4878 .39508 L .48682 .40431 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .53562 .42291 L .54097 .41534 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .54097 .41534 L .54354 .4064 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .54354 .4064 L .54303 .39709 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .54303 .39709 L .5395 .3884 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .5395 .3884 L .53332 .38129 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .53332 .38129 L .52517 .37654 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .52517 .37654 L .51593 .37468 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .51593 .37468 L .50662 .37589 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .50662 .37589 L .49826 .38005 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .49826 .38005 L .49175 .38669 L closepath p
1 g
F P
s
P
p
.002 w
.51538 .40269 m .49175 .38669 L .4878 .39508 L closepath p
1 g
F P
s
P
p
.002 w
.54011 .45407 m .55509 .44341 L .53562 .42291 L p
1 g
F P
s
P
p
.002 w
.54097 .41534 m .53562 .42291 L .55509 .44341 L p
1 g
F P
s
P
p
.002 w
.49805 .48598 m .52523 .4871 L .52245 .4593 L p
1 g
F P
s
P
p
.002 w
.54011 .45407 m .52245 .4593 L .52523 .4871 L p
1 g
F P
s
P
p
.002 w
.46817 .37164 m .46039 .3883 L .4878 .39508 L p
1 g
F P
s
P
p
.002 w
.4878 .39508 m .49175 .38669 L .46817 .37164 L p
1 g
F P
s
P
p
.002 w
.43094 .40945 m .43716 .43587 L .46267 .42452 L p
1 g
F P
s
P
p
.002 w
.46267 .42452 m .4585 .40658 L .43094 .40945 L p
1 g
F P
s
P
p
.002 w
.55509 .44341 m .56574 .42844 L .54097 .41534 L p
1 g
F P
s
P
p
.002 w
.54354 .4064 m .54097 .41534 L .56574 .42844 L p
1 g
F P
s
P
p
.002 w
.48103 .35843 m .46817 .37164 L .49175 .38669 L p
1 g
F P
s
P
p
.002 w
.49175 .38669 m .49826 .38005 L .48103 .35843 L p
1 g
F P
s
P
p
.002 w
.52523 .4871 m .55128 .47946 L .54011 .45407 L p
1 g
F P
s
P
p
.002 w
.55509 .44341 m .54011 .45407 L .55128 .47946 L p
1 g
F P
s
P
p
.002 w
.43364 .38247 m .43094 .40945 L .4585 .40658 L p
1 g
F P
s
P
p
.002 w
.4585 .40658 m .46039 .3883 L .43364 .38247 L p
1 g
F P
s
P
p
.002 w
.56574 .42844 m .57089 .41074 L .54354 .4064 L p
1 g
F P
s
P
p
.002 w
.54303 .39709 m .54354 .4064 L .57089 .41074 L p
1 g
F P
s
P
p
.002 w
.49761 .35013 m .48103 .35843 L .49826 .38005 L p
1 g
F P
s
P
p
.002 w
.49826 .38005 m .50662 .37589 L .49761 .35013 L p
1 g
F P
s
P
p
.002 w
.43163 .47721 m .459 .4997 L .4726 .47624 L p
1 g
F P
s
P
p
.002 w
.4726 .47624 m .45156 .45894 L .43163 .47721 L p
1 g
F P
s
P
p
.002 w
.49805 .48598 m .4726 .47624 L .459 .4997 L p
1 g
F P
s
P
p
.002 w
.57089 .41074 m .56994 .39224 L .54303 .39709 L p
1 g
F P
s
P
p
.002 w
.5395 .3884 m .54303 .39709 L .56994 .39224 L p
1 g
F P
s
P
p
.002 w
.5161 .34768 m .49761 .35013 L .50662 .37589 L p
1 g
F P
s
P
p
.002 w
.50662 .37589 m .51593 .37468 L .5161 .34768 L p
1 g
F P
s
P
p
.002 w
.459 .4997 m .49208 .51237 L .49805 .48598 L p
1 g
F P
s
P
p
.002 w
.52523 .4871 m .49805 .48598 L .49208 .51237 L p
1 g
F P
s
P
p
.002 w
.41284 .44724 m .43163 .47721 L .45156 .45894 L p
1 g
F P
s
P
p
.002 w
.45156 .45894 m .43716 .43587 L .41284 .44724 L p
1 g
F P
s
P
p
.002 w
.55128 .47946 m .57341 .46381 L .55509 .44341 L p
1 g
F P
s
P
p
.002 w
.56574 .42844 m .55509 .44341 L .57341 .46381 L p
1 g
F P
s
P
p
.002 w
.56994 .39224 m .56296 .37496 L .5395 .3884 L p
1 g
F P
s
P
p
.002 w
.53332 .38129 m .5395 .3884 L .56296 .37496 L p
1 g
F P
s
P
p
.002 w
.44505 .35784 m .43364 .38247 L .46039 .3883 L p
1 g
F P
s
P
p
.002 w
.46039 .3883 m .46817 .37164 L .44505 .35784 L p
1 g
F P
s
P
p
.002 w
.53447 .35138 m .5161 .34768 L .51593 .37468 L p
1 g
F P
s
P
p
.002 w
.51593 .37468 m .52517 .37654 L .53447 .35138 L p
1 g
F P
s
P
p
.002 w
.56296 .37496 m .55068 .36082 L .53332 .38129 L p
1 g
F P
s
P
p
.002 w
.52517 .37654 m .53332 .38129 L .55068 .36082 L p
1 g
F P
s
P
p
.002 w
.55068 .36082 m .53447 .35138 L .52517 .37654 L p
1 g
F P
s
P
p
.002 w
.49208 .51237 m .52743 .51389 L .52523 .4871 L p
1 g
F P
s
P
p
.002 w
.55128 .47946 m .52523 .4871 L .52743 .51389 L p
1 g
F P
s
P
p
.002 w
.40467 .41288 m .41284 .44724 L .43716 .43587 L p
1 g
F P
s
P
p
.002 w
.43716 .43587 m .43094 .40945 L .40467 .41288 L p
1 g
F P
s
P
p
.002 w
.57341 .46381 m .58922 .44176 L .56574 .42844 L p
1 g
F P
s
P
p
.002 w
.57089 .41074 m .56574 .42844 L .58922 .44176 L p
1 g
F P
s
P
p
.002 w
.464 .33826 m .44505 .35784 L .46817 .37164 L p
1 g
F P
s
P
p
.002 w
.46817 .37164 m .48103 .35843 L .464 .33826 L p
1 g
F P
s
P
p
.002 w
.52743 .51389 m .56135 .50403 L .55128 .47946 L p
1 g
F P
s
P
p
.002 w
.57341 .46381 m .55128 .47946 L .56135 .50403 L p
1 g
F P
s
P
p
.002 w
.40808 .37773 m .40467 .41288 L .43094 .40945 L p
1 g
F P
s
P
p
.002 w
.43094 .40945 m .43364 .38247 L .40808 .37773 L p
1 g
F P
s
P
p
.002 w
.58922 .44176 m .59691 .41563 L .57089 .41074 L p
1 g
F P
s
P
p
.002 w
.56994 .39224 m .57089 .41074 L .59691 .41563 L p
1 g
F P
s
P
p
.002 w
.4885 .32591 m .464 .33826 L .48103 .35843 L p
1 g
F P
s
P
p
.002 w
.48103 .35843 m .49761 .35013 L .4885 .32591 L p
1 g
F P
s
P
p
.002 w
.59691 .41563 m .59558 .38826 L .56994 .39224 L p
1 g
F P
s
P
p
.002 w
.56296 .37496 m .56994 .39224 L .59558 .38826 L p
1 g
F P
s
P
p
.002 w
.51587 .32223 m .4885 .32591 L .49761 .35013 L p
1 g
F P
s
P
p
.002 w
.49761 .35013 m .5161 .34768 L .51587 .32223 L p
1 g
F P
s
P
p
.002 w
.41302 .49467 m .44616 .52187 L .459 .4997 L p
1 g
F P
s
P
p
.002 w
.459 .4997 m .43163 .47721 L .41302 .49467 L p
1 g
F P
s
P
p
.002 w
.49208 .51237 m .459 .4997 L .44616 .52187 L p
1 g
F P
s
P
p
.002 w
.56135 .50403 m .59023 .48373 L .57341 .46381 L p
1 g
F P
s
P
p
.002 w
.58922 .44176 m .57341 .46381 L .59023 .48373 L p
1 g
F P
s
P
p
.002 w
.42285 .34558 m .40808 .37773 L .43364 .38247 L p
1 g
F P
s
P
p
.002 w
.43364 .38247 m .44505 .35784 L .42285 .34558 L p
1 g
F P
s
P
p
.002 w
.44616 .52187 m .4862 .53723 L .49208 .51237 L p
1 g
F P
s
P
p
.002 w
.52743 .51389 m .49208 .51237 L .4862 .53723 L p
1 g
F P
s
P
p
.002 w
.39022 .45841 m .41302 .49467 L .43163 .47721 L p
1 g
F P
s
P
p
.002 w
.43163 .47721 m .41284 .44724 L .39022 .45841 L p
1 g
F P
s
P
p
.002 w
.59558 .38826 m .58529 .36265 L .56296 .37496 L p
1 g
F P
s
P
p
.002 w
.55068 .36082 m .56296 .37496 L .58529 .36265 L p
1 g
F P
s
P
p
.002 w
.54309 .32768 m .51587 .32223 L .5161 .34768 L p
1 g
F P
s
P
p
.002 w
.5161 .34768 m .53447 .35138 L .54309 .32768 L p
1 g
F P
s
P
p
.002 w
.58529 .36265 m .56713 .34167 L .55068 .36082 L p
1 g
F P
s
P
p
.002 w
.53447 .35138 m .55068 .36082 L .56713 .34167 L p
1 g
F P
s
P
p
.002 w
.56713 .34167 m .54309 .32768 L .53447 .35138 L p
1 g
F P
s
P
p
.002 w
.4862 .53723 m .52899 .53912 L .52743 .51389 L p
1 g
F P
s
P
p
.002 w
.56135 .50403 m .52743 .51389 L .52899 .53912 L p
1 g
F P
s
P
p
.002 w
.38023 .41681 m .39022 .45841 L .41284 .44724 L p
1 g
F P
s
P
p
.002 w
.41284 .44724 m .40467 .41288 L .38023 .41681 L p
1 g
F P
s
P
p
.002 w
.59023 .48373 m .61092 .45505 L .58922 .44176 L p
1 g
F P
s
P
p
.002 w
.59691 .41563 m .58922 .44176 L .61092 .45505 L p
1 g
F P
s
P
p
.002 w
.44751 .31995 m .42285 .34558 L .44505 .35784 L p
1 g
F P
s
P
p
.002 w
.44505 .35784 m .464 .33826 L .44751 .31995 L p
1 g
F P
s
P
p
.002 w
.52899 .53912 m .5701 .52727 L .56135 .50403 L p
1 g
F P
s
P
p
.002 w
.59023 .48373 m .56135 .50403 L .5701 .52727 L p
1 g
F P
s
P
p
.002 w
.38424 .37421 m .38023 .41681 L .40467 .41288 L p
1 g
F P
s
P
p
.002 w
.40467 .41288 m .40808 .37773 L .38424 .37421 L p
1 g
F P
s
P
p
.002 w
.61092 .45505 m .62106 .42099 L .59691 .41563 L p
1 g
F P
s
P
p
.002 w
.59558 .38826 m .59691 .41563 L .62106 .42099 L p
1 g
F P
s
P
p
.002 w
.47946 .30375 m .44751 .31995 L .464 .33826 L p
1 g
F P
s
P
p
.002 w
.464 .33826 m .4885 .32591 L .47946 .30375 L p
1 g
F P
s
P
p
.002 w
.62106 .42099 m .61941 .38524 L .59558 .38826 L p
1 g
F P
s
P
p
.002 w
.58529 .36265 m .59558 .38826 L .61941 .38524 L p
1 g
F P
s
P
p
.002 w
.5701 .52727 m .60518 .50276 L .59023 .48373 L p
1 g
F P
s
P
p
.002 w
.61092 .45505 m .59023 .48373 L .60518 .50276 L p
1 g
F P
s
P
p
.002 w
.51524 .29887 m .47946 .30375 L .4885 .32591 L p
1 g
F P
s
P
p
.002 w
.4885 .32591 m .51587 .32223 L .51524 .29887 L p
1 g
F P
s
P
p
.002 w
.40204 .33515 m .38424 .37421 L .40808 .37773 L p
1 g
F P
s
P
p
.002 w
.40808 .37773 m .42285 .34558 L .40204 .33515 L p
1 g
F P
s
P
p
.002 w
.39614 .51094 m .43437 .54228 L .44616 .52187 L p
1 g
F P
s
P
p
.002 w
.44616 .52187 m .41302 .49467 L .39614 .51094 L p
1 g
F P
s
P
p
.002 w
.4862 .53723 m .44616 .52187 L .43437 .54228 L p
1 g
F P
s
P
p
.002 w
.43437 .54228 m .48052 .56001 L .4862 .53723 L p
1 g
F P
s
P
p
.002 w
.52899 .53912 m .4862 .53723 L .48052 .56001 L p
1 g
F P
s
P
p
.002 w
.36979 .46917 m .39614 .51094 L .41302 .49467 L p
1 g
F P
s
P
p
.002 w
.41302 .49467 m .39022 .45841 L .36979 .46917 L p
1 g
F P
s
P
p
.002 w
.61941 .38524 m .60602 .35174 L .58529 .36265 L p
1 g
F P
s
P
p
.002 w
.56713 .34167 m .58529 .36265 L .60602 .35174 L p
1 g
F P
s
P
p
.002 w
.55085 .30597 m .51524 .29887 L .51587 .32223 L p
1 g
F P
s
P
p
.002 w
.51587 .32223 m .54309 .32768 L .55085 .30597 L p
1 g
F P
s
P
p
.002 w
.60602 .35174 m .58229 .32428 L .56713 .34167 L p
1 g
F P
s
P
p
.002 w
.54309 .32768 m .56713 .34167 L .58229 .32428 L p
1 g
F P
s
P
p
.002 w
.58229 .32428 m .55085 .30597 L .54309 .32768 L p
1 g
F P
s
P
p
.002 w
.48052 .56001 m .52987 .56226 L .52899 .53912 L p
1 g
F P
s
P
p
.002 w
.5701 .52727 m .52899 .53912 L .52987 .56226 L p
1 g
F P
s
P
p
.002 w
.35816 .4212 m .36979 .46917 L .39022 .45841 L p
1 g
F P
s
P
p
.002 w
.39022 .45841 m .38023 .41681 L .35816 .4212 L p
1 g
F P
s
P
p
.002 w
.60518 .50276 m .63037 .46805 L .61092 .45505 L p
1 g
F P
s
P
p
.002 w
.62106 .42099 m .61092 .45505 L .63037 .46805 L p
1 g
F P
s
P
p
.002 w
.4319 .30395 m .40204 .33515 L .42285 .34558 L p
1 g
F P
s
P
p
.002 w
.42285 .34558 m .44751 .31995 L .4319 .30395 L p
1 g
F P
s
P
p
.002 w
.52987 .56226 m .57732 .54868 L .5701 .52727 L p
1 g
F P
s
P
p
.002 w
.60518 .50276 m .5701 .52727 L .57732 .54868 L p
1 g
F P
s
P
p
.002 w
.36267 .37201 m .35816 .4212 L .38023 .41681 L p
1 g
F P
s
P
p
.002 w
.38023 .41681 m .38424 .37421 L .36267 .37201 L p
1 g
F P
s
P
p
.002 w
.63037 .46805 m .6428 .42673 L .62106 .42099 L p
1 g
F P
s
P
p
.002 w
.61941 .38524 m .62106 .42099 L .6428 .42673 L p
1 g
F P
s
P
p
.002 w
.4707 .28417 m .4319 .30395 L .44751 .31995 L p
1 g
F P
s
P
p
.002 w
.44751 .31995 m .47946 .30375 L .4707 .28417 L p
1 g
F P
s
P
p
.002 w
.57732 .54868 m .61787 .5205 L .60518 .50276 L p
1 g
F P
s
P
p
.002 w
.63037 .46805 m .60518 .50276 L .61787 .5205 L p
1 g
F P
s
P
p
.002 w
.6428 .42673 m .64089 .38328 L .61941 .38524 L p
1 g
F P
s
P
p
.002 w
.60602 .35174 m .61941 .38524 L .64089 .38328 L p
1 g
F P
s
P
p
.002 w
.5142 .27818 m .4707 .28417 L .47946 .30375 L p
1 g
F P
s
P
p
.002 w
.47946 .30375 m .51524 .29887 L .5142 .27818 L p
1 g
F P
s
P
p
.002 w
.38312 .32684 m .36267 .37201 L .38424 .37421 L p
1 g
F P
s
P
p
.002 w
.38424 .37421 m .40204 .33515 L .38312 .32684 L p
1 g
F P
s
P
p
.002 w
.3814 .52565 m .4239 .56045 L .43437 .54228 L p
1 g
F P
s
P
p
.002 w
.43437 .54228 m .39614 .51094 L .3814 .52565 L p
1 g
F P
s
P
p
.002 w
.48052 .56001 m .43437 .54228 L .4239 .56045 L p
1 g
F P
s
P
p
.002 w
.4239 .56045 m .47517 .58017 L .48052 .56001 L p
1 g
F P
s
P
p
.002 w
.52987 .56226 m .48052 .56001 L .47517 .58017 L p
1 g
F P
s
P
p
.002 w
.35206 .47926 m .3814 .52565 L .39614 .51094 L p
1 g
F P
s
P
p
.002 w
.39614 .51094 m .36979 .46917 L .35206 .47926 L p
1 g
F P
s
P
p
.002 w
.64089 .38328 m .62467 .34251 L .60602 .35174 L p
1 g
F P
s
P
p
.002 w
.58229 .32428 m .60602 .35174 L .62467 .34251 L p
1 g
F P
s
P
p
.002 w
.55755 .28678 m .5142 .27818 L .51524 .29887 L p
1 g
F P
s
P
p
.002 w
.51524 .29887 m .55085 .30597 L .55755 .28678 L p
1 g
F P
s
P
p
.002 w
.62467 .34251 m .59582 .30907 L .58229 .32428 L p
1 g
F P
s
P
p
.002 w
.55085 .30597 m .58229 .32428 L .59582 .30907 L p
1 g
F P
s
P
p
.002 w
.59582 .30907 m .55755 .28678 L .55085 .30597 L p
1 g
F P
s
P
p
.002 w
.47517 .58017 m .53001 .58273 L .52987 .56226 L p
1 g
F P
s
P
p
.002 w
.57732 .54868 m .52987 .56226 L .53001 .58273 L p
1 g
F P
s
P
p
.002 w
.61787 .5205 m .64707 .48047 L .63037 .46805 L p
1 g
F P
s
P
p
.002 w
.6428 .42673 m .63037 .46805 L .64707 .48047 L p
1 g
F P
s
P
p
.002 w
.33904 .42596 m .35206 .47926 L .36979 .46917 L p
1 g
F P
s
P
p
.002 w
.36979 .46917 m .35816 .4212 L .33904 .42596 L p
1 g
F P
s
P
p
.002 w
.41755 .29069 m .38312 .32684 L .40204 .33515 L p
1 g
F P
s
P
p
.002 w
.40204 .33515 m .4319 .30395 L .41755 .29069 L p
1 g
F P
s
P
p
.002 w
.53001 .58273 m .58278 .56773 L .57732 .54868 L p
1 g
F P
s
P
p
.002 w
.61787 .5205 m .57732 .54868 L .58278 .56773 L p
1 g
F P
s
P
p
.002 w
.34394 .37125 m .33904 .42596 L .35816 .4212 L p
1 g
F P
s
P
p
.002 w
.35816 .4212 m .36267 .37201 L .34394 .37125 L p
1 g
F P
s
P
p
.002 w
.64707 .48047 m .66155 .43275 L .6428 .42673 L p
1 g
F P
s
P
p
.002 w
.64089 .38328 m .6428 .42673 L .66155 .43275 L p
1 g
F P
s
P
p
.002 w
.46239 .26772 m .41755 .29069 L .4319 .30395 L p
1 g
F P
s
P
p
.002 w
.4319 .30395 m .4707 .28417 L .46239 .26772 L p
1 g
F P
s
P
p
.002 w
.58278 .56773 m .62794 .53649 L .61787 .5205 L p
1 g
F P
s
P
p
.002 w
.64707 .48047 m .61787 .5205 L .62794 .53649 L p
1 g
F P
s
P
p
.002 w
.66155 .43275 m .65944 .38247 L .64089 .38328 L p
1 g
F P
s
P
p
.002 w
.62467 .34251 m .64089 .38328 L .65944 .38247 L p
1 g
F P
s
P
p
.002 w
.51276 .26072 m .46239 .26772 L .4707 .28417 L p
1 g
F P
s
P
p
.002 w
.4707 .28417 m .5142 .27818 L .51276 .26072 L p
1 g
F P
s
P
p
.002 w
.36658 .32094 m .34394 .37125 L .36267 .37201 L p
1 g
F P
s
P
p
.002 w
.36267 .37201 m .38312 .32684 L .36658 .32094 L p
1 g
F P
s
P
p
.002 w
.36923 .53839 m .41504 .57588 L .4239 .56045 L p
1 g
F P
s
P
p
.002 w
.4239 .56045 m .3814 .52565 L .36923 .53839 L p
1 g
F P
s
P
p
.002 w
.47517 .58017 m .4239 .56045 L .41504 .57588 L p
1 g
F P
s
P
p
.002 w
.41504 .57588 m .47028 .59714 L .47517 .58017 L p
1 g
F P
s
P
p
.002 w
.53001 .58273 m .47517 .58017 L .47028 .59714 L p
1 g
F P
s
P
p
.002 w
.33756 .48844 m .36923 .53839 L .3814 .52565 L p
1 g
F P
s
P
p
.002 w
.3814 .52565 m .35206 .47926 L .33756 .48844 L p
1 g
F P
s
P
p
.002 w
.65944 .38247 m .64073 .33525 L .62467 .34251 L p
1 g
F P
s
P
p
.002 w
.59582 .30907 m .62467 .34251 L .64073 .33525 L p
1 g
F P
s
P
p
.002 w
.56299 .27065 m .51276 .26072 L .5142 .27818 L p
1 g
F P
s
P
p
.002 w
.5142 .27818 m .55755 .28678 L .56299 .27065 L p
1 g
F P
s
P
p
.002 w
.64073 .33525 m .60734 .29648 L .59582 .30907 L p
1 g
F P
s
P
p
.002 w
.55755 .28678 m .59582 .30907 L .60734 .29648 L p
1 g
F P
s
P
p
.002 w
.60734 .29648 m .56299 .27065 L .55755 .28678 L p
1 g
F P
s
P
p
.002 w
.47028 .59714 m .52937 .59996 L .53001 .58273 L p
1 g
F P
s
P
p
.002 w
.58278 .56773 m .53001 .58273 L .52937 .59996 L p
1 g
F P
s
P
p
.002 w
.62794 .53649 m .66053 .49203 L .64707 .48047 L p
1 g
F P
s
P
p
.002 w
.66155 .43275 m .64707 .48047 L .66053 .49203 L p
1 g
F P
s
P
p
.002 w
.32344 .43102 m .33756 .48844 L .35206 .47926 L p
1 g
F P
s
P
p
.002 w
.35206 .47926 m .33904 .42596 L .32344 .43102 L p
1 g
F P
s
P
p
.002 w
.40484 .28061 m .36658 .32094 L .38312 .32684 L p
1 g
F P
s
P
p
.002 w
.38312 .32684 m .41755 .29069 L .40484 .28061 L p
1 g
F P
s
P
p
.002 w
.52937 .59996 m .58627 .58388 L .58278 .56773 L p
1 g
F P
s
P
p
.002 w
.62794 .53649 m .58278 .56773 L .58627 .58388 L p
1 g
F P
s
P
p
.002 w
.32862 .37202 m .32344 .43102 L .33904 .42596 L p
1 g
F P
s
P
p
.002 w
.33904 .42596 m .34394 .37125 L .32862 .37202 L p
1 g
F P
s
P
p
.002 w
.66053 .49203 m .67675 .43893 L .66155 .43275 L p
1 g
F P
s
P
p
.002 w
.65944 .38247 m .66155 .43275 L .67675 .43893 L p
1 g
F P
s
P
p
.002 w
.45477 .25494 m .40484 .28061 L .41755 .29069 L p
1 g
F P
s
P
p
.002 w
.41755 .29069 m .46239 .26772 L .45477 .25494 L p
1 g
F P
s
P
p
.002 w
.58627 .58388 m .63501 .55028 L .62794 .53649 L p
1 g
F P
s
P
p
.002 w
.66053 .49203 m .62794 .53649 L .63501 .55028 L p
1 g
F P
s
P
p
.002 w
.67675 .43893 m .67449 .3829 L .65944 .38247 L p
1 g
F P
s
P
p
.002 w
.64073 .33525 m .65944 .38247 L .67449 .3829 L p
1 g
F P
s
P
p
.002 w
.35294 .31772 m .32862 .37202 L .34394 .37125 L p
1 g
F P
s
P
p
.002 w
.34394 .37125 m .36658 .32094 L .35294 .31772 L p
1 g
F P
s
P
p
.002 w
.51093 .24707 m .45477 .25494 L .46239 .26772 L p
1 g
F P
s
P
p
.002 w
.46239 .26772 m .51276 .26072 L .51093 .24707 L p
1 g
F P
s
P
p
.002 w
.36005 .54878 m .40808 .58806 L .41504 .57588 L p
1 g
F P
s
P
p
.002 w
.41504 .57588 m .36923 .53839 L .36005 .54878 L p
1 g
F P
s
P
p
.002 w
.47028 .59714 m .41504 .57588 L .40808 .58806 L p
1 g
F P
s
P
p
.002 w
.40808 .58806 m .46599 .61036 L .47028 .59714 L p
1 g
F P
s
P
p
.002 w
.52937 .59996 m .47028 .59714 L .46599 .61036 L p
1 g
F P
s
P
p
.002 w
.32681 .49643 m .36005 .54878 L .36923 .53839 L p
1 g
F P
s
P
p
.002 w
.36923 .53839 m .33756 .48844 L .32681 .49643 L p
1 g
F P
s
P
p
.002 w
.67449 .3829 m .65368 .33023 L .64073 .33525 L p
1 g
F P
s
P
p
.002 w
.60734 .29648 m .64073 .33525 L .65368 .33023 L p
1 g
F P
s
P
p
.002 w
.56697 .25813 m .51093 .24707 L .51276 .26072 L p
1 g
F P
s
P
p
.002 w
.51276 .26072 m .56299 .27065 L .56697 .25813 L p
1 g
F P
s
P
p
.002 w
.65368 .33023 m .61645 .28696 L .60734 .29648 L p
1 g
F P
s
P
p
.002 w
.56299 .27065 m .60734 .29648 L .61645 .28696 L p
1 g
F P
s
P
p
.002 w
.61645 .28696 m .56697 .25813 L .56299 .27065 L p
1 g
F P
s
P
p
.002 w
.63501 .55028 m .67024 .50239 L .66053 .49203 L p
1 g
F P
s
P
p
.002 w
.67675 .43893 m .66053 .49203 L .67024 .50239 L p
1 g
F P
s
P
p
.002 w
.46599 .61036 m .52793 .61337 L .52937 .59996 L p
1 g
F P
s
P
p
.002 w
.58627 .58388 m .52937 .59996 L .52793 .61337 L p
1 g
F P
s
P
p
.002 w
.31193 .43626 m .32681 .49643 L .33756 .48844 L p
1 g
F P
s
P
p
.002 w
.33756 .48844 m .32344 .43102 L .31193 .43626 L p
1 g
F P
s
P
p
.002 w
.39416 .27414 m .35294 .31772 L .36658 .32094 L p
1 g
F P
s
P
p
.002 w
.36658 .32094 m .40484 .28061 L .39416 .27414 L p
1 g
F P
s
P
p
.002 w
.52793 .61337 m .5876 .59657 L .58627 .58388 L p
1 g
F P
s
P
p
.002 w
.63501 .55028 m .58627 .58388 L .5876 .59657 L p
1 g
F P
s
P
p
.002 w
.31728 .3744 m .31193 .43626 L .32344 .43102 L p
1 g
F P
s
P
p
.002 w
.32344 .43102 m .32862 .37202 L .31728 .3744 L p
1 g
F P
s
P
p
.002 w
.67024 .50239 m .68784 .44512 L .67675 .43893 L p
1 g
F P
s
P
p
.002 w
.67449 .3829 m .67675 .43893 L .68784 .44512 L p
1 g
F P
s
P
p
.002 w
.44805 .24636 m .39416 .27414 L .40484 .28061 L p
1 g
F P
s
P
p
.002 w
.40484 .28061 m .45477 .25494 L .44805 .24636 L p
1 g
F P
s
P
p
.002 w
.5876 .59657 m .63875 .56141 L .63501 .55028 L p
1 g
F P
s
P
p
.002 w
.67024 .50239 m .63501 .55028 L .63875 .56141 L p
1 g
F P
s
P
p
.002 w
.68784 .44512 m .68546 .38463 L .67449 .3829 L p
1 g
F P
s
P
p
.002 w
.65368 .33023 m .67449 .3829 L .68546 .38463 L p
1 g
F P
s
P
p
.002 w
.34272 .31742 m .31728 .3744 L .32862 .37202 L p
1 g
F P
s
P
p
.002 w
.32862 .37202 m .35294 .31772 L .34272 .31742 L p
1 g
F P
s
P
p
.002 w
.50873 .23782 m .44805 .24636 L .45477 .25494 L p
1 g
F P
s
P
p
.002 w
.45477 .25494 m .51093 .24707 L .50873 .23782 L p
1 g
F P
s
P
p
.002 w
.35426 .5564 m .40332 .5965 L .40808 .58806 L p
1 g
F P
s
P
p
.002 w
.40808 .58806 m .36005 .54878 L .35426 .5564 L p
1 g
F P
s
P
p
.002 w
.46599 .61036 m .40808 .58806 L .40332 .5965 L p
1 g
F P
s
P
p
.002 w
.40332 .5965 m .46244 .61928 L .46599 .61036 L p
1 g
F P
s
P
p
.002 w
.52793 .61337 m .46599 .61036 L .46244 .61928 L p
1 g
F P
s
P
p
.002 w
.32029 .50298 m .35426 .5564 L .36005 .54878 L p
1 g
F P
s
P
p
.002 w
.36005 .54878 m .32681 .49643 L .32029 .50298 L p
1 g
F P
s
P
p
.002 w
.68546 .38463 m .66302 .3277 L .65368 .33023 L p
1 g
F P
s
P
p
.002 w
.61645 .28696 m .65368 .33023 L .66302 .3277 L p
1 g
F P
s
P
p
.002 w
.56931 .24975 m .50873 .23782 L .51093 .24707 L p
1 g
F P
s
P
p
.002 w
.51093 .24707 m .56697 .25813 L .56931 .24975 L p
1 g
F P
s
P
p
.002 w
.63875 .56141 m .67575 .51124 L .67024 .50239 L p
1 g
F P
s
P
p
.002 w
.68784 .44512 m .67024 .50239 L .67575 .51124 L p
1 g
F P
s
P
p
.002 w
.66302 .3277 m .6228 .28091 L .61645 .28696 L p
1 g
F P
s
P
p
.002 w
.56697 .25813 m .61645 .28696 L .6228 .28091 L p
1 g
F P
s
P
p
.002 w
.6228 .28091 m .56931 .24975 L .56697 .25813 L p
1 g
F P
s
P
p
.002 w
.46244 .61928 m .52568 .62238 L .52793 .61337 L p
1 g
F P
s
P
p
.002 w
.5876 .59657 m .52793 .61337 L .52568 .62238 L p
1 g
F P
s
P
p
.002 w
.30506 .44156 m .32029 .50298 L .32681 .49643 L p
1 g
F P
s
P
p
.002 w
.32681 .49643 m .31193 .43626 L .30506 .44156 L p
1 g
F P
s
P
p
.002 w
.38593 .27166 m .34272 .31742 L .35294 .31772 L p
1 g
F P
s
P
p
.002 w
.35294 .31772 m .39416 .27414 L .38593 .27166 L p
1 g
F P
s
P
p
.002 w
.52568 .62238 m .58661 .60528 L .5876 .59657 L p
1 g
F P
s
P
p
.002 w
.63875 .56141 m .5876 .59657 L .58661 .60528 L p
1 g
F P
s
P
p
.002 w
.31048 .37841 m .30506 .44156 L .31193 .43626 L p
1 g
F P
s
P
p
.002 w
.31193 .43626 m .31728 .3744 L .31048 .37841 L p
1 g
F P
s
P
p
.002 w
.67575 .51124 m .69427 .45118 L .68784 .44512 L p
1 g
F P
s
P
p
.002 w
.68546 .38463 m .68784 .44512 L .69427 .45118 L p
1 g
F P
s
P
p
.002 w
.44247 .24246 m .38593 .27166 L .39416 .27414 L p
1 g
F P
s
P
p
.002 w
.39416 .27414 m .44805 .24636 L .44247 .24246 L p
1 g
F P
s
P
p
.002 w
.58661 .60528 m .63884 .56943 L .63875 .56141 L p
1 g
F P
s
P
p
.002 w
.67575 .51124 m .63875 .56141 L .63884 .56943 L p
1 g
F P
s
P
p
.002 w
.69427 .45118 m .69182 .38769 L .68546 .38463 L p
1 g
F P
s
P
p
.002 w
.66302 .3277 m .68546 .38463 L .69182 .38769 L p
1 g
F P
s
P
p
.002 w
.33641 .32023 m .31048 .37841 L .31728 .3744 L p
1 g
F P
s
P
p
.002 w
.31728 .3744 m .34272 .31742 L .33641 .32023 L p
1 g
F P
s
P
p
.002 w
.50619 .23347 m .44247 .24246 L .44805 .24636 L p
1 g
F P
s
P
p
.002 w
.44805 .24636 m .50873 .23782 L .50619 .23347 L p
1 g
F P
s
P
p
.002 w
.35224 .56089 m .401 .60074 L .40332 .5965 L p
1 g
F P
s
P
p
.002 w
.40332 .5965 m .35426 .5564 L .35224 .56089 L p
1 g
F P
s
P
p
.002 w
.46244 .61928 m .40332 .5965 L .401 .60074 L p
1 g
F P
s
P
p
.002 w
.401 .60074 m .45977 .62339 L .46244 .61928 L p
1 g
F P
s
P
p
.002 w
.52568 .62238 m .46244 .61928 L .45977 .62339 L p
1 g
F P
s
P
p
.002 w
.31846 .5078 m .35224 .56089 L .35426 .5564 L p
1 g
F P
s
P
p
.002 w
.35426 .5564 m .32029 .50298 L .31846 .5078 L p
1 g
F P
s
P
p
.002 w
.69182 .38769 m .66828 .3279 L .66302 .3277 L p
1 g
F P
s
P
p
.002 w
.6228 .28091 m .66302 .3277 L .66828 .3279 L p
1 g
F P
s
P
p
.002 w
.56983 .246 m .50619 .23347 L .50873 .23782 L p
1 g
F P
s
P
p
.002 w
.50873 .23782 m .56931 .24975 L .56983 .246 L p
1 g
F P
s
P
p
.002 w
.63884 .56943 m .67665 .51824 L .67575 .51124 L p
1 g
F P
s
P
p
.002 w
.69427 .45118 m .67575 .51124 L .67665 .51824 L p
1 g
F P
s
P
p
.002 w
.66828 .3279 m .62603 .27874 L .6228 .28091 L p
1 g
F P
s
P
p
.002 w
.56931 .24975 m .6228 .28091 L .62603 .27874 L p
1 g
F P
s
P
p
.002 w
.45977 .62339 m .52262 .62649 L .52568 .62238 L p
1 g
F P
s
P
p
.002 w
.58661 .60528 m .52568 .62238 L .52262 .62649 L p
1 g
F P
s
P
p
.002 w
.62603 .27874 m .56983 .246 L .56931 .24975 L p
1 g
F P
s
P
p
.002 w
.38051 .27349 m .33641 .32023 L .34272 .31742 L p
1 g
F P
s
P
p
.002 w
.34272 .31742 m .38593 .27166 L .38051 .27349 L p
1 g
F P
s
P
p
.002 w
.30331 .44678 m .31846 .5078 L .32029 .50298 L p
1 g
F P
s
P
p
.002 w
.32029 .50298 m .30506 .44156 L .30331 .44678 L p
1 g
F P
s
P
p
.002 w
.52262 .62649 m .58316 .60952 L .58661 .60528 L p
1 g
F P
s
P
p
.002 w
.63884 .56943 m .58661 .60528 L .58316 .60952 L p
1 g
F P
s
P
p
.002 w
.30868 .38406 m .30331 .44678 L .30506 .44156 L p
1 g
F P
s
P
p
.002 w
.30506 .44156 m .31048 .37841 L .30868 .38406 L p
1 g
F P
s
P
p
.002 w
.67665 .51824 m .69557 .45692 L .69427 .45118 L p
1 g
F P
s
P
p
.002 w
.69182 .38769 m .69427 .45118 L .69557 .45692 L p
1 g
F P
s
P
p
.002 w
.43826 .24367 m .38051 .27349 L .38593 .27166 L p
1 g
F P
s
P
p
.002 w
.38593 .27166 m .44247 .24246 L .43826 .24367 L p
1 g
F P
s
P
p
.004 w
.26922 .51325 m
.30084 .50192 L
s
P
p
.004 w
.23169 .52671 m
.26922 .51325 L
s
P
p
.002 w
.58316 .60952 m .63506 .57391 L .63884 .56943 L p
1 g
F P
s
P
p
.002 w
.67665 .51824 m .63884 .56943 L .63506 .57391 L p
1 g
F P
s
P
p
.002 w
.69557 .45692 m .69308 .39208 L .69182 .38769 L p
1 g
F P
s
P
p
.002 w
.66828 .3279 m .69182 .38769 L .69308 .39208 L p
1 g
F P
s
P
p
.002 w
.33444 .32628 m .30868 .38406 L .31048 .37841 L p
1 g
F P
s
P
p
.002 w
.31048 .37841 m .33641 .32023 L .33444 .32628 L p
1 g
F P
s
P
p
.002 w
.50336 .23449 m .43826 .24367 L .44247 .24246 L p
1 g
F P
s
P
p
.002 w
.44247 .24246 m .50619 .23347 L .50336 .23449 L p
1 g
F P
s
P
p
.002 w
.35428 .56191 m .40137 .60038 L .401 .60074 L p
1 g
F P
s
P
p
.002 w
.401 .60074 m .35224 .56089 L .35428 .56191 L p
1 g
F P
s
P
p
.002 w
.45977 .62339 m .401 .60074 L .40137 .60038 L p
1 g
F P
s
P
p
.002 w
.40137 .60038 m .45811 .62225 L .45977 .62339 L p
1 g
F P
s
P
p
.002 w
.52262 .62649 m .45977 .62339 L .45811 .62225 L p
1 g
F P
s
P
p
.002 w
.32168 .51066 m .35428 .56191 L .35224 .56089 L p
1 g
F P
s
P
p
.002 w
.35224 .56089 m .31846 .5078 L .32168 .51066 L p
1 g
F P
s
P
p
.002 w
.69308 .39208 m .66903 .33099 L .66828 .3279 L p
1 g
F P
s
P
p
.002 w
.62603 .27874 m .66828 .3279 L .66903 .33099 L p
1 g
F P
s
P
p
.002 w
.56841 .24729 m .50336 .23449 L .50619 .23347 L p
1 g
F P
s
P
p
.002 w
.50619 .23347 m .56983 .246 L .56841 .24729 L p
1 g
F P
s
P
p
.002 w
.63506 .57391 m .6726 .52307 L .67665 .51824 L p
1 g
F P
s
P
p
.002 w
.69557 .45692 m .67665 .51824 L .6726 .52307 L p
1 g
F P
s
P
p
.002 w
.66903 .33099 m .62585 .28076 L .62603 .27874 L p
1 g
F P
s
P
p
.002 w
.56983 .246 m .62603 .27874 L .62585 .28076 L p
1 g
F P
s
P
p
.002 w
.45811 .62225 m .51879 .62524 L .52262 .62649 L p
1 g
F P
s
P
p
.002 w
.58316 .60952 m .52262 .62649 L .51879 .62524 L p
1 g
F P
s
P
p
.002 w
.62585 .28076 m .56841 .24729 L .56983 .246 L p
1 g
F P
s
P
p
.002 w
.37825 .27988 m .33444 .32628 L .33641 .32023 L p
1 g
F P
s
P
p
.002 w
.33641 .32023 m .38051 .27349 L .37825 .27988 L p
1 g
F P
s
P
p
.002 w
.30708 .45178 m .32168 .51066 L .31846 .5078 L p
1 g
F P
s
P
p
.002 w
.31846 .5078 m .30331 .44678 L .30708 .45178 L p
1 g
F P
s
P
p
.002 w
.51879 .62524 m .5772 .60885 L .58316 .60952 L p
1 g
F P
s
P
p
.002 w
.63506 .57391 m .58316 .60952 L .5772 .60885 L p
1 g
F P
s
P
p
.002 w
.31229 .39128 m .30708 .45178 L .30331 .44678 L p
1 g
F P
s
P
p
.002 w
.30331 .44678 m .30868 .38406 L .31229 .39128 L p
1 g
F P
s
P
p
.002 w
.6726 .52307 m .69138 .46217 L .69557 .45692 L p
1 g
F P
s
P
p
.002 w
.69308 .39208 m .69557 .45692 L .69138 .46217 L p
1 g
F P
s
P
p
.002 w
.43563 .25028 m .37825 .27988 L .38051 .27349 L p
1 g
F P
s
P
p
.002 w
.38051 .27349 m .43826 .24367 L .43563 .25028 L p
1 g
F P
s
P
p
.002 w
.5772 .60885 m .62724 .57449 L .63506 .57391 L p
1 g
F P
s
P
p
.002 w
.6726 .52307 m .63506 .57391 L .62724 .57449 L p
1 g
F P
s
P
p
.002 w
.33717 .3356 m .31229 .39128 L .30868 .38406 L p
1 g
F P
s
P
p
.002 w
.30868 .38406 m .33444 .32628 L .33717 .3356 L p
1 g
F P
s
P
p
.002 w
.69138 .46217 m .68887 .39776 L .69308 .39208 L p
1 g
F P
s
P
p
.002 w
.66903 .33099 m .69308 .39208 L .68887 .39776 L p
1 g
F P
s
P
p
.002 w
.50031 .24119 m .43563 .25028 L .43826 .24367 L p
1 g
F P
s
P
p
.002 w
.43826 .24367 m .50336 .23449 L .50031 .24119 L p
1 g
F P
s
P
p
.002 w
.36061 .55919 m .40458 .59513 L .40137 .60038 L p
1 g
F P
s
P
p
.002 w
.40137 .60038 m .35428 .56191 L .36061 .55919 L p
1 g
F P
s
P
p
.002 w
.45811 .62225 m .40137 .60038 L .40458 .59513 L p
1 g
F P
s
P
p
.002 w
.40458 .59513 m .45758 .61555 L .45811 .62225 L p
1 g
F P
s
P
p
.002 w
.51879 .62524 m .45811 .62225 L .45758 .61555 L p
1 g
F P
s
P
p
.002 w
.33019 .51133 m .36061 .55919 L .35428 .56191 L p
1 g
F P
s
P
p
.002 w
.35428 .56191 m .32168 .51066 L .33019 .51133 L p
1 g
F P
s
P
p
.002 w
.68887 .39776 m .66494 .33709 L .66903 .33099 L p
1 g
F P
s
P
p
.002 w
.62585 .28076 m .66903 .33099 L .66494 .33709 L p
1 g
F P
s
P
p
.002 w
.56494 .25393 m .50031 .24119 L .50336 .23449 L p
1 g
F P
s
P
p
.002 w
.50336 .23449 m .56841 .24729 L .56494 .25393 L p
1 g
F P
s
P
p
.002 w
.62724 .57449 m .6634 .52544 L .6726 .52307 L p
1 g
F P
s
P
p
.002 w
.69138 .46217 m .6726 .52307 L .6634 .52544 L p
1 g
F P
s
P
p
.002 w
.37944 .29092 m .33717 .3356 L .33444 .32628 L p
1 g
F P
s
P
p
.002 w
.33444 .32628 m .37825 .27988 L .37944 .29092 L p
1 g
F P
s
P
p
.002 w
.45758 .61555 m .51424 .61832 L .51879 .62524 L p
1 g
F P
s
P
p
.002 w
.5772 .60885 m .51879 .62524 L .51424 .61832 L p
1 g
F P
s
P
p
.002 w
.66494 .33709 m .62203 .28719 L .62585 .28076 L p
1 g
F P
s
P
p
.002 w
.56841 .24729 m .62585 .28076 L .62203 .28719 L p
1 g
F P
s
P
p
.002 w
.62203 .28719 m .56494 .25393 L .56841 .24729 L p
1 g
F P
s
P
p
.002 w
.3166 .45637 m .33019 .51133 L .32168 .51066 L p
1 g
F P
s
P
p
.002 w
.32168 .51066 m .30708 .45178 L .3166 .45637 L p
1 g
F P
s
P
p
.004 w
.30084 .50192 m
.30826 .49926 L
s
P
p
.002 w
.51424 .61832 m .56875 .60299 L .5772 .60885 L p
1 g
F P
s
P
p
.002 w
.62724 .57449 m .5772 .60885 L .56875 .60299 L p
1 g
F P
s
P
p
.002 w
.32153 .39996 m .3166 .45637 L .30708 .45178 L p
1 g
F P
s
P
p
.002 w
.30708 .45178 m .31229 .39128 L .32153 .39996 L p
1 g
F P
s
P
p
.002 w
.6634 .52544 m .68144 .46672 L .69138 .46217 L p
1 g
F P
s
P
p
.002 w
.68887 .39776 m .69138 .46217 L .68144 .46672 L p
1 g
F P
s
P
p
.002 w
.43477 .26245 m .37944 .29092 L .37825 .27988 L p
1 g
F P
s
P
p
.002 w
.37825 .27988 m .43563 .25028 L .43477 .26245 L p
1 g
F P
s
P
p
.002 w
.56875 .60299 m .61538 .57089 L .62724 .57449 L p
1 g
F P
s
P
p
.002 w
.6634 .52544 m .62724 .57449 L .61538 .57089 L p
1 g
F P
s
P
p
.002 w
.34479 .3481 m .32153 .39996 L .31229 .39128 L p
1 g
F P
s
P
p
.002 w
.31229 .39128 m .33717 .3356 L .34479 .3481 L p
1 g
F P
s
P
p
.002 w
.68144 .46672 m .67896 .40465 L .68887 .39776 L p
1 g
F P
s
P
p
.002 w
.66494 .33709 m .68887 .39776 L .67896 .40465 L p
1 g
F P
s
P
p
.002 w
.49713 .25374 m .43477 .26245 L .43563 .25028 L p
1 g
F P
s
P
p
.002 w
.43563 .25028 m .50031 .24119 L .49713 .25374 L p
1 g
F P
s
P
p
.002 w
.3713 .55258 m .41073 .58483 L .40458 .59513 L p
1 g
F P
s
P
p
.002 w
.40458 .59513 m .36061 .55919 L .3713 .55258 L p
1 g
F P
s
P
p
.002 w
.45758 .61555 m .40458 .59513 L .41073 .58483 L p
1 g
F P
s
P
p
.002 w
.41073 .58483 m .45828 .60314 L .45758 .61555 L p
1 g
F P
s
P
p
.002 w
.51424 .61832 m .45758 .61555 L .45828 .60314 L p
1 g
F P
s
P
p
.002 w
.34406 .50964 m .3713 .55258 L .36061 .55919 L p
1 g
F P
s
P
p
.002 w
.36061 .55919 m .33019 .51133 L .34406 .50964 L p
1 g
F P
s
P
p
.002 w
.67896 .40465 m .65584 .34619 L .66494 .33709 L p
1 g
F P
s
P
p
.002 w
.62203 .28719 m .66494 .33709 L .65584 .34619 L p
1 g
F P
s
P
p
.002 w
.55942 .26605 m .49713 .25374 L .50031 .24119 L p
1 g
F P
s
P
p
.002 w
.50031 .24119 m .56494 .25393 L .55942 .26605 L p
1 g
F P
s
P
p
.002 w
.61538 .57089 m .64902 .52512 L .6634 .52544 L p
1 g
F P
s
P
p
.002 w
.68144 .46672 m .6634 .52544 L .64902 .52512 L p
1 g
F P
s
P
p
.002 w
.38425 .30654 m .34479 .3481 L .33717 .3356 L p
1 g
F P
s
P
p
.002 w
.33717 .3356 m .37944 .29092 L .38425 .30654 L p
1 g
F P
s
P
p
.002 w
.45828 .60314 m .50908 .60558 L .51424 .61832 L p
1 g
F P
s
P
p
.002 w
.56875 .60299 m .51424 .61832 L .50908 .60558 L p
1 g
F P
s
P
p
.002 w
.65584 .34619 m .61445 .29811 L .62203 .28719 L p
1 g
F P
s
P
p
.002 w
.56494 .25393 m .62203 .28719 L .61445 .29811 L p
1 g
F P
s
P
p
.002 w
.61445 .29811 m .55942 .26605 L .56494 .25393 L p
1 g
F P
s
P
p
.002 w
.33195 .46038 m .34406 .50964 L .33019 .51133 L p
1 g
F P
s
P
p
.004 w
.33881 .4883 m
.5 .43051 L
s
P
p
.002 w
.33019 .51133 m .3166 .45637 L .33195 .46038 L p
1 g
F P
s
P
p
.004 w
.32776 .49226 m
.32909 .49179 L
s
P
p
.004 w
.30826 .49926 m
.32118 .49462 L
s
P
p
.004 w
.32118 .49462 m
.32776 .49226 L
s
P
p
.002 w
.50908 .60558 m .55791 .59178 L .56875 .60299 L p
1 g
F P
s
P
p
.002 w
.61538 .57089 m .56875 .60299 L .55791 .59178 L p
1 g
F P
s
P
p
.002 w
.33645 .40989 m .33195 .46038 L .3166 .45637 L p
1 g
F P
s
P
p
.002 w
.3166 .45637 m .32153 .39996 L .33645 .40989 L p
1 g
F P
s
P
p
.002 w
.64902 .52512 m .66573 .47039 L .68144 .46672 L p
1 g
F P
s
P
p
.002 w
.67896 .40465 m .68144 .46672 L .66573 .47039 L p
1 g
F P
s
P
p
.002 w
.43582 .28011 m .38425 .30654 L .37944 .29092 L p
1 g
F P
s
P
p
.002 w
.37944 .29092 m .43477 .26245 L .43582 .28011 L p
1 g
F P
s
P
p
.002 w
.55791 .59178 m .59961 .56297 L .61538 .57089 L p
1 g
F P
s
P
p
.002 w
.64902 .52512 m .61538 .57089 L .59961 .56297 L p
1 g
F P
s
P
p
.002 w
.35736 .36355 m .33645 .40989 L .32153 .39996 L p
1 g
F P
s
P
p
.002 w
.32153 .39996 m .34479 .3481 L .35736 .36355 L p
1 g
F P
s
P
p
.002 w
.66573 .47039 m .66332 .41258 L .67896 .40465 L p
1 g
F P
s
P
p
.002 w
.65584 .34619 m .67896 .40465 L .66332 .41258 L p
1 g
F P
s
P
p
.002 w
.4939 .27208 m .43582 .28011 L .43477 .26245 L p
1 g
F P
s
P
p
.002 w
.43477 .26245 m .49713 .25374 L .4939 .27208 L p
1 g
F P
s
P
p
.002 w
.38627 .54205 m .4198 .5695 L .41073 .58483 L p
1 g
F P
s
P
p
.002 w
.41073 .58483 m .3713 .55258 L .38627 .54205 L p
1 g
F P
s
P
p
.002 w
.45828 .60314 m .41073 .58483 L .4198 .5695 L p
1 g
F P
s
P
p
.002 w
.4198 .5695 m .46025 .58506 L .45828 .60314 L p
1 g
F P
s
P
p
.002 w
.50908 .60558 m .45828 .60314 L .46025 .58506 L p
1 g
F P
s
P
p
.002 w
.36315 .50552 m .38627 .54205 L .3713 .55258 L p
1 g
F P
s
P
p
.002 w
.3713 .55258 m .34406 .50964 L .36315 .50552 L p
1 g
F P
s
P
p
.002 w
.66332 .41258 m .64172 .35817 L .65584 .34619 L p
1 g
F P
s
P
p
.002 w
.61445 .29811 m .65584 .34619 L .64172 .35817 L p
1 g
F P
s
P
p
.002 w
.5519 .28359 m .4939 .27208 L .49713 .25374 L p
1 g
F P
s
P
p
.002 w
.49713 .25374 m .55942 .26605 L .5519 .28359 L p
1 g
F P
s
P
p
.002 w
.59961 .56297 m .62961 .52196 L .64902 .52512 L p
1 g
F P
s
P
p
.002 w
.66573 .47039 m .64902 .52512 L .62961 .52196 L p
1 g
F P
s
P
p
.002 w
.39272 .32648 m .35736 .36355 L .34479 .3481 L p
1 g
F P
s
P
p
.002 w
.34479 .3481 m .38425 .30654 L .39272 .32648 L p
1 g
F P
s
P
p
.002 w
.46025 .58506 m .50345 .5871 L .50908 .60558 L p
1 g
F P
s
P
p
.002 w
.55791 .59178 m .50908 .60558 L .50345 .5871 L p
1 g
F P
s
P
p
.002 w
.64172 .35817 m .60314 .31343 L .61445 .29811 L p
1 g
F P
s
P
p
.002 w
.55942 .26605 m .61445 .29811 L .60314 .31343 L p
1 g
F P
s
P
p
.002 w
.35293 .46365 m .36315 .50552 L .34406 .50964 L p
1 g
F P
s
P
p
.002 w
.34406 .50964 m .33195 .46038 L .35293 .46365 L p
1 g
F P
s
P
p
.002 w
.60314 .31343 m .5519 .28359 L .55942 .26605 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.50345 .5871 m .54492 .5753 L .55791 .59178 L p
1 g
F P
s
P
p
.002 w
.59961 .56297 m .55791 .59178 L .54492 .5753 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.35686 .42081 m .35293 .46365 L .33195 .46038 L p
1 g
F P
s
P
p
.002 w
.33195 .46038 m .33645 .40989 L .35686 .42081 L p
1 g
F P
s
P
p
.002 w
.62961 .52196 m .64444 .473 L .66573 .47039 L p
1 g
F P
s
P
p
.002 w
.66332 .41258 m .66573 .47039 L .64444 .473 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.43886 .30298 m .39272 .32648 L .38425 .30654 L p
1 g
F P
s
P
p
.002 w
.38425 .30654 m .43582 .28011 L .43886 .30298 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.54492 .5753 m .58026 .55075 L .59961 .56297 L p
1 g
F P
s
P
p
.002 w
.62961 .52196 m .59961 .56297 L .58026 .55075 L p
1 g
F P
s
P
p
.002 w
.37471 .38157 m .35686 .42081 L .33645 .40989 L p
1 g
F P
s
P
p
.002 w
.33645 .40989 m .35736 .36355 L .37471 .38157 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.64444 .473 m .64217 .42135 L .66332 .41258 L p
1 g
F P
s
P
p
.002 w
.64172 .35817 m .66332 .41258 L .64217 .42135 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.49074 .29589 m .43886 .30298 L .43582 .28011 L p
1 g
F P
s
P
p
.002 w
.43582 .28011 m .4939 .27208 L .49074 .29589 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.40523 .52775 m .43163 .54939 L .4198 .5695 L p
1 g
F P
s
P
p
.002 w
.4198 .5695 m .38627 .54205 L .40523 .52775 L p
1 g
F P
s
P
p
.002 w
.46025 .58506 m .4198 .5695 L .43163 .54939 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46025 .58506 m .43287 .54987 L .45091 .56278 L 1 g
F
P
p
.002 w
.46222 .57088 m .46161 .57524 L p
.45091 .56278 L 1 g
F P
s
P
p
.002 w
.46161 .57524 m .46025 .58506 L p
.45091 .56278 L 1 g
F P
s
P
p
.002 w
.45091 .56278 m .45146 .56129 L p
.4442 .55499 L 1 g
F P
s
P
p
.46872 .57265 m .45961 .56901 L .46222 .57088 L 1 g
F
P
p
.002 w
.49062 .58649 m .46025 .58506 L .462 .57245 L p
1 g
F P
s
P
p
.002 w
.462 .57245 m .46222 .57088 L p
.46837 .57426 L 1 g
F P
s
P
p
.49062 .58649 m .462 .57245 L .46837 .57426 L 1 g
F
P
p
.002 w
.4891 .58015 m .48921 .57862 L p
.48148 .57799 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50345 .5871 m .49062 .58649 L p
.48327 .57976 L 1 g
F P
s
P
p
.50345 .5871 m .48327 .57976 L .48617 .57995 L 1 g
F
P
p
.50345 .5871 m .48617 .57995 L .49534 .58192 L 1 g
F
P
p
.48617 .57995 m .48128 .57793 L .4891 .58015 L 1 g
F
P
p
.48617 .57995 m .4891 .58015 L .49534 .58192 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58015 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58015 L .49959 .58086 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46837 .57426 L p
1 g
F P
s
P
p
.48921 .57862 m .46837 .57426 L .48148 .57799 L 1 g
F
P
p
.49534 .58192 m .48128 .57793 L .4635 .56164 L 1 g
F
P
p
.51079 .57862 m .49959 .58086 L .50195 .58102 L 1 g
F
P
p
.002 w
.53247 .57884 m .50345 .5871 L .50241 .58289 L p
1 g
F P
s
P
p
.002 w
.50241 .58289 m .50195 .58102 L p
.51092 .58038 L 1 g
F P
s
P
p
.53247 .57884 m .50241 .58289 L .51092 .58038 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58038 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58038 L .52342 .57668 L 1 g
F
P
p
.002 w
.51092 .58038 m .51079 .57862 L p
.50195 .58102 L 1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53163 .57425 m .53128 .57265 L p
.52342 .57668 L 1 g
F P
s
P
p
.002 w
.50195 .58102 m .49752 .56319 L p
.52597 .57593 L 1 g
F P
s
P
p
.53247 .57884 m .51092 .58038 L .52597 .57593 L 1 g
F
P
p
.51092 .58038 m .50195 .58102 L .52597 .57593 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54492 .5753 m .53247 .57884 L p
.5275 .57662 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53163 .57425 L p
1 g
F P
s
P
p
.54854 .56129 m .53163 .57425 L .5399 .56952 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53447 .57263 m .5275 .57662 L .49752 .56319 L 1 g
F
P
p
.54492 .5753 m .5275 .57662 L .53447 .57263 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.54854 .56129 m .5399 .56952 L .54064 .5691 L 1 g
F
P
p
.58026 .55075 m .54595 .56664 L .56331 .5518 L 1 g
F
P
p
.54595 .56664 m .54064 .5691 L .54906 .56268 L 1 g
F
P
p
.54595 .56664 m .54906 .56268 L .56331 .5518 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54906 .56268 L p
1 g
F P
s
P
p
.002 w
.58026 .55075 m .54492 .5753 L .54064 .5691 L p
1 g
F P
s
P
p
.56075 .54566 m .54906 .56268 L .55683 .55277 L 1 g
F
P
p
.002 w
.54906 .56268 m .54854 .56129 L p
.54064 .5691 L 1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56142 .54692 m .56075 .54566 L p
.55683 .55277 L 1 g
F P
s
P
p
.002 w
.54064 .5691 m .53012 .55384 L p
.5573 .55217 L 1 g
F P
s
P
p
.56331 .5518 m .54906 .56268 L .5573 .55217 L 1 g
F
P
p
.54906 .56268 m .54064 .5691 L .5573 .55217 L 1 g
F
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56142 .54692 L p
1 g
F P
s
P
p
.56654 .52734 m .56142 .54692 L .56436 .53921 L 1 g
F
P
p
.6056 .51591 m .56436 .53921 L .56669 .53103 L 1 g
F
P
p
.56439 .53913 m .56436 .53921 L .56438 .53917 L 1 g
F
P
p
.56654 .52734 m .56436 .53921 L .56439 .53913 L 1 g
F
P
p
.002 w
.6056 .51591 m .58026 .55075 L .56436 .53921 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56436 .53921 m .58026 .55075 L p
.55946 .55203 L 1 g
F P
s
P
p
.002 w
.57763 .50705 m .6056 .51591 L p
.56749 .53072 L 1 g
F P
s
P
p
.56749 .53072 m .56669 .53103 L .56743 .52942 L 1 g
F
P
p
.56749 .53072 m .56743 .52942 L .57763 .50705 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56739 .52858 L p
1 g
F P
s
P
p
.56515 .50826 m .56739 .52858 L .56708 .52167 L 1 g
F
P
p
.002 w
.57763 .50705 m .56997 .51766 L p
.56599 .50901 L 1 g
F P
s
P
p
.002 w
.56997 .51766 m .56708 .52167 L p
.56601 .50929 L 1 g
F P
s
P
p
.56997 .51766 m .56601 .50929 L .56599 .50901 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56601 .50929 L p
1 g
F P
s
P
p
.55661 .4905 m .56601 .50929 L .56228 .50139 L 1 g
F
P
p
.58726 .47446 m .56489 .49858 L .55687 .49028 L 1 g
F
P
p
.56489 .49858 m .56228 .50139 L .55737 .4913 L 1 g
F
P
p
.56489 .49858 m .55737 .4913 L .55687 .49028 L 1 g
F
P
p
.55661 .4905 m .56228 .50139 L .56203 .50087 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.58726 .47446 m .57763 .50705 L .56228 .50139 L p
1 g
F P
s
P
p
.002 w
.56228 .50139 m .57763 .50705 L p
.56589 .50903 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55768 .49163 L p
1 g
F P
s
P
p
.002 w
.55768 .49163 m .55661 .4905 L p
.56211 .50103 L 1 g
F P
s
P
p
.56211 .50103 m .56713 .51061 L .55768 .49163 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53306 .51456 m .54662 .49561 L .56228 .50139 L p
1 g
F P
s
P
p
.56515 .50826 m .56708 .52167 L .5669 .51958 L 1 g
F
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56739 .52858 m .56654 .52734 L p
.56439 .53913 L 1 g
F P
s
P
p
.002 w
.55784 .53447 m .56708 .52167 L p
.56669 .53103 L 1 g
F P
s
P
p
.002 w
.56708 .52167 m .57084 .51646 L p
.56739 .52858 L 1 g
F P
s
P
p
.56669 .53103 m .56708 .52167 L .56739 .52858 L 1 g
F
P
p
.002 w
.57084 .51646 m .57763 .50705 L p
.56669 .53103 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56654 .50991 L p
1 g
F P
s
P
p
.002 w
.56654 .50991 m .56515 .50826 L p
.56702 .52036 L 1 g
F P
s
P
p
.56702 .52036 m .56854 .53025 L .56654 .50991 L 1 g
F
P
p
.56589 .50903 m .53306 .51456 L .56228 .50139 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55737 .4913 L p
1 g
F P
s
P
p
.54174 .47608 m .55737 .4913 L .55119 .48533 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56228 .50139 m .54662 .49561 L p
.55687 .49028 L 1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55316 .47316 m .58726 .47446 L p
.5565 .49047 L 1 g
F P
s
P
p
.002 w
.54662 .49561 m .54996 .48414 L p
.5565 .49047 L 1 g
F P
s
P
p
.54174 .47608 m .55119 .48533 L .54996 .48414 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54996 .48414 m .54662 .49561 L p
.54151 .47634 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54234 .47673 L .53293 .47225 L 1 g
F
P
p
.54234 .47673 m .54151 .47634 L .54137 .47579 L 1 g
F
P
p
.54996 .48414 m .54151 .47634 L .54234 .47673 L 1 g
F
P
p
.002 w
.54662 .49561 m .51367 .48196 L p
.54068 .47594 L 1 g
F P
s
P
p
.54137 .47579 m .54151 .47634 L .54068 .47594 L 1 g
F
P
p
.54151 .47634 m .54662 .49561 L .54068 .47594 L 1 g
F
P
p
.52214 .46667 m .53293 .47225 L .53151 .47158 L 1 g
F
P
p
.002 w
.53151 .47158 m .51695 .47051 L p
.52243 .46724 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46724 L p
1 g
F P
s
P
p
.52245 .46723 m .52249 .46724 L .52243 .46724 L 1 g
F
P
p
.52249 .46724 m .53151 .47158 L .52243 .46724 L 1 g
F
P
p
.5 .4634 m .52249 .46724 L .51672 .4665 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51672 .4665 m .51695 .47051 L p
.49832 .46414 L 1 g
F P
s
P
p
.51672 .4665 m .49832 .46414 L .5 .46388 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.51695 .47051 m .48149 .46675 L p
.49832 .46414 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.48991 .46544 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .48991 .46544 L 1 g
F
P
p
.002 w
.47355 .50141 m .46226 .49708 L .47982 .467 L p
1 g
F P
s
P
p
.002 w
.49709 .49855 m .48559 .50192 L .48011 .46696 L p
1 g
F P
s
P
p
.002 w
.51367 .48196 m .5068 .49165 L .4804 .46692 L p
1 g
F P
s
P
p
.47786 .46667 m .48991 .46544 L .48149 .46675 L 1 g
F
P
p
.002 w
.48149 .46675 m .51695 .47051 L p
.48067 .46688 L 1 g
F P
s
P
p
.48093 .46684 m .48149 .46675 L .48093 .46684 L 1 g
F
P
p
.47786 .46667 m .48149 .46675 L .48093 .46684 L 1 g
F
P
p
.002 w
.51695 .47051 m .51367 .48196 L .48067 .46688 L p
1 g
F P
s
P
p
.002 w
.48067 .46688 m .48005 .4666 L .48149 .46675 L p
1 g
F P
s
P
p
.002 w
.4804 .46692 m .48005 .4666 L .48067 .46688 L p
1 g
F P
s
P
p
.002 w
.48067 .46688 m .51367 .48196 L p
.4804 .46692 L 1 g
F P
s
P
p
.48066 .46688 m .48093 .46684 L .48067 .46688 L 1 g
F
P
p
.47786 .46667 m .48093 .46684 L .48066 .46688 L 1 g
F
P
p
.4805 .4669 m .48067 .46688 L .48051 .4669 L 1 g
F
P
p
.47786 .46667 m .48067 .46688 L .4805 .4669 L 1 g
F
P
p
.002 w
.5068 .49165 m .49709 .49855 L .48024 .46694 L p
1 g
F P
s
P
p
.002 w
.48024 .46694 m .48005 .4666 L .4804 .46692 L p
1 g
F P
s
P
p
.002 w
.4804 .46692 m .5068 .49165 L p
.48024 .46694 L 1 g
F P
s
P
p
.002 w
.48011 .46696 m .48005 .4666 L .48024 .46694 L p
1 g
F P
s
P
p
.002 w
.48024 .46694 m .49709 .49855 L p
.48011 .46696 L 1 g
F P
s
P
p
.48039 .46692 m .48051 .4669 L .48039 .46692 L 1 g
F
P
p
.47786 .46667 m .48051 .4669 L .48039 .46692 L 1 g
F
P
p
.4803 .46693 m .48039 .46692 L .48031 .46694 L 1 g
F
P
p
.47786 .46667 m .48039 .46692 L .4803 .46693 L 1 g
F
P
p
.002 w
.48559 .50192 m .47355 .50141 L .47998 .46698 L p
1 g
F P
s
P
p
.002 w
.47998 .46698 m .48005 .4666 L .48011 .46696 L p
1 g
F P
s
P
p
.002 w
.48011 .46696 m .48559 .50192 L p
.47998 .46698 L 1 g
F P
s
P
p
.002 w
.47982 .467 m .48005 .4666 L .47998 .46698 L p
1 g
F P
s
P
p
.002 w
.47998 .46698 m .47355 .50141 L p
.47982 .467 L 1 g
F P
s
P
p
.48023 .46695 m .48031 .46694 L .48023 .46695 L 1 g
F
P
p
.47786 .46667 m .48031 .46694 L .48023 .46695 L 1 g
F
P
p
.002 w
.46226 .49708 m .45292 .48941 L .47953 .46704 L p
1 g
F P
s
P
p
.002 w
.47982 .467 m .46226 .49708 L p
.47953 .46704 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45292 .48941 m .44979 .4844 L p
.47855 .46716 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44979 .4844 m .45764 .47675 L .47855 .46716 L 1 g
F
P
p
.002 w
.45764 .47675 m .45826 .47608 L p
.46822 .47171 L 1 g
F P
s
P
p
.002 w
.47483 .46856 m .47855 .46716 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .4673 L p
1 g
F P
s
P
p
.47786 .46667 m .48023 .46695 L .47924 .46708 L 1 g
F
P
p
.002 w
.47748 .4673 m .47786 .46667 L p
.47924 .46708 L 1 g
F P
s
P
p
.002 w
.47888 .46663 m .48005 .4666 L .47855 .46716 L p
1 g
F P
s
P
p
.002 w
.47855 .46716 m .47483 .46856 L p
.47748 .4673 L 1 g
F P
s
P
p
.47748 .4673 m .47888 .46663 L .47855 .46716 L 1 g
F
P
p
.002 w
.47953 .46704 m .45292 .48941 L p
.47855 .46716 L 1 g
F P
s
P
p
.002 w
.47743 .46738 m .47748 .4673 L p
.47924 .46708 L 1 g
F P
s
P
p
.47924 .46708 m .47953 .46704 L .4795 .46704 L 1 g
F
P
p
.47924 .46708 m .4795 .46704 L .47743 .46738 L 1 g
F
P
p
.002 w
.47748 .4673 m .47748 .4673 L p
.47924 .46708 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.44379 .46755 m .47888 .46663 L p
.47701 .46736 L 1 g
F P
s
P
p
.002 w
.44653 .4792 m .44471 .47143 L p
.47701 .46736 L 1 g
F P
s
P
p
.002 w
.44471 .47143 m .44379 .46755 L p
.47701 .46736 L 1 g
F P
s
P
p
.45826 .47608 m .47748 .4673 L .47743 .46732 L 1 g
F
P
p
.45826 .47608 m .47748 .4673 L .46822 .47171 L 1 g
F
P
p
.002 w
.47483 .46856 m .44653 .4792 L p
.47888 .46663 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47748 .4673 L p
.47743 .46732 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47718 .46778 L p
.46822 .47171 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45723 .4772 L p
1 g
F P
s
P
p
.002 w
.45723 .4772 m .45698 .47747 L p
.453 .4813 L 1 g
F P
s
P
p
.44339 .4905 m .45723 .4772 L .453 .4813 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.42768 .51003 m .43406 .49959 L .44019 .49628 L 1 g
F
P
p
.002 w
.43736 .50212 m .42768 .51003 L p
.44019 .49628 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .43834 .50011 L 1 g
F
P
p
.002 w
.44979 .4844 m .45292 .48941 L p
.44019 .49628 L 1 g
F P
s
P
p
.43406 .49959 m .44258 .49136 L .44019 .49628 L 1 g
F
P
p
.44258 .49136 m .44979 .4844 L .44019 .49628 L 1 g
F
P
p
.002 w
.44258 .49136 m .44166 .49233 L p
.43834 .50011 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43332 .51466 m .4319 .51349 L p
.43363 .51151 L 1 g
F P
s
P
p
.002 w
.4319 .51349 m .42768 .51003 L .43432 .5046 L p
1 g
F P
s
P
p
.002 w
.43432 .5046 m .43736 .50212 L p
.43384 .50947 L 1 g
F P
s
P
p
.4319 .51349 m .43432 .5046 L .43384 .50947 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43384 .50947 L p
1 g
F P
s
P
p
.43346 .52734 m .43384 .50947 L .43332 .51466 L 1 g
F
P
p
.002 w
.42768 .51003 m .43332 .51466 L p
.43265 .5285 L 1 g
F P
s
P
p
.43163 .54939 m .42787 .51196 L .43265 .5285 L 1 g
F
P
p
.42787 .51196 m .42768 .51003 L .43265 .5285 L 1 g
F
P
p
.43925 .54566 m .4354 .53804 L .43635 .54134 L 1 g
F
P
p
.002 w
.44022 .55269 m .43163 .54939 L .4353 .54313 L p
1 g
F P
s
P
p
.002 w
.4353 .54313 m .43635 .54134 L p
.43838 .5473 L 1 g
F P
s
P
p
.44022 .55269 m .4353 .54313 L .43838 .5473 L 1 g
F
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44323 .55385 m .44022 .55269 L p
.44069 .55042 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43838 .5473 L p
1 g
F P
s
P
p
.44022 .55269 m .43838 .5473 L .44069 .55042 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.4635 .56164 m .46222 .57088 L p
.45091 .56278 L 1 g
F P
s
P
p
.002 w
.43287 .54987 m .44323 .55385 L p
.45091 .56278 L 1 g
F P
s
P
p
.45146 .56129 m .43838 .5473 L .44382 .55465 L 1 g
F
P
p
.002 w
.44323 .55385 m .4635 .56164 L p
.45091 .56278 L 1 g
F P
s
P
p
.44382 .55465 m .44323 .55385 L .43743 .5491 L 1 g
F
P
p
.002 w
.43838 .5473 m .43808 .54786 L p
.44323 .55385 L 1 g
F P
s
P
p
.002 w
.43808 .54786 m .43743 .5491 L p
.44323 .55385 L 1 g
F P
s
P
p
.002 w
.43838 .5473 m .43925 .54566 L p
.43635 .54134 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43265 .52852 L p
1 g
F P
s
P
p
.43925 .54566 m .43265 .52852 L .4354 .53804 L 1 g
F
P
p
.002 w
.43332 .51466 m .44593 .525 L .43635 .54134 L p
1 g
F P
s
P
p
.002 w
.43635 .54134 m .43164 .54937 L p
.43265 .52852 L 1 g
F P
s
P
p
.43346 .52734 m .43332 .51466 L .43315 .5183 L 1 g
F
P
p
.002 w
.43164 .54937 m .43163 .54939 L p
.43332 .51466 L 1 g
F P
s
P
p
.002 w
.43182 .52972 m .43346 .52734 L p
.4331 .51692 L 1 g
F P
s
P
p
.43265 .52852 m .43332 .51466 L .43635 .54134 L 1 g
F
P
p
.002 w
.43265 .52852 m .43146 .53025 L p
.4354 .53804 L 1 g
F P
s
P
p
.002 w
.43635 .54134 m .44593 .525 L p
.44069 .55042 L 1 g
F P
s
P
p
.43838 .5473 m .43635 .54134 L .44069 .55042 L 1 g
F
P
p
.002 w
.4635 .56164 m .44323 .55385 L p
.44593 .525 L 1 g
F P
s
P
p
.44323 .55385 m .44069 .55042 L .44593 .525 L 1 g
F
P
p
.4442 .55499 m .44382 .55465 L .45091 .56278 L 1 g
F
P
p
.44382 .55465 m .43743 .5491 L .4466 .55841 L 1 g
F
P
p
.44382 .55465 m .4466 .55841 L .45091 .56278 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45055 .56375 L p
1 g
F P
s
P
p
.002 w
.45055 .56375 m .45091 .56278 L p
.4466 .55841 L 1 g
F P
s
P
p
.4466 .55841 m .43743 .5491 L .45055 .56375 L 1 g
F
P
p
.002 w
.43818 .54768 m .43838 .5473 L p
.43635 .54134 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43818 .54768 L p
1 g
F P
s
P
p
.4354 .53804 m .43146 .53025 L .43818 .54768 L 1 g
F
P
p
.43315 .5183 m .43332 .51466 L .4331 .51692 L 1 g
F
P
p
.43485 .50826 m .43834 .50011 L .43736 .50212 L 1 g
F
P
p
.002 w
.43384 .50947 m .43485 .50826 L p
.43736 .50212 L 1 g
F P
s
P
p
.002 w
.43736 .50212 m .45292 .48941 L p
.4319 .51349 L 1 g
F P
s
P
p
.002 w
.43384 .50947 m .43287 .51061 L p
.4331 .51692 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43182 .52972 L p
1 g
F P
s
P
p
.4331 .51692 m .43287 .51061 L .43182 .52972 L 1 g
F
P
p
.002 w
.44593 .525 m .43332 .51466 L p
.45292 .48941 L 1 g
F P
s
P
p
.43332 .51466 m .43363 .51151 L .45292 .48941 L 1 g
F
P
p
.002 w
.43374 .50958 m .43384 .50947 L p
.43736 .50212 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43374 .50958 L p
1 g
F P
s
P
p
.43834 .50011 m .44166 .49233 L .43374 .50958 L 1 g
F
P
p
.002 w
.45292 .48941 m .43736 .50212 L p
.44019 .49628 L 1 g
F P
s
P
p
.002 w
.44204 .49193 m .44339 .4905 L p
.45154 .48269 L 1 g
F P
s
P
p
.002 w
.44653 .4792 m .44979 .4844 L p
.43406 .49959 L 1 g
F P
s
P
p
.002 w
.44653 .4792 m .46054 .47393 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.44979 .4844 m .44791 .48139 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.44791 .48139 m .44653 .4792 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.46054 .47393 m .47483 .46856 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45764 .47675 L p
1 g
F P
s
P
p
.46822 .47171 m .47718 .46778 L .45764 .47675 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44204 .49193 L p
1 g
F P
s
P
p
.45154 .48269 m .45698 .47747 L .44204 .49193 L 1 g
F
P
p
.002 w
.47855 .46716 m .48005 .4666 L .47953 .46704 L p
1 g
F P
s
P
p
.47953 .46704 m .48023 .46695 L .48017 .46696 L 1 g
F
P
p
.47953 .46704 m .48017 .46696 L .47743 .46738 L 1 g
F
P
p
.002 w
.47953 .46704 m .48005 .4666 L .47982 .467 L p
1 g
F P
s
P
p
.002 w
.48005 .4666 m .49548 .46317 L p
.49832 .46414 L 1 g
F P
s
P
p
.002 w
.48149 .46675 m .48005 .4666 L p
.49832 .46414 L 1 g
F P
s
P
p
.5 .46388 m .49832 .46414 L .49548 .46317 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47743 .46738 L p
1 g
F P
s
P
p
.48991 .46544 m .5 .46442 L .47743 .46738 L 1 g
F
P
p
.51358 .46601 m .51672 .4665 L .515 .46628 L 1 g
F
P
p
.5 .4634 m .51672 .4665 L .51358 .46601 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52249 .46724 m .52214 .46667 L p
.53151 .47158 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51627 .45855 m .55189 .44963 L p
.52243 .46724 L 1 g
F P
s
P
p
.002 w
.51695 .47051 m .51672 .4665 L p
.52243 .46724 L 1 g
F P
s
P
p
.002 w
.51672 .4665 m .51627 .45855 L p
.52243 .46724 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46436 L p
1 g
F P
s
P
p
.002 w
.5 .46436 m .5 .4634 L p
.515 .46628 L 1 g
F P
s
P
p
.515 .46628 m .52282 .46778 L .5 .46436 L 1 g
F
P
p
.002 w
.49548 .46317 m .51627 .45855 L .51672 .4665 L p
1 g
F P
s
P
p
.002 w
.52249 .46724 m .52282 .46778 L p
.515 .46628 L 1 g
F P
s
P
p
.002 w
.52252 .4673 m .52249 .46724 L p
.53151 .47158 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55189 .44963 m .55316 .47316 L .53151 .47158 L p
1 g
F P
s
P
p
.55189 .44963 m .53151 .47158 L .52245 .46723 L 1 g
F
P
p
.002 w
.51367 .48196 m .51695 .47051 L .55316 .47316 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52252 .4673 L p
1 g
F P
s
P
p
.53293 .47225 m .54302 .47747 L .52252 .4673 L 1 g
F
P
p
.002 w
.54234 .47673 m .54302 .47747 L p
.53293 .47225 L 1 g
F P
s
P
p
.002 w
.54269 .47712 m .54234 .47673 L p
.54996 .48414 L 1 g
F P
s
P
p
.002 w
.54234 .47673 m .54174 .47608 L p
.54996 .48414 L 1 g
F P
s
P
p
.002 w
.55316 .47316 m .54996 .48414 L p
.54137 .47579 L 1 g
F P
s
P
p
.002 w
.54996 .48414 m .55316 .47316 L p
.5565 .49047 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54269 .47712 L p
1 g
F P
s
P
p
.55119 .48533 m .55834 .49233 L .54269 .47712 L 1 g
F
P
p
.002 w
.55737 .4913 m .55834 .49233 L p
.55119 .48533 L 1 g
F P
s
P
p
.56203 .50087 m .56228 .50139 L .56211 .50103 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55784 .53447 m .53306 .51456 L p
.56599 .50901 L 1 g
F P
s
P
p
.002 w
.56708 .52167 m .55784 .53447 L p
.56599 .50901 L 1 g
F P
s
P
p
.002 w
.56601 .50929 m .56713 .51061 L p
.56211 .50103 L 1 g
F P
s
P
p
.5669 .51958 m .56708 .52167 L .56702 .52036 L 1 g
F
P
p
.002 w
.56739 .52858 m .56854 .53025 L p
.56702 .52036 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56739 .52858 L p
1 g
F P
s
P
p
.56439 .53913 m .56257 .5491 L .56739 .52858 L 1 g
F
P
p
.002 w
.56436 .53921 m .55784 .53447 L p
.56669 .53103 L 1 g
F P
s
P
p
.002 w
.53012 .55384 m .55784 .53447 L .56436 .53921 L p
1 g
F P
s
P
p
.55946 .55203 m .53012 .55384 L .56436 .53921 L 1 g
F
P
p
.002 w
.56142 .54692 m .56257 .5491 L p
.56438 .53917 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56142 .54692 L p
1 g
F P
s
P
p
.55683 .55277 m .54998 .56518 L .56142 .54692 L 1 g
F
P
p
.002 w
.54906 .56268 m .54998 .56518 L p
.55683 .55277 L 1 g
F P
s
P
p
.002 w
.54955 .56401 m .54906 .56268 L p
.54064 .5691 L 1 g
F P
s
P
p
.002 w
.49752 .56319 m .53012 .55384 L .54064 .5691 L p
1 g
F P
s
P
p
.002 w
.54064 .5691 m .54492 .5753 L p
.53447 .57263 L 1 g
F P
s
P
p
.53447 .57263 m .49752 .56319 L .54064 .5691 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54955 .56401 L p
1 g
F P
s
P
p
.5399 .56952 m .5322 .57686 L .54955 .56401 L 1 g
F
P
p
.002 w
.53163 .57425 m .5322 .57686 L p
.5399 .56952 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53163 .57425 L p
1 g
F P
s
P
p
.52342 .57668 m .51111 .583 L .53163 .57425 L 1 g
F
P
p
.002 w
.51092 .58038 m .51111 .583 L p
.52342 .57668 L 1 g
F P
s
P
p
.002 w
.51101 .58163 m .51092 .58038 L p
.50195 .58102 L 1 g
F P
s
P
p
.002 w
.4635 .56164 m .49752 .56319 L .50345 .5871 L p
1 g
F P
s
P
p
.002 w
.4891 .58015 m .48889 .583 L p
.49959 .58086 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51101 .58163 L p
1 g
F P
s
P
p
.49959 .58086 m .48889 .583 L .51101 .58163 L 1 g
F
P
p
.48617 .57995 m .48327 .57976 L .48128 .57793 L 1 g
F
P
p
.002 w
.46837 .57426 m .46872 .57265 L p
.46222 .57088 L 1 g
F P
s
P
p
.002 w
.46222 .57088 m .4635 .56164 L p
.49062 .58649 L 1 g
F P
s
P
p
.002 w
.46837 .57426 m .4678 .57686 L p
.48148 .57799 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58015 L p
1 g
F P
s
P
p
.48148 .57799 m .4678 .57686 L .4891 .58015 L 1 g
F
P
p
.002 w
.46817 .57514 m .46837 .57426 L p
.46222 .57088 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46817 .57514 L p
1 g
F P
s
P
p
.45961 .56901 m .45002 .56518 L .46817 .57514 L 1 g
F
P
p
.002 w
.43163 .54939 m .43287 .54987 L p
.46025 .58506 L 1 g
F P
s
P
p
.002 w
.38706 .49897 m .40523 .52775 L .38627 .54205 L p
1 g
F P
s
P
p
.002 w
.38627 .54205 m .36315 .50552 L .38706 .49897 L p
1 g
F P
s
P
p
.002 w
.64217 .42135 m .62279 .37278 L .64172 .35817 L p
1 g
F P
s
P
p
.002 w
.60314 .31343 m .64172 .35817 L .62279 .37278 L p
1 g
F P
s
P
p
.002 w
.58026 .55075 m .6056 .51591 L .62961 .52196 L p
1 g
F P
s
P
p
.002 w
.64444 .473 m .62961 .52196 L .6056 .51591 L p
1 g
F P
s
P
p
.002 w
.54253 .30621 m .49074 .29589 L .4939 .27208 L p
1 g
F P
s
P
p
.002 w
.4939 .27208 m .5519 .28359 L .54253 .30621 L p
1 g
F P
s
P
p
.002 w
.40475 .35026 m .37471 .38157 L .35736 .36355 L p
1 g
F P
s
P
p
.002 w
.35736 .36355 m .39272 .32648 L .40475 .35026 L p
1 g
F P
s
P
p
.002 w
.37911 .46601 m .38706 .49897 L .36315 .50552 L p
1 g
F P
s
P
p
.002 w
.36315 .50552 m .35293 .46365 L .37911 .46601 L p
1 g
F P
s
P
p
.002 w
.62279 .37278 m .58829 .33286 L .60314 .31343 L p
1 g
F P
s
P
p
.002 w
.5519 .28359 m .60314 .31343 L .58829 .33286 L p
1 g
F P
s
P
p
.002 w
.58829 .33286 m .54253 .30621 L .5519 .28359 L p
1 g
F P
s
P
p
.002 w
.38229 .43236 m .37911 .46601 L .35293 .46365 L p
1 g
F P
s
P
p
.002 w
.35293 .46365 m .35686 .42081 L .38229 .43236 L p
1 g
F P
s
P
p
.002 w
.6056 .51591 m .61803 .47439 L .64444 .473 L p
1 g
F P
s
P
p
.002 w
.64217 .42135 m .64444 .473 L .61803 .47439 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44386 .33047 m .40475 .35026 L .39272 .32648 L p
1 g
F P
s
P
p
.002 w
.39272 .32648 m .43886 .30298 L .44386 .33047 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39641 .40161 m .38229 .43236 L .35686 .42081 L p
1 g
F P
s
P
p
.002 w
.35686 .42081 m .37471 .38157 L .39641 .40161 L p
1 g
F P
s
P
p
.002 w
.61803 .47439 m .61599 .43067 L .64217 .42135 L p
1 g
F P
s
P
p
.002 w
.62279 .37278 m .64217 .42135 L .61599 .43067 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.48778 .32456 m .44386 .33047 L .43886 .30298 L p
1 g
F P
s
P
p
.002 w
.43886 .30298 m .49074 .29589 L .48778 .32456 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.43163 .54939 m .40523 .52775 L .42768 .51003 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.44593 .525 m .46798 .53346 L .4635 .56164 L p
1 g
F P
s
P
p
.002 w
.49752 .56319 m .4635 .56164 L .46798 .53346 L p
1 g
F P
s
P
p
.002 w
.61803 .47439 m .6056 .51591 L .57763 .50705 L p
1 g
F P
s
P
p
.002 w
.41516 .49011 m .42768 .51003 L .40523 .52775 L p
1 g
F P
s
P
p
.002 w
.40523 .52775 m .38706 .49897 L .41516 .49011 L p
1 g
F P
s
P
p
.002 w
.61599 .43067 m .5995 .38961 L .62279 .37278 L p
1 g
F P
s
P
p
.002 w
.58829 .33286 m .62279 .37278 L .5995 .38961 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53157 .33334 m .48778 .32456 L .49074 .29589 L p
1 g
F P
s
P
p
.002 w
.49074 .29589 m .54253 .30621 L .53157 .33334 L p
1 g
F P
s
P
p
.002 w
.42005 .37715 m .39641 .40161 L .37471 .38157 L p
1 g
F P
s
P
p
.002 w
.37471 .38157 m .40475 .35026 L .42005 .37715 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46798 .53346 m .49149 .5345 L .49752 .56319 L p
1 g
F P
s
P
p
.002 w
.53012 .55384 m .49752 .56319 L .49149 .5345 L p
1 g
F P
s
P
p
.002 w
.40973 .46734 m .41516 .49011 L .38706 .49897 L p
1 g
F P
s
P
p
.002 w
.38706 .49897 m .37911 .46601 L .40973 .46734 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.5995 .38961 m .57027 .35588 L .58829 .33286 L p
1 g
F P
s
P
p
.002 w
.54253 .30621 m .58829 .33286 L .57027 .35588 L p
1 g
F P
s
P
p
.002 w
.57027 .35588 m .53157 .33334 L .54253 .30621 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.49149 .5345 m .51399 .52798 L .53012 .55384 L p
1 g
F P
s
P
p
.002 w
.55784 .53447 m .53012 .55384 L .51399 .52798 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41201 .44414 m .40973 .46734 L .37911 .46601 L p
1 g
F P
s
P
p
.002 w
.37911 .46601 m .38229 .43236 L .41201 .44414 L p
1 g
F P
s
P
p
.002 w
.57763 .50705 m .58726 .47446 L .61803 .47439 L p
1 g
F P
s
P
p
.002 w
.61599 .43067 m .61803 .47439 L .58726 .47446 L p
1 g
F P
s
P
p
.002 w
.45074 .36175 m .42005 .37715 L .40475 .35026 L p
1 g
F P
s
P
p
.002 w
.40475 .35026 m .44386 .33047 L .45074 .36175 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.51399 .52798 m .53306 .51456 L .55784 .53447 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42182 .423 m .41201 .44414 L .38229 .43236 L p
1 g
F P
s
P
p
.002 w
.38229 .43236 m .39641 .40161 L .42182 .423 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58726 .47446 m .58555 .44022 L .61599 .43067 L p
1 g
F P
s
P
p
.002 w
.5995 .38961 m .61599 .43067 L .58555 .44022 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.48512 .35721 m .45074 .36175 L .44386 .33047 L p
1 g
F P
s
P
p
.002 w
.44386 .33047 m .48778 .32456 L .48512 .35721 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.45292 .48941 m .46226 .49708 L .44593 .525 L p
1 g
F P
s
P
p
.002 w
.46798 .53346 m .44593 .525 L .46226 .49708 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46226 .49708 m .47355 .50141 L .46798 .53346 L p
1 g
F P
s
P
p
.002 w
.49149 .5345 m .46798 .53346 L .47355 .50141 L p
1 g
F P
s
P
p
.002 w
.58555 .44022 m .57256 .40811 L .5995 .38961 L p
1 g
F P
s
P
p
.002 w
.57027 .35588 m .5995 .38961 L .57256 .40811 L p
1 g
F P
s
P
p
.002 w
.43815 .40624 m .42182 .423 L .39641 .40161 L p
1 g
F P
s
P
p
.002 w
.39641 .40161 m .42005 .37715 L .43815 .40624 L p
1 g
F P
s
P
p
.002 w
.42768 .51003 m .41516 .49011 L .44653 .4792 L p
1 g
F P
s
P
p
.002 w
.51938 .36412 m .48512 .35721 L .48778 .32456 L p
1 g
F P
s
P
p
.002 w
.48778 .32456 m .53157 .33334 L .51938 .36412 L p
1 g
F P
s
P
p
.002 w
.47355 .50141 m .48559 .50192 L .49149 .5345 L p
1 g
F P
s
P
p
.002 w
.51399 .52798 m .49149 .5345 L .48559 .50192 L p
1 g
F P
s
P
p
.002 w
.44379 .46755 m .44653 .4792 L .41516 .49011 L p
1 g
F P
s
P
p
.002 w
.41516 .49011 m .40973 .46734 L .44379 .46755 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.57256 .40811 m .54966 .38175 L .57027 .35588 L p
1 g
F P
s
P
p
.002 w
.53157 .33334 m .57027 .35588 L .54966 .38175 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.54966 .38175 m .51938 .36412 L .53157 .33334 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48559 .50192 m .49709 .49855 L .51399 .52798 L p
1 g
F P
s
P
p
.002 w
.53306 .51456 m .51399 .52798 L .49709 .49855 L p
1 g
F P
s
P
p
.002 w
.58555 .44022 m .58726 .47446 L .55316 .47316 L p
1 g
F P
s
P
p
.002 w
.44501 .45571 m .44379 .46755 L .40973 .46734 L p
1 g
F P
s
P
p
.002 w
.40973 .46734 m .41201 .44414 L .44501 .45571 L p
1 g
F P
s
P
p
.002 w
.45927 .39573 m .43815 .40624 L .42005 .37715 L p
1 g
F P
s
P
p
.002 w
.42005 .37715 m .45074 .36175 L .45927 .39573 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.49709 .49855 m .5068 .49165 L .53306 .51456 L p
1 g
F P
s
P
p
.002 w
.54662 .49561 m .53306 .51456 L .5068 .49165 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.45005 .44495 m .44501 .45571 L .41201 .44414 L p
1 g
F P
s
P
p
.002 w
.41201 .44414 m .42182 .423 L .45005 .44495 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55316 .47316 m .55189 .44963 L .58555 .44022 L p
1 g
F P
s
P
p
.002 w
.57256 .40811 m .58555 .44022 L .55189 .44963 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48289 .39268 m .45927 .39573 L .45074 .36175 L p
1 g
F P
s
P
p
.002 w
.45074 .36175 m .48512 .35721 L .48289 .39268 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.5068 .49165 m .51367 .48196 L .54662 .49561 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.45841 .43645 m .45005 .44495 L .42182 .423 L p
1 g
F P
s
P
p
.002 w
.42182 .423 m .43815 .40624 L .45841 .43645 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.55189 .44963 m .54291 .42761 L .57256 .40811 L p
1 g
F P
s
P
p
.002 w
.54966 .38175 m .57256 .40811 L .54291 .42761 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.50639 .39745 m .48289 .39268 L .48512 .35721 L p
1 g
F P
s
P
p
.002 w
.48512 .35721 m .51938 .36412 L .50639 .39745 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54291 .42761 m .52717 .40954 L .54966 .38175 L p
1 g
F P
s
P
p
.002 w
.51938 .36412 m .54966 .38175 L .52717 .40954 L p
1 g
F P
s
P
p
.002 w
.52717 .40954 m .50639 .39745 L .51938 .36412 L p
1 g
F P
s
P
p
.002 w
.44379 .46755 m .44501 .45571 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.46917 .43114 m .45841 .43645 L .43815 .40624 L p
1 g
F P
s
P
p
.002 w
.43815 .40624 m .45927 .39573 L .46917 .43114 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.44501 .45571 m .45005 .44495 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54291 .42761 m .55189 .44963 L .51627 .45855 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48118 .42962 m .46917 .43114 L .45927 .39573 L p
1 g
F P
s
P
p
.002 w
.45927 .39573 m .48289 .39268 L .48118 .42962 L p
1 g
F P
s
P
p
.002 w
.45005 .44495 m .45841 .43645 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51627 .45855 m .51167 .44737 L .54291 .42761 L p
1 g
F P
s
P
p
.002 w
.52717 .40954 m .54291 .42761 L .51167 .44737 L p
1 g
F P
s
P
p
.002 w
.45841 .43645 m .46917 .43114 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.49311 .43206 m .48118 .42962 L .48289 .39268 L p
1 g
F P
s
P
p
.002 w
.48289 .39268 m .50639 .39745 L .49311 .43206 L p
1 g
F P
s
P
p
.002 w
.51167 .44737 m .51627 .45855 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.50366 .4382 m .51167 .44737 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.49311 .43206 m .50366 .4382 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.004 w
.49767 .43472 m
.5 .43051 L
s
P
p
.002 w
.48118 .42962 m .49311 .43206 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.46917 .43114 m .48118 .42962 L .48005 .4666 L closepath p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51167 .44737 m .50366 .4382 L .52717 .40954 L p
1 g
F P
s
P
p
.002 w
.50639 .39745 m .52717 .40954 L .50366 .4382 L p
1 g
F P
s
P
p
.002 w
.50366 .4382 m .49311 .43206 L .50639 .39745 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.46768 .48898 m
.48005 .4666 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .23169 .52671 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .46768 .48898 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0478947)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0478947)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48641 .4608 m .50493 .46087 L .50041 .43275 L p
1 g
F P
s
P
p
.002 w
.50041 .43275 m .49104 .43271 L .48641 .4608 L p
1 g
F P
s
P
p
.002 w
.50929 .42977 m .50041 .43275 L .50493 .46087 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .49104 .43271 L .50041 .43275 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .50041 .43275 L .50929 .42977 L closepath p
1 g
F P
s
P
p
.002 w
.46891 .45481 m .48641 .4608 L .49104 .43271 L p
1 g
F P
s
P
p
.002 w
.49104 .43271 m .48219 .42966 L .46891 .45481 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .48219 .42966 L .49104 .43271 L closepath p
1 g
F P
s
P
p
.002 w
.50493 .46087 m .52249 .45501 L .50929 .42977 L p
1 g
F P
s
P
p
.002 w
.51674 .42411 m .50929 .42977 L .52249 .45501 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .50929 .42977 L .51674 .42411 L closepath p
1 g
F P
s
P
p
.002 w
.45431 .44351 m .46891 .45481 L .48219 .42966 L p
1 g
F P
s
P
p
.002 w
.48219 .42966 m .47482 .42393 L .45431 .44351 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .47482 .42393 L .48219 .42966 L closepath p
1 g
F P
s
P
p
.002 w
.52249 .45501 m .53722 .44383 L .51674 .42411 L p
1 g
F P
s
P
p
.002 w
.52194 .41636 m .51674 .42411 L .53722 .44383 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .51674 .42411 L .52194 .41636 L closepath p
1 g
F P
s
P
p
.002 w
.44419 .42809 m .45431 .44351 L .47482 .42393 L p
1 g
F P
s
P
p
.002 w
.47482 .42393 m .46973 .41613 L .44419 .42809 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .46973 .41613 L .47482 .42393 L closepath p
1 g
F P
s
P
p
.002 w
.53722 .44383 m .54755 .42852 L .52194 .41636 L p
1 g
F P
s
P
p
.002 w
.52433 .40736 m .52194 .41636 L .54755 .42852 L p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .52194 .41636 L .52433 .40736 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .52433 .40736 L .52365 .39807 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .52365 .39807 L .51996 .38951 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .51996 .38951 L .51366 .3826 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .46828 .39781 L .46746 .4071 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .46746 .4071 L .46973 .41613 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .51366 .3826 L .50542 .3781 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .50542 .3781 L .49614 .37651 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .49614 .37651 L .48683 .37801 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .48683 .37801 L .47852 .38243 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .47852 .38243 L .4721 .38928 L closepath p
1 g
F P
s
P
p
.002 w
.49588 .40458 m .4721 .38928 L .46828 .39781 L closepath p
1 g
F P
s
P
p
.002 w
.48208 .48837 m .50936 .48845 L .50493 .46087 L p
1 g
F P
s
P
p
.002 w
.50493 .46087 m .48641 .4608 L .48208 .48837 L p
1 g
F P
s
P
p
.002 w
.52249 .45501 m .50493 .46087 L .50936 .48845 L p
1 g
F P
s
P
p
.002 w
.45629 .47956 m .48208 .48837 L .48641 .4608 L p
1 g
F P
s
P
p
.002 w
.48641 .4608 m .46891 .45481 L .45629 .47956 L p
1 g
F P
s
P
p
.002 w
.50936 .48845 m .53524 .47982 L .52249 .45501 L p
1 g
F P
s
P
p
.002 w
.53722 .44383 m .52249 .45501 L .53524 .47982 L p
1 g
F P
s
P
p
.002 w
.43965 .41021 m .44419 .42809 L .46973 .41613 L p
1 g
F P
s
P
p
.002 w
.46973 .41613 m .46746 .4071 L .43965 .41021 L p
1 g
F P
s
P
p
.002 w
.54755 .42852 m .55234 .41071 L .52433 .40736 L p
1 g
F P
s
P
p
.002 w
.52365 .39807 m .52433 .40736 L .55234 .41071 L p
1 g
F P
s
P
p
.002 w
.43472 .46295 m .45629 .47956 L .46891 .45481 L p
1 g
F P
s
P
p
.002 w
.46891 .45481 m .45431 .44351 L .43472 .46295 L p
1 g
F P
s
P
p
.002 w
.53524 .47982 m .55697 .46338 L .53722 .44383 L p
1 g
F P
s
P
p
.002 w
.54755 .42852 m .53722 .44383 L .55697 .46338 L p
1 g
F P
s
P
p
.002 w
.44122 .39179 m .43965 .41021 L .46746 .4071 L p
1 g
F P
s
P
p
.002 w
.46746 .4071 m .46828 .39781 L .44122 .39179 L p
1 g
F P
s
P
p
.002 w
.55234 .41071 m .55104 .3923 L .52365 .39807 L p
1 g
F P
s
P
p
.002 w
.51996 .38951 m .52365 .39807 L .55104 .3923 L p
1 g
F P
s
P
p
.002 w
.44877 .37482 m .44122 .39179 L .46828 .39781 L p
1 g
F P
s
P
p
.002 w
.46828 .39781 m .4721 .38928 L .44877 .37482 L p
1 g
F P
s
P
p
.002 w
.55104 .3923 m .54377 .3753 L .51996 .38951 L p
1 g
F P
s
P
p
.002 w
.51366 .3826 m .51996 .38951 L .54377 .3753 L p
1 g
F P
s
P
p
.002 w
.41972 .44024 m .43472 .46295 L .45431 .44351 L p
1 g
F P
s
P
p
.002 w
.45431 .44351 m .44419 .42809 L .41972 .44024 L p
1 g
F P
s
P
p
.002 w
.55697 .46338 m .57224 .44084 L .54755 .42852 L p
1 g
F P
s
P
p
.002 w
.55234 .41071 m .54755 .42852 L .57224 .44084 L p
1 g
F P
s
P
p
.002 w
.46149 .36119 m .44877 .37482 L .4721 .38928 L p
1 g
F P
s
P
p
.002 w
.4721 .38928 m .47852 .38243 L .46149 .36119 L p
1 g
F P
s
P
p
.002 w
.54377 .3753 m .53129 .36156 L .51366 .3826 L p
1 g
F P
s
P
p
.002 w
.50542 .3781 m .51366 .3826 L .53129 .36156 L p
1 g
F P
s
P
p
.002 w
.478 .3524 m .46149 .36119 L .47852 .38243 L p
1 g
F P
s
P
p
.002 w
.47852 .38243 m .48683 .37801 L .478 .3524 L p
1 g
F P
s
P
p
.002 w
.53129 .36156 m .51493 .3526 L .50542 .3781 L p
1 g
F P
s
P
p
.002 w
.49614 .37651 m .50542 .3781 L .51493 .3526 L p
1 g
F P
s
P
p
.002 w
.4965 .34943 m .478 .3524 L .48683 .37801 L p
1 g
F P
s
P
p
.002 w
.48683 .37801 m .49614 .37651 L .4965 .34943 L p
1 g
F P
s
P
p
.002 w
.51493 .3526 m .4965 .34943 L .49614 .37651 L p
1 g
F P
s
P
p
.002 w
.41295 .41386 m .41972 .44024 L .44419 .42809 L p
1 g
F P
s
P
p
.002 w
.44419 .42809 m .43965 .41021 L .41295 .41386 L p
1 g
F P
s
P
p
.002 w
.57224 .44084 m .57937 .41458 L .55234 .41071 L p
1 g
F P
s
P
p
.002 w
.55104 .3923 m .55234 .41071 L .57937 .41458 L p
1 g
F P
s
P
p
.002 w
.47813 .51488 m .51362 .51498 L .50936 .48845 L p
1 g
F P
s
P
p
.002 w
.50936 .48845 m .48208 .48837 L .47813 .51488 L p
1 g
F P
s
P
p
.002 w
.53524 .47982 m .50936 .48845 L .51362 .51498 L p
1 g
F P
s
P
p
.002 w
.44455 .50347 m .47813 .51488 L .48208 .48837 L p
1 g
F P
s
P
p
.002 w
.48208 .48837 m .45629 .47956 L .44455 .50347 L p
1 g
F P
s
P
p
.002 w
.51362 .51498 m .54729 .50376 L .53524 .47982 L p
1 g
F P
s
P
p
.002 w
.55697 .46338 m .53524 .47982 L .54729 .50376 L p
1 g
F P
s
P
p
.002 w
.4152 .38662 m .41295 .41386 L .43965 .41021 L p
1 g
F P
s
P
p
.002 w
.43965 .41021 m .44122 .39179 L .4152 .38662 L p
1 g
F P
s
P
p
.002 w
.57937 .41458 m .57753 .3874 L .55104 .3923 L p
1 g
F P
s
P
p
.002 w
.54377 .3753 m .55104 .3923 L .57753 .3874 L p
1 g
F P
s
P
p
.002 w
.41643 .48189 m .44455 .50347 L .45629 .47956 L p
1 g
F P
s
P
p
.002 w
.45629 .47956 m .43472 .46295 L .41643 .48189 L p
1 g
F P
s
P
p
.002 w
.54729 .50376 m .5756 .4824 L .55697 .46338 L p
1 g
F P
s
P
p
.002 w
.57224 .44084 m .55697 .46338 L .5756 .4824 L p
1 g
F P
s
P
p
.002 w
.42631 .36151 m .4152 .38662 L .44122 .39179 L p
1 g
F P
s
P
p
.002 w
.44122 .39179 m .44877 .37482 L .42631 .36151 L p
1 g
F P
s
P
p
.002 w
.57753 .3874 m .56685 .36224 L .54377 .3753 L p
1 g
F P
s
P
p
.002 w
.53129 .36156 m .54377 .3753 L .56685 .36224 L p
1 g
F P
s
P
p
.002 w
.39682 .45236 m .41643 .48189 L .43472 .46295 L p
1 g
F P
s
P
p
.002 w
.43472 .46295 m .41972 .44024 L .39682 .45236 L p
1 g
F P
s
P
p
.002 w
.5756 .4824 m .59554 .4531 L .57224 .44084 L p
1 g
F P
s
P
p
.002 w
.57937 .41458 m .57224 .44084 L .59554 .4531 L p
1 g
F P
s
P
p
.002 w
.44511 .3413 m .42631 .36151 L .44877 .37482 L p
1 g
F P
s
P
p
.002 w
.44877 .37482 m .46149 .36119 L .44511 .3413 L p
1 g
F P
s
P
p
.002 w
.56685 .36224 m .54843 .34188 L .53129 .36156 L p
1 g
F P
s
P
p
.002 w
.51493 .3526 m .53129 .36156 L .54843 .34188 L p
1 g
F P
s
P
p
.002 w
.46955 .32826 m .44511 .3413 L .46149 .36119 L p
1 g
F P
s
P
p
.002 w
.46149 .36119 m .478 .3524 L .46955 .32826 L p
1 g
F P
s
P
p
.002 w
.54843 .34188 m .52425 .32858 L .51493 .3526 L p
1 g
F P
s
P
p
.002 w
.4965 .34943 m .51493 .3526 L .52425 .32858 L p
1 g
F P
s
P
p
.002 w
.3879 .41798 m .39682 .45236 L .41972 .44024 L p
1 g
F P
s
P
p
.002 w
.41972 .44024 m .41295 .41386 L .3879 .41798 L p
1 g
F P
s
P
p
.002 w
.59554 .4531 m .60491 .41891 L .57937 .41458 L p
1 g
F P
s
P
p
.002 w
.57753 .3874 m .57937 .41458 L .60491 .41891 L p
1 g
F P
s
P
p
.002 w
.49695 .32386 m .46955 .32826 L .478 .3524 L p
1 g
F P
s
P
p
.002 w
.478 .3524 m .4965 .34943 L .49695 .32386 L p
1 g
F P
s
P
p
.002 w
.52425 .32858 m .49695 .32386 L .4965 .34943 L p
1 g
F P
s
P
p
.002 w
.47464 .53982 m .51762 .53992 L .51362 .51498 L p
1 g
F P
s
P
p
.002 w
.51362 .51498 m .47813 .51488 L .47464 .53982 L p
1 g
F P
s
P
p
.002 w
.54729 .50376 m .51362 .51498 L .51762 .53992 L p
1 g
F P
s
P
p
.002 w
.43395 .52605 m .47464 .53982 L .47813 .51488 L p
1 g
F P
s
P
p
.002 w
.47813 .51488 m .44455 .50347 L .43395 .52605 L p
1 g
F P
s
P
p
.002 w
.51762 .53992 m .55841 .52636 L .54729 .50376 L p
1 g
F P
s
P
p
.002 w
.5756 .4824 m .54729 .50376 L .55841 .52636 L p
1 g
F P
s
P
p
.002 w
.39076 .38244 m .3879 .41798 L .41295 .41386 L p
1 g
F P
s
P
p
.002 w
.41295 .41386 m .4152 .38662 L .39076 .38244 L p
1 g
F P
s
P
p
.002 w
.60491 .41891 m .6026 .38347 L .57753 .3874 L p
1 g
F P
s
P
p
.002 w
.56685 .36224 m .57753 .3874 L .6026 .38347 L p
1 g
F P
s
P
p
.002 w
.39983 .49996 m .43395 .52605 L .44455 .50347 L p
1 g
F P
s
P
p
.002 w
.44455 .50347 m .41643 .48189 L .39983 .49996 L p
1 g
F P
s
P
p
.002 w
.55841 .52636 m .59274 .50053 L .5756 .4824 L p
1 g
F P
s
P
p
.002 w
.59554 .4531 m .5756 .4824 L .59274 .50053 L p
1 g
F P
s
P
p
.002 w
.40519 .34961 m .39076 .38244 L .4152 .38662 L p
1 g
F P
s
P
p
.002 w
.4152 .38662 m .42631 .36151 L .40519 .34961 L p
1 g
F P
s
P
p
.002 w
.6026 .38347 m .58875 .35061 L .56685 .36224 L p
1 g
F P
s
P
p
.002 w
.54843 .34188 m .56685 .36224 L .58875 .35061 L p
1 g
F P
s
P
p
.002 w
.37597 .46421 m .39983 .49996 L .41643 .48189 L p
1 g
F P
s
P
p
.002 w
.41643 .48189 m .39682 .45236 L .37597 .46421 L p
1 g
F P
s
P
p
.002 w
.59274 .50053 m .61696 .46506 L .59554 .4531 L p
1 g
F P
s
P
p
.002 w
.60491 .41891 m .59554 .4531 L .61696 .46506 L p
1 g
F P
s
P
p
.002 w
.42972 .32317 m .40519 .34961 L .42631 .36151 L p
1 g
F P
s
P
p
.002 w
.42631 .36151 m .44511 .3413 L .42972 .32317 L p
1 g
F P
s
P
p
.002 w
.58875 .35061 m .56475 .32396 L .54843 .34188 L p
1 g
F P
s
P
p
.002 w
.52425 .32858 m .54843 .34188 L .56475 .32396 L p
1 g
F P
s
P
p
.002 w
.46166 .3061 m .42972 .32317 L .44511 .3413 L p
1 g
F P
s
P
p
.002 w
.44511 .3413 m .46955 .32826 L .46166 .3061 L p
1 g
F P
s
P
p
.002 w
.56475 .32396 m .53317 .30654 L .52425 .32858 L p
1 g
F P
s
P
p
.002 w
.49695 .32386 m .52425 .32858 L .53317 .30654 L p
1 g
F P
s
P
p
.002 w
.36505 .42253 m .37597 .46421 L .39682 .45236 L p
1 g
F P
s
P
p
.002 w
.39682 .45236 m .3879 .41798 L .36505 .42253 L p
1 g
F P
s
P
p
.002 w
.61696 .46506 m .62841 .42364 L .60491 .41891 L p
1 g
F P
s
P
p
.002 w
.6026 .38347 m .60491 .41891 L .62841 .42364 L p
1 g
F P
s
P
p
.002 w
.49748 .30034 m .46166 .3061 L .46955 .32826 L p
1 g
F P
s
P
p
.002 w
.46955 .32826 m .49695 .32386 L .49748 .30034 L p
1 g
F P
s
P
p
.002 w
.53317 .30654 m .49748 .30034 L .49695 .32386 L p
1 g
F P
s
P
p
.002 w
.47171 .56264 m .52129 .56274 L .51762 .53992 L p
1 g
F P
s
P
p
.002 w
.51762 .53992 m .47464 .53982 L .47171 .56264 L p
1 g
F P
s
P
p
.002 w
.55841 .52636 m .51762 .53992 L .52129 .56274 L p
1 g
F P
s
P
p
.002 w
.42474 .5468 m .47171 .56264 L .47464 .53982 L p
1 g
F P
s
P
p
.002 w
.47464 .53982 m .43395 .52605 L .42474 .5468 L p
1 g
F P
s
P
p
.002 w
.52129 .56274 m .56834 .54711 L .55841 .52636 L p
1 g
F P
s
P
p
.002 w
.59274 .50053 m .55841 .52636 L .56834 .54711 L p
1 g
F P
s
P
p
.002 w
.36842 .37936 m .36505 .42253 L .3879 .41798 L p
1 g
F P
s
P
p
.002 w
.3879 .41798 m .39076 .38244 L .36842 .37936 L p
1 g
F P
s
P
p
.002 w
.62841 .42364 m .62572 .38063 L .6026 .38347 L p
1 g
F P
s
P
p
.002 w
.58875 .35061 m .6026 .38347 L .62572 .38063 L p
1 g
F P
s
P
p
.002 w
.38532 .51676 m .42474 .5468 L .43395 .52605 L p
1 g
F P
s
P
p
.002 w
.43395 .52605 m .39983 .49996 L .38532 .51676 L p
1 g
F P
s
P
p
.002 w
.56834 .54711 m .60798 .51735 L .59274 .50053 L p
1 g
F P
s
P
p
.002 w
.61696 .46506 m .59274 .50053 L .60798 .51735 L p
1 g
F P
s
P
p
.002 w
.38589 .33944 m .36842 .37936 L .39076 .38244 L p
1 g
F P
s
P
p
.002 w
.39076 .38244 m .40519 .34961 L .38589 .33944 L p
1 g
F P
s
P
p
.002 w
.62572 .38063 m .60899 .34069 L .58875 .35061 L p
1 g
F P
s
P
p
.002 w
.56475 .32396 m .58875 .35061 L .60899 .34069 L p
1 g
F P
s
P
p
.002 w
.35768 .47554 m .38532 .51676 L .39983 .49996 L p
1 g
F P
s
P
p
.002 w
.39983 .49996 m .37597 .46421 L .35768 .47554 L p
1 g
F P
s
P
p
.002 w
.60798 .51735 m .636 .47647 L .61696 .46506 L p
1 g
F P
s
P
p
.002 w
.62841 .42364 m .61696 .46506 L .636 .47647 L p
1 g
F P
s
P
p
.002 w
.41567 .30724 m .38589 .33944 L .40519 .34961 L p
1 g
F P
s
P
p
.002 w
.40519 .34961 m .42972 .32317 L .41567 .30724 L p
1 g
F P
s
P
p
.002 w
.60899 .34069 m .57988 .30825 L .56475 .32396 L p
1 g
F P
s
P
p
.002 w
.53317 .30654 m .56475 .32396 L .57988 .30825 L p
1 g
F P
s
P
p
.002 w
.45452 .28645 m .41567 .30724 L .42972 .32317 L p
1 g
F P
s
P
p
.002 w
.42972 .32317 m .46166 .3061 L .45452 .28645 L p
1 g
F P
s
P
p
.002 w
.57988 .30825 m .54151 .28701 L .53317 .30654 L p
1 g
F P
s
P
p
.002 w
.49748 .30034 m .53317 .30654 L .54151 .28701 L p
1 g
F P
s
P
p
.002 w
.34496 .42741 m .35768 .47554 L .37597 .46421 L p
1 g
F P
s
P
p
.002 w
.37597 .46421 m .36505 .42253 L .34496 .42741 L p
1 g
F P
s
P
p
.002 w
.636 .47647 m .64932 .42867 L .62841 .42364 L p
1 g
F P
s
P
p
.002 w
.62572 .38063 m .62841 .42364 L .64932 .42867 L p
1 g
F P
s
P
p
.002 w
.4981 .27944 m .45452 .28645 L .46166 .3061 L p
1 g
F P
s
P
p
.002 w
.46166 .3061 m .49748 .30034 L .4981 .27944 L p
1 g
F P
s
P
p
.002 w
.54151 .28701 m .4981 .27944 L .49748 .30034 L p
1 g
F P
s
P
p
.002 w
.4694 .58279 m .52452 .58287 L .52129 .56274 L p
1 g
F P
s
P
p
.002 w
.52129 .56274 m .47171 .56264 L .4694 .58279 L p
1 g
F P
s
P
p
.002 w
.56834 .54711 m .52129 .56274 L .52452 .58287 L p
1 g
F P
s
P
p
.002 w
.41717 .56523 m .4694 .58279 L .47171 .56264 L p
1 g
F P
s
P
p
.002 w
.47171 .56264 m .42474 .5468 L .41717 .56523 L p
1 g
F P
s
P
p
.002 w
.52452 .58287 m .57683 .56552 L .56834 .54711 L p
1 g
F P
s
P
p
.002 w
.60798 .51735 m .56834 .54711 L .57683 .56552 L p
1 g
F P
s
P
p
.002 w
.34876 .37749 m .34496 .42741 L .36505 .42253 L p
1 g
F P
s
P
p
.002 w
.36505 .42253 m .36842 .37936 L .34876 .37749 L p
1 g
F P
s
P
p
.002 w
.64932 .42867 m .64631 .37897 L .62572 .38063 L p
1 g
F P
s
P
p
.002 w
.60899 .34069 m .62572 .38063 L .64631 .37897 L p
1 g
F P
s
P
p
.002 w
.37328 .53189 m .41717 .56523 L .42474 .5468 L p
1 g
F P
s
P
p
.002 w
.42474 .5468 m .38532 .51676 L .37328 .53189 L p
1 g
F P
s
P
p
.002 w
.57683 .56552 m .62093 .53248 L .60798 .51735 L p
1 g
F P
s
P
p
.002 w
.636 .47647 m .60798 .51735 L .62093 .53248 L p
1 g
F P
s
P
p
.002 w
.3689 .33127 m .34876 .37749 L .36842 .37936 L p
1 g
F P
s
P
p
.002 w
.36842 .37936 m .38589 .33944 L .3689 .33127 L p
1 g
F P
s
P
p
.002 w
.64631 .37897 m .62706 .33275 L .60899 .34069 L p
1 g
F P
s
P
p
.002 w
.57988 .30825 m .60899 .34069 L .62706 .33275 L p
1 g
F P
s
P
p
.002 w
.34246 .48608 m .37328 .53189 L .38532 .51676 L p
1 g
F P
s
P
p
.002 w
.38532 .51676 m .35768 .47554 L .34246 .48608 L p
1 g
F P
s
P
p
.002 w
.62093 .53248 m .65216 .48706 L .636 .47647 L p
1 g
F P
s
P
p
.002 w
.64932 .42867 m .636 .47647 L .65216 .48706 L p
1 g
F P
s
P
p
.002 w
.40333 .29397 m .3689 .33127 L .38589 .33944 L p
1 g
F P
s
P
p
.002 w
.38589 .33944 m .41567 .30724 L .40333 .29397 L p
1 g
F P
s
P
p
.002 w
.62706 .33275 m .59345 .29518 L .57988 .30825 L p
1 g
F P
s
P
p
.002 w
.54151 .28701 m .57988 .30825 L .59345 .29518 L p
1 g
F P
s
P
p
.002 w
.32821 .43254 m .34246 .48608 L .35768 .47554 L p
1 g
F P
s
P
p
.002 w
.35768 .47554 m .34496 .42741 L .32821 .43254 L p
1 g
F P
s
P
p
.002 w
.65216 .48706 m .66707 .43391 L .64932 .42867 L p
1 g
F P
s
P
p
.002 w
.64631 .37897 m .64932 .42867 L .66707 .43391 L p
1 g
F P
s
P
p
.002 w
.44831 .26986 m .40333 .29397 L .41567 .30724 L p
1 g
F P
s
P
p
.002 w
.41567 .30724 m .45452 .28645 L .44831 .26986 L p
1 g
F P
s
P
p
.002 w
.59345 .29518 m .54906 .27054 L .54151 .28701 L p
1 g
F P
s
P
p
.002 w
.4981 .27944 m .54151 .28701 L .54906 .27054 L p
1 g
F P
s
P
p
.002 w
.49879 .26174 m .44831 .26986 L .45452 .28645 L p
1 g
F P
s
P
p
.002 w
.45452 .28645 m .4981 .27944 L .49879 .26174 L p
1 g
F P
s
P
p
.002 w
.54906 .27054 m .49879 .26174 L .4981 .27944 L p
1 g
F P
s
P
p
.002 w
.46781 .59968 m .52722 .59976 L .52452 .58287 L p
1 g
F P
s
P
p
.002 w
.52452 .58287 m .4694 .58279 L .46781 .59968 L p
1 g
F P
s
P
p
.002 w
.57683 .56552 m .52452 .58287 L .52722 .59976 L p
1 g
F P
s
P
p
.002 w
.33235 .37694 m .32821 .43254 L .34496 .42741 L p
1 g
F P
s
P
p
.002 w
.34496 .42741 m .34876 .37749 L .33235 .37694 L p
1 g
F P
s
P
p
.002 w
.66707 .43391 m .66382 .37859 L .64631 .37897 L p
1 g
F P
s
P
p
.002 w
.62706 .33275 m .64631 .37897 L .66382 .37859 L p
1 g
F P
s
P
p
.002 w
.41149 .5808 m .46781 .59968 L .4694 .58279 L p
1 g
F P
s
P
p
.002 w
.4694 .58279 m .41717 .56523 L .41149 .5808 L p
1 g
F P
s
P
p
.002 w
.52722 .59976 m .58362 .58107 L .57683 .56552 L p
1 g
F P
s
P
p
.002 w
.62093 .53248 m .57683 .56552 L .58362 .58107 L p
1 g
F P
s
P
p
.002 w
.36413 .5449 m .41149 .5808 L .41717 .56523 L p
1 g
F P
s
P
p
.002 w
.41717 .56523 m .37328 .53189 L .36413 .5449 L p
1 g
F P
s
P
p
.002 w
.58362 .58107 m .63119 .54549 L .62093 .53248 L p
1 g
F P
s
P
p
.002 w
.65216 .48706 m .62093 .53248 L .63119 .54549 L p
1 g
F P
s
P
p
.002 w
.35472 .32541 m .33235 .37694 L .34876 .37749 L p
1 g
F P
s
P
p
.002 w
.34876 .37749 m .3689 .33127 L .35472 .32541 L p
1 g
F P
s
P
p
.002 w
.66382 .37859 m .64246 .32709 L .62706 .33275 L p
1 g
F P
s
P
p
.002 w
.59345 .29518 m .62706 .33275 L .64246 .32709 L p
1 g
F P
s
P
p
.002 w
.33082 .49556 m .36413 .5449 L .37328 .53189 L p
1 g
F P
s
P
p
.002 w
.37328 .53189 m .34246 .48608 L .33082 .49556 L p
1 g
F P
s
P
p
.002 w
.63119 .54549 m .66492 .49656 L .65216 .48706 L p
1 g
F P
s
P
p
.002 w
.66707 .43391 m .65216 .48706 L .66492 .49656 L p
1 g
F P
s
P
p
.002 w
.39307 .28379 m .35472 .32541 L .3689 .33127 L p
1 g
F P
s
P
p
.002 w
.3689 .33127 m .40333 .29397 L .39307 .28379 L p
1 g
F P
s
P
p
.002 w
.64246 .32709 m .60507 .28517 L .59345 .29518 L p
1 g
F P
s
P
p
.002 w
.54906 .27054 m .59345 .29518 L .60507 .28517 L p
1 g
F P
s
P
p
.002 w
.31536 .43781 m .33082 .49556 L .34246 .48608 L p
1 g
F P
s
P
p
.002 w
.34246 .48608 m .32821 .43254 L .31536 .43781 L p
1 g
F P
s
P
p
.002 w
.66492 .49656 m .68108 .43926 L .66707 .43391 L p
1 g
F P
s
P
p
.002 w
.66382 .37859 m .66707 .43391 L .68108 .43926 L p
1 g
F P
s
P
p
.002 w
.44322 .25687 m .39307 .28379 L .40333 .29397 L p
1 g
F P
s
P
p
.002 w
.40333 .29397 m .44831 .26986 L .44322 .25687 L p
1 g
F P
s
P
p
.002 w
.60507 .28517 m .5556 .25766 L .54906 .27054 L p
1 g
F P
s
P
p
.002 w
.49879 .26174 m .54906 .27054 L .5556 .25766 L p
1 g
F P
s
P
p
.002 w
.49953 .24782 m .44322 .25687 L .44831 .26986 L p
1 g
F P
s
P
p
.002 w
.44831 .26986 m .49879 .26174 L .49953 .24782 L p
1 g
F P
s
P
p
.002 w
.5556 .25766 m .49953 .24782 L .49879 .26174 L p
1 g
F P
s
P
p
.002 w
.46701 .61275 m .52932 .61282 L .52722 .59976 L p
1 g
F P
s
P
p
.002 w
.52722 .59976 m .46781 .59968 L .46701 .61275 L p
1 g
F P
s
P
p
.002 w
.58362 .58107 m .52722 .59976 L .52932 .61282 L p
1 g
F P
s
P
p
.002 w
.31975 .3778 m .31536 .43781 L .32821 .43254 L p
1 g
F P
s
P
p
.002 w
.32821 .43254 m .33235 .37694 L .31975 .3778 L p
1 g
F P
s
P
p
.002 w
.68108 .43926 m .67766 .37957 L .66382 .37859 L p
1 g
F P
s
P
p
.002 w
.64246 .32709 m .66382 .37859 L .67766 .37957 L p
1 g
F P
s
P
p
.002 w
.40794 .59298 m .46701 .61275 L .46781 .59968 L p
1 g
F P
s
P
p
.002 w
.46781 .59968 m .41149 .5808 L .40794 .59298 L p
1 g
F P
s
P
p
.002 w
.52932 .61282 m .58846 .59323 L .58362 .58107 L p
1 g
F P
s
P
p
.002 w
.63119 .54549 m .58362 .58107 L .58846 .59323 L p
1 g
F P
s
P
p
.002 w
.35824 .55538 m .40794 .59298 L .41149 .5808 L p
1 g
F P
s
P
p
.002 w
.41149 .5808 m .36413 .5449 L .35824 .55538 L p
1 g
F P
s
P
p
.002 w
.58846 .59323 m .63836 .55595 L .63119 .54549 L p
1 g
F P
s
P
p
.002 w
.66492 .49656 m .63119 .54549 L .63836 .55595 L p
1 g
F P
s
P
p
.002 w
.34385 .32213 m .31975 .3778 L .33235 .37694 L p
1 g
F P
s
P
p
.002 w
.33235 .37694 m .35472 .32541 L .34385 .32213 L p
1 g
F P
s
P
p
.002 w
.67766 .37957 m .65468 .32396 L .64246 .32709 L p
1 g
F P
s
P
p
.002 w
.60507 .28517 m .64246 .32709 L .65468 .32396 L p
1 g
F P
s
P
p
.002 w
.32325 .50366 m .35824 .55538 L .36413 .5449 L p
1 g
F P
s
P
p
.002 w
.36413 .5449 m .33082 .49556 L .32325 .50366 L p
1 g
F P
s
P
p
.002 w
.63836 .55595 m .67378 .50467 L .66492 .49656 L p
1 g
F P
s
P
p
.002 w
.68108 .43926 m .66492 .49656 L .67378 .50467 L p
1 g
F P
s
P
p
.002 w
.38526 .27713 m .34385 .32213 L .35472 .32541 L p
1 g
F P
s
P
p
.002 w
.35472 .32541 m .39307 .28379 L .38526 .27713 L p
1 g
F P
s
P
p
.002 w
.65468 .32396 m .61434 .27865 L .60507 .28517 L p
1 g
F P
s
P
p
.002 w
.5556 .25766 m .60507 .28517 L .61434 .27865 L p
1 g
F P
s
P
p
.002 w
.30698 .4431 m .32325 .50366 L .33082 .49556 L p
1 g
F P
s
P
p
.002 w
.33082 .49556 m .31536 .43781 L .30698 .4431 L p
1 g
F P
s
P
p
.002 w
.67378 .50467 m .6908 .44459 L .68108 .43926 L p
1 g
F P
s
P
p
.002 w
.67766 .37957 m .68108 .43926 L .6908 .44459 L p
1 g
F P
s
P
p
.002 w
.43945 .24803 m .38526 .27713 L .39307 .28379 L p
1 g
F P
s
P
p
.002 w
.39307 .28379 m .44322 .25687 L .43945 .24803 L p
1 g
F P
s
P
p
.002 w
.61434 .27865 m .56091 .24889 L .5556 .25766 L p
1 g
F P
s
P
p
.002 w
.49953 .24782 m .5556 .25766 L .56091 .24889 L p
1 g
F P
s
P
p
.002 w
.50032 .23824 m .43945 .24803 L .44322 .25687 L p
1 g
F P
s
P
p
.002 w
.44322 .25687 m .49953 .24782 L .50032 .23824 L p
1 g
F P
s
P
p
.002 w
.56091 .24889 m .50032 .23824 L .49953 .24782 L p
1 g
F P
s
P
p
.002 w
.46707 .62143 m .5307 .62149 L .52932 .61282 L p
1 g
F P
s
P
p
.002 w
.52932 .61282 m .46701 .61275 L .46707 .62143 L p
1 g
F P
s
P
p
.002 w
.58846 .59323 m .52932 .61282 L .5307 .62149 L p
1 g
F P
s
P
p
.002 w
.31153 .38013 m .30698 .4431 L .31536 .43781 L p
1 g
F P
s
P
p
.002 w
.31536 .43781 m .31975 .3778 L .31153 .38013 L p
1 g
F P
s
P
p
.002 w
.6908 .44459 m .68727 .38197 L .67766 .37957 L p
1 g
F P
s
P
p
.002 w
.65468 .32396 m .67766 .37957 L .68727 .38197 L p
1 g
F P
s
P
p
.002 w
.40674 .60127 m .46707 .62143 L .46701 .61275 L p
1 g
F P
s
P
p
.002 w
.46701 .61275 m .40794 .59298 L .40674 .60127 L p
1 g
F P
s
P
p
.002 w
.5307 .62149 m .59111 .6015 L .58846 .59323 L p
1 g
F P
s
P
p
.002 w
.63836 .55595 m .58846 .59323 L .59111 .6015 L p
1 g
F P
s
P
p
.002 w
.35596 .5629 m .40674 .60127 L .40794 .59298 L p
1 g
F P
s
P
p
.002 w
.40794 .59298 m .35824 .55538 L .35596 .5629 L p
1 g
F P
s
P
p
.002 w
.59111 .6015 m .64209 .56345 L .63836 .55595 L p
1 g
F P
s
P
p
.002 w
.67378 .50467 m .63836 .55595 L .64209 .56345 L p
1 g
F P
s
P
p
.002 w
.3368 .32168 m .31153 .38013 L .31975 .3778 L p
1 g
F P
s
P
p
.002 w
.31975 .3778 m .34385 .32213 L .3368 .32168 L p
1 g
F P
s
P
p
.002 w
.68727 .38197 m .6632 .3236 L .65468 .32396 L p
1 g
F P
s
P
p
.002 w
.61434 .27865 m .65468 .32396 L .6632 .3236 L p
1 g
F P
s
P
p
.002 w
.32021 .51011 m .35596 .5629 L .35824 .55538 L p
1 g
F P
s
P
p
.002 w
.35824 .55538 m .32325 .50366 L .32021 .51011 L p
1 g
F P
s
P
p
.002 w
.64209 .56345 m .67828 .5111 L .67378 .50467 L p
1 g
F P
s
P
p
.002 w
.6908 .44459 m .67378 .50467 L .67828 .5111 L p
1 g
F P
s
P
p
.002 w
.38026 .2744 m .3368 .32168 L .34385 .32213 L p
1 g
F P
s
P
p
.002 w
.34385 .32213 m .38526 .27713 L .38026 .2744 L p
1 g
F P
s
P
p
.002 w
.6632 .3236 m .62088 .27601 L .61434 .27865 L p
1 g
F P
s
P
p
.002 w
.56091 .24889 m .61434 .27865 L .62088 .27601 L p
1 g
F P
s
P
p
.002 w
.30356 .44828 m .32021 .51011 L .32325 .50366 L p
1 g
F P
s
P
p
.002 w
.32325 .50366 m .30698 .4431 L .30356 .44828 L p
1 g
F P
s
P
p
.002 w
.67828 .5111 m .69569 .44976 L .6908 .44459 L p
1 g
F P
s
P
p
.002 w
.68727 .38197 m .6908 .44459 L .69569 .44976 L p
1 g
F P
s
P
p
.002 w
.43719 .24382 m .38026 .2744 L .38526 .27713 L p
1 g
F P
s
P
p
.002 w
.38526 .27713 m .43945 .24803 L .43719 .24382 L p
1 g
F P
s
P
p
.002 w
.62088 .27601 m .56478 .24474 L .56091 .24889 L p
1 g
F P
s
P
p
.002 w
.50032 .23824 m .56091 .24889 L .56478 .24474 L p
1 g
F P
s
P
p
.002 w
.50114 .23354 m .43719 .24382 L .43945 .24803 L p
1 g
F P
s
P
p
.002 w
.43945 .24803 m .50032 .23824 L .50114 .23354 L p
1 g
F P
s
P
p
.002 w
.56478 .24474 m .50114 .23354 L .50032 .23824 L p
1 g
F P
s
P
p
.002 w
.46805 .62522 m .5313 .62527 L .5307 .62149 L p
1 g
F P
s
P
p
.002 w
.5307 .62149 m .46707 .62143 L .46805 .62522 L p
1 g
F P
s
P
p
.002 w
.59111 .6015 m .5307 .62149 L .5313 .62527 L p
1 g
F P
s
P
p
.002 w
.30819 .38396 m .30356 .44828 L .30698 .4431 L p
1 g
F P
s
P
p
.002 w
.30698 .4431 m .31153 .38013 L .30819 .38396 L p
1 g
F P
s
P
p
.002 w
.69569 .44976 m .69212 .38582 L .68727 .38197 L p
1 g
F P
s
P
p
.002 w
.6632 .3236 m .68727 .38197 L .69212 .38582 L p
1 g
F P
s
P
p
.002 w
.40807 .60518 m .46805 .62522 L .46707 .62143 L p
1 g
F P
s
P
p
.002 w
.46707 .62143 m .40674 .60127 L .40807 .60518 L p
1 g
F P
s
P
p
.002 w
.5313 .62527 m .59135 .6054 L .59111 .6015 L p
1 g
F P
s
P
p
.002 w
.64209 .56345 m .59111 .6015 L .59135 .6054 L p
1 g
F P
s
P
p
.002 w
.3576 .56706 m .40807 .60518 L .40674 .60127 L p
1 g
F P
s
P
p
.002 w
.40674 .60127 m .35596 .5629 L .3576 .56706 L p
1 g
F P
s
P
p
.002 w
.59135 .6054 m .64203 .56758 L .64209 .56345 L p
1 g
F P
s
P
p
.002 w
.67828 .5111 m .64209 .56345 L .64203 .56758 L p
1 g
F P
s
P
p
.002 w
.334 .32424 m .30819 .38396 L .31153 .38013 L p
1 g
F P
s
P
p
.002 w
.31153 .38013 m .3368 .32168 L .334 .32424 L p
1 g
F P
s
P
p
.002 w
.69212 .38582 m .66755 .32619 L .6632 .3236 L p
1 g
F P
s
P
p
.002 w
.62088 .27601 m .6632 .3236 L .66755 .32619 L p
1 g
F P
s
P
p
.002 w
.32207 .51461 m .3576 .56706 L .35596 .5629 L p
1 g
F P
s
P
p
.002 w
.35596 .5629 m .32021 .51011 L .32207 .51461 L p
1 g
F P
s
P
p
.002 w
.64203 .56758 m .67801 .51557 L .67828 .5111 L p
1 g
F P
s
P
p
.002 w
.69569 .44976 m .67828 .5111 L .67801 .51557 L p
1 g
F P
s
P
p
.004 w
.28134 .44604 m
.29074 .44537 L
s
P
p
.004 w
.23534 .4493 m
.28134 .44604 L
s
P
p
.002 w
.37841 .27593 m .334 .32424 L .3368 .32168 L p
1 g
F P
s
P
p
.002 w
.3368 .32168 m .38026 .2744 L .37841 .27593 L p
1 g
F P
s
P
p
.002 w
.66755 .32619 m .62432 .27757 L .62088 .27601 L p
1 g
F P
s
P
p
.002 w
.56478 .24474 m .62088 .27601 L .62432 .27757 L p
1 g
F P
s
P
p
.002 w
.30553 .45318 m .32207 .51461 L .32021 .51011 L p
1 g
F P
s
P
p
.002 w
.32021 .51011 m .30356 .44828 L .30553 .45318 L p
1 g
F P
s
P
p
.002 w
.67801 .51557 m .69531 .45462 L .69569 .44976 L p
1 g
F P
s
P
p
.002 w
.69212 .38582 m .69569 .44976 L .69531 .45462 L p
1 g
F P
s
P
p
.002 w
.43659 .24468 m .37841 .27593 L .38026 .2744 L p
1 g
F P
s
P
p
.002 w
.38026 .2744 m .43719 .24382 L .43659 .24468 L p
1 g
F P
s
P
p
.002 w
.62432 .27757 m .567 .24561 L .56478 .24474 L p
1 g
F P
s
P
p
.002 w
.50114 .23354 m .56478 .24474 L .567 .24561 L p
1 g
F P
s
P
p
.002 w
.50195 .23417 m .43659 .24468 L .43719 .24382 L p
1 g
F P
s
P
p
.002 w
.43719 .24382 m .50114 .23354 L .50195 .23417 L p
1 g
F P
s
P
p
.002 w
.567 .24561 m .50195 .23417 L .50114 .23354 L p
1 g
F P
s
P
p
.002 w
.31015 .38928 m .30553 .45318 L .30356 .44828 L p
1 g
F P
s
P
p
.002 w
.30356 .44828 m .30819 .38396 L .31015 .38928 L p
1 g
F P
s
P
p
.002 w
.69531 .45462 m .69176 .3911 L .69212 .38582 L p
1 g
F P
s
P
p
.002 w
.66755 .32619 m .69212 .38582 L .69176 .3911 L p
1 g
F P
s
P
p
.002 w
.46997 .62366 m .53104 .62372 L .5313 .62527 L p
1 g
F P
s
P
p
.002 w
.5313 .62527 m .46805 .62522 L .46997 .62366 L p
1 g
F P
s
P
p
.002 w
.59135 .6054 m .5313 .62527 L .53104 .62372 L p
1 g
F P
s
P
p
.002 w
.41207 .60432 m .46997 .62366 L .46805 .62522 L p
1 g
F P
s
P
p
.002 w
.46805 .62522 m .40807 .60518 L .41207 .60432 L p
1 g
F P
s
P
p
.002 w
.53104 .62372 m .58902 .60453 L .59135 .6054 L p
1 g
F P
s
P
p
.002 w
.64203 .56758 m .59135 .6054 L .58902 .60453 L p
1 g
F P
s
P
p
.002 w
.36337 .56752 m .41207 .60432 L .40807 .60518 L p
1 g
F P
s
P
p
.002 w
.40807 .60518 m .3576 .56706 L .36337 .56752 L p
1 g
F P
s
P
p
.002 w
.58902 .60453 m .63794 .56802 L .64203 .56758 L p
1 g
F P
s
P
p
.002 w
.67801 .51557 m .64203 .56758 L .63794 .56802 L p
1 g
F P
s
P
p
.002 w
.33581 .32995 m .31015 .38928 L .30819 .38396 L p
1 g
F P
s
P
p
.002 w
.30819 .38396 m .334 .32424 L .33581 .32995 L p
1 g
F P
s
P
p
.002 w
.69176 .3911 m .66734 .33186 L .66755 .32619 L p
1 g
F P
s
P
p
.002 w
.62432 .27757 m .66755 .32619 L .66734 .33186 L p
1 g
F P
s
P
p
.002 w
.32911 .5169 m .36337 .56752 L .3576 .56706 L p
1 g
F P
s
P
p
.002 w
.3576 .56706 m .32207 .51461 L .32911 .5169 L p
1 g
F P
s
P
p
.002 w
.63794 .56802 m .67266 .51781 L .67801 .51557 L p
1 g
F P
s
P
p
.002 w
.69531 .45462 m .67801 .51557 L .67266 .51781 L p
1 g
F P
s
P
p
.002 w
.37996 .28196 m .33581 .32995 L .334 .32424 L p
1 g
F P
s
P
p
.002 w
.334 .32424 m .37841 .27593 L .37996 .28196 L p
1 g
F P
s
P
p
.002 w
.66734 .33186 m .62437 .28356 L .62432 .27757 L p
1 g
F P
s
P
p
.002 w
.567 .24561 m .62432 .27757 L .62437 .28356 L p
1 g
F P
s
P
p
.002 w
.3132 .45764 m .32911 .5169 L .32207 .51461 L p
1 g
F P
s
P
p
.002 w
.32207 .51461 m .30553 .45318 L .3132 .45764 L p
1 g
F P
s
P
p
.002 w
.67266 .51781 m .68932 .459 L .69531 .45462 L p
1 g
F P
s
P
p
.002 w
.69176 .3911 m .69531 .45462 L .68932 .459 L p
1 g
F P
s
P
p
.002 w
.43779 .25091 m .37996 .28196 L .37841 .27593 L p
1 g
F P
s
P
p
.002 w
.37841 .27593 m .43659 .24468 L .43779 .25091 L p
1 g
F P
s
P
p
.002 w
.62437 .28356 m .5674 .25183 L .567 .24561 L p
1 g
F P
s
P
p
.002 w
.50195 .23417 m .567 .24561 L .5674 .25183 L p
1 g
F P
s
P
p
.002 w
.50275 .24047 m .43779 .25091 L .43659 .24468 L p
1 g
F P
s
P
p
.002 w
.43659 .24468 m .50195 .23417 L .50275 .24047 L p
1 g
F P
s
P
p
.002 w
.5674 .25183 m .50275 .24047 L .50195 .23417 L p
1 g
F P
s
P
p
.002 w
.3177 .39603 m .3132 .45764 L .30553 .45318 L p
1 g
F P
s
P
p
.002 w
.30553 .45318 m .31015 .38928 L .3177 .39603 L p
1 g
F P
s
P
p
.004 w
.29074 .44537 m
.31243 .44383 L
s
P
p
.002 w
.68932 .459 m .68586 .39774 L .69176 .3911 L p
1 g
F P
s
P
p
.002 w
.66734 .33186 m .69176 .3911 L .68586 .39774 L p
1 g
F P
s
P
p
.002 w
.47284 .61647 m .52988 .61652 L .53104 .62372 L p
1 g
F P
s
P
p
.002 w
.53104 .62372 m .46997 .62366 L .47284 .61647 L p
1 g
F P
s
P
p
.002 w
.58902 .60453 m .53104 .62372 L .52988 .61652 L p
1 g
F P
s
P
p
.002 w
.41879 .59838 m .47284 .61647 L .46997 .62366 L p
1 g
F P
s
P
p
.002 w
.46997 .62366 m .41207 .60432 L .41879 .59838 L p
1 g
F P
s
P
p
.002 w
.52988 .61652 m .58402 .5986 L .58902 .60453 L p
1 g
F P
s
P
p
.002 w
.63794 .56802 m .58902 .60453 L .58402 .5986 L p
1 g
F P
s
P
p
.002 w
.37336 .56401 m .41879 .59838 L .41207 .60432 L p
1 g
F P
s
P
p
.002 w
.41207 .60432 m .36337 .56752 L .37336 .56401 L p
1 g
F P
s
P
p
.002 w
.58402 .5986 m .62969 .56449 L .63794 .56802 L p
1 g
F P
s
P
p
.002 w
.67266 .51781 m .63794 .56802 L .62969 .56449 L p
1 g
F P
s
P
p
.002 w
.34249 .33885 m .3177 .39603 L .31015 .38928 L p
1 g
F P
s
P
p
.002 w
.31015 .38928 m .33581 .32995 L .34249 .33885 L p
1 g
F P
s
P
p
.002 w
.68586 .39774 m .66227 .34064 L .66734 .33186 L p
1 g
F P
s
P
p
.002 w
.62437 .28356 m .66734 .33186 L .66227 .34064 L p
1 g
F P
s
P
p
.002 w
.34145 .51676 m .37336 .56401 L .36337 .56752 L p
1 g
F P
s
P
p
.002 w
.36337 .56752 m .32911 .5169 L .34145 .51676 L p
1 g
F P
s
P
p
.002 w
.62969 .56449 m .66205 .51761 L .67266 .51781 L p
1 g
F P
s
P
p
.002 w
.68932 .459 m .67266 .51781 L .66205 .51761 L p
1 g
F P
s
P
p
.002 w
.38509 .2926 m .34249 .33885 L .33581 .32995 L p
1 g
F P
s
P
p
.002 w
.33581 .32995 m .37996 .28196 L .38509 .2926 L p
1 g
F P
s
P
p
.002 w
.66227 .34064 m .6208 .29411 L .62437 .28356 L p
1 g
F P
s
P
p
.002 w
.5674 .25183 m .62437 .28356 L .6208 .29411 L p
1 g
F P
s
P
p
.002 w
.32668 .46149 m .34145 .51676 L .32911 .5169 L p
1 g
F P
s
P
p
.002 w
.32911 .5169 m .3132 .45764 L .32668 .46149 L p
1 g
F P
s
P
p
.002 w
.66205 .51761 m .67755 .46274 L .68932 .459 L p
1 g
F P
s
P
p
.002 w
.68586 .39774 m .68932 .459 L .67755 .46274 L p
1 g
F P
s
P
p
.002 w
.44086 .26269 m .38509 .2926 L .37996 .28196 L p
1 g
F P
s
P
p
.002 w
.37996 .28196 m .43779 .25091 L .44086 .26269 L p
1 g
F P
s
P
p
.002 w
.6208 .29411 m .56585 .26355 L .5674 .25183 L p
1 g
F P
s
P
p
.002 w
.50275 .24047 m .5674 .25183 L .56585 .26355 L p
1 g
F P
s
P
p
.002 w
.5035 .25262 m .44086 .26269 L .43779 .25091 L p
1 g
F P
s
P
p
.002 w
.43779 .25091 m .50275 .24047 L .5035 .25262 L p
1 g
F P
s
P
p
.002 w
.56585 .26355 m .5035 .25262 L .50275 .24047 L p
1 g
F P
s
P
p
.002 w
.33096 .40407 m .32668 .46149 L .3132 .45764 L p
1 g
F P
s
P
p
.002 w
.3132 .45764 m .3177 .39603 L .33096 .40407 L p
1 g
F P
s
P
p
.004 w
.31243 .44383 m
.32532 .44291 L
s
P
p
.002 w
.67755 .46274 m .67424 .40562 L .68586 .39774 L p
1 g
F P
s
P
p
.002 w
.66227 .34064 m .68586 .39774 L .67424 .40562 L p
1 g
F P
s
P
p
.002 w
.47663 .60348 m .52778 .60355 L .52988 .61652 L p
1 g
F P
s
P
p
.002 w
.52988 .61652 m .47284 .61647 L .47663 .60348 L p
1 g
F P
s
P
p
.002 w
.58402 .5986 m .52988 .61652 L .52778 .60355 L p
1 g
F P
s
P
p
.002 w
.42819 .58724 m .47663 .60348 L .47284 .61647 L p
1 g
F P
s
P
p
.002 w
.47284 .61647 m .41879 .59838 L .42819 .58724 L p
1 g
F P
s
P
p
.002 w
.52778 .60355 m .57633 .58746 L .58402 .5986 L p
1 g
F P
s
P
p
.002 w
.62969 .56449 m .58402 .5986 L .57633 .58746 L p
1 g
F P
s
P
p
.002 w
.38752 .5564 m .42819 .58724 L .41879 .59838 L p
1 g
F P
s
P
p
.002 w
.41879 .59838 m .37336 .56401 L .38752 .5564 L p
1 g
F P
s
P
p
.002 w
.57633 .58746 m .61725 .55686 L .62969 .56449 L p
1 g
F P
s
P
p
.002 w
.66205 .51761 m .62969 .56449 L .61725 .55686 L p
1 g
F P
s
P
p
.002 w
.35413 .35083 m .33096 .40407 L .3177 .39603 L p
1 g
F P
s
P
p
.002 w
.3177 .39603 m .34249 .33885 L .35413 .35083 L p
1 g
F P
s
P
p
.002 w
.67424 .40562 m .65218 .35244 L .66227 .34064 L p
1 g
F P
s
P
p
.002 w
.6208 .29411 m .66227 .34064 L .65218 .35244 L p
1 g
F P
s
P
p
.002 w
.35901 .51405 m .38752 .5564 L .37336 .56401 L p
1 g
F P
s
P
p
.002 w
.37336 .56401 m .34145 .51676 L .35901 .51405 L p
1 g
F P
s
P
p
.002 w
.61725 .55686 m .6462 .51482 L .66205 .51761 L p
1 g
F P
s
P
p
.002 w
.67755 .46274 m .66205 .51761 L .6462 .51482 L p
1 g
F P
s
P
p
.002 w
.39386 .30779 m .35413 .35083 L .34249 .33885 L p
1 g
F P
s
P
p
.002 w
.34249 .33885 m .38509 .2926 L .39386 .30779 L p
1 g
F P
s
P
p
.002 w
.65218 .35244 m .61349 .30913 L .6208 .29411 L p
1 g
F P
s
P
p
.002 w
.56585 .26355 m .6208 .29411 L .61349 .30913 L p
1 g
F P
s
P
p
.002 w
.34588 .46456 m .35901 .51405 L .34145 .51676 L p
1 g
F P
s
P
p
.002 w
.34145 .51676 m .32668 .46149 L .34588 .46456 L p
1 g
F P
s
P
p
.002 w
.6462 .51482 m .66 .46567 L .67755 .46274 L p
1 g
F P
s
P
p
.002 w
.67424 .40562 m .67755 .46274 L .66 .46567 L p
1 g
F P
s
P
p
.002 w
.44583 .27995 m .39386 .30779 L .38509 .2926 L p
1 g
F P
s
P
p
.002 w
.38509 .2926 m .44086 .26269 L .44583 .27995 L p
1 g
F P
s
P
p
.002 w
.61349 .30913 m .56226 .28072 L .56585 .26355 L p
1 g
F P
s
P
p
.002 w
.5035 .25262 m .56585 .26355 L .56226 .28072 L p
1 g
F P
s
P
p
.002 w
.50418 .27057 m .44583 .27995 L .44086 .26269 L p
1 g
F P
s
P
p
.002 w
.44086 .26269 m .5035 .25262 L .50418 .27057 L p
1 g
F P
s
P
p
.002 w
.56226 .28072 m .50418 .27057 L .5035 .25262 L p
1 g
F P
s
P
p
.002 w
.34981 .41322 m .34588 .46456 L .32668 .46149 L p
1 g
F P
s
P
p
.004 w
.34766 .44133 m
.5 .43051 L
s
P
p
.002 w
.32668 .46149 m .33096 .40407 L .34981 .41322 L p
1 g
F P
s
P
p
.004 w
.33187 .44245 m
.33318 .44236 L
s
P
p
.004 w
.32532 .44291 m
.33187 .44245 L
s
P
p
.002 w
.66 .46567 m .65695 .41456 L .67424 .40562 L p
1 g
F P
s
P
p
.002 w
.65218 .35244 m .67424 .40562 L .65695 .41456 L p
1 g
F P
s
P
p
.002 w
.48128 .5848 m .52477 .58487 L .52778 .60355 L p
1 g
F P
s
P
p
.002 w
.52778 .60355 m .47663 .60348 L .48128 .5848 L p
1 g
F P
s
P
p
.002 w
.57633 .58746 m .52778 .60355 L .52477 .58487 L p
1 g
F P
s
P
p
.002 w
.44011 .57096 m .48128 .5848 L .47663 .60348 L p
1 g
F P
s
P
p
.002 w
.47663 .60348 m .42819 .58724 L .44011 .57096 L p
1 g
F P
s
P
p
.002 w
.52477 .58487 m .56605 .57118 L .57633 .58746 L p
1 g
F P
s
P
p
.002 w
.61725 .55686 m .57633 .58746 L .56605 .57118 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.4056 .5447 m .44011 .57096 L .42819 .58724 L p
1 g
F P
s
P
p
.002 w
.42819 .58724 m .38752 .5564 L .4056 .5447 L p
1 g
F P
s
P
p
.002 w
.56605 .57118 m .60081 .54513 L .61725 .55686 L p
1 g
F P
s
P
p
.002 w
.6462 .51482 m .61725 .55686 L .60081 .54513 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.3706 .36566 m .34981 .41322 L .33096 .40407 L p
1 g
F P
s
P
p
.002 w
.33096 .40407 m .35413 .35083 L .3706 .36566 L p
1 g
F P
s
P
p
.002 w
.65695 .41456 m .63713 .36703 L .65218 .35244 L p
1 g
F P
s
P
p
.002 w
.61349 .30913 m .65218 .35244 L .63713 .36703 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.38147 .5087 m .4056 .5447 L .38752 .5564 L p
1 g
F P
s
P
p
.002 w
.38752 .5564 m .35901 .51405 L .38147 .5087 L p
1 g
F P
s
P
p
.002 w
.60081 .54513 m .62535 .50938 L .6462 .51482 L p
1 g
F P
s
P
p
.002 w
.66 .46567 m .6462 .51482 L .62535 .50938 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.40617 .32725 m .3706 .36566 L .35413 .35083 L p
1 g
F P
s
P
p
.002 w
.35413 .35083 m .39386 .30779 L .40617 .32725 L p
1 g
F P
s
P
p
.002 w
.63713 .36703 m .60247 .32839 L .61349 .30913 L p
1 g
F P
s
P
p
.002 w
.56226 .28072 m .61349 .30913 L .60247 .32839 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.37044 .46671 m .38147 .5087 L .35901 .51405 L p
1 g
F P
s
P
p
.002 w
.35901 .51405 m .34588 .46456 L .37044 .46671 L p
1 g
F P
s
P
p
.002 w
.62535 .50938 m .63698 .46764 L .66 .46567 L p
1 g
F P
s
P
p
.002 w
.65695 .41456 m .66 .46567 L .63698 .46764 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.45262 .30241 m .40617 .32725 L .39386 .30779 L p
1 g
F P
s
P
p
.002 w
.39386 .30779 m .44583 .27995 L .45262 .30241 L p
1 g
F P
s
P
p
.002 w
.60247 .32839 m .55666 .30305 L .56226 .28072 L p
1 g
F P
s
P
p
.002 w
.50418 .27057 m .56226 .28072 L .55666 .30305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.50476 .29403 m .45262 .30241 L .44583 .27995 L p
1 g
F P
s
P
p
.002 w
.44583 .27995 m .50418 .27057 L .50476 .29403 L p
1 g
F P
s
P
p
.002 w
.55666 .30305 m .50476 .29403 L .50418 .27057 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.37387 .4232 m .37044 .46671 L .34588 .46456 L p
1 g
F P
s
P
p
.002 w
.34588 .46456 m .34981 .41322 L .37387 .4232 L p
1 g
F P
s
P
p
.002 w
.63698 .46764 m .63429 .4243 L .65695 .41456 L p
1 g
F P
s
P
p
.002 w
.63713 .36703 m .65695 .41456 L .63429 .4243 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58021 L p
1 g
F P
s
P
p
.002 w
.52355 .57729 m .52477 .58487 L p
.51567 .57911 L 1 g
F P
s
P
p
.53128 .57265 m .51091 .58021 L .52115 .57784 L 1 g
F
P
p
.002 w
.52477 .58487 m .5102 .58485 L p
.50573 .58028 L 1 g
F P
s
P
p
.52477 .58487 m .50573 .58028 L .51729 .58014 L 1 g
F
P
p
.002 w
.5102 .58485 m .48128 .5848 L .48223 .58056 L p
1 g
F P
s
P
p
.002 w
.48223 .58056 m .48255 .57913 L p
.48907 .58048 L 1 g
F P
s
P
p
.5102 .58485 m .48223 .58056 L .48907 .58048 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58048 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58048 L .5023 .58032 L 1 g
F
P
p
.002 w
.51091 .58021 m .51079 .57862 L p
.5023 .58032 L 1 g
F P
s
P
p
.002 w
.48907 .58048 m .48921 .57862 L p
.4787 .57776 L 1 g
F P
s
P
p
.002 w
.48255 .57913 m .48128 .5848 L p
.47474 .57635 L 1 g
F P
s
P
p
.002 w
.48128 .5848 m .44011 .57096 L .44387 .56534 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.48128 .5848 m .44387 .56534 L .46841 .57409 L 1 g
F
P
p
.47749 .5799 m .46841 .57409 L .47474 .57635 L 1 g
F
P
p
.48128 .5848 m .46841 .57409 L .47749 .5799 L 1 g
F
P
p
.002 w
.46841 .57409 m .46872 .57265 L p
.46191 .56993 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46841 .57409 L p
1 g
F P
s
P
p
.002 w
.46841 .57409 m .4678 .57686 L p
.4787 .57776 L 1 g
F P
s
P
p
.48921 .57862 m .46841 .57409 L .4787 .57776 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45087 .56287 L p
1 g
F P
s
P
p
.002 w
.44387 .56534 m .44713 .56047 L p
.45087 .56287 L 1 g
F P
s
P
p
.46841 .57409 m .45763 .57025 L .45087 .56287 L 1 g
F
P
p
.45763 .57025 m .44387 .56534 L .45087 .56287 L 1 g
F
P
p
.002 w
.45087 .56287 m .45146 .56129 L p
.44499 .55567 L 1 g
F P
s
P
p
.44011 .57096 m .42831 .53284 L .43859 .54691 L 1 g
F
P
p
.002 w
.44779 .5595 m .44475 .56403 L p
.43859 .54691 L 1 g
F P
s
P
p
.002 w
.44475 .56403 m .44011 .57096 L p
.43859 .54691 L 1 g
F P
s
P
p
.002 w
.43859 .54691 m .43925 .54566 L p
.43539 .53802 L 1 g
F P
s
P
p
.44499 .55567 m .44779 .5595 L .45087 .56287 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43774 .54852 L p
1 g
F P
s
P
p
.45146 .56129 m .43774 .54852 L .44152 .55265 L 1 g
F
P
p
.46872 .57265 m .45087 .56287 L .46191 .56993 L 1 g
F
P
p
.46841 .57409 m .45087 .56287 L .45426 .54983 L 1 g
F
P
p
.002 w
.44713 .56047 m .44779 .5595 L p
.45087 .56287 L 1 g
F P
s
P
p
.002 w
.44779 .5595 m .45426 .54983 L p
.45087 .56287 L 1 g
F P
s
P
p
.002 w
.43774 .54852 m .43743 .5491 L p
.44152 .55265 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52882 L p
1 g
F P
s
P
p
.002 w
.42716 .52913 m .43153 .52572 L p
.43244 .52882 L 1 g
F P
s
P
p
.002 w
.43409 .53442 m .4322 .53298 L p
.43244 .52882 L 1 g
F P
s
P
p
.002 w
.4322 .53298 m .42716 .52913 L p
.43244 .52882 L 1 g
F P
s
P
p
.002 w
.43244 .52882 m .43346 .52734 L p
.43318 .51921 L 1 g
F P
s
P
p
.002 w
.43268 .52482 m .42716 .52913 L p
.43134 .515 L 1 g
F P
s
P
p
.43134 .515 m .43451 .50429 L .43407 .50918 L 1 g
F
P
p
.43134 .515 m .43407 .50918 L .43268 .52482 L 1 g
F
P
p
.002 w
.43407 .50918 m .43485 .50826 L p
.43834 .50011 L 1 g
F P
s
P
p
.43318 .51921 m .43268 .52482 L .43244 .52882 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.43925 .54566 m .43244 .52882 L .43331 .53177 L 1 g
F
P
p
.43925 .54566 m .4322 .52917 L .43539 .53802 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.43409 .53442 m .43244 .52882 L .45156 .51008 L 1 g
F
P
p
.002 w
.43153 .52572 m .43268 .52482 L p
.43244 .52882 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43355 .50981 L p
1 g
F P
s
P
p
.43346 .52734 m .43355 .50981 L .43311 .51733 L 1 g
F
P
p
.002 w
.43268 .52482 m .45156 .51008 L p
.43244 .52882 L 1 g
F P
s
P
p
.002 w
.43355 .50981 m .43287 .51061 L p
.43311 .51733 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44245 .49149 L p
1 g
F P
s
P
p
.002 w
.43859 .4905 m .44395 .48848 L p
.44245 .49149 L 1 g
F P
s
P
p
.002 w
.44108 .49427 m .4405 .49339 L p
.44245 .49149 L 1 g
F P
s
P
p
.002 w
.4405 .49339 m .43859 .4905 L p
.44245 .49149 L 1 g
F P
s
P
p
.002 w
.44245 .49149 m .44231 .49164 L p
.44166 .4931 L 1 g
F P
s
P
p
.43485 .50826 m .44245 .49149 L .44166 .4931 L 1 g
F
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44245 .49149 m .44339 .4905 L p
.45034 .48385 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45768 .47671 m .45826 .47608 L p
.47007 .4709 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.51102 .49946 m .49891 .49942 L .50524 .46481 L p
1 g
F P
s
P
p
.002 w
.53215 .48835 m .52251 .49563 L .50573 .46488 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54201 .4668 m .57701 .46825 L p
.54326 .47722 L 1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50935 L p
1 g
F P
s
P
p
.59998 .50135 m .57213 .5224 L .56607 .50935 L 1 g
F
P
p
.566 .50859 m .56607 .50935 L .56574 .50864 L 1 g
F
P
p
.59998 .50135 m .56607 .50935 L .566 .50859 L 1 g
F
P
p
.002 w
.56607 .50935 m .56515 .50826 L p
.56688 .51948 L 1 g
F P
s
P
p
.002 w
.5668 .51799 m .58073 .5295 L p
.56734 .52794 L 1 g
F P
s
P
p
.56688 .51948 m .56698 .52013 L .5668 .51799 L 1 g
F
P
p
.56688 .51948 m .5668 .51799 L .56607 .50935 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56737 .52855 L p
1 g
F P
s
P
p
.002 w
.58073 .5295 m .56794 .53911 L p
.56737 .52855 L 1 g
F P
s
P
p
.56754 .52796 m .56737 .52855 L .56734 .52794 L 1 g
F
P
p
.58073 .5295 m .56737 .52855 L .56754 .52796 L 1 g
F
P
p
.002 w
.56737 .52855 m .56654 .52734 L p
.56458 .5381 L 1 g
F P
s
P
p
.56515 .50826 m .56737 .52855 L .56714 .52425 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56159 .54723 L p
1 g
F P
s
P
p
.56085 .54927 m .56159 .54723 L .58073 .5295 L 1 g
F
P
p
.002 w
.56324 .54264 m .56685 .53994 L p
.56159 .54723 L 1 g
F P
s
P
p
.002 w
.56685 .53994 m .58073 .5295 L p
.56159 .54723 L 1 g
F P
s
P
p
.002 w
.58073 .5295 m .60081 .54513 L p
.56085 .54927 L 1 g
F P
s
P
p
.002 w
.56159 .54723 m .56075 .54566 L p
.55506 .55597 L 1 g
F P
s
P
p
.56605 .57118 m .54561 .5665 L .54905 .56266 L 1 g
F
P
p
.002 w
.55619 .55471 m .55757 .55701 L p
.54905 .56266 L 1 g
F P
s
P
p
.002 w
.55757 .55701 m .56605 .57118 L p
.54905 .56266 L 1 g
F P
s
P
p
.002 w
.54905 .56266 m .54854 .56129 L p
.54264 .56692 L 1 g
F P
s
P
p
.55506 .55597 m .55619 .55471 L .56159 .54723 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53162 .57422 L p
1 g
F P
s
P
p
.54854 .56129 m .53162 .57422 L .54264 .56692 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54953 .56395 L p
1 g
F P
s
P
p
.002 w
.54953 .56395 m .54998 .56518 L p
.55434 .55728 L 1 g
F P
s
P
p
.56075 .54566 m .54953 .56395 L .55434 .55728 L 1 g
F
P
p
.002 w
.60081 .54513 m .56605 .57118 L .55619 .55471 L p
1 g
F P
s
P
p
.002 w
.55619 .55471 m .5534 .55004 L p
.56006 .54935 L 1 g
F P
s
P
p
.60081 .54513 m .55619 .55471 L .56006 .54935 L 1 g
F
P
p
.54905 .56266 m .5209 .56083 L .55619 .55471 L 1 g
F
P
p
.54561 .5665 m .54387 .5661 L .54905 .56266 L 1 g
F
P
p
.54387 .5661 m .5209 .56083 L .54905 .56266 L 1 g
F
P
p
.002 w
.56605 .57118 m .52477 .58487 L .52355 .57729 L p
1 g
F P
s
P
p
.002 w
.53162 .57422 m .53128 .57265 L p
.51845 .57923 L 1 g
F P
s
P
p
.002 w
.52355 .57729 m .5209 .56083 L p
.54954 .5674 L 1 g
F P
s
P
p
.56605 .57118 m .52355 .57729 L .54954 .5674 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53162 .57422 L p
1 g
F P
s
P
p
.51567 .57911 m .50573 .58028 L .48665 .56077 L 1 g
F
P
p
.51729 .58014 m .51091 .58021 L .51567 .57911 L 1 g
F
P
p
.51091 .58021 m .50573 .58028 L .51567 .57911 L 1 g
F
P
p
.51845 .57923 m .51111 .583 L .5255 .57684 L 1 g
F
P
p
.52355 .57729 m .5255 .57684 L .53162 .57422 L 1 g
F
P
p
.51845 .57923 m .5255 .57684 L .52355 .57729 L 1 g
F
P
p
.002 w
.53162 .57422 m .5322 .57686 L p
.54264 .56692 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54905 .56266 L p
1 g
F P
s
P
p
.54264 .56692 m .5322 .57686 L .54905 .56266 L 1 g
F
P
p
.55506 .55597 m .55434 .55728 L .55619 .55471 L 1 g
F
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5209 .56083 m .5534 .55004 L .55619 .55471 L p
1 g
F P
s
P
p
.56654 .52734 m .56159 .54723 L .56242 .54494 L 1 g
F
P
p
.56654 .52734 m .56179 .54762 L .56458 .5381 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5534 .55004 m .56324 .54264 L p
.56085 .54927 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56159 .54723 L p
1 g
F P
s
P
p
.55434 .55728 m .54998 .56518 L .56159 .54723 L 1 g
F
P
p
.002 w
.56159 .54723 m .56179 .54762 L p
.56242 .54494 L 1 g
F P
s
P
p
.56737 .52855 m .5534 .55004 L .56734 .52794 L 1 g
F
P
p
.002 w
.56794 .53911 m .56324 .54264 L p
.56737 .52855 L 1 g
F P
s
P
p
.002 w
.56324 .54264 m .5534 .55004 L p
.56737 .52855 L 1 g
F P
s
P
p
.002 w
.56179 .54762 m .56257 .5491 L p
.56458 .5381 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56737 .52855 L p
1 g
F P
s
P
p
.56458 .5381 m .56257 .5491 L .56737 .52855 L 1 g
F
P
p
.002 w
.56737 .52855 m .56774 .52909 L p
.56714 .52425 L 1 g
F P
s
P
p
.002 w
.5534 .55004 m .53873 .52459 L p
.56734 .52794 L 1 g
F P
s
P
p
.56515 .50826 m .56774 .52909 L .56698 .52013 L 1 g
F
P
p
.55661 .4905 m .56607 .50935 L .56291 .50256 L 1 g
F
P
p
.55661 .4905 m .56291 .50256 L .56286 .50245 L 1 g
F
P
p
.002 w
.56532 .49901 m .56291 .50256 L p
.55739 .49133 L 1 g
F P
s
P
p
.002 w
.57083 .49091 m .59998 .50135 L p
.56574 .50864 L 1 g
F P
s
P
p
.002 w
.56291 .50256 m .57083 .49091 L p
.56574 .50864 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55798 .49196 L p
1 g
F P
s
P
p
.002 w
.55798 .49196 m .55661 .4905 L p
.56288 .5025 L 1 g
F P
s
P
p
.56288 .5025 m .56713 .51061 L .55798 .49196 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55759 .51038 m .56291 .50256 L p
.56574 .50864 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55033 .48449 L 1 g
F
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55759 .51038 m .53215 .48835 L p
.55594 .48992 L 1 g
F P
s
P
p
.55673 .48998 m .55676 .49072 L .55594 .48992 L 1 g
F
P
p
.55676 .49072 m .55759 .51038 L .55594 .48992 L 1 g
F
P
p
.002 w
.56291 .50256 m .55759 .51038 L p
.55673 .48998 L 1 g
F P
s
P
p
.002 w
.5389 .47838 m .53966 .47556 L p
.54244 .47684 L 1 g
F P
s
P
p
.54174 .47608 m .55033 .48449 L .54751 .48176 L 1 g
F
P
p
.54326 .47722 m .54292 .47731 L .54244 .47684 L 1 g
F
P
p
.54292 .47731 m .5389 .47838 L .54244 .47684 L 1 g
F
P
p
.002 w
.54244 .47684 m .54174 .47608 L p
.54751 .48176 L 1 g
F P
s
P
p
.002 w
.57701 .46825 m .57083 .49091 L .54751 .48176 L p
1 g
F P
s
P
p
.002 w
.54751 .48176 m .5389 .47838 L p
.54292 .47731 L 1 g
F P
s
P
p
.57701 .46825 m .54751 .48176 L .54292 .47731 L 1 g
F
P
p
.002 w
.53215 .48835 m .5389 .47838 L .57083 .49091 L p
1 g
F P
s
P
p
.54751 .48176 m .55834 .49233 L .54249 .47689 L 1 g
F
P
p
.55033 .48449 m .55068 .48483 L .54751 .48176 L 1 g
F
P
p
.55068 .48483 m .55834 .49233 L .54751 .48176 L 1 g
F
P
p
.002 w
.54249 .47689 m .54244 .47684 L p
.54751 .48176 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54249 .47689 L p
1 g
F P
s
P
p
.002 w
.55739 .49133 m .55834 .49233 L p
.55033 .48449 L 1 g
F P
s
P
p
.002 w
.57083 .49091 m .56532 .49901 L p
.55673 .48998 L 1 g
F P
s
P
p
.56532 .49901 m .55739 .49133 L .55673 .48998 L 1 g
F
P
p
.56286 .50245 m .56291 .50256 L .56288 .5025 L 1 g
F
P
p
.56574 .50864 m .56607 .50935 L .55759 .51038 L 1 g
F
P
p
.002 w
.57213 .5224 m .5668 .51799 L p
.56607 .50935 L 1 g
F P
s
P
p
.002 w
.5668 .51799 m .55759 .51038 L p
.56607 .50935 L 1 g
F P
s
P
p
.002 w
.56774 .52909 m .56854 .53025 L p
.56698 .52013 L 1 g
F P
s
P
p
.002 w
.53873 .52459 m .55759 .51038 L .5668 .51799 L p
1 g
F P
s
P
p
.56734 .52794 m .53873 .52459 L .5668 .51799 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56607 .50935 L p
1 g
F P
s
P
p
.56698 .52013 m .56854 .53025 L .56607 .50935 L 1 g
F
P
p
.002 w
.56607 .50935 m .56713 .51061 L p
.56288 .5025 L 1 g
F P
s
P
p
.002 w
.59998 .50135 m .58073 .5295 L .57213 .5224 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47684 L p
1 g
F P
s
P
p
.52214 .46667 m .54244 .47684 L .54085 .47611 L 1 g
F
P
p
.52214 .46667 m .54255 .47697 L .53394 .47278 L 1 g
F
P
p
.002 w
.53966 .47556 m .54201 .4668 L p
.54326 .47722 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54255 .47697 L p
.54085 .47611 L 1 g
F P
s
P
p
.002 w
.5389 .47838 m .5076 .46514 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.53394 .47278 L 1 g
F P
s
P
p
.002 w
.54121 .46977 m .53966 .47556 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.53966 .47556 m .5389 .47838 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.53394 .47278 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.54255 .47697 m .54302 .47747 L p
.53394 .47278 L 1 g
F P
s
P
p
.002 w
.54201 .4668 m .54121 .46977 L p
.52144 .4667 L 1 g
F P
s
P
p
.002 w
.50535 .46419 m .51817 .4651 L p
.52144 .4667 L 1 g
F P
s
P
p
.002 w
.51817 .4651 m .54201 .4668 L p
.52144 .4667 L 1 g
F P
s
P
p
.5 .4634 m .52245 .46719 L .52188 .46711 L 1 g
F
P
p
.5 .4634 m .52247 .46721 L .52113 .46703 L 1 g
F
P
p
.5 .4634 m .5225 .46726 L .52055 .46698 L 1 g
F
P
p
.5 .4634 m .52254 .46733 L .52015 .46698 L 1 g
F
P
p
.5 .4634 m .52259 .46742 L .51571 .46638 L 1 g
F
P
p
.51607 .46649 m .52278 .46772 L .52073 .46738 L 1 g
F
P
p
.5 .4634 m .51716 .46666 L .51607 .46649 L 1 g
F
P
p
.51716 .46666 m .52278 .46772 L .51607 .46649 L 1 g
F
P
p
.002 w
.49891 .49942 m .48748 .49553 L .50502 .46478 L p
1 g
F P
s
P
p
.002 w
.50524 .46481 m .49891 .49942 L p
.50502 .46478 L 1 g
F P
s
P
p
.002 w
.5389 .47838 m .53215 .48835 L .50619 .46495 L p
1 g
F P
s
P
p
.002 w
.5076 .46514 m .5389 .47838 L p
.50619 .46495 L 1 g
F P
s
P
p
.002 w
.50619 .46495 m .53215 .48835 L p
.50573 .46488 L 1 g
F P
s
P
p
.002 w
.52251 .49563 m .51102 .49946 L .50546 .46484 L p
1 g
F P
s
P
p
.002 w
.50573 .46488 m .52251 .49563 L p
.50546 .46484 L 1 g
F P
s
P
p
.002 w
.50546 .46484 m .51102 .49946 L p
.50524 .46481 L 1 g
F P
s
P
p
.46959 .47114 m .47752 .46723 L .50302 .46445 L 1 g
F
P
p
.46959 .47114 m .50302 .46445 L .50357 .46454 L 1 g
F
P
p
.002 w
.49288 .46499 m .50256 .46437 L p
.47752 .46723 L 1 g
F P
s
P
p
.47752 .46723 m .50256 .46437 L .50302 .46445 L 1 g
F
P
p
.5 .4634 m .5176 .46678 L .50049 .46403 L 1 g
F
P
p
.002 w
.5 .46394 m .5 .4634 L p
.50049 .46403 L 1 g
F P
s
P
p
.5176 .46678 m .50474 .46473 L .5 .46395 L 1 g
F
P
p
.002 w
.50474 .46473 m .47795 .48818 L p
.50424 .46465 L 1 g
F P
s
P
p
.50474 .46473 m .50454 .4647 L .50424 .46465 L 1 g
F
P
p
.50474 .46473 m .50424 .46465 L .5 .46395 L 1 g
F
P
p
.002 w
.47795 .48818 m .47136 .47816 L .50424 .46465 L p
1 g
F P
s
P
p
.002 w
.50424 .46465 m .50535 .46419 L .50474 .46473 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46394 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46394 L .49288 .46499 L 1 g
F
P
p
.48937 .4655 m .49288 .46499 L .4894 .4655 L 1 g
F
P
p
.47786 .46667 m .49288 .46499 L .48937 .4655 L 1 g
F
P
p
.002 w
.47752 .46723 m .47786 .46667 L p
.48937 .4655 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47735 .4675 L p
1 g
F P
s
P
p
.002 w
.47735 .4675 m .47718 .46778 L p
.47047 .47073 L 1 g
F P
s
P
p
.45826 .47608 m .47735 .4675 L .47047 .47073 L 1 g
F
P
p
.002 w
.47136 .47816 m .44658 .48749 L p
.45796 .47658 L 1 g
F P
s
P
p
.47007 .4709 m .46959 .47114 L .45768 .47671 L 1 g
F
P
p
.002 w
.46843 .46654 m .46959 .47114 L p
.45796 .47658 L 1 g
F P
s
P
p
.002 w
.46959 .47114 m .47136 .47816 L p
.45796 .47658 L 1 g
F P
s
P
p
.002 w
.46843 .46654 m .48047 .46578 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.46959 .47114 m .46892 .46848 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.46892 .46848 m .46843 .46654 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46843 .46654 m .46912 .45879 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.50256 .46437 m .49288 .46499 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.49288 .46499 m .46843 .46654 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46723 L p
1 g
F P
s
P
p
.002 w
.47752 .46723 m .47752 .46723 L p
.47781 .46719 L 1 g
F P
s
P
p
.47781 .46719 m .5 .46442 L .47752 .46723 L 1 g
F
P
p
.002 w
.5 .46394 m .5 .46442 L p
.4894 .4655 L 1 g
F P
s
P
p
.002 w
.50535 .46419 m .50256 .46437 L p
.50075 .46384 L 1 g
F P
s
P
p
.002 w
.46949 .45459 m .50286 .46353 L p
.50075 .46384 L 1 g
F P
s
P
p
.002 w
.50286 .46353 m .50535 .46419 L p
.50075 .46384 L 1 g
F P
s
P
p
.002 w
.46912 .45879 m .46949 .45459 L p
.50256 .46437 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .46394 L p
.50049 .46403 L 1 g
F P
s
P
p
.002 w
.48748 .49553 m .47795 .48818 L .50474 .46473 L p
1 g
F P
s
P
p
.002 w
.50502 .46478 m .48748 .49553 L p
.50474 .46473 L 1 g
F P
s
P
p
.5176 .46678 m .52073 .46738 L .50454 .4647 L 1 g
F
P
p
.002 w
.50474 .46473 m .50535 .46419 L .50502 .46478 L p
1 g
F P
s
P
p
.002 w
.50535 .46419 m .47136 .47816 L .46959 .47114 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.52073 .46738 m .52282 .46778 L .5 .46395 L 1 g
F
P
p
.002 w
.50256 .46437 m .50535 .46419 L p
.50302 .46445 L 1 g
F P
s
P
p
.002 w
.50502 .46478 m .50535 .46419 L .50524 .46481 L p
1 g
F P
s
P
p
.002 w
.5076 .46514 m .50535 .46419 L p
.54121 .46977 L 1 g
F P
s
P
p
.002 w
.52245 .46719 m .52247 .46721 L p
.52188 .46711 L 1 g
F P
s
P
p
.002 w
.52247 .46721 m .5225 .46726 L p
.52113 .46703 L 1 g
F P
s
P
p
.002 w
.50619 .46495 m .50535 .46419 L .5076 .46514 L p
1 g
F P
s
P
p
.002 w
.50573 .46488 m .50535 .46419 L .50619 .46495 L p
1 g
F P
s
P
p
.002 w
.5225 .46726 m .52254 .46733 L p
.52055 .46698 L 1 g
F P
s
P
p
.002 w
.52254 .46733 m .52259 .46742 L p
.52015 .46698 L 1 g
F P
s
P
p
.002 w
.50546 .46484 m .50535 .46419 L .50573 .46488 L p
1 g
F P
s
P
p
.002 w
.50524 .46481 m .50535 .46419 L .50546 .46484 L p
1 g
F P
s
P
p
.002 w
.52259 .46742 m .52278 .46772 L p
.51571 .46638 L 1 g
F P
s
P
p
.002 w
.52278 .46772 m .52282 .46778 L p
.52073 .46738 L 1 g
F P
s
P
p
.50357 .46454 m .50302 .46445 L .50535 .46419 L 1 g
F
P
p
.002 w
.48047 .46578 m .49288 .46499 L p
.47752 .46723 L 1 g
F P
s
P
p
.48937 .4655 m .5 .46442 L .47752 .46723 L 1 g
F
P
p
.47007 .4709 m .47047 .47073 L .46959 .47114 L 1 g
F
P
p
.46683 .46782 m .46843 .46654 L .45796 .47658 L 1 g
F
P
p
.45768 .47671 m .45796 .47658 L .44658 .48749 L 1 g
F
P
p
.46683 .46782 m .45796 .47658 L .45768 .47671 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45768 .47671 L p
1 g
F P
s
P
p
.47047 .47073 m .47718 .46778 L .45768 .47671 L 1 g
F
P
p
.45034 .48385 m .45073 .48346 L .44658 .48749 L 1 g
F
P
p
.45034 .48385 m .44658 .48749 L .44245 .49149 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43485 .50826 m .44231 .49164 L .43834 .50011 L 1 g
F
P
p
.44108 .49427 m .44245 .49149 L .47136 .47816 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45757 .47683 L p
1 g
F P
s
P
p
.44339 .4905 m .45757 .47683 L .45073 .48346 L 1 g
F
P
p
.002 w
.44395 .48848 m .44658 .48749 L p
.44245 .49149 L 1 g
F P
s
P
p
.002 w
.44658 .48749 m .47136 .47816 L p
.44245 .49149 L 1 g
F P
s
P
p
.002 w
.45757 .47683 m .45698 .47747 L p
.45073 .48346 L 1 g
F P
s
P
p
.002 w
.44658 .48749 m .43859 .4905 L p
.46683 .46782 L 1 g
F P
s
P
p
.002 w
.43859 .4905 m .44108 .49427 L p
.43612 .50482 L 1 g
F P
s
P
p
.002 w
.44231 .49164 m .44166 .49233 L p
.43834 .50011 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44245 .49149 L p
1 g
F P
s
P
p
.45073 .48346 m .45698 .47747 L .44245 .49149 L 1 g
F
P
p
.002 w
.45156 .51008 m .44108 .49427 L p
.47136 .47816 L 1 g
F P
s
P
p
.002 w
.45156 .51008 m .43268 .52482 L p
.43612 .50482 L 1 g
F P
s
P
p
.002 w
.44108 .49427 m .45156 .51008 L p
.43612 .50482 L 1 g
F P
s
P
p
.43451 .50429 m .43859 .4905 L .43268 .52482 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43407 .50918 L p
1 g
F P
s
P
p
.43834 .50011 m .44166 .49233 L .43407 .50918 L 1 g
F
P
p
.43318 .51921 m .43311 .51733 L .43268 .52482 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43244 .52882 L p
1 g
F P
s
P
p
.43311 .51733 m .43287 .51061 L .43244 .52882 L 1 g
F
P
p
.002 w
.43244 .52882 m .4322 .52917 L p
.43331 .53177 L 1 g
F P
s
P
p
.002 w
.45426 .54983 m .43409 .53442 L p
.45156 .51008 L 1 g
F P
s
P
p
.002 w
.45426 .54983 m .44779 .5595 L p
.43786 .54487 L 1 g
F P
s
P
p
.002 w
.42716 .52913 m .43409 .53442 L p
.43786 .54487 L 1 g
F P
s
P
p
.002 w
.43409 .53442 m .45426 .54983 L p
.43786 .54487 L 1 g
F P
s
P
p
.002 w
.4322 .52917 m .43146 .53025 L p
.43539 .53802 L 1 g
F P
s
P
p
.42831 .53284 m .42716 .52913 L .44779 .5595 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43859 .54691 L p
1 g
F P
s
P
p
.43539 .53802 m .43146 .53025 L .43859 .54691 L 1 g
F
P
p
.44499 .55567 m .44152 .55265 L .44779 .5595 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45087 .56287 L p
1 g
F P
s
P
p
.44152 .55265 m .43743 .5491 L .45087 .56287 L 1 g
F
P
p
.002 w
.45087 .56287 m .45002 .56518 L p
.46191 .56993 L 1 g
F P
s
P
p
.47474 .57635 m .46841 .57409 L .45426 .54983 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46841 .57409 L p
1 g
F P
s
P
p
.46191 .56993 m .45002 .56518 L .46841 .57409 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .489 .58143 L p
1 g
F P
s
P
p
.002 w
.489 .58143 m .48907 .58048 L p
.48384 .57959 L 1 g
F P
s
P
p
.48384 .57959 m .4678 .57686 L .489 .58143 L 1 g
F
P
p
.4787 .57776 m .4741 .57738 L .48255 .57913 L 1 g
F
P
p
.4787 .57776 m .48255 .57913 L .48907 .58048 L 1 g
F
P
p
.002 w
.45426 .54983 m .48665 .56077 L .48255 .57913 L p
1 g
F P
s
P
p
.47474 .57635 m .45426 .54983 L .48255 .57913 L 1 g
F
P
p
.002 w
.48255 .57913 m .48665 .56077 L p
.5102 .58485 L 1 g
F P
s
P
p
.002 w
.48907 .58048 m .48889 .583 L p
.5023 .58032 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58021 L p
1 g
F P
s
P
p
.5023 .58032 m .48889 .583 L .51091 .58021 L 1 g
F
P
p
.4741 .57738 m .4678 .57686 L .48907 .58048 L 1 g
F
P
p
.002 w
.51091 .58021 m .51111 .583 L p
.52115 .57784 L 1 g
F P
s
P
p
.002 w
.48665 .56077 m .5209 .56083 L .52355 .57729 L p
1 g
F P
s
P
p
.51567 .57911 m .48665 .56077 L .52355 .57729 L 1 g
F
P
p
.002 w
.44011 .57096 m .4056 .5447 L .42716 .52913 L p
1 g
F P
s
P
p
.002 w
.62535 .50938 m .60081 .54513 L .58073 .5295 L p
1 g
F P
s
P
p
.002 w
.39158 .38296 m .37387 .4232 L .34981 .41322 L p
1 g
F P
s
P
p
.002 w
.34981 .41322 m .3706 .36566 L .39158 .38296 L p
1 g
F P
s
P
p
.002 w
.63429 .4243 m .61739 .38406 L .63713 .36703 L p
1 g
F P
s
P
p
.002 w
.60247 .32839 m .63713 .36703 L .61739 .38406 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40827 .50079 m .42716 .52913 L .4056 .5447 L p
1 g
F P
s
P
p
.002 w
.4056 .5447 m .38147 .5087 L .40827 .50079 L p
1 g
F P
s
P
p
.002 w
.58073 .5295 m .59998 .50135 L .62535 .50938 L p
1 g
F P
s
P
p
.002 w
.63698 .46764 m .62535 .50938 L .59998 .50135 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.42174 .35049 m .39158 .38296 L .3706 .36566 L p
1 g
F P
s
P
p
.002 w
.3706 .36566 m .40617 .32725 L .42174 .35049 L p
1 g
F P
s
P
p
.002 w
.61739 .38406 m .58796 .35139 L .60247 .32839 L p
1 g
F P
s
P
p
.002 w
.55666 .30305 m .60247 .32839 L .58796 .35139 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.39971 .4678 m .40827 .50079 L .38147 .5087 L p
1 g
F P
s
P
p
.002 w
.38147 .5087 m .37044 .46671 L .39971 .4678 L p
1 g
F P
s
P
p
.002 w
.59998 .50135 m .60903 .46852 L .63698 .46764 L p
1 g
F P
s
P
p
.002 w
.63429 .4243 m .63698 .46764 L .60903 .46852 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46108 .3295 m .42174 .35049 L .40617 .32725 L p
1 g
F P
s
P
p
.002 w
.40617 .32725 m .45262 .30241 L .46108 .3295 L p
1 g
F P
s
P
p
.002 w
.58796 .35139 m .54914 .33001 L .55666 .30305 L p
1 g
F P
s
P
p
.002 w
.50476 .29403 m .55666 .30305 L .54914 .33001 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.5052 .32241 m .46108 .3295 L .45262 .30241 L p
1 g
F P
s
P
p
.002 w
.45262 .30241 m .50476 .29403 L .5052 .32241 L p
1 g
F P
s
P
p
.002 w
.54914 .33001 m .5052 .32241 L .50476 .29403 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.4025 .43368 m .39971 .4678 L .37044 .46671 L p
1 g
F P
s
P
p
.002 w
.37044 .46671 m .37387 .4232 L .4025 .43368 L p
1 g
F P
s
P
p
.002 w
.60903 .46852 m .60682 .43451 L .63429 .4243 L p
1 g
F P
s
P
p
.002 w
.61739 .38406 m .63429 .4243 L .60682 .43451 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.4926 .532 m .51627 .53206 L .5209 .56083 L p
1 g
F P
s
P
p
.002 w
.5209 .56083 m .48665 .56077 L .4926 .532 L p
1 g
F P
s
P
p
.002 w
.5534 .55004 m .5209 .56083 L .51627 .53206 L p
1 g
F P
s
P
p
.002 w
.47023 .52442 m .4926 .532 L .48665 .56077 L p
1 g
F P
s
P
p
.002 w
.48665 .56077 m .45426 .54983 L .47023 .52442 L p
1 g
F P
s
P
p
.002 w
.51627 .53206 m .53873 .52459 L .5534 .55004 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.45156 .51008 m .47023 .52442 L .45426 .54983 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.41646 .40218 m .4025 .43368 L .37387 .4232 L p
1 g
F P
s
P
p
.002 w
.37387 .4232 m .39158 .38296 L .41646 .40218 L p
1 g
F P
s
P
p
.002 w
.60682 .43451 m .59348 .40299 L .61739 .38406 L p
1 g
F P
s
P
p
.002 w
.58796 .35139 m .61739 .38406 L .59348 .40299 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42716 .52913 m .40827 .50079 L .43859 .4905 L p
1 g
F P
s
P
p
.002 w
.60903 .46852 m .59998 .50135 L .57083 .49091 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.44014 .37679 m .41646 .40218 L .39158 .38296 L p
1 g
F P
s
P
p
.002 w
.39158 .38296 m .42174 .35049 L .44014 .37679 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.59348 .40299 m .57034 .37744 L .58796 .35139 L p
1 g
F P
s
P
p
.002 w
.54914 .33001 m .58796 .35139 L .57034 .37744 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43276 .46775 m .43859 .4905 L .40827 .50079 L p
1 g
F P
s
P
p
.002 w
.40827 .50079 m .39971 .4678 L .43276 .46775 L p
1 g
F P
s
P
p
.002 w
.57083 .49091 m .57701 .46825 L .60903 .46852 L p
1 g
F P
s
P
p
.002 w
.60682 .43451 m .60903 .46852 L .57701 .46825 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.47095 .36039 m .44014 .37679 L .42174 .35049 L p
1 g
F P
s
P
p
.002 w
.42174 .35049 m .46108 .3295 L .47095 .36039 L p
1 g
F P
s
P
p
.002 w
.57034 .37744 m .5399 .36076 L .54914 .33001 L p
1 g
F P
s
P
p
.002 w
.5052 .32241 m .54914 .33001 L .5399 .36076 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.5055 .35484 m .47095 .36039 L .46108 .3295 L p
1 g
F P
s
P
p
.002 w
.46108 .3295 m .5052 .32241 L .5055 .35484 L p
1 g
F P
s
P
p
.002 w
.5399 .36076 m .5055 .35484 L .5052 .32241 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.43476 .44428 m .43276 .46775 L .39971 .4678 L p
1 g
F P
s
P
p
.002 w
.39971 .4678 m .4025 .43368 L .43476 .44428 L p
1 g
F P
s
P
p
.002 w
.57701 .46825 m .57541 .44483 L .60682 .43451 L p
1 g
F P
s
P
p
.002 w
.59348 .40299 m .60682 .43451 L .57541 .44483 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49891 .49942 m .51102 .49946 L .51627 .53206 L p
1 g
F P
s
P
p
.002 w
.51627 .53206 m .4926 .532 L .49891 .49942 L p
1 g
F P
s
P
p
.002 w
.53873 .52459 m .51627 .53206 L .51102 .49946 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48748 .49553 m .49891 .49942 L .4926 .532 L p
1 g
F P
s
P
p
.002 w
.4926 .532 m .47023 .52442 L .48748 .49553 L p
1 g
F P
s
P
p
.002 w
.51102 .49946 m .52251 .49563 L .53873 .52459 L p
1 g
F P
s
P
p
.002 w
.55759 .51038 m .53873 .52459 L .52251 .49563 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47795 .48818 m .48748 .49553 L .47023 .52442 L p
1 g
F P
s
P
p
.002 w
.47023 .52442 m .45156 .51008 L .47795 .48818 L p
1 g
F P
s
P
p
.002 w
.52251 .49563 m .53215 .48835 L .55759 .51038 L p
1 g
F P
s
P
p
.002 w
.44442 .42265 m .43476 .44428 L .4025 .43368 L p
1 g
F P
s
P
p
.002 w
.4025 .43368 m .41646 .40218 L .44442 .42265 L p
1 g
F P
s
P
p
.002 w
.57541 .44483 m .56615 .42316 L .59348 .40299 L p
1 g
F P
s
P
p
.002 w
.57034 .37744 m .59348 .40299 L .56615 .42316 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47136 .47816 m .47795 .48818 L .45156 .51008 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.46073 .40524 m .44442 .42265 L .41646 .40218 L p
1 g
F P
s
P
p
.002 w
.41646 .40218 m .44014 .37679 L .46073 .40524 L p
1 g
F P
s
P
p
.002 w
.56615 .42316 m .5502 .40565 L .57034 .37744 L p
1 g
F P
s
P
p
.002 w
.5399 .36076 m .57034 .37744 L .5502 .40565 L p
1 g
F P
s
P
p
.002 w
.43859 .4905 m .43276 .46775 L .46843 .46654 L p
1 g
F P
s
P
p
.002 w
.57541 .44483 m .57701 .46825 L .54201 .4668 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.48191 .39401 m .46073 .40524 L .44014 .37679 L p
1 g
F P
s
P
p
.002 w
.44014 .37679 m .47095 .36039 L .48191 .39401 L p
1 g
F P
s
P
p
.002 w
.5502 .40565 m .52926 .39423 L .5399 .36076 L p
1 g
F P
s
P
p
.002 w
.5055 .35484 m .5399 .36076 L .52926 .39423 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.46949 .45459 m .46843 .46654 L .43276 .46775 L p
1 g
F P
s
P
p
.002 w
.43276 .46775 m .43476 .44428 L .46949 .45459 L p
1 g
F P
s
P
p
.002 w
.54201 .4668 m .54115 .45485 L .57541 .44483 L p
1 g
F P
s
P
p
.002 w
.56615 .42316 m .57541 .44483 L .54115 .45485 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.50562 .39019 m .48191 .39401 L .47095 .36039 L p
1 g
F P
s
P
p
.002 w
.47095 .36039 m .5055 .35484 L .50562 .39019 L p
1 g
F P
s
P
p
.002 w
.52926 .39423 m .50562 .39019 L .5055 .35484 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.47444 .44359 m .46949 .45459 L .43476 .44428 L p
1 g
F P
s
P
p
.002 w
.43476 .44428 m .44442 .42265 L .47444 .44359 L p
1 g
F P
s
P
p
.002 w
.54115 .45485 m .5364 .44383 L .56615 .42316 L p
1 g
F P
s
P
p
.002 w
.5502 .40565 m .56615 .42316 L .5364 .44383 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.48275 .43476 m .47444 .44359 L .44442 .42265 L p
1 g
F P
s
P
p
.002 w
.44442 .42265 m .46073 .40524 L .48275 .43476 L p
1 g
F P
s
P
p
.002 w
.5364 .44383 m .52825 .43494 L .5502 .40565 L p
1 g
F P
s
P
p
.002 w
.52926 .39423 m .5502 .40565 L .52825 .43494 L p
1 g
F P
s
P
p
.002 w
.54115 .45485 m .54201 .4668 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5364 .44383 m .54115 .45485 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.49352 .42906 m .48275 .43476 L .46073 .40524 L p
1 g
F P
s
P
p
.002 w
.46073 .40524 m .48191 .39401 L .49352 .42906 L p
1 g
F P
s
P
p
.002 w
.52825 .43494 m .51759 .42916 L .52926 .39423 L p
1 g
F P
s
P
p
.002 w
.50562 .39019 m .52926 .39423 L .51759 .42916 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50558 .42713 m .49352 .42906 L .48191 .39401 L p
1 g
F P
s
P
p
.002 w
.48191 .39401 m .50562 .39019 L .50558 .42713 L p
1 g
F P
s
P
p
.002 w
.51759 .42916 m .50558 .42713 L .50562 .39019 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.46949 .45459 m .47444 .44359 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.52825 .43494 m .5364 .44383 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51759 .42916 m .52825 .43494 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.50558 .42713 m .51759 .42916 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.49352 .42906 m .50558 .42713 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.48275 .43476 m .49352 .42906 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.47444 .44359 m .48275 .43476 L .50535 .46419 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.50535 .46419 m
.50868 .48511 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .23534 .4493 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .50868 .48511 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0515789)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0515789)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48773 .45599 m .50504 .44953 L .49088 .42472 L p
1 g
F P
s
P
p
.002 w
.49088 .42472 m .48211 .42799 L .48773 .45599 L p
1 g
F P
s
P
p
.002 w
.49817 .41884 m .49088 .42472 L .50504 .44953 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .48211 .42799 L .49088 .42472 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .49088 .42472 L .49817 .41884 L closepath p
1 g
F P
s
P
p
.002 w
.50504 .44953 m .51944 .43791 L .49817 .41884 L p
1 g
F P
s
P
p
.002 w
.5032 .41095 m .49817 .41884 L .51944 .43791 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .49817 .41884 L .5032 .41095 L closepath p
1 g
F P
s
P
p
.002 w
.46934 .4566 m .48773 .45599 L .48211 .42799 L p
1 g
F P
s
P
p
.002 w
.48211 .42799 m .47279 .42827 L .46934 .4566 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .47279 .42827 L .48211 .42799 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .48352 m .51914 .47398 L .50504 .44953 L p
1 g
F P
s
P
p
.002 w
.50504 .44953 m .48773 .45599 L .49369 .48352 L p
1 g
F P
s
P
p
.002 w
.51944 .43791 m .50504 .44953 L .51914 .47398 L p
1 g
F P
s
P
p
.002 w
.51944 .43791 m .52939 .42236 L .5032 .41095 L p
1 g
F P
s
P
p
.002 w
.50542 .40191 m .5032 .41095 L .52939 .42236 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .5032 .41095 L .50542 .40191 L closepath p
1 g
F P
s
P
p
.002 w
.51914 .47398 m .54032 .45689 L .51944 .43791 L p
1 g
F P
s
P
p
.002 w
.52939 .42236 m .51944 .43791 L .54032 .45689 L p
1 g
F P
s
P
p
.002 w
.45181 .45125 m .46934 .4566 L .47279 .42827 L p
1 g
F P
s
P
p
.002 w
.47279 .42827 m .46394 .42553 L .45181 .45125 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .46394 .42553 L .47279 .42827 L closepath p
1 g
F P
s
P
p
.002 w
.4666 .48448 m .49369 .48352 L .48773 .45599 L p
1 g
F P
s
P
p
.002 w
.48773 .45599 m .46934 .4566 L .4666 .48448 L p
1 g
F P
s
P
p
.002 w
.52939 .42236 m .53383 .40451 L .50542 .40191 L p
1 g
F P
s
P
p
.002 w
.5046 .39269 m .50542 .40191 L .53383 .40451 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .50542 .40191 L .5046 .39269 L closepath p
1 g
F P
s
P
p
.002 w
.54032 .45689 m .555 .43402 L .52939 .42236 L p
1 g
F P
s
P
p
.002 w
.53383 .40451 m .52939 .42236 L .555 .43402 L p
1 g
F P
s
P
p
.002 w
.43703 .44049 m .45181 .45125 L .46394 .42553 L p
1 g
F P
s
P
p
.002 w
.46394 .42553 m .45649 .42007 L .43703 .44049 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .45649 .42007 L .46394 .42553 L closepath p
1 g
F P
s
P
p
.002 w
.53383 .40451 m .53226 .38626 L .5046 .39269 L p
1 g
F P
s
P
p
.002 w
.5008 .38427 m .5046 .39269 L .53226 .38626 L p
1 g
F P
s
P
p
.002 w
.47691 .4 m .5046 .39269 L .5008 .38427 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .45127 .41245 L .45649 .42007 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .44885 .4035 L .45127 .41245 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .5008 .38427 L .49443 .37758 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .49443 .37758 L .48617 .37335 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .48617 .37335 L .47691 .37204 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .47691 .37204 L .46767 .37382 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .46767 .37382 L .45946 .37849 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .45946 .37849 L .45318 .38554 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .45318 .38554 L .44951 .39419 L closepath p
1 g
F P
s
P
p
.002 w
.47691 .4 m .44951 .39419 L .44885 .4035 L closepath p
1 g
F P
s
P
p
.002 w
.44075 .47669 m .4666 .48448 L .46934 .4566 L p
1 g
F P
s
P
p
.002 w
.46934 .4566 m .45181 .45125 L .44075 .47669 L p
1 g
F P
s
P
p
.002 w
.555 .43402 m .56161 .40776 L .53383 .40451 L p
1 g
F P
s
P
p
.002 w
.53226 .38626 m .53383 .40451 L .56161 .40776 L p
1 g
F P
s
P
p
.002 w
.42662 .42544 m .43703 .44049 L .45649 .42007 L p
1 g
F P
s
P
p
.002 w
.45649 .42007 m .45127 .41245 L .42662 .42544 L p
1 g
F P
s
P
p
.002 w
.53226 .38626 m .52481 .36957 L .5008 .38427 L p
1 g
F P
s
P
p
.002 w
.49443 .37758 m .5008 .38427 L .52481 .36957 L p
1 g
F P
s
P
p
.002 w
.49986 .51007 m .53293 .49763 L .51914 .47398 L p
1 g
F P
s
P
p
.002 w
.51914 .47398 m .49369 .48352 L .49986 .51007 L p
1 g
F P
s
P
p
.002 w
.54032 .45689 m .51914 .47398 L .53293 .49763 L p
1 g
F P
s
P
p
.002 w
.53293 .49763 m .56045 .47543 L .54032 .45689 L p
1 g
F P
s
P
p
.002 w
.555 .43402 m .54032 .45689 L .56045 .47543 L p
1 g
F P
s
P
p
.002 w
.42175 .4077 m .42662 .42544 L .45127 .41245 L p
1 g
F P
s
P
p
.002 w
.45127 .41245 m .44885 .4035 L .42175 .4077 L p
1 g
F P
s
P
p
.002 w
.41888 .4609 m .44075 .47669 L .45181 .45125 L p
1 g
F P
s
P
p
.002 w
.45181 .45125 m .43703 .44049 L .41888 .4609 L p
1 g
F P
s
P
p
.002 w
.52481 .36957 m .51224 .35626 L .49443 .37758 L p
1 g
F P
s
P
p
.002 w
.48617 .37335 m .49443 .37758 L .51224 .35626 L p
1 g
F P
s
P
p
.002 w
.46465 .51139 m .49986 .51007 L .49369 .48352 L p
1 g
F P
s
P
p
.002 w
.49369 .48352 m .4666 .48448 L .46465 .51139 L p
1 g
F P
s
P
p
.002 w
.56161 .40776 m .5594 .38086 L .53226 .38626 L p
1 g
F P
s
P
p
.002 w
.52481 .36957 m .53226 .38626 L .5594 .38086 L p
1 g
F P
s
P
p
.002 w
.56045 .47543 m .57956 .44574 L .555 .43402 L p
1 g
F P
s
P
p
.002 w
.56161 .40776 m .555 .43402 L .57956 .44574 L p
1 g
F P
s
P
p
.002 w
.423 .38919 m .42175 .4077 L .44885 .4035 L p
1 g
F P
s
P
p
.002 w
.44885 .4035 m .44951 .39419 L .423 .38919 L p
1 g
F P
s
P
p
.002 w
.51224 .35626 m .49587 .34779 L .48617 .37335 L p
1 g
F P
s
P
p
.002 w
.47691 .37204 m .48617 .37335 L .49587 .34779 L p
1 g
F P
s
P
p
.002 w
.43026 .37197 m .423 .38919 L .44951 .39419 L p
1 g
F P
s
P
p
.002 w
.44951 .39419 m .45318 .38554 L .43026 .37197 L p
1 g
F P
s
P
p
.002 w
.49587 .34779 m .47749 .34515 L .47691 .37204 L p
1 g
F P
s
P
p
.002 w
.46767 .37382 m .47691 .37204 L .47749 .34515 L p
1 g
F P
s
P
p
.002 w
.43098 .50137 m .46465 .51139 L .4666 .48448 L p
1 g
F P
s
P
p
.002 w
.4666 .48448 m .44075 .47669 L .43098 .50137 L p
1 g
F P
s
P
p
.002 w
.40342 .43873 m .41888 .4609 L .43703 .44049 L p
1 g
F P
s
P
p
.002 w
.43703 .44049 m .42662 .42544 L .40342 .43873 L p
1 g
F P
s
P
p
.002 w
.44275 .35793 m .43026 .37197 L .45318 .38554 L p
1 g
F P
s
P
p
.002 w
.45318 .38554 m .45946 .37849 L .44275 .35793 L p
1 g
F P
s
P
p
.002 w
.47749 .34515 m .4591 .34865 L .46767 .37382 L p
1 g
F P
s
P
p
.002 w
.45946 .37849 m .46767 .37382 L .4591 .34865 L p
1 g
F P
s
P
p
.002 w
.57956 .44574 m .58825 .41161 L .56161 .40776 L p
1 g
F P
s
P
p
.002 w
.5594 .38086 m .56161 .40776 L .58825 .41161 L p
1 g
F P
s
P
p
.002 w
.5594 .38086 m .5485 .35619 L .52481 .36957 L p
1 g
F P
s
P
p
.002 w
.51224 .35626 m .52481 .36957 L .5485 .35619 L p
1 g
F P
s
P
p
.002 w
.4591 .34865 m .44275 .35793 L .45946 .37849 L p
1 g
F P
s
P
p
.002 w
.39613 .41252 m .40342 .43873 L .42662 .42544 L p
1 g
F P
s
P
p
.002 w
.42662 .42544 m .42175 .4077 L .39613 .41252 L p
1 g
F P
s
P
p
.002 w
.50614 .53511 m .54613 .52002 L .53293 .49763 L p
1 g
F P
s
P
p
.002 w
.53293 .49763 m .49986 .51007 L .50614 .53511 L p
1 g
F P
s
P
p
.002 w
.56045 .47543 m .53293 .49763 L .54613 .52002 L p
1 g
F P
s
P
p
.002 w
.40243 .48092 m .43098 .50137 L .44075 .47669 L p
1 g
F P
s
P
p
.002 w
.44075 .47669 m .41888 .4609 L .40243 .48092 L p
1 g
F P
s
P
p
.002 w
.5485 .35619 m .53001 .33645 L .51224 .35626 L p
1 g
F P
s
P
p
.002 w
.49587 .34779 m .51224 .35626 L .53001 .33645 L p
1 g
F P
s
P
p
.002 w
.54613 .52002 m .57942 .49317 L .56045 .47543 L p
1 g
F P
s
P
p
.002 w
.57956 .44574 m .56045 .47543 L .57942 .49317 L p
1 g
F P
s
P
p
.002 w
.58825 .41161 m .58548 .3766 L .5594 .38086 L p
1 g
F P
s
P
p
.002 w
.5485 .35619 m .5594 .38086 L .58548 .3766 L p
1 g
F P
s
P
p
.002 w
.46354 .53681 m .50614 .53511 L .49986 .51007 L p
1 g
F P
s
P
p
.002 w
.49986 .51007 m .46465 .51139 L .46354 .53681 L p
1 g
F P
s
P
p
.002 w
.57942 .49317 m .6026 .45728 L .57956 .44574 L p
1 g
F P
s
P
p
.002 w
.58825 .41161 m .57956 .44574 L .6026 .45728 L p
1 g
F P
s
P
p
.002 w
.39789 .38512 m .39613 .41252 L .42175 .4077 L p
1 g
F P
s
P
p
.002 w
.42175 .4077 m .423 .38919 L .39789 .38512 L p
1 g
F P
s
P
p
.002 w
.53001 .33645 m .50585 .32384 L .49587 .34779 L p
1 g
F P
s
P
p
.002 w
.47749 .34515 m .49587 .34779 L .50585 .32384 L p
1 g
F P
s
P
p
.002 w
.38216 .45209 m .40243 .48092 L .41888 .4609 L p
1 g
F P
s
P
p
.002 w
.41888 .4609 m .40342 .43873 L .38216 .45209 L p
1 g
F P
s
P
p
.002 w
.4086 .35957 m .39789 .38512 L .423 .38919 L p
1 g
F P
s
P
p
.002 w
.423 .38919 m .43026 .37197 L .4086 .35957 L p
1 g
F P
s
P
p
.002 w
.42273 .52479 m .46354 .53681 L .46465 .51139 L p
1 g
F P
s
P
p
.002 w
.46465 .51139 m .43098 .50137 L .42273 .52479 L p
1 g
F P
s
P
p
.002 w
.50585 .32384 m .47863 .31985 L .47749 .34515 L p
1 g
F P
s
P
p
.002 w
.4591 .34865 m .47749 .34515 L .47863 .31985 L p
1 g
F P
s
P
p
.002 w
.58548 .3766 m .57142 .34441 L .5485 .35619 L p
1 g
F P
s
P
p
.002 w
.53001 .33645 m .5485 .35619 L .57142 .34441 L p
1 g
F P
s
P
p
.002 w
.6026 .45728 m .61321 .41601 L .58825 .41161 L p
1 g
F P
s
P
p
.002 w
.58548 .3766 m .58825 .41161 L .61321 .41601 L p
1 g
F P
s
P
p
.002 w
.42711 .33875 m .4086 .35957 L .43026 .37197 L p
1 g
F P
s
P
p
.002 w
.43026 .37197 m .44275 .35793 L .42711 .33875 L p
1 g
F P
s
P
p
.002 w
.47863 .31985 m .45137 .325 L .4591 .34865 L p
1 g
F P
s
P
p
.002 w
.44275 .35793 m .4591 .34865 L .45137 .325 L p
1 g
F P
s
P
p
.002 w
.45137 .325 m .42711 .33875 L .44275 .35793 L p
1 g
F P
s
P
p
.002 w
.37253 .41791 m .38216 .45209 L .40342 .43873 L p
1 g
F P
s
P
p
.002 w
.40342 .43873 m .39613 .41252 L .37253 .41791 L p
1 g
F P
s
P
p
.002 w
.57142 .34441 m .54739 .31857 L .53001 .33645 L p
1 g
F P
s
P
p
.002 w
.50585 .32384 m .53001 .33645 L .54739 .31857 L p
1 g
F P
s
P
p
.002 w
.38804 .50013 m .42273 .52479 L .43098 .50137 L p
1 g
F P
s
P
p
.002 w
.43098 .50137 m .40243 .48092 L .38804 .50013 L p
1 g
F P
s
P
p
.002 w
.51242 .55812 m .55848 .54069 L .54613 .52002 L p
1 g
F P
s
P
p
.002 w
.54613 .52002 m .50614 .53511 L .51242 .55812 L p
1 g
F P
s
P
p
.002 w
.57942 .49317 m .54613 .52002 L .55848 .54069 L p
1 g
F P
s
P
p
.002 w
.61321 .41601 m .60999 .37359 L .58548 .3766 L p
1 g
F P
s
P
p
.002 w
.57142 .34441 m .58548 .3766 L .60999 .37359 L p
1 g
F P
s
P
p
.002 w
.55848 .54069 m .59684 .50975 L .57942 .49317 L p
1 g
F P
s
P
p
.002 w
.6026 .45728 m .57942 .49317 L .59684 .50975 L p
1 g
F P
s
P
p
.002 w
.46332 .56018 m .51242 .55812 L .50614 .53511 L p
1 g
F P
s
P
p
.002 w
.50614 .53511 m .46354 .53681 L .46332 .56018 L p
1 g
F P
s
P
p
.002 w
.37474 .38209 m .37253 .41791 L .39613 .41252 L p
1 g
F P
s
P
p
.002 w
.39613 .41252 m .39789 .38512 L .37474 .38209 L p
1 g
F P
s
P
p
.002 w
.59684 .50975 m .6236 .46842 L .6026 .45728 L p
1 g
F P
s
P
p
.002 w
.61321 .41601 m .6026 .45728 L .6236 .46842 L p
1 g
F P
s
P
p
.002 w
.54739 .31857 m .5159 .30201 L .50585 .32384 L p
1 g
F P
s
P
p
.002 w
.47863 .31985 m .50585 .32384 L .5159 .30201 L p
1 g
F P
s
P
p
.002 w
.36333 .46524 m .38804 .50013 L .40243 .48092 L p
1 g
F P
s
P
p
.002 w
.40243 .48092 m .38216 .45209 L .36333 .46524 L p
1 g
F P
s
P
p
.002 w
.38869 .34865 m .37474 .38209 L .39789 .38512 L p
1 g
F P
s
P
p
.002 w
.39789 .38512 m .4086 .35957 L .38869 .34865 L p
1 g
F P
s
P
p
.002 w
.60999 .37359 m .59308 .33451 L .57142 .34441 L p
1 g
F P
s
P
p
.002 w
.54739 .31857 m .57142 .34441 L .59308 .33451 L p
1 g
F P
s
P
p
.002 w
.41621 .54645 m .46332 .56018 L .46354 .53681 L p
1 g
F P
s
P
p
.002 w
.46354 .53681 m .42273 .52479 L .41621 .54645 L p
1 g
F P
s
P
p
.002 w
.5159 .30201 m .48033 .29671 L .47863 .31985 L p
1 g
F P
s
P
p
.002 w
.45137 .325 m .47863 .31985 L .48033 .29671 L p
1 g
F P
s
P
p
.002 w
.6236 .46842 m .63594 .42087 L .61321 .41601 L p
1 g
F P
s
P
p
.002 w
.60999 .37359 m .61321 .41601 L .63594 .42087 L p
1 g
F P
s
P
p
.002 w
.4129 .32137 m .38869 .34865 L .4086 .35957 L p
1 g
F P
s
P
p
.002 w
.4086 .35957 m .42711 .33875 L .4129 .32137 L p
1 g
F P
s
P
p
.002 w
.48033 .29671 m .44466 .30339 L .45137 .325 L p
1 g
F P
s
P
p
.002 w
.42711 .33875 m .45137 .325 L .44466 .30339 L p
1 g
F P
s
P
p
.002 w
.44466 .30339 m .4129 .32137 L .42711 .33875 L p
1 g
F P
s
P
p
.002 w
.3515 .42376 m .36333 .46524 L .38216 .45209 L p
1 g
F P
s
P
p
.002 w
.38216 .45209 m .37253 .41791 L .3515 .42376 L p
1 g
F P
s
P
p
.002 w
.59308 .33451 m .56403 .30306 L .54739 .31857 L p
1 g
F P
s
P
p
.002 w
.5159 .30201 m .54739 .31857 L .56403 .30306 L p
1 g
F P
s
P
p
.002 w
.37609 .51811 m .41621 .54645 L .42273 .52479 L p
1 g
F P
s
P
p
.002 w
.42273 .52479 m .38804 .50013 L .37609 .51811 L p
1 g
F P
s
P
p
.002 w
.63594 .42087 m .63237 .37194 L .60999 .37359 L p
1 g
F P
s
P
p
.002 w
.59308 .33451 m .60999 .37359 L .63237 .37194 L p
1 g
F P
s
P
p
.002 w
.51856 .57855 m .56969 .55914 L .55848 .54069 L p
1 g
F P
s
P
p
.002 w
.55848 .54069 m .51242 .55812 L .51856 .57855 L p
1 g
F P
s
P
p
.002 w
.59684 .50975 m .55848 .54069 L .56969 .55914 L p
1 g
F P
s
P
p
.002 w
.56969 .55914 m .6123 .52478 L .59684 .50975 L p
1 g
F P
s
P
p
.002 w
.6236 .46842 m .59684 .50975 L .6123 .52478 L p
1 g
F P
s
P
p
.002 w
.35409 .38021 m .3515 .42376 L .37253 .41791 L p
1 g
F P
s
P
p
.002 w
.37253 .41791 m .37474 .38209 L .35409 .38021 L p
1 g
F P
s
P
p
.002 w
.46402 .58094 m .51856 .57855 L .51242 .55812 L p
1 g
F P
s
P
p
.002 w
.51242 .55812 m .46332 .56018 L .46402 .58094 L p
1 g
F P
s
P
p
.002 w
.6123 .52478 m .64207 .47892 L .6236 .46842 L p
1 g
F P
s
P
p
.002 w
.63594 .42087 m .6236 .46842 L .64207 .47892 L p
1 g
F P
s
P
p
.002 w
.56403 .30306 m .52583 .28283 L .5159 .30201 L p
1 g
F P
s
P
p
.002 w
.48033 .29671 m .5159 .30201 L .52583 .28283 L p
1 g
F P
s
P
p
.002 w
.34743 .4779 m .37609 .51811 L .38804 .50013 L p
1 g
F P
s
P
p
.002 w
.38804 .50013 m .36333 .46524 L .34743 .4779 L p
1 g
F P
s
P
p
.002 w
.63237 .37194 m .61299 .32677 L .59308 .33451 L p
1 g
F P
s
P
p
.002 w
.56403 .30306 m .59308 .33451 L .61299 .32677 L p
1 g
F P
s
P
p
.002 w
.37101 .33947 m .35409 .38021 L .37474 .38209 L p
1 g
F P
s
P
p
.002 w
.37474 .38209 m .38869 .34865 L .37101 .33947 L p
1 g
F P
s
P
p
.002 w
.41164 .56581 m .46402 .58094 L .46332 .56018 L p
1 g
F P
s
P
p
.002 w
.46332 .56018 m .41621 .54645 L .41164 .56581 L p
1 g
F P
s
P
p
.002 w
.52583 .28283 m .48259 .27629 L .48033 .29671 L p
1 g
F P
s
P
p
.002 w
.44466 .30339 m .48033 .29671 L .48259 .27629 L p
1 g
F P
s
P
p
.002 w
.64207 .47892 m .65588 .42613 L .63594 .42087 L p
1 g
F P
s
P
p
.002 w
.63237 .37194 m .63594 .42087 L .65588 .42613 L p
1 g
F P
s
P
p
.002 w
.40048 .30625 m .37101 .33947 L .38869 .34865 L p
1 g
F P
s
P
p
.002 w
.38869 .34865 m .4129 .32137 L .40048 .30625 L p
1 g
F P
s
P
p
.002 w
.48259 .27629 m .43915 .28436 L .44466 .30339 L p
1 g
F P
s
P
p
.002 w
.4129 .32137 m .44466 .30339 L .43915 .28436 L p
1 g
F P
s
P
p
.002 w
.43915 .28436 m .40048 .30625 L .4129 .32137 L p
1 g
F P
s
P
p
.002 w
.33362 .42998 m .34743 .4779 L .36333 .46524 L p
1 g
F P
s
P
p
.002 w
.36333 .46524 m .3515 .42376 L .33362 .42998 L p
1 g
F P
s
P
p
.002 w
.61299 .32677 m .57955 .29033 L .56403 .30306 L p
1 g
F P
s
P
p
.002 w
.52583 .28283 m .56403 .30306 L .57955 .29033 L p
1 g
F P
s
P
p
.002 w
.36696 .53443 m .41164 .56581 L .41621 .54645 L p
1 g
F P
s
P
p
.002 w
.41621 .54645 m .37609 .51811 L .36696 .53443 L p
1 g
F P
s
P
p
.002 w
.65588 .42613 m .65206 .37174 L .63237 .37194 L p
1 g
F P
s
P
p
.002 w
.61299 .32677 m .63237 .37194 L .65206 .37174 L p
1 g
F P
s
P
p
.002 w
.52443 .59584 m .57949 .57489 L .56969 .55914 L p
1 g
F P
s
P
p
.002 w
.56969 .55914 m .51856 .57855 L .52443 .59584 L p
1 g
F P
s
P
p
.002 w
.6123 .52478 m .56969 .55914 L .57949 .57489 L p
1 g
F P
s
P
p
.002 w
.57949 .57489 m .62537 .53789 L .6123 .52478 L p
1 g
F P
s
P
p
.002 w
.64207 .47892 m .6123 .52478 L .62537 .53789 L p
1 g
F P
s
P
p
.002 w
.33651 .37956 m .33362 .42998 L .3515 .42376 L p
1 g
F P
s
P
p
.002 w
.3515 .42376 m .35409 .38021 L .33651 .37956 L p
1 g
F P
s
P
p
.002 w
.46568 .5985 m .52443 .59584 L .51856 .57855 L p
1 g
F P
s
P
p
.002 w
.51856 .57855 m .46402 .58094 L .46568 .5985 L p
1 g
F P
s
P
p
.002 w
.57955 .29033 m .53542 .26683 L .52583 .28283 L p
1 g
F P
s
P
p
.002 w
.48259 .27629 m .52583 .28283 L .53542 .26683 L p
1 g
F P
s
P
p
.002 w
.62537 .53789 m .65749 .48853 L .64207 .47892 L p
1 g
F P
s
P
p
.002 w
.65588 .42613 m .64207 .47892 L .65749 .48853 L p
1 g
F P
s
P
p
.002 w
.33495 .48977 m .36696 .53443 L .37609 .51811 L p
1 g
F P
s
P
p
.002 w
.37609 .51811 m .34743 .4779 L .33495 .48977 L p
1 g
F P
s
P
p
.002 w
.65206 .37174 m .63064 .32146 L .61299 .32677 L p
1 g
F P
s
P
p
.002 w
.57955 .29033 m .61299 .32677 L .63064 .32146 L p
1 g
F P
s
P
p
.002 w
.35606 .33235 m .33651 .37956 L .35409 .38021 L p
1 g
F P
s
P
p
.002 w
.35409 .38021 m .37101 .33947 L .35606 .33235 L p
1 g
F P
s
P
p
.002 w
.40922 .58232 m .46568 .5985 L .46402 .58094 L p
1 g
F P
s
P
p
.002 w
.46402 .58094 m .41164 .56581 L .40922 .58232 L p
1 g
F P
s
P
p
.002 w
.53542 .26683 m .48538 .25916 L .48259 .27629 L p
1 g
F P
s
P
p
.002 w
.43915 .28436 m .48259 .27629 L .48538 .25916 L p
1 g
F P
s
P
p
.002 w
.65749 .48853 m .67246 .43168 L .65588 .42613 L p
1 g
F P
s
P
p
.002 w
.65206 .37174 m .65588 .42613 L .67246 .43168 L p
1 g
F P
s
P
p
.002 w
.3902 .29382 m .35606 .33235 L .37101 .33947 L p
1 g
F P
s
P
p
.002 w
.37101 .33947 m .40048 .30625 L .3902 .29382 L p
1 g
F P
s
P
p
.002 w
.48538 .25916 m .43504 .26846 L .43915 .28436 L p
1 g
F P
s
P
p
.002 w
.40048 .30625 m .43915 .28436 L .43504 .26846 L p
1 g
F P
s
P
p
.002 w
.43504 .26846 m .3902 .29382 L .40048 .30625 L p
1 g
F P
s
P
p
.002 w
.31946 .43644 m .33495 .48977 L .34743 .4779 L p
1 g
F P
s
P
p
.002 w
.34743 .4779 m .33362 .42998 L .31946 .43644 L p
1 g
F P
s
P
p
.002 w
.63064 .32146 m .59353 .28082 L .57955 .29033 L p
1 g
F P
s
P
p
.002 w
.53542 .26683 m .57955 .29033 L .59353 .28082 L p
1 g
F P
s
P
p
.002 w
.36099 .5486 m .40922 .58232 L .41164 .56581 L p
1 g
F P
s
P
p
.002 w
.41164 .56581 m .36696 .53443 L .36099 .5486 L p
1 g
F P
s
P
p
.002 w
.67246 .43168 m .66846 .37308 L .65206 .37174 L p
1 g
F P
s
P
p
.002 w
.63064 .32146 m .65206 .37174 L .66846 .37308 L p
1 g
F P
s
P
p
.002 w
.52987 .60943 m .58755 .58744 L .57949 .57489 L p
1 g
F P
s
P
p
.002 w
.57949 .57489 m .52443 .59584 L .52987 .60943 L p
1 g
F P
s
P
p
.002 w
.62537 .53789 m .57949 .57489 L .58755 .58744 L p
1 g
F P
s
P
p
.002 w
.58755 .58744 m .63565 .54867 L .62537 .53789 L p
1 g
F P
s
P
p
.002 w
.65749 .48853 m .62537 .53789 L .63565 .54867 L p
1 g
F P
s
P
p
.002 w
.3226 .38024 m .31946 .43644 L .33362 .42998 L p
1 g
F P
s
P
p
.002 w
.33362 .42998 m .33651 .37956 L .3226 .38024 L p
1 g
F P
s
P
p
.002 w
.46831 .61229 m .52987 .60943 L .52443 .59584 L p
1 g
F P
s
P
p
.002 w
.52443 .59584 m .46568 .5985 L .46831 .61229 L p
1 g
F P
s
P
p
.002 w
.59353 .28082 m .54444 .25454 L .53542 .26683 L p
1 g
F P
s
P
p
.002 w
.48538 .25916 m .53542 .26683 L .54444 .25454 L p
1 g
F P
s
P
p
.002 w
.63565 .54867 m .66934 .49696 L .65749 .48853 L p
1 g
F P
s
P
p
.002 w
.67246 .43168 m .65749 .48853 L .66934 .49696 L p
1 g
F P
s
P
p
.002 w
.32638 .50052 m .36099 .5486 L .36696 .53443 L p
1 g
F P
s
P
p
.002 w
.36696 .53443 m .33495 .48977 L .32638 .50052 L p
1 g
F P
s
P
p
.002 w
.66846 .37308 m .64549 .31884 L .63064 .32146 L p
1 g
F P
s
P
p
.002 w
.59353 .28082 m .63064 .32146 L .64549 .31884 L p
1 g
F P
s
P
p
.002 w
.34435 .32755 m .3226 .38024 L .33651 .37956 L p
1 g
F P
s
P
p
.002 w
.33651 .37956 m .35606 .33235 L .34435 .32755 L p
1 g
F P
s
P
p
.002 w
.40912 .59543 m .46831 .61229 L .46568 .5985 L p
1 g
F P
s
P
p
.002 w
.46568 .5985 m .40922 .58232 L .40912 .59543 L p
1 g
F P
s
P
p
.002 w
.54444 .25454 m .48866 .24592 L .48538 .25916 L p
1 g
F P
s
P
p
.002 w
.43504 .26846 m .48538 .25916 L .48866 .24592 L p
1 g
F P
s
P
p
.002 w
.66934 .49696 m .6851 .43741 L .67246 .43168 L p
1 g
F P
s
P
p
.002 w
.66846 .37308 m .67246 .43168 L .6851 .43741 L p
1 g
F P
s
P
p
.002 w
.38243 .28453 m .34435 .32755 L .35606 .33235 L p
1 g
F P
s
P
p
.002 w
.35606 .33235 m .3902 .29382 L .38243 .28453 L p
1 g
F P
s
P
p
.002 w
.48866 .24592 m .43249 .25624 L .43504 .26846 L p
1 g
F P
s
P
p
.002 w
.3902 .29382 m .43504 .26846 L .43249 .25624 L p
1 g
F P
s
P
p
.002 w
.43249 .25624 m .38243 .28453 L .3902 .29382 L p
1 g
F P
s
P
p
.002 w
.30957 .443 m .32638 .50052 L .33495 .48977 L p
1 g
F P
s
P
p
.002 w
.33495 .48977 m .31946 .43644 L .30957 .443 L p
1 g
F P
s
P
p
.002 w
.64549 .31884 m .60556 .27493 L .59353 .28082 L p
1 g
F P
s
P
p
.002 w
.54444 .25454 m .59353 .28082 L .60556 .27493 L p
1 g
F P
s
P
p
.002 w
.35852 .56017 m .40912 .59543 L .40922 .58232 L p
1 g
F P
s
P
p
.002 w
.40922 .58232 m .36099 .5486 L .35852 .56017 L p
1 g
F P
s
P
p
.002 w
.6851 .43741 m .68101 .376 L .66846 .37308 L p
1 g
F P
s
P
p
.002 w
.64549 .31884 m .66846 .37308 L .68101 .376 L p
1 g
F P
s
P
p
.002 w
.53473 .61876 m .5936 .59629 L .58755 .58744 L p
1 g
F P
s
P
p
.002 w
.58755 .58744 m .52987 .60943 L .53473 .61876 L p
1 g
F P
s
P
p
.002 w
.63565 .54867 m .58755 .58744 L .5936 .59629 L p
1 g
F P
s
P
p
.002 w
.5936 .59629 m .6427 .55671 L .63565 .54867 L p
1 g
F P
s
P
p
.002 w
.66934 .49696 m .63565 .54867 L .6427 .55671 L p
1 g
F P
s
P
p
.002 w
.31289 .3823 m .30957 .443 L .31946 .43644 L p
1 g
F P
s
P
p
.002 w
.31946 .43644 m .3226 .38024 L .31289 .3823 L p
1 g
F P
s
P
p
.002 w
.47191 .62173 m .53473 .61876 L .52987 .60943 L p
1 g
F P
s
P
p
.002 w
.52987 .60943 m .46831 .61229 L .47191 .62173 L p
1 g
F P
s
P
p
.002 w
.60556 .27493 m .55262 .24649 L .54444 .25454 L p
1 g
F P
s
P
p
.002 w
.48866 .24592 m .54444 .25454 L .55262 .24649 L p
1 g
F P
s
P
p
.002 w
.6427 .55671 m .67712 .50395 L .66934 .49696 L p
1 g
F P
s
P
p
.002 w
.6851 .43741 m .66934 .49696 L .67712 .50395 L p
1 g
F P
s
P
p
.002 w
.32217 .50981 m .35852 .56017 L .36099 .5486 L p
1 g
F P
s
P
p
.002 w
.36099 .5486 m .32638 .50052 L .32217 .50981 L p
1 g
F P
s
P
p
.002 w
.68101 .376 m .65703 .31911 L .64549 .31884 L p
1 g
F P
s
P
p
.002 w
.60556 .27493 m .64549 .31884 L .65703 .31911 L p
1 g
F P
s
P
p
.002 w
.33637 .32534 m .31289 .3823 L .3226 .38024 L p
1 g
F P
s
P
p
.002 w
.3226 .38024 m .34435 .32755 L .33637 .32534 L p
1 g
F P
s
P
p
.002 w
.41149 .60459 m .47191 .62173 L .46831 .61229 L p
1 g
F P
s
P
p
.002 w
.46831 .61229 m .40912 .59543 L .41149 .60459 L p
1 g
F P
s
P
p
.002 w
.55262 .24649 m .49239 .23711 L .48866 .24592 L p
1 g
F P
s
P
p
.002 w
.43249 .25624 m .48866 .24592 L .49239 .23711 L p
1 g
F P
s
P
p
.002 w
.67712 .50395 m .69326 .4432 L .6851 .43741 L p
1 g
F P
s
P
p
.002 w
.68101 .376 m .6851 .43741 L .69326 .4432 L p
1 g
F P
s
P
p
.002 w
.37754 .27882 m .33637 .32534 L .34435 .32755 L p
1 g
F P
s
P
p
.002 w
.34435 .32755 m .38243 .28453 L .37754 .27882 L p
1 g
F P
s
P
p
.002 w
.49239 .23711 m .43167 .24824 L .43249 .25624 L p
1 g
F P
s
P
p
.002 w
.38243 .28453 m .43249 .25624 L .43167 .24824 L p
1 g
F P
s
P
p
.002 w
.30449 .44949 m .32217 .50981 L .32638 .50052 L p
1 g
F P
s
P
p
.002 w
.32638 .50052 m .30957 .443 L .30449 .44949 L p
1 g
F P
s
P
p
.002 w
.43167 .24824 m .37754 .27882 L .38243 .28453 L p
1 g
F P
s
P
p
.002 w
.65703 .31911 m .61522 .27303 L .60556 .27493 L p
1 g
F P
s
P
p
.002 w
.55262 .24649 m .60556 .27493 L .61522 .27303 L p
1 g
F P
s
P
p
.002 w
.35983 .56866 m .41149 .60459 L .40912 .59543 L p
1 g
F P
s
P
p
.002 w
.40912 .59543 m .35852 .56017 L .35983 .56866 L p
1 g
F P
s
P
p
.002 w
.69326 .4432 m .68915 .38052 L .68101 .376 L p
1 g
F P
s
P
p
.002 w
.65703 .31911 m .68101 .376 L .68915 .38052 L p
1 g
F P
s
P
p
.002 w
.53885 .62333 m .59735 .60098 L .5936 .59629 L p
1 g
F P
s
P
p
.002 w
.5936 .59629 m .53473 .61876 L .53885 .62333 L p
1 g
F P
s
P
p
.002 w
.6427 .55671 m .5936 .59629 L .59735 .60098 L p
1 g
F P
s
P
p
.002 w
.59735 .60098 m .64615 .56165 L .6427 .55671 L p
1 g
F P
s
P
p
.002 w
.67712 .50395 m .6427 .55671 L .64615 .56165 L p
1 g
F P
s
P
p
.002 w
.30794 .38578 m .30449 .44949 L .30957 .443 L p
1 g
F P
s
P
p
.002 w
.30957 .443 m .31289 .3823 L .30794 .38578 L p
1 g
F P
s
P
p
.002 w
.61522 .27303 m .55971 .24315 L .55262 .24649 L p
1 g
F P
s
P
p
.002 w
.49239 .23711 m .55262 .24649 L .55971 .24315 L p
1 g
F P
s
P
p
.002 w
.47644 .62631 m .53885 .62333 L .53473 .61876 L p
1 g
F P
s
P
p
.002 w
.53473 .61876 m .47191 .62173 L .47644 .62631 L p
1 g
F P
s
P
p
.002 w
.64615 .56165 m .68037 .50923 L .67712 .50395 L p
1 g
F P
s
P
p
.002 w
.69326 .4432 m .67712 .50395 L .68037 .50923 L p
1 g
F P
s
P
p
.002 w
.32272 .5173 m .35983 .56866 L .35852 .56017 L p
1 g
F P
s
P
p
.002 w
.35852 .56017 m .32217 .50981 L .32272 .5173 L p
1 g
F P
s
P
p
.002 w
.68915 .38052 m .66473 .32247 L .65703 .31911 L p
1 g
F P
s
P
p
.002 w
.61522 .27303 m .65703 .31911 L .66473 .32247 L p
1 g
F P
s
P
p
.002 w
.33258 .32596 m .30794 .38578 L .31289 .3823 L p
1 g
F P
s
P
p
.002 w
.31289 .3823 m .33637 .32534 L .33258 .32596 L p
1 g
F P
s
P
p
.002 w
.41643 .60931 m .47644 .62631 L .47191 .62173 L p
1 g
F P
s
P
p
.002 w
.47191 .62173 m .41149 .60459 L .41643 .60931 L p
1 g
F P
s
P
p
.002 w
.55971 .24315 m .49649 .23327 L .49239 .23711 L p
1 g
F P
s
P
p
.002 w
.43167 .24824 m .49239 .23711 L .49649 .23327 L p
1 g
F P
s
P
p
.002 w
.68037 .50923 m .69643 .44888 L .69326 .4432 L p
1 g
F P
s
P
p
.002 w
.68915 .38052 m .69326 .4432 L .69643 .44888 L p
1 g
F P
s
P
p
.002 w
.37583 .27708 m .33258 .32596 L .33637 .32534 L p
1 g
F P
s
P
p
.002 w
.33637 .32534 m .37754 .27882 L .37583 .27708 L p
1 g
F P
s
P
p
.002 w
.49649 .23327 m .4327 .24495 L .43167 .24824 L p
1 g
F P
s
P
p
.002 w
.37754 .27882 m .43167 .24824 L .4327 .24495 L p
1 g
F P
s
P
p
.002 w
.30465 .45574 m .32272 .5173 L .32217 .50981 L p
1 g
F P
s
P
p
.002 w
.32217 .50981 m .30449 .44949 L .30465 .45574 L p
1 g
F P
s
P
p
.002 w
.4327 .24495 m .37583 .27708 L .37754 .27882 L p
1 g
F P
s
P
p
.002 w
.66473 .32247 m .62209 .27542 L .61522 .27303 L p
1 g
F P
s
P
p
.002 w
.55971 .24315 m .61522 .27303 L .62209 .27542 L p
1 g
F P
s
P
p
.002 w
.36514 .57365 m .41643 .60931 L .41149 .60459 L p
1 g
F P
s
P
p
.002 w
.41149 .60459 m .35983 .56866 L .36514 .57365 L p
1 g
F P
s
P
p
.002 w
.69643 .44888 m .69237 .38664 L .68915 .38052 L p
1 g
F P
s
P
p
.002 w
.66473 .32247 m .68915 .38052 L .69237 .38664 L p
1 g
F P
s
P
p
.004 w
.27596 .37764 m
.28736 .38033 L
s
P
p
.004 w
.26983 .37619 m
.27596 .37764 L
s
P
p
.002 w
.54206 .62269 m .59854 .60111 L .59735 .60098 L p
1 g
F P
s
P
p
.002 w
.59735 .60098 m .53885 .62333 L .54206 .62269 L p
1 g
F P
s
P
p
.002 w
.64615 .56165 m .59735 .60098 L .59854 .60111 L p
1 g
F P
s
P
p
.002 w
.59854 .60111 m .64566 .56313 L .64615 .56165 L p
1 g
F P
s
P
p
.002 w
.68037 .50923 m .64615 .56165 L .64566 .56313 L p
1 g
F P
s
P
p
.002 w
.30818 .39068 m .30465 .45574 L .30449 .44949 L p
1 g
F P
s
P
p
.002 w
.30449 .44949 m .30794 .38578 L .30818 .39068 L p
1 g
F P
s
P
p
.002 w
.62209 .27542 m .56544 .24491 L .55971 .24315 L p
1 g
F P
s
P
p
.002 w
.49649 .23327 m .55971 .24315 L .56544 .24491 L p
1 g
F P
s
P
p
.002 w
.48183 .62556 m .54206 .62269 L .53885 .62333 L p
1 g
F P
s
P
p
.002 w
.53885 .62333 m .47644 .62631 L .48183 .62556 L p
1 g
F P
s
P
p
.002 w
.64566 .56313 m .67869 .51253 L .68037 .50923 L p
1 g
F P
s
P
p
.002 w
.69643 .44888 m .68037 .50923 L .67869 .51253 L p
1 g
F P
s
P
p
.002 w
.32831 .52266 m .36514 .57365 L .35983 .56866 L p
1 g
F P
s
P
p
.002 w
.35983 .56866 m .32272 .5173 L .32831 .52266 L p
1 g
F P
s
P
p
.002 w
.69237 .38664 m .66813 .32901 L .66473 .32247 L p
1 g
F P
s
P
p
.002 w
.62209 .27542 m .66473 .32247 L .66813 .32901 L p
1 g
F P
s
P
p
.002 w
.33337 .32956 m .30818 .39068 L .30794 .38578 L p
1 g
F P
s
P
p
.002 w
.30794 .38578 m .33258 .32596 L .33337 .32956 L p
1 g
F P
s
P
p
.002 w
.42396 .60915 m .48183 .62556 L .47644 .62631 L p
1 g
F P
s
P
p
.002 w
.47644 .62631 m .41643 .60931 L .42396 .60915 L p
1 g
F P
s
P
p
.002 w
.56544 .24491 m .50086 .23483 L .49649 .23327 L p
1 g
F P
s
P
p
.002 w
.4327 .24495 m .49649 .23327 L .50086 .23483 L p
1 g
F P
s
P
p
.002 w
.67869 .51253 m .69419 .45429 L .69643 .44888 L p
1 g
F P
s
P
p
.002 w
.69237 .38664 m .69643 .44888 L .69419 .45429 L p
1 g
F P
s
P
p
.002 w
.37757 .27961 m .33337 .32956 L .33258 .32596 L p
1 g
F P
s
P
p
.002 w
.33258 .32596 m .37583 .27708 L .37757 .27961 L p
1 g
F P
s
P
p
.002 w
.31041 .46154 m .32831 .52266 L .32272 .5173 L p
1 g
F P
s
P
p
.002 w
.32272 .5173 m .30465 .45574 L .31041 .46154 L p
1 g
F P
s
P
p
.002 w
.50086 .23483 m .43569 .24677 L .4327 .24495 L p
1 g
F P
s
P
p
.002 w
.37583 .27708 m .4327 .24495 L .43569 .24677 L p
1 g
F P
s
P
p
.002 w
.43569 .24677 m .37757 .27961 L .37583 .27708 L p
1 g
F P
s
P
p
.002 w
.66813 .32901 m .62579 .28232 L .62209 .27542 L p
1 g
F P
s
P
p
.002 w
.56544 .24491 m .62209 .27542 L .62579 .28232 L p
1 g
F P
s
P
p
.002 w
.37454 .57475 m .42396 .60915 L .41643 .60931 L p
1 g
F P
s
P
p
.002 w
.41643 .60931 m .36514 .57365 L .37454 .57475 L p
1 g
F P
s
P
p
.002 w
.69419 .45429 m .69025 .39428 L .69237 .38664 L p
1 g
F P
s
P
p
.002 w
.66813 .32901 m .69237 .38664 L .69025 .39428 L p
1 g
F P
s
P
p
.002 w
.54421 .61651 m .59696 .59637 L .59854 .60111 L p
1 g
F P
s
P
p
.002 w
.59854 .60111 m .54206 .62269 L .54421 .61651 L p
1 g
F P
s
P
p
.002 w
.64566 .56313 m .59854 .60111 L .59696 .59637 L p
1 g
F P
s
P
p
.002 w
.59696 .59637 m .64098 .56089 L .64566 .56313 L p
1 g
F P
s
P
p
.002 w
.67869 .51253 m .64566 .56313 L .64098 .56089 L p
1 g
F P
s
P
p
.002 w
.31396 .39694 m .31041 .46154 L .30465 .45574 L p
1 g
F P
s
P
p
.002 w
.30465 .45574 m .30818 .39068 L .31396 .39694 L p
1 g
F P
s
P
p
.002 w
.62579 .28232 m .56954 .25207 L .56544 .24491 L p
1 g
F P
s
P
p
.002 w
.50086 .23483 m .56544 .24491 L .56954 .25207 L p
1 g
F P
s
P
p
.002 w
.48798 .61916 m .54421 .61651 L .54206 .62269 L p
1 g
F P
s
P
p
.002 w
.54206 .62269 m .48183 .62556 L .48798 .61916 L p
1 g
F P
s
P
p
.002 w
.33911 .52558 m .37454 .57475 L .36514 .57365 L p
1 g
F P
s
P
p
.002 w
.36514 .57365 m .32831 .52266 L .33911 .52558 L p
1 g
F P
s
P
p
.002 w
.64098 .56089 m .67182 .51362 L .67869 .51253 L p
1 g
F P
s
P
p
.002 w
.69419 .45429 m .67869 .51253 L .67182 .51362 L p
1 g
F P
s
P
p
.002 w
.69025 .39428 m .66685 .33875 L .66813 .32901 L p
1 g
F P
s
P
p
.002 w
.62579 .28232 m .66813 .32901 L .66685 .33875 L p
1 g
F P
s
P
p
.002 w
.33901 .33625 m .31396 .39694 L .30818 .39068 L p
1 g
F P
s
P
p
.002 w
.30818 .39068 m .33337 .32956 L .33901 .33625 L p
1 g
F P
s
P
p
.004 w
.28736 .38033 m
.31073 .38585 L
s
P
p
.002 w
.43402 .6038 m .48798 .61916 L .48183 .62556 L p
1 g
F P
s
P
p
.002 w
.48183 .62556 m .42396 .60915 L .43402 .6038 L p
1 g
F P
s
P
p
.002 w
.56954 .25207 m .50541 .2421 L .50086 .23483 L p
1 g
F P
s
P
p
.002 w
.43569 .24677 m .50086 .23483 L .50541 .2421 L p
1 g
F P
s
P
p
.002 w
.67182 .51362 m .68625 .45926 L .69419 .45429 L p
1 g
F P
s
P
p
.002 w
.69025 .39428 m .69419 .45429 L .68625 .45926 L p
1 g
F P
s
P
p
.002 w
.32195 .46668 m .33911 .52558 L .32831 .52266 L p
1 g
F P
s
P
p
.002 w
.32831 .52266 m .31041 .46154 L .32195 .46668 L p
1 g
F P
s
P
p
.002 w
.38294 .28663 m .33901 .33625 L .33337 .32956 L p
1 g
F P
s
P
p
.002 w
.33337 .32956 m .37757 .27961 L .38294 .28663 L p
1 g
F P
s
P
p
.002 w
.50541 .2421 m .44068 .254 L .43569 .24677 L p
1 g
F P
s
P
p
.002 w
.37757 .27961 m .43569 .24677 L .44068 .254 L p
1 g
F P
s
P
p
.002 w
.66685 .33875 m .62601 .29381 L .62579 .28232 L p
1 g
F P
s
P
p
.002 w
.56954 .25207 m .62579 .28232 L .62601 .29381 L p
1 g
F P
s
P
p
.002 w
.44068 .254 m .38294 .28663 L .37757 .27961 L p
1 g
F P
s
P
p
.002 w
.38801 .57167 m .43402 .6038 L .42396 .60915 L p
1 g
F P
s
P
p
.002 w
.42396 .60915 m .37454 .57475 L .38801 .57167 L p
1 g
F P
s
P
p
.002 w
.68625 .45926 m .68252 .40329 L .69025 .39428 L p
1 g
F P
s
P
p
.002 w
.66685 .33875 m .69025 .39428 L .68252 .40329 L p
1 g
F P
s
P
p
.002 w
.54515 .60463 m .59249 .58658 L .59696 .59637 L p
1 g
F P
s
P
p
.002 w
.59696 .59637 m .54421 .61651 L .54515 .60463 L p
1 g
F P
s
P
p
.002 w
.64098 .56089 m .59696 .59637 L .59249 .58658 L p
1 g
F P
s
P
p
.002 w
.32545 .40445 m .32195 .46668 L .31041 .46154 L p
1 g
F P
s
P
p
.002 w
.31041 .46154 m .31396 .39694 L .32545 .40445 L p
1 g
F P
s
P
p
.002 w
.59249 .58658 m .63198 .55474 L .64098 .56089 L p
1 g
F P
s
P
p
.002 w
.67182 .51362 m .64098 .56089 L .63198 .55474 L p
1 g
F P
s
P
p
.002 w
.62601 .29381 m .57178 .26474 L .56954 .25207 L p
1 g
F P
s
P
p
.002 w
.50541 .2421 m .56954 .25207 L .57178 .26474 L p
1 g
F P
s
P
p
.002 w
.49474 .60695 m .54515 .60463 L .54421 .61651 L p
1 g
F P
s
P
p
.002 w
.54421 .61651 m .48798 .61916 L .49474 .60695 L p
1 g
F P
s
P
p
.002 w
.3551 .52582 m .38801 .57167 L .37454 .57475 L p
1 g
F P
s
P
p
.002 w
.37454 .57475 m .33911 .52558 L .3551 .52582 L p
1 g
F P
s
P
p
.002 w
.63198 .55474 m .65962 .51232 L .67182 .51362 L p
1 g
F P
s
P
p
.002 w
.68625 .45926 m .67182 .51362 L .65962 .51232 L p
1 g
F P
s
P
p
.002 w
.68252 .40329 m .66063 .35158 L .66685 .33875 L p
1 g
F P
s
P
p
.002 w
.62601 .29381 m .66685 .33875 L .66063 .35158 L p
1 g
F P
s
P
p
.002 w
.34965 .346 m .32545 .40445 L .31396 .39694 L p
1 g
F P
s
P
p
.002 w
.31396 .39694 m .33901 .33625 L .34965 .346 L p
1 g
F P
s
P
p
.004 w
.31073 .38585 m
.31904 .38781 L
s
P
p
.002 w
.44643 .59311 m .49474 .60695 L .48798 .61916 L p
1 g
F P
s
P
p
.002 w
.48798 .61916 m .43402 .6038 L .44643 .59311 L p
1 g
F P
s
P
p
.002 w
.57178 .26474 m .50999 .25522 L .50541 .2421 L p
1 g
F P
s
P
p
.002 w
.44068 .254 m .50541 .2421 L .50999 .25522 L p
1 g
F P
s
P
p
.002 w
.65962 .51232 m .6725 .46358 L .68625 .45926 L p
1 g
F P
s
P
p
.002 w
.68252 .40329 m .68625 .45926 L .6725 .46358 L p
1 g
F P
s
P
p
.002 w
.33924 .47095 m .3551 .52582 L .33911 .52558 L p
1 g
F P
s
P
p
.002 w
.33911 .52558 m .32195 .46668 L .33924 .47095 L p
1 g
F P
s
P
p
.002 w
.392 .29821 m .34965 .346 L .33901 .33625 L p
1 g
F P
s
P
p
.002 w
.33901 .33625 m .38294 .28663 L .392 .29821 L p
1 g
F P
s
P
p
.002 w
.50999 .25522 m .44763 .26674 L .44068 .254 L p
1 g
F P
s
P
p
.002 w
.38294 .28663 m .44068 .254 L .44763 .26674 L p
1 g
F P
s
P
p
.002 w
.66063 .35158 m .62251 .30981 L .62601 .29381 L p
1 g
F P
s
P
p
.002 w
.57178 .26474 m .62601 .29381 L .62251 .30981 L p
1 g
F P
s
P
p
.002 w
.44763 .26674 m .392 .29821 L .38294 .28663 L p
1 g
F P
s
P
p
.002 w
.40534 .56427 m .44643 .59311 L .43402 .6038 L p
1 g
F P
s
P
p
.002 w
.43402 .6038 m .38801 .57167 L .40534 .56427 L p
1 g
F P
s
P
p
.002 w
.6725 .46358 m .66907 .41347 L .68252 .40329 L p
1 g
F P
s
P
p
.002 w
.66063 .35158 m .68252 .40329 L .66907 .41347 L p
1 g
F P
s
P
p
.002 w
.34262 .41304 m .33924 .47095 L .32195 .46668 L p
1 g
F P
s
P
p
.002 w
.32195 .46668 m .32545 .40445 L .34262 .41304 L p
1 g
F P
s
P
p
.002 w
.54479 .58707 m .58508 .57174 L .59249 .58658 L p
1 g
F P
s
P
p
.002 w
.59249 .58658 m .54515 .60463 L .54479 .58707 L p
1 g
F P
s
P
p
.002 w
.63198 .55474 m .59249 .58658 L .58508 .57174 L p
1 g
F P
s
P
p
.002 w
.58508 .57174 m .61869 .54464 L .63198 .55474 L p
1 g
F P
s
P
p
.002 w
.65962 .51232 m .63198 .55474 L .61869 .54464 L p
1 g
F P
s
P
p
.002 w
.62251 .30981 m .57197 .28286 L .57178 .26474 L p
1 g
F P
s
P
p
.002 w
.50999 .25522 m .57178 .26474 L .57197 .28286 L p
1 g
F P
s
P
p
.002 w
.37604 .5232 m .40534 .56427 L .38801 .57167 L p
1 g
F P
s
P
p
.002 w
.38801 .57167 m .3551 .52582 L .37604 .5232 L p
1 g
F P
s
P
p
.002 w
.50193 .58898 m .54479 .58707 L .54515 .60463 L p
1 g
F P
s
P
p
.002 w
.54515 .60463 m .49474 .60695 L .50193 .58898 L p
1 g
F P
s
P
p
.002 w
.61869 .54464 m .64217 .50854 L .65962 .51232 L p
1 g
F P
s
P
p
.002 w
.6725 .46358 m .65962 .51232 L .64217 .50854 L p
1 g
F P
s
P
p
.002 w
.66907 .41347 m .64938 .36727 L .66063 .35158 L p
1 g
F P
s
P
p
.002 w
.62251 .30981 m .66063 .35158 L .64938 .36727 L p
1 g
F P
s
P
p
.002 w
.46093 .57713 m .50193 .58898 L .49474 .60695 L p
1 g
F P
s
P
p
.002 w
.49474 .60695 m .44643 .59311 L .46093 .57713 L p
1 g
F P
s
P
p
.002 w
.36521 .35867 m .34262 .41304 L .32545 .40445 L p
1 g
F P
s
P
p
.002 w
.32545 .40445 m .34965 .346 L .36521 .35867 L p
1 g
F P
s
P
p
.004 w
.31904 .38781 m
.33815 .39232 L
s
P
p
.002 w
.64217 .50854 m .65305 .46708 L .6725 .46358 L p
1 g
F P
s
P
p
.002 w
.66907 .41347 m .6725 .46358 L .65305 .46708 L p
1 g
F P
s
P
p
.002 w
.57197 .28286 m .51444 .27411 L .50999 .25522 L p
1 g
F P
s
P
p
.002 w
.44763 .26674 m .50999 .25522 L .51444 .27411 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.36202 .47415 m .37604 .5232 L .3551 .52582 L p
1 g
F P
s
P
p
.002 w
.3551 .52582 m .33924 .47095 L .36202 .47415 L p
1 g
F P
s
P
p
.002 w
.40466 .31421 m .36521 .35867 L .34965 .346 L p
1 g
F P
s
P
p
.002 w
.34965 .346 m .392 .29821 L .40466 .31421 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.64938 .36727 m .6152 .33004 L .62251 .30981 L p
1 g
F P
s
P
p
.002 w
.57197 .28286 m .62251 .30981 L .6152 .33004 L p
1 g
F P
s
P
p
.002 w
.51444 .27411 m .45642 .28491 L .44763 .26674 L p
1 g
F P
s
P
p
.002 w
.392 .29821 m .44763 .26674 L .45642 .28491 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.42615 .55256 m .46093 .57713 L .44643 .59311 L p
1 g
F P
s
P
p
.002 w
.44643 .59311 m .40534 .56427 L .42615 .55256 L p
1 g
F P
s
P
p
.002 w
.45642 .28491 m .40466 .31421 L .392 .29821 L p
1 g
F P
s
P
p
.002 w
.65305 .46708 m .65002 .42455 L .66907 .41347 L p
1 g
F P
s
P
p
.002 w
.64938 .36727 m .66907 .41347 L .65002 .42455 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.36517 .42245 m .36202 .47415 L .33924 .47095 L p
1 g
F P
s
P
p
.002 w
.33924 .47095 m .34262 .41304 L .36517 .42245 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5316 .5741 L p
1 g
F P
s
P
p
.54854 .56129 m .5316 .5741 L .53793 .57055 L 1 g
F
P
p
.54479 .58707 m .52734 .57649 L .5316 .5741 L 1 g
F
P
p
.002 w
.54331 .56753 m .54354 .57051 L p
.5316 .5741 L 1 g
F P
s
P
p
.002 w
.54354 .57051 m .54479 .58707 L p
.5316 .5741 L 1 g
F P
s
P
p
.002 w
.5316 .5741 m .53128 .57265 L p
.52396 .5764 L 1 g
F P
s
P
p
.54011 .56933 m .53196 .57576 L .53781 .57152 L 1 g
F
P
p
.54854 .56129 m .53793 .57055 L .54011 .56933 L 1 g
F
P
p
.53793 .57055 m .53196 .57576 L .54011 .56933 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58033 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58033 L .52396 .5764 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.54479 .58707 m .50193 .58898 L .50447 .58091 L p
1 g
F P
s
P
p
.002 w
.51092 .58033 m .51079 .57862 L p
.50036 .58071 L 1 g
F P
s
P
p
.002 w
.50447 .58091 m .50193 .58898 L p
.49549 .58047 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46093 .57713 m .46385 .57334 L p
.46831 .57455 L 1 g
F P
s
P
p
.48733 .57968 m .47573 .57856 L .46831 .57455 L 1 g
F
P
p
.47573 .57856 m .46093 .57713 L .46831 .57455 L 1 g
F
P
p
.002 w
.46831 .57455 m .46872 .57265 L p
.45991 .56913 L 1 g
F P
s
P
p
.002 w
.4645 .57249 m .46093 .57713 L p
.45844 .56806 L 1 g
F P
s
P
p
.002 w
.46093 .57713 m .42615 .55256 L .43195 .54869 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.46093 .57713 m .43195 .54869 L .45097 .5626 L 1 g
F
P
p
.46 .57374 m .45097 .5626 L .45844 .56806 L 1 g
F
P
p
.46093 .57713 m .45097 .5626 L .46 .57374 L 1 g
F
P
p
.002 w
.45097 .5626 m .45146 .56129 L p
.44624 .55676 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45097 .5626 L p
1 g
F P
s
P
p
.002 w
.45097 .5626 m .45002 .56518 L p
.45991 .56913 L 1 g
F P
s
P
p
.46872 .57265 m .45097 .5626 L .45991 .56913 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43846 .54715 L p
1 g
F P
s
P
p
.002 w
.43195 .54869 m .43699 .54533 L p
.43846 .54715 L 1 g
F P
s
P
p
.45097 .5626 m .44193 .55599 L .43846 .54715 L 1 g
F
P
p
.44193 .55599 m .43195 .54869 L .43846 .54715 L 1 g
F
P
p
.002 w
.43846 .54715 m .43925 .54566 L p
.43584 .53891 L 1 g
F P
s
P
p
.42615 .55256 m .42972 .51789 L .43277 .52835 L 1 g
F
P
p
.002 w
.43759 .54493 m .43183 .54876 L p
.43277 .52835 L 1 g
F P
s
P
p
.002 w
.43183 .54876 m .42615 .55256 L p
.43277 .52835 L 1 g
F P
s
P
p
.002 w
.43277 .52835 m .43346 .52734 L p
.43318 .51928 L 1 g
F P
s
P
p
.43584 .53891 m .43759 .54493 L .43846 .54715 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.45146 .56129 m .43846 .54715 L .44624 .55676 L 1 g
F
P
p
.45097 .5626 m .43846 .54715 L .44986 .53674 L 1 g
F
P
p
.002 w
.43699 .54533 m .43759 .54493 L p
.43846 .54715 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43169 .52992 L p
1 g
F P
s
P
p
.43925 .54566 m .43169 .52992 L .43309 .53347 L 1 g
F
P
p
.002 w
.43759 .54493 m .44986 .53674 L p
.43846 .54715 L 1 g
F P
s
P
p
.002 w
.43169 .52992 m .43146 .53025 L p
.43309 .53347 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43377 .50954 L p
1 g
F P
s
P
p
.002 w
.43061 .5093 m .43389 .50817 L p
.43377 .50954 L 1 g
F P
s
P
p
.002 w
.43345 .51335 m .43256 .51209 L p
.43377 .50954 L 1 g
F P
s
P
p
.002 w
.43256 .51209 m .43061 .5093 L p
.43377 .50954 L 1 g
F P
s
P
p
.002 w
.43377 .50954 m .43485 .50826 L p
.43813 .50059 L 1 g
F P
s
P
p
.002 w
.43452 .50795 m .43061 .5093 L p
.4395 .49779 L 1 g
F P
s
P
p
.002 w
.43061 .5093 m .42157 .47671 L .45016 .47603 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.43061 .5093 m .43928 .49454 L .4395 .49779 L 1 g
F
P
p
.43928 .49454 m .45016 .47603 L .44272 .49121 L 1 g
F
P
p
.43928 .49454 m .44272 .49121 L .4395 .49779 L 1 g
F
P
p
.43346 .52734 m .43377 .50954 L .4336 .51158 L 1 g
F
P
p
.43346 .52734 m .43362 .50973 L .43318 .51928 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.43345 .51335 m .43377 .50954 L .46253 .49831 L 1 g
F
P
p
.002 w
.43389 .50817 m .43452 .50795 L p
.43377 .50954 L 1 g
F P
s
P
p
.002 w
.44325 .49079 m .44215 .49186 L p
.43485 .50826 L 1 g
F P
s
P
p
.43485 .50826 m .44215 .49186 L .43922 .49805 L 1 g
F
P
p
.43813 .50059 m .43452 .50795 L .43377 .50954 L 1 g
F
P
p
.002 w
.43452 .50795 m .46253 .49831 L p
.43377 .50954 L 1 g
F P
s
P
p
.002 w
.44215 .49186 m .44166 .49233 L p
.43922 .49805 L 1 g
F P
s
P
p
.002 w
.44333 .49062 m .44339 .4905 L p
.44272 .49121 L 1 g
F P
s
P
p
.002 w
.44272 .49121 m .44339 .4905 L p
.45009 .48409 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45752 .47689 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.45687 .47752 m .45752 .47689 L .49301 .47361 L 1 g
F
P
p
.002 w
.45752 .47689 m .45826 .47608 L p
.46799 .47181 L 1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.4709 .4704 m .48051 .46676 L .46009 .47565 L 1 g
F
P
p
.002 w
.47756 .46716 m .47786 .46667 L p
.49111 .46532 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55618 .4928 m .54678 .50038 L .53056 .47121 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47674 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56603 .5093 L p
1 g
F P
s
P
p
.002 w
.58026 .51327 m .57132 .52048 L p
.56603 .5093 L 1 g
F P
s
P
p
.56589 .50773 m .56603 .5093 L .56515 .50745 L 1 g
F
P
p
.58026 .51327 m .56603 .5093 L .56589 .50773 L 1 g
F
P
p
.002 w
.56603 .5093 m .56515 .50826 L p
.56706 .52065 L 1 g
F P
s
P
p
.55661 .4905 m .56603 .5093 L .56211 .50102 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56753 .52878 L p
1 g
F P
s
P
p
.60131 .53072 m .56792 .53923 L .56753 .52878 L 1 g
F
P
p
.56763 .52844 m .56753 .52878 L .56752 .52843 L 1 g
F
P
p
.60131 .53072 m .56753 .52878 L .56763 .52844 L 1 g
F
P
p
.002 w
.56753 .52878 m .56654 .52734 L p
.56455 .53826 L 1 g
F P
s
P
p
.002 w
.56567 .53503 m .57481 .55208 L p
.56177 .5462 L 1 g
F P
s
P
p
.56455 .53826 m .56428 .53971 L .56567 .53503 L 1 g
F
P
p
.56455 .53826 m .56567 .53503 L .56753 .52878 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56148 .54704 L p
1 g
F P
s
P
p
.002 w
.57481 .55208 m .55742 .55868 L p
.56148 .54704 L 1 g
F P
s
P
p
.56202 .54631 m .56148 .54704 L .56177 .5462 L 1 g
F
P
p
.57481 .55208 m .56148 .54704 L .56202 .54631 L 1 g
F
P
p
.002 w
.56148 .54704 m .56075 .54566 L p
.5556 .555 L 1 g
F P
s
P
p
.56654 .52734 m .56148 .54704 L .56312 .54234 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .53444 .57539 L p
.53964 .57019 L 1 g
F P
s
P
p
.54854 .56129 m .53781 .57152 L .53964 .57019 L 1 g
F
P
p
.53781 .57152 m .5322 .57686 L .53964 .57019 L 1 g
F
P
p
.002 w
.58508 .57174 m .54479 .58707 L .54331 .56753 L p
1 g
F P
s
P
p
.58508 .57174 m .54331 .56753 L .54701 .56485 L 1 g
F
P
p
.002 w
.57481 .55208 m .58508 .57174 L p
.54774 .56498 L 1 g
F P
s
P
p
.54774 .56498 m .54701 .56485 L .5484 .56421 L 1 g
F
P
p
.54774 .56498 m .5484 .56421 L .57481 .55208 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56322 L p
1 g
F P
s
P
p
.55823 .55635 m .55239 .55934 L .56148 .54704 L 1 g
F
P
p
.56075 .54566 m .54926 .56322 L .55111 .56107 L 1 g
F
P
p
.55111 .56107 m .55239 .55934 L .55823 .55635 L 1 g
F
P
p
.5556 .555 m .55111 .56107 L .55426 .55743 L 1 g
F
P
p
.56075 .54566 m .55111 .56107 L .5556 .555 L 1 g
F
P
p
.002 w
.55343 .56019 m .55111 .56107 L p
.55823 .55635 L 1 g
F P
s
P
p
.002 w
.54855 .56131 m .54854 .56129 L p
.54849 .56134 L 1 g
F P
s
P
p
.54849 .56134 m .53444 .57539 L .54855 .56131 L 1 g
F
P
p
.002 w
.55343 .56019 m .57481 .55208 L p
.54701 .56485 L 1 g
F P
s
P
p
.002 w
.54935 .56346 m .54855 .56131 L p
.53444 .57539 L 1 g
F P
s
P
p
.002 w
.55111 .56107 m .54305 .56413 L p
.55239 .55934 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56148 .54704 m .54305 .56413 L .56177 .5462 L 1 g
F
P
p
.55239 .55934 m .54305 .56413 L .56148 .54704 L 1 g
F
P
p
.002 w
.54305 .56413 m .55343 .56019 L p
.54701 .56485 L 1 g
F P
s
P
p
.55426 .55743 m .55111 .56107 L .54998 .56518 L 1 g
F
P
p
.002 w
.54926 .56322 m .54935 .56346 L p
.55111 .56107 L 1 g
F P
s
P
p
.002 w
.54935 .56346 m .54998 .56518 L p
.55111 .56107 L 1 g
F P
s
P
p
.002 w
.54331 .56753 m .54305 .56413 L p
.54701 .56485 L 1 g
F P
s
P
p
.002 w
.55742 .55868 m .55343 .56019 L p
.55823 .55635 L 1 g
F P
s
P
p
.002 w
.53444 .57539 m .54998 .56518 L .54935 .56346 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56148 .54704 L p
1 g
F P
s
P
p
.5556 .555 m .54998 .56518 L .56148 .54704 L 1 g
F
P
p
.002 w
.56148 .54704 m .56188 .54779 L p
.56312 .54234 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54305 .56413 m .53994 .53636 L p
.56177 .5462 L 1 g
F P
s
P
p
.56654 .52734 m .56188 .54779 L .56428 .53971 L 1 g
F
P
p
.56515 .50826 m .56753 .52878 L .56742 .52597 L 1 g
F
P
p
.56752 .52843 m .56753 .52878 L .56193 .52805 L 1 g
F
P
p
.002 w
.56792 .53923 m .56567 .53503 L p
.56753 .52878 L 1 g
F P
s
P
p
.002 w
.56567 .53503 m .56193 .52805 L p
.56753 .52878 L 1 g
F P
s
P
p
.002 w
.56188 .54779 m .56257 .5491 L p
.56428 .53971 L 1 g
F P
s
P
p
.002 w
.53994 .53636 m .56193 .52805 L .56567 .53503 L p
1 g
F P
s
P
p
.56177 .5462 m .53994 .53636 L .56567 .53503 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56753 .52878 L p
1 g
F P
s
P
p
.56428 .53971 m .56257 .5491 L .56753 .52878 L 1 g
F
P
p
.002 w
.58026 .51327 m .60131 .53072 L p
.56752 .52843 L 1 g
F P
s
P
p
.002 w
.56734 .52369 m .58026 .51327 L p
.56752 .52843 L 1 g
F P
s
P
p
.56515 .50826 m .56784 .52924 L .56706 .52065 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56193 .52805 m .56734 .52369 L p
.56752 .52843 L 1 g
F P
s
P
p
.002 w
.57132 .52048 m .56734 .52369 L p
.56603 .5093 L 1 g
F P
s
P
p
.002 w
.56784 .52924 m .56854 .53025 L p
.56728 .52204 L 1 g
F P
s
P
p
.56706 .52065 m .56734 .52369 L .56728 .52204 L 1 g
F
P
p
.56734 .52369 m .56784 .52924 L .56728 .52204 L 1 g
F
P
p
.002 w
.56753 .52878 m .56784 .52924 L p
.56742 .52597 L 1 g
F P
s
P
p
.002 w
.60131 .53072 m .57481 .55208 L .56792 .53923 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56603 .5093 m .56193 .52805 L .56515 .50745 L 1 g
F
P
p
.002 w
.56734 .52369 m .56193 .52805 L p
.56603 .5093 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56603 .5093 L p
1 g
F P
s
P
p
.56706 .52065 m .56854 .53025 L .56603 .5093 L 1 g
F
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.55661 .4905 m .56211 .50102 L .55959 .4957 L 1 g
F
P
p
.59301 .49355 m .55959 .4957 L .55822 .49284 L 1 g
F
P
p
.55661 .4905 m .55959 .4957 L .55772 .49178 L 1 g
F
P
p
.002 w
.56269 .48268 m .59301 .49355 L p
.55895 .49285 L 1 g
F P
s
P
p
.55895 .49285 m .55822 .49284 L .55762 .49157 L 1 g
F
P
p
.002 w
.55765 .4916 m .55762 .49157 L p
.55777 .49184 L 1 g
F P
s
P
p
.002 w
.55762 .49157 m .55661 .4905 L p
.55772 .49178 L 1 g
F P
s
P
p
.55772 .49178 m .55777 .49184 L .55762 .49157 L 1 g
F
P
p
.002 w
.55618 .4928 m .55722 .49118 L p
.55762 .49157 L 1 g
F P
s
P
p
.55822 .49284 m .55618 .4928 L .55762 .49157 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55762 .49157 L p
1 g
F P
s
P
p
.54174 .47608 m .55762 .49157 L .55739 .49135 L 1 g
F
P
p
.54174 .47608 m .55765 .4916 L .55076 .48491 L 1 g
F
P
p
.002 w
.55722 .49118 m .56269 .48268 L p
.55895 .49285 L 1 g
F P
s
P
p
.002 w
.55762 .49157 m .55765 .4916 L p
.55739 .49135 L 1 g
F P
s
P
p
.55772 .49178 m .55959 .4957 L .55777 .49184 L 1 g
F
P
p
.002 w
.59301 .49355 m .58026 .51327 L .55959 .4957 L p
1 g
F P
s
P
p
.002 w
.55959 .4957 m .55618 .4928 L p
.55822 .49284 L 1 g
F P
s
P
p
.55496 .48899 m .55618 .4928 L .54234 .47674 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55734 .49099 m .55722 .49118 L p
.55258 .48154 L 1 g
F P
s
P
p
.002 w
.55722 .49118 m .55618 .4928 L p
.55496 .48899 L 1 g
F P
s
P
p
.55722 .49118 m .55496 .48899 L .55258 .48154 L 1 g
F
P
p
.002 w
.55959 .4957 m .58026 .51327 L p
.56515 .50745 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55766 .49162 L p
1 g
F P
s
P
p
.56211 .50102 m .56713 .51061 L .55766 .49162 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54234 .47674 L p
1 g
F P
s
P
p
.002 w
.54234 .47674 m .54174 .47608 L p
.55076 .48491 L 1 g
F P
s
P
p
.55076 .48491 m .55834 .49233 L .54234 .47674 L 1 g
F
P
p
.002 w
.55766 .49162 m .55765 .4916 L p
.55777 .49184 L 1 g
F P
s
P
p
.002 w
.55765 .4916 m .55834 .49233 L p
.55076 .48491 L 1 g
F P
s
P
p
.002 w
.55618 .4928 m .53214 .47195 L p
.54234 .47674 L 1 g
F P
s
P
p
.55258 .48154 m .55496 .48899 L .54234 .47674 L 1 g
F
P
p
.002 w
.56091 .48545 m .55734 .49099 L p
.55258 .48154 L 1 g
F P
s
P
p
.002 w
.54678 .50038 m .55618 .4928 L .55959 .4957 L p
1 g
F P
s
P
p
.56515 .50745 m .54678 .50038 L .55959 .4957 L 1 g
F
P
p
.002 w
.56603 .5093 m .56713 .51061 L p
.56211 .50102 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.56193 .52805 m .54678 .50038 L p
.56515 .50745 L 1 g
F P
s
P
p
.002 w
.54234 .47674 m .54236 .47676 L p
.54197 .47656 L 1 g
F P
s
P
p
.52214 .46667 m .54234 .47674 L .54197 .47656 L 1 g
F
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52989 .47 m .56269 .48268 L .56091 .48545 L p
1 g
F P
s
P
p
.52214 .46667 m .54236 .47676 L .54145 .47633 L 1 g
F
P
p
.52214 .46667 m .54241 .47681 L .53451 .47307 L 1 g
F
P
p
.002 w
.53214 .47195 m .55618 .4928 L p
.53056 .47121 L 1 g
F P
s
P
p
.002 w
.54678 .50038 m .53551 .50462 L .53005 .47096 L p
1 g
F P
s
P
p
.002 w
.53056 .47121 m .54678 .50038 L p
.53005 .47096 L 1 g
F P
s
P
p
.002 w
.49301 .47361 m .49366 .46497 L p
.52735 .46965 L 1 g
F P
s
P
p
.002 w
.52837 .47015 m .49301 .47361 L p
.52735 .46965 L 1 g
F P
s
P
p
.52214 .46667 m .53488 .47326 L .52291 .46745 L 1 g
F
P
p
.53488 .47326 m .52974 .47082 L .52249 .46724 L 1 g
F
P
p
.002 w
.51222 .50165 m .5027 .49474 L .52925 .47058 L p
1 g
F P
s
P
p
.002 w
.52925 .47058 m .52989 .47 L .5295 .4707 L p
1 g
F P
s
P
p
.002 w
.5295 .4707 m .51222 .50165 L p
.52925 .47058 L 1 g
F P
s
P
p
.002 w
.5027 .49474 m .49605 .48504 L .52893 .47042 L p
1 g
F P
s
P
p
.002 w
.52893 .47042 m .52989 .47 L .52925 .47058 L p
1 g
F P
s
P
p
.002 w
.52925 .47058 m .5027 .49474 L p
.52893 .47042 L 1 g
F P
s
P
p
.52938 .47064 m .52925 .47059 L .52911 .47051 L 1 g
F
P
p
.5295 .4707 m .52944 .47067 L .52938 .47064 L 1 g
F
P
p
.52944 .47067 m .52925 .47059 L .52938 .47064 L 1 g
F
P
p
.002 w
.52974 .47082 m .52356 .50507 L p
.5295 .4707 L 1 g
F P
s
P
p
.52974 .47082 m .52962 .47076 L .5295 .4707 L 1 g
F
P
p
.52962 .47076 m .52925 .47059 L .5295 .4707 L 1 g
F
P
p
.002 w
.49605 .48504 m .49301 .47361 L .52837 .47015 L p
1 g
F P
s
P
p
.002 w
.52837 .47015 m .52989 .47 L .52893 .47042 L p
1 g
F P
s
P
p
.002 w
.52893 .47042 m .49605 .48504 L p
.52837 .47015 L 1 g
F P
s
P
p
.52974 .47082 m .52925 .47058 L .52249 .46724 L 1 g
F
P
p
.52925 .47058 m .52911 .47051 L .52837 .47015 L 1 g
F
P
p
.52925 .47058 m .52837 .47015 L .52249 .46724 L 1 g
F
P
p
.002 w
.52356 .50507 m .51222 .50165 L .5295 .4707 L p
1 g
F P
s
P
p
.002 w
.5295 .4707 m .52989 .47 L .52974 .47082 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.49869 .45058 m .52989 .47 L .52646 .46921 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46724 L p
1 g
F P
s
P
p
.002 w
.52646 .46921 m .51 .46541 L p
.52248 .46724 L 1 g
F P
s
P
p
.002 w
.52248 .46724 m .52282 .46778 L p
.51182 .46567 L 1 g
F P
s
P
p
.5 .4634 m .52248 .46724 L .51182 .46567 L 1 g
F
P
p
.002 w
.49391 .46169 m .49695 .45461 L p
.52248 .46724 L 1 g
F P
s
P
p
.49366 .46497 m .5 .46393 L .52989 .47 L 1 g
F
P
p
.002 w
.5 .46393 m .5 .4634 L p
.51184 .46568 L 1 g
F P
s
P
p
.002 w
.50212 .46359 m .51 .46541 L p
.5 .46393 L 1 g
F P
s
P
p
.002 w
.51 .46541 m .52989 .47 L p
.5 .46393 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46393 L p
1 g
F P
s
P
p
.51184 .46568 m .52282 .46778 L .5 .46393 L 1 g
F
P
p
.002 w
.51 .46541 m .49391 .46169 L p
.52248 .46724 L 1 g
F P
s
P
p
.002 w
.52248 .46724 m .52214 .46667 L p
.52291 .46745 L 1 g
F P
s
P
p
.002 w
.49695 .45461 m .49869 .45058 L p
.52646 .46921 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52248 .46724 L p
.52291 .46745 L 1 g
F P
s
P
p
.002 w
.53551 .50462 m .52356 .50507 L .52974 .47082 L p
1 g
F P
s
P
p
.002 w
.53005 .47096 m .53551 .50462 L p
.52974 .47082 L 1 g
F P
s
P
p
.53488 .47326 m .53903 .47541 L .52925 .47059 L 1 g
F
P
p
.002 w
.52974 .47082 m .52989 .47 L .53005 .47096 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46724 L p
1 g
F P
s
P
p
.53903 .47541 m .54302 .47747 L .52249 .46724 L 1 g
F
P
p
.002 w
.52989 .47 m .52837 .47015 L p
.52735 .46965 L 1 g
F P
s
P
p
.002 w
.53214 .47195 m .52989 .47 L p
.56091 .48545 L 1 g
F P
s
P
p
.002 w
.53056 .47121 m .52989 .47 L .53214 .47195 L p
1 g
F P
s
P
p
.002 w
.54236 .47676 m .54241 .47681 L p
.54145 .47633 L 1 g
F P
s
P
p
.002 w
.54241 .47681 m .54302 .47747 L p
.53451 .47307 L 1 g
F P
s
P
p
.002 w
.53005 .47096 m .52989 .47 L .53056 .47121 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46393 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46393 L .49631 .46454 L 1 g
F
P
p
.47786 .46667 m .5 .46411 L .49111 .46532 L 1 g
F
P
p
.002 w
.49366 .46497 m .49391 .46169 L .50212 .46359 L p
1 g
F P
s
P
p
.002 w
.5 .46393 m .5 .46411 L p
.49631 .46454 L 1 g
F P
s
P
p
.002 w
.49366 .46497 m .49301 .47361 L p
.48217 .46654 L 1 g
F P
s
P
p
.002 w
.5 .46411 m .5 .46442 L p
.49111 .46532 L 1 g
F P
s
P
p
.002 w
.49301 .47361 m .46009 .47565 L p
.48217 .46654 L 1 g
F P
s
P
p
.002 w
.49391 .46169 m .49366 .46497 L p
.48217 .46654 L 1 g
F P
s
P
p
.48051 .46676 m .49391 .46169 L .48217 .46654 L 1 g
F
P
p
.48051 .46676 m .48217 .46654 L .46009 .47565 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45643 .47588 m .45811 .4524 L .4906 .46083 L p
1 g
F P
s
P
p
.002 w
.4906 .46083 m .49391 .46169 L p
.4709 .4704 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47749 .46728 L p
1 g
F P
s
P
p
.002 w
.47749 .46728 m .47718 .46778 L p
.46886 .47143 L 1 g
F P
s
P
p
.45826 .47608 m .47749 .46728 L .46886 .47143 L 1 g
F
P
p
.002 w
.45643 .47588 m .4587 .47574 L p
.45752 .47689 L 1 g
F P
s
P
p
.002 w
.45687 .47752 m .4568 .47724 L p
.45752 .47689 L 1 g
F P
s
P
p
.002 w
.4568 .47724 m .45643 .47588 L p
.45752 .47689 L 1 g
F P
s
P
p
.45643 .47588 m .4906 .46083 L .4709 .4704 L 1 g
F
P
p
.002 w
.46009 .47565 m .49301 .47361 L p
.45752 .47689 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4575 .47691 L p
1 g
F P
s
P
p
.002 w
.4575 .47691 m .45752 .47689 L p
.45805 .47664 L 1 g
F P
s
P
p
.45805 .47664 m .47718 .46778 L .4575 .47691 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46716 L p
1 g
F P
s
P
p
.49111 .46532 m .5 .46442 L .47756 .46716 L 1 g
F
P
p
.46799 .47181 m .46886 .47143 L .46009 .47565 L 1 g
F
P
p
.46799 .47181 m .46009 .47565 L .45752 .47689 L 1 g
F
P
p
.002 w
.46009 .47565 m .45643 .47588 L p
.4709 .4704 L 1 g
F P
s
P
p
.002 w
.4587 .47574 m .46009 .47565 L p
.45752 .47689 L 1 g
F P
s
P
p
.46886 .47143 m .47718 .46778 L .45752 .47689 L 1 g
F
P
p
.002 w
.45752 .47689 m .45749 .47692 L p
.45714 .47725 L 1 g
F P
s
P
p
.44339 .4905 m .45752 .47689 L .45714 .47725 L 1 g
F
P
p
.002 w
.46253 .49831 m .45687 .47752 L p
.49301 .47361 L 1 g
F P
s
P
p
.44339 .4905 m .45749 .47692 L .45009 .48409 L 1 g
F
P
p
.002 w
.45016 .47603 m .45643 .47588 L p
.45009 .48408 L 1 g
F P
s
P
p
.4395 .49779 m .44272 .49121 L .45009 .48408 L 1 g
F
P
p
.44272 .49121 m .45016 .47603 L .45009 .48408 L 1 g
F
P
p
.002 w
.45643 .47588 m .46253 .49831 L .43452 .50795 L p
1 g
F P
s
P
p
.4395 .49779 m .45643 .47588 L .43452 .50795 L 1 g
F
P
p
.002 w
.45749 .47692 m .45698 .47747 L p
.45009 .48409 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44272 .49121 L p
1 g
F P
s
P
p
.45009 .48409 m .45698 .47747 L .44272 .49121 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43371 .50962 L p
1 g
F P
s
P
p
.002 w
.43371 .50962 m .43377 .50954 L p
.43414 .50873 L 1 g
F P
s
P
p
.43414 .50873 m .44166 .49233 L .43371 .50962 L 1 g
F
P
p
.43813 .50059 m .43922 .49805 L .43452 .50795 L 1 g
F
P
p
.43922 .49805 m .44166 .49233 L .43377 .50954 L 1 g
F
P
p
.002 w
.43377 .50954 m .43362 .50973 L p
.4336 .51158 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44986 .53674 m .43345 .51335 L p
.46253 .49831 L 1 g
F P
s
P
p
.002 w
.44986 .53674 m .43759 .54493 L p
.43306 .52183 L 1 g
F P
s
P
p
.002 w
.43061 .5093 m .43345 .51335 L p
.43306 .52183 L 1 g
F P
s
P
p
.002 w
.43345 .51335 m .44986 .53674 L p
.43306 .52183 L 1 g
F P
s
P
p
.002 w
.43362 .50973 m .43287 .51061 L p
.43318 .51928 L 1 g
F P
s
P
p
.42972 .51789 m .43061 .5093 L .43759 .54493 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43277 .52835 L p
1 g
F P
s
P
p
.43318 .51928 m .43287 .51061 L .43277 .52835 L 1 g
F
P
p
.43584 .53891 m .43309 .53347 L .43759 .54493 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43846 .54715 L p
1 g
F P
s
P
p
.43309 .53347 m .43146 .53025 L .43846 .54715 L 1 g
F
P
p
.002 w
.43846 .54715 m .43743 .5491 L p
.44624 .55676 L 1 g
F P
s
P
p
.45844 .56806 m .45097 .5626 L .44986 .53674 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45097 .5626 L p
1 g
F P
s
P
p
.44624 .55676 m .43743 .5491 L .45097 .5626 L 1 g
F
P
p
.002 w
.48909 .58016 m .48921 .57862 L p
.48087 .57794 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.48733 .57968 m .46831 .57455 L .47709 .55615 L 1 g
F
P
p
.002 w
.46385 .57334 m .4645 .57249 L p
.46831 .57455 L 1 g
F P
s
P
p
.45991 .56913 m .4645 .57249 L .46831 .57455 L 1 g
F
P
p
.002 w
.4645 .57249 m .47709 .55615 L p
.46831 .57455 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46817 .57517 L p
1 g
F P
s
P
p
.002 w
.46817 .57517 m .46831 .57455 L p
.465 .57285 L 1 g
F P
s
P
p
.465 .57285 m .45002 .56518 L .46817 .57517 L 1 g
F
P
p
.45991 .56913 m .45373 .56666 L .4645 .57249 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44986 .53674 m .47709 .55615 L .4645 .57249 L p
1 g
F P
s
P
p
.45844 .56806 m .44986 .53674 L .4645 .57249 L 1 g
F
P
p
.45373 .56666 m .45002 .56518 L .46831 .57455 L 1 g
F
P
p
.002 w
.50193 .58898 m .4678 .57912 L p
.49549 .58047 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.4678 .57912 m .46093 .57713 L p
.49549 .58047 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58016 L p
1 g
F P
s
P
p
.48087 .57794 m .4678 .57686 L .48909 .58016 L 1 g
F
P
p
.49549 .58047 m .48733 .57968 L .47709 .55615 L 1 g
F
P
p
.54479 .58707 m .50447 .58091 L .53076 .57857 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58123 L p
1 g
F P
s
P
p
.002 w
.51098 .58123 m .51092 .58033 L p
.50568 .58097 L 1 g
F P
s
P
p
.50568 .58097 m .48889 .583 L .51098 .58123 L 1 g
F
P
p
.50036 .58071 m .49523 .58173 L .50447 .58091 L 1 g
F
P
p
.50036 .58071 m .50447 .58091 L .51092 .58033 L 1 g
F
P
p
.002 w
.47709 .55615 m .5093 .56556 L .50447 .58091 L p
1 g
F P
s
P
p
.49549 .58047 m .47709 .55615 L .50447 .58091 L 1 g
F
P
p
.002 w
.50447 .58091 m .5093 .56556 L p
.53076 .57857 L 1 g
F P
s
P
p
.49523 .58173 m .48889 .583 L .51092 .58033 L 1 g
F
P
p
.002 w
.51092 .58033 m .51111 .583 L p
.52396 .5764 L 1 g
F P
s
P
p
.5316 .5741 m .5093 .56556 L .54331 .56753 L 1 g
F
P
p
.52734 .57649 m .52612 .57575 L .5316 .5741 L 1 g
F
P
p
.52612 .57575 m .5093 .56556 L .5316 .5741 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5316 .5741 L p
1 g
F P
s
P
p
.52396 .5764 m .51111 .583 L .5316 .5741 L 1 g
F
P
p
.002 w
.5093 .56556 m .54305 .56413 L .54331 .56753 L p
1 g
F P
s
P
p
.002 w
.5316 .5741 m .53196 .57576 L p
.53793 .57055 L 1 g
F P
s
P
p
.002 w
.53196 .57576 m .5322 .57686 L p
.53781 .57152 L 1 g
F P
s
P
p
.002 w
.61869 .54464 m .58508 .57174 L .57481 .55208 L p
1 g
F P
s
P
p
.002 w
.57481 .55208 m .60131 .53072 L .61869 .54464 L p
1 g
F P
s
P
p
.002 w
.64217 .50854 m .61869 .54464 L .60131 .53072 L p
1 g
F P
s
P
p
.002 w
.6152 .33004 m .56999 .3061 L .57197 .28286 L p
1 g
F P
s
P
p
.002 w
.51444 .27411 m .57197 .28286 L .56999 .3061 L p
1 g
F P
s
P
p
.002 w
.40146 .51767 m .42615 .55256 L .40534 .56427 L p
1 g
F P
s
P
p
.002 w
.40534 .56427 m .37604 .5232 L .40146 .51767 L p
1 g
F P
s
P
p
.002 w
.65002 .42455 m .6332 .38542 L .64938 .36727 L p
1 g
F P
s
P
p
.002 w
.6152 .33004 m .64938 .36727 L .6332 .38542 L p
1 g
F P
s
P
p
.002 w
.60131 .53072 m .61978 .50224 L .64217 .50854 L p
1 g
F P
s
P
p
.002 w
.65305 .46708 m .64217 .50854 L .61978 .50224 L p
1 g
F P
s
P
p
.002 w
.38543 .37396 m .36517 .42245 L .34262 .41304 L p
1 g
F P
s
P
p
.004 w
.37421 .40083 m
.5 .43051 L
s
P
p
.002 w
.34262 .41304 m .36521 .35867 L .38543 .37396 L p
1 g
F P
s
P
p
.004 w
.34947 .39499 m
.35521 .39634 L
s
P
p
.004 w
.33815 .39232 m
.34947 .39499 L
s
P
p
.004 w
.35521 .39634 m
.35636 .39662 L
s
P
p
.002 w
.61978 .50224 m .62827 .46959 L .65305 .46708 L p
1 g
F P
s
P
p
.002 w
.65002 .42455 m .65305 .46708 L .62827 .46959 L p
1 g
F P
s
P
p
.002 w
.56999 .3061 m .51861 .29842 L .51444 .27411 L p
1 g
F P
s
P
p
.002 w
.45642 .28491 m .51444 .27411 L .51861 .29842 L p
1 g
F P
s
P
p
.002 w
.38974 .47611 m .40146 .51767 L .37604 .5232 L p
1 g
F P
s
P
p
.002 w
.37604 .5232 m .36202 .47415 L .38974 .47611 L p
1 g
F P
s
P
p
.002 w
.6332 .38542 m .60414 .35399 L .6152 .33004 L p
1 g
F P
s
P
p
.002 w
.56999 .3061 m .6152 .33004 L .60414 .35399 L p
1 g
F P
s
P
p
.002 w
.42066 .33431 m .38543 .37396 L .36521 .35867 L p
1 g
F P
s
P
p
.002 w
.36521 .35867 m .40466 .31421 L .42066 .33431 L p
1 g
F P
s
P
p
.002 w
.51861 .29842 m .46684 .30814 L .45642 .28491 L p
1 g
F P
s
P
p
.002 w
.40466 .31421 m .45642 .28491 L .46684 .30814 L p
1 g
F P
s
P
p
.002 w
.46684 .30814 m .42066 .33431 L .40466 .31421 L p
1 g
F P
s
P
p
.002 w
.62827 .46959 m .62578 .43616 L .65002 .42455 L p
1 g
F P
s
P
p
.002 w
.6332 .38542 m .65002 .42455 L .62578 .43616 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39254 .4324 m .38974 .47611 L .36202 .47415 L p
1 g
F P
s
P
p
.002 w
.36202 .47415 m .36517 .42245 L .39254 .4324 L p
1 g
F P
s
P
p
.002 w
.60414 .35399 m .5658 .33387 L .56999 .3061 L p
1 g
F P
s
P
p
.002 w
.51861 .29842 m .56999 .3061 L .5658 .33387 L p
1 g
F P
s
P
p
.002 w
.42615 .55256 m .40146 .51767 L .43061 .5093 L p
1 g
F P
s
P
p
.002 w
.61978 .50224 m .60131 .53072 L .58026 .51327 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.62578 .43616 m .61245 .40549 L .6332 .38542 L p
1 g
F P
s
P
p
.002 w
.60414 .35399 m .6332 .38542 L .61245 .40549 L p
1 g
F P
s
P
p
.002 w
.51661 .5373 m .53994 .53636 L .54305 .56413 L p
1 g
F P
s
P
p
.002 w
.54305 .56413 m .5093 .56556 L .51661 .5373 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58026 .51327 m .59301 .49355 L .61978 .50224 L p
1 g
F P
s
P
p
.002 w
.62827 .46959 m .61978 .50224 L .59301 .49355 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49439 .53072 m .51661 .5373 L .5093 .56556 L p
1 g
F P
s
P
p
.002 w
.5093 .56556 m .47709 .55615 L .49439 .53072 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.40976 .39144 m .39254 .4324 L .36517 .42245 L p
1 g
F P
s
P
p
.002 w
.36517 .42245 m .38543 .37396 L .40976 .39144 L p
1 g
F P
s
P
p
.002 w
.59301 .49355 m .59881 .47097 L .62827 .46959 L p
1 g
F P
s
P
p
.002 w
.62578 .43616 m .62827 .46959 L .59881 .47097 L p
1 g
F P
s
P
p
.002 w
.5658 .33387 m .52233 .32751 L .51861 .29842 L p
1 g
F P
s
P
p
.002 w
.46684 .30814 m .51861 .29842 L .52233 .32751 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42157 .47671 m .43061 .5093 L .40146 .51767 L p
1 g
F P
s
P
p
.002 w
.40146 .51767 m .38974 .47611 L .42157 .47671 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61245 .40549 m .58956 .38095 L .60414 .35399 L p
1 g
F P
s
P
p
.002 w
.5658 .33387 m .60414 .35399 L .58956 .38095 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.43957 .35796 m .40976 .39144 L .38543 .37396 L p
1 g
F P
s
P
p
.002 w
.38543 .37396 m .42066 .33431 L .43957 .35796 L p
1 g
F P
s
P
p
.002 w
.47568 .51726 m .49439 .53072 L .47709 .55615 L p
1 g
F P
s
P
p
.002 w
.47709 .55615 m .44986 .53674 L .47568 .51726 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.52233 .32751 m .47859 .33581 L .46684 .30814 L p
1 g
F P
s
P
p
.002 w
.42066 .33431 m .46684 .30814 L .47859 .33581 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.59881 .47097 m .59701 .4479 L .62578 .43616 L p
1 g
F P
s
P
p
.002 w
.61245 .40549 m .62578 .43616 L .59701 .4479 L p
1 g
F P
s
P
p
.002 w
.47859 .33581 m .43957 .35796 L .42066 .33431 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.42389 .44251 m .42157 .47671 L .38974 .47611 L p
1 g
F P
s
P
p
.002 w
.38974 .47611 m .39254 .4324 L .42389 .44251 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46253 .49831 m .47568 .51726 L .44986 .53674 L p
1 g
F P
s
P
p
.002 w
.58956 .38095 m .55947 .36533 L .5658 .33387 L p
1 g
F P
s
P
p
.002 w
.52233 .32751 m .5658 .33387 L .55947 .36533 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53551 .50462 m .54678 .50038 L .56193 .52805 L p
1 g
F P
s
P
p
.002 w
.56193 .52805 m .53994 .53636 L .53551 .50462 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.59701 .4479 m .58773 .42681 L .61245 .40549 L p
1 g
F P
s
P
p
.002 w
.58956 .38095 m .61245 .40549 L .58773 .42681 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52356 .50507 m .53551 .50462 L .53994 .53636 L p
1 g
F P
s
P
p
.002 w
.53994 .53636 m .51661 .5373 L .52356 .50507 L p
1 g
F P
s
P
p
.002 w
.59881 .47097 m .59301 .49355 L .56269 .48268 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51222 .50165 m .52356 .50507 L .51661 .5373 L p
1 g
F P
s
P
p
.002 w
.51661 .5373 m .49439 .53072 L .51222 .50165 L p
1 g
F P
s
P
p
.002 w
.43744 .41052 m .42389 .44251 L .39254 .4324 L p
1 g
F P
s
P
p
.002 w
.39254 .4324 m .40976 .39144 L .43744 .41052 L p
1 g
F P
s
P
p
.002 w
.56269 .48268 m .56563 .47112 L .59881 .47097 L p
1 g
F P
s
P
p
.002 w
.59701 .4479 m .59881 .47097 L .56563 .47112 L p
1 g
F P
s
P
p
.002 w
.55947 .36533 m .52544 .36046 L .52233 .32751 L p
1 g
F P
s
P
p
.002 w
.47859 .33581 m .52233 .32751 L .52544 .36046 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.58773 .42681 m .57189 .41001 L .58956 .38095 L p
1 g
F P
s
P
p
.002 w
.55947 .36533 m .58956 .38095 L .57189 .41001 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5027 .49474 m .51222 .50165 L .49439 .53072 L p
1 g
F P
s
P
p
.002 w
.49439 .53072 m .47568 .51726 L .5027 .49474 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56563 .47112 m .56466 .45933 L .59701 .4479 L p
1 g
F P
s
P
p
.002 w
.58773 .42681 m .59701 .4479 L .56466 .45933 L p
1 g
F P
s
P
p
.002 w
.46076 .38436 m .43744 .41052 L .40976 .39144 L p
1 g
F P
s
P
p
.002 w
.40976 .39144 m .43957 .35796 L .46076 .38436 L p
1 g
F P
s
P
p
.002 w
.52544 .36046 m .49125 .36703 L .47859 .33581 L p
1 g
F P
s
P
p
.002 w
.43957 .35796 m .47859 .33581 L .49125 .36703 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49125 .36703 m .46076 .38436 L .43957 .35796 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45811 .4524 m .45643 .47588 L .42157 .47671 L p
1 g
F P
s
P
p
.002 w
.42157 .47671 m .42389 .44251 L .45811 .4524 L p
1 g
F P
s
P
p
.002 w
.49605 .48504 m .5027 .49474 L .47568 .51726 L p
1 g
F P
s
P
p
.002 w
.47568 .51726 m .46253 .49831 L .49605 .48504 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57189 .41001 m .55117 .39937 L .55947 .36533 L p
1 g
F P
s
P
p
.002 w
.52544 .36046 m .55947 .36533 L .55117 .39937 L p
1 g
F P
s
P
p
.002 w
.56466 .45933 m .55986 .4486 L .58773 .42681 L p
1 g
F P
s
P
p
.002 w
.57189 .41001 m .58773 .42681 L .55986 .4486 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56563 .47112 m .56269 .48268 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49301 .47361 m .49605 .48504 L .46253 .49831 L p
1 g
F P
s
P
p
.002 w
.56466 .45933 m .56563 .47112 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.46746 .43049 m .45811 .4524 L .42389 .44251 L p
1 g
F P
s
P
p
.002 w
.42389 .44251 m .43744 .41052 L .46746 .43049 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.55986 .4486 m .55175 .44008 L .57189 .41001 L p
1 g
F P
s
P
p
.002 w
.55117 .39937 m .57189 .41001 L .55175 .44008 L p
1 g
F P
s
P
p
.002 w
.55117 .39937 m .5278 .39612 L .52544 .36046 L p
1 g
F P
s
P
p
.002 w
.49125 .36703 m .52544 .36046 L .5278 .39612 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55986 .4486 m .56466 .45933 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48347 .41257 m .46746 .43049 L .43744 .41052 L p
1 g
F P
s
P
p
.002 w
.43744 .41052 m .46076 .38436 L .48347 .41257 L p
1 g
F P
s
P
p
.002 w
.5278 .39612 m .50436 .40068 L .49125 .36703 L p
1 g
F P
s
P
p
.002 w
.46076 .38436 m .49125 .36703 L .50436 .40068 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.55175 .44008 m .55986 .4486 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.50436 .40068 m .48347 .41257 L .46076 .38436 L p
1 g
F P
s
P
p
.002 w
.55175 .44008 m .54118 .43472 L .55117 .39937 L p
1 g
F P
s
P
p
.002 w
.5278 .39612 m .55117 .39937 L .54118 .43472 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54118 .43472 m .55175 .44008 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.5293 .43311 m .54118 .43472 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.51741 .43546 m .5293 .43311 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.50682 .4415 m .51741 .43546 L .52989 .47 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50787 .4409 L
s
P
p
.002 w
.49869 .45058 m .50682 .4415 L .52989 .47 L closepath p
1 g
F P
s
P
p
.002 w
.49869 .45058 m .49391 .46169 L .45811 .4524 L p
1 g
F P
s
P
p
.002 w
.45811 .4524 m .46746 .43049 L .49869 .45058 L p
1 g
F P
s
P
p
.002 w
.54118 .43472 m .5293 .43311 L .5278 .39612 L p
1 g
F P
s
P
p
.002 w
.50436 .40068 m .5278 .39612 L .5293 .43311 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50682 .4415 m .49869 .45058 L .46746 .43049 L p
1 g
F P
s
P
p
.002 w
.46746 .43049 m .48347 .41257 L .50682 .4415 L p
1 g
F P
s
P
p
.002 w
.5293 .43311 m .51741 .43546 L .50436 .40068 L p
1 g
F P
s
P
p
.002 w
.48347 .41257 m .50436 .40068 L .51741 .43546 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.51741 .43546 m .50682 .4415 L .48347 .41257 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.52989 .47 m
.5484 .49445 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .26983 .37619 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .5484 .49445 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0552632)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0552632)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50484 .46236 m .52552 .44478 L .50395 .42614 L p
1 g
F P
s
P
p
.002 w
.50395 .42614 m .48986 .43811 L .50484 .46236 L p
1 g
F P
s
P
p
.002 w
.51363 .41045 m .50395 .42614 L .52552 .44478 L p
1 g
F P
s
P
p
.002 w
.48986 .43811 m .50395 .42614 L .48228 .40761 L p
1 g
F P
s
P
p
.002 w
.50395 .42614 m .51363 .41045 L .48718 .39964 L p
1 g
F P
s
P
p
.002 w
.48718 .39964 m .48228 .40761 L .50395 .42614 L p
1 g
F P
s
P
p
.002 w
.47988 .4727 m .50484 .46236 L .48986 .43811 L p
1 g
F P
s
P
p
.002 w
.48986 .43811 m .47285 .44511 L .47988 .4727 L p
1 g
F P
s
P
p
.002 w
.47285 .44511 m .48986 .43811 L .47513 .41369 L p
1 g
F P
s
P
p
.002 w
.48228 .40761 m .47513 .41369 L .48986 .43811 L p
1 g
F P
s
P
p
.002 w
.52552 .44478 m .53978 .42176 L .51363 .41045 L p
1 g
F P
s
P
p
.002 w
.51789 .39267 m .51363 .41045 L .53978 .42176 L p
1 g
F P
s
P
p
.002 w
.51363 .41045 m .51789 .39267 L .48931 .39062 L p
1 g
F P
s
P
p
.002 w
.48931 .39062 m .48718 .39964 L .51363 .41045 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .47513 .41369 L .48228 .40761 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .48228 .40761 L .48718 .39964 L closepath p
1 g
F P
s
P
p
.002 w
.51981 .486 m .54661 .46319 L .52552 .44478 L p
1 g
F P
s
P
p
.002 w
.52552 .44478 m .50484 .46236 L .51981 .486 L p
1 g
F P
s
P
p
.002 w
.53978 .42176 m .52552 .44478 L .54661 .46319 L p
1 g
F P
s
P
p
.002 w
.47513 .41369 m .46648 .41722 L .47285 .44511 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .46648 .41722 L .47513 .41369 L closepath p
1 g
F P
s
P
p
.002 w
.45318 .47466 m .47988 .4727 L .47285 .44511 L p
1 g
F P
s
P
p
.002 w
.47285 .44511 m .45468 .44637 L .45318 .47466 L p
1 g
F P
s
P
p
.002 w
.45468 .44637 m .47285 .44511 L .46648 .41722 L p
1 g
F P
s
P
p
.002 w
.48746 .49948 m .51981 .486 L .50484 .46236 L p
1 g
F P
s
P
p
.002 w
.50484 .46236 m .47988 .4727 L .48746 .49948 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .48718 .39964 L .48931 .39062 L closepath p
1 g
F P
s
P
p
.002 w
.46648 .41722 m .45727 .41782 L .45468 .44637 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .45727 .41782 L .46648 .41722 L closepath p
1 g
F P
s
P
p
.002 w
.54661 .46319 m .56516 .43337 L .53978 .42176 L p
1 g
F P
s
P
p
.002 w
.54614 .39566 m .53978 .42176 L .56516 .43337 L p
1 g
F P
s
P
p
.002 w
.53978 .42176 m .54614 .39566 L .51789 .39267 L p
1 g
F P
s
P
p
.002 w
.48843 .3815 m .48931 .39062 L .51789 .39267 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .48931 .39062 L .48843 .3815 L closepath p
1 g
F P
s
P
p
.002 w
.51624 .37467 m .51789 .39267 L .54614 .39566 L p
1 g
F P
s
P
p
.002 w
.51789 .39267 m .51624 .37467 L .48843 .3815 L p
1 g
F P
s
P
p
.002 w
.43728 .44172 m .45468 .44637 L .45727 .41782 L p
1 g
F P
s
P
p
.002 w
.45727 .41782 m .44848 .41541 L .43728 .44172 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .44848 .41541 L .45727 .41782 L closepath p
1 g
F P
s
P
p
.002 w
.45281 .50217 m .48746 .49948 L .47988 .4727 L p
1 g
F P
s
P
p
.002 w
.47988 .4727 m .45318 .47466 L .45281 .50217 L p
1 g
F P
s
P
p
.002 w
.42753 .46795 m .45318 .47466 L .45468 .44637 L p
1 g
F P
s
P
p
.002 w
.45468 .44637 m .43728 .44172 L .42753 .46795 L p
1 g
F P
s
P
p
.002 w
.48461 .37328 m .48843 .3815 L .51624 .37467 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .48843 .3815 L .48461 .37328 L closepath p
1 g
F P
s
P
p
.002 w
.42251 .43159 m .43728 .44172 L .44848 .41541 L p
1 g
F P
s
P
p
.002 w
.44848 .41541 m .44105 .41025 L .42251 .43159 L p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .44105 .41025 L .44848 .41541 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .43386 .38478 L .4333 .39406 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .4333 .39406 L .43579 .40287 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .43579 .40287 L .44105 .41025 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .48461 .37328 L .47826 .36683 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .47826 .36683 L .47005 .36289 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .47005 .36289 L .46086 .36188 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .46086 .36188 L .45171 .36394 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .45171 .36394 L .4436 .36884 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .4436 .36884 L .43742 .37605 L closepath p
1 g
F P
s
P
p
.002 w
.4609 .38952 m .43742 .37605 L .43386 .38478 L closepath p
1 g
F P
s
P
p
.002 w
.53448 .50858 m .56683 .48104 L .54661 .46319 L p
1 g
F P
s
P
p
.002 w
.54661 .46319 m .51981 .486 L .53448 .50858 L p
1 g
F P
s
P
p
.002 w
.56516 .43337 m .54661 .46319 L .56683 .48104 L p
1 g
F P
s
P
p
.002 w
.56516 .43337 m .57352 .39952 L .54614 .39566 L p
1 g
F P
s
P
p
.002 w
.54384 .36916 m .54614 .39566 L .57352 .39952 L p
1 g
F P
s
P
p
.002 w
.54614 .39566 m .54384 .36916 L .51624 .37467 L p
1 g
F P
s
P
p
.002 w
.5088 .35836 m .51624 .37467 L .54384 .36916 L p
1 g
F P
s
P
p
.002 w
.51624 .37467 m .5088 .35836 L .48461 .37328 L p
1 g
F P
s
P
p
.002 w
.49545 .52494 m .53448 .50858 L .51981 .486 L p
1 g
F P
s
P
p
.002 w
.51981 .486 m .48746 .49948 L .49545 .52494 L p
1 g
F P
s
P
p
.002 w
.47826 .36683 m .48461 .37328 L .5088 .35836 L p
1 g
F P
s
P
p
.002 w
.412 .41702 m .42251 .43159 L .44105 .41025 L p
1 g
F P
s
P
p
.002 w
.44105 .41025 m .43579 .40287 L .412 .41702 L p
1 g
F P
s
P
p
.002 w
.40566 .45316 m .42753 .46795 L .43728 .44172 L p
1 g
F P
s
P
p
.002 w
.43728 .44172 m .42251 .43159 L .40566 .45316 L p
1 g
F P
s
P
p
.002 w
.41943 .49362 m .45281 .50217 L .45318 .47466 L p
1 g
F P
s
P
p
.002 w
.45318 .47466 m .42753 .46795 L .41943 .49362 L p
1 g
F P
s
P
p
.002 w
.56683 .48104 m .58928 .44506 L .56516 .43337 L p
1 g
F P
s
P
p
.002 w
.57352 .39952 m .56516 .43337 L .58928 .44506 L p
1 g
F P
s
P
p
.002 w
.5088 .35836 m .4963 .34552 L .47826 .36683 L p
1 g
F P
s
P
p
.002 w
.47005 .36289 m .47826 .36683 L .4963 .34552 L p
1 g
F P
s
P
p
.002 w
.40696 .39955 m .412 .41702 L .43579 .40287 L p
1 g
F P
s
P
p
.002 w
.43579 .40287 m .4333 .39406 L .40696 .39955 L p
1 g
F P
s
P
p
.002 w
.4536 .52835 m .49545 .52494 L .48746 .49948 L p
1 g
F P
s
P
p
.002 w
.48746 .49948 m .45281 .50217 L .4536 .52835 L p
1 g
F P
s
P
p
.002 w
.54384 .36916 m .53301 .34506 L .5088 .35836 L p
1 g
F P
s
P
p
.002 w
.4963 .34552 m .5088 .35836 L .53301 .34506 L p
1 g
F P
s
P
p
.002 w
.4963 .34552 m .48004 .33759 L .47005 .36289 L p
1 g
F P
s
P
p
.002 w
.46086 .36188 m .47005 .36289 L .48004 .33759 L p
1 g
F P
s
P
p
.002 w
.57352 .39952 m .5707 .36508 L .54384 .36916 L p
1 g
F P
s
P
p
.002 w
.53301 .34506 m .54384 .36916 L .5707 .36508 L p
1 g
F P
s
P
p
.002 w
.408 .38109 m .40696 .39955 L .4333 .39406 L p
1 g
F P
s
P
p
.002 w
.4333 .39406 m .43386 .38478 L .408 .38109 L p
1 g
F P
s
P
p
.002 w
.39002 .43173 m .40566 .45316 L .42251 .43159 L p
1 g
F P
s
P
p
.002 w
.42251 .43159 m .412 .41702 L .39002 .43173 L p
1 g
F P
s
P
p
.002 w
.48004 .33759 m .46179 .3355 L .46086 .36188 L p
1 g
F P
s
P
p
.002 w
.45171 .36394 m .46086 .36188 L .46179 .3355 L p
1 g
F P
s
P
p
.002 w
.58928 .44506 m .59952 .4042 L .57352 .39952 L p
1 g
F P
s
P
p
.002 w
.5707 .36508 m .57352 .39952 L .59952 .4042 L p
1 g
F P
s
P
p
.002 w
.41505 .36369 m .408 .38109 L .43386 .38478 L p
1 g
F P
s
P
p
.002 w
.43386 .38478 m .43742 .37605 L .41505 .36369 L p
1 g
F P
s
P
p
.002 w
.39086 .47454 m .41943 .49362 L .42753 .46795 L p
1 g
F P
s
P
p
.002 w
.42753 .46795 m .40566 .45316 L .39086 .47454 L p
1 g
F P
s
P
p
.002 w
.46179 .3355 m .44355 .33954 L .45171 .36394 L p
1 g
F P
s
P
p
.002 w
.4436 .36884 m .45171 .36394 L .44355 .33954 L p
1 g
F P
s
P
p
.002 w
.42736 .3493 m .41505 .36369 L .43742 .37605 L p
1 g
F P
s
P
p
.002 w
.43742 .37605 m .4436 .36884 L .42736 .3493 L p
1 g
F P
s
P
p
.002 w
.44355 .33954 m .42736 .3493 L .4436 .36884 L p
1 g
F P
s
P
p
.002 w
.54858 .52966 m .58577 .49796 L .56683 .48104 L p
1 g
F P
s
P
p
.002 w
.56683 .48104 m .53448 .50858 L .54858 .52966 L p
1 g
F P
s
P
p
.002 w
.58928 .44506 m .56683 .48104 L .58577 .49796 L p
1 g
F P
s
P
p
.002 w
.53301 .34506 m .51468 .32599 L .4963 .34552 L p
1 g
F P
s
P
p
.002 w
.48004 .33759 m .4963 .34552 L .51468 .32599 L p
1 g
F P
s
P
p
.002 w
.50372 .54858 m .54858 .52966 L .53448 .50858 L p
1 g
F P
s
P
p
.002 w
.53448 .50858 m .49545 .52494 L .50372 .54858 L p
1 g
F P
s
P
p
.002 w
.41318 .51822 m .4536 .52835 L .45281 .50217 L p
1 g
F P
s
P
p
.002 w
.45281 .50217 m .41943 .49362 L .41318 .51822 L p
1 g
F P
s
P
p
.002 w
.38243 .40593 m .39002 .43173 L .412 .41702 L p
1 g
F P
s
P
p
.002 w
.412 .41702 m .40696 .39955 L .38243 .40593 L p
1 g
F P
s
P
p
.002 w
.58577 .49796 m .61166 .45662 L .58928 .44506 L p
1 g
F P
s
P
p
.002 w
.59952 .4042 m .58928 .44506 L .61166 .45662 L p
1 g
F P
s
P
p
.002 w
.5707 .36508 m .5568 .33366 L .53301 .34506 L p
1 g
F P
s
P
p
.002 w
.51468 .32599 m .53301 .34506 L .5568 .33366 L p
1 g
F P
s
P
p
.002 w
.45557 .55267 m .50372 .54858 L .49545 .52494 L p
1 g
F P
s
P
p
.002 w
.49545 .52494 m .4536 .52835 L .45557 .55267 L p
1 g
F P
s
P
p
.002 w
.51468 .32599 m .49071 .31413 L .48004 .33759 L p
1 g
F P
s
P
p
.002 w
.46179 .3355 m .48004 .33759 L .49071 .31413 L p
1 g
F P
s
P
p
.002 w
.59952 .4042 m .5963 .36255 L .5707 .36508 L p
1 g
F P
s
P
p
.002 w
.5568 .33366 m .5707 .36508 L .5963 .36255 L p
1 g
F P
s
P
p
.002 w
.37032 .44673 m .39086 .47454 L .40566 .45316 L p
1 g
F P
s
P
p
.002 w
.40566 .45316 m .39002 .43173 L .37032 .44673 L p
1 g
F P
s
P
p
.002 w
.38386 .37855 m .38243 .40593 L .40696 .39955 L p
1 g
F P
s
P
p
.002 w
.40696 .39955 m .408 .38109 L .38386 .37855 L p
1 g
F P
s
P
p
.002 w
.37847 .4953 m .41318 .51822 L .41943 .49362 L p
1 g
F P
s
P
p
.002 w
.41943 .49362 m .39086 .47454 L .37847 .4953 L p
1 g
F P
s
P
p
.002 w
.49071 .31413 m .46369 .31093 L .46179 .3355 L p
1 g
F P
s
P
p
.002 w
.44355 .33954 m .46179 .3355 L .46369 .31093 L p
1 g
F P
s
P
p
.002 w
.61166 .45662 m .62358 .40964 L .59952 .4042 L p
1 g
F P
s
P
p
.002 w
.5963 .36255 m .59952 .4042 L .62358 .40964 L p
1 g
F P
s
P
p
.002 w
.39427 .3527 m .38386 .37855 L .408 .38109 L p
1 g
F P
s
P
p
.002 w
.408 .38109 m .41505 .36369 L .39427 .3527 L p
1 g
F P
s
P
p
.002 w
.5568 .33366 m .53306 .30868 L .51468 .32599 L p
1 g
F P
s
P
p
.002 w
.49071 .31413 m .51468 .32599 L .53306 .30868 L p
1 g
F P
s
P
p
.002 w
.46369 .31093 m .4366 .31685 L .44355 .33954 L p
1 g
F P
s
P
p
.002 w
.42736 .3493 m .44355 .33954 L .4366 .31685 L p
1 g
F P
s
P
p
.002 w
.41255 .33131 m .39427 .3527 L .41505 .36369 L p
1 g
F P
s
P
p
.002 w
.41505 .36369 m .42736 .3493 L .41255 .33131 L p
1 g
F P
s
P
p
.002 w
.40897 .54122 m .45557 .55267 L .4536 .52835 L p
1 g
F P
s
P
p
.002 w
.4536 .52835 m .41318 .51822 L .40897 .54122 L p
1 g
F P
s
P
p
.002 w
.4366 .31685 m .41255 .33131 L .42736 .3493 L p
1 g
F P
s
P
p
.002 w
.56181 .54877 m .60303 .51362 L .58577 .49796 L p
1 g
F P
s
P
p
.002 w
.58577 .49796 m .54858 .52966 L .56181 .54877 L p
1 g
F P
s
P
p
.002 w
.61166 .45662 m .58577 .49796 L .60303 .51362 L p
1 g
F P
s
P
p
.002 w
.36024 .41308 m .37032 .44673 L .39002 .43173 L p
1 g
F P
s
P
p
.002 w
.39002 .43173 m .38243 .40593 L .36024 .41308 L p
1 g
F P
s
P
p
.002 w
.5121 .56984 m .56181 .54877 L .54858 .52966 L p
1 g
F P
s
P
p
.002 w
.54858 .52966 m .50372 .54858 L .5121 .56984 L p
1 g
F P
s
P
p
.002 w
.5963 .36255 m .57968 .32444 L .5568 .33366 L p
1 g
F P
s
P
p
.002 w
.53306 .30868 m .5568 .33366 L .57968 .32444 L p
1 g
F P
s
P
p
.002 w
.60303 .51362 m .63179 .46781 L .61166 .45662 L p
1 g
F P
s
P
p
.002 w
.62358 .40964 m .61166 .45662 L .63179 .46781 L p
1 g
F P
s
P
p
.002 w
.53306 .30868 m .50187 .29305 L .49071 .31413 L p
1 g
F P
s
P
p
.002 w
.46369 .31093 m .49071 .31413 L .50187 .29305 L p
1 g
F P
s
P
p
.002 w
.35338 .46171 m .37847 .4953 L .39086 .47454 L p
1 g
F P
s
P
p
.002 w
.39086 .47454 m .37032 .44673 L .35338 .46171 L p
1 g
F P
s
P
p
.002 w
.62358 .40964 m .62009 .36168 L .5963 .36255 L p
1 g
F P
s
P
p
.002 w
.57968 .32444 m .5963 .36255 L .62009 .36168 L p
1 g
F P
s
P
p
.002 w
.45872 .57456 m .5121 .56984 L .50372 .54858 L p
1 g
F P
s
P
p
.002 w
.50372 .54858 m .45557 .55267 L .45872 .57456 L p
1 g
F P
s
P
p
.002 w
.362 .37726 m .36024 .41308 L .38243 .40593 L p
1 g
F P
s
P
p
.002 w
.38243 .40593 m .38386 .37855 L .362 .37726 L p
1 g
F P
s
P
p
.002 w
.36883 .51499 m .40897 .54122 L .41318 .51822 L p
1 g
F P
s
P
p
.002 w
.41318 .51822 m .37847 .4953 L .36883 .51499 L p
1 g
F P
s
P
p
.002 w
.50187 .29305 m .46655 .28872 L .46369 .31093 L p
1 g
F P
s
P
p
.002 w
.4366 .31685 m .46369 .31093 L .46655 .28872 L p
1 g
F P
s
P
p
.002 w
.63179 .46781 m .64516 .41576 L .62358 .40964 L p
1 g
F P
s
P
p
.002 w
.62009 .36168 m .62358 .40964 L .64516 .41576 L p
1 g
F P
s
P
p
.002 w
.57968 .32444 m .55108 .29402 L .53306 .30868 L p
1 g
F P
s
P
p
.002 w
.50187 .29305 m .53306 .30868 L .55108 .29402 L p
1 g
F P
s
P
p
.002 w
.37558 .34336 m .362 .37726 L .38386 .37855 L p
1 g
F P
s
P
p
.002 w
.38386 .37855 m .39427 .3527 L .37558 .34336 L p
1 g
F P
s
P
p
.002 w
.40696 .56206 m .45872 .57456 L .45557 .55267 L p
1 g
F P
s
P
p
.002 w
.45557 .55267 m .40897 .54122 L .40696 .56206 L p
1 g
F P
s
P
p
.002 w
.46655 .28872 m .43107 .29639 L .4366 .31685 L p
1 g
F P
s
P
p
.002 w
.41255 .33131 m .4366 .31685 L .43107 .29639 L p
1 g
F P
s
P
p
.002 w
.34098 .42089 m .35338 .46171 L .37032 .44673 L p
1 g
F P
s
P
p
.002 w
.37032 .44673 m .36024 .41308 L .34098 .42089 L p
1 g
F P
s
P
p
.002 w
.39952 .31531 m .37558 .34336 L .39427 .3527 L p
1 g
F P
s
P
p
.002 w
.39427 .3527 m .41255 .33131 L .39952 .31531 L p
1 g
F P
s
P
p
.002 w
.43107 .29639 m .39952 .31531 L .41255 .33131 L p
1 g
F P
s
P
p
.002 w
.57385 .56544 m .61818 .52762 L .60303 .51362 L p
1 g
F P
s
P
p
.002 w
.60303 .51362 m .56181 .54877 L .57385 .56544 L p
1 g
F P
s
P
p
.002 w
.63179 .46781 m .60303 .51362 L .61818 .52762 L p
1 g
F P
s
P
p
.002 w
.62009 .36168 m .60115 .31766 L .57968 .32444 L p
1 g
F P
s
P
p
.002 w
.55108 .29402 m .57968 .32444 L .60115 .31766 L p
1 g
F P
s
P
p
.002 w
.52044 .58819 m .57385 .56544 L .56181 .54877 L p
1 g
F P
s
P
p
.002 w
.56181 .54877 m .5121 .56984 L .52044 .58819 L p
1 g
F P
s
P
p
.002 w
.61818 .52762 m .64917 .47839 L .63179 .46781 L p
1 g
F P
s
P
p
.002 w
.64516 .41576 m .63179 .46781 L .64917 .47839 L p
1 g
F P
s
P
p
.002 w
.55108 .29402 m .5133 .27488 L .50187 .29305 L p
1 g
F P
s
P
p
.002 w
.46655 .28872 m .50187 .29305 L .5133 .27488 L p
1 g
F P
s
P
p
.002 w
.3397 .47635 m .36883 .51499 L .37847 .4953 L p
1 g
F P
s
P
p
.002 w
.37847 .4953 m .35338 .46171 L .3397 .47635 L p
1 g
F P
s
P
p
.002 w
.64516 .41576 m .64149 .36254 L .62009 .36168 L p
1 g
F P
s
P
p
.002 w
.60115 .31766 m .62009 .36168 L .64149 .36254 L p
1 g
F P
s
P
p
.002 w
.46304 .59342 m .52044 .58819 L .5121 .56984 L p
1 g
F P
s
P
p
.002 w
.5121 .56984 m .45872 .57456 L .46304 .59342 L p
1 g
F P
s
P
p
.002 w
.34299 .3773 m .34098 .42089 L .36024 .41308 L p
1 g
F P
s
P
p
.002 w
.36024 .41308 m .362 .37726 L .34299 .3773 L p
1 g
F P
s
P
p
.002 w
.36228 .53313 m .40696 .56206 L .40897 .54122 L p
1 g
F P
s
P
p
.002 w
.40897 .54122 m .36883 .51499 L .36228 .53313 L p
1 g
F P
s
P
p
.002 w
.5133 .27488 m .47037 .26946 L .46655 .28872 L p
1 g
F P
s
P
p
.002 w
.43107 .29639 m .46655 .28872 L .47037 .26946 L p
1 g
F P
s
P
p
.002 w
.60115 .31766 m .56832 .28243 L .55108 .29402 L p
1 g
F P
s
P
p
.002 w
.5133 .27488 m .55108 .29402 L .56832 .28243 L p
1 g
F P
s
P
p
.002 w
.64917 .47839 m .66369 .42244 L .64516 .41576 L p
1 g
F P
s
P
p
.002 w
.64149 .36254 m .64516 .41576 L .66369 .42244 L p
1 g
F P
s
P
p
.002 w
.35946 .33597 m .34299 .3773 L .362 .37726 L p
1 g
F P
s
P
p
.002 w
.362 .37726 m .37558 .34336 L .35946 .33597 L p
1 g
F P
s
P
p
.002 w
.40732 .58018 m .46304 .59342 L .45872 .57456 L p
1 g
F P
s
P
p
.002 w
.45872 .57456 m .40696 .56206 L .40732 .58018 L p
1 g
F P
s
P
p
.002 w
.3252 .42921 m .3397 .47635 L .35338 .46171 L p
1 g
F P
s
P
p
.002 w
.35338 .46171 m .34098 .42089 L .3252 .42921 L p
1 g
F P
s
P
p
.002 w
.47037 .26946 m .42713 .27871 L .43107 .29639 L p
1 g
F P
s
P
p
.002 w
.39952 .31531 m .43107 .29639 L .42713 .27871 L p
1 g
F P
s
P
p
.002 w
.64149 .36254 m .62068 .3136 L .60115 .31766 L p
1 g
F P
s
P
p
.002 w
.56832 .28243 m .60115 .31766 L .62068 .3136 L p
1 g
F P
s
P
p
.002 w
.38864 .30175 m .35946 .33597 L .37558 .34336 L p
1 g
F P
s
P
p
.002 w
.37558 .34336 m .39952 .31531 L .38864 .30175 L p
1 g
F P
s
P
p
.002 w
.42713 .27871 m .38864 .30175 L .39952 .31531 L p
1 g
F P
s
P
p
.002 w
.5844 .57919 m .63079 .53959 L .61818 .52762 L p
1 g
F P
s
P
p
.002 w
.61818 .52762 m .57385 .56544 L .5844 .57919 L p
1 g
F P
s
P
p
.002 w
.64917 .47839 m .61818 .52762 L .63079 .53959 L p
1 g
F P
s
P
p
.002 w
.52853 .60308 m .5844 .57919 L .57385 .56544 L p
1 g
F P
s
P
p
.002 w
.57385 .56544 m .52044 .58819 L .52853 .60308 L p
1 g
F P
s
P
p
.002 w
.32975 .49031 m .36228 .53313 L .36883 .51499 L p
1 g
F P
s
P
p
.002 w
.36883 .51499 m .3397 .47635 L .32975 .49031 L p
1 g
F P
s
P
p
.002 w
.56832 .28243 m .52476 .26014 L .5133 .27488 L p
1 g
F P
s
P
p
.002 w
.47037 .26946 m .5133 .27488 L .52476 .26014 L p
1 g
F P
s
P
p
.002 w
.63079 .53959 m .66328 .4881 L .64917 .47839 L p
1 g
F P
s
P
p
.002 w
.66369 .42244 m .64917 .47839 L .66328 .4881 L p
1 g
F P
s
P
p
.002 w
.66369 .42244 m .65993 .36519 L .64149 .36254 L p
1 g
F P
s
P
p
.002 w
.62068 .3136 m .64149 .36254 L .65993 .36519 L p
1 g
F P
s
P
p
.002 w
.46848 .60869 m .52853 .60308 L .52044 .58819 L p
1 g
F P
s
P
p
.002 w
.52044 .58819 m .46304 .59342 L .46848 .60869 L p
1 g
F P
s
P
p
.002 w
.3274 .37874 m .3252 .42921 L .34098 .42089 L p
1 g
F P
s
P
p
.002 w
.34098 .42089 m .34299 .3773 L .3274 .37874 L p
1 g
F P
s
P
p
.002 w
.35914 .54921 m .40732 .58018 L .40696 .56206 L p
1 g
F P
s
P
p
.002 w
.40696 .56206 m .36228 .53313 L .35914 .54921 L p
1 g
F P
s
P
p
.002 w
.62068 .3136 m .58436 .27431 L .56832 .28243 L p
1 g
F P
s
P
p
.002 w
.52476 .26014 m .56832 .28243 L .58436 .27431 L p
1 g
F P
s
P
p
.002 w
.52476 .26014 m .4751 .25374 L .47037 .26946 L p
1 g
F P
s
P
p
.002 w
.42713 .27871 m .47037 .26946 L .4751 .25374 L p
1 g
F P
s
P
p
.002 w
.66328 .4881 m .67859 .42958 L .66369 .42244 L p
1 g
F P
s
P
p
.002 w
.65993 .36519 m .66369 .42244 L .67859 .42958 L p
1 g
F P
s
P
p
.002 w
.34645 .33078 m .3274 .37874 L .34299 .3773 L p
1 g
F P
s
P
p
.002 w
.34299 .3773 m .35946 .33597 L .34645 .33078 L p
1 g
F P
s
P
p
.002 w
.31346 .43789 m .32975 .49031 L .3397 .47635 L p
1 g
F P
s
P
p
.002 w
.3397 .47635 m .3252 .42921 L .31346 .43789 L p
1 g
F P
s
P
p
.002 w
.41016 .59499 m .46848 .60869 L .46304 .59342 L p
1 g
F P
s
P
p
.002 w
.46304 .59342 m .40732 .58018 L .41016 .59499 L p
1 g
F P
s
P
p
.002 w
.65993 .36519 m .63772 .31246 L .62068 .3136 L p
1 g
F P
s
P
p
.002 w
.58436 .27431 m .62068 .3136 L .63772 .31246 L p
1 g
F P
s
P
p
.002 w
.4751 .25374 m .42497 .26437 L .42713 .27871 L p
1 g
F P
s
P
p
.002 w
.38864 .30175 m .42713 .27871 L .42497 .26437 L p
1 g
F P
s
P
p
.002 w
.38029 .29107 m .34645 .33078 L .35946 .33597 L p
1 g
F P
s
P
p
.002 w
.35946 .33597 m .38864 .30175 L .38029 .29107 L p
1 g
F P
s
P
p
.002 w
.42497 .26437 m .38029 .29107 L .38864 .30175 L p
1 g
F P
s
P
p
.002 w
.59312 .58953 m .64042 .54913 L .63079 .53959 L p
1 g
F P
s
P
p
.002 w
.63079 .53959 m .5844 .57919 L .59312 .58953 L p
1 g
F P
s
P
p
.002 w
.66328 .4881 m .63079 .53959 L .64042 .54913 L p
1 g
F P
s
P
p
.002 w
.53618 .61395 m .59312 .58953 L .5844 .57919 L p
1 g
F P
s
P
p
.002 w
.5844 .57919 m .52853 .60308 L .53618 .61395 L p
1 g
F P
s
P
p
.002 w
.32398 .5032 m .35914 .54921 L .36228 .53313 L p
1 g
F P
s
P
p
.002 w
.36228 .53313 m .32975 .49031 L .32398 .5032 L p
1 g
F P
s
P
p
.002 w
.58436 .27431 m .53599 .24937 L .52476 .26014 L p
1 g
F P
s
P
p
.002 w
.4751 .25374 m .52476 .26014 L .53599 .24937 L p
1 g
F P
s
P
p
.002 w
.67859 .42958 m .67481 .36967 L .65993 .36519 L p
1 g
F P
s
P
p
.002 w
.63772 .31246 m .65993 .36519 L .67481 .36967 L p
1 g
F P
s
P
p
.002 w
.64042 .54913 m .6736 .49665 L .66328 .4881 L p
1 g
F P
s
P
p
.002 w
.67859 .42958 m .66328 .4881 L .6736 .49665 L p
1 g
F P
s
P
p
.002 w
.31582 .38163 m .31346 .43789 L .3252 .42921 L p
1 g
F P
s
P
p
.002 w
.3252 .42921 m .3274 .37874 L .31582 .38163 L p
1 g
F P
s
P
p
.002 w
.47498 .61978 m .53618 .61395 L .52853 .60308 L p
1 g
F P
s
P
p
.002 w
.52853 .60308 m .46848 .60869 L .47498 .61978 L p
1 g
F P
s
P
p
.002 w
.35967 .56272 m .41016 .59499 L .40732 .58018 L p
1 g
F P
s
P
p
.002 w
.40732 .58018 m .35914 .54921 L .35967 .56272 L p
1 g
F P
s
P
p
.002 w
.63772 .31246 m .59876 .27005 L .58436 .27431 L p
1 g
F P
s
P
p
.002 w
.53599 .24937 m .58436 .27431 L .59876 .27005 L p
1 g
F P
s
P
p
.002 w
.53599 .24937 m .48068 .24211 L .4751 .25374 L p
1 g
F P
s
P
p
.002 w
.42497 .26437 m .4751 .25374 L .48068 .24211 L p
1 g
F P
s
P
p
.002 w
.6736 .49665 m .6893 .43702 L .67859 .42958 L p
1 g
F P
s
P
p
.002 w
.67481 .36967 m .67859 .42958 L .6893 .43702 L p
1 g
F P
s
P
p
.002 w
.33703 .32807 m .31582 .38163 L .3274 .37874 L p
1 g
F P
s
P
p
.002 w
.3274 .37874 m .34645 .33078 L .33703 .32807 L p
1 g
F P
s
P
p
.002 w
.30631 .44672 m .32398 .5032 L .32975 .49031 L p
1 g
F P
s
P
p
.002 w
.32975 .49031 m .31346 .43789 L .30631 .44672 L p
1 g
F P
s
P
p
.002 w
.41555 .60593 m .47498 .61978 L .46848 .60869 L p
1 g
F P
s
P
p
.002 w
.46848 .60869 m .41016 .59499 L .41555 .60593 L p
1 g
F P
s
P
p
.002 w
.67481 .36967 m .65173 .31445 L .63772 .31246 L p
1 g
F P
s
P
p
.002 w
.59876 .27005 m .63772 .31246 L .65173 .31445 L p
1 g
F P
s
P
p
.002 w
.48068 .24211 m .42473 .25391 L .42497 .26437 L p
1 g
F P
s
P
p
.002 w
.38029 .29107 m .42497 .26437 L .42473 .25391 L p
1 g
F P
s
P
p
.002 w
.37483 .28371 m .33703 .32807 L .34645 .33078 L p
1 g
F P
s
P
p
.002 w
.34645 .33078 m .38029 .29107 L .37483 .28371 L p
1 g
F P
s
P
p
.002 w
.42473 .25391 m .37483 .28371 L .38029 .29107 L p
1 g
F P
s
P
p
.002 w
.59969 .59601 m .64667 .55587 L .64042 .54913 L p
1 g
F P
s
P
p
.002 w
.64042 .54913 m .59312 .58953 L .59969 .59601 L p
1 g
F P
s
P
p
.002 w
.6736 .49665 m .64042 .54913 L .64667 .55587 L p
1 g
F P
s
P
p
.002 w
.32279 .51463 m .35967 .56272 L .35914 .54921 L p
1 g
F P
s
P
p
.002 w
.35914 .54921 m .32398 .5032 L .32279 .51463 L p
1 g
F P
s
P
p
.002 w
.54316 .6203 m .59969 .59601 L .59312 .58953 L p
1 g
F P
s
P
p
.002 w
.59312 .58953 m .53618 .61395 L .54316 .6203 L p
1 g
F P
s
P
p
.002 w
.59876 .27005 m .54669 .24306 L .53599 .24937 L p
1 g
F P
s
P
p
.002 w
.48068 .24211 m .53599 .24937 L .54669 .24306 L p
1 g
F P
s
P
p
.002 w
.6893 .43702 m .68556 .37597 L .67481 .36967 L p
1 g
F P
s
P
p
.002 w
.65173 .31445 m .67481 .36967 L .68556 .37597 L p
1 g
F P
s
P
p
.002 w
.64667 .55587 m .67965 .50377 L .6736 .49665 L p
1 g
F P
s
P
p
.002 w
.6893 .43702 m .6736 .49665 L .67965 .50377 L p
1 g
F P
s
P
p
.002 w
.3088 .38597 m .30631 .44672 L .31346 .43789 L p
1 g
F P
s
P
p
.002 w
.31346 .43789 m .31582 .38163 L .3088 .38597 L p
1 g
F P
s
P
p
.002 w
.48245 .62614 m .54316 .6203 L .53618 .61395 L p
1 g
F P
s
P
p
.002 w
.53618 .61395 m .47498 .61978 L .48245 .62614 L p
1 g
F P
s
P
p
.002 w
.36409 .57314 m .41555 .60593 L .41016 .59499 L p
1 g
F P
s
P
p
.002 w
.41016 .59499 m .35967 .56272 L .36409 .57314 L p
1 g
F P
s
P
p
.002 w
.65173 .31445 m .61105 .26999 L .59876 .27005 L p
1 g
F P
s
P
p
.002 w
.54669 .24306 m .59876 .27005 L .61105 .26999 L p
1 g
F P
s
P
p
.002 w
.54669 .24306 m .48702 .23515 L .48068 .24211 L p
1 g
F P
s
P
p
.002 w
.42473 .25391 m .48068 .24211 L .48702 .23515 L p
1 g
F P
s
P
p
.002 w
.67965 .50377 m .69529 .44459 L .6893 .43702 L p
1 g
F P
s
P
p
.002 w
.68556 .37597 m .6893 .43702 L .69529 .44459 L p
1 g
F P
s
P
p
.002 w
.30422 .45548 m .32279 .51463 L .32398 .5032 L p
1 g
F P
s
P
p
.002 w
.32398 .5032 m .30631 .44672 L .30422 .45548 L p
1 g
F P
s
P
p
.002 w
.33169 .32807 m .3088 .38597 L .31582 .38163 L p
1 g
F P
s
P
p
.002 w
.31582 .38163 m .33703 .32807 L .33169 .32807 L p
1 g
F P
s
P
p
.002 w
.4235 .61247 m .48245 .62614 L .47498 .61978 L p
1 g
F P
s
P
p
.002 w
.47498 .61978 m .41555 .60593 L .4235 .61247 L p
1 g
F P
s
P
p
.002 w
.68556 .37597 m .66215 .3197 L .65173 .31445 L p
1 g
F P
s
P
p
.002 w
.61105 .26999 m .65173 .31445 L .66215 .3197 L p
1 g
F P
s
P
p
.002 w
.48702 .23515 m .42656 .24785 L .42473 .25391 L p
1 g
F P
s
P
p
.002 w
.37483 .28371 m .42473 .25391 L .42656 .24785 L p
1 g
F P
s
P
p
.002 w
.37258 .28007 m .33169 .32807 L .33703 .32807 L p
1 g
F P
s
P
p
.002 w
.33703 .32807 m .37483 .28371 L .37258 .28007 L p
1 g
F P
s
P
p
.002 w
.3265 .52419 m .36409 .57314 L .35967 .56272 L p
1 g
F P
s
P
p
.002 w
.35967 .56272 m .32279 .51463 L .3265 .52419 L p
1 g
F P
s
P
p
.002 w
.42656 .24785 m .37258 .28007 L .37483 .28371 L p
1 g
F P
s
P
p
.002 w
.60379 .5982 m .64915 .55945 L .64667 .55587 L p
1 g
F P
s
P
p
.002 w
.64667 .55587 m .59969 .59601 L .60379 .5982 L p
1 g
F P
s
P
p
.002 w
.67965 .50377 m .64667 .55587 L .64915 .55945 L p
1 g
F P
s
P
p
.002 w
.61105 .26999 m .55656 .24165 L .54669 .24306 L p
1 g
F P
s
P
p
.002 w
.48702 .23515 m .54669 .24306 L .55656 .24165 L p
1 g
F P
s
P
p
.002 w
.54925 .62165 m .60379 .5982 L .59969 .59601 L p
1 g
F P
s
P
p
.002 w
.59969 .59601 m .54316 .6203 L .54925 .62165 L p
1 g
F P
s
P
p
.002 w
.69529 .44459 m .69164 .38405 L .68556 .37597 L p
1 g
F P
s
P
p
.002 w
.66215 .3197 m .68556 .37597 L .69164 .38405 L p
1 g
F P
s
P
p
.002 w
.64915 .55945 m .68099 .50916 L .67965 .50377 L p
1 g
F P
s
P
p
.002 w
.69529 .44459 m .67965 .50377 L .68099 .50916 L p
1 g
F P
s
P
p
.002 w
.30681 .39175 m .30422 .45548 L .30631 .44672 L p
1 g
F P
s
P
p
.002 w
.30631 .44672 m .3088 .38597 L .30681 .39175 L p
1 g
F P
s
P
p
.002 w
.49072 .62731 m .54925 .62165 L .54316 .6203 L p
1 g
F P
s
P
p
.002 w
.54316 .6203 m .48245 .62614 L .49072 .62731 L p
1 g
F P
s
P
p
.002 w
.37251 .58 m .4235 .61247 L .41555 .60593 L p
1 g
F P
s
P
p
.002 w
.41555 .60593 m .36409 .57314 L .37251 .58 L p
1 g
F P
s
P
p
.002 w
.66215 .3197 m .62077 .27438 L .61105 .26999 L p
1 g
F P
s
P
p
.002 w
.55656 .24165 m .61105 .26999 L .62077 .27438 L p
1 g
F P
s
P
p
.002 w
.55656 .24165 m .494 .23333 L .48702 .23515 L p
1 g
F P
s
P
p
.002 w
.42656 .24785 m .48702 .23515 L .494 .23333 L p
1 g
F P
s
P
p
.002 w
.68099 .50916 m .69609 .4521 L .69529 .44459 L p
1 g
F P
s
P
p
.002 w
.69164 .38405 m .69529 .44459 L .69609 .4521 L p
1 g
F P
s
P
p
.002 w
.30758 .4639 m .3265 .52419 L .32279 .51463 L p
1 g
F P
s
P
p
.002 w
.32279 .51463 m .30422 .45548 L .30758 .4639 L p
1 g
F P
s
P
p
.002 w
.33086 .33095 m .30681 .39175 L .3088 .38597 L p
1 g
F P
s
P
p
.002 w
.3088 .38597 m .33169 .32807 L .33086 .33095 L p
1 g
F P
s
P
p
.002 w
.69164 .38405 m .66847 .32827 L .66215 .3197 L p
1 g
F P
s
P
p
.002 w
.62077 .27438 m .66215 .3197 L .66847 .32827 L p
1 g
F P
s
P
p
.002 w
.43397 .61413 m .49072 .62731 L .48245 .62614 L p
1 g
F P
s
P
p
.002 w
.48245 .62614 m .4235 .61247 L .43397 .61413 L p
1 g
F P
s
P
p
.002 w
.494 .23333 m .43053 .24667 L .42656 .24785 L p
1 g
F P
s
P
p
.002 w
.37258 .28007 m .42656 .24785 L .43053 .24667 L p
1 g
F P
s
P
p
.002 w
.33531 .53148 m .37251 .58 L .36409 .57314 L p
1 g
F P
s
P
p
.002 w
.36409 .57314 m .3265 .52419 L .33531 .53148 L p
1 g
F P
s
P
p
.002 w
.37382 .28052 m .33086 .33095 L .33169 .32807 L p
1 g
F P
s
P
p
.002 w
.33169 .32807 m .37258 .28007 L .37382 .28052 L p
1 g
F P
s
P
p
.002 w
.62077 .27438 m .56525 .24551 L .55656 .24165 L p
1 g
F P
s
P
p
.002 w
.494 .23333 m .55656 .24165 L .56525 .24551 L p
1 g
F P
s
P
p
.002 w
.43053 .24667 m .37382 .28052 L .37258 .28007 L p
1 g
F P
s
P
p
.002 w
.60515 .59576 m .64753 .55955 L .64915 .55945 L p
1 g
F P
s
P
p
.002 w
.64915 .55945 m .60379 .5982 L .60515 .59576 L p
1 g
F P
s
P
p
.002 w
.68099 .50916 m .64915 .55945 L .64753 .55955 L p
1 g
F P
s
P
p
.002 w
.69609 .4521 m .69258 .39377 L .69164 .38405 L p
1 g
F P
s
P
p
.002 w
.66847 .32827 m .69164 .38405 L .69258 .39377 L p
1 g
F P
s
P
p
.002 w
.55421 .61765 m .60515 .59576 L .60379 .5982 L p
1 g
F P
s
P
p
.002 w
.60379 .5982 m .54925 .62165 L .55421 .61765 L p
1 g
F P
s
P
p
.002 w
.64753 .55955 m .67727 .51258 L .68099 .50916 L p
1 g
F P
s
P
p
.002 w
.69609 .4521 m .68099 .50916 L .67727 .51258 L p
1 g
F P
s
P
p
.002 w
.31026 .39889 m .30758 .4639 L .30422 .45548 L p
1 g
F P
s
P
p
.002 w
.30422 .45548 m .30681 .39175 L .31026 .39889 L p
1 g
F P
s
P
p
.002 w
.38495 .58285 m .43397 .61413 L .4235 .61247 L p
1 g
F P
s
P
p
.002 w
.4235 .61247 m .37251 .58 L .38495 .58285 L p
1 g
F P
s
P
p
.002 w
.49961 .6229 m .55421 .61765 L .54925 .62165 L p
1 g
F P
s
P
p
.002 w
.54925 .62165 m .49072 .62731 L .49961 .6229 L p
1 g
F P
s
P
p
.002 w
.66847 .32827 m .62747 .28339 L .62077 .27438 L p
1 g
F P
s
P
p
.002 w
.56525 .24551 m .62077 .27438 L .62747 .28339 L p
1 g
F P
s
P
p
.002 w
.67727 .51258 m .69134 .45932 L .69609 .4521 L p
1 g
F P
s
P
p
.002 w
.69258 .39377 m .69609 .4521 L .69134 .45932 L p
1 g
F P
s
P
p
.002 w
.56525 .24551 m .50145 .23705 L .494 .23333 L p
1 g
F P
s
P
p
.002 w
.43053 .24667 m .494 .23333 L .50145 .23705 L p
1 g
F P
s
P
p
.002 w
.31664 .47172 m .33531 .53148 L .3265 .52419 L p
1 g
F P
s
P
p
.002 w
.3265 .52419 m .30758 .4639 L .31664 .47172 L p
1 g
F P
s
P
p
.002 w
.69258 .39377 m .67025 .34012 L .66847 .32827 L p
1 g
F P
s
P
p
.002 w
.62747 .28339 m .66847 .32827 L .67025 .34012 L p
1 g
F P
s
P
p
.002 w
.33485 .33682 m .31026 .39889 L .30681 .39175 L p
1 g
F P
s
P
p
.002 w
.30681 .39175 m .33086 .33095 L .33485 .33682 L p
1 g
F P
s
P
p
.002 w
.44677 .61056 m .49961 .6229 L .49072 .62731 L p
1 g
F P
s
P
p
.002 w
.49072 .62731 m .43397 .61413 L .44677 .61056 L p
1 g
F P
s
P
p
.002 w
.50145 .23705 m .43667 .2507 L .43053 .24667 L p
1 g
F P
s
P
p
.002 w
.37382 .28052 m .43053 .24667 L .43667 .2507 L p
1 g
F P
s
P
p
.002 w
.34927 .53615 m .38495 .58285 L .37251 .58 L p
1 g
F P
s
P
p
.002 w
.37251 .58 m .33531 .53148 L .34927 .53615 L p
1 g
F P
s
P
p
.002 w
.37875 .2853 m .33485 .33682 L .33086 .33095 L p
1 g
F P
s
P
p
.002 w
.33086 .33095 m .37382 .28052 L .37875 .2853 L p
1 g
F P
s
P
p
.002 w
.62747 .28339 m .57244 .25484 L .56525 .24551 L p
1 g
F P
s
P
p
.002 w
.50145 .23705 m .56525 .24551 L .57244 .25484 L p
1 g
F P
s
P
p
.002 w
.69134 .45932 m .68802 .40497 L .69258 .39377 L p
1 g
F P
s
P
p
.002 w
.67025 .34012 m .69258 .39377 L .68802 .40497 L p
1 g
F P
s
P
p
.002 w
.43667 .2507 m .37875 .2853 L .37382 .28052 L p
1 g
F P
s
P
p
.002 w
.60353 .58844 m .64159 .55594 L .64753 .55955 L p
1 g
F P
s
P
p
.002 w
.64753 .55955 m .60515 .59576 L .60353 .58844 L p
1 g
F P
s
P
p
.002 w
.67727 .51258 m .64753 .55955 L .64159 .55594 L p
1 g
F P
s
P
p
.002 w
.55782 .60806 m .60353 .58844 L .60515 .59576 L p
1 g
F P
s
P
p
.002 w
.60515 .59576 m .55421 .61765 L .55782 .60806 L p
1 g
F P
s
P
p
.002 w
.64159 .55594 m .66826 .51377 L .67727 .51258 L p
1 g
F P
s
P
p
.002 w
.69134 .45932 m .67727 .51258 L .66826 .51377 L p
1 g
F P
s
P
p
.002 w
.31939 .40726 m .31664 .47172 L .30758 .4639 L p
1 g
F P
s
P
p
.002 w
.30758 .4639 m .31026 .39889 L .31939 .40726 L p
1 g
F P
s
P
p
.002 w
.40125 .58136 m .44677 .61056 L .43397 .61413 L p
1 g
F P
s
P
p
.002 w
.43397 .61413 m .38495 .58285 L .40125 .58136 L p
1 g
F P
s
P
p
.002 w
.50889 .61269 m .55782 .60806 L .55421 .61765 L p
1 g
F P
s
P
p
.002 w
.55421 .61765 m .49961 .6229 L .50889 .61269 L p
1 g
F P
s
P
p
.002 w
.67025 .34012 m .63076 .29703 L .62747 .28339 L p
1 g
F P
s
P
p
.002 w
.57244 .25484 m .62747 .28339 L .63076 .29703 L p
1 g
F P
s
P
p
.002 w
.66826 .51377 m .68083 .466 L .69134 .45932 L p
1 g
F P
s
P
p
.002 w
.68802 .40497 m .69134 .45932 L .68083 .466 L p
1 g
F P
s
P
p
.002 w
.57244 .25484 m .50918 .24655 L .50145 .23705 L p
1 g
F P
s
P
p
.002 w
.43667 .2507 m .50145 .23705 L .50918 .24655 L p
1 g
F P
s
P
p
.002 w
.33146 .47865 m .34927 .53615 L .33531 .53148 L p
1 g
F P
s
P
p
.002 w
.33531 .53148 m .31664 .47172 L .33146 .47865 L p
1 g
F P
s
P
p
.002 w
.68802 .40497 m .66715 .35508 L .67025 .34012 L p
1 g
F P
s
P
p
.002 w
.63076 .29703 m .67025 .34012 L .66715 .35508 L p
1 g
F P
s
P
p
.002 w
.46165 .60154 m .50889 .61269 L .49961 .6229 L p
1 g
F P
s
P
p
.002 w
.49961 .6229 m .44677 .61056 L .46165 .60154 L p
1 g
F P
s
P
p
.002 w
.34386 .34569 m .31939 .40726 L .31026 .39889 L p
1 g
F P
s
P
p
.002 w
.31026 .39889 m .33485 .33682 L .34386 .34569 L p
1 g
F P
s
P
p
.002 w
.36823 .53786 m .40125 .58136 L .38495 .58285 L p
1 g
F P
s
P
p
.002 w
.38495 .58285 m .34927 .53615 L .36823 .53786 L p
1 g
F P
s
P
p
.002 w
.50918 .24655 m .44492 .26018 L .43667 .2507 L p
1 g
F P
s
P
p
.002 w
.37875 .2853 m .43667 .2507 L .44492 .26018 L p
1 g
F P
s
P
p
.002 w
.63076 .29703 m .5778 .26971 L .57244 .25484 L p
1 g
F P
s
P
p
.002 w
.50918 .24655 m .57244 .25484 L .5778 .26971 L p
1 g
F P
s
P
p
.002 w
.38745 .29456 m .34386 .34569 L .33485 .33682 L p
1 g
F P
s
P
p
.002 w
.33485 .33682 m .37875 .2853 L .38745 .29456 L p
1 g
F P
s
P
p
.002 w
.68083 .466 m .67776 .41736 L .68802 .40497 L p
1 g
F P
s
P
p
.002 w
.66715 .35508 m .68802 .40497 L .67776 .41736 L p
1 g
F P
s
P
p
.002 w
.44492 .26018 m .38745 .29456 L .37875 .2853 L p
1 g
F P
s
P
p
.002 w
.59881 .57617 m .63123 .54849 L .64159 .55594 L p
1 g
F P
s
P
p
.002 w
.64159 .55594 m .60353 .58844 L .59881 .57617 L p
1 g
F P
s
P
p
.002 w
.66826 .51377 m .64159 .55594 L .63123 .54849 L p
1 g
F P
s
P
p
.002 w
.55987 .59284 m .59881 .57617 L .60353 .58844 L p
1 g
F P
s
P
p
.002 w
.60353 .58844 m .55782 .60806 L .55987 .59284 L p
1 g
F P
s
P
p
.002 w
.33425 .41665 m .33146 .47865 L .31664 .47172 L p
1 g
F P
s
P
p
.002 w
.31664 .47172 m .31939 .40726 L .33425 .41665 L p
1 g
F P
s
P
p
.002 w
.4211 .57533 m .46165 .60154 L .44677 .61056 L p
1 g
F P
s
P
p
.002 w
.44677 .61056 m .40125 .58136 L .4211 .57533 L p
1 g
F P
s
P
p
.002 w
.63123 .54849 m .65392 .51255 L .66826 .51377 L p
1 g
F P
s
P
p
.002 w
.68083 .466 m .66826 .51377 L .65392 .51255 L p
1 g
F P
s
P
p
.002 w
.66715 .35508 m .63033 .31514 L .63076 .29703 L p
1 g
F P
s
P
p
.002 w
.5778 .26971 m .63076 .29703 L .63033 .31514 L p
1 g
F P
s
P
p
.002 w
.51827 .59668 m .55987 .59284 L .55782 .60806 L p
1 g
F P
s
P
p
.002 w
.55782 .60806 m .50889 .61269 L .51827 .59668 L p
1 g
F P
s
P
p
.002 w
.65392 .51255 m .66454 .47191 L .68083 .466 L p
1 g
F P
s
P
p
.002 w
.67776 .41736 m .68083 .466 L .66454 .47191 L p
1 g
F P
s
P
p
.002 w
.5778 .26971 m .51694 .26189 L .50918 .24655 L p
1 g
F P
s
P
p
.002 w
.44492 .26018 m .50918 .24655 L .51694 .26189 L p
1 g
F P
s
P
p
.002 w
.35189 .48439 m .36823 .53786 L .34927 .53615 L p
1 g
F P
s
P
p
.002 w
.34927 .53615 m .33146 .47865 L .35189 .48439 L p
1 g
F P
s
P
p
.002 w
.67776 .41736 m .65897 .37286 L .66715 .35508 L p
1 g
F P
s
P
p
.002 w
.63033 .31514 m .66715 .35508 L .65897 .37286 L p
1 g
F P
s
P
p
.002 w
.47823 .58708 m .51827 .59668 L .50889 .61269 L p
1 g
F P
s
P
p
.002 w
.50889 .61269 m .46165 .60154 L .47823 .58708 L p
1 g
F P
s
P
p
.002 w
.35789 .35744 m .33425 .41665 L .31939 .40726 L p
1 g
F P
s
P
p
.002 w
.31939 .40726 m .34386 .34569 L .35789 .35744 L p
1 g
F P
s
P
p
.002 w
.39183 .5364 m .4211 .57533 L .40125 .58136 L p
1 g
F P
s
P
p
.002 w
.40125 .58136 m .36823 .53786 L .39183 .5364 L p
1 g
F P
s
P
p
.002 w
.51694 .26189 m .45515 .27512 L .44492 .26018 L p
1 g
F P
s
P
p
.002 w
.38745 .29456 m .44492 .26018 L .45515 .27512 L p
1 g
F P
s
P
p
.002 w
.63033 .31514 m .58104 .28993 L .5778 .26971 L p
1 g
F P
s
P
p
.002 w
.51694 .26189 m .5778 .26971 L .58104 .28993 L p
1 g
F P
s
P
p
.002 w
.66454 .47191 m .66181 .43062 L .67776 .41736 L p
1 g
F P
s
P
p
.002 w
.65897 .37286 m .67776 .41736 L .66181 .43062 L p
1 g
F P
s
P
p
.002 w
.39987 .30825 m .35789 .35744 L .34386 .34569 L p
1 g
F P
s
P
p
.002 w
.34386 .34569 m .38745 .29456 L .39987 .30825 L p
1 g
F P
s
P
p
.004 w
.33262 .31709 m
.34563 .32591 L
s
P
p
.002 w
.45515 .27512 m .39987 .30825 L .38745 .29456 L p
1 g
F P
s
P
p
.002 w
.59093 .55906 m .61653 .53721 L .63123 .54849 L p
1 g
F P
s
P
p
.002 w
.63123 .54849 m .59881 .57617 L .59093 .55906 L p
1 g
F P
s
P
p
.002 w
.65392 .51255 m .63123 .54849 L .61653 .53721 L p
1 g
F P
s
P
p
.002 w
.5602 .57215 m .59093 .55906 L .59881 .57617 L p
1 g
F P
s
P
p
.002 w
.59881 .57617 m .55987 .59284 L .5602 .57215 L p
1 g
F P
s
P
p
.002 w
.44401 .56472 m .47823 .58708 L .46165 .60154 L p
1 g
F P
s
P
p
.002 w
.46165 .60154 m .4211 .57533 L .44401 .56472 L p
1 g
F P
s
P
p
.002 w
.35467 .42681 m .35189 .48439 L .33146 .47865 L p
1 g
F P
s
P
p
.002 w
.33146 .47865 m .33425 .41665 L .35467 .42681 L p
1 g
F P
s
P
p
.002 w
.61653 .53721 m .63441 .50883 L .65392 .51255 L p
1 g
F P
s
P
p
.002 w
.66454 .47191 m .65392 .51255 L .63441 .50883 L p
1 g
F P
s
P
p
.002 w
.65897 .37286 m .62597 .33736 L .63033 .31514 L p
1 g
F P
s
P
p
.002 w
.58104 .28993 m .63033 .31514 L .62597 .33736 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.5602 .57215 m .55987 .59284 L p
.52953 .57623 L 1 g
F P
s
P
p
.52953 .57623 m .52894 .5759 L .53039 .57573 L 1 g
F
P
p
.52953 .57623 m .53039 .57573 L .5602 .57215 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53178 .57492 L p
1 g
F P
s
P
p
.54854 .56129 m .53178 .57492 L .53224 .57465 L 1 g
F
P
p
.002 w
.5602 .57215 m .53966 .57398 L p
.55004 .56216 L 1 g
F P
s
P
p
.002 w
.53966 .57398 m .53224 .57465 L p
.54911 .56281 L 1 g
F P
s
P
p
.53966 .57398 m .54911 .56281 L .55004 .56216 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56281 L p
1 g
F P
s
P
p
.56075 .54566 m .54911 .56281 L .55539 .55538 L 1 g
F
P
p
.54854 .56129 m .53224 .57465 L .5409 .56857 L 1 g
F
P
p
.002 w
.53178 .57492 m .53128 .57265 L p
.52103 .57791 L 1 g
F P
s
P
p
.51827 .59668 m .50642 .5811 L .5109 .58012 L 1 g
F
P
p
.002 w
.52676 .57666 m .52538 .57991 L p
.5109 .58012 L 1 g
F P
s
P
p
.002 w
.52538 .57991 m .51827 .59668 L p
.5109 .58012 L 1 g
F P
s
P
p
.002 w
.5109 .58012 m .51079 .57862 L p
.50271 .58024 L 1 g
F P
s
P
p
.52103 .57791 m .52676 .57666 L .53178 .57492 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58043 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58043 L .50271 .58024 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.5109 .58012 m .496 .56739 L .52676 .57666 L 1 g
F
P
p
.50642 .5811 m .50574 .58019 L .5109 .58012 L 1 g
F
P
p
.50574 .58019 m .496 .56739 L .5109 .58012 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51827 .59668 m .47823 .58708 L .48494 .57965 L p
1 g
F P
s
P
p
.002 w
.48907 .58043 m .48921 .57862 L p
.47952 .57782 L 1 g
F P
s
P
p
.002 w
.48494 .57965 m .47823 .58708 L p
.47571 .57654 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47823 .58708 m .44765 .5671 L p
.46841 .57409 L 1 g
F P
s
P
p
.47629 .57897 m .46841 .57409 L .47571 .57654 L 1 g
F
P
p
.47823 .58708 m .46841 .57409 L .47629 .57897 L 1 g
F
P
p
.002 w
.46841 .57409 m .46872 .57265 L p
.46133 .5697 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46841 .57409 L p
1 g
F P
s
P
p
.002 w
.46841 .57409 m .4678 .57686 L p
.47952 .57782 L 1 g
F P
s
P
p
.48921 .57862 m .46841 .57409 L .47952 .57782 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56315 L p
1 g
F P
s
P
p
.002 w
.44401 .56472 m .44875 .5619 L p
.45077 .56315 L 1 g
F P
s
P
p
.46733 .57342 m .45662 .56942 L .45077 .56315 L 1 g
F
P
p
.45662 .56942 m .44401 .56472 L .45077 .56315 L 1 g
F
P
p
.002 w
.45077 .56315 m .45146 .56129 L p
.4451 .55577 L 1 g
F P
s
P
p
.002 w
.44929 .56157 m .44401 .56472 L p
.44532 .55607 L 1 g
F P
s
P
p
.4451 .55577 m .44929 .56157 L .45077 .56315 L 1 g
F
P
p
.002 w
.44401 .56472 m .41945 .53167 L .42641 .52987 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.44401 .56472 m .42641 .52987 L .43864 .54681 L 1 g
F
P
p
.44421 .56334 m .43864 .54681 L .44532 .55607 L 1 g
F
P
p
.44401 .56472 m .43864 .54681 L .44421 .56334 L 1 g
F
P
p
.002 w
.43864 .54681 m .43925 .54566 L p
.43625 .53973 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .54681 L p
1 g
F P
s
P
p
.002 w
.43864 .54681 m .43743 .5491 L p
.4451 .55577 L 1 g
F P
s
P
p
.45146 .56129 m .43864 .54681 L .4451 .55577 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43253 .52869 L p
1 g
F P
s
P
p
.002 w
.42641 .52987 m .4324 .52831 L p
.43253 .52869 L 1 g
F P
s
P
p
.43864 .54681 m .4323 .53802 L .43253 .52869 L 1 g
F
P
p
.4323 .53802 m .42641 .52987 L .43253 .52869 L 1 g
F
P
p
.002 w
.43253 .52869 m .43346 .52734 L p
.43322 .52035 L 1 g
F P
s
P
p
.41945 .53167 m .43461 .50404 L .43418 .50905 L 1 g
F
P
p
.002 w
.43254 .52828 m .4242 .53044 L p
.43418 .50905 L 1 g
F P
s
P
p
.002 w
.4242 .53044 m .41945 .53167 L p
.43418 .50905 L 1 g
F P
s
P
p
.43322 .52035 m .43254 .52828 L .43253 .52869 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4424 .49155 L p
1 g
F P
s
P
p
.43485 .50826 m .4424 .49155 L .4423 .49175 L 1 g
F
P
p
.43485 .50826 m .44238 .49158 L .44191 .49253 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.47863 .46785 m .47705 .49097 L .44214 .49206 L p
1 g
F P
s
P
p
.002 w
.4424 .49155 m .44339 .4905 L p
.44992 .48424 L 1 g
F P
s
P
p
.4426 .49116 m .47863 .46785 L .44214 .49206 L 1 g
F
P
p
.002 w
.44214 .49206 m .44187 .49207 L p
.4424 .49155 L 1 g
F P
s
P
p
.002 w
.4424 .49155 m .44238 .49158 L p
.4423 .49175 L 1 g
F P
s
P
p
.002 w
.44238 .49158 m .44231 .49165 L p
.44191 .49253 L 1 g
F P
s
P
p
.002 w
.44152 .49333 m .44116 .49209 L .44214 .49206 L p
1 g
F P
s
P
p
.002 w
.44116 .49209 m .44152 .49333 L p
.44019 .4962 L 1 g
F P
s
P
p
.43485 .50826 m .44231 .49165 L .43809 .50069 L 1 g
F
P
p
.002 w
.43418 .50905 m .43485 .50826 L p
.43809 .50069 L 1 g
F P
s
P
p
.43461 .50404 m .44116 .49209 L .43254 .52828 L 1 g
F
P
p
.002 w
.44231 .49165 m .44166 .49233 L p
.43809 .50069 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.44116 .49209 m .44327 .45832 L .46936 .46535 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44321 .49077 m .45777 .47662 L .47863 .46785 L 1 g
F
P
p
.002 w
.47717 .46746 m .47863 .46785 L p
.45777 .47662 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45777 .47662 L p
1 g
F P
s
P
p
.002 w
.45777 .47662 m .45826 .47608 L p
.46737 .47208 L 1 g
F P
s
P
p
.46737 .47208 m .47718 .46778 L .45777 .47662 L 1 g
F
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5194 .46515 m .52734 .45592 L .53859 .46933 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56627 .5096 L p
1 g
F P
s
P
p
.55661 .4905 m .56627 .5096 L .56218 .50115 L 1 g
F
P
p
.002 w
.57284 .50627 m .56705 .5112 L p
.56627 .5096 L 1 g
F P
s
P
p
.56504 .49873 m .56627 .5096 L .55744 .49138 L 1 g
F
P
p
.57284 .50627 m .56627 .5096 L .56504 .49873 L 1 g
F
P
p
.002 w
.57542 .50407 m .59777 .52228 L p
.56652 .51192 L 1 g
F P
s
P
p
.56515 .50826 m .56696 .51998 L .56651 .51167 L 1 g
F
P
p
.56696 .51998 m .56655 .51232 L .56651 .51167 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56655 .51232 m .58001 .53742 L p
.56731 .52663 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56742 .52862 L p
1 g
F P
s
P
p
.002 w
.58001 .53742 m .56815 .54245 L p
.56742 .52862 L 1 g
F P
s
P
p
.56786 .52709 m .56742 .52862 L .56731 .52663 L 1 g
F
P
p
.58001 .53742 m .56742 .52862 L .56786 .52709 L 1 g
F
P
p
.002 w
.56742 .52862 m .56654 .52734 L p
.56439 .53909 L 1 g
F P
s
P
p
.56515 .50826 m .56742 .52862 L .56696 .51998 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56172 .54749 L p
1 g
F P
s
P
p
.002 w
.58001 .53742 m .59093 .55906 L p
.56167 .54761 L 1 g
F P
s
P
p
.56167 .54761 m .56172 .54749 L .58001 .53742 L 1 g
F
P
p
.002 w
.56277 .54473 m .56427 .54409 L p
.56172 .54749 L 1 g
F P
s
P
p
.002 w
.56427 .54409 m .58001 .53742 L p
.56172 .54749 L 1 g
F P
s
P
p
.002 w
.56172 .54749 m .56075 .54566 L p
.55539 .55538 L 1 g
F P
s
P
p
.002 w
.55897 .55114 m .5602 .57215 L p
.54983 .56196 L 1 g
F P
s
P
p
.55539 .55538 m .55428 .55739 L .55897 .55114 L 1 g
F
P
p
.55539 .55538 m .55897 .55114 L .56172 .54749 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.53603 .54839 m .5587 .54645 L .55897 .55114 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54983 .56196 m .53603 .54839 L .55897 .55114 L 1 g
F
P
p
.56654 .52734 m .56172 .54749 L .5623 .54595 L 1 g
F
P
p
.56654 .52734 m .5623 .54595 L .56439 .53909 L 1 g
F
P
p
.59093 .55906 m .55915 .55423 L .56167 .54761 L 1 g
F
P
p
.5623 .54595 m .56188 .5478 L .56277 .54473 L 1 g
F
P
p
.5623 .54595 m .56277 .54473 L .56439 .53909 L 1 g
F
P
p
.002 w
.59093 .55906 m .5602 .57215 L .55915 .55423 L p
1 g
F P
s
P
p
.002 w
.55915 .55423 m .5587 .54645 L p
.56167 .54761 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5587 .54645 m .56277 .54473 L p
.56167 .54761 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56172 .54749 L p
1 g
F P
s
P
p
.55428 .55739 m .54998 .56518 L .56172 .54749 L 1 g
F
P
p
.002 w
.56172 .54749 m .56188 .5478 L p
.5623 .54595 L 1 g
F P
s
P
p
.56742 .52862 m .5587 .54645 L .56731 .52663 L 1 g
F
P
p
.002 w
.56815 .54245 m .56277 .54473 L p
.56742 .52862 L 1 g
F P
s
P
p
.002 w
.56277 .54473 m .5587 .54645 L p
.56742 .52862 L 1 g
F P
s
P
p
.002 w
.56188 .5478 m .56257 .5491 L p
.56439 .53909 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56742 .52862 L p
1 g
F P
s
P
p
.56439 .53909 m .56257 .5491 L .56742 .52862 L 1 g
F
P
p
.002 w
.56742 .52862 m .56854 .53025 L p
.56696 .51998 L 1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5587 .54645 m .55535 .51645 L p
.56731 .52663 L 1 g
F P
s
P
p
.002 w
.55535 .51645 m .5663 .51185 L .56655 .51232 L p
1 g
F P
s
P
p
.56731 .52663 m .55535 .51645 L .56655 .51232 L 1 g
F
P
p
.56696 .51998 m .5671 .52092 L .56655 .51232 L 1 g
F
P
p
.002 w
.56705 .5112 m .56651 .51167 L p
.56627 .5096 L 1 g
F P
s
P
p
.002 w
.56638 .50973 m .56627 .5096 L p
.56651 .51167 L 1 g
F P
s
P
p
.002 w
.56627 .5096 m .56515 .50826 L p
.56651 .51167 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55744 .49138 L p
1 g
F P
s
P
p
.002 w
.55744 .49138 m .55661 .4905 L p
.56218 .50115 L 1 g
F P
s
P
p
.56218 .50115 m .56713 .51061 L .55744 .49138 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55744 .49138 L p
1 g
F P
s
P
p
.54174 .47608 m .55744 .49138 L .55174 .48588 L 1 g
F
P
p
.56627 .5096 m .5663 .51185 L .55563 .48765 L 1 g
F
P
p
.002 w
.56651 .51167 m .5663 .51185 L p
.56627 .5096 L 1 g
F P
s
P
p
.002 w
.5663 .51185 m .56651 .51167 L p
.56652 .51192 L 1 g
F P
s
P
p
.002 w
.56651 .51167 m .57542 .50407 L p
.56652 .51192 L 1 g
F P
s
P
p
.002 w
.59777 .52228 m .58001 .53742 L .5663 .51185 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56638 .50973 L p
1 g
F P
s
P
p
.5671 .52092 m .56854 .53025 L .56638 .50973 L 1 g
F
P
p
.002 w
.56713 .51061 m .5684 .52836 L p
.57056 .53318 L 1 g
F P
s
P
p
.002 w
.5684 .52836 m .56854 .53025 L .56863 .53039 L p
1 g
F P
s
P
p
.002 w
.56863 .53039 m .57056 .53318 L p
.5684 .52836 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.5502 .48315 m .55563 .48765 L p
.55715 .49111 L 1 g
F P
s
P
p
.002 w
.5663 .51185 m .55172 .48585 L p
.55715 .49111 L 1 g
F P
s
P
p
.002 w
.55172 .48585 m .5502 .48315 L p
.55715 .49111 L 1 g
F P
s
P
p
.54174 .47608 m .55174 .48588 L .55172 .48585 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55535 .51645 m .54373 .51739 L .55 .48419 L p
1 g
F P
s
P
p
.54174 .47608 m .55172 .48585 L .55018 .48436 L 1 g
F
P
p
.002 w
.53268 .51455 m .52339 .5082 L .54955 .48375 L p
1 g
F P
s
P
p
.002 w
.54955 .48375 m .5502 .48315 L .54975 .48395 L p
1 g
F P
s
P
p
.002 w
.54975 .48395 m .53268 .51455 L p
.54955 .48375 L 1 g
F P
s
P
p
.002 w
.52339 .5082 m .51688 .499 L .54934 .48355 L p
1 g
F P
s
P
p
.002 w
.54934 .48355 m .5502 .48315 L .54955 .48375 L p
1 g
F P
s
P
p
.002 w
.54955 .48375 m .52339 .5082 L p
.54934 .48355 L 1 g
F P
s
P
p
.54946 .48366 m .54965 .48385 L .54953 .48373 L 1 g
F
P
p
.54965 .48385 m .54975 .48395 L .54972 .48392 L 1 g
F
P
p
.54965 .48385 m .54972 .48392 L .54953 .48373 L 1 g
F
P
p
.002 w
.55 .48419 m .54373 .51739 L p
.54975 .48395 L 1 g
F P
s
P
p
.54975 .48395 m .55018 .48436 L .55001 .4842 L 1 g
F
P
p
.54975 .48395 m .55001 .4842 L .54953 .48373 L 1 g
F
P
p
.54174 .47608 m .55018 .48436 L .54946 .48366 L 1 g
F
P
p
.002 w
.54373 .51739 m .53268 .51455 L .54975 .48395 L p
1 g
F P
s
P
p
.002 w
.54975 .48395 m .5502 .48315 L .55 .48419 L p
1 g
F P
s
P
p
.002 w
.55 .48419 m .5502 .48315 L .55043 .4846 L p
1 g
F P
s
P
p
.002 w
.55043 .4846 m .55535 .51645 L p
.55 .48419 L 1 g
F P
s
P
p
.54953 .48373 m .55043 .4846 L .54957 .48377 L 1 g
F
P
p
.002 w
.55172 .48585 m .5663 .51185 L p
.55043 .4846 L 1 g
F P
s
P
p
.55043 .4846 m .55172 .48585 L .55084 .485 L 1 g
F
P
p
.55043 .4846 m .55084 .485 L .54957 .48377 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.5663 .51185 m .55535 .51645 L .55043 .4846 L p
1 g
F P
s
P
p
.002 w
.55043 .4846 m .5502 .48315 L .55172 .48585 L p
1 g
F P
s
P
p
.002 w
.51688 .499 m .51388 .48795 L .54908 .4833 L p
1 g
F P
s
P
p
.002 w
.54908 .4833 m .5502 .48315 L .54934 .48355 L p
1 g
F P
s
P
p
.002 w
.54934 .48355 m .51688 .499 L p
.54908 .4833 L 1 g
F P
s
P
p
.002 w
.54237 .47676 m .54174 .47608 L p
.54943 .48364 L 1 g
F P
s
P
p
.54943 .48364 m .54946 .48366 L .54924 .48346 L 1 g
F
P
p
.54943 .48364 m .54924 .48346 L .54237 .47676 L 1 g
F
P
p
.002 w
.54908 .4833 m .51388 .48795 L p
.5486 .48283 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52251 .46728 L p
1 g
F P
s
P
p
.51871 .46679 m .52251 .46728 L .547 .48128 L 1 g
F
P
p
.002 w
.52251 .46728 m .52214 .46667 L p
.533 .47229 L 1 g
F P
s
P
p
.002 w
.547 .48128 m .52547 .4687 L p
.54237 .47676 L 1 g
F P
s
P
p
.533 .47229 m .53306 .47232 L .52547 .4687 L 1 g
F
P
p
.533 .47229 m .52547 .4687 L .52251 .46728 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47676 L p
1 g
F P
s
P
p
.002 w
.54237 .47676 m .54302 .47747 L p
.533 .47229 L 1 g
F P
s
P
p
.52214 .46667 m .54237 .47676 L .533 .47229 L 1 g
F
P
p
.53414 .46876 m .53859 .46933 L .54457 .47782 L 1 g
F
P
p
.54946 .48366 m .54812 .48237 L .54237 .47676 L 1 g
F
P
p
.54237 .47676 m .54457 .47782 L .547 .48128 L 1 g
F
P
p
.53414 .46876 m .54457 .47782 L .54237 .47676 L 1 g
F
P
p
.5232 .46737 m .53414 .46876 L .54237 .47676 L 1 g
F
P
p
.002 w
.52547 .4687 m .5232 .46737 L p
.54237 .47676 L 1 g
F P
s
P
p
.002 w
.5232 .46737 m .52547 .4687 L p
.52251 .46728 L 1 g
F P
s
P
p
.002 w
.52547 .4687 m .547 .48128 L p
.52251 .46728 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52251 .46728 L p
1 g
F P
s
P
p
.53306 .47232 m .54302 .47747 L .52251 .46728 L 1 g
F
P
p
.002 w
.52251 .46728 m .52251 .46728 L p
.52248 .46728 L 1 g
F P
s
P
p
.5 .4634 m .52251 .46728 L .52248 .46728 L 1 g
F
P
p
.002 w
.51474 .47623 m .51871 .46679 L p
.547 .48128 L 1 g
F P
s
P
p
.5 .4634 m .52251 .46728 L .5204 .46702 L 1 g
F
P
p
.5 .4634 m .52258 .4674 L .51285 .46587 L 1 g
F
P
p
.002 w
.51871 .46679 m .5194 .46515 L .5232 .46737 L p
1 g
F P
s
P
p
.002 w
.547 .48128 m .5502 .48315 L .5486 .48283 L p
1 g
F P
s
P
p
.002 w
.5486 .48283 m .51474 .47623 L p
.547 .48128 L 1 g
F P
s
P
p
.5486 .48283 m .54957 .48377 L .54812 .48237 L 1 g
F
P
p
.54946 .48366 m .5495 .48371 L .5486 .48283 L 1 g
F
P
p
.5495 .48371 m .54957 .48377 L .5486 .48283 L 1 g
F
P
p
.002 w
.51388 .48795 m .51474 .47623 L .5486 .48283 L p
1 g
F P
s
P
p
.002 w
.5486 .48283 m .5502 .48315 L .54908 .4833 L p
1 g
F P
s
P
p
.002 w
.53859 .46933 m .5502 .48315 L .547 .48128 L p
1 g
F P
s
P
p
.002 w
.54275 .47718 m .54237 .47676 L p
.54957 .48377 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54275 .47718 L p
1 g
F P
s
P
p
.55174 .48588 m .55834 .49233 L .54275 .47718 L 1 g
F
P
p
.002 w
.55744 .49138 m .55834 .49233 L p
.55174 .48588 L 1 g
F P
s
P
p
.002 w
.55563 .48765 m .57542 .50407 L .57284 .50627 L p
1 g
F P
s
P
p
.57284 .50627 m .55744 .49138 L .55563 .48765 L 1 g
F
P
p
.002 w
.56627 .5096 m .56713 .51061 L p
.56218 .50115 L 1 g
F P
s
P
p
.002 w
.5232 .46737 m .5194 .46515 L p
.53859 .46933 L 1 g
F P
s
P
p
.002 w
.52251 .46728 m .52258 .4674 L p
.5204 .46702 L 1 g
F P
s
P
p
.002 w
.51474 .47623 m .47863 .46785 L p
.51156 .46567 L 1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .4634 L p
.51285 .46587 L 1 g
F P
s
P
p
.002 w
.5194 .46515 m .51871 .46679 L p
.51156 .46567 L 1 g
F P
s
P
p
.002 w
.51871 .46679 m .51474 .47623 L p
.51156 .46567 L 1 g
F P
s
P
p
.002 w
.47863 .46785 m .47893 .46713 L p
.5109 .46556 L 1 g
F P
s
P
p
.47863 .46785 m .5109 .46556 L .51156 .46567 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.51374 .46171 m .5194 .46515 L p
.47893 .46713 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46385 L p
1 g
F P
s
P
p
.51285 .46587 m .52282 .46778 L .5 .46385 L 1 g
F
P
p
.002 w
.52258 .4674 m .52282 .46778 L p
.51285 .46587 L 1 g
F P
s
P
p
.51156 .46567 m .5109 .46556 L .5194 .46515 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46385 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46385 L .48982 .46543 L 1 g
F
P
p
.47786 .46667 m .5 .46438 L .49856 .46456 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.47863 .46785 m .47717 .46746 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.47893 .46713 m .47863 .46785 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47786 .46667 L p
.49856 .46456 L 1 g
F P
s
P
p
.49856 .46456 m .5 .46442 L .47747 .46732 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47747 .46732 L p
1 g
F P
s
P
p
.44327 .45832 m .4792 .46648 L .47747 .46732 L 1 g
F
P
p
.002 w
.47717 .46746 m .47691 .46739 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.47691 .46739 m .44327 .45832 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.47893 .46713 m .48775 .44592 L .51374 .46171 L p
1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .46438 L p
.48982 .46543 L 1 g
F P
s
P
p
.002 w
.5 .46438 m .5 .46442 L p
.49856 .46456 L 1 g
F P
s
P
p
.002 w
.4792 .46648 m .47893 .46713 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.48775 .44592 m .4792 .46648 L p
.44327 .45832 L 1 g
F P
s
P
p
.002 w
.47747 .46732 m .47747 .46732 L p
.47733 .46738 L 1 g
F P
s
P
p
.45826 .47608 m .47747 .46732 L .47733 .46738 L 1 g
F
P
p
.002 w
.47747 .46732 m .47718 .46778 L p
.46737 .47208 L 1 g
F P
s
P
p
.45826 .47608 m .47747 .46732 L .46737 .47208 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45777 .47662 L p
1 g
F P
s
P
p
.44339 .4905 m .45777 .47662 L .44992 .48424 L 1 g
F
P
p
.44116 .49209 m .4572 .47689 L .44321 .49077 L 1 g
F
P
p
.4572 .47689 m .46936 .46535 L .45777 .47662 L 1 g
F
P
p
.4572 .47689 m .45777 .47662 L .44321 .49077 L 1 g
F
P
p
.002 w
.46936 .46535 m .47717 .46746 L p
.45777 .47662 L 1 g
F P
s
P
p
.002 w
.45777 .47662 m .45698 .47747 L p
.44992 .48424 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4424 .49155 L p
1 g
F P
s
P
p
.44992 .48424 m .45698 .47747 L .4424 .49155 L 1 g
F
P
p
.44116 .49209 m .4426 .49116 L .4424 .49155 L 1 g
F
P
p
.002 w
.44187 .49207 m .44116 .49209 L p
.4424 .49155 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45024 .5237 m .44152 .49333 L p
.47705 .49097 L 1 g
F P
s
P
p
.002 w
.44214 .49206 m .47705 .49097 L p
.44152 .49333 L 1 g
F P
s
P
p
.002 w
.45024 .5237 m .43254 .52828 L p
.44019 .4962 L 1 g
F P
s
P
p
.002 w
.44152 .49333 m .45024 .5237 L p
.44019 .4962 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43418 .50905 L p
1 g
F P
s
P
p
.43809 .50069 m .44166 .49233 L .43418 .50905 L 1 g
F
P
p
.43322 .52035 m .43294 .51241 L .43254 .52828 L 1 g
F
P
p
.43925 .54566 m .43253 .52869 L .43625 .53973 L 1 g
F
P
p
.002 w
.4324 .52831 m .45024 .5237 L p
.43864 .54681 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43253 .52869 L p
1 g
F P
s
P
p
.43294 .51241 m .43287 .51061 L .43253 .52869 L 1 g
F
P
p
.002 w
.43253 .52869 m .43146 .53025 L p
.43625 .53973 L 1 g
F P
s
P
p
.44532 .55607 m .43864 .54681 L .45024 .5237 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43864 .54681 L p
1 g
F P
s
P
p
.43625 .53973 m .43146 .53025 L .43864 .54681 L 1 g
F
P
p
.46872 .57265 m .45077 .56315 L .46133 .5697 L 1 g
F
P
p
.46733 .57342 m .45077 .56315 L .46928 .54969 L 1 g
F
P
p
.002 w
.44875 .5619 m .44929 .56157 L p
.45077 .56315 L 1 g
F P
s
P
p
.002 w
.44929 .56157 m .46928 .54969 L p
.45077 .56315 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45065 .56346 L p
1 g
F P
s
P
p
.002 w
.45065 .56346 m .45077 .56315 L p
.44937 .56168 L 1 g
F P
s
P
p
.44937 .56168 m .43743 .5491 L .45065 .56346 L 1 g
F
P
p
.4451 .55577 m .43856 .55008 L .44929 .56157 L 1 g
F
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45024 .5237 m .46928 .54969 L .44929 .56157 L p
1 g
F P
s
P
p
.44532 .55607 m .45024 .5237 L .44929 .56157 L 1 g
F
P
p
.43856 .55008 m .43743 .5491 L .45077 .56315 L 1 g
F
P
p
.002 w
.45077 .56315 m .45002 .56518 L p
.46133 .5697 L 1 g
F P
s
P
p
.47571 .57654 m .46733 .57342 L .46928 .54969 L 1 g
F
P
p
.002 w
.44765 .5671 m .44401 .56472 L p
.47571 .57654 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46841 .57409 L p
1 g
F P
s
P
p
.46133 .5697 m .45002 .56518 L .46841 .57409 L 1 g
F
P
p
.51827 .59668 m .48494 .57965 L .50875 .58415 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58103 L p
1 g
F P
s
P
p
.002 w
.48903 .58103 m .48907 .58043 L p
.48546 .57982 L 1 g
F P
s
P
p
.48546 .57982 m .4678 .57686 L .48903 .58103 L 1 g
F
P
p
.47952 .57782 m .47204 .57721 L .48494 .57965 L 1 g
F
P
p
.47952 .57782 m .48494 .57965 L .48907 .58043 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46928 .54969 m .496 .56739 L .48494 .57965 L p
1 g
F P
s
P
p
.47571 .57654 m .46928 .54969 L .48494 .57965 L 1 g
F
P
p
.002 w
.48494 .57965 m .496 .56739 L p
.50875 .58415 L 1 g
F P
s
P
p
.47204 .57721 m .4678 .57686 L .48907 .58043 L 1 g
F
P
p
.002 w
.48907 .58043 m .48889 .583 L p
.50271 .58024 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58012 L p
1 g
F P
s
P
p
.50271 .58024 m .48889 .583 L .5109 .58012 L 1 g
F
P
p
.52103 .57791 m .51663 .58017 L .52676 .57666 L 1 g
F
P
p
.002 w
.496 .56739 m .52743 .57508 L .52676 .57666 L p
1 g
F P
s
P
p
.002 w
.53267 .57461 m .5602 .57215 L p
.52894 .5759 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.52743 .57508 m .53603 .54839 L p
.55004 .56216 L 1 g
F P
s
P
p
.002 w
.53224 .57465 m .52743 .57508 L p
.55004 .56216 L 1 g
F P
s
P
p
.002 w
.54911 .56281 m .54998 .56518 L p
.55539 .55538 L 1 g
F P
s
P
p
.5409 .56857 m .53224 .57465 L .53814 .57121 L 1 g
F
P
p
.002 w
.52743 .57508 m .53267 .57461 L p
.52894 .5759 L 1 g
F P
s
P
p
.002 w
.53178 .57492 m .5322 .57686 L p
.53814 .57121 L 1 g
F P
s
P
p
.002 w
.55987 .59284 m .51827 .59668 L .52743 .57508 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53178 .57492 L p
1 g
F P
s
P
p
.51663 .58017 m .51111 .583 L .53178 .57492 L 1 g
F
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37749 .48868 m .39183 .5364 L .36823 .53786 L p
1 g
F P
s
P
p
.002 w
.36823 .53786 m .35189 .48439 L .37749 .48868 L p
1 g
F P
s
P
p
.002 w
.63441 .50883 m .64269 .47678 L .66454 .47191 L p
1 g
F P
s
P
p
.002 w
.66181 .43062 m .66454 .47191 L .64269 .47678 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.58104 .28993 m .52448 .28287 L .51694 .26189 L p
1 g
F P
s
P
p
.002 w
.45515 .27512 m .51694 .26189 L .52448 .28287 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.66181 .43062 m .64572 .39299 L .65897 .37286 L p
1 g
F P
s
P
p
.002 w
.62597 .33736 m .65897 .37286 L .64572 .39299 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.37675 .37184 m .35467 .42681 L .33425 .41665 L p
1 g
F P
s
P
p
.002 w
.33425 .41665 m .35789 .35744 L .37675 .37184 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.41945 .53167 m .44401 .56472 L .4211 .57533 L p
1 g
F P
s
P
p
.002 w
.4211 .57533 m .39183 .5364 L .41945 .53167 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52587 .45763 L
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.62597 .33736 m .58193 .3151 L .58104 .28993 L p
1 g
F P
s
P
p
.002 w
.52448 .28287 m .58104 .28993 L .58193 .3151 L p
1 g
F P
s
P
p
.002 w
.64269 .47678 m .64042 .44432 L .66181 .43062 L p
1 g
F P
s
P
p
.002 w
.64572 .39299 m .66181 .43062 L .64042 .44432 L p
1 g
F P
s
P
p
.002 w
.52448 .28287 m .46711 .29531 L .45515 .27512 L p
1 g
F P
s
P
p
.002 w
.39987 .30825 m .45515 .27512 L .46711 .29531 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.41578 .32616 m .37675 .37184 L .35789 .35744 L p
1 g
F P
s
P
p
.002 w
.35789 .35744 m .39987 .30825 L .41578 .32616 L p
1 g
F P
s
P
p
.004 w
.34563 .32591 m
.36902 .34176 L
s
P
p
.002 w
.46711 .29531 m .41578 .32616 L .39987 .30825 L p
1 g
F P
s
P
p
.002 w
.58001 .53742 m .59777 .52228 L .61653 .53721 L p
1 g
F P
s
P
p
.002 w
.61653 .53721 m .59093 .55906 L .58001 .53742 L p
1 g
F P
s
P
p
.002 w
.63441 .50883 m .61653 .53721 L .59777 .52228 L p
1 g
F P
s
P
p
.002 w
.38018 .43739 m .37749 .48868 L .35189 .48439 L p
1 g
F P
s
P
p
.002 w
.35189 .48439 m .35467 .42681 L .38018 .43739 L p
1 g
F P
s
P
p
.002 w
.64572 .39299 m .61765 .36312 L .62597 .33736 L p
1 g
F P
s
P
p
.002 w
.58193 .3151 m .62597 .33736 L .61765 .36312 L p
1 g
F P
s
P
p
.002 w
.59777 .52228 m .61013 .50259 L .63441 .50883 L p
1 g
F P
s
P
p
.002 w
.64269 .47678 m .63441 .50883 L .61013 .50259 L p
1 g
F P
s
P
p
.002 w
.40758 .4913 m .41945 .53167 L .39183 .5364 L p
1 g
F P
s
P
p
.002 w
.39183 .5364 m .37749 .48868 L .40758 .4913 L p
1 g
F P
s
P
p
.002 w
.64042 .44432 m .62763 .41486 L .64572 .39299 L p
1 g
F P
s
P
p
.002 w
.61765 .36312 m .64572 .39299 L .62763 .41486 L p
1 g
F P
s
P
p
.002 w
.61013 .50259 m .61579 .4804 L .64269 .47678 L p
1 g
F P
s
P
p
.002 w
.64042 .44432 m .64269 .47678 L .61579 .4804 L p
1 g
F P
s
P
p
.002 w
.58193 .3151 m .53152 .30903 L .52448 .28287 L p
1 g
F P
s
P
p
.002 w
.46711 .29531 m .52448 .28287 L .53152 .30903 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51438 .54296 m .53603 .54839 L .52743 .57508 L p
1 g
F P
s
P
p
.002 w
.52743 .57508 m .496 .56739 L .51438 .54296 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39997 .38849 m .38018 .43739 L .35467 .42681 L p
1 g
F P
s
P
p
.002 w
.35467 .42681 m .37675 .37184 L .39997 .38849 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.61765 .36312 m .58034 .34454 L .58193 .3151 L p
1 g
F P
s
P
p
.002 w
.53152 .30903 m .58193 .3151 L .58034 .34454 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.61579 .4804 m .61411 .45799 L .64042 .44432 L p
1 g
F P
s
P
p
.002 w
.62763 .41486 m .64042 .44432 L .61411 .45799 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.53152 .30903 m .48044 .32028 L .46711 .29531 L p
1 g
F P
s
P
p
.002 w
.41578 .32616 m .46711 .29531 L .48044 .32028 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49606 .53065 m .51438 .54296 L .496 .56739 L p
1 g
F P
s
P
p
.002 w
.496 .56739 m .46928 .54969 L .49606 .53065 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43476 .34782 m .39997 .38849 L .37675 .37184 L p
1 g
F P
s
P
p
.004 w
.41392 .37218 m
.5 .43051 L
s
P
p
.002 w
.37675 .37184 m .41578 .32616 L .43476 .34782 L p
1 g
F P
s
P
p
.004 w
.38307 .35127 m
.39136 .35689 L
s
P
p
.004 w
.39136 .35689 m
.39556 .35974 L
s
P
p
.004 w
.36902 .34176 m
.38307 .35127 L
s
P
p
.004 w
.39556 .35974 m
.3964 .36031 L
s
P
p
.002 w
.41005 .44803 m .40758 .4913 L .37749 .48868 L p
1 g
F P
s
P
p
.002 w
.37749 .48868 m .38018 .43739 L .41005 .44803 L p
1 g
F P
s
P
p
.002 w
.62763 .41486 m .60549 .39162 L .61765 .36312 L p
1 g
F P
s
P
p
.002 w
.58034 .34454 m .61765 .36312 L .60549 .39162 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.48044 .32028 m .43476 .34782 L .41578 .32616 L p
1 g
F P
s
P
p
.002 w
.61013 .50259 m .59777 .52228 L .57542 .50407 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57542 .50407 m .58175 .49395 L .61013 .50259 L p
1 g
F P
s
P
p
.002 w
.61579 .4804 m .61013 .50259 L .58175 .49395 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.54373 .51739 m .55535 .51645 L .5587 .54645 L p
1 g
F P
s
P
p
.002 w
.5587 .54645 m .53603 .54839 L .54373 .51739 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41945 .53167 m .40758 .4913 L .44116 .49209 L p
1 g
F P
s
P
p
.002 w
.61411 .45799 m .60517 .43775 L .62763 .41486 L p
1 g
F P
s
P
p
.002 w
.60549 .39162 m .62763 .41486 L .60517 .43775 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58175 .49395 m .58461 .48256 L .61579 .4804 L p
1 g
F P
s
P
p
.002 w
.61411 .45799 m .61579 .4804 L .58461 .48256 L p
1 g
F P
s
P
p
.002 w
.58034 .34454 m .53776 .33963 L .53152 .30903 L p
1 g
F P
s
P
p
.002 w
.48044 .32028 m .53152 .30903 L .53776 .33963 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53268 .51455 m .54373 .51739 L .53603 .54839 L p
1 g
F P
s
P
p
.002 w
.53603 .54839 m .51438 .54296 L .53268 .51455 L p
1 g
F P
s
P
p
.002 w
.48312 .51269 m .49606 .53065 L .46928 .54969 L p
1 g
F P
s
P
p
.002 w
.46928 .54969 m .45024 .5237 L .48312 .51269 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42687 .40683 m .41005 .44803 L .38018 .43739 L p
1 g
F P
s
P
p
.002 w
.38018 .43739 m .39997 .38849 L .42687 .40683 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.60549 .39162 m .57622 .37729 L .58034 .34454 L p
1 g
F P
s
P
p
.002 w
.53776 .33963 m .58034 .34454 L .57622 .37729 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58461 .48256 m .58369 .4711 L .61411 .45799 L p
1 g
F P
s
P
p
.002 w
.60517 .43775 m .61411 .45799 L .58369 .4711 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52339 .5082 m .53268 .51455 L .51438 .54296 L p
1 g
F P
s
P
p
.002 w
.51438 .54296 m .49606 .53065 L .52339 .5082 L p
1 g
F P
s
P
p
.002 w
.60517 .43775 m .58982 .42188 L .60549 .39162 L p
1 g
F P
s
P
p
.002 w
.57622 .37729 m .60549 .39162 L .58982 .42188 L p
1 g
F P
s
P
p
.002 w
.53776 .33963 m .49471 .34928 L .48044 .32028 L p
1 g
F P
s
P
p
.002 w
.43476 .34782 m .48044 .32028 L .49471 .34928 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.44327 .45832 m .44116 .49209 L .40758 .4913 L p
1 g
F P
s
P
p
.002 w
.40758 .4913 m .41005 .44803 L .44327 .45832 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45623 .37256 m .42687 .40683 L .39997 .38849 L p
1 g
F P
s
P
p
.002 w
.39997 .38849 m .43476 .34782 L .45623 .37256 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.47705 .49097 m .48312 .51269 L .45024 .5237 L p
1 g
F P
s
P
p
.002 w
.58369 .4711 m .57904 .4608 L .60517 .43775 L p
1 g
F P
s
P
p
.002 w
.58982 .42188 m .60517 .43775 L .57904 .4608 L p
1 g
F P
s
P
p
.002 w
.58175 .49395 m .57542 .50407 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.49471 .34928 m .45623 .37256 L .43476 .34782 L p
1 g
F P
s
P
p
.002 w
.58461 .48256 m .58175 .49395 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.51688 .499 m .52339 .5082 L .49606 .53065 L p
1 g
F P
s
P
p
.002 w
.49606 .53065 m .48312 .51269 L .51688 .499 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58369 .4711 m .58461 .48256 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.57622 .37729 m .54294 .37365 L .53776 .33963 L p
1 g
F P
s
P
p
.002 w
.49471 .34928 m .53776 .33963 L .54294 .37365 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57904 .4608 m .58369 .4711 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.58982 .42188 m .56966 .4122 L .57622 .37729 L p
1 g
F P
s
P
p
.002 w
.54294 .37365 m .57622 .37729 L .56966 .4122 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45649 .42623 m .44327 .45832 L .41005 .44803 L p
1 g
F P
s
P
p
.002 w
.41005 .44803 m .42687 .40683 L .45649 .42623 L p
1 g
F P
s
P
p
.002 w
.57904 .4608 m .57116 .45279 L .58982 .42188 L p
1 g
F P
s
P
p
.002 w
.56966 .4122 m .58982 .42188 L .57116 .45279 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57116 .45279 m .57904 .4608 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.51388 .48795 m .51688 .499 L .48312 .51269 L p
1 g
F P
s
P
p
.002 w
.48312 .51269 m .47705 .49097 L .51388 .48795 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54294 .37365 m .50939 .38132 L .49471 .34928 L p
1 g
F P
s
P
p
.002 w
.45623 .37256 m .49471 .34928 L .50939 .38132 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.47941 .39953 m .45649 .42623 L .42687 .40683 L p
1 g
F P
s
P
p
.002 w
.42687 .40683 m .45623 .37256 L .47941 .39953 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56088 .44795 m .57116 .45279 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.57116 .45279 m .56088 .44795 L .56966 .4122 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5493 .44683 m .56088 .44795 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.53769 .44959 m .5493 .44683 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.52734 .45592 m .53769 .44959 L .5502 .48315 L closepath p
1 g
F P
s
P
p
.002 w
.50939 .38132 m .47941 .39953 L .45623 .37256 L p
1 g
F P
s
P
p
.002 w
.54685 .40985 m .56966 .4122 L .56088 .44795 L p
1 g
F P
s
P
p
.002 w
.56966 .4122 m .54685 .40985 L .54294 .37365 L p
1 g
F P
s
P
p
.002 w
.50939 .38132 m .54294 .37365 L .54685 .40985 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.51474 .47623 m .51388 .48795 L .47705 .49097 L p
1 g
F P
s
P
p
.002 w
.47705 .49097 m .47863 .46785 L .51474 .47623 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.56088 .44795 m .5493 .44683 L .54685 .40985 L p
1 g
F P
s
P
p
.002 w
.44327 .45832 m .45649 .42623 L .48775 .44592 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.004 w
.5502 .48315 m
.55182 .48484 L
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5493 .44683 m .53769 .44959 L .5239 .41519 L p
1 g
F P
s
P
p
.002 w
.5239 .41519 m .54685 .40985 L .5493 .44683 L p
1 g
F P
s
P
p
.002 w
.54685 .40985 m .5239 .41519 L .50939 .38132 L p
1 g
F P
s
P
p
.002 w
.47941 .39953 m .50939 .38132 L .5239 .41519 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50343 .42768 m .48775 .44592 L .45649 .42623 L p
1 g
F P
s
P
p
.002 w
.45649 .42623 m .47941 .39953 L .50343 .42768 L p
1 g
F P
s
P
p
.002 w
.53769 .44959 m .52734 .45592 L .50343 .42768 L p
1 g
F P
s
P
p
.002 w
.50343 .42768 m .5239 .41519 L .53769 .44959 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.52734 .45592 m .5194 .46515 L .48775 .44592 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.48775 .44592 m .50343 .42768 L .52734 .45592 L p
1 g
F P
s
P
p
.002 w
.5239 .41519 m .50343 .42768 L .47941 .39953 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.55182 .48484 m
.58106 .5155 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .33262 .31709 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58106 .5155 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0589474)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0589474)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50978 .46986 m .53622 .44682 L .51473 .42825 L p
1 g
F P
s
P
p
.002 w
.51473 .42825 m .4943 .44605 L .50978 .46986 L p
1 g
F P
s
P
p
.002 w
.52893 .40534 m .51473 .42825 L .53622 .44682 L p
1 g
F P
s
P
p
.002 w
.4943 .44605 m .51473 .42825 L .49294 .40977 L p
1 g
F P
s
P
p
.002 w
.51473 .42825 m .52893 .40534 L .50258 .39412 L p
1 g
F P
s
P
p
.002 w
.50258 .39412 m .49294 .40977 L .51473 .42825 L p
1 g
F P
s
P
p
.002 w
.47795 .48406 m .50978 .46986 L .4943 .44605 L p
1 g
F P
s
P
p
.002 w
.4943 .44605 m .46968 .45696 L .47795 .48406 L p
1 g
F P
s
P
p
.002 w
.46968 .45696 m .4943 .44605 L .47899 .42192 L p
1 g
F P
s
P
p
.002 w
.49294 .40977 m .47899 .42192 L .4943 .44605 L p
1 g
F P
s
P
p
.002 w
.47899 .42192 m .49294 .40977 L .47122 .39172 L p
1 g
F P
s
P
p
.002 w
.49294 .40977 m .50258 .39412 L .47611 .38375 L p
1 g
F P
s
P
p
.002 w
.47611 .38375 m .47122 .39172 L .49294 .40977 L p
1 g
F P
s
P
p
.002 w
.47899 .42192 m .46217 .42932 L .46968 .45696 L p
1 g
F P
s
P
p
.002 w
.46217 .42932 m .47899 .42192 L .46412 .39791 L p
1 g
F P
s
P
p
.002 w
.47122 .39172 m .46412 .39791 L .47899 .42192 L p
1 g
F P
s
P
p
.002 w
.5069 .37657 m .50258 .39412 L .52893 .40534 L p
1 g
F P
s
P
p
.002 w
.50258 .39412 m .5069 .37657 L .47825 .37483 L p
1 g
F P
s
P
p
.002 w
.47825 .37483 m .47611 .38375 L .50258 .39412 L p
1 g
F P
s
P
p
.002 w
.44336 .4598 m .46968 .45696 L .46217 .42932 L p
1 g
F P
s
P
p
.002 w
.46217 .42932 m .44422 .43116 L .44336 .4598 L p
1 g
F P
s
P
p
.002 w
.44422 .43116 m .46217 .42932 L .45556 .40164 L p
1 g
F P
s
P
p
.002 w
.46412 .39791 m .45556 .40164 L .46217 .42932 L p
1 g
F P
s
P
p
.002 w
.53622 .44682 m .55467 .41721 L .52893 .40534 L p
1 g
F P
s
P
p
.002 w
.53539 .37962 m .52893 .40534 L .55467 .41721 L p
1 g
F P
s
P
p
.002 w
.52893 .40534 m .53539 .37962 L .5069 .37657 L p
1 g
F P
s
P
p
.002 w
.52516 .49291 m .55701 .46515 L .53622 .44682 L p
1 g
F P
s
P
p
.002 w
.53622 .44682 m .50978 .46986 L .52516 .49291 L p
1 g
F P
s
P
p
.002 w
.55467 .41721 m .53622 .44682 L .55701 .46515 L p
1 g
F P
s
P
p
.002 w
.44387 .48792 m .47795 .48406 L .46968 .45696 L p
1 g
F P
s
P
p
.002 w
.46968 .45696 m .44336 .4598 L .44387 .48792 L p
1 g
F P
s
P
p
.002 w
.48685 .51013 m .52516 .49291 L .50978 .46986 L p
1 g
F P
s
P
p
.002 w
.50978 .46986 m .47795 .48406 L .48685 .51013 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .46412 .39791 L .47122 .39172 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .47122 .39172 L .47611 .38375 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .45556 .40164 L .46412 .39791 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .47611 .38375 L .47825 .37483 L closepath p
1 g
F P
s
P
p
.002 w
.45556 .40164 m .44644 .40253 L .44422 .43116 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .44644 .40253 L .45556 .40164 L closepath p
1 g
F P
s
P
p
.002 w
.50539 .35895 m .5069 .37657 L .53539 .37962 L p
1 g
F P
s
P
p
.002 w
.5069 .37657 m .50539 .35895 L .47742 .3659 L p
1 g
F P
s
P
p
.002 w
.47742 .3659 m .47825 .37483 L .5069 .37657 L p
1 g
F P
s
P
p
.002 w
.41803 .45417 m .44336 .4598 L .44422 .43116 L p
1 g
F P
s
P
p
.002 w
.44422 .43116 m .42702 .4272 L .41803 .45417 L p
1 g
F P
s
P
p
.002 w
.42702 .4272 m .44422 .43116 L .44644 .40253 L p
1 g
F P
s
P
p
.002 w
.55701 .46515 m .57933 .42953 L .55467 .41721 L p
1 g
F P
s
P
p
.002 w
.56321 .38394 m .55467 .41721 L .57933 .42953 L p
1 g
F P
s
P
p
.002 w
.55467 .41721 m .56321 .38394 L .53539 .37962 L p
1 g
F P
s
P
p
.002 w
.44577 .51499 m .48685 .51013 L .47795 .48406 L p
1 g
F P
s
P
p
.002 w
.47795 .48406 m .44387 .48792 L .44577 .51499 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .47825 .37483 L .47742 .3659 L closepath p
1 g
F P
s
P
p
.002 w
.44644 .40253 m .43774 .40046 L .42702 .4272 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .43774 .40046 L .44644 .40253 L closepath p
1 g
F P
s
P
p
.002 w
.53336 .35371 m .53539 .37962 L .56321 .38394 L p
1 g
F P
s
P
p
.002 w
.53539 .37962 m .53336 .35371 L .50539 .35895 L p
1 g
F P
s
P
p
.002 w
.41096 .48084 m .44387 .48792 L .44336 .4598 L p
1 g
F P
s
P
p
.002 w
.44336 .4598 m .41803 .45417 L .41096 .48084 L p
1 g
F P
s
P
p
.002 w
.54014 .51477 m .57671 .48289 L .55701 .46515 L p
1 g
F P
s
P
p
.002 w
.55701 .46515 m .52516 .49291 L .54014 .51477 L p
1 g
F P
s
P
p
.002 w
.57933 .42953 m .55701 .46515 L .57671 .48289 L p
1 g
F P
s
P
p
.002 w
.49621 .53466 m .54014 .51477 L .52516 .49291 L p
1 g
F P
s
P
p
.002 w
.52516 .49291 m .48685 .51013 L .49621 .53466 L p
1 g
F P
s
P
p
.002 w
.47368 .35793 m .47742 .3659 L .50539 .35895 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .47742 .3659 L .47368 .35793 L closepath p
1 g
F P
s
P
p
.002 w
.41239 .41779 m .42702 .4272 L .43774 .40046 L p
1 g
F P
s
P
p
.002 w
.43774 .40046 m .43038 .39563 L .41239 .41779 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .43038 .39563 L .43774 .40046 L closepath p
1 g
F P
s
P
p
.002 w
.49813 .34313 m .50539 .35895 L .53336 .35371 L p
1 g
F P
s
P
p
.002 w
.50539 .35895 m .49813 .34313 L .47368 .35793 L p
1 g
F P
s
P
p
.002 w
.39637 .44049 m .41803 .45417 L .42702 .4272 L p
1 g
F P
s
P
p
.002 w
.42702 .4272 m .41239 .41779 L .39637 .44049 L p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .42683 .36212 L .42328 .37083 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .42328 .37083 L .42271 .37997 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .42271 .37997 L .42517 .38855 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .42517 .38855 L .43038 .39563 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .47368 .35793 L .46741 .35178 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .46741 .35178 L .45928 .34813 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .45928 .34813 L .45016 .34742 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .45016 .34742 L .44106 .34973 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .44106 .34973 L .43298 .35481 L closepath p
1 g
F P
s
P
p
.002 w
.44998 .37443 m .43298 .35481 L .42683 .36212 L closepath p
1 g
F P
s
P
p
.002 w
.46741 .35178 m .47368 .35793 L .49813 .34313 L p
1 g
F P
s
P
p
.002 w
.40196 .40385 m .41239 .41779 L .43038 .39563 L p
1 g
F P
s
P
p
.002 w
.43038 .39563 m .42517 .38855 L .40196 .40385 L p
1 g
F P
s
P
p
.002 w
.57933 .42953 m .58983 .38946 L .56321 .38394 L p
1 g
F P
s
P
p
.002 w
.5608 .35031 m .56321 .38394 L .58983 .38946 L p
1 g
F P
s
P
p
.002 w
.56321 .38394 m .5608 .35031 L .53336 .35371 L p
1 g
F P
s
P
p
.002 w
.57671 .48289 m .60243 .44206 L .57933 .42953 L p
1 g
F P
s
P
p
.002 w
.58983 .38946 m .57933 .42953 L .60243 .44206 L p
1 g
F P
s
P
p
.002 w
.40598 .50672 m .44577 .51499 L .44387 .48792 L p
1 g
F P
s
P
p
.002 w
.44387 .48792 m .41096 .48084 L .40598 .50672 L p
1 g
F P
s
P
p
.002 w
.44905 .54046 m .49621 .53466 L .48685 .51013 L p
1 g
F P
s
P
p
.002 w
.48685 .51013 m .44577 .51499 L .44905 .54046 L p
1 g
F P
s
P
p
.002 w
.52286 .33034 m .53336 .35371 L .5608 .35031 L p
1 g
F P
s
P
p
.002 w
.53336 .35371 m .52286 .33034 L .49813 .34313 L p
1 g
F P
s
P
p
.002 w
.49813 .34313 m .48582 .33084 L .46741 .35178 L p
1 g
F P
s
P
p
.002 w
.45928 .34813 m .46741 .35178 L .48582 .33084 L p
1 g
F P
s
P
p
.002 w
.38268 .4633 m .41096 .48084 L .41803 .45417 L p
1 g
F P
s
P
p
.002 w
.41803 .45417 m .39637 .44049 L .38268 .4633 L p
1 g
F P
s
P
p
.002 w
.39694 .38685 m .40196 .40385 L .42517 .38855 L p
1 g
F P
s
P
p
.002 w
.42517 .38855 m .42271 .37997 L .39694 .38685 L p
1 g
F P
s
P
p
.002 w
.48582 .33084 m .49813 .34313 L .52286 .33034 L p
1 g
F P
s
P
p
.002 w
.38082 .42005 m .39637 .44049 L .41239 .41779 L p
1 g
F P
s
P
p
.002 w
.41239 .41779 m .40196 .40385 L .38082 .42005 L p
1 g
F P
s
P
p
.002 w
.48582 .33084 m .46973 .32349 L .45928 .34813 L p
1 g
F P
s
P
p
.002 w
.45016 .34742 m .45928 .34813 L .46973 .32349 L p
1 g
F P
s
P
p
.002 w
.39797 .36864 m .39694 .38685 L .42271 .37997 L p
1 g
F P
s
P
p
.002 w
.42271 .37997 m .42328 .37083 L .39797 .36864 L p
1 g
F P
s
P
p
.002 w
.55444 .53499 m .5949 .49971 L .57671 .48289 L p
1 g
F P
s
P
p
.002 w
.57671 .48289 m .54014 .51477 L .55444 .53499 L p
1 g
F P
s
P
p
.002 w
.60243 .44206 m .57671 .48289 L .5949 .49971 L p
1 g
F P
s
P
p
.002 w
.50587 .55711 m .55444 .53499 L .54014 .51477 L p
1 g
F P
s
P
p
.002 w
.54014 .51477 m .49621 .53466 L .50587 .55711 L p
1 g
F P
s
P
p
.002 w
.46973 .32349 m .45159 .32196 L .45016 .34742 L p
1 g
F P
s
P
p
.002 w
.44106 .34973 m .45016 .34742 L .45159 .32196 L p
1 g
F P
s
P
p
.002 w
.405 .35124 m .39797 .36864 L .42328 .37083 L p
1 g
F P
s
P
p
.002 w
.42328 .37083 m .42683 .36212 L .405 .35124 L p
1 g
F P
s
P
p
.002 w
.60243 .44206 m .61469 .39609 L .58983 .38946 L p
1 g
F P
s
P
p
.002 w
.58719 .34885 m .58983 .38946 L .61469 .39609 L p
1 g
F P
s
P
p
.002 w
.58983 .38946 m .58719 .34885 L .5608 .35031 L p
1 g
F P
s
P
p
.002 w
.45159 .32196 m .43342 .3265 L .44106 .34973 L p
1 g
F P
s
P
p
.002 w
.43298 .35481 m .44106 .34973 L .43342 .3265 L p
1 g
F P
s
P
p
.002 w
.41727 .33664 m .405 .35124 L .42683 .36212 L p
1 g
F P
s
P
p
.002 w
.42683 .36212 m .43298 .35481 L .41727 .33664 L p
1 g
F P
s
P
p
.002 w
.40327 .53124 m .44905 .54046 L .44577 .51499 L p
1 g
F P
s
P
p
.002 w
.44577 .51499 m .40598 .50672 L .40327 .53124 L p
1 g
F P
s
P
p
.002 w
.54741 .31983 m .5608 .35031 L .58719 .34885 L p
1 g
F P
s
P
p
.002 w
.5608 .35031 m .54741 .31983 L .52286 .33034 L p
1 g
F P
s
P
p
.002 w
.52286 .33034 m .50485 .31206 L .48582 .33084 L p
1 g
F P
s
P
p
.002 w
.46973 .32349 m .48582 .33084 L .50485 .31206 L p
1 g
F P
s
P
p
.002 w
.43342 .3265 m .41727 .33664 L .43298 .35481 L p
1 g
F P
s
P
p
.002 w
.37322 .39497 m .38082 .42005 L .40196 .40385 L p
1 g
F P
s
P
p
.002 w
.40196 .40385 m .39694 .38685 L .37322 .39497 L p
1 g
F P
s
P
p
.002 w
.37165 .48577 m .40598 .50672 L .41096 .48084 L p
1 g
F P
s
P
p
.002 w
.41096 .48084 m .38268 .4633 L .37165 .48577 L p
1 g
F P
s
P
p
.002 w
.50485 .31206 m .52286 .33034 L .54741 .31983 L p
1 g
F P
s
P
p
.002 w
.5949 .49971 m .62347 .45458 L .60243 .44206 L p
1 g
F P
s
P
p
.002 w
.61469 .39609 m .60243 .44206 L .62347 .45458 L p
1 g
F P
s
P
p
.002 w
.36223 .43686 m .38268 .4633 L .39637 .44049 L p
1 g
F P
s
P
p
.002 w
.39637 .44049 m .38082 .42005 L .36223 .43686 L p
1 g
F P
s
P
p
.002 w
.4537 .56377 m .50587 .55711 L .49621 .53466 L p
1 g
F P
s
P
p
.002 w
.49621 .53466 m .44905 .54046 L .4537 .56377 L p
1 g
F P
s
P
p
.002 w
.50485 .31206 m .48114 .30102 L .46973 .32349 L p
1 g
F P
s
P
p
.002 w
.45159 .32196 m .46973 .32349 L .48114 .30102 L p
1 g
F P
s
P
p
.002 w
.3746 .36795 m .37322 .39497 L .39694 .38685 L p
1 g
F P
s
P
p
.002 w
.39694 .38685 m .39797 .36864 L .3746 .36795 L p
1 g
F P
s
P
p
.002 w
.56774 .55311 m .61119 .51522 L .5949 .49971 L p
1 g
F P
s
P
p
.002 w
.5949 .49971 m .55444 .53499 L .56774 .55311 L p
1 g
F P
s
P
p
.002 w
.62347 .45458 m .5949 .49971 L .61119 .51522 L p
1 g
F P
s
P
p
.002 w
.51565 .57698 m .56774 .55311 L .55444 .53499 L p
1 g
F P
s
P
p
.002 w
.55444 .53499 m .50587 .55711 L .51565 .57698 L p
1 g
F P
s
P
p
.002 w
.54741 .31983 m .52416 .29587 L .50485 .31206 L p
1 g
F P
s
P
p
.002 w
.48114 .30102 m .50485 .31206 L .52416 .29587 L p
1 g
F P
s
P
p
.002 w
.48114 .30102 m .45427 .29861 L .45159 .32196 L p
1 g
F P
s
P
p
.002 w
.43342 .3265 m .45159 .32196 L .45427 .29861 L p
1 g
F P
s
P
p
.002 w
.38497 .34207 m .3746 .36795 L .39797 .36864 L p
1 g
F P
s
P
p
.002 w
.39797 .36864 m .405 .35124 L .38497 .34207 L p
1 g
F P
s
P
p
.002 w
.61469 .39609 m .61195 .34941 L .58719 .34885 L p
1 g
F P
s
P
p
.002 w
.57128 .3119 m .58719 .34885 L .61195 .34941 L p
1 g
F P
s
P
p
.002 w
.58719 .34885 m .57128 .3119 L .54741 .31983 L p
1 g
F P
s
P
p
.002 w
.3521 .40419 m .36223 .43686 L .38082 .42005 L p
1 g
F P
s
P
p
.002 w
.38082 .42005 m .37322 .39497 L .3521 .40419 L p
1 g
F P
s
P
p
.002 w
.62347 .45458 m .63727 .40376 L .61469 .39609 L p
1 g
F P
s
P
p
.002 w
.61195 .34941 m .61469 .39609 L .63727 .40376 L p
1 g
F P
s
P
p
.002 w
.52416 .29587 m .54741 .31983 L .57128 .3119 L p
1 g
F P
s
P
p
.002 w
.36362 .50741 m .40327 .53124 L .40598 .50672 L p
1 g
F P
s
P
p
.002 w
.40598 .50672 m .37165 .48577 L .36362 .50741 L p
1 g
F P
s
P
p
.002 w
.40295 .55385 m .4537 .56377 L .44905 .54046 L p
1 g
F P
s
P
p
.002 w
.44905 .54046 m .40327 .53124 L .40295 .55385 L p
1 g
F P
s
P
p
.002 w
.34667 .45394 m .37165 .48577 L .38268 .4633 L p
1 g
F P
s
P
p
.002 w
.38268 .4633 m .36223 .43686 L .34667 .45394 L p
1 g
F P
s
P
p
.002 w
.45427 .29861 m .42725 .30527 L .43342 .3265 L p
1 g
F P
s
P
p
.002 w
.41727 .33664 m .43342 .3265 L .42725 .30527 L p
1 g
F P
s
P
p
.002 w
.40321 .32033 m .38497 .34207 L .405 .35124 L p
1 g
F P
s
P
p
.002 w
.405 .35124 m .41727 .33664 L .40321 .32033 L p
1 g
F P
s
P
p
.002 w
.42725 .30527 m .40321 .32033 L .41727 .33664 L p
1 g
F P
s
P
p
.002 w
.61119 .51522 m .64196 .46683 L .62347 .45458 L p
1 g
F P
s
P
p
.002 w
.63727 .40376 m .62347 .45458 L .64196 .46683 L p
1 g
F P
s
P
p
.002 w
.45967 .58434 m .51565 .57698 L .50587 .55711 L p
1 g
F P
s
P
p
.002 w
.50587 .55711 m .4537 .56377 L .45967 .58434 L p
1 g
F P
s
P
p
.002 w
.52416 .29587 m .49333 .28126 L .48114 .30102 L p
1 g
F P
s
P
p
.002 w
.45427 .29861 m .48114 .30102 L .49333 .28126 L p
1 g
F P
s
P
p
.002 w
.35375 .36884 m .3521 .40419 L .37322 .39497 L p
1 g
F P
s
P
p
.002 w
.37322 .39497 m .3746 .36795 L .35375 .36884 L p
1 g
F P
s
P
p
.002 w
.57128 .3119 m .54335 .28269 L .52416 .29587 L p
1 g
F P
s
P
p
.002 w
.49333 .28126 m .52416 .29587 L .54335 .28269 L p
1 g
F P
s
P
p
.002 w
.33416 .41438 m .34667 .45394 L .36223 .43686 L p
1 g
F P
s
P
p
.002 w
.36223 .43686 m .3521 .40419 L .33416 .41438 L p
1 g
F P
s
P
p
.002 w
.63727 .40376 m .63452 .35206 L .61195 .34941 L p
1 g
F P
s
P
p
.002 w
.59395 .30679 m .61195 .34941 L .63452 .35206 L p
1 g
F P
s
P
p
.002 w
.61195 .34941 m .59395 .30679 L .57128 .3119 L p
1 g
F P
s
P
p
.002 w
.54335 .28269 m .57128 .3119 L .59395 .30679 L p
1 g
F P
s
P
p
.002 w
.49333 .28126 m .45819 .27795 L .45427 .29861 L p
1 g
F P
s
P
p
.002 w
.42725 .30527 m .45427 .29861 L .45819 .27795 L p
1 g
F P
s
P
p
.002 w
.35887 .52772 m .40295 .55385 L .40327 .53124 L p
1 g
F P
s
P
p
.002 w
.40327 .53124 m .36362 .50741 L .35887 .52772 L p
1 g
F P
s
P
p
.002 w
.33461 .47093 m .36362 .50741 L .37165 .48577 L p
1 g
F P
s
P
p
.002 w
.37165 .48577 m .34667 .45394 L .33461 .47093 L p
1 g
F P
s
P
p
.002 w
.57973 .56866 m .62514 .52905 L .61119 .51522 L p
1 g
F P
s
P
p
.002 w
.61119 .51522 m .56774 .55311 L .57973 .56866 L p
1 g
F P
s
P
p
.002 w
.64196 .46683 m .61119 .51522 L .62514 .52905 L p
1 g
F P
s
P
p
.002 w
.64196 .46683 m .65698 .41232 L .63727 .40376 L p
1 g
F P
s
P
p
.002 w
.63452 .35206 m .63727 .40376 L .65698 .41232 L p
1 g
F P
s
P
p
.002 w
.52533 .59371 m .57973 .56866 L .56774 .55311 L p
1 g
F P
s
P
p
.002 w
.56774 .55311 m .51565 .57698 L .52533 .59371 L p
1 g
F P
s
P
p
.002 w
.36726 .33487 m .35375 .36884 L .3746 .36795 L p
1 g
F P
s
P
p
.002 w
.3746 .36795 m .38497 .34207 L .36726 .33487 L p
1 g
F P
s
P
p
.002 w
.40514 .57397 m .45967 .58434 L .4537 .56377 L p
1 g
F P
s
P
p
.002 w
.4537 .56377 m .40295 .55385 L .40514 .57397 L p
1 g
F P
s
P
p
.002 w
.45819 .27795 m .42275 .28658 L .42725 .30527 L p
1 g
F P
s
P
p
.002 w
.40321 .32033 m .42725 .30527 L .42275 .28658 L p
1 g
F P
s
P
p
.002 w
.39119 .30631 m .36726 .33487 L .38497 .34207 L p
1 g
F P
s
P
p
.002 w
.38497 .34207 m .40321 .32033 L .39119 .30631 L p
1 g
F P
s
P
p
.002 w
.62514 .52905 m .65739 .47853 L .64196 .46683 L p
1 g
F P
s
P
p
.002 w
.65698 .41232 m .64196 .46683 L .65739 .47853 L p
1 g
F P
s
P
p
.002 w
.42275 .28658 m .39119 .30631 L .40321 .32033 L p
1 g
F P
s
P
p
.002 w
.46688 .60159 m .52533 .59371 L .51565 .57698 L p
1 g
F P
s
P
p
.002 w
.51565 .57698 m .45967 .58434 L .46688 .60159 L p
1 g
F P
s
P
p
.002 w
.54335 .28269 m .50605 .26476 L .49333 .28126 L p
1 g
F P
s
P
p
.002 w
.45819 .27795 m .49333 .28126 L .50605 .26476 L p
1 g
F P
s
P
p
.002 w
.336 .37137 m .33416 .41438 L .3521 .40419 L p
1 g
F P
s
P
p
.002 w
.3521 .40419 m .35375 .36884 L .336 .37137 L p
1 g
F P
s
P
p
.002 w
.59395 .30679 m .562 .27294 L .54335 .28269 L p
1 g
F P
s
P
p
.002 w
.50605 .26476 m .54335 .28269 L .562 .27294 L p
1 g
F P
s
P
p
.002 w
.31995 .42534 m .33461 .47093 L .34667 .45394 L p
1 g
F P
s
P
p
.002 w
.34667 .45394 m .33416 .41438 L .31995 .42534 L p
1 g
F P
s
P
p
.002 w
.63452 .35206 m .61487 .30472 L .59395 .30679 L p
1 g
F P
s
P
p
.002 w
.562 .27294 m .59395 .30679 L .61487 .30472 L p
1 g
F P
s
P
p
.002 w
.65698 .41232 m .6543 .35682 L .63452 .35206 L p
1 g
F P
s
P
p
.002 w
.61487 .30472 m .63452 .35206 L .6543 .35682 L p
1 g
F P
s
P
p
.002 w
.3265 .48744 m .35887 .52772 L .36362 .50741 L p
1 g
F P
s
P
p
.002 w
.36362 .50741 m .33461 .47093 L .3265 .48744 L p
1 g
F P
s
P
p
.002 w
.35769 .54616 m .40514 .57397 L .40295 .55385 L p
1 g
F P
s
P
p
.002 w
.40295 .55385 m .35887 .52772 L .35769 .54616 L p
1 g
F P
s
P
p
.002 w
.65739 .47853 m .67326 .42165 L .65698 .41232 L p
1 g
F P
s
P
p
.002 w
.6543 .35682 m .65698 .41232 L .67326 .42165 L p
1 g
F P
s
P
p
.002 w
.50605 .26476 m .46334 .26056 L .45819 .27795 L p
1 g
F P
s
P
p
.002 w
.42275 .28658 m .45819 .27795 L .46334 .26056 L p
1 g
F P
s
P
p
.002 w
.35238 .32992 m .336 .37137 L .35375 .36884 L p
1 g
F P
s
P
p
.002 w
.35375 .36884 m .36726 .33487 L .35238 .32992 L p
1 g
F P
s
P
p
.002 w
.40992 .59099 m .46688 .60159 L .45967 .58434 L p
1 g
F P
s
P
p
.002 w
.45967 .58434 m .40514 .57397 L .40992 .59099 L p
1 g
F P
s
P
p
.002 w
.59006 .58116 m .63632 .54081 L .62514 .52905 L p
1 g
F P
s
P
p
.002 w
.62514 .52905 m .57973 .56866 L .59006 .58116 L p
1 g
F P
s
P
p
.002 w
.65739 .47853 m .62514 .52905 L .63632 .54081 L p
1 g
F P
s
P
p
.002 w
.5347 .60676 m .59006 .58116 L .57973 .56866 L p
1 g
F P
s
P
p
.002 w
.57973 .56866 m .52533 .59371 L .5347 .60676 L p
1 g
F P
s
P
p
.002 w
.46334 .26056 m .42012 .27098 L .42275 .28658 L p
1 g
F P
s
P
p
.002 w
.39119 .30631 m .42275 .28658 L .42012 .27098 L p
1 g
F P
s
P
p
.002 w
.38156 .29504 m .35238 .32992 L .36726 .33487 L p
1 g
F P
s
P
p
.002 w
.36726 .33487 m .39119 .30631 L .38156 .29504 L p
1 g
F P
s
P
p
.002 w
.63632 .54081 m .66924 .4894 L .65739 .47853 L p
1 g
F P
s
P
p
.002 w
.67326 .42165 m .65739 .47853 L .66924 .4894 L p
1 g
F P
s
P
p
.002 w
.42012 .27098 m .38156 .29504 L .39119 .30631 L p
1 g
F P
s
P
p
.002 w
.47524 .61494 m .5347 .60676 L .52533 .59371 L p
1 g
F P
s
P
p
.002 w
.52533 .59371 m .46688 .60159 L .47524 .61494 L p
1 g
F P
s
P
p
.002 w
.562 .27294 m .51905 .25204 L .50605 .26476 L p
1 g
F P
s
P
p
.002 w
.46334 .26056 m .50605 .26476 L .51905 .25204 L p
1 g
F P
s
P
p
.002 w
.32194 .37557 m .31995 .42534 L .33416 .41438 L p
1 g
F P
s
P
p
.002 w
.33416 .41438 m .336 .37137 L .32194 .37557 L p
1 g
F P
s
P
p
.002 w
.61487 .30472 m .57964 .26701 L .562 .27294 L p
1 g
F P
s
P
p
.002 w
.51905 .25204 m .562 .27294 L .57964 .26701 L p
1 g
F P
s
P
p
.002 w
.31003 .43685 m .3265 .48744 L .33461 .47093 L p
1 g
F P
s
P
p
.002 w
.33461 .47093 m .31995 .42534 L .31003 .43685 L p
1 g
F P
s
P
p
.002 w
.6543 .35682 m .63347 .30591 L .61487 .30472 L p
1 g
F P
s
P
p
.002 w
.57964 .26701 m .61487 .30472 L .63347 .30591 L p
1 g
F P
s
P
p
.002 w
.67326 .42165 m .6707 .36369 L .6543 .35682 L p
1 g
F P
s
P
p
.002 w
.63347 .30591 m .6543 .35682 L .6707 .36369 L p
1 g
F P
s
P
p
.002 w
.32275 .50303 m .35769 .54616 L .35887 .52772 L p
1 g
F P
s
P
p
.002 w
.35887 .52772 m .3265 .48744 L .32275 .50303 L p
1 g
F P
s
P
p
.002 w
.3603 .56217 m .40992 .59099 L .40514 .57397 L p
1 g
F P
s
P
p
.002 w
.40514 .57397 m .35769 .54616 L .3603 .56217 L p
1 g
F P
s
P
p
.002 w
.66924 .4894 m .68554 .43155 L .67326 .42165 L p
1 g
F P
s
P
p
.002 w
.6707 .36369 m .67326 .42165 L .68554 .43155 L p
1 g
F P
s
P
p
.002 w
.51905 .25204 m .46965 .24703 L .46334 .26056 L p
1 g
F P
s
P
p
.002 w
.42012 .27098 m .46334 .26056 L .46965 .24703 L p
1 g
F P
s
P
p
.002 w
.41731 .60434 m .47524 .61494 L .46688 .60159 L p
1 g
F P
s
P
p
.002 w
.46688 .60159 m .40992 .59099 L .41731 .60434 L p
1 g
F P
s
P
p
.002 w
.34085 .32747 m .32194 .37557 L .336 .37137 L p
1 g
F P
s
P
p
.002 w
.336 .37137 m .35238 .32992 L .34085 .32747 L p
1 g
F P
s
P
p
.002 w
.59841 .59015 m .64432 .55009 L .63632 .54081 L p
1 g
F P
s
P
p
.002 w
.63632 .54081 m .59006 .58116 L .59841 .59015 L p
1 g
F P
s
P
p
.002 w
.66924 .4894 m .63632 .54081 L .64432 .55009 L p
1 g
F P
s
P
p
.002 w
.54351 .6156 m .59841 .59015 L .59006 .58116 L p
1 g
F P
s
P
p
.002 w
.59006 .58116 m .5347 .60676 L .54351 .6156 L p
1 g
F P
s
P
p
.002 w
.46965 .24703 m .41951 .25903 L .42012 .27098 L p
1 g
F P
s
P
p
.002 w
.38156 .29504 m .42012 .27098 L .41951 .25903 L p
1 g
F P
s
P
p
.002 w
.37473 .28694 m .34085 .32747 L .35238 .32992 L p
1 g
F P
s
P
p
.002 w
.35238 .32992 m .38156 .29504 L .37473 .28694 L p
1 g
F P
s
P
p
.002 w
.64432 .55009 m .67704 .49912 L .66924 .4894 L p
1 g
F P
s
P
p
.002 w
.68554 .43155 m .66924 .4894 L .67704 .49912 L p
1 g
F P
s
P
p
.002 w
.57964 .26701 m .53203 .24362 L .51905 .25204 L p
1 g
F P
s
P
p
.002 w
.46965 .24703 m .51905 .25204 L .53203 .24362 L p
1 g
F P
s
P
p
.002 w
.48461 .62382 m .54351 .6156 L .5347 .60676 L p
1 g
F P
s
P
p
.002 w
.5347 .60676 m .47524 .61494 L .48461 .62382 L p
1 g
F P
s
P
p
.002 w
.41951 .25903 m .37473 .28694 L .38156 .29504 L p
1 g
F P
s
P
p
.002 w
.31212 .38143 m .31003 .43685 L .31995 .42534 L p
1 g
F P
s
P
p
.002 w
.31995 .42534 m .32194 .37557 L .31212 .38143 L p
1 g
F P
s
P
p
.002 w
.63347 .30591 m .59579 .26525 L .57964 .26701 L p
1 g
F P
s
P
p
.002 w
.53203 .24362 m .57964 .26701 L .59579 .26525 L p
1 g
F P
s
P
p
.002 w
.6707 .36369 m .64916 .31048 L .63347 .30591 L p
1 g
F P
s
P
p
.002 w
.59579 .26525 m .63347 .30591 L .64916 .31048 L p
1 g
F P
s
P
p
.002 w
.30491 .44865 m .32275 .50303 L .3265 .48744 L p
1 g
F P
s
P
p
.002 w
.3265 .48744 m .31003 .43685 L .30491 .44865 L p
1 g
F P
s
P
p
.002 w
.68554 .43155 m .68312 .37262 L .6707 .36369 L p
1 g
F P
s
P
p
.002 w
.64916 .31048 m .6707 .36369 L .68312 .37262 L p
1 g
F P
s
P
p
.002 w
.32371 .51725 m .3603 .56217 L .35769 .54616 L p
1 g
F P
s
P
p
.002 w
.35769 .54616 m .32275 .50303 L .32371 .51725 L p
1 g
F P
s
P
p
.002 w
.36684 .57519 m .41731 .60434 L .40992 .59099 L p
1 g
F P
s
P
p
.002 w
.40992 .59099 m .3603 .56217 L .36684 .57519 L p
1 g
F P
s
P
p
.002 w
.67704 .49912 m .6933 .44182 L .68554 .43155 L p
1 g
F P
s
P
p
.002 w
.68312 .37262 m .68554 .43155 L .6933 .44182 L p
1 g
F P
s
P
p
.002 w
.53203 .24362 m .47704 .23791 L .46965 .24703 L p
1 g
F P
s
P
p
.002 w
.41951 .25903 m .46965 .24703 L .47704 .23791 L p
1 g
F P
s
P
p
.002 w
.42726 .61344 m .48461 .62382 L .47524 .61494 L p
1 g
F P
s
P
p
.002 w
.47524 .61494 m .41731 .60434 L .42726 .61344 L p
1 g
F P
s
P
p
.002 w
.33318 .32772 m .31212 .38143 L .32194 .37557 L p
1 g
F P
s
P
p
.002 w
.32194 .37557 m .34085 .32747 L .33318 .32772 L p
1 g
F P
s
P
p
.002 w
.60443 .59517 m .64873 .55652 L .64432 .55009 L p
1 g
F P
s
P
p
.002 w
.64432 .55009 m .59841 .59015 L .60443 .59517 L p
1 g
F P
s
P
p
.002 w
.67704 .49912 m .64432 .55009 L .64873 .55652 L p
1 g
F P
s
P
p
.002 w
.55151 .61976 m .60443 .59517 L .59841 .59015 L p
1 g
F P
s
P
p
.002 w
.59841 .59015 m .54351 .6156 L .55151 .61976 L p
1 g
F P
s
P
p
.002 w
.47704 .23791 m .42108 .25125 L .41951 .25903 L p
1 g
F P
s
P
p
.002 w
.37473 .28694 m .41951 .25903 L .42108 .25125 L p
1 g
F P
s
P
p
.002 w
.37103 .28243 m .33318 .32772 L .34085 .32747 L p
1 g
F P
s
P
p
.002 w
.34085 .32747 m .37473 .28694 L .37103 .28243 L p
1 g
F P
s
P
p
.002 w
.59579 .26525 m .54465 .23996 L .53203 .24362 L p
1 g
F P
s
P
p
.002 w
.47704 .23791 m .53203 .24362 L .54465 .23996 L p
1 g
F P
s
P
p
.002 w
.64873 .55652 m .68032 .50738 L .67704 .49912 L p
1 g
F P
s
P
p
.002 w
.6933 .44182 m .67704 .49912 L .68032 .50738 L p
1 g
F P
s
P
p
.002 w
.3071 .38889 m .30491 .44865 L .31003 .43685 L p
1 g
F P
s
P
p
.002 w
.31003 .43685 m .31212 .38143 L .3071 .38889 L p
1 g
F P
s
P
p
.002 w
.49478 .62773 m .55151 .61976 L .54351 .6156 L p
1 g
F P
s
P
p
.002 w
.54351 .6156 m .48461 .62382 L .49478 .62773 L p
1 g
F P
s
P
p
.002 w
.42108 .25125 m .37103 .28243 L .37473 .28694 L p
1 g
F P
s
P
p
.002 w
.64916 .31048 m .60996 .26795 L .59579 .26525 L p
1 g
F P
s
P
p
.002 w
.54465 .23996 m .59579 .26525 L .60996 .26795 L p
1 g
F P
s
P
p
.002 w
.68312 .37262 m .66139 .31853 L .64916 .31048 L p
1 g
F P
s
P
p
.002 w
.60996 .26795 m .64916 .31048 L .66139 .31853 L p
1 g
F P
s
P
p
.002 w
.305 .46043 m .32371 .51725 L .32275 .50303 L p
1 g
F P
s
P
p
.002 w
.32275 .50303 m .30491 .44865 L .305 .46043 L p
1 g
F P
s
P
p
.002 w
.32964 .52961 m .36684 .57519 L .3603 .56217 L p
1 g
F P
s
P
p
.002 w
.3603 .56217 m .32371 .51725 L .32964 .52961 L p
1 g
F P
s
P
p
.002 w
.6933 .44182 m .69101 .3835 L .68312 .37262 L p
1 g
F P
s
P
p
.002 w
.66139 .31853 m .68312 .37262 L .69101 .3835 L p
1 g
F P
s
P
p
.002 w
.37737 .58469 m .42726 .61344 L .41731 .60434 L p
1 g
F P
s
P
p
.002 w
.41731 .60434 m .36684 .57519 L .37737 .58469 L p
1 g
F P
s
P
p
.002 w
.68032 .50738 m .69604 .4522 L .6933 .44182 L p
1 g
F P
s
P
p
.002 w
.69101 .3835 m .6933 .44182 L .69604 .4522 L p
1 g
F P
s
P
p
.002 w
.43966 .61779 m .49478 .62773 L .48461 .62382 L p
1 g
F P
s
P
p
.002 w
.48461 .62382 m .42726 .61344 L .43966 .61779 L p
1 g
F P
s
P
p
.002 w
.54465 .23996 m .48538 .23374 L .47704 .23791 L p
1 g
F P
s
P
p
.002 w
.42108 .25125 m .47704 .23791 L .48538 .23374 L p
1 g
F P
s
P
p
.002 w
.32983 .33086 m .3071 .38889 L .31212 .38143 L p
1 g
F P
s
P
p
.002 w
.31212 .38143 m .33318 .32772 L .32983 .33086 L p
1 g
F P
s
P
p
.002 w
.60782 .59584 m .64921 .55973 L .64873 .55652 L p
1 g
F P
s
P
p
.002 w
.64873 .55652 m .60443 .59517 L .60782 .59584 L p
1 g
F P
s
P
p
.002 w
.68032 .50738 m .64873 .55652 L .64921 .55973 L p
1 g
F P
s
P
p
.002 w
.55841 .61881 m .60782 .59584 L .60443 .59517 L p
1 g
F P
s
P
p
.002 w
.60443 .59517 m .55151 .61976 L .55841 .61881 L p
1 g
F P
s
P
p
.002 w
.60996 .26795 m .55654 .24145 L .54465 .23996 L p
1 g
F P
s
P
p
.002 w
.48538 .23374 m .54465 .23996 L .55654 .24145 L p
1 g
F P
s
P
p
.002 w
.48538 .23374 m .42492 .24813 L .42108 .25125 L p
1 g
F P
s
P
p
.002 w
.37103 .28243 m .42108 .25125 L .42492 .24813 L p
1 g
F P
s
P
p
.002 w
.30731 .39785 m .305 .46043 L .30491 .44865 L p
1 g
F P
s
P
p
.002 w
.30491 .44865 m .3071 .38889 L .30731 .39785 L p
1 g
F P
s
P
p
.002 w
.37077 .28186 m .32983 .33086 L .33318 .32772 L p
1 g
F P
s
P
p
.002 w
.33318 .32772 m .37103 .28243 L .37077 .28186 L p
1 g
F P
s
P
p
.002 w
.64921 .55973 m .67871 .51385 L .68032 .50738 L p
1 g
F P
s
P
p
.002 w
.69604 .4522 m .68032 .50738 L .67871 .51385 L p
1 g
F P
s
P
p
.002 w
.50554 .62624 m .55841 .61881 L .55151 .61976 L p
1 g
F P
s
P
p
.002 w
.55151 .61976 m .49478 .62773 L .50554 .62624 L p
1 g
F P
s
P
p
.002 w
.66139 .31853 m .62163 .27529 L .60996 .26795 L p
1 g
F P
s
P
p
.002 w
.55654 .24145 m .60996 .26795 L .62163 .27529 L p
1 g
F P
s
P
p
.002 w
.42492 .24813 m .37077 .28186 L .37103 .28243 L p
1 g
F P
s
P
p
.002 w
.69101 .3835 m .66959 .33002 L .66139 .31853 L p
1 g
F P
s
P
p
.002 w
.62163 .27529 m .66139 .31853 L .66959 .33002 L p
1 g
F P
s
P
p
.002 w
.31065 .47185 m .32964 .52961 L .32371 .51725 L p
1 g
F P
s
P
p
.002 w
.32371 .51725 m .305 .46043 L .31065 .47185 L p
1 g
F P
s
P
p
.002 w
.34066 .53965 m .37737 .58469 L .36684 .57519 L p
1 g
F P
s
P
p
.002 w
.36684 .57519 m .32964 .52961 L .34066 .53965 L p
1 g
F P
s
P
p
.002 w
.69604 .4522 m .69387 .39614 L .69101 .3835 L p
1 g
F P
s
P
p
.002 w
.66959 .33002 m .69101 .3835 L .69387 .39614 L p
1 g
F P
s
P
p
.002 w
.39182 .59016 m .43966 .61779 L .42726 .61344 L p
1 g
F P
s
P
p
.002 w
.42726 .61344 m .37737 .58469 L .39182 .59016 L p
1 g
F P
s
P
p
.002 w
.67871 .51385 m .69337 .46241 L .69604 .4522 L p
1 g
F P
s
P
p
.002 w
.69387 .39614 m .69604 .4522 L .69337 .46241 L p
1 g
F P
s
P
p
.002 w
.45429 .61695 m .50554 .62624 L .49478 .62773 L p
1 g
F P
s
P
p
.002 w
.49478 .62773 m .43966 .61779 L .45429 .61695 L p
1 g
F P
s
P
p
.002 w
.55654 .24145 m .49449 .23495 L .48538 .23374 L p
1 g
F P
s
P
p
.002 w
.42492 .24813 m .48538 .23374 L .49449 .23495 L p
1 g
F P
s
P
p
.002 w
.33119 .33697 m .30731 .39785 L .3071 .38889 L p
1 g
F P
s
P
p
.002 w
.3071 .38889 m .32983 .33086 L .33119 .33697 L p
1 g
F P
s
P
p
.002 w
.60829 .59185 m .64547 .55941 L .64921 .55973 L p
1 g
F P
s
P
p
.002 w
.64921 .55973 m .60782 .59584 L .60829 .59185 L p
1 g
F P
s
P
p
.002 w
.67871 .51385 m .64921 .55973 L .64547 .55941 L p
1 g
F P
s
P
p
.002 w
.56394 .61244 m .60829 .59185 L .60782 .59584 L p
1 g
F P
s
P
p
.002 w
.60782 .59584 m .55841 .61881 L .56394 .61244 L p
1 g
F P
s
P
p
.002 w
.62163 .27529 m .56733 .24838 L .55654 .24145 L p
1 g
F P
s
P
p
.002 w
.49449 .23495 m .55654 .24145 L .56733 .24838 L p
1 g
F P
s
P
p
.002 w
.31309 .40813 m .31065 .47185 L .305 .46043 L p
1 g
F P
s
P
p
.002 w
.305 .46043 m .30731 .39785 L .31309 .40813 L p
1 g
F P
s
P
p
.002 w
.49449 .23495 m .43106 .25008 L .42492 .24813 L p
1 g
F P
s
P
p
.002 w
.37077 .28186 m .42492 .24813 L .43106 .25008 L p
1 g
F P
s
P
p
.002 w
.37421 .28551 m .33119 .33697 L .32983 .33086 L p
1 g
F P
s
P
p
.002 w
.32983 .33086 m .37077 .28186 L .37421 .28551 L p
1 g
F P
s
P
p
.002 w
.66959 .33002 m .6303 .28735 L .62163 .27529 L p
1 g
F P
s
P
p
.002 w
.56733 .24838 m .62163 .27529 L .6303 .28735 L p
1 g
F P
s
P
p
.002 w
.64547 .55941 m .67194 .51822 L .67871 .51385 L p
1 g
F P
s
P
p
.002 w
.69337 .46241 m .67871 .51385 L .67194 .51822 L p
1 g
F P
s
P
p
.002 w
.51658 .61905 m .56394 .61244 L .55841 .61881 L p
1 g
F P
s
P
p
.002 w
.55841 .61881 m .50554 .62624 L .51658 .61905 L p
1 g
F P
s
P
p
.002 w
.69387 .39614 m .67329 .34484 L .66959 .33002 L p
1 g
F P
s
P
p
.002 w
.6303 .28735 m .66959 .33002 L .67329 .34484 L p
1 g
F P
s
P
p
.002 w
.32203 .48253 m .34066 .53965 L .32964 .52961 L p
1 g
F P
s
P
p
.002 w
.32964 .52961 m .31065 .47185 L .32203 .48253 L p
1 g
F P
s
P
p
.002 w
.35675 .54691 m .39182 .59016 L .37737 .58469 L p
1 g
F P
s
P
p
.002 w
.37737 .58469 m .34066 .53965 L .35675 .54691 L p
1 g
F P
s
P
p
.002 w
.43106 .25008 m .37421 .28551 L .37077 .28186 L p
1 g
F P
s
P
p
.002 w
.69337 .46241 m .69131 .41027 L .69387 .39614 L p
1 g
F P
s
P
p
.002 w
.67329 .34484 m .69387 .39614 L .69131 .41027 L p
1 g
F P
s
P
p
.002 w
.40997 .59121 m .45429 .61695 L .43966 .61779 L p
1 g
F P
s
P
p
.002 w
.43966 .61779 m .39182 .59016 L .40997 .59121 L p
1 g
F P
s
P
p
.002 w
.67194 .51822 m .68502 .47213 L .69337 .46241 L p
1 g
F P
s
P
p
.002 w
.69131 .41027 m .69337 .46241 L .68502 .47213 L p
1 g
F P
s
P
p
.002 w
.47083 .61064 m .51658 .61905 L .50554 .62624 L p
1 g
F P
s
P
p
.002 w
.50554 .62624 m .45429 .61695 L .47083 .61064 L p
1 g
F P
s
P
p
.002 w
.56733 .24838 m .50414 .24185 L .49449 .23495 L p
1 g
F P
s
P
p
.002 w
.43106 .25008 m .49449 .23495 L .50414 .24185 L p
1 g
F P
s
P
p
.002 w
.33752 .34608 m .31309 .40813 L .30731 .39785 L p
1 g
F P
s
P
p
.002 w
.30731 .39785 m .33119 .33697 L .33752 .34608 L p
1 g
F P
s
P
p
.002 w
.60565 .583 m .63734 .55534 L .64547 .55941 L p
1 g
F P
s
P
p
.002 w
.64547 .55941 m .60829 .59185 L .60565 .583 L p
1 g
F P
s
P
p
.002 w
.67194 .51822 m .64547 .55941 L .63734 .55534 L p
1 g
F P
s
P
p
.002 w
.56784 .60051 m .60565 .583 L .60829 .59185 L p
1 g
F P
s
P
p
.002 w
.60829 .59185 m .56394 .61244 L .56784 .60051 L p
1 g
F P
s
P
p
.002 w
.6303 .28735 m .57659 .26087 L .56733 .24838 L p
1 g
F P
s
P
p
.002 w
.50414 .24185 m .56733 .24838 L .57659 .26087 L p
1 g
F P
s
P
p
.002 w
.3246 .41949 m .32203 .48253 L .31065 .47185 L p
1 g
F P
s
P
p
.002 w
.31065 .47185 m .31309 .40813 L .3246 .41949 L p
1 g
F P
s
P
p
.002 w
.67329 .34484 m .63554 .30403 L .6303 .28735 L p
1 g
F P
s
P
p
.002 w
.57659 .26087 m .6303 .28735 L .63554 .30403 L p
1 g
F P
s
P
p
.002 w
.69131 .41027 m .6721 .36272 L .67329 .34484 L p
1 g
F P
s
P
p
.002 w
.63554 .30403 m .67329 .34484 L .6721 .36272 L p
1 g
F P
s
P
p
.002 w
.50414 .24185 m .43948 .25736 L .43106 .25008 L p
1 g
F P
s
P
p
.002 w
.37421 .28551 m .43106 .25008 L .43948 .25736 L p
1 g
F P
s
P
p
.002 w
.33909 .49209 m .35675 .54691 L .34066 .53965 L p
1 g
F P
s
P
p
.002 w
.34066 .53965 m .32203 .48253 L .33909 .49209 L p
1 g
F P
s
P
p
.002 w
.63734 .55534 m .65987 .52023 L .67194 .51822 L p
1 g
F P
s
P
p
.002 w
.68502 .47213 m .67194 .51822 L .65987 .52023 L p
1 g
F P
s
P
p
.002 w
.38146 .29356 m .33752 .34608 L .33119 .33697 L p
1 g
F P
s
P
p
.002 w
.33119 .33697 m .37421 .28551 L .38146 .29356 L p
1 g
F P
s
P
p
.002 w
.37766 .551 m .40997 .59121 L .39182 .59016 L p
1 g
F P
s
P
p
.002 w
.39182 .59016 m .35675 .54691 L .37766 .551 L p
1 g
F P
s
P
p
.002 w
.52758 .60604 m .56784 .60051 L .56394 .61244 L p
1 g
F P
s
P
p
.002 w
.56394 .61244 m .51658 .61905 L .52758 .60604 L p
1 g
F P
s
P
p
.002 w
.68502 .47213 m .68308 .42555 L .69131 .41027 L p
1 g
F P
s
P
p
.002 w
.6721 .36272 m .69131 .41027 L .68308 .42555 L p
1 g
F P
s
P
p
.002 w
.43948 .25736 m .38146 .29356 L .37421 .28551 L p
1 g
F P
s
P
p
.002 w
.43144 .58754 m .47083 .61064 L .45429 .61695 L p
1 g
F P
s
P
p
.002 w
.45429 .61695 m .40997 .59121 L .43144 .58754 L p
1 g
F P
s
P
p
.002 w
.65987 .52023 m .67091 .48102 L .68502 .47213 L p
1 g
F P
s
P
p
.002 w
.68308 .42555 m .68502 .47213 L .67091 .48102 L p
1 g
F P
s
P
p
.002 w
.48883 .59876 m .52758 .60604 L .51658 .61905 L p
1 g
F P
s
P
p
.002 w
.51658 .61905 m .47083 .61064 L .48883 .59876 L p
1 g
F P
s
P
p
.002 w
.57659 .26087 m .51407 .25457 L .50414 .24185 L p
1 g
F P
s
P
p
.002 w
.43948 .25736 m .50414 .24185 L .51407 .25457 L p
1 g
F P
s
P
p
.002 w
.34893 .35806 m .3246 .41949 L .31309 .40813 L p
1 g
F P
s
P
p
.002 w
.31309 .40813 m .33752 .34608 L .34893 .35806 L p
1 g
F P
s
P
p
.002 w
.63554 .30403 m .58396 .27885 L .57659 .26087 L p
1 g
F P
s
P
p
.002 w
.51407 .25457 m .57659 .26087 L .58396 .27885 L p
1 g
F P
s
P
p
.002 w
.59976 .56927 m .62482 .54741 L .63734 .55534 L p
1 g
F P
s
P
p
.002 w
.63734 .55534 m .60565 .583 L .59976 .56927 L p
1 g
F P
s
P
p
.002 w
.65987 .52023 m .63734 .55534 L .62482 .54741 L p
1 g
F P
s
P
p
.002 w
.56989 .58305 m .59976 .56927 L .60565 .583 L p
1 g
F P
s
P
p
.002 w
.60565 .583 m .56784 .60051 L .56989 .58305 L p
1 g
F P
s
P
p
.002 w
.3418 .43161 m .33909 .49209 L .32203 .48253 L p
1 g
F P
s
P
p
.002 w
.32203 .48253 m .3246 .41949 L .3418 .43161 L p
1 g
F P
s
P
p
.002 w
.6721 .36272 m .63696 .32506 L .63554 .30403 L p
1 g
F P
s
P
p
.002 w
.58396 .27885 m .63554 .30403 L .63696 .32506 L p
1 g
F P
s
P
p
.002 w
.68308 .42555 m .66578 .38326 L .6721 .36272 L p
1 g
F P
s
P
p
.002 w
.63696 .32506 m .6721 .36272 L .66578 .38326 L p
1 g
F P
s
P
p
.002 w
.36158 .50013 m .37766 .551 L .35675 .54691 L p
1 g
F P
s
P
p
.002 w
.35675 .54691 m .33909 .49209 L .36158 .50013 L p
1 g
F P
s
P
p
.002 w
.40293 .5516 m .43144 .58754 L .40997 .59121 L p
1 g
F P
s
P
p
.002 w
.40997 .59121 m .37766 .551 L .40293 .5516 L p
1 g
F P
s
P
p
.002 w
.51407 .25457 m .45004 .27007 L .43948 .25736 L p
1 g
F P
s
P
p
.002 w
.38146 .29356 m .43948 .25736 L .45004 .27007 L p
1 g
F P
s
P
p
.002 w
.62482 .54741 m .64257 .51966 L .65987 .52023 L p
1 g
F P
s
P
p
.002 w
.67091 .48102 m .65987 .52023 L .64257 .51966 L p
1 g
F P
s
P
p
.002 w
.67091 .48102 m .66912 .44155 L .68308 .42555 L p
1 g
F P
s
P
p
.002 w
.66578 .38326 m .68308 .42555 L .66912 .44155 L p
1 g
F P
s
P
p
.002 w
.39254 .30602 m .34893 .35806 L .33752 .34608 L p
1 g
F P
s
P
p
.002 w
.33752 .34608 m .38146 .29356 L .39254 .30602 L p
1 g
F P
s
P
p
.002 w
.53816 .5873 m .56989 .58305 L .56784 .60051 L p
1 g
F P
s
P
p
.002 w
.56784 .60051 m .52758 .60604 L .53816 .5873 L p
1 g
F P
s
P
p
.002 w
.45568 .57904 m .48883 .59876 L .47083 .61064 L p
1 g
F P
s
P
p
.002 w
.47083 .61064 m .43144 .58754 L .45568 .57904 L p
1 g
F P
s
P
p
.002 w
.45004 .27007 m .39254 .30602 L .38146 .29356 L p
1 g
F P
s
P
p
.002 w
.64257 .51966 m .65118 .48873 L .67091 .48102 L p
1 g
F P
s
P
p
.002 w
.66912 .44155 m .67091 .48102 L .65118 .48873 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58101 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .58101 L .51294 .58037 L 1 g
F
P
p
.002 w
.53816 .5873 m .50897 .58166 L p
.51097 .58101 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53163 .57428 L p
1 g
F P
s
P
p
.53468 .57849 m .52238 .5798 L .53286 .57388 L 1 g
F
P
p
.52238 .5798 m .53163 .57428 L .53286 .57388 L 1 g
F
P
p
.54854 .56129 m .53163 .57428 L .54038 .56907 L 1 g
F
P
p
.48883 .59876 m .48488 .57985 L .48916 .58014 L 1 g
F
P
p
.002 w
.50777 .58142 m .5046 .58432 L p
.48916 .58014 L 1 g
F P
s
P
p
.002 w
.5046 .58432 m .48883 .59876 L p
.48916 .58014 L 1 g
F P
s
P
p
.002 w
.4891 .58012 m .48921 .57862 L p
.48107 .57795 L 1 g
F P
s
P
p
.51079 .57862 m .49975 .58083 L .50108 .58091 L 1 g
F
P
p
.002 w
.50764 .58134 m .50777 .58142 L p
.48488 .57985 L 1 g
F P
s
P
p
.002 w
.51097 .58101 m .51079 .57862 L p
.49856 .58151 L 1 g
F P
s
P
p
.49856 .58151 m .50784 .58134 L .51097 .58101 L 1 g
F
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48193 .56578 m .50933 .54808 L p
.50777 .58134 L 1 g
F P
s
P
p
.002 w
.50777 .58142 m .50764 .58134 L p
.50777 .58134 L 1 g
F P
s
P
p
.002 w
.50764 .58134 m .48193 .56578 L p
.50777 .58134 L 1 g
F P
s
P
p
.52238 .5798 m .51097 .58101 L .53163 .57428 L 1 g
F
P
p
.53816 .5873 m .51097 .58101 L .53468 .57849 L 1 g
F
P
p
.52197 .57743 m .51098 .58119 L .51767 .57963 L 1 g
F
P
p
.53128 .57265 m .51294 .58037 L .52197 .57743 L 1 g
F
P
p
.51294 .58037 m .51098 .58119 L .52197 .57743 L 1 g
F
P
p
.002 w
.53816 .5873 m .52758 .60604 L p
.50812 .58186 L 1 g
F P
s
P
p
.002 w
.50897 .58166 m .53816 .5873 L p
.50812 .58186 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.50897 .58166 m .50777 .58142 L p
.53286 .57388 L 1 g
F P
s
P
p
.002 w
.50777 .58142 m .50897 .58166 L p
.50812 .58186 L 1 g
F P
s
P
p
.002 w
.52758 .60604 m .48883 .59876 L .50777 .58142 L p
1 g
F P
s
P
p
.002 w
.49225 .583 m .51111 .583 L .51099 .58128 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53286 .57388 m .50815 .58131 L .52699 .559 L 1 g
F
P
p
.002 w
.50777 .58142 m .50784 .58134 L p
.50815 .58131 L 1 g
F P
s
P
p
.002 w
.50784 .58134 m .52699 .559 L p
.50815 .58131 L 1 g
F P
s
P
p
.002 w
.51099 .58128 m .51097 .58101 L p
.50784 .58134 L 1 g
F P
s
P
p
.002 w
.50784 .58134 m .50777 .58142 L p
.50777 .58134 L 1 g
F P
s
P
p
.50784 .58134 m .49225 .583 L .51099 .58128 L 1 g
F
P
p
.49856 .58151 m .49225 .583 L .50784 .58134 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50933 .54808 m .52699 .559 L .50784 .58134 L p
1 g
F P
s
P
p
.50777 .58134 m .50933 .54808 L .50784 .58134 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46832 .5745 L p
1 g
F P
s
P
p
.48921 .57862 m .46832 .5745 L .48107 .57795 L 1 g
F
P
p
.002 w
.48193 .56578 m .50764 .58134 L p
.4891 .58012 L 1 g
F P
s
P
p
.48488 .57985 m .48468 .57893 L .4891 .58012 L 1 g
F
P
p
.48468 .57893 m .48193 .56578 L .4891 .58012 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48883 .59876 m .45568 .57904 L .46652 .57356 L p
1 g
F P
s
P
p
.002 w
.46832 .5745 m .46872 .57265 L p
.46066 .56943 L 1 g
F P
s
P
p
.002 w
.46652 .57356 m .45568 .57904 L p
.4581 .56762 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45568 .57904 m .43284 .54978 L p
.45098 .56259 L 1 g
F P
s
P
p
.4575 .57041 m .45098 .56259 L .4581 .56762 L 1 g
F
P
p
.45568 .57904 m .45098 .56259 L .4575 .57041 L 1 g
F
P
p
.002 w
.45098 .56259 m .45146 .56129 L p
.44576 .55634 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45098 .56259 L p
1 g
F P
s
P
p
.002 w
.45098 .56259 m .45002 .56518 L p
.46066 .56943 L 1 g
F P
s
P
p
.46872 .57265 m .45098 .56259 L .46066 .56943 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43832 .54742 L p
1 g
F P
s
P
p
.002 w
.43188 .54854 m .43814 .54721 L p
.43832 .54742 L 1 g
F P
s
P
p
.45066 .5622 m .44166 .55566 L .43832 .54742 L 1 g
F
P
p
.44166 .55566 m .43188 .54854 L .43832 .54742 L 1 g
F
P
p
.43925 .54566 m .43584 .53892 L .43597 .53936 L 1 g
F
P
p
.002 w
.43823 .54719 m .43188 .54854 L p
.4365 .54119 L 1 g
F P
s
P
p
.002 w
.43832 .54742 m .43925 .54566 L p
.43597 .53936 L 1 g
F P
s
P
p
.43188 .54854 m .43172 .54715 L .4365 .54119 L 1 g
F
P
p
.43172 .54715 m .42768 .51061 L .43279 .52832 L 1 g
F
P
p
.43172 .54715 m .43279 .52832 L .4365 .54119 L 1 g
F
P
p
.002 w
.43279 .52832 m .43346 .52734 L p
.43323 .52059 L 1 g
F P
s
P
p
.43597 .53936 m .43823 .54719 L .43832 .54742 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.4365 .54119 m .43279 .52832 L .45492 .51186 L 1 g
F
P
p
.002 w
.42768 .51061 m .43378 .51089 L p
.43279 .52832 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43396 .50932 L p
1 g
F P
s
P
p
.42043 .51028 m .43533 .49772 L .43396 .50932 L 1 g
F
P
p
.002 w
.43378 .51089 m .43321 .51086 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.43321 .51086 m .42043 .51028 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.43396 .50932 m .43485 .50826 L p
.43758 .50188 L 1 g
F P
s
P
p
.43346 .52734 m .43396 .50932 L .43384 .51037 L 1 g
F
P
p
.43346 .52734 m .43386 .50944 L .43323 .52059 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44282 .49111 L p
1 g
F P
s
P
p
.43485 .50826 m .44282 .49111 L .43758 .50188 L 1 g
F
P
p
.43396 .50932 m .45724 .47925 L .43378 .51089 L 1 g
F
P
p
.43533 .49772 m .44257 .49161 L .43396 .50932 L 1 g
F
P
p
.44257 .49161 m .45724 .47925 L .43396 .50932 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45562 .47873 m .45724 .47925 L p
.44042 .49342 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45755 .47686 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45724 .47925 m .45562 .47873 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.45755 .47686 m .45826 .47608 L p
.46741 .47207 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45842 .47645 m .4776 .4671 L .50211 .46715 L 1 g
F
P
p
.002 w
.4776 .4671 m .47786 .46667 L p
.48844 .46559 L 1 g
F P
s
P
p
.002 w
.49753 .46433 m .50211 .46715 L p
.4776 .4671 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.51766 .4489 m .50557 .46309 L p
.47049 .44768 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54248 .47689 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5635 .50171 m .57846 .5281 L .57543 .52948 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56613 .50943 L p
1 g
F P
s
P
p
.55661 .4905 m .56613 .50943 L .56421 .50527 L 1 g
F
P
p
.002 w
.5639 .50462 m .5635 .50171 L p
.56598 .50748 L 1 g
F P
s
P
p
.57543 .52948 m .56613 .50943 L .56598 .50748 L 1 g
F
P
p
.56613 .50943 m .5639 .50462 L .56598 .50748 L 1 g
F
P
p
.002 w
.56613 .50943 m .56515 .50826 L p
.56692 .51973 L 1 g
F P
s
P
p
.55661 .4905 m .56421 .50527 L .5639 .50462 L 1 g
F
P
p
.55661 .4905 m .5639 .50462 L .5632 .50311 L 1 g
F
P
p
.002 w
.56297 .50262 m .5635 .50171 L .5632 .50311 L p
1 g
F P
s
P
p
.56319 .50308 m .5632 .50311 L .56319 .50309 L 1 g
F
P
p
.55661 .4905 m .5632 .50311 L .56319 .50308 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.5632 .50311 m .5635 .50171 L .5639 .50462 L p
1 g
F P
s
P
p
.002 w
.55669 .48342 m .5635 .50171 L .56126 .49912 L p
1 g
F P
s
P
p
.55257 .48153 m .55669 .48342 L .55962 .4935 L 1 g
F
P
p
.55743 .49138 m .55962 .4935 L .56126 .49912 L 1 g
F
P
p
.55257 .48153 m .55962 .4935 L .55743 .49138 L 1 g
F
P
p
.002 w
.55677 .4908 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.55677 .49082 m .56321 .50312 L .56283 .50233 L 1 g
F
P
p
.002 w
.56218 .50099 m .5635 .50171 L .56245 .50154 L p
1 g
F P
s
P
p
.55677 .49082 m .56283 .50233 L .56272 .5021 L 1 g
F
P
p
.55677 .49082 m .56272 .5021 L .56266 .50197 L 1 g
F
P
p
.55677 .49082 m .56267 .50198 L .56235 .50132 L 1 g
F
P
p
.002 w
.56126 .49912 m .5635 .50171 L .56218 .50099 L p
1 g
F P
s
P
p
.002 w
.55764 .49166 m .55753 .49155 L p
.56235 .50132 L 1 g
F P
s
P
p
.002 w
.55753 .49155 m .55677 .49082 L p
.56235 .50132 L 1 g
F P
s
P
p
.52214 .46667 m .54248 .47689 L .54177 .47656 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53352 .48539 m .54127 .47633 L p
.56126 .49912 L 1 g
F P
s
P
p
.002 w
.54166 .47651 m .56126 .49912 L p
.54127 .47633 L 1 g
F P
s
P
p
.002 w
.54248 .47689 m .54174 .47608 L p
.55048 .48464 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55743 .49138 L p
1 g
F P
s
P
p
.54174 .47608 m .55743 .49138 L .55048 .48464 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56126 .49912 m .54166 .47651 L p
.55257 .48153 L 1 g
F P
s
P
p
.002 w
.50211 .46715 m .50425 .46464 L p
.54029 .47586 L 1 g
F P
s
P
p
.50211 .46715 m .54029 .47586 L .54064 .47602 L 1 g
F
P
p
.52214 .46667 m .54253 .47695 L .53338 .47249 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53505 .4689 m .54138 .47619 L p
.54029 .47586 L 1 g
F P
s
P
p
.50425 .46464 m .52243 .46716 L .54029 .47586 L 1 g
F
P
p
.002 w
.52243 .46716 m .52214 .46667 L p
.53338 .47249 L 1 g
F P
s
P
p
.52243 .46716 m .53505 .4689 L .54029 .47586 L 1 g
F
P
p
.002 w
.54138 .47619 m .53352 .48539 L .50211 .46715 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46716 L p
1 g
F P
s
P
p
.53338 .47249 m .54302 .47747 L .52243 .46716 L 1 g
F
P
p
.002 w
.54253 .47695 m .54302 .47747 L p
.53696 .47434 L 1 g
F P
s
P
p
.53338 .47249 m .54127 .47633 L .53696 .47434 L 1 g
F
P
p
.54127 .47633 m .54253 .47695 L .53696 .47434 L 1 g
F
P
p
.002 w
.54127 .47633 m .54138 .47619 L .54166 .47651 L p
1 g
F P
s
P
p
.002 w
.56218 .50099 m .53352 .48539 L p
.56126 .49912 L 1 g
F P
s
P
p
.002 w
.53065 .51797 m .52786 .50751 L .56261 .50185 L p
1 g
F P
s
P
p
.002 w
.56261 .50185 m .5635 .50171 L .56272 .5021 L p
1 g
F P
s
P
p
.002 w
.56272 .5021 m .53065 .51797 L p
.56261 .50185 L 1 g
F P
s
P
p
.56266 .50197 m .56272 .5021 L .56267 .50198 L 1 g
F
P
p
.002 w
.55783 .49184 m .55764 .49166 L p
.56267 .50198 L 1 g
F P
s
P
p
.002 w
.52786 .50751 m .52885 .49623 L .56245 .50154 L p
1 g
F P
s
P
p
.002 w
.56245 .50154 m .5635 .50171 L .56261 .50185 L p
1 g
F P
s
P
p
.002 w
.56261 .50185 m .52786 .50751 L p
.56245 .50154 L 1 g
F P
s
P
p
.002 w
.52885 .49623 m .53352 .48539 L .56218 .50099 L p
1 g
F P
s
P
p
.002 w
.56245 .50154 m .52885 .49623 L p
.56218 .50099 L 1 g
F P
s
P
p
.002 w
.55792 .49193 m .55783 .49184 L p
.56261 .50186 L 1 g
F P
s
P
p
.56261 .50186 m .56283 .50233 L .56267 .50198 L 1 g
F
P
p
.56261 .50186 m .56267 .50198 L .55792 .49193 L 1 g
F
P
p
.002 w
.53687 .52648 m .53065 .51797 L .56272 .5021 L p
1 g
F P
s
P
p
.002 w
.56272 .5021 m .5635 .50171 L .56283 .50233 L p
1 g
F P
s
P
p
.002 w
.56283 .50233 m .53687 .52648 L p
.56272 .5021 L 1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54581 .53214 m .53687 .52648 L .56283 .50233 L p
1 g
F P
s
P
p
.002 w
.56283 .50233 m .5635 .50171 L .56297 .50262 L p
1 g
F P
s
P
p
.002 w
.56297 .50262 m .54581 .53214 L p
.56283 .50233 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .55792 .49193 L p
.56713 .51061 L 1 g
F P
s
P
p
.56321 .50312 m .56713 .51061 L .55792 .49193 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54248 .47689 L p
1 g
F P
s
P
p
.55048 .48464 m .55834 .49233 L .54248 .47689 L 1 g
F
P
p
.002 w
.5565 .53437 m .54581 .53214 L .56297 .50262 L p
1 g
F P
s
P
p
.002 w
.5632 .50311 m .5565 .53437 L p
.56297 .50262 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56155 .54717 L p
1 g
F P
s
P
p
.002 w
.56778 .53297 m .56991 .56035 L p
.56219 .54539 L 1 g
F P
s
P
p
.002 w
.56654 .53312 m .56778 .53297 L p
.56219 .54539 L 1 g
F P
s
P
p
.56654 .52734 m .56155 .54717 L .56437 .53924 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.5472 .565 m .53816 .5873 L p
.53276 .57361 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53664 .57394 L p
.54231 .56792 L 1 g
F P
s
P
p
.54854 .56129 m .54038 .56907 L .54231 .56792 L 1 g
F
P
p
.54038 .56907 m .5322 .57686 L .54231 .56792 L 1 g
F
P
p
.002 w
.56991 .56035 m .56989 .58305 L p
.54888 .56406 L 1 g
F P
s
P
p
.54888 .56406 m .54875 .56394 L .54902 .5639 L 1 g
F
P
p
.54888 .56406 m .54902 .5639 L .56991 .56035 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54937 .56352 L p
1 g
F P
s
P
p
.56075 .54566 m .54937 .56352 L .54989 .56295 L 1 g
F
P
p
.56505 .55093 m .55169 .56051 L .56247 .54593 L 1 g
F
P
p
.56075 .54566 m .54989 .56295 L .55512 .55588 L 1 g
F
P
p
.002 w
.55027 .5629 m .54989 .56295 L p
.56505 .55093 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54854 .56129 L p
.54116 .56914 L 1 g
F P
s
P
p
.002 w
.54989 .56295 m .54793 .5632 L p
.55169 .56051 L 1 g
F P
s
P
p
.54989 .56295 m .55169 .56051 L .56505 .55093 L 1 g
F
P
p
.002 w
.54793 .5632 m .54989 .56295 L p
.54875 .56394 L 1 g
F P
s
P
p
.002 w
.54989 .56295 m .55027 .5629 L p
.54937 .56352 L 1 g
F P
s
P
p
.54875 .56394 m .54989 .56295 L .54937 .56352 L 1 g
F
P
p
.002 w
.55027 .5629 m .56991 .56035 L p
.54875 .56394 L 1 g
F P
s
P
p
.002 w
.56991 .56035 m .55027 .5629 L p
.56505 .55093 L 1 g
F P
s
P
p
.002 w
.56989 .58305 m .53816 .5873 L .54793 .5632 L p
1 g
F P
s
P
p
.55326 .55924 m .54989 .56295 L .54998 .56518 L 1 g
F
P
p
.002 w
.54937 .56352 m .5494 .56361 L p
.54989 .56295 L 1 g
F P
s
P
p
.002 w
.5494 .56361 m .54998 .56518 L p
.54989 .56295 L 1 g
F P
s
P
p
.55512 .55588 m .54989 .56295 L .55326 .55924 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54793 .5632 m .5565 .53437 L p
.56247 .54593 L 1 g
F P
s
P
p
.55169 .56051 m .54793 .5632 L .56247 .54593 L 1 g
F
P
p
.002 w
.5494 .56361 m .54937 .56352 L p
.53664 .57394 L 1 g
F P
s
P
p
.54116 .56914 m .53664 .57394 L .54937 .56352 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52699 .559 m .54793 .5632 L .5472 .565 L p
1 g
F P
s
P
p
.53276 .57361 m .52699 .559 L .5472 .565 L 1 g
F
P
p
.002 w
.53664 .57394 m .54998 .56518 L .5494 .56361 L p
1 g
F P
s
P
p
.002 w
.56155 .54717 m .56257 .5491 L p
.56437 .53924 L 1 g
F P
s
P
p
.002 w
.56778 .53297 m .56654 .53312 L p
.56733 .53004 L 1 g
F P
s
P
p
.56654 .52734 m .56293 .5471 L .56737 .52992 L 1 g
F
P
p
.57543 .52948 m .5677 .5299 L .57028 .51838 L 1 g
F
P
p
.5677 .5299 m .56737 .52992 L .56762 .52891 L 1 g
F
P
p
.5677 .5299 m .56762 .52891 L .57028 .51838 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56762 .52891 L p
1 g
F P
s
P
p
.002 w
.57543 .52948 m .56778 .53297 L .56737 .52992 L p
1 g
F P
s
P
p
.56515 .50826 m .56762 .52891 L .56692 .51973 L 1 g
F
P
p
.002 w
.56762 .52891 m .56654 .52734 L p
.56737 .52992 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56737 .52992 m .5639 .50462 L p
.57028 .51838 L 1 g
F P
s
P
p
.002 w
.56762 .52891 m .56854 .53025 L p
.56692 .51973 L 1 g
F P
s
P
p
.002 w
.56762 .52892 m .56762 .52891 L p
.56737 .52992 L 1 g
F P
s
P
p
.002 w
.5639 .50462 m .56778 .53297 L p
.5632 .50311 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56762 .52892 L p
1 g
F P
s
P
p
.56293 .5471 m .56257 .5491 L .56762 .52892 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.5565 .53437 m .5632 .50311 L p
.56733 .53004 L 1 g
F P
s
P
p
.002 w
.56654 .53312 m .5565 .53437 L p
.56733 .53004 L 1 g
F P
s
P
p
.002 w
.5565 .53437 m .56654 .53312 L p
.56219 .54539 L 1 g
F P
s
P
p
.56319 .50309 m .5639 .50462 L .56321 .50312 L 1 g
F
P
p
.56321 .50312 m .56668 .51008 L .56377 .50419 L 1 g
F
P
p
.56421 .50527 m .56668 .51008 L .56321 .50312 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56613 .50943 L p
1 g
F P
s
P
p
.56692 .51973 m .56854 .53025 L .56613 .50943 L 1 g
F
P
p
.002 w
.56613 .50943 m .56668 .51008 L p
.56421 .50527 L 1 g
F P
s
P
p
.002 w
.56668 .51008 m .56713 .51061 L p
.56377 .50419 L 1 g
F P
s
P
p
.002 w
.55743 .49138 m .55834 .49233 L p
.55048 .48464 L 1 g
F P
s
P
p
.002 w
.55156 .46967 m .55669 .48342 L p
.54213 .47654 L 1 g
F P
s
P
p
.002 w
.54138 .47619 m .54161 .47605 L p
.54213 .47654 L 1 g
F P
s
P
p
.002 w
.54161 .47605 m .55156 .46967 L p
.54213 .47654 L 1 g
F P
s
P
p
.002 w
.54166 .47651 m .54138 .47619 L p
.55669 .48342 L 1 g
F P
s
P
p
.002 w
.54248 .47689 m .54253 .47695 L p
.54177 .47656 L 1 g
F P
s
P
p
.54064 .47602 m .54029 .47586 L .54138 .47619 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46716 L p
1 g
F P
s
P
p
.5 .4634 m .52243 .46716 L .51332 .4659 L 1 g
F
P
p
.5 .4634 m .52274 .46766 L .51897 .46704 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.50211 .46715 m .49753 .46433 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.50425 .46464 m .50211 .46715 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .4634 L p
.51897 .46704 L 1 g
F P
s
P
p
.51897 .46704 m .52282 .46778 L .5 .46395 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.47049 .44768 m .50557 .46309 L .5 .46395 L 1 g
F
P
p
.47786 .46667 m .5 .46395 L .49887 .46412 L 1 g
F
P
p
.47786 .46667 m .5 .46399 L .48844 .46559 L 1 g
F
P
p
.002 w
.49753 .46433 m .4958 .46326 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.4958 .46326 m .47049 .44768 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.50425 .46464 m .51766 .4489 L .53505 .4689 L p
1 g
F P
s
P
p
.002 w
.52243 .46716 m .52274 .46766 L p
.51332 .4659 L 1 g
F P
s
P
p
.002 w
.52274 .46766 m .52282 .46778 L p
.51897 .46704 L 1 g
F P
s
P
p
.002 w
.50557 .46309 m .50425 .46464 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .46399 L p
.49887 .46412 L 1 g
F P
s
P
p
.002 w
.5 .46399 m .5 .46442 L p
.48844 .46559 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47733 .46755 L p
1 g
F P
s
P
p
.002 w
.47733 .46755 m .47718 .46778 L p
.472 .47005 L 1 g
F P
s
P
p
.45826 .47608 m .47733 .46755 L .472 .47005 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.42308 .46839 m .45873 .47571 L .45755 .47686 L 1 g
F
P
p
.44339 .4905 m .45755 .47686 L .45236 .48191 L 1 g
F
P
p
.002 w
.45562 .47873 m .45439 .47834 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.45439 .47834 m .42308 .46839 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.47049 .44768 m .49124 .46046 L p
.4776 .4671 L 1 g
F P
s
P
p
.46741 .47207 m .45842 .47645 L .45755 .47686 L 1 g
F
P
p
.002 w
.45842 .47645 m .46139 .46936 L p
.4776 .4671 L 1 g
F P
s
P
p
.002 w
.46139 .46936 m .47049 .44768 L p
.4776 .4671 L 1 g
F P
s
P
p
.002 w
.49124 .46046 m .49753 .46433 L p
.4776 .4671 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .4671 L p
1 g
F P
s
P
p
.48844 .46559 m .5 .46442 L .4776 .4671 L 1 g
F
P
p
.46741 .47207 m .472 .47005 L .45842 .47645 L 1 g
F
P
p
.002 w
.45724 .47925 m .45842 .47645 L p
.50211 .46715 L 1 g
F P
s
P
p
.002 w
.45873 .47571 m .45842 .47645 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.45842 .47645 m .45724 .47925 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45755 .47686 L p
1 g
F P
s
P
p
.472 .47005 m .47718 .46778 L .45755 .47686 L 1 g
F
P
p
.002 w
.45755 .47686 m .45698 .47747 L p
.45236 .48191 L 1 g
F P
s
P
p
.002 w
.47049 .44768 m .45873 .47571 L p
.42308 .46839 L 1 g
F P
s
P
p
.002 w
.42043 .51028 m .42308 .46839 L .45562 .47873 L p
1 g
F P
s
P
p
.002 w
.44282 .49111 m .44339 .4905 L p
.44988 .48428 L 1 g
F P
s
P
p
.42043 .51028 m .45562 .47873 L .44042 .49342 L 1 g
F
P
p
.002 w
.44282 .49111 m .44166 .49233 L p
.43758 .50188 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44282 .49111 L p
1 g
F P
s
P
p
.44988 .48428 m .45698 .47747 L .44282 .49111 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43396 .50932 L p
1 g
F P
s
P
p
.43758 .50188 m .44166 .49233 L .43396 .50932 L 1 g
F
P
p
.002 w
.43396 .50932 m .43386 .50944 L p
.43384 .51037 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45724 .47925 m .45492 .51186 L .43378 .51089 L p
1 g
F P
s
P
p
.002 w
.43378 .51089 m .45492 .51186 L p
.43279 .52832 L 1 g
F P
s
P
p
.002 w
.43386 .50944 m .43287 .51061 L p
.43323 .52059 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43279 .52832 L p
1 g
F P
s
P
p
.43323 .52059 m .43287 .51061 L .43279 .52832 L 1 g
F
P
p
.43597 .53936 m .43182 .53138 L .43823 .54719 L 1 g
F
P
p
.002 w
.43188 .54854 m .42043 .51028 L .42768 .51061 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45492 .51186 m .46357 .54179 L .43823 .54719 L p
1 g
F P
s
P
p
.4365 .54119 m .45492 .51186 L .43823 .54719 L 1 g
F
P
p
.002 w
.43146 .53025 m .43182 .53138 L p
.43597 .53936 L 1 g
F P
s
P
p
.43584 .53892 m .43146 .53025 L .43597 .53936 L 1 g
F
P
p
.45146 .56129 m .43832 .54742 L .44576 .55634 L 1 g
F
P
p
.002 w
.43814 .54721 m .46357 .54179 L p
.45066 .5622 L 1 g
F P
s
P
p
.002 w
.43182 .53138 m .43743 .5491 L .43832 .54742 L p
1 g
F P
s
P
p
.002 w
.43832 .54742 m .43743 .5491 L p
.44576 .55634 L 1 g
F P
s
P
p
.4581 .56762 m .45066 .5622 L .46357 .54179 L 1 g
F
P
p
.002 w
.43284 .54978 m .43188 .54854 L p
.4581 .56762 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45098 .56259 L p
1 g
F P
s
P
p
.44576 .55634 m .43743 .5491 L .45098 .56259 L 1 g
F
P
p
.48883 .59876 m .46652 .57356 L .48564 .58352 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46825 .57479 L p
1 g
F P
s
P
p
.002 w
.46825 .57479 m .46832 .5745 L p
.46661 .57363 L 1 g
F P
s
P
p
.46661 .57363 m .45002 .56518 L .46825 .57479 L 1 g
F
P
p
.46066 .56943 m .45165 .56583 L .46652 .57356 L 1 g
F
P
p
.46066 .56943 m .46652 .57356 L .46832 .5745 L 1 g
F
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.46357 .54179 m .48193 .56578 L .46652 .57356 L p
1 g
F P
s
P
p
.4581 .56762 m .46357 .54179 L .46652 .57356 L 1 g
F
P
p
.002 w
.46652 .57356 m .48193 .56578 L p
.48564 .58352 L 1 g
F P
s
P
p
.45165 .56583 m .45002 .56518 L .46832 .5745 L 1 g
F
P
p
.002 w
.46832 .5745 m .4678 .57686 L p
.48107 .57795 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58012 L p
1 g
F P
s
P
p
.48107 .57795 m .4678 .57686 L .4891 .58012 L 1 g
F
P
p
.002 w
.48889 .583 m .49225 .583 L p
.50108 .58091 L 1 g
F P
s
P
p
.49975 .58083 m .48889 .583 L .50108 .58091 L 1 g
F
P
p
.002 w
.53163 .57428 m .5322 .57686 L p
.54038 .56907 L 1 g
F P
s
P
p
.002 w
.51097 .58101 m .51098 .58119 L p
.51294 .58037 L 1 g
F P
s
P
p
.002 w
.51098 .58119 m .51111 .583 L p
.51767 .57963 L 1 g
F P
s
P
p
.002 w
.58396 .27885 m .52395 .27304 L .51407 .25457 L p
1 g
F P
s
P
p
.002 w
.45004 .27007 m .51407 .25457 L .52395 .27304 L p
1 g
F P
s
P
p
.002 w
.36534 .37267 m .3418 .43161 L .3246 .41949 L p
1 g
F P
s
P
p
.002 w
.3246 .41949 m .34893 .35806 L .36534 .37267 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51637 .44886 L
s
P
p
.002 w
.63696 .32506 m .58906 .30199 L .58396 .27885 L p
1 g
F P
s
P
p
.002 w
.52395 .27304 m .58396 .27885 L .58906 .30199 L p
1 g
F P
s
P
p
.002 w
.66578 .38326 m .63433 .34995 L .63696 .32506 L p
1 g
F P
s
P
p
.002 w
.58906 .30199 m .63696 .32506 L .63433 .34995 L p
1 g
F P
s
P
p
.002 w
.66912 .44155 m .65429 .40589 L .66578 .38326 L p
1 g
F P
s
P
p
.002 w
.63433 .34995 m .66578 .38326 L .65429 .40589 L p
1 g
F P
s
P
p
.002 w
.36437 .4441 m .36158 .50013 L .33909 .49209 L p
1 g
F P
s
P
p
.002 w
.33909 .49209 m .3418 .43161 L .36437 .4441 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.38896 .50629 m .40293 .5516 L .37766 .551 L p
1 g
F P
s
P
p
.002 w
.37766 .551 m .36158 .50013 L .38896 .50629 L p
1 g
F P
s
P
p
.002 w
.43188 .54854 m .45568 .57904 L .43144 .58754 L p
1 g
F P
s
P
p
.002 w
.43144 .58754 m .40293 .5516 L .43188 .54854 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.59065 .55083 m .60805 .53565 L .62482 .54741 L p
1 g
F P
s
P
p
.002 w
.62482 .54741 m .59976 .56927 L .59065 .55083 L p
1 g
F P
s
P
p
.002 w
.64257 .51966 m .62482 .54741 L .60805 .53565 L p
1 g
F P
s
P
p
.002 w
.56991 .56035 m .59065 .55083 L .59976 .56927 L p
1 g
F P
s
P
p
.002 w
.59976 .56927 m .56989 .58305 L .56991 .56035 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.65118 .48873 m .64961 .45774 L .66912 .44155 L p
1 g
F P
s
P
p
.002 w
.65429 .40589 m .66912 .44155 L .64961 .45774 L p
1 g
F P
s
P
p
.002 w
.60805 .53565 m .62034 .51637 L .64257 .51966 L p
1 g
F P
s
P
p
.002 w
.65118 .48873 m .64257 .51966 L .62034 .51637 L p
1 g
F P
s
P
p
.002 w
.52395 .27304 m .4625 .2881 L .45004 .27007 L p
1 g
F P
s
P
p
.002 w
.39254 .30602 m .45004 .27007 L .4625 .2881 L p
1 g
F P
s
P
p
.002 w
.40729 .32271 m .36534 .37267 L .34893 .35806 L p
1 g
F P
s
P
p
.002 w
.34893 .35806 m .39254 .30602 L .40729 .32271 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.4625 .2881 m .40729 .32271 L .39254 .30602 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62034 .51637 m .62621 .49494 L .65118 .48873 L p
1 g
F P
s
P
p
.002 w
.64961 .45774 m .65118 .48873 L .62621 .49494 L p
1 g
F P
s
P
p
.002 w
.58906 .30199 m .53343 .2969 L .52395 .27304 L p
1 g
F P
s
P
p
.002 w
.4625 .2881 m .52395 .27304 L .53343 .2969 L p
1 g
F P
s
P
p
.002 w
.38639 .38953 m .36437 .4441 L .3418 .43161 L p
1 g
F P
s
P
p
.002 w
.3418 .43161 m .36534 .37267 L .38639 .38953 L p
1 g
F P
s
P
p
.002 w
.65429 .40589 m .62754 .37801 L .63433 .34995 L p
1 g
F P
s
P
p
.002 w
.59162 .32975 m .63433 .34995 L .62754 .37801 L p
1 g
F P
s
P
p
.002 w
.63433 .34995 m .59162 .32975 L .58906 .30199 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53343 .2969 m .58906 .30199 L .59162 .32975 L p
1 g
F P
s
P
p
.002 w
.64961 .45774 m .63778 .42991 L .65429 .40589 L p
1 g
F P
s
P
p
.002 w
.62754 .37801 m .65429 .40589 L .63778 .42991 L p
1 g
F P
s
P
p
.002 w
.42043 .51028 m .43188 .54854 L .40293 .5516 L p
1 g
F P
s
P
p
.002 w
.40293 .5516 m .38896 .50629 L .42043 .51028 L p
1 g
F P
s
P
p
.002 w
.39175 .45652 m .38896 .50629 L .36158 .50013 L p
1 g
F P
s
P
p
.002 w
.36158 .50013 m .36437 .4441 L .39175 .45652 L p
1 g
F P
s
P
p
.002 w
.62621 .49494 m .62498 .47356 L .64961 .45774 L p
1 g
F P
s
P
p
.002 w
.63778 .42991 m .64961 .45774 L .62498 .47356 L p
1 g
F P
s
P
p
.002 w
.57846 .5281 m .58742 .52028 L .60805 .53565 L p
1 g
F P
s
P
p
.002 w
.60805 .53565 m .59065 .55083 L .57846 .5281 L p
1 g
F P
s
P
p
.002 w
.62034 .51637 m .60805 .53565 L .58742 .52028 L p
1 g
F P
s
P
p
.002 w
.56778 .53297 m .57846 .5281 L .59065 .55083 L p
1 g
F P
s
P
p
.002 w
.59065 .55083 m .56991 .56035 L .56778 .53297 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.58742 .52028 m .59371 .51035 L .62034 .51637 L p
1 g
F P
s
P
p
.002 w
.62621 .49494 m .62034 .51637 L .59371 .51035 L p
1 g
F P
s
P
p
.002 w
.53343 .2969 m .47651 .31108 L .4625 .2881 L p
1 g
F P
s
P
p
.002 w
.40729 .32271 m .4625 .2881 L .47651 .31108 L p
1 g
F P
s
P
p
.004 w
.41658 .28065 m
.42315 .29245 L
s
P
p
.002 w
.42535 .34324 m .38639 .38953 L .36534 .37267 L p
1 g
F P
s
P
p
.002 w
.36534 .37267 m .40729 .32271 L .42535 .34324 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.47651 .31108 m .42535 .34324 L .40729 .32271 L p
1 g
F P
s
P
p
.002 w
.59371 .51035 m .59667 .49934 L .62621 .49494 L p
1 g
F P
s
P
p
.002 w
.62498 .47356 m .62621 .49494 L .59667 .49934 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.54581 .53214 m .5565 .53437 L .54793 .5632 L p
1 g
F P
s
P
p
.002 w
.54793 .5632 m .52699 .559 L .54581 .53214 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.63778 .42991 m .61668 .40833 L .62754 .37801 L p
1 g
F P
s
P
p
.002 w
.59142 .3613 m .62754 .37801 L .61668 .40833 L p
1 g
F P
s
P
p
.002 w
.62754 .37801 m .59142 .3613 L .59162 .32975 L p
1 g
F P
s
P
p
.002 w
.62498 .47356 m .61667 .45449 L .63778 .42991 L p
1 g
F P
s
P
p
.002 w
.61668 .40833 m .63778 .42991 L .61667 .45449 L p
1 g
F P
s
P
p
.002 w
.59162 .32975 m .54214 .32554 L .53343 .2969 L p
1 g
F P
s
P
p
.002 w
.47651 .31108 m .53343 .2969 L .54214 .32554 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49691 .53149 m .50933 .54808 L .48193 .56578 L p
1 g
F P
s
P
p
.002 w
.48193 .56578 m .46357 .54179 L .49691 .53149 L p
1 g
F P
s
P
p
.002 w
.41152 .4081 m .39175 .45652 L .36437 .4441 L p
1 g
F P
s
P
p
.002 w
.36437 .4441 m .38639 .38953 L .41152 .4081 L p
1 g
F P
s
P
p
.002 w
.54214 .32554 m .59162 .32975 L .59142 .3613 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42308 .46839 m .42043 .51028 L .38896 .50629 L p
1 g
F P
s
P
p
.002 w
.38896 .50629 m .39175 .45652 L .42308 .46839 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.59667 .49934 m .59596 .48841 L .62498 .47356 L p
1 g
F P
s
P
p
.002 w
.61667 .45449 m .62498 .47356 L .59596 .48841 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.53687 .52648 m .54581 .53214 L .52699 .559 L p
1 g
F P
s
P
p
.002 w
.52699 .559 m .50933 .54808 L .53687 .52648 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58742 .52028 m .57846 .5281 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.59371 .51035 m .58742 .52028 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59667 .49934 m .59371 .51035 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.54214 .32554 m .49162 .33836 L .47651 .31108 L p
1 g
F P
s
P
p
.002 w
.42535 .34324 m .47651 .31108 L .49162 .33836 L p
1 g
F P
s
P
p
.004 w
.44822 .3375 m
.44864 .33825 L
s
P
p
.004 w
.45039 .3414 m
.5 .43051 L
s
P
p
.004 w
.44612 .33372 m
.44822 .3375 L
s
P
p
.004 w
.43492 .3136 m
.44612 .33372 L
s
P
p
.004 w
.42315 .29245 m
.43492 .3136 L
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4462 .36702 m .41152 .4081 L .38639 .38953 L p
1 g
F P
s
P
p
.002 w
.38639 .38953 m .42535 .34324 L .4462 .36702 L p
1 g
F P
s
P
p
.002 w
.59596 .48841 m .59162 .47873 L .61667 .45449 L p
1 g
F P
s
P
p
.002 w
.60204 .43984 m .61667 .45449 L .59162 .47873 L p
1 g
F P
s
P
p
.002 w
.61667 .45449 m .60204 .43984 L .61668 .40833 L p
1 g
F P
s
P
p
.002 w
.58838 .39556 m .61668 .40833 L .60204 .43984 L p
1 g
F P
s
P
p
.002 w
.61668 .40833 m .58838 .39556 L .59142 .3613 L p
1 g
F P
s
P
p
.002 w
.59596 .48841 m .59667 .49934 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.53065 .51797 m .53687 .52648 L .50933 .54808 L p
1 g
F P
s
P
p
.002 w
.50933 .54808 m .49691 .53149 L .53065 .51797 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.4912 .51094 m .49691 .53149 L .46357 .54179 L p
1 g
F P
s
P
p
.002 w
.46357 .54179 m .45492 .51186 L .4912 .51094 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49162 .33836 m .4462 .36702 L .42535 .34324 L p
1 g
F P
s
P
p
.002 w
.54974 .35805 m .59142 .3613 L .58838 .39556 L p
1 g
F P
s
P
p
.002 w
.59142 .3613 m .54974 .35805 L .54214 .32554 L p
1 g
F P
s
P
p
.002 w
.49162 .33836 m .54214 .32554 L .54974 .35805 L p
1 g
F P
s
P
p
.002 w
.59162 .47873 m .59596 .48841 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.4399 .42773 m .42308 .46839 L .39175 .45652 L p
1 g
F P
s
P
p
.002 w
.39175 .45652 m .41152 .4081 L .4399 .42773 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5841 .47137 m .59162 .47873 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.59162 .47873 m .5841 .47137 L .60204 .43984 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.58257 .43129 m .60204 .43984 L .5841 .47137 L p
1 g
F P
s
P
p
.002 w
.60204 .43984 m .58257 .43129 L .58838 .39556 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.52786 .50751 m .53065 .51797 L .49691 .53149 L p
1 g
F P
s
P
p
.002 w
.49691 .53149 m .4912 .51094 L .52786 .50751 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57417 .46714 m .5841 .47137 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.56291 .46654 m .57417 .46714 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.55156 .46967 m .56291 .46654 L .5635 .50171 L closepath p
1 g
F P
s
P
p
.002 w
.5559 .39329 m .58838 .39556 L .58257 .43129 L p
1 g
F P
s
P
p
.002 w
.58838 .39556 m .5559 .39329 L .54974 .35805 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.5841 .47137 m .57417 .46714 L .58257 .43129 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.49296 .48865 m .4912 .51094 L .45492 .51186 L p
1 g
F P
s
P
p
.002 w
.45492 .51186 m .45724 .47925 L .49296 .48865 L p
1 g
F P
s
P
p
.002 w
.54974 .35805 m .50728 .36905 L .49162 .33836 L p
1 g
F P
s
P
p
.002 w
.4462 .36702 m .49162 .33836 L .50728 .36905 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46912 .39322 m .4399 .42773 L .41152 .4081 L p
1 g
F P
s
P
p
.002 w
.41152 .4081 m .4462 .36702 L .46912 .39322 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.004 w
.5635 .50171 m
.56392 .50217 L
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.004 w
.56469 .50304 m
.56553 .50398 L
s
P
p
.002 w
.50728 .36905 m .54974 .35805 L .5559 .39329 L p
1 g
F P
s
P
p
.002 w
.42308 .46839 m .4399 .42773 L .47049 .44768 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.50728 .36905 m .46912 .39322 L .4462 .36702 L p
1 g
F P
s
P
p
.002 w
.57417 .46714 m .56291 .46654 L .56035 .42993 L p
1 g
F P
s
P
p
.002 w
.56035 .42993 m .58257 .43129 L .57417 .46714 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.58257 .43129 m .56035 .42993 L .5559 .39329 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52885 .49623 m .52786 .50751 L .4912 .51094 L p
1 g
F P
s
P
p
.002 w
.4912 .51094 m .49296 .48865 L .52885 .49623 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.004 w
.56553 .50398 m
.56577 .50425 L
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.56291 .46654 m .55156 .46967 L .53785 .43601 L p
1 g
F P
s
P
p
.002 w
.53785 .43601 m .56035 .42993 L .56291 .46654 L p
1 g
F P
s
P
p
.002 w
.53352 .48539 m .52885 .49623 L .49296 .48865 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.5229 .40202 m .5559 .39329 L .56035 .42993 L p
1 g
F P
s
P
p
.002 w
.5559 .39329 m .5229 .40202 L .50728 .36905 L p
1 g
F P
s
P
p
.002 w
.50211 .46715 m .49296 .48865 L .45724 .47925 L p
1 g
F P
s
P
p
.002 w
.55156 .46967 m .54138 .47619 L .51766 .4489 L p
1 g
F P
s
P
p
.002 w
.51766 .4489 m .53785 .43601 L .55156 .46967 L p
1 g
F P
s
P
p
.002 w
.49296 .48865 m .50211 .46715 L .53352 .48539 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.46912 .39322 m .50728 .36905 L .5229 .40202 L p
1 g
F P
s
P
p
.002 w
.56035 .42993 m .53785 .43601 L .5229 .40202 L p
1 g
F P
s
P
p
.002 w
.49325 .42087 m .47049 .44768 L .4399 .42773 L p
1 g
F P
s
P
p
.002 w
.4399 .42773 m .46912 .39322 L .49325 .42087 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.004 w
.56655 .50513 m
.56765 .50635 L
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.004 w
.56843 .50723 m
.56994 .50892 L
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5229 .40202 m .49325 .42087 L .46912 .39322 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53785 .43601 m .51766 .4489 L .49325 .42087 L p
1 g
F P
s
P
p
.002 w
.49325 .42087 m .5229 .40202 L .53785 .43601 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47049 .44768 m .49325 .42087 L .51766 .4489 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.004 w
.57032 .50935 m
.57143 .5106 L
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.004 w
.57223 .51149 m
.57334 .51274 L
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.004 w
.57415 .51364 m
.57527 .5149 L
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.004 w
.57608 .51581 m
.57721 .51708 L
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.57803 .51799 m
.57917 .51927 L
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.004 w
.57999 .52019 m
.58114 .52148 L
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.58312 .5237 m
.60214 .54502 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .41658 .28065 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60214 .54502 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0626316)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0626316)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47296 .46539 m .50467 .45098 L .4893 .4269 L p
1 g
F P
s
P
p
.002 w
.4893 .4269 m .46472 .438 L .47296 .46539 L p
1 g
F P
s
P
p
.002 w
.50987 .40927 m .4893 .4269 L .50467 .45098 L p
1 g
F P
s
P
p
.002 w
.46472 .438 m .4893 .4269 L .47415 .40287 L p
1 g
F P
s
P
p
.002 w
.4893 .4269 m .50987 .40927 L .48821 .3908 L p
1 g
F P
s
P
p
.002 w
.48821 .3908 m .47415 .40287 L .4893 .4269 L p
1 g
F P
s
P
p
.002 w
.48191 .49209 m .52 .47466 L .50467 .45098 L p
1 g
F P
s
P
p
.002 w
.50467 .45098 m .47296 .46539 L .48191 .49209 L p
1 g
F P
s
P
p
.002 w
.53125 .42823 m .50467 .45098 L .52 .47466 L p
1 g
F P
s
P
p
.002 w
.50467 .45098 m .53125 .42823 L .50987 .40927 L p
1 g
F P
s
P
p
.002 w
.52437 .38685 m .50987 .40927 L .53125 .42823 L p
1 g
F P
s
P
p
.002 w
.50987 .40927 m .52437 .38685 L .49806 .37544 L p
1 g
F P
s
P
p
.002 w
.49806 .37544 m .48821 .3908 L .50987 .40927 L p
1 g
F P
s
P
p
.002 w
.52 .47466 m .55199 .44734 L .53125 .42823 L p
1 g
F P
s
P
p
.002 w
.55012 .39933 m .53125 .42823 L .55199 .44734 L p
1 g
F P
s
P
p
.002 w
.53125 .42823 m .55012 .39933 L .52437 .38685 L p
1 g
F P
s
P
p
.002 w
.43918 .47 m .47296 .46539 L .46472 .438 L p
1 g
F P
s
P
p
.002 w
.46472 .438 m .43857 .44142 L .43918 .47 L p
1 g
F P
s
P
p
.002 w
.43857 .44142 m .46472 .438 L .45733 .41042 L p
1 g
F P
s
P
p
.002 w
.47415 .40287 m .45733 .41042 L .46472 .438 L p
1 g
F P
s
P
p
.002 w
.45733 .41042 m .47415 .40287 L .45951 .37931 L p
1 g
F P
s
P
p
.002 w
.47415 .40287 m .48821 .3908 L .46667 .37315 L p
1 g
F P
s
P
p
.002 w
.46667 .37315 m .45951 .37931 L .47415 .40287 L p
1 g
F P
s
P
p
.002 w
.48821 .3908 m .49806 .37544 L .47165 .36531 L p
1 g
F P
s
P
p
.002 w
.47165 .36531 m .46667 .37315 L .48821 .3908 L p
1 g
F P
s
P
p
.002 w
.44128 .49786 m .48191 .49209 L .47296 .46539 L p
1 g
F P
s
P
p
.002 w
.47296 .46539 m .43918 .47 L .44128 .49786 L p
1 g
F P
s
P
p
.002 w
.45733 .41042 m .43946 .41265 L .43857 .44142 L p
1 g
F P
s
P
p
.002 w
.43946 .41265 m .45733 .41042 L .45093 .38313 L p
1 g
F P
s
P
p
.002 w
.45951 .37931 m .45093 .38313 L .45733 .41042 L p
1 g
F P
s
P
p
.002 w
.4914 .5176 m .53501 .49752 L .52 .47466 L p
1 g
F P
s
P
p
.002 w
.52 .47466 m .48191 .49209 L .4914 .5176 L p
1 g
F P
s
P
p
.002 w
.55199 .44734 m .52 .47466 L .53501 .49752 L p
1 g
F P
s
P
p
.002 w
.53128 .36184 m .52437 .38685 L .55012 .39933 L p
1 g
F P
s
P
p
.002 w
.52437 .38685 m .53128 .36184 L .50265 .35834 L p
1 g
F P
s
P
p
.002 w
.50265 .35834 m .49806 .37544 L .52437 .38685 L p
1 g
F P
s
P
p
.002 w
.53501 .49752 m .57168 .46624 L .55199 .44734 L p
1 g
F P
s
P
p
.002 w
.57482 .41266 m .55199 .44734 L .57168 .46624 L p
1 g
F P
s
P
p
.002 w
.55199 .44734 m .57482 .41266 L .55012 .39933 L p
1 g
F P
s
P
p
.002 w
.49806 .37544 m .50265 .35834 L .47393 .3566 L p
1 g
F P
s
P
p
.002 w
.47393 .3566 m .47165 .36531 L .49806 .37544 L p
1 g
F P
s
P
p
.002 w
.55929 .36704 m .55012 .39933 L .57482 .41266 L p
1 g
F P
s
P
p
.002 w
.55012 .39933 m .55929 .36704 L .53128 .36184 L p
1 g
F P
s
P
p
.002 w
.40664 .46415 m .43918 .47 L .43857 .44142 L p
1 g
F P
s
P
p
.002 w
.43857 .44142 m .41348 .43669 L .40664 .46415 L p
1 g
F P
s
P
p
.002 w
.41348 .43669 m .43857 .44142 L .43946 .41265 L p
1 g
F P
s
P
p
.002 w
.43946 .41265 m .42239 .40928 L .41348 .43669 L p
1 g
F P
s
P
p
.002 w
.42239 .40928 m .43946 .41265 L .44183 .38422 L p
1 g
F P
s
P
p
.002 w
.45093 .38313 m .44183 .38422 L .43946 .41265 L p
1 g
F P
s
P
p
.002 w
.44486 .52445 m .4914 .5176 L .48191 .49209 L p
1 g
F P
s
P
p
.002 w
.48191 .49209 m .44128 .49786 L .44486 .52445 L p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .45093 .38313 L .45951 .37931 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .45951 .37931 L .46667 .37315 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .46667 .37315 L .47165 .36531 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .44183 .38422 L .45093 .38313 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .47165 .36531 L .47393 .3566 L closepath p
1 g
F P
s
P
p
.002 w
.50144 .34128 m .50265 .35834 L .53128 .36184 L p
1 g
F P
s
P
p
.002 w
.50265 .35834 m .50144 .34128 L .47323 .34796 L p
1 g
F P
s
P
p
.002 w
.47323 .34796 m .47393 .3566 L .50265 .35834 L p
1 g
F P
s
P
p
.002 w
.40203 .49113 m .44128 .49786 L .43918 .47 L p
1 g
F P
s
P
p
.002 w
.43918 .47 m .40664 .46415 L .40203 .49113 L p
1 g
F P
s
P
p
.002 w
.44183 .38422 m .43318 .38244 L .42239 .40928 L p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .43318 .38244 L .44183 .38422 L closepath p
1 g
F P
s
P
p
.002 w
.52974 .33677 m .53128 .36184 L .55929 .36704 L p
1 g
F P
s
P
p
.002 w
.53128 .36184 m .52974 .33677 L .50144 .34128 L p
1 g
F P
s
P
p
.002 w
.50128 .5414 m .5494 .51912 L .53501 .49752 L p
1 g
F P
s
P
p
.002 w
.53501 .49752 m .4914 .5176 L .50128 .5414 L p
1 g
F P
s
P
p
.002 w
.57168 .46624 m .53501 .49752 L .5494 .51912 L p
1 g
F P
s
P
p
.002 w
.57168 .46624 m .598 .42661 L .57482 .41266 L p
1 g
F P
s
P
p
.002 w
.58613 .37386 m .57482 .41266 L .598 .42661 L p
1 g
F P
s
P
p
.002 w
.57482 .41266 m .58613 .37386 L .55929 .36704 L p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .47393 .3566 L .47323 .34796 L closepath p
1 g
F P
s
P
p
.002 w
.5494 .51912 m .58995 .48459 L .57168 .46624 L p
1 g
F P
s
P
p
.002 w
.598 .42661 m .57168 .46624 L .58995 .48459 L p
1 g
F P
s
P
p
.002 w
.39208 .42413 m .41348 .43669 L .42239 .40928 L p
1 g
F P
s
P
p
.002 w
.42239 .40928 m .40792 .40059 L .39208 .42413 L p
1 g
F P
s
P
p
.002 w
.40792 .40059 m .42239 .40928 L .43318 .38244 L p
1 g
F P
s
P
p
.002 w
.43318 .38244 m .42589 .37795 L .40792 .40059 L p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .42589 .37795 L .43318 .38244 L closepath p
1 g
F P
s
P
p
.002 w
.37872 .44814 m .40664 .46415 L .41348 .43669 L p
1 g
F P
s
P
p
.002 w
.41348 .43669 m .39208 .42413 L .37872 .44814 L p
1 g
F P
s
P
p
.002 w
.46961 .3403 m .47323 .34796 L .50144 .34128 L p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .47323 .34796 L .46961 .3403 L closepath p
1 g
F P
s
P
p
.002 w
.5576 .33454 m .55929 .36704 L .58613 .37386 L p
1 g
F P
s
P
p
.002 w
.55929 .36704 m .5576 .33454 L .52974 .33677 L p
1 g
F P
s
P
p
.002 w
.44989 .54923 m .50128 .5414 L .4914 .5176 L p
1 g
F P
s
P
p
.002 w
.4914 .5176 m .44486 .52445 L .44989 .54923 L p
1 g
F P
s
P
p
.002 w
.49445 .32607 m .50144 .34128 L .52974 .33677 L p
1 g
F P
s
P
p
.002 w
.50144 .34128 m .49445 .32607 L .46961 .3403 L p
1 g
F P
s
P
p
.002 w
.39978 .51708 m .44486 .52445 L .44128 .49786 L p
1 g
F P
s
P
p
.002 w
.44128 .49786 m .40203 .49113 L .39978 .51708 L p
1 g
F P
s
P
p
.002 w
.39765 .38739 m .40792 .40059 L .42589 .37795 L p
1 g
F P
s
P
p
.002 w
.42589 .37795 m .42078 .37123 L .39765 .38739 L p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .42078 .37123 L .42589 .37795 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .42896 .33826 L .42272 .34552 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .42272 .34552 L .41908 .35408 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .41908 .35408 L .41841 .36297 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .41841 .36297 L .42078 .37123 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .46961 .3403 L .46343 .33447 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .46343 .33447 L .45535 .33112 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .45535 .33112 L .44624 .33064 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .44624 .33064 L .43711 .33311 L closepath p
1 g
F P
s
P
p
.002 w
.44565 .35666 m .43711 .33311 L .42896 .33826 L closepath p
1 g
F P
s
P
p
.002 w
.46343 .33447 m .46961 .3403 L .49445 .32607 L p
1 g
F P
s
P
p
.002 w
.37675 .40486 m .39208 .42413 L .40792 .40059 L p
1 g
F P
s
P
p
.002 w
.40792 .40059 m .39765 .38739 L .37675 .40486 L p
1 g
F P
s
P
p
.002 w
.58995 .48459 m .61919 .44091 L .598 .42661 L p
1 g
F P
s
P
p
.002 w
.61127 .3822 m .598 .42661 L .61919 .44091 L p
1 g
F P
s
P
p
.002 w
.598 .42661 m .61127 .3822 L .58613 .37386 L p
1 g
F P
s
P
p
.002 w
.51971 .31428 m .52974 .33677 L .5576 .33454 L p
1 g
F P
s
P
p
.002 w
.52974 .33677 m .51971 .31428 L .49445 .32607 L p
1 g
F P
s
P
p
.002 w
.39279 .37106 m .39765 .38739 L .42078 .37123 L p
1 g
F P
s
P
p
.002 w
.42078 .37123 m .41841 .36297 L .39279 .37106 L p
1 g
F P
s
P
p
.002 w
.36817 .47214 m .40203 .49113 L .40664 .46415 L p
1 g
F P
s
P
p
.002 w
.40664 .46415 m .37872 .44814 L .36817 .47214 L p
1 g
F P
s
P
p
.002 w
.51135 .56298 m .56289 .53899 L .5494 .51912 L p
1 g
F P
s
P
p
.002 w
.5494 .51912 m .50128 .5414 L .51135 .56298 L p
1 g
F P
s
P
p
.002 w
.58995 .48459 m .5494 .51912 L .56289 .53899 L p
1 g
F P
s
P
p
.002 w
.49445 .32607 m .48235 .31439 L .46343 .33447 L p
1 g
F P
s
P
p
.002 w
.45535 .33112 m .46343 .33447 L .48235 .31439 L p
1 g
F P
s
P
p
.002 w
.58445 .33467 m .58613 .37386 L .61127 .3822 L p
1 g
F P
s
P
p
.002 w
.58613 .37386 m .58445 .33467 L .5576 .33454 L p
1 g
F P
s
P
p
.002 w
.48235 .31439 m .49445 .32607 L .51971 .31428 L p
1 g
F P
s
P
p
.002 w
.56289 .53899 m .60638 .50201 L .58995 .48459 L p
1 g
F P
s
P
p
.002 w
.61919 .44091 m .58995 .48459 L .60638 .50201 L p
1 g
F P
s
P
p
.002 w
.39398 .35335 m .39279 .37106 L .41841 .36297 L p
1 g
F P
s
P
p
.002 w
.41841 .36297 m .41908 .35408 L .39398 .35335 L p
1 g
F P
s
P
p
.002 w
.35855 .42331 m .37872 .44814 L .39208 .42413 L p
1 g
F P
s
P
p
.002 w
.39208 .42413 m .37675 .40486 L .35855 .42331 L p
1 g
F P
s
P
p
.002 w
.40003 .54143 m .44989 .54923 L .44486 .52445 L p
1 g
F P
s
P
p
.002 w
.44486 .52445 m .39978 .51708 L .40003 .54143 L p
1 g
F P
s
P
p
.002 w
.48235 .31439 m .46635 .3076 L .45535 .33112 L p
1 g
F P
s
P
p
.002 w
.44624 .33064 m .45535 .33112 L .46635 .3076 L p
1 g
F P
s
P
p
.002 w
.45632 .57163 m .51135 .56298 L .50128 .5414 L p
1 g
F P
s
P
p
.002 w
.50128 .5414 m .44989 .54923 L .45632 .57163 L p
1 g
F P
s
P
p
.002 w
.36935 .38081 m .37675 .40486 L .39765 .38739 L p
1 g
F P
s
P
p
.002 w
.39765 .38739 m .39279 .37106 L .36935 .38081 L p
1 g
F P
s
P
p
.002 w
.40118 .33625 m .39398 .35335 L .41908 .35408 L p
1 g
F P
s
P
p
.002 w
.41908 .35408 m .42272 .34552 L .40118 .33625 L p
1 g
F P
s
P
p
.002 w
.54488 .30521 m .5576 .33454 L .58445 .33467 L p
1 g
F P
s
P
p
.002 w
.5576 .33454 m .54488 .30521 L .51971 .31428 L p
1 g
F P
s
P
p
.002 w
.46635 .3076 m .4482 .30654 L .44624 .33064 L p
1 g
F P
s
P
p
.002 w
.43711 .33311 m .44624 .33064 L .4482 .30654 L p
1 g
F P
s
P
p
.002 w
.41363 .32171 m .40118 .33625 L .42272 .34552 L p
1 g
F P
s
P
p
.002 w
.42272 .34552 m .42896 .33826 L .41363 .32171 L p
1 g
F P
s
P
p
.002 w
.36074 .49563 m .39978 .51708 L .40203 .49113 L p
1 g
F P
s
P
p
.002 w
.40203 .49113 m .36817 .47214 L .36074 .49563 L p
1 g
F P
s
P
p
.002 w
.4482 .30654 m .42993 .31141 L .43711 .33311 L p
1 g
F P
s
P
p
.002 w
.42896 .33826 m .43711 .33311 L .42993 .31141 L p
1 g
F P
s
P
p
.002 w
.42993 .31141 m .41363 .32171 L .42896 .33826 L p
1 g
F P
s
P
p
.002 w
.51971 .31428 m .50203 .29687 L .48235 .31439 L p
1 g
F P
s
P
p
.002 w
.46635 .3076 m .48235 .31439 L .50203 .29687 L p
1 g
F P
s
P
p
.002 w
.50203 .29687 m .51971 .31428 L .54488 .30521 L p
1 g
F P
s
P
p
.002 w
.60638 .50201 m .63789 .4553 L .61919 .44091 L p
1 g
F P
s
P
p
.002 w
.63415 .39194 m .61919 .44091 L .63789 .4553 L p
1 g
F P
s
P
p
.002 w
.61919 .44091 m .63415 .39194 L .61127 .3822 L p
1 g
F P
s
P
p
.002 w
.60973 .33722 m .61127 .3822 L .63415 .39194 L p
1 g
F P
s
P
p
.002 w
.61127 .3822 m .60973 .33722 L .58445 .33467 L p
1 g
F P
s
P
p
.002 w
.34354 .44239 m .36817 .47214 L .37872 .44814 L p
1 g
F P
s
P
p
.002 w
.37872 .44814 m .35855 .42331 L .34354 .44239 L p
1 g
F P
s
P
p
.002 w
.37094 .35457 m .36935 .38081 L .39279 .37106 L p
1 g
F P
s
P
p
.002 w
.39279 .37106 m .39398 .35335 L .37094 .35457 L p
1 g
F P
s
P
p
.002 w
.52143 .58181 m .57517 .55668 L .56289 .53899 L p
1 g
F P
s
P
p
.002 w
.56289 .53899 m .51135 .56298 L .52143 .58181 L p
1 g
F P
s
P
p
.002 w
.60638 .50201 m .56289 .53899 L .57517 .55668 L p
1 g
F P
s
P
p
.002 w
.34865 .39208 m .35855 .42331 L .37675 .40486 L p
1 g
F P
s
P
p
.002 w
.37675 .40486 m .36935 .38081 L .34865 .39208 L p
1 g
F P
s
P
p
.002 w
.50203 .29687 m .47846 .28663 L .46635 .3076 L p
1 g
F P
s
P
p
.002 w
.4482 .30654 m .46635 .3076 L .47846 .28663 L p
1 g
F P
s
P
p
.002 w
.56945 .29913 m .58445 .33467 L .60973 .33722 L p
1 g
F P
s
P
p
.002 w
.58445 .33467 m .56945 .29913 L .54488 .30521 L p
1 g
F P
s
P
p
.002 w
.57517 .55668 m .62059 .51811 L .60638 .50201 L p
1 g
F P
s
P
p
.002 w
.63789 .4553 m .60638 .50201 L .62059 .51811 L p
1 g
F P
s
P
p
.002 w
.40285 .56361 m .45632 .57163 L .44989 .54923 L p
1 g
F P
s
P
p
.002 w
.44989 .54923 m .40003 .54143 L .40285 .56361 L p
1 g
F P
s
P
p
.002 w
.38153 .32911 m .37094 .35457 L .39398 .35335 L p
1 g
F P
s
P
p
.002 w
.39398 .35335 m .40118 .33625 L .38153 .32911 L p
1 g
F P
s
P
p
.002 w
.3567 .51808 m .40003 .54143 L .39978 .51708 L p
1 g
F P
s
P
p
.002 w
.39978 .51708 m .36074 .49563 L .3567 .51808 L p
1 g
F P
s
P
p
.002 w
.46407 .59106 m .52143 .58181 L .51135 .56298 L p
1 g
F P
s
P
p
.002 w
.51135 .56298 m .45632 .57163 L .46407 .59106 L p
1 g
F P
s
P
p
.002 w
.52211 .28235 m .54488 .30521 L .56945 .29913 L p
1 g
F P
s
P
p
.002 w
.54488 .30521 m .52211 .28235 L .50203 .29687 L p
1 g
F P
s
P
p
.002 w
.47846 .28663 m .50203 .29687 L .52211 .28235 L p
1 g
F P
s
P
p
.002 w
.47846 .28663 m .45153 .28492 L .4482 .30654 L p
1 g
F P
s
P
p
.002 w
.42993 .31141 m .4482 .30654 L .45153 .28492 L p
1 g
F P
s
P
p
.002 w
.40003 .30742 m .38153 .32911 L .40118 .33625 L p
1 g
F P
s
P
p
.002 w
.40118 .33625 m .41363 .32171 L .40003 .30742 L p
1 g
F P
s
P
p
.002 w
.45153 .28492 m .42432 .2921 L .42993 .31141 L p
1 g
F P
s
P
p
.002 w
.41363 .32171 m .42993 .31141 L .42432 .2921 L p
1 g
F P
s
P
p
.002 w
.33215 .46169 m .36074 .49563 L .36817 .47214 L p
1 g
F P
s
P
p
.002 w
.36817 .47214 m .34354 .44239 L .33215 .46169 L p
1 g
F P
s
P
p
.002 w
.42432 .2921 m .40003 .30742 L .41363 .32171 L p
1 g
F P
s
P
p
.002 w
.63789 .4553 m .65421 .40291 L .63415 .39194 L p
1 g
F P
s
P
p
.002 w
.63283 .34222 m .63415 .39194 L .65421 .40291 L p
1 g
F P
s
P
p
.002 w
.63415 .39194 m .63283 .34222 L .60973 .33722 L p
1 g
F P
s
P
p
.002 w
.35052 .35778 m .34865 .39208 L .36935 .38081 L p
1 g
F P
s
P
p
.002 w
.36935 .38081 m .37094 .35457 L .35052 .35778 L p
1 g
F P
s
P
p
.002 w
.62059 .51811 m .6536 .46947 L .63789 .4553 L p
1 g
F P
s
P
p
.002 w
.65421 .40291 m .63789 .4553 L .6536 .46947 L p
1 g
F P
s
P
p
.002 w
.33127 .40467 m .34354 .44239 L .35855 .42331 L p
1 g
F P
s
P
p
.002 w
.35855 .42331 m .34865 .39208 L .33127 .40467 L p
1 g
F P
s
P
p
.002 w
.59286 .29626 m .60973 .33722 L .63283 .34222 L p
1 g
F P
s
P
p
.002 w
.60973 .33722 m .59286 .29626 L .56945 .29913 L p
1 g
F P
s
P
p
.002 w
.52211 .28235 m .49145 .26877 L .47846 .28663 L p
1 g
F P
s
P
p
.002 w
.45153 .28492 m .47846 .28663 L .49145 .26877 L p
1 g
F P
s
P
p
.002 w
.53128 .59736 m .58591 .5717 L .57517 .55668 L p
1 g
F P
s
P
p
.002 w
.57517 .55668 m .52143 .58181 L .53128 .59736 L p
1 g
F P
s
P
p
.002 w
.62059 .51811 m .57517 .55668 L .58591 .5717 L p
1 g
F P
s
P
p
.002 w
.40831 .58301 m .46407 .59106 L .45632 .57163 L p
1 g
F P
s
P
p
.002 w
.45632 .57163 m .40285 .56361 L .40831 .58301 L p
1 g
F P
s
P
p
.002 w
.54215 .27126 m .56945 .29913 L .59286 .29626 L p
1 g
F P
s
P
p
.002 w
.56945 .29913 m .54215 .27126 L .52211 .28235 L p
1 g
F P
s
P
p
.002 w
.58591 .5717 m .63215 .53249 L .62059 .51811 L p
1 g
F P
s
P
p
.002 w
.6536 .46947 m .62059 .51811 L .63215 .53249 L p
1 g
F P
s
P
p
.002 w
.3563 .53893 m .40285 .56361 L .40003 .54143 L p
1 g
F P
s
P
p
.002 w
.40003 .54143 m .3567 .51808 L .3563 .53893 L p
1 g
F P
s
P
p
.002 w
.36428 .32436 m .35052 .35778 L .37094 .35457 L p
1 g
F P
s
P
p
.002 w
.37094 .35457 m .38153 .32911 L .36428 .32436 L p
1 g
F P
s
P
p
.002 w
.49145 .26877 m .52211 .28235 L .54215 .27126 L p
1 g
F P
s
P
p
.002 w
.47302 .60695 m .53128 .59736 L .52143 .58181 L p
1 g
F P
s
P
p
.002 w
.52143 .58181 m .46407 .59106 L .47302 .60695 L p
1 g
F P
s
P
p
.002 w
.49145 .26877 m .45623 .26637 L .45153 .28492 L p
1 g
F P
s
P
p
.002 w
.42432 .2921 m .45153 .28492 L .45623 .26637 L p
1 g
F P
s
P
p
.002 w
.32483 .48079 m .3567 .51808 L .36074 .49563 L p
1 g
F P
s
P
p
.002 w
.36074 .49563 m .33215 .46169 L .32483 .48079 L p
1 g
F P
s
P
p
.002 w
.38855 .29583 m .36428 .32436 L .38153 .32911 L p
1 g
F P
s
P
p
.002 w
.38153 .32911 m .40003 .30742 L .38855 .29583 L p
1 g
F P
s
P
p
.002 w
.33332 .36301 m .33127 .40467 L .34865 .39208 L p
1 g
F P
s
P
p
.002 w
.34865 .39208 m .35052 .35778 L .33332 .36301 L p
1 g
F P
s
P
p
.002 w
.6536 .46947 m .67089 .41495 L .65421 .40291 L p
1 g
F P
s
P
p
.002 w
.65316 .34967 m .65421 .40291 L .67089 .41495 L p
1 g
F P
s
P
p
.002 w
.65421 .40291 m .65316 .34967 L .63283 .34222 L p
1 g
F P
s
P
p
.002 w
.31775 .41837 m .33215 .46169 L .34354 .44239 L p
1 g
F P
s
P
p
.002 w
.34354 .44239 m .33127 .40467 L .31775 .41837 L p
1 g
F P
s
P
p
.002 w
.45623 .26637 m .42049 .2757 L .42432 .2921 L p
1 g
F P
s
P
p
.002 w
.40003 .30742 m .42432 .2921 L .42049 .2757 L p
1 g
F P
s
P
p
.002 w
.63215 .53249 m .66585 .48311 L .6536 .46947 L p
1 g
F P
s
P
p
.002 w
.67089 .41495 m .6536 .46947 L .66585 .48311 L p
1 g
F P
s
P
p
.002 w
.42049 .2757 m .38855 .29583 L .40003 .30742 L p
1 g
F P
s
P
p
.002 w
.61455 .29682 m .63283 .34222 L .65316 .34967 L p
1 g
F P
s
P
p
.002 w
.63283 .34222 m .61455 .29682 L .59286 .29626 L p
1 g
F P
s
P
p
.002 w
.54215 .27126 m .50509 .25456 L .49145 .26877 L p
1 g
F P
s
P
p
.002 w
.45623 .26637 m .49145 .26877 L .50509 .25456 L p
1 g
F P
s
P
p
.002 w
.56171 .26398 m .59286 .29626 L .61455 .29682 L p
1 g
F P
s
P
p
.002 w
.59286 .29626 m .56171 .26398 L .54215 .27126 L p
1 g
F P
s
P
p
.002 w
.41641 .59903 m .47302 .60695 L .46407 .59106 L p
1 g
F P
s
P
p
.002 w
.46407 .59106 m .40831 .58301 L .41641 .59903 L p
1 g
F P
s
P
p
.002 w
.50509 .25456 m .54215 .27126 L .56171 .26398 L p
1 g
F P
s
P
p
.002 w
.35972 .5576 m .40831 .58301 L .40285 .56361 L p
1 g
F P
s
P
p
.002 w
.40285 .56361 m .3563 .53893 L .35972 .5576 L p
1 g
F P
s
P
p
.002 w
.54068 .60907 m .5948 .58358 L .58591 .5717 L p
1 g
F P
s
P
p
.002 w
.58591 .5717 m .53128 .59736 L .54068 .60907 L p
1 g
F P
s
P
p
.002 w
.63215 .53249 m .58591 .5717 L .5948 .58358 L p
1 g
F P
s
P
p
.002 w
.34998 .32224 m .33332 .36301 L .35052 .35778 L p
1 g
F P
s
P
p
.002 w
.35052 .35778 m .36428 .32436 L .34998 .32224 L p
1 g
F P
s
P
p
.002 w
.5948 .58358 m .64067 .54471 L .63215 .53249 L p
1 g
F P
s
P
p
.002 w
.66585 .48311 m .63215 .53249 L .64067 .54471 L p
1 g
F P
s
P
p
.002 w
.32195 .4992 m .3563 .53893 L .3567 .51808 L p
1 g
F P
s
P
p
.002 w
.3567 .51808 m .32483 .48079 L .32195 .4992 L p
1 g
F P
s
P
p
.002 w
.48302 .61872 m .54068 .60907 L .53128 .59736 L p
1 g
F P
s
P
p
.002 w
.53128 .59736 m .47302 .60695 L .48302 .61872 L p
1 g
F P
s
P
p
.002 w
.50509 .25456 m .46225 .25147 L .45623 .26637 L p
1 g
F P
s
P
p
.002 w
.42049 .2757 m .45623 .26637 L .46225 .25147 L p
1 g
F P
s
P
p
.002 w
.31994 .37025 m .31775 .41837 L .33127 .40467 L p
1 g
F P
s
P
p
.002 w
.33127 .40467 m .33332 .36301 L .31994 .37025 L p
1 g
F P
s
P
p
.002 w
.30864 .43289 m .32483 .48079 L .33215 .46169 L p
1 g
F P
s
P
p
.002 w
.33215 .46169 m .31775 .41837 L .30864 .43289 L p
1 g
F P
s
P
p
.002 w
.66585 .48311 m .68363 .42781 L .67089 .41495 L p
1 g
F P
s
P
p
.002 w
.67011 .3595 m .67089 .41495 L .68363 .42781 L p
1 g
F P
s
P
p
.002 w
.67089 .41495 m .67011 .3595 L .65316 .34967 L p
1 g
F P
s
P
p
.002 w
.37958 .28737 m .34998 .32224 L .36428 .32436 L p
1 g
F P
s
P
p
.002 w
.36428 .32436 m .38855 .29583 L .37958 .28737 L p
1 g
F P
s
P
p
.002 w
.6339 .30094 m .65316 .34967 L .67011 .3595 L p
1 g
F P
s
P
p
.002 w
.65316 .34967 m .6339 .30094 L .61455 .29682 L p
1 g
F P
s
P
p
.002 w
.64067 .54471 m .67415 .49586 L .66585 .48311 L p
1 g
F P
s
P
p
.002 w
.68363 .42781 m .66585 .48311 L .67415 .49586 L p
1 g
F P
s
P
p
.002 w
.46225 .25147 m .41862 .26278 L .42049 .2757 L p
1 g
F P
s
P
p
.002 w
.38855 .29583 m .42049 .2757 L .41862 .26278 L p
1 g
F P
s
P
p
.002 w
.41862 .26278 m .37958 .28737 L .38855 .29583 L p
1 g
F P
s
P
p
.002 w
.56171 .26398 m .51909 .24452 L .50509 .25456 L p
1 g
F P
s
P
p
.002 w
.46225 .25147 m .50509 .25456 L .51909 .24452 L p
1 g
F P
s
P
p
.002 w
.5803 .2609 m .61455 .29682 L .6339 .30094 L p
1 g
F P
s
P
p
.002 w
.61455 .29682 m .5803 .2609 L .56171 .26398 L p
1 g
F P
s
P
p
.002 w
.51909 .24452 m .56171 .26398 L .5803 .2609 L p
1 g
F P
s
P
p
.002 w
.36709 .57349 m .41641 .59903 L .40831 .58301 L p
1 g
F P
s
P
p
.002 w
.40831 .58301 m .35972 .5576 L .36709 .57349 L p
1 g
F P
s
P
p
.002 w
.42708 .61107 m .48302 .61872 L .47302 .60695 L p
1 g
F P
s
P
p
.002 w
.47302 .60695 m .41641 .59903 L .42708 .61107 L p
1 g
F P
s
P
p
.002 w
.33915 .32296 m .31994 .37025 L .33332 .36301 L p
1 g
F P
s
P
p
.002 w
.33332 .36301 m .34998 .32224 L .33915 .32296 L p
1 g
F P
s
P
p
.002 w
.32383 .51641 m .35972 .5576 L .3563 .53893 L p
1 g
F P
s
P
p
.002 w
.3563 .53893 m .32195 .4992 L .32383 .51641 L p
1 g
F P
s
P
p
.002 w
.54936 .61645 m .60151 .59183 L .5948 .58358 L p
1 g
F P
s
P
p
.002 w
.5948 .58358 m .54068 .60907 L .54936 .61645 L p
1 g
F P
s
P
p
.002 w
.64067 .54471 m .5948 .58358 L .60151 .59183 L p
1 g
F P
s
P
p
.002 w
.60151 .59183 m .64575 .55437 L .64067 .54471 L p
1 g
F P
s
P
p
.002 w
.67415 .49586 m .64067 .54471 L .64575 .55437 L p
1 g
F P
s
P
p
.002 w
.30443 .4479 m .32195 .4992 L .32483 .48079 L p
1 g
F P
s
P
p
.002 w
.32483 .48079 m .30864 .43289 L .30443 .4479 L p
1 g
F P
s
P
p
.002 w
.31093 .37942 m .30864 .43289 L .31775 .41837 L p
1 g
F P
s
P
p
.002 w
.31775 .41837 m .31994 .37025 L .31093 .37942 L p
1 g
F P
s
P
p
.002 w
.51909 .24452 m .46952 .2408 L .46225 .25147 L p
1 g
F P
s
P
p
.002 w
.41862 .26278 m .46225 .25147 L .46952 .2408 L p
1 g
F P
s
P
p
.002 w
.49389 .62583 m .54936 .61645 L .54068 .60907 L p
1 g
F P
s
P
p
.002 w
.54068 .60907 m .48302 .61872 L .49389 .62583 L p
1 g
F P
s
P
p
.002 w
.67415 .49586 m .6919 .44122 L .68363 .42781 L p
1 g
F P
s
P
p
.002 w
.68308 .3716 m .68363 .42781 L .6919 .44122 L p
1 g
F P
s
P
p
.002 w
.68363 .42781 m .68308 .3716 L .67011 .3595 L p
1 g
F P
s
P
p
.002 w
.65033 .30872 m .67011 .3595 L .68308 .3716 L p
1 g
F P
s
P
p
.002 w
.67011 .3595 m .65033 .30872 L .6339 .30094 L p
1 g
F P
s
P
p
.002 w
.37351 .28243 m .33915 .32296 L .34998 .32224 L p
1 g
F P
s
P
p
.002 w
.34998 .32224 m .37958 .28737 L .37351 .28243 L p
1 g
F P
s
P
p
.002 w
.64575 .55437 m .67807 .50735 L .67415 .49586 L p
1 g
F P
s
P
p
.002 w
.6919 .44122 m .67415 .49586 L .67807 .50735 L p
1 g
F P
s
P
p
.002 w
.59739 .2623 m .6339 .30094 L .65033 .30872 L p
1 g
F P
s
P
p
.002 w
.6339 .30094 m .59739 .2623 L .5803 .2609 L p
1 g
F P
s
P
p
.002 w
.46952 .2408 m .41888 .25387 L .41862 .26278 L p
1 g
F P
s
P
p
.002 w
.37958 .28737 m .41862 .26278 L .41888 .25387 L p
1 g
F P
s
P
p
.002 w
.5803 .2609 m .5331 .23914 L .51909 .24452 L p
1 g
F P
s
P
p
.002 w
.46952 .2408 m .51909 .24452 L .5331 .23914 L p
1 g
F P
s
P
p
.002 w
.41888 .25387 m .37351 .28243 L .37958 .28737 L p
1 g
F P
s
P
p
.002 w
.5331 .23914 m .5803 .2609 L .59739 .2623 L p
1 g
F P
s
P
p
.002 w
.37842 .58601 m .42708 .61107 L .41641 .59903 L p
1 g
F P
s
P
p
.002 w
.41641 .59903 m .36709 .57349 L .37842 .58601 L p
1 g
F P
s
P
p
.002 w
.44018 .61858 m .49389 .62583 L .48302 .61872 L p
1 g
F P
s
P
p
.002 w
.48302 .61872 m .42708 .61107 L .44018 .61858 L p
1 g
F P
s
P
p
.002 w
.33069 .53188 m .36709 .57349 L .35972 .5576 L p
1 g
F P
s
P
p
.002 w
.35972 .5576 m .32383 .51641 L .33069 .53188 L p
1 g
F P
s
P
p
.002 w
.3323 .32668 m .31093 .37942 L .31994 .37025 L p
1 g
F P
s
P
p
.002 w
.31994 .37025 m .33915 .32296 L .3323 .32668 L p
1 g
F P
s
P
p
.002 w
.55705 .61903 m .60573 .59602 L .60151 .59183 L p
1 g
F P
s
P
p
.002 w
.60151 .59183 m .54936 .61645 L .55705 .61903 L p
1 g
F P
s
P
p
.002 w
.64575 .55437 m .60151 .59183 L .60573 .59602 L p
1 g
F P
s
P
p
.002 w
.3055 .46301 m .32383 .51641 L .32195 .4992 L p
1 g
F P
s
P
p
.002 w
.32195 .4992 m .30443 .4479 L .3055 .46301 L p
1 g
F P
s
P
p
.002 w
.60573 .59602 m .64705 .56104 L .64575 .55437 L p
1 g
F P
s
P
p
.002 w
.67807 .50735 m .64575 .55437 L .64705 .56104 L p
1 g
F P
s
P
p
.002 w
.30682 .39039 m .30443 .4479 L .30864 .43289 L p
1 g
F P
s
P
p
.002 w
.30864 .43289 m .31093 .37942 L .30682 .39039 L p
1 g
F P
s
P
p
.002 w
.5331 .23914 m .47794 .23491 L .46952 .2408 L p
1 g
F P
s
P
p
.002 w
.41888 .25387 m .46952 .2408 L .47794 .23491 L p
1 g
F P
s
P
p
.002 w
.67807 .50735 m .69523 .45487 L .6919 .44122 L p
1 g
F P
s
P
p
.002 w
.69152 .38577 m .6919 .44122 L .69523 .45487 L p
1 g
F P
s
P
p
.002 w
.6919 .44122 m .69152 .38577 L .68308 .3716 L p
1 g
F P
s
P
p
.002 w
.66322 .32013 m .68308 .3716 L .69152 .38577 L p
1 g
F P
s
P
p
.002 w
.68308 .3716 m .66322 .32013 L .65033 .30872 L p
1 g
F P
s
P
p
.002 w
.50537 .62781 m .55705 .61903 L .54936 .61645 L p
1 g
F P
s
P
p
.002 w
.54936 .61645 m .49389 .62583 L .50537 .62781 L p
1 g
F P
s
P
p
.002 w
.61244 .2684 m .65033 .30872 L .66322 .32013 L p
1 g
F P
s
P
p
.002 w
.65033 .30872 m .61244 .2684 L .59739 .2623 L p
1 g
F P
s
P
p
.002 w
.37068 .28139 m .3323 .32668 L .33915 .32296 L p
1 g
F P
s
P
p
.002 w
.33915 .32296 m .37351 .28243 L .37068 .28139 L p
1 g
F P
s
P
p
.002 w
.64705 .56104 m .67724 .5172 L .67807 .50735 L p
1 g
F P
s
P
p
.002 w
.69523 .45487 m .67807 .50735 L .67724 .5172 L p
1 g
F P
s
P
p
.002 w
.59739 .2623 m .54675 .23883 L .5331 .23914 L p
1 g
F P
s
P
p
.002 w
.47794 .23491 m .5331 .23914 L .54675 .23883 L p
1 g
F P
s
P
p
.002 w
.54675 .23883 m .59739 .2623 L .61244 .2684 L p
1 g
F P
s
P
p
.002 w
.47794 .23491 m .4214 .24946 L .41888 .25387 L p
1 g
F P
s
P
p
.002 w
.37351 .28243 m .41888 .25387 L .4214 .24946 L p
1 g
F P
s
P
p
.002 w
.39362 .59461 m .44018 .61858 L .42708 .61107 L p
1 g
F P
s
P
p
.002 w
.42708 .61107 m .37842 .58601 L .39362 .59461 L p
1 g
F P
s
P
p
.002 w
.4214 .24946 m .37068 .28139 L .37351 .28243 L p
1 g
F P
s
P
p
.002 w
.34261 .54507 m .37842 .58601 L .36709 .57349 L p
1 g
F P
s
P
p
.002 w
.36709 .57349 m .33069 .53188 L .34261 .54507 L p
1 g
F P
s
P
p
.002 w
.45549 .62108 m .50537 .62781 L .49389 .62583 L p
1 g
F P
s
P
p
.002 w
.49389 .62583 m .44018 .61858 L .45549 .62108 L p
1 g
F P
s
P
p
.002 w
.32988 .3335 m .30682 .39039 L .31093 .37942 L p
1 g
F P
s
P
p
.002 w
.31093 .37942 m .3323 .32668 L .32988 .3335 L p
1 g
F P
s
P
p
.002 w
.31216 .47779 m .33069 .53188 L .32383 .51641 L p
1 g
F P
s
P
p
.002 w
.32383 .51641 m .3055 .46301 L .31216 .47779 L p
1 g
F P
s
P
p
.002 w
.30804 .40296 m .3055 .46301 L .30443 .4479 L p
1 g
F P
s
P
p
.002 w
.30443 .4479 m .30682 .39039 L .30804 .40296 L p
1 g
F P
s
P
p
.002 w
.56347 .61642 m .60718 .59576 L .60573 .59602 L p
1 g
F P
s
P
p
.002 w
.60573 .59602 m .55705 .61903 L .56347 .61642 L p
1 g
F P
s
P
p
.002 w
.64705 .56104 m .60573 .59602 L .60718 .59576 L p
1 g
F P
s
P
p
.002 w
.60718 .59576 m .64429 .56434 L .64705 .56104 L p
1 g
F P
s
P
p
.002 w
.67724 .5172 m .64705 .56104 L .64429 .56434 L p
1 g
F P
s
P
p
.002 w
.69523 .45487 m .69493 .40174 L .69152 .38577 L p
1 g
F P
s
P
p
.002 w
.69152 .38577 m .67202 .33508 L .66322 .32013 L p
1 g
F P
s
P
p
.002 w
.67202 .33508 m .69152 .38577 L .69493 .40174 L p
1 g
F P
s
P
p
.002 w
.67724 .5172 m .69322 .46839 L .69523 .45487 L p
1 g
F P
s
P
p
.002 w
.69493 .40174 m .69523 .45487 L .69322 .46839 L p
1 g
F P
s
P
p
.002 w
.54675 .23883 m .48733 .23425 L .47794 .23491 L p
1 g
F P
s
P
p
.002 w
.4214 .24946 m .47794 .23491 L .48733 .23425 L p
1 g
F P
s
P
p
.002 w
.51718 .62427 m .56347 .61642 L .55705 .61903 L p
1 g
F P
s
P
p
.002 w
.55705 .61903 m .50537 .62781 L .51718 .62427 L p
1 g
F P
s
P
p
.002 w
.66322 .32013 m .62491 .27931 L .61244 .2684 L p
1 g
F P
s
P
p
.002 w
.62491 .27931 m .66322 .32013 L .67202 .33508 L p
1 g
F P
s
P
p
.002 w
.37139 .28453 m .32988 .3335 L .3323 .32668 L p
1 g
F P
s
P
p
.002 w
.3323 .32668 m .37068 .28139 L .37139 .28453 L p
1 g
F P
s
P
p
.002 w
.61244 .2684 m .55964 .24391 L .54675 .23883 L p
1 g
F P
s
P
p
.002 w
.55964 .24391 m .61244 .2684 L .62491 .27931 L p
1 g
F P
s
P
p
.002 w
.48733 .23425 m .54675 .23883 L .55964 .24391 L p
1 g
F P
s
P
p
.002 w
.64429 .56434 m .67136 .52503 L .67724 .5172 L p
1 g
F P
s
P
p
.002 w
.69322 .46839 m .67724 .5172 L .67136 .52503 L p
1 g
F P
s
P
p
.002 w
.41245 .59882 m .45549 .62108 L .44018 .61858 L p
1 g
F P
s
P
p
.002 w
.44018 .61858 m .39362 .59461 L .41245 .59882 L p
1 g
F P
s
P
p
.002 w
.48733 .23425 m .42626 .24999 L .4214 .24946 L p
1 g
F P
s
P
p
.002 w
.37068 .28139 m .4214 .24946 L .42626 .24999 L p
1 g
F P
s
P
p
.002 w
.35952 .55543 m .39362 .59461 L .37842 .58601 L p
1 g
F P
s
P
p
.002 w
.37842 .58601 m .34261 .54507 L .35952 .55543 L p
1 g
F P
s
P
p
.002 w
.42626 .24999 m .37139 .28453 L .37068 .28139 L p
1 g
F P
s
P
p
.002 w
.47268 .6182 m .51718 .62427 L .50537 .62781 L p
1 g
F P
s
P
p
.002 w
.50537 .62781 m .45549 .62108 L .47268 .6182 L p
1 g
F P
s
P
p
.002 w
.32451 .49177 m .34261 .54507 L .33069 .53188 L p
1 g
F P
s
P
p
.002 w
.33069 .53188 m .31216 .47779 L .32451 .49177 L p
1 g
F P
s
P
p
.002 w
.33226 .3434 m .30804 .40296 L .30682 .39039 L p
1 g
F P
s
P
p
.002 w
.30682 .39039 m .32988 .3335 L .33226 .3434 L p
1 g
F P
s
P
p
.002 w
.31487 .41684 m .31216 .47779 L .3055 .46301 L p
1 g
F P
s
P
p
.002 w
.3055 .46301 m .30804 .40296 L .31487 .41684 L p
1 g
F P
s
P
p
.002 w
.69322 .46839 m .69291 .41914 L .69493 .40174 L p
1 g
F P
s
P
p
.002 w
.67624 .35332 m .69493 .40174 L .69291 .41914 L p
1 g
F P
s
P
p
.002 w
.69493 .40174 m .67624 .35332 L .67202 .33508 L p
1 g
F P
s
P
p
.002 w
.56835 .60836 m .60562 .59076 L .60718 .59576 L p
1 g
F P
s
P
p
.002 w
.60718 .59576 m .56347 .61642 L .56835 .60836 L p
1 g
F P
s
P
p
.002 w
.64429 .56434 m .60718 .59576 L .60562 .59076 L p
1 g
F P
s
P
p
.002 w
.67136 .52503 m .68561 .48137 L .69322 .46839 L p
1 g
F P
s
P
p
.002 w
.69291 .41914 m .69322 .46839 L .68561 .48137 L p
1 g
F P
s
P
p
.002 w
.60562 .59076 m .63727 .56396 L .64429 .56434 L p
1 g
F P
s
P
p
.002 w
.67136 .52503 m .64429 .56434 L .63727 .56396 L p
1 g
F P
s
P
p
.002 w
.63426 .29497 m .67202 .33508 L .67624 .35332 L p
1 g
F P
s
P
p
.002 w
.67202 .33508 m .63426 .29497 L .62491 .27931 L p
1 g
F P
s
P
p
.002 w
.55964 .24391 m .49749 .23919 L .48733 .23425 L p
1 g
F P
s
P
p
.002 w
.42626 .24999 m .48733 .23425 L .49749 .23919 L p
1 g
F P
s
P
p
.002 w
.52898 .61498 m .56835 .60836 L .56347 .61642 L p
1 g
F P
s
P
p
.002 w
.56347 .61642 m .51718 .62427 L .52898 .61498 L p
1 g
F P
s
P
p
.002 w
.57133 .25457 m .62491 .27931 L .63426 .29497 L p
1 g
F P
s
P
p
.002 w
.62491 .27931 m .57133 .25457 L .55964 .24391 L p
1 g
F P
s
P
p
.002 w
.49749 .23919 m .55964 .24391 L .57133 .25457 L p
1 g
F P
s
P
p
.002 w
.37586 .29205 m .33226 .3434 L .32988 .3335 L p
1 g
F P
s
P
p
.002 w
.32988 .3335 m .37139 .28453 L .37586 .29205 L p
1 g
F P
s
P
p
.002 w
.4345 .59825 m .47268 .6182 L .45549 .62108 L p
1 g
F P
s
P
p
.002 w
.45549 .62108 m .41245 .59882 L .4345 .59825 L p
1 g
F P
s
P
p
.002 w
.63727 .56396 m .66029 .53046 L .67136 .52503 L p
1 g
F P
s
P
p
.002 w
.68561 .48137 m .67136 .52503 L .66029 .53046 L p
1 g
F P
s
P
p
.002 w
.38113 .56249 m .41245 .59882 L .39362 .59461 L p
1 g
F P
s
P
p
.002 w
.39362 .59461 m .35952 .55543 L .38113 .56249 L p
1 g
F P
s
P
p
.002 w
.49749 .23919 m .43346 .25576 L .42626 .24999 L p
1 g
F P
s
P
p
.002 w
.37139 .28453 m .42626 .24999 L .43346 .25576 L p
1 g
F P
s
P
p
.002 w
.34248 .50444 m .35952 .55543 L .34261 .54507 L p
1 g
F P
s
P
p
.002 w
.34261 .54507 m .32451 .49177 L .34248 .50444 L p
1 g
F P
s
P
p
.002 w
.43346 .25576 m .37586 .29205 L .37139 .28453 L p
1 g
F P
s
P
p
.002 w
.49131 .60971 m .52898 .61498 L .51718 .62427 L p
1 g
F P
s
P
p
.002 w
.51718 .62427 m .47268 .6182 L .49131 .60971 L p
1 g
F P
s
P
p
.002 w
.33966 .35628 m .31487 .41684 L .30804 .40296 L p
1 g
F P
s
P
p
.002 w
.30804 .40296 m .33226 .3434 L .33966 .35628 L p
1 g
F P
s
P
p
.002 w
.32743 .43166 m .32451 .49177 L .31216 .47779 L p
1 g
F P
s
P
p
.002 w
.31216 .47779 m .31487 .41684 L .32743 .43166 L p
1 g
F P
s
P
p
.002 w
.68561 .48137 m .68521 .43751 L .69291 .41914 L p
1 g
F P
s
P
p
.002 w
.67549 .37445 m .69291 .41914 L .68521 .43751 L p
1 g
F P
s
P
p
.002 w
.69291 .41914 m .67549 .37445 L .67624 .35332 L p
1 g
F P
s
P
p
.002 w
.66029 .53046 m .67231 .49338 L .68561 .48137 L p
1 g
F P
s
P
p
.002 w
.68521 .43751 m .68561 .48137 L .67231 .49338 L p
1 g
F P
s
P
p
.002 w
.64004 .31516 m .67624 .35332 L .67549 .37445 L p
1 g
F P
s
P
p
.002 w
.67624 .35332 m .64004 .31516 L .63426 .29497 L p
1 g
F P
s
P
p
.002 w
.57143 .59475 m .60091 .58086 L .60562 .59076 L p
1 g
F P
s
P
p
.002 w
.60562 .59076 m .56835 .60836 L .57143 .59475 L p
1 g
F P
s
P
p
.002 w
.63727 .56396 m .60562 .59076 L .60091 .58086 L p
1 g
F P
s
P
p
.002 w
.60091 .58086 m .62594 .55965 L .63727 .56396 L p
1 g
F P
s
P
p
.002 w
.66029 .53046 m .63727 .56396 L .62594 .55965 L p
1 g
F P
s
P
p
.002 w
.57133 .25457 m .50813 .24993 L .49749 .23919 L p
1 g
F P
s
P
p
.002 w
.43346 .25576 m .49749 .23919 L .50813 .24993 L p
1 g
F P
s
P
p
.002 w
.58139 .27079 m .63426 .29497 L .64004 .31516 L p
1 g
F P
s
P
p
.002 w
.63426 .29497 m .58139 .27079 L .57133 .25457 L p
1 g
F P
s
P
p
.002 w
.54038 .59989 m .57143 .59475 L .56835 .60836 L p
1 g
F P
s
P
p
.002 w
.56835 .60836 m .52898 .61498 L .54038 .59989 L p
1 g
F P
s
P
p
.002 w
.50813 .24993 m .57133 .25457 L .58139 .27079 L p
1 g
F P
s
P
p
.002 w
.40697 .56585 m .4345 .59825 L .41245 .59882 L p
1 g
F P
s
P
p
.002 w
.41245 .59882 m .38113 .56249 L .40697 .56585 L p
1 g
F P
s
P
p
.002 w
.45921 .59268 m .49131 .60971 L .47268 .6182 L p
1 g
F P
s
P
p
.002 w
.47268 .6182 m .4345 .59825 L .45921 .59268 L p
1 g
F P
s
P
p
.002 w
.38418 .30397 m .33966 .35628 L .33226 .3434 L p
1 g
F P
s
P
p
.002 w
.33226 .3434 m .37586 .29205 L .38418 .30397 L p
1 g
F P
s
P
p
.002 w
.62594 .55965 m .64407 .53317 L .66029 .53046 L p
1 g
F P
s
P
p
.002 w
.67231 .49338 m .66029 .53046 L .64407 .53317 L p
1 g
F P
s
P
p
.002 w
.36575 .51532 m .38113 .56249 L .35952 .55543 L p
1 g
F P
s
P
p
.002 w
.35952 .55543 m .34248 .50444 L .36575 .51532 L p
1 g
F P
s
P
p
.002 w
.50813 .24993 m .44292 .26693 L .43346 .25576 L p
1 g
F P
s
P
p
.002 w
.37586 .29205 m .43346 .25576 L .44292 .26693 L p
1 g
F P
s
P
p
.002 w
.51082 .5956 m .54038 .59989 L .52898 .61498 L p
1 g
F P
s
P
p
.002 w
.52898 .61498 m .49131 .60971 L .51082 .5956 L p
1 g
F P
s
P
p
.002 w
.44292 .26693 m .38418 .30397 L .37586 .29205 L p
1 g
F P
s
P
p
.002 w
.34561 .44695 m .34248 .50444 L .32451 .49177 L p
1 g
F P
s
P
p
.002 w
.32451 .49177 m .32743 .43166 L .34561 .44695 L p
1 g
F P
s
P
p
.002 w
.35215 .37187 m .32743 .43166 L .31487 .41684 L p
1 g
F P
s
P
p
.002 w
.31487 .41684 m .33966 .35628 L .35215 .37187 L p
1 g
F P
s
P
p
.002 w
.67231 .49338 m .67179 .45632 L .68521 .43751 L p
1 g
F P
s
P
p
.002 w
.66953 .39795 m .68521 .43751 L .67179 .45632 L p
1 g
F P
s
P
p
.002 w
.68521 .43751 m .66953 .39795 L .67549 .37445 L p
1 g
F P
s
P
p
.002 w
.64185 .33945 m .67549 .37445 L .66953 .39795 L p
1 g
F P
s
P
p
.002 w
.67549 .37445 m .64185 .33945 L .64004 .31516 L p
1 g
F P
s
P
p
.002 w
.64407 .53317 m .65341 .50397 L .67231 .49338 L p
1 g
F P
s
P
p
.002 w
.67179 .45632 m .67231 .49338 L .65341 .50397 L p
1 g
F P
s
P
p
.002 w
.58937 .29233 m .64004 .31516 L .64185 .33945 L p
1 g
F P
s
P
p
.002 w
.64004 .31516 m .58937 .29233 L .58139 .27079 L p
1 g
F P
s
P
p
.002 w
.57251 .57571 m .593 .56609 L .60091 .58086 L p
1 g
F P
s
P
p
.002 w
.60091 .58086 m .57143 .59475 L .57251 .57571 L p
1 g
F P
s
P
p
.002 w
.62594 .55965 m .60091 .58086 L .593 .56609 L p
1 g
F P
s
P
p
.002 w
.58139 .27079 m .51895 .26645 L .50813 .24993 L p
1 g
F P
s
P
p
.002 w
.44292 .26693 m .50813 .24993 L .51895 .26645 L p
1 g
F P
s
P
p
.002 w
.593 .56609 m .6104 .55133 L .62594 .55965 L p
1 g
F P
s
P
p
.002 w
.64407 .53317 m .62594 .55965 L .6104 .55133 L p
1 g
F P
s
P
p
.002 w
.43632 .56521 m .45921 .59268 L .4345 .59825 L p
1 g
F P
s
P
p
.002 w
.4345 .59825 m .40697 .56585 L .43632 .56521 L p
1 g
F P
s
P
p
.002 w
.48585 .58208 m .51082 .5956 L .49131 .60971 L p
1 g
F P
s
P
p
.002 w
.49131 .60971 m .45921 .59268 L .48585 .58208 L p
1 g
F P
s
P
p
.002 w
.51895 .26645 m .58139 .27079 L .58937 .29233 L p
1 g
F P
s
P
p
.002 w
.55097 .57919 m .57251 .57571 L .57143 .59475 L p
1 g
F P
s
P
p
.002 w
.57143 .59475 m .54038 .59989 L .55097 .57919 L p
1 g
F P
s
P
p
.002 w
.39374 .52392 m .40697 .56585 L .38113 .56249 L p
1 g
F P
s
P
p
.002 w
.38113 .56249 m .36575 .51532 L .39374 .52392 L p
1 g
F P
s
P
p
.002 w
.6104 .55133 m .62294 .53292 L .64407 .53317 L p
1 g
F P
s
P
p
.002 w
.65341 .50397 m .64407 .53317 L .62294 .53292 L p
1 g
F P
s
P
p
.002 w
.39632 .32016 m .35215 .37187 L .33966 .35628 L p
1 g
F P
s
P
p
.002 w
.33966 .35628 m .38418 .30397 L .39632 .32016 L p
1 g
F P
s
P
p
.002 w
.5306 .57609 m .55097 .57919 L .54038 .59989 L p
1 g
F P
s
P
p
.002 w
.54038 .59989 m .51082 .5956 L .5306 .57609 L p
1 g
F P
s
P
p
.002 w
.36904 .46222 m .36575 .51532 L .34248 .50444 L p
1 g
F P
s
P
p
.002 w
.34248 .50444 m .34561 .44695 L .36904 .46222 L p
1 g
F P
s
P
p
.002 w
.65341 .50397 m .65281 .47494 L .67179 .45632 L p
1 g
F P
s
P
p
.002 w
.65832 .42312 m .67179 .45632 L .65281 .47494 L p
1 g
F P
s
P
p
.002 w
.67179 .45632 m .65832 .42312 L .66953 .39795 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.51895 .26645 m .45447 .28345 L .44292 .26693 L p
1 g
F P
s
P
p
.002 w
.38418 .30397 m .44292 .26693 L .45447 .28345 L p
1 g
F P
s
P
p
.002 w
.63946 .36719 m .66953 .39795 L .65832 .42312 L p
1 g
F P
s
P
p
.002 w
.66953 .39795 m .63946 .36719 L .64185 .33945 L p
1 g
F P
s
P
p
.002 w
.36956 .38978 m .34561 .44695 L .32743 .43166 L p
1 g
F P
s
P
p
.002 w
.32743 .43166 m .35215 .37187 L .36956 .38978 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.45447 .28345 m .39632 .32016 L .38418 .30397 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.62294 .53292 m .62929 .51269 L .65341 .50397 L p
1 g
F P
s
P
p
.002 w
.65281 .47494 m .65341 .50397 L .62929 .51269 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.5949 .31872 m .64185 .33945 L .63946 .36719 L p
1 g
F P
s
P
p
.002 w
.64185 .33945 m .5949 .31872 L .58937 .29233 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.45921 .59268 m .46479 .57282 L .46994 .57509 L 1 g
F
P
p
.002 w
.48585 .58208 m .48296 .58323 L p
.46994 .57509 L 1 g
F P
s
P
p
.002 w
.48296 .58323 m .45921 .59268 L p
.46994 .57509 L 1 g
F P
s
P
p
.002 w
.4684 .57413 m .46872 .57265 L p
.46129 .56968 L 1 g
F P
s
P
p
.48921 .57862 m .47841 .57773 L .48393 .57972 L 1 g
F
P
p
.48921 .57862 m .48393 .57972 L .48625 .58034 L 1 g
F
P
p
.002 w
.48807 .58084 m .48585 .58208 L p
.48669 .58046 L 1 g
F P
s
P
p
.002 w
.48903 .581 m .48921 .57862 L p
.48625 .58034 L 1 g
F P
s
P
p
.48625 .58034 m .48602 .58047 L .48807 .58084 L 1 g
F
P
p
.48625 .58034 m .48807 .58084 L .48903 .581 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48393 .57972 m .48585 .58208 L p
.46479 .57282 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46826 .56046 m .50169 .55165 L p
.48669 .58046 L 1 g
F P
s
P
p
.002 w
.48585 .58208 m .48393 .57972 L p
.48669 .58046 L 1 g
F P
s
P
p
.002 w
.48393 .57972 m .46826 .56046 L p
.48669 .58046 L 1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .581 L p
1 g
F P
s
P
p
.002 w
.51082 .5956 m .48585 .58208 L .4877 .58105 L p
1 g
F P
s
P
p
.51082 .5956 m .4877 .58105 L .48837 .58102 L 1 g
F
P
p
.51079 .57862 m .48903 .581 L .5007 .58064 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51092 .58032 m .51079 .57862 L p
.5007 .58064 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58032 L p
1 g
F P
s
P
p
.51226 .58027 m .51097 .5803 L .51229 .57999 L 1 g
F
P
p
.51182 .58501 m .48903 .581 L .51226 .58027 L 1 g
F
P
p
.53128 .57265 m .51092 .58032 L .52108 .57788 L 1 g
F
P
p
.48903 .581 m .48807 .58084 L .51226 .58027 L 1 g
F
P
p
.002 w
.5306 .57609 m .51082 .5956 L p
.51229 .57999 L 1 g
F P
s
P
p
.53128 .57265 m .52108 .57788 L .52998 .57575 L 1 g
F
P
p
.53128 .57265 m .52998 .57575 L .53033 .57562 L 1 g
F
P
p
.002 w
.53181 .57507 m .53128 .57265 L p
.53033 .57562 L 1 g
F P
s
P
p
.002 w
.5306 .57609 m .52998 .57575 L p
.53083 .57544 L 1 g
F P
s
P
p
.53033 .57562 m .53032 .57567 L .53122 .5753 L 1 g
F
P
p
.53033 .57562 m .53122 .5753 L .53181 .57507 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53181 .57507 L p
1 g
F P
s
P
p
.002 w
.55097 .57919 m .5306 .57609 L .53093 .57568 L p
1 g
F P
s
P
p
.55097 .57919 m .53093 .57568 L .53141 .57534 L 1 g
F
P
p
.54854 .56129 m .53181 .57507 L .54016 .56928 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54918 .56302 m .54854 .56129 L p
.54016 .56928 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56302 L p
1 g
F P
s
P
p
.55033 .56223 m .54921 .563 L .55031 .56172 L 1 g
F
P
p
.55053 .56749 m .53181 .57507 L .55033 .56223 L 1 g
F
P
p
.56075 .54566 m .54918 .56302 L .55467 .55668 L 1 g
F
P
p
.53181 .57507 m .53122 .5753 L .55033 .56223 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56034 .55333 m .55097 .57919 L p
.55031 .56172 L 1 g
F P
s
P
p
.56075 .54566 m .55467 .55668 L .55791 .55294 L 1 g
F
P
p
.56075 .54566 m .55791 .55294 L .55822 .55248 L 1 g
F
P
p
.002 w
.56195 .54706 m .56034 .55333 L .55985 .55325 L p
1 g
F P
s
P
p
.002 w
.55985 .55325 m .55791 .55294 L p
.56169 .54744 L 1 g
F P
s
P
p
.55985 .55325 m .56169 .54744 L .56195 .54706 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56169 .54744 L p
1 g
F P
s
P
p
.56654 .52734 m .56169 .54744 L .56252 .54481 L 1 g
F
P
p
.002 w
.56845 .52607 m .56958 .53581 L p
.56788 .53799 L 1 g
F P
s
P
p
.56788 .53799 m .56252 .54481 L .56757 .52884 L 1 g
F
P
p
.56788 .53799 m .56757 .52884 L .56845 .52607 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56757 .52884 L p
1 g
F P
s
P
p
.56515 .50826 m .56757 .52884 L .56746 .52552 L 1 g
F
P
p
.56515 .50826 m .56746 .52552 L .56741 .52412 L 1 g
F
P
p
.56515 .50826 m .56741 .52412 L .56739 .52352 L 1 g
F
P
p
.56515 .50826 m .56739 .52352 L .56738 .52337 L 1 g
F
P
p
.56515 .50826 m .56738 .52339 L .56737 .52324 L 1 g
F
P
p
.56515 .50826 m .56738 .52328 L .56736 .52312 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53539 .53903 m .53289 .52937 L .56737 .52317 L p
1 g
F P
s
P
p
.002 w
.56737 .52317 m .5681 .52304 L .56738 .52339 L p
1 g
F P
s
P
p
.002 w
.56738 .52339 m .53539 .53903 L p
.56737 .52317 L 1 g
F P
s
P
p
.002 w
.56738 .52339 m .5681 .52304 L .56739 .52366 L p
1 g
F P
s
P
p
.56738 .52337 m .56739 .52352 L .56738 .52339 L 1 g
F
P
p
.56737 .52324 m .56738 .52339 L .56738 .52328 L 1 g
F
P
p
.56515 .50826 m .56737 .52318 L .56728 .52214 L 1 g
F
P
p
.002 w
.56712 .52039 m .5681 .52304 L .56728 .52214 L p
1 g
F P
s
P
p
.56727 .52202 m .56728 .52214 L .56727 .52203 L 1 g
F
P
p
.56515 .50826 m .56728 .52214 L .56727 .52202 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56735 .52295 m .5681 .52304 L .56737 .52317 L p
1 g
F P
s
P
p
.002 w
.56733 .52265 m .5681 .52304 L .56735 .52295 L p
1 g
F P
s
P
p
.002 w
.56728 .52214 m .5681 .52304 L .56733 .52265 L p
1 g
F P
s
P
p
.002 w
.56739 .52366 m .5681 .52304 L .56741 .52412 L p
1 g
F P
s
P
p
.002 w
.56741 .52412 m .5681 .52304 L .56746 .52552 L p
1 g
F P
s
P
p
.002 w
.5681 .52304 m .56845 .52607 L p
.56757 .52884 L 1 g
F P
s
P
p
.56654 .52734 m .56252 .54481 L .56448 .53864 L 1 g
F
P
p
.002 w
.56195 .54706 m .56252 .54481 L p
.56958 .53581 L 1 g
F P
s
P
p
.002 w
.57142 .55159 m .56034 .55333 L .56195 .54706 L p
1 g
F P
s
P
p
.002 w
.56958 .53581 m .57142 .55159 L p
.56195 .54706 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56758 .52886 L p
1 g
F P
s
P
p
.002 w
.56758 .52886 m .56654 .52734 L p
.56447 .53868 L 1 g
F P
s
P
p
.56447 .53868 m .56257 .5491 L .56758 .52886 L 1 g
F
P
p
.002 w
.56169 .54744 m .56169 .54744 L p
.55816 .55264 L 1 g
F P
s
P
p
.002 w
.56169 .54744 m .56075 .54566 L p
.55822 .55248 L 1 g
F P
s
P
p
.55822 .55248 m .55816 .55264 L .56169 .54744 L 1 g
F
P
p
.002 w
.54993 .55166 m .56741 .52412 L p
.56236 .54532 L 1 g
F P
s
P
p
.56195 .54706 m .56179 .54712 L .56236 .54532 L 1 g
F
P
p
.56179 .54712 m .54993 .55166 L .56236 .54532 L 1 g
F
P
p
.002 w
.56252 .54481 m .56746 .52552 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.56746 .52552 m .5681 .52304 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.56826 .48969 m .5681 .52304 L .56712 .52039 L p
1 g
F P
s
P
p
.002 w
.56608 .50936 m .56515 .50826 L p
.56728 .52208 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56608 .50936 L p
1 g
F P
s
P
p
.002 w
.55818 .4927 m .56433 .49086 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56433 .49086 m .56826 .48969 L p
.56743 .51221 L 1 g
F P
s
P
p
.56608 .50936 m .56743 .51221 L .56712 .52039 L 1 g
F
P
p
.56433 .49086 m .56743 .51221 L .56608 .50936 L 1 g
F
P
p
.002 w
.55175 .47991 m .54398 .46056 L p
.55772 .49167 L 1 g
F P
s
P
p
.55772 .49167 m .55818 .4927 L .5576 .49156 L 1 g
F
P
p
.55772 .49167 m .5576 .49156 L .55175 .47991 L 1 g
F
P
p
.55677 .49082 m .56225 .5013 L .55772 .49174 L 1 g
F
P
p
.55677 .49082 m .55772 .49174 L .55767 .49162 L 1 g
F
P
p
.002 w
.55767 .49162 m .55661 .4905 L p
.55677 .49082 L 1 g
F P
s
P
p
.002 w
.55864 .49256 m .55818 .4927 L p
.55772 .49167 L 1 g
F P
s
P
p
.55661 .4905 m .56608 .50936 L .56225 .5013 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5576 .49156 L p
1 g
F P
s
P
p
.54174 .47608 m .5576 .49156 L .55568 .48969 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55568 .48969 m .55703 .49305 L p
.54095 .47606 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .4767 L p
1 g
F P
s
P
p
.52214 .46667 m .54231 .4767 L .53354 .47257 L 1 g
F
P
p
.53295 .46761 m .54231 .4767 L .54095 .47606 L 1 g
F
P
p
.54231 .4767 m .55568 .48969 L .54095 .47606 L 1 g
F
P
p
.002 w
.52379 .47346 m .52873 .47031 L p
.55703 .49305 L 1 g
F P
s
P
p
.52214 .46667 m .53354 .47257 L .52873 .47031 L 1 g
F
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52873 .47031 m .52379 .47346 L .5178 .46657 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .5178 .46657 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5178 .46657 m .52379 .47346 L p
.49524 .46455 L 1 g
F P
s
P
p
.5 .4638 m .5178 .46657 L .49524 .46455 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.48128 .46673 m .49524 .46455 L .52379 .47346 L 1 g
F
P
p
.002 w
.5 .4638 m .5 .46442 L p
.48871 .46557 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .48871 .46557 L 1 g
F
P
p
.002 w
.47671 .47193 m .48128 .46673 L p
.52379 .47346 L 1 g
F P
s
P
p
.47786 .46667 m .48871 .46557 L .48128 .46673 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48128 .46673 m .47671 .47193 L .47302 .46945 L p
1 g
F P
s
P
p
.47751 .46724 m .48128 .46673 L .47302 .46945 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46724 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.45331 .48094 m .45354 .48071 L .47671 .47193 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47302 .46945 m .47671 .47193 L p
.45354 .48071 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45784 .47654 L p
1 g
F P
s
P
p
.44339 .4905 m .45784 .47654 L .44864 .48547 L 1 g
F
P
p
.42895 .49004 m .45784 .47654 L .45354 .48071 L 1 g
F
P
p
.45784 .47654 m .47302 .46945 L .45354 .48071 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44266 .49128 L p
1 g
F P
s
P
p
.43485 .50826 m .44266 .49128 L .441 .49457 L 1 g
F
P
p
.002 w
.42586 .52671 m .4288 .49038 L .43557 .4927 L p
1 g
F P
s
P
p
.002 w
.43557 .4927 m .441 .49457 L p
.43417 .50906 L 1 g
F P
s
P
p
.42586 .52671 m .43557 .4927 L .43417 .50906 L 1 g
F
P
p
.002 w
.43249 .52876 m .43346 .52734 L p
.43321 .52027 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4256 .52986 m .42586 .52671 L p
.43307 .52195 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43417 .50906 L p
1 g
F P
s
P
p
.43346 .52734 m .43417 .50906 L .43321 .52027 L 1 g
F
P
p
.43285 .5245 m .43307 .52195 L .46309 .50216 L 1 g
F
P
p
.4256 .52986 m .43307 .52195 L .43285 .5245 L 1 g
F
P
p
.43485 .50826 m .441 .49457 L .43777 .50144 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.441 .49457 m .4288 .49038 L p
.44655 .48354 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.441 .49457 m .46309 .50216 L p
.42586 .52671 L 1 g
F P
s
P
p
.002 w
.43417 .50906 m .43287 .51061 L p
.43321 .52027 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43292 .53049 m .4256 .52986 L p
.43166 .52539 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43237 .52893 L p
1 g
F P
s
P
p
.002 w
.43632 .56521 m .4256 .52986 L .43292 .53049 L p
1 g
F P
s
P
p
.43632 .56521 m .43389 .54039 L .44228 .55715 L 1 g
F
P
p
.43389 .54039 m .43292 .53049 L .43865 .5468 L 1 g
F
P
p
.43389 .54039 m .43865 .5468 L .44228 .55715 L 1 g
F
P
p
.43925 .54566 m .43237 .52893 L .43596 .53916 L 1 g
F
P
p
.002 w
.43749 .54899 m .43925 .54566 L p
.43419 .53566 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43865 .5468 L p
1 g
F P
s
P
p
.45146 .56129 m .43865 .5468 L .44569 .55628 L 1 g
F
P
p
.002 w
.43292 .53049 m .46027 .53284 L p
.44431 .55442 L 1 g
F P
s
P
p
.44228 .55715 m .43865 .5468 L .44431 .55442 L 1 g
F
P
p
.43865 .5468 m .43292 .53049 L .44431 .55442 L 1 g
F
P
p
.45146 .56129 m .44569 .55628 L .45073 .56306 L 1 g
F
P
p
.45921 .59268 m .45074 .56309 L .46373 .5766 L 1 g
F
P
p
.45074 .56309 m .45073 .56306 L .45078 .56311 L 1 g
F
P
p
.45074 .56309 m .45078 .56311 L .46373 .5766 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56311 L p
1 g
F P
s
P
p
.002 w
.45921 .59268 m .43632 .56521 L .45073 .56306 L p
1 g
F P
s
P
p
.46872 .57265 m .45078 .56311 L .46129 .56968 L 1 g
F
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.45073 .56306 L 1 g
F P
s
P
p
.002 w
.45073 .56306 m .46826 .56046 L p
.46373 .5766 L 1 g
F P
s
P
p
.002 w
.45078 .56311 m .45002 .56518 L p
.46129 .56968 L 1 g
F P
s
P
p
.002 w
.45078 .56312 m .45078 .56311 L p
.45073 .56306 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.46027 .53284 m .46826 .56046 L .43632 .56521 L p
1 g
F P
s
P
p
.002 w
.43865 .5468 m .43743 .5491 L p
.44569 .55628 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.44569 .55628 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.002 w
.43237 .52893 m .43146 .53025 L p
.43596 .53916 L 1 g
F P
s
P
p
.002 w
.46309 .50216 m .46027 .53284 L .43292 .53049 L p
1 g
F P
s
P
p
.43166 .52539 m .46309 .50216 L .43292 .53049 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43749 .54899 L p
1 g
F P
s
P
p
.43419 .53566 m .43146 .53025 L .43749 .54899 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43249 .52876 L p
1 g
F P
s
P
p
.43321 .52027 m .43287 .51061 L .43249 .52876 L 1 g
F
P
p
.43777 .50144 m .441 .49457 L .439 .49855 L 1 g
F
P
p
.002 w
.47671 .47193 m .46309 .50216 L .441 .49457 L p
1 g
F P
s
P
p
.002 w
.44266 .49128 m .44339 .4905 L p
.44864 .48547 L 1 g
F P
s
P
p
.44266 .49128 m .47671 .47193 L .441 .49457 L 1 g
F
P
p
.44655 .48354 m .45331 .48094 L .44266 .49128 L 1 g
F
P
p
.45331 .48094 m .47671 .47193 L .44266 .49128 L 1 g
F
P
p
.002 w
.44266 .49128 m .44166 .49233 L p
.439 .49855 L 1 g
F P
s
P
p
.002 w
.45784 .47654 m .45698 .47747 L p
.44864 .48547 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44266 .49128 L p
1 g
F P
s
P
p
.44864 .48547 m .45698 .47747 L .44266 .49128 L 1 g
F
P
p
.002 w
.4288 .49038 m .42895 .49004 L p
.45354 .48071 L 1 g
F P
s
P
p
.4288 .49038 m .45354 .48071 L .45331 .48094 L 1 g
F
P
p
.45826 .47608 m .47751 .46724 L .47001 .47093 L 1 g
F
P
p
.002 w
.45723 .4772 m .45826 .47608 L p
.47001 .47093 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.42895 .49004 m .44604 .45133 L .47302 .46945 L p
1 g
F P
s
P
p
.47001 .47093 m .47302 .46945 L .47718 .46778 L 1 g
F
P
p
.002 w
.47751 .46724 m .47742 .46739 L p
.47302 .46945 L 1 g
F P
s
P
p
.002 w
.47742 .46739 m .47718 .46778 L p
.47302 .46945 L 1 g
F P
s
P
p
.002 w
.47105 .46813 m .44604 .45133 L p
.47984 .4661 L 1 g
F P
s
P
p
.002 w
.47751 .46724 m .47786 .46667 L p
.48128 .46673 L 1 g
F P
s
P
p
.47984 .4661 m .48128 .46673 L .47751 .46724 L 1 g
F
P
p
.47984 .4661 m .47751 .46724 L .47105 .46813 L 1 g
F
P
p
.002 w
.47302 .46945 m .47105 .46813 L p
.47751 .46724 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45723 .4772 L p
1 g
F P
s
P
p
.47001 .47093 m .47718 .46778 L .45723 .4772 L 1 g
F
P
p
.002 w
.47747 .46732 m .47751 .46724 L p
.48128 .46673 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.49971 .44575 m .48128 .46673 L p
.44604 .45133 L 1 g
F P
s
P
p
.002 w
.48128 .46673 m .48579 .4616 L p
.49524 .46455 L 1 g
F P
s
P
p
.48579 .4616 m .5 .4638 L .49524 .46455 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46732 L p
1 g
F P
s
P
p
.48871 .46557 m .5 .46442 L .47747 .46732 L 1 g
F
P
p
.51099 .46551 m .5178 .46657 L .51299 .4659 L 1 g
F
P
p
.5 .4634 m .5178 .46657 L .51099 .46551 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.52248 .46723 m .52873 .47031 L .5178 .46657 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48579 .4616 m .49971 .44575 L .5178 .46657 L p
1 g
F P
s
P
p
.002 w
.5178 .46657 m .5153 .46369 L p
.52248 .46723 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52282 .46778 L p
.51299 .4659 L 1 g
F P
s
P
p
.002 w
.52259 .46742 m .52248 .46723 L p
.52873 .47031 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.52873 .47031 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54398 .46056 m .52873 .47031 L p
.49971 .44575 L 1 g
F P
s
P
p
.002 w
.5153 .46369 m .49971 .44575 L p
.52873 .47031 L 1 g
F P
s
P
p
.002 w
.52873 .47031 m .53295 .46761 L p
.54095 .47606 L 1 g
F P
s
P
p
.52873 .47031 m .54095 .47606 L .55703 .49305 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52259 .46742 L p
1 g
F P
s
P
p
.53354 .47257 m .54302 .47747 L .52259 .46742 L 1 g
F
P
p
.002 w
.54231 .4767 m .54302 .47747 L p
.53354 .47257 L 1 g
F P
s
P
p
.55042 .48458 m .55568 .48969 L .55113 .48528 L 1 g
F
P
p
.54174 .47608 m .55568 .48969 L .55042 .48458 L 1 g
F
P
p
.002 w
.54244 .47685 m .54174 .47608 L p
.55113 .48528 L 1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53295 .46761 m .54398 .46056 L .55568 .48969 L p
1 g
F P
s
P
p
.002 w
.55818 .4927 m .55703 .49305 L .55175 .47991 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .55767 .49162 L p
.56112 .49856 L 1 g
F P
s
P
p
.56225 .5013 m .56713 .51061 L .55767 .49162 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54244 .47685 L p
1 g
F P
s
P
p
.55113 .48528 m .55834 .49233 L .54244 .47685 L 1 g
F
P
p
.002 w
.5576 .49156 m .55834 .49233 L p
.55113 .48528 L 1 g
F P
s
P
p
.002 w
.56826 .48969 m .55864 .49256 L p
.54398 .46056 L 1 g
F P
s
P
p
.54398 .46056 m .55864 .49256 L .55772 .49167 L 1 g
F
P
p
.002 w
.56713 .51061 m .56594 .50816 L p
.56112 .49856 L 1 g
F P
s
P
p
.002 w
.56594 .50816 m .55834 .49233 L p
.56112 .49856 L 1 g
F P
s
P
p
.002 w
.56608 .50936 m .56713 .51061 L p
.56225 .5013 L 1 g
F P
s
P
p
.002 w
.56712 .52039 m .55703 .49305 L .55818 .4927 L p
1 g
F P
s
P
p
.55818 .4927 m .56608 .50936 L .56712 .52039 L 1 g
F
P
p
.002 w
.56696 .51042 m .56608 .50936 L p
.56737 .52265 L 1 g
F P
s
P
p
.56728 .52208 m .56737 .52265 L .56608 .50936 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56696 .51042 L p
1 g
F P
s
P
p
.56737 .52265 m .56854 .53025 L .56696 .51042 L 1 g
F
P
p
.002 w
.54687 .49955 m .55703 .49305 L .56712 .52039 L p
1 g
F P
s
P
p
.002 w
.56728 .52214 m .54687 .49955 L p
.56712 .52039 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53289 .52937 m .5341 .51879 L .56735 .52295 L p
1 g
F P
s
P
p
.002 w
.56737 .52317 m .53289 .52937 L p
.56735 .52295 L 1 g
F P
s
P
p
.002 w
.5341 .51879 m .53894 .50847 L .56733 .52265 L p
1 g
F P
s
P
p
.002 w
.56735 .52295 m .5341 .51879 L p
.56733 .52265 L 1 g
F P
s
P
p
.56736 .52312 m .56738 .52328 L .56737 .52318 L 1 g
F
P
p
.56727 .52203 m .56737 .52318 L .56734 .52249 L 1 g
F
P
p
.002 w
.53894 .50847 m .54687 .49955 L .56728 .52214 L p
1 g
F P
s
P
p
.002 w
.56733 .52265 m .53894 .50847 L p
.56728 .52214 L 1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.5413 .54673 m .53539 .53903 L .56738 .52339 L p
1 g
F P
s
P
p
.002 w
.56739 .52366 m .5413 .54673 L p
.56738 .52339 L 1 g
F P
s
P
p
.56734 .52249 m .56739 .52366 L .56736 .52258 L 1 g
F
P
p
.56739 .52366 m .56741 .52412 L .5674 .52385 L 1 g
F
P
p
.56739 .52366 m .5674 .52385 L .56736 .52258 L 1 g
F
P
p
.002 w
.54993 .55166 m .5413 .54673 L .56739 .52366 L p
1 g
F P
s
P
p
.002 w
.56741 .52412 m .54993 .55166 L p
.56739 .52366 L 1 g
F P
s
P
p
.002 w
.56746 .52552 m .56195 .54706 L p
.56741 .52412 L 1 g
F P
s
P
p
.56736 .52258 m .56746 .52552 L .56737 .52265 L 1 g
F
P
p
.002 w
.56757 .52884 m .56854 .53025 L p
.56737 .52265 L 1 g
F P
s
P
p
.56448 .53864 m .56252 .54481 L .56447 .53868 L 1 g
F
P
p
.002 w
.55791 .55294 m .54993 .55166 L p
.56195 .54706 L 1 g
F P
s
P
p
.002 w
.56169 .54744 m .56257 .5491 L p
.56447 .53868 L 1 g
F P
s
P
p
.55822 .55248 m .55791 .55294 L .55816 .55264 L 1 g
F
P
p
.002 w
.56206 .54814 m .56169 .54744 L p
.55816 .55264 L 1 g
F P
s
P
p
.002 w
.54993 .55166 m .55791 .55294 L p
.55031 .56172 L 1 g
F P
s
P
p
.002 w
.55791 .55294 m .56034 .55333 L p
.55031 .56172 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56206 .54814 L p
1 g
F P
s
P
p
.55467 .55668 m .54998 .56518 L .56206 .54814 L 1 g
F
P
p
.002 w
.54918 .56302 m .54998 .56518 L p
.55467 .55668 L 1 g
F P
s
P
p
.002 w
.53122 .5753 m .54993 .55166 L p
.55031 .56172 L 1 g
F P
s
P
p
.54921 .563 m .53122 .5753 L .55031 .56172 L 1 g
F
P
p
.55097 .57919 m .53122 .5753 L .55053 .56749 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56302 L p
1 g
F P
s
P
p
.54016 .56928 m .5322 .57686 L .54918 .56302 L 1 g
F
P
p
.002 w
.53181 .57507 m .5322 .57686 L p
.54016 .56928 L 1 g
F P
s
P
p
.002 w
.53093 .57568 m .53122 .5753 L p
.53141 .57534 L 1 g
F P
s
P
p
.002 w
.5413 .54673 m .54993 .55166 L .53122 .5753 L p
1 g
F P
s
P
p
.002 w
.53122 .5753 m .5306 .57609 L p
.53083 .57544 L 1 g
F P
s
P
p
.53083 .57544 m .5413 .54673 L .53122 .5753 L 1 g
F
P
p
.002 w
.51354 .56662 m .5413 .54673 L p
.53083 .57544 L 1 g
F P
s
P
p
.002 w
.52998 .57575 m .51354 .56662 L p
.53083 .57544 L 1 g
F P
s
P
p
.53033 .57562 m .52998 .57575 L .53032 .57567 L 1 g
F
P
p
.002 w
.53186 .5753 m .53181 .57507 L p
.53032 .57567 L 1 g
F P
s
P
p
.002 w
.51354 .56662 m .52998 .57575 L p
.51229 .57999 L 1 g
F P
s
P
p
.002 w
.52998 .57575 m .5306 .57609 L p
.51229 .57999 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53186 .5753 L p
1 g
F P
s
P
p
.52108 .57788 m .51111 .583 L .53186 .5753 L 1 g
F
P
p
.002 w
.51092 .58032 m .51111 .583 L p
.52108 .57788 L 1 g
F P
s
P
p
.002 w
.48807 .58084 m .51354 .56662 L p
.51229 .57999 L 1 g
F P
s
P
p
.51097 .5803 m .48807 .58084 L .51229 .57999 L 1 g
F
P
p
.51082 .5956 m .48807 .58084 L .51182 .58501 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58032 L p
1 g
F P
s
P
p
.5007 .58064 m .48889 .583 L .51092 .58032 L 1 g
F
P
p
.002 w
.48903 .581 m .48889 .583 L p
.5007 .58064 L 1 g
F P
s
P
p
.002 w
.4877 .58105 m .48807 .58084 L p
.48837 .58102 L 1 g
F P
s
P
p
.002 w
.50169 .55165 m .51354 .56662 L .48807 .58084 L p
1 g
F P
s
P
p
.48669 .58046 m .50169 .55165 L .48807 .58084 L 1 g
F
P
p
.48625 .58034 m .48393 .57972 L .48602 .58047 L 1 g
F
P
p
.002 w
.48899 .58155 m .48903 .581 L p
.48602 .58047 L 1 g
F P
s
P
p
.002 w
.46826 .56046 m .48393 .57972 L p
.46479 .57282 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4684 .57413 L p
1 g
F P
s
P
p
.46129 .56968 m .45002 .56518 L .4684 .57413 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58155 L p
1 g
F P
s
P
p
.47841 .57773 m .4678 .57686 L .48899 .58155 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51498 .45086 L
s
P
p
.004 w
.5376 .4816 m
.54955 .49784 L
s
P
p
.002 w
.58937 .29233 m .52956 .2885 L .51895 .26645 L p
1 g
F P
s
P
p
.002 w
.45447 .28345 m .51895 .26645 L .52956 .2885 L p
1 g
F P
s
P
p
.002 w
.52956 .2885 m .58937 .29233 L .5949 .31872 L p
1 g
F P
s
P
p
.002 w
.57142 .55159 m .58198 .54666 L .593 .56609 L p
1 g
F P
s
P
p
.002 w
.593 .56609 m .57251 .57571 L .57142 .55159 L p
1 g
F P
s
P
p
.002 w
.6104 .55133 m .593 .56609 L .58198 .54666 L p
1 g
F P
s
P
p
.004 w
.59657 .56173 m
.60904 .57867 L
s
P
p
.002 w
.4256 .52986 m .43632 .56521 L .40697 .56585 L p
1 g
F P
s
P
p
.002 w
.40697 .56585 m .39374 .52392 L .4256 .52986 L p
1 g
F P
s
P
p
.002 w
.58198 .54666 m .59095 .53904 L .6104 .55133 L p
1 g
F P
s
P
p
.002 w
.62294 .53292 m .6104 .55133 L .59095 .53904 L p
1 g
F P
s
P
p
.002 w
.56034 .55333 m .57142 .55159 L .57251 .57571 L p
1 g
F P
s
P
p
.002 w
.57251 .57571 m .55097 .57919 L .56034 .55333 L p
1 g
F P
s
P
p
.002 w
.59095 .53904 m .59737 .52955 L .62294 .53292 L p
1 g
F P
s
P
p
.002 w
.62929 .51269 m .62294 .53292 L .59737 .52955 L p
1 g
F P
s
P
p
.002 w
.62929 .51269 m .6287 .49271 L .65281 .47494 L p
1 g
F P
s
P
p
.002 w
.64203 .44914 m .65281 .47494 L .6287 .49271 L p
1 g
F P
s
P
p
.002 w
.65281 .47494 m .64203 .44914 L .65832 .42312 L p
1 g
F P
s
P
p
.002 w
.41203 .34027 m .36956 .38978 L .35215 .37187 L p
1 g
F P
s
P
p
.002 w
.35215 .37187 m .39632 .32016 L .41203 .34027 L p
1 g
F P
s
P
p
.002 w
.39707 .47688 m .39374 .52392 L .36575 .51532 L p
1 g
F P
s
P
p
.002 w
.36575 .51532 m .36904 .46222 L .39707 .47688 L p
1 g
F P
s
P
p
.002 w
.63277 .39754 m .65832 .42312 L .64203 .44914 L p
1 g
F P
s
P
p
.002 w
.65832 .42312 m .63277 .39754 L .63946 .36719 L p
1 g
F P
s
P
p
.002 w
.39149 .40946 m .36904 .46222 L .34561 .44695 L p
1 g
F P
s
P
p
.002 w
.34561 .44695 m .36956 .38978 L .39149 .40946 L p
1 g
F P
s
P
p
.002 w
.52956 .2885 m .4678 .30502 L .45447 .28345 L p
1 g
F P
s
P
p
.002 w
.39632 .32016 m .45447 .28345 L .4678 .30502 L p
1 g
F P
s
P
p
.002 w
.59737 .52955 m .60056 .51915 L .62929 .51269 L p
1 g
F P
s
P
p
.002 w
.6287 .49271 m .62929 .51269 L .60056 .51915 L p
1 g
F P
s
P
p
.002 w
.59768 .34922 m .63946 .36719 L .63277 .39754 L p
1 g
F P
s
P
p
.002 w
.63946 .36719 m .59768 .34922 L .5949 .31872 L p
1 g
F P
s
P
p
.002 w
.4678 .30502 m .41203 .34027 L .39632 .32016 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.53959 .31555 m .5949 .31872 L .59768 .34922 L p
1 g
F P
s
P
p
.002 w
.5949 .31872 m .53959 .31555 L .52956 .2885 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4678 .30502 m .52956 .2885 L .53959 .31555 L p
1 g
F P
s
P
p
.002 w
.6287 .49271 m .62109 .47511 L .64203 .44914 L p
1 g
F P
s
P
p
.002 w
.62188 .42948 m .64203 .44914 L .62109 .47511 L p
1 g
F P
s
P
p
.002 w
.64203 .44914 m .62188 .42948 L .63277 .39754 L p
1 g
F P
s
P
p
.002 w
.60056 .51915 m .60015 .50896 L .6287 .49271 L p
1 g
F P
s
P
p
.002 w
.62109 .47511 m .6287 .49271 L .60015 .50896 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.58198 .54666 m .57142 .55159 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.59095 .53904 m .58198 .54666 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.59737 .52955 m .59095 .53904 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.4288 .49038 m .4256 .52986 L .39374 .52392 L p
1 g
F P
s
P
p
.002 w
.39374 .52392 m .39707 .47688 L .4288 .49038 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60056 .51915 m .59737 .52955 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.5975 .38283 m .63277 .39754 L .62188 .42948 L p
1 g
F P
s
P
p
.002 w
.63277 .39754 m .5975 .38283 L .59768 .34922 L p
1 g
F P
s
P
p
.002 w
.53539 .53903 m .5413 .54673 L .51354 .56662 L p
1 g
F P
s
P
p
.002 w
.51354 .56662 m .50169 .55165 L .53539 .53903 L p
1 g
F P
s
P
p
.002 w
.43091 .36374 m .39149 .40946 L .36956 .38978 L p
1 g
F P
s
P
p
.002 w
.36956 .38978 m .41203 .34027 L .43091 .36374 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.41728 .43023 m .39707 .47688 L .36904 .46222 L p
1 g
F P
s
P
p
.002 w
.36904 .46222 m .39149 .40946 L .41728 .43023 L p
1 g
F P
s
P
p
.002 w
.60015 .50896 m .60056 .51915 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.49648 .53268 m .50169 .55165 L .46826 .56046 L p
1 g
F P
s
P
p
.002 w
.46826 .56046 m .46027 .53284 L .49648 .53268 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.53959 .31555 m .4825 .33107 L .4678 .30502 L p
1 g
F P
s
P
p
.002 w
.41203 .34027 m .4678 .30502 L .4825 .33107 L p
1 g
F P
s
P
p
.002 w
.60015 .50896 m .59616 .50006 L .62109 .47511 L p
1 g
F P
s
P
p
.002 w
.60711 .46185 m .62109 .47511 L .59616 .50006 L p
1 g
F P
s
P
p
.002 w
.62109 .47511 m .60711 .46185 L .62188 .42948 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.59616 .50006 m .60015 .50896 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.54862 .34679 m .59768 .34922 L .5975 .38283 L p
1 g
F P
s
P
p
.002 w
.59768 .34922 m .54862 .34679 L .53959 .31555 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.4825 .33107 m .43091 .36374 L .41203 .34027 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59431 .41837 m .62188 .42948 L .60711 .46185 L p
1 g
F P
s
P
p
.002 w
.62188 .42948 m .59431 .41837 L .5975 .38283 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.4825 .33107 m .53959 .31555 L .54862 .34679 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50631 .33673 L
s
P
p
.004 w
.50738 .32076 m
.51063 .27251 L
s
P
p
.002 w
.53289 .52937 m .53539 .53903 L .50169 .55165 L p
1 g
F P
s
P
p
.002 w
.50169 .55165 m .49648 .53268 L .53289 .52937 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58896 .49343 m .59616 .50006 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.59616 .50006 m .58896 .49343 L .60711 .46185 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.57931 .48983 m .58896 .49343 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.56826 .48969 m .57931 .48983 L .5681 .52304 L closepath p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44604 .45133 m .4288 .49038 L .39707 .47688 L p
1 g
F P
s
P
p
.002 w
.39707 .47688 m .41728 .43023 L .44604 .45133 L p
1 g
F P
s
P
p
.002 w
.58817 .45449 m .60711 .46185 L .58896 .49343 L p
1 g
F P
s
P
p
.002 w
.60711 .46185 m .58817 .45449 L .59431 .41837 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.45235 .3898 m .41728 .43023 L .39149 .40946 L p
1 g
F P
s
P
p
.002 w
.39149 .40946 m .43091 .36374 L .45235 .3898 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.49865 .51175 m .49648 .53268 L .46027 .53284 L p
1 g
F P
s
P
p
.002 w
.46027 .53284 m .46309 .50216 L .49865 .51175 L p
1 g
F P
s
P
p
.002 w
.58896 .49343 m .57931 .48983 L .58817 .45449 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.55628 .38115 m .5975 .38283 L .59431 .41837 L p
1 g
F P
s
P
p
.002 w
.5975 .38283 m .55628 .38115 L .54862 .34679 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5341 .51879 m .53289 .52937 L .49648 .53268 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49648 .53268 m .49865 .51175 L .5341 .51879 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.54862 .34679 m .49806 .36079 L .4825 .33107 L p
1 g
F P
s
P
p
.004 w
.50658 .33262 m
.50738 .32076 L
s
P
p
.004 w
.50653 .33342 m
.50658 .33262 L
s
P
p
.002 w
.43091 .36374 m .4825 .33107 L .49806 .36079 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57931 .48983 m .56826 .48969 L .5663 .45401 L p
1 g
F P
s
P
p
.002 w
.5663 .45401 m .58817 .45449 L .57931 .48983 L p
1 g
F P
s
P
p
.002 w
.49806 .36079 m .54862 .34679 L .55628 .38115 L p
1 g
F P
s
P
p
.002 w
.49806 .36079 m .45235 .3898 L .43091 .36374 L p
1 g
F P
s
P
p
.002 w
.56226 .41736 m .59431 .41837 L .58817 .45449 L p
1 g
F P
s
P
p
.002 w
.59431 .41837 m .56226 .41736 L .55628 .38115 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.53894 .50847 m .5341 .51879 L .49865 .51175 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.58817 .45449 m .5663 .45401 L .56226 .41736 L p
1 g
F P
s
P
p
.002 w
.54398 .46056 m .5663 .45401 L .56826 .48969 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54687 .49955 m .53894 .50847 L .50808 .49122 L p
1 g
F P
s
P
p
.002 w
.49865 .51175 m .50808 .49122 L .53894 .50847 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.55703 .49305 m .54687 .49955 L .52379 .47346 L p
1 g
F P
s
P
p
.002 w
.50808 .49122 m .52379 .47346 L .54687 .49955 L p
1 g
F P
s
P
p
.002 w
.47558 .41749 m .44604 .45133 L .41728 .43023 L p
1 g
F P
s
P
p
.002 w
.41728 .43023 m .45235 .3898 L .47558 .41749 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.50808 .49122 m .49865 .51175 L .46309 .50216 L p
1 g
F P
s
P
p
.002 w
.46309 .50216 m .47671 .47193 L .50808 .49122 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51391 .39311 m .55628 .38115 L .56226 .41736 L p
1 g
F P
s
P
p
.002 w
.55628 .38115 m .51391 .39311 L .49806 .36079 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.5663 .45401 m .54398 .46056 L .52942 .42681 L p
1 g
F P
s
P
p
.002 w
.52942 .42681 m .56226 .41736 L .5663 .45401 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.45235 .3898 m .49806 .36079 L .51391 .39311 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.56226 .41736 m .52942 .42681 L .51391 .39311 L p
1 g
F P
s
P
p
.002 w
.51391 .39311 m .47558 .41749 L .45235 .3898 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.52379 .47346 m .50808 .49122 L .47671 .47193 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.44604 .45133 m .47558 .41749 L .49971 .44575 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49971 .44575 m .52942 .42681 L .54398 .46056 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.47558 .41749 m .51391 .39311 L .52942 .42681 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52942 .42681 m .49971 .44575 L .47558 .41749 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59084 .55393 m
.59657 .56173 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .51063 .27251 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60904 .57867 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0663158)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0663158)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48205 .47305 m .52048 .45627 L .50582 .43187 L p
1 g
F P
s
P
p
.002 w
.50582 .43187 m .47379 .4458 L .48205 .47305 L p
1 g
F P
s
P
p
.002 w
.53297 .41007 m .50582 .43187 L .52048 .45627 L p
1 g
F P
s
P
p
.002 w
.47379 .4458 m .50582 .43187 L .49104 .40745 L p
1 g
F P
s
P
p
.002 w
.50582 .43187 m .53297 .41007 L .51206 .3905 L p
1 g
F P
s
P
p
.002 w
.51206 .3905 m .49104 .40745 L .50582 .43187 L p
1 g
F P
s
P
p
.002 w
.49104 .40745 m .46619 .41822 L .47379 .4458 L p
1 g
F P
s
P
p
.002 w
.46619 .41822 m .49104 .40745 L .4764 .38346 L p
1 g
F P
s
P
p
.002 w
.49104 .40745 m .51206 .3905 L .49076 .37182 L p
1 g
F P
s
P
p
.002 w
.49076 .37182 m .4764 .38346 L .49104 .40745 L p
1 g
F P
s
P
p
.002 w
.4414 .47889 m .48205 .47305 L .47379 .4458 L p
1 g
F P
s
P
p
.002 w
.47379 .4458 m .43993 .45049 L .4414 .47889 L p
1 g
F P
s
P
p
.002 w
.43993 .45049 m .47379 .4458 L .46619 .41822 L p
1 g
F P
s
P
p
.002 w
.49081 .49948 m .53474 .48023 L .52048 .45627 L p
1 g
F P
s
P
p
.002 w
.52048 .45627 m .48205 .47305 L .49081 .49948 L p
1 g
F P
s
P
p
.002 w
.55313 .43018 m .52048 .45627 L .53474 .48023 L p
1 g
F P
s
P
p
.002 w
.52048 .45627 m .55313 .43018 L .53297 .41007 L p
1 g
F P
s
P
p
.002 w
.46619 .41822 m .43992 .42172 L .43993 .45049 L p
1 g
F P
s
P
p
.002 w
.43992 .42172 m .46619 .41822 L .45936 .39082 L p
1 g
F P
s
P
p
.002 w
.4764 .38346 m .45936 .39082 L .46619 .41822 L p
1 g
F P
s
P
p
.002 w
.5526 .38244 m .53297 .41007 L .55313 .43018 L p
1 g
F P
s
P
p
.002 w
.53297 .41007 m .5526 .38244 L .52713 .369 L p
1 g
F P
s
P
p
.002 w
.52713 .369 m .51206 .3905 L .53297 .41007 L p
1 g
F P
s
P
p
.002 w
.51206 .3905 m .52713 .369 L .50098 .35706 L p
1 g
F P
s
P
p
.002 w
.50098 .35706 m .49076 .37182 L .51206 .3905 L p
1 g
F P
s
P
p
.002 w
.44432 .5064 m .49081 .49948 L .48205 .47305 L p
1 g
F P
s
P
p
.002 w
.48205 .47305 m .4414 .47889 L .44432 .5064 L p
1 g
F P
s
P
p
.002 w
.45936 .39082 m .4764 .38346 L .46216 .36034 L p
1 g
F P
s
P
p
.002 w
.4764 .38346 m .49076 .37182 L .46948 .35438 L p
1 g
F P
s
P
p
.002 w
.46948 .35438 m .46216 .36034 L .4764 .38346 L p
1 g
F P
s
P
p
.002 w
.53474 .48023 m .57217 .45047 L .55313 .43018 L p
1 g
F P
s
P
p
.002 w
.57692 .39712 m .55313 .43018 L .57217 .45047 L p
1 g
F P
s
P
p
.002 w
.55313 .43018 m .57692 .39712 L .5526 .38244 L p
1 g
F P
s
P
p
.002 w
.45936 .39082 m .44138 .39312 L .43992 .42172 L p
1 g
F P
s
P
p
.002 w
.44138 .39312 m .45936 .39082 L .45346 .36409 L p
1 g
F P
s
P
p
.002 w
.46216 .36034 m .45346 .36409 L .45936 .39082 L p
1 g
F P
s
P
p
.002 w
.49076 .37182 m .50098 .35706 L .47464 .34683 L p
1 g
F P
s
P
p
.002 w
.47464 .34683 m .46948 .35438 L .49076 .37182 L p
1 g
F P
s
P
p
.002 w
.49992 .52459 m .54834 .50329 L .53474 .48023 L p
1 g
F P
s
P
p
.002 w
.53474 .48023 m .49081 .49948 L .49992 .52459 L p
1 g
F P
s
P
p
.002 w
.57217 .45047 m .53474 .48023 L .54834 .50329 L p
1 g
F P
s
P
p
.002 w
.40748 .44533 m .43993 .45049 L .43992 .42172 L p
1 g
F P
s
P
p
.002 w
.43992 .42172 m .41485 .41751 L .40748 .44533 L p
1 g
F P
s
P
p
.002 w
.41485 .41751 m .43992 .42172 L .44138 .39312 L p
1 g
F P
s
P
p
.002 w
.40232 .47302 m .4414 .47889 L .43993 .45049 L p
1 g
F P
s
P
p
.002 w
.43993 .45049 m .40748 .44533 L .40232 .47302 L p
1 g
F P
s
P
p
.002 w
.53466 .34503 m .52713 .369 L .5526 .38244 L p
1 g
F P
s
P
p
.002 w
.52713 .369 m .53466 .34503 L .50597 .34065 L p
1 g
F P
s
P
p
.002 w
.50597 .34065 m .50098 .35706 L .52713 .369 L p
1 g
F P
s
P
p
.002 w
.44138 .39312 m .42428 .3901 L .41485 .41751 L p
1 g
F P
s
P
p
.002 w
.42428 .3901 m .44138 .39312 L .44428 .36522 L p
1 g
F P
s
P
p
.002 w
.45346 .36409 m .44428 .36522 L .44138 .39312 L p
1 g
F P
s
P
p
.002 w
.44867 .53247 m .49992 .52459 L .49081 .49948 L p
1 g
F P
s
P
p
.002 w
.49081 .49948 m .44432 .5064 L .44867 .53247 L p
1 g
F P
s
P
p
.002 w
.56263 .35154 m .5526 .38244 L .57692 .39712 L p
1 g
F P
s
P
p
.002 w
.5526 .38244 m .56263 .35154 L .53466 .34503 L p
1 g
F P
s
P
p
.002 w
.50098 .35706 m .50597 .34065 L .47709 .33847 L p
1 g
F P
s
P
p
.002 w
.47709 .33847 m .47464 .34683 L .50098 .35706 L p
1 g
F P
s
P
p
.002 w
.54834 .50329 m .5897 .47055 L .57217 .45047 L p
1 g
F P
s
P
p
.002 w
.59961 .41279 m .57217 .45047 L .5897 .47055 L p
1 g
F P
s
P
p
.002 w
.57217 .45047 m .59961 .41279 L .57692 .39712 L p
1 g
F P
s
P
p
.002 w
.39953 .50004 m .44432 .5064 L .4414 .47889 L p
1 g
F P
s
P
p
.002 w
.4414 .47889 m .40232 .47302 L .39953 .50004 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .45346 .36409 L .46216 .36034 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .46216 .36034 L .46948 .35438 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .44428 .36522 L .45346 .36409 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .46948 .35438 L .47464 .34683 L closepath p
1 g
F P
s
P
p
.002 w
.58933 .36007 m .57692 .39712 L .59961 .41279 L p
1 g
F P
s
P
p
.002 w
.57692 .39712 m .58933 .36007 L .56263 .35154 L p
1 g
F P
s
P
p
.002 w
.39356 .40583 m .41485 .41751 L .42428 .3901 L p
1 g
F P
s
P
p
.002 w
.42428 .3901 m .40987 .38197 L .39356 .40583 L p
1 g
F P
s
P
p
.002 w
.40987 .38197 m .42428 .3901 L .4356 .3636 L p
1 g
F P
s
P
p
.002 w
.44428 .36522 m .4356 .3636 L .42428 .3901 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .4356 .3636 L .44428 .36522 L closepath p
1 g
F P
s
P
p
.002 w
.37975 .43053 m .40748 .44533 L .41485 .41751 L p
1 g
F P
s
P
p
.002 w
.41485 .41751 m .39356 .40583 L .37975 .43053 L p
1 g
F P
s
P
p
.002 w
.50921 .54786 m .56102 .525 L .54834 .50329 L p
1 g
F P
s
P
p
.002 w
.54834 .50329 m .49992 .52459 L .50921 .54786 L p
1 g
F P
s
P
p
.002 w
.5897 .47055 m .54834 .50329 L .56102 .525 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .47464 .34683 L .47709 .33847 L closepath p
1 g
F P
s
P
p
.002 w
.5051 .3243 m .50597 .34065 L .53466 .34503 L p
1 g
F P
s
P
p
.002 w
.50597 .34065 m .5051 .3243 L .47655 .33018 L p
1 g
F P
s
P
p
.002 w
.47655 .33018 m .47709 .33847 L .50597 .34065 L p
1 g
F P
s
P
p
.002 w
.53368 .32101 m .53466 .34503 L .56263 .35154 L p
1 g
F P
s
P
p
.002 w
.53466 .34503 m .53368 .32101 L .5051 .3243 L p
1 g
F P
s
P
p
.002 w
.4356 .3636 m .42834 .3594 L .40987 .38197 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .42834 .3594 L .4356 .3636 L closepath p
1 g
F P
s
P
p
.002 w
.36875 .45558 m .40232 .47302 L .40748 .44533 L p
1 g
F P
s
P
p
.002 w
.40748 .44533 m .37975 .43053 L .36875 .45558 L p
1 g
F P
s
P
p
.002 w
.4544 .55654 m .50921 .54786 L .49992 .52459 L p
1 g
F P
s
P
p
.002 w
.49992 .52459 m .44867 .53247 L .4544 .55654 L p
1 g
F P
s
P
p
.002 w
.39921 .52584 m .44867 .53247 L .44432 .5064 L p
1 g
F P
s
P
p
.002 w
.44432 .5064 m .39953 .50004 L .39921 .52584 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .47709 .33847 L .47655 .33018 L closepath p
1 g
F P
s
P
p
.002 w
.56102 .525 m .60536 .49005 L .5897 .47055 L p
1 g
F P
s
P
p
.002 w
.62021 .42915 m .5897 .47055 L .60536 .49005 L p
1 g
F P
s
P
p
.002 w
.5897 .47055 m .62021 .42915 L .59961 .41279 L p
1 g
F P
s
P
p
.002 w
.56173 .32042 m .56263 .35154 L .58933 .36007 L p
1 g
F P
s
P
p
.002 w
.56263 .35154 m .56173 .32042 L .53368 .32101 L p
1 g
F P
s
P
p
.002 w
.39973 .36951 m .40987 .38197 L .42834 .3594 L p
1 g
F P
s
P
p
.002 w
.42834 .3594 m .42329 .35302 L .39973 .36951 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .42329 .35302 L .42834 .3594 L closepath p
1 g
F P
s
P
p
.002 w
.6142 .37049 m .59961 .41279 L .62021 .42915 L p
1 g
F P
s
P
p
.002 w
.59961 .41279 m .6142 .37049 L .58933 .36007 L p
1 g
F P
s
P
p
.002 w
.37841 .38771 m .39356 .40583 L .40987 .38197 L p
1 g
F P
s
P
p
.002 w
.40987 .38197 m .39973 .36951 L .37841 .38771 L p
1 g
F P
s
P
p
.002 w
.47304 .32287 m .47655 .33018 L .5051 .3243 L p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .47655 .33018 L .47304 .32287 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .44034 .3163 L .43204 .32134 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .43204 .32134 L .42563 .32837 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .42563 .32837 L .42182 .33662 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .42182 .33662 L .42102 .34514 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .42102 .34514 L .42329 .35302 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .47304 .32287 L .46691 .31733 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .46691 .31733 L .4588 .31419 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .4588 .31419 L .44961 .31383 L closepath p
1 g
F P
s
P
p
.002 w
.4486 .33854 m .44961 .31383 L .44034 .3163 L closepath p
1 g
F P
s
P
p
.002 w
.49835 .30974 m .5051 .3243 L .53368 .32101 L p
1 g
F P
s
P
p
.002 w
.5051 .3243 m .49835 .30974 L .47304 .32287 L p
1 g
F P
s
P
p
.002 w
.36087 .48047 m .39953 .50004 L .40232 .47302 L p
1 g
F P
s
P
p
.002 w
.40232 .47302 m .36875 .45558 L .36087 .48047 L p
1 g
F P
s
P
p
.002 w
.39505 .35397 m .39973 .36951 L .42329 .35302 L p
1 g
F P
s
P
p
.002 w
.42329 .35302 m .42102 .34514 L .39505 .35397 L p
1 g
F P
s
P
p
.002 w
.35981 .40728 m .37975 .43053 L .39356 .40583 L p
1 g
F P
s
P
p
.002 w
.39356 .40583 m .37841 .38771 L .35981 .40728 L p
1 g
F P
s
P
p
.002 w
.46691 .31733 m .47304 .32287 L .49835 .30974 L p
1 g
F P
s
P
p
.002 w
.51851 .56878 m .57248 .54489 L .56102 .525 L p
1 g
F P
s
P
p
.002 w
.56102 .525 m .50921 .54786 L .51851 .56878 L p
1 g
F P
s
P
p
.002 w
.60536 .49005 m .56102 .525 L .57248 .54489 L p
1 g
F P
s
P
p
.002 w
.58868 .32259 m .58933 .36007 L .6142 .37049 L p
1 g
F P
s
P
p
.002 w
.58933 .36007 m .58868 .32259 L .56173 .32042 L p
1 g
F P
s
P
p
.002 w
.40145 .54982 m .4544 .55654 L .44867 .53247 L p
1 g
F P
s
P
p
.002 w
.44867 .53247 m .39921 .52584 L .40145 .54982 L p
1 g
F P
s
P
p
.002 w
.52403 .29947 m .53368 .32101 L .56173 .32042 L p
1 g
F P
s
P
p
.002 w
.53368 .32101 m .52403 .29947 L .49835 .30974 L p
1 g
F P
s
P
p
.002 w
.39647 .33701 m .39505 .35397 L .42102 .34514 L p
1 g
F P
s
P
p
.002 w
.42102 .34514 m .42182 .33662 L .39647 .33701 L p
1 g
F P
s
P
p
.002 w
.37124 .3649 m .37841 .38771 L .39973 .36951 L p
1 g
F P
s
P
p
.002 w
.39973 .36951 m .39505 .35397 L .37124 .3649 L p
1 g
F P
s
P
p
.002 w
.46144 .57805 m .51851 .56878 L .50921 .54786 L p
1 g
F P
s
P
p
.002 w
.50921 .54786 m .4544 .55654 L .46144 .57805 L p
1 g
F P
s
P
p
.002 w
.49835 .30974 m .48633 .29862 L .46691 .31733 L p
1 g
F P
s
P
p
.002 w
.4588 .31419 m .46691 .31733 L .48633 .29862 L p
1 g
F P
s
P
p
.002 w
.60536 .49005 m .63823 .44592 L .62021 .42915 L p
1 g
F P
s
P
p
.002 w
.63669 .38264 m .62021 .42915 L .63823 .44592 L p
1 g
F P
s
P
p
.002 w
.62021 .42915 m .63669 .38264 L .6142 .37049 L p
1 g
F P
s
P
p
.002 w
.3444 .42786 m .36875 .45558 L .37975 .43053 L p
1 g
F P
s
P
p
.002 w
.37975 .43053 m .35981 .40728 L .3444 .42786 L p
1 g
F P
s
P
p
.002 w
.48633 .29862 m .49835 .30974 L .52403 .29947 L p
1 g
F P
s
P
p
.002 w
.57248 .54489 m .61876 .50855 L .60536 .49005 L p
1 g
F P
s
P
p
.002 w
.63823 .44592 m .60536 .49005 L .61876 .50855 L p
1 g
F P
s
P
p
.002 w
.40395 .32053 m .39647 .33701 L .42182 .33662 L p
1 g
F P
s
P
p
.002 w
.42182 .33662 m .42563 .32837 L .40395 .32053 L p
1 g
F P
s
P
p
.002 w
.35637 .50467 m .39921 .52584 L .39953 .50004 L p
1 g
F P
s
P
p
.002 w
.39953 .50004 m .36087 .48047 L .35637 .50467 L p
1 g
F P
s
P
p
.002 w
.48633 .29862 m .47027 .29224 L .4588 .31419 L p
1 g
F P
s
P
p
.002 w
.44961 .31383 m .4588 .31419 L .47027 .29224 L p
1 g
F P
s
P
p
.002 w
.54957 .29233 m .56173 .32042 L .58868 .32259 L p
1 g
F P
s
P
p
.002 w
.56173 .32042 m .54957 .29233 L .52403 .29947 L p
1 g
F P
s
P
p
.002 w
.41673 .30641 m .40395 .32053 L .42563 .32837 L p
1 g
F P
s
P
p
.002 w
.42563 .32837 m .43204 .32134 L .41673 .30641 L p
1 g
F P
s
P
p
.002 w
.47027 .29224 m .45192 .29141 L .44961 .31383 L p
1 g
F P
s
P
p
.002 w
.44034 .3163 m .44961 .31383 L .45192 .29141 L p
1 g
F P
s
P
p
.002 w
.43336 .29632 m .41673 .30641 L .43204 .32134 L p
1 g
F P
s
P
p
.002 w
.43204 .32134 m .44034 .3163 L .43336 .29632 L p
1 g
F P
s
P
p
.002 w
.45192 .29141 m .43336 .29632 L .44034 .3163 L p
1 g
F P
s
P
p
.002 w
.35017 .37775 m .35981 .40728 L .37841 .38771 L p
1 g
F P
s
P
p
.002 w
.37841 .38771 m .37124 .3649 L .35017 .37775 L p
1 g
F P
s
P
p
.002 w
.61392 .32755 m .6142 .37049 L .63669 .38264 L p
1 g
F P
s
P
p
.002 w
.6142 .37049 m .61392 .32755 L .58868 .32259 L p
1 g
F P
s
P
p
.002 w
.37312 .33981 m .37124 .3649 L .39505 .35397 L p
1 g
F P
s
P
p
.002 w
.39505 .35397 m .39647 .33701 L .37312 .33981 L p
1 g
F P
s
P
p
.002 w
.52403 .29947 m .5065 .28287 L .48633 .29862 L p
1 g
F P
s
P
p
.002 w
.47027 .29224 m .48633 .29862 L .5065 .28287 L p
1 g
F P
s
P
p
.002 w
.5065 .28287 m .52403 .29947 L .54957 .29233 L p
1 g
F P
s
P
p
.002 w
.33263 .44901 m .36087 .48047 L .36875 .45558 L p
1 g
F P
s
P
p
.002 w
.36875 .45558 m .3444 .42786 L .33263 .44901 L p
1 g
F P
s
P
p
.002 w
.4063 .57141 m .46144 .57805 L .4544 .55654 L p
1 g
F P
s
P
p
.002 w
.4544 .55654 m .40145 .54982 L .4063 .57141 L p
1 g
F P
s
P
p
.002 w
.52761 .5868 m .58244 .56246 L .57248 .54489 L p
1 g
F P
s
P
p
.002 w
.57248 .54489 m .51851 .56878 L .52761 .5868 L p
1 g
F P
s
P
p
.002 w
.61876 .50855 m .57248 .54489 L .58244 .56246 L p
1 g
F P
s
P
p
.002 w
.35549 .52761 m .40145 .54982 L .39921 .52584 L p
1 g
F P
s
P
p
.002 w
.39921 .52584 m .35637 .50467 L .35549 .52761 L p
1 g
F P
s
P
p
.002 w
.61876 .50855 m .65322 .46275 L .63823 .44592 L p
1 g
F P
s
P
p
.002 w
.65624 .39632 m .63823 .44592 L .65322 .46275 L p
1 g
F P
s
P
p
.002 w
.63823 .44592 m .65624 .39632 L .63669 .38264 L p
1 g
F P
s
P
p
.002 w
.38409 .31527 m .37312 .33981 L .39647 .33701 L p
1 g
F P
s
P
p
.002 w
.39647 .33701 m .40395 .32053 L .38409 .31527 L p
1 g
F P
s
P
p
.002 w
.4697 .59641 m .52761 .5868 L .51851 .56878 L p
1 g
F P
s
P
p
.002 w
.51851 .56878 m .46144 .57805 L .4697 .59641 L p
1 g
F P
s
P
p
.002 w
.57441 .28857 m .58868 .32259 L .61392 .32755 L p
1 g
F P
s
P
p
.002 w
.58868 .32259 m .57441 .28857 L .54957 .29233 L p
1 g
F P
s
P
p
.002 w
.5065 .28287 m .48281 .27323 L .47027 .29224 L p
1 g
F P
s
P
p
.002 w
.45192 .29141 m .47027 .29224 L .48281 .27323 L p
1 g
F P
s
P
p
.002 w
.33242 .39234 m .3444 .42786 L .35981 .40728 L p
1 g
F P
s
P
p
.002 w
.35981 .40728 m .35017 .37775 L .33242 .39234 L p
1 g
F P
s
P
p
.002 w
.58244 .56246 m .62953 .52561 L .61876 .50855 L p
1 g
F P
s
P
p
.002 w
.65322 .46275 m .61876 .50855 L .62953 .52561 L p
1 g
F P
s
P
p
.002 w
.35236 .34503 m .35017 .37775 L .37124 .3649 L p
1 g
F P
s
P
p
.002 w
.37124 .3649 m .37312 .33981 L .35236 .34503 L p
1 g
F P
s
P
p
.002 w
.63684 .33529 m .63669 .38264 L .65624 .39632 L p
1 g
F P
s
P
p
.002 w
.63669 .38264 m .63684 .33529 L .61392 .32755 L p
1 g
F P
s
P
p
.002 w
.40306 .29419 m .38409 .31527 L .40395 .32053 L p
1 g
F P
s
P
p
.002 w
.40395 .32053 m .41673 .30641 L .40306 .29419 L p
1 g
F P
s
P
p
.002 w
.527 .27051 m .54957 .29233 L .57441 .28857 L p
1 g
F P
s
P
p
.002 w
.54957 .29233 m .527 .27051 L .5065 .28287 L p
1 g
F P
s
P
p
.002 w
.48281 .27323 m .45554 .27188 L .45192 .29141 L p
1 g
F P
s
P
p
.002 w
.43336 .29632 m .45192 .29141 L .45554 .27188 L p
1 g
F P
s
P
p
.002 w
.48281 .27323 m .5065 .28287 L .527 .27051 L p
1 g
F P
s
P
p
.002 w
.32492 .47028 m .35637 .50467 L .36087 .48047 L p
1 g
F P
s
P
p
.002 w
.36087 .48047 m .33263 .44901 L .32492 .47028 L p
1 g
F P
s
P
p
.002 w
.42786 .27913 m .40306 .29419 L .41673 .30641 L p
1 g
F P
s
P
p
.002 w
.41673 .30641 m .43336 .29632 L .42786 .27913 L p
1 g
F P
s
P
p
.002 w
.45554 .27188 m .42786 .27913 L .43336 .29632 L p
1 g
F P
s
P
p
.002 w
.41378 .58998 m .4697 .59641 L .46144 .57805 L p
1 g
F P
s
P
p
.002 w
.46144 .57805 m .4063 .57141 L .41378 .58998 L p
1 g
F P
s
P
p
.002 w
.59798 .28841 m .61392 .32755 L .63684 .33529 L p
1 g
F P
s
P
p
.002 w
.61392 .32755 m .59798 .28841 L .57441 .28857 L p
1 g
F P
s
P
p
.002 w
.3584 .54869 m .4063 .57141 L .40145 .54982 L p
1 g
F P
s
P
p
.002 w
.40145 .54982 m .35549 .52761 L .3584 .54869 L p
1 g
F P
s
P
p
.002 w
.53632 .60137 m .59061 .57723 L .58244 .56246 L p
1 g
F P
s
P
p
.002 w
.58244 .56246 m .52761 .5868 L .53632 .60137 L p
1 g
F P
s
P
p
.002 w
.62953 .52561 m .58244 .56246 L .59061 .57723 L p
1 g
F P
s
P
p
.002 w
.31853 .40837 m .33263 .44901 L .3444 .42786 L p
1 g
F P
s
P
p
.002 w
.3444 .42786 m .33242 .39234 L .31853 .40837 L p
1 g
F P
s
P
p
.002 w
.36657 .31285 m .35236 .34503 L .37312 .33981 L p
1 g
F P
s
P
p
.002 w
.37312 .33981 m .38409 .31527 L .36657 .31285 L p
1 g
F P
s
P
p
.002 w
.62953 .52561 m .66469 .47926 L .65322 .46275 L p
1 g
F P
s
P
p
.002 w
.67229 .41128 m .65322 .46275 L .66469 .47926 L p
1 g
F P
s
P
p
.002 w
.65322 .46275 m .67229 .41128 L .65624 .39632 L p
1 g
F P
s
P
p
.002 w
.527 .27051 m .49618 .25773 L .48281 .27323 L p
1 g
F P
s
P
p
.002 w
.45554 .27188 m .48281 .27323 L .49618 .25773 L p
1 g
F P
s
P
p
.002 w
.47905 .61105 m .53632 .60137 L .52761 .5868 L p
1 g
F P
s
P
p
.002 w
.52761 .5868 m .4697 .59641 L .47905 .61105 L p
1 g
F P
s
P
p
.002 w
.33481 .35269 m .33242 .39234 L .35017 .37775 L p
1 g
F P
s
P
p
.002 w
.35017 .37775 m .35236 .34503 L .33481 .35269 L p
1 g
F P
s
P
p
.002 w
.65684 .34575 m .65624 .39632 L .67229 .41128 L p
1 g
F P
s
P
p
.002 w
.65624 .39632 m .65684 .34575 L .63684 .33529 L p
1 g
F P
s
P
p
.002 w
.5474 .26198 m .57441 .28857 L .59798 .28841 L p
1 g
F P
s
P
p
.002 w
.57441 .28857 m .5474 .26198 L .527 .27051 L p
1 g
F P
s
P
p
.002 w
.59061 .57723 m .6373 .5408 L .62953 .52561 L p
1 g
F P
s
P
p
.002 w
.66469 .47926 m .62953 .52561 L .6373 .5408 L p
1 g
F P
s
P
p
.002 w
.32163 .49117 m .35549 .52761 L .35637 .50467 L p
1 g
F P
s
P
p
.002 w
.35637 .50467 m .32492 .47028 L .32163 .49117 L p
1 g
F P
s
P
p
.002 w
.49618 .25773 m .527 .27051 L .5474 .26198 L p
1 g
F P
s
P
p
.002 w
.39143 .2851 m .36657 .31285 L .38409 .31527 L p
1 g
F P
s
P
p
.002 w
.38409 .31527 m .40306 .29419 L .39143 .2851 L p
1 g
F P
s
P
p
.002 w
.49618 .25773 m .46046 .25581 L .45554 .27188 L p
1 g
F P
s
P
p
.002 w
.42786 .27913 m .45554 .27188 L .46046 .25581 L p
1 g
F P
s
P
p
.002 w
.61966 .29198 m .63684 .33529 L .65684 .34575 L p
1 g
F P
s
P
p
.002 w
.63684 .33529 m .61966 .29198 L .59798 .28841 L p
1 g
F P
s
P
p
.002 w
.42405 .26527 m .39143 .2851 L .40306 .29419 L p
1 g
F P
s
P
p
.002 w
.40306 .29419 m .42786 .27913 L .42405 .26527 L p
1 g
F P
s
P
p
.002 w
.46046 .25581 m .42405 .26527 L .42786 .27913 L p
1 g
F P
s
P
p
.002 w
.30905 .42555 m .32492 .47028 L .33263 .44901 L p
1 g
F P
s
P
p
.002 w
.33263 .44901 m .31853 .40837 L .30905 .42555 L p
1 g
F P
s
P
p
.002 w
.42383 .60494 m .47905 .61105 L .4697 .59641 L p
1 g
F P
s
P
p
.002 w
.4697 .59641 m .41378 .58998 L .42383 .60494 L p
1 g
F P
s
P
p
.002 w
.36522 .56729 m .41378 .58998 L .4063 .57141 L p
1 g
F P
s
P
p
.002 w
.4063 .57141 m .3584 .54869 L .36522 .56729 L p
1 g
F P
s
P
p
.002 w
.35195 .31347 m .33481 .35269 L .35236 .34503 L p
1 g
F P
s
P
p
.002 w
.35236 .34503 m .36657 .31285 L .35195 .31347 L p
1 g
F P
s
P
p
.002 w
.6373 .5408 m .67222 .49507 L .66469 .47926 L p
1 g
F P
s
P
p
.002 w
.68431 .42724 m .66469 .47926 L .67222 .49507 L p
1 g
F P
s
P
p
.002 w
.66469 .47926 m .68431 .42724 L .67229 .41128 L p
1 g
F P
s
P
p
.002 w
.32105 .36271 m .31853 .40837 L .33242 .39234 L p
1 g
F P
s
P
p
.002 w
.33242 .39234 m .33481 .35269 L .32105 .36271 L p
1 g
F P
s
P
p
.002 w
.5444 .61197 m .5967 .58867 L .59061 .57723 L p
1 g
F P
s
P
p
.002 w
.59061 .57723 m .53632 .60137 L .5444 .61197 L p
1 g
F P
s
P
p
.002 w
.6373 .5408 m .59061 .57723 L .5967 .58867 L p
1 g
F P
s
P
p
.002 w
.56719 .25763 m .59798 .28841 L .61966 .29198 L p
1 g
F P
s
P
p
.002 w
.59798 .28841 m .56719 .25763 L .5474 .26198 L p
1 g
F P
s
P
p
.002 w
.5474 .26198 m .51011 .24625 L .49618 .25773 L p
1 g
F P
s
P
p
.002 w
.46046 .25581 m .49618 .25773 L .51011 .24625 L p
1 g
F P
s
P
p
.002 w
.6733 .3588 m .67229 .41128 L .68431 .42724 L p
1 g
F P
s
P
p
.002 w
.67229 .41128 m .6733 .3588 L .65684 .34575 L p
1 g
F P
s
P
p
.002 w
.32307 .51111 m .3584 .54869 L .35549 .52761 L p
1 g
F P
s
P
p
.002 w
.35549 .52761 m .32163 .49117 L .32307 .51111 L p
1 g
F P
s
P
p
.002 w
.48932 .6214 m .5444 .61197 L .53632 .60137 L p
1 g
F P
s
P
p
.002 w
.53632 .60137 m .47905 .61105 L .48932 .6214 L p
1 g
F P
s
P
p
.002 w
.51011 .24625 m .5474 .26198 L .56719 .25763 L p
1 g
F P
s
P
p
.002 w
.5967 .58867 m .64171 .55363 L .6373 .5408 L p
1 g
F P
s
P
p
.002 w
.67222 .49507 m .6373 .5408 L .64171 .55363 L p
1 g
F P
s
P
p
.002 w
.38225 .27955 m .35195 .31347 L .36657 .31285 L p
1 g
F P
s
P
p
.002 w
.36657 .31285 m .39143 .2851 L .38225 .27955 L p
1 g
F P
s
P
p
.002 w
.63884 .29939 m .65684 .34575 L .6733 .3588 L p
1 g
F P
s
P
p
.002 w
.65684 .34575 m .63884 .29939 L .61966 .29198 L p
1 g
F P
s
P
p
.002 w
.51011 .24625 m .46662 .24379 L .46046 .25581 L p
1 g
F P
s
P
p
.002 w
.42405 .26527 m .46046 .25581 L .46662 .24379 L p
1 g
F P
s
P
p
.002 w
.30445 .44347 m .32163 .49117 L .32492 .47028 L p
1 g
F P
s
P
p
.002 w
.32492 .47028 m .30905 .42555 L .30445 .44347 L p
1 g
F P
s
P
p
.002 w
.37598 .58281 m .42383 .60494 L .41378 .58998 L p
1 g
F P
s
P
p
.002 w
.41378 .58998 m .36522 .56729 L .37598 .58281 L p
1 g
F P
s
P
p
.002 w
.42214 .2553 m .38225 .27955 L .39143 .2851 L p
1 g
F P
s
P
p
.002 w
.39143 .2851 m .42405 .26527 L .42214 .2553 L p
1 g
F P
s
P
p
.002 w
.43634 .61569 m .48932 .6214 L .47905 .61105 L p
1 g
F P
s
P
p
.002 w
.47905 .61105 m .42383 .60494 L .43634 .61569 L p
1 g
F P
s
P
p
.002 w
.46662 .24379 m .42214 .2553 L .42405 .26527 L p
1 g
F P
s
P
p
.002 w
.34077 .31731 m .32105 .36271 L .33481 .35269 L p
1 g
F P
s
P
p
.002 w
.33481 .35269 m .35195 .31347 L .34077 .31731 L p
1 g
F P
s
P
p
.002 w
.31167 .37498 m .30905 .42555 L .31853 .40837 L p
1 g
F P
s
P
p
.002 w
.31853 .40837 m .32105 .36271 L .31167 .37498 L p
1 g
F P
s
P
p
.002 w
.58587 .25779 m .61966 .29198 L .63884 .29939 L p
1 g
F P
s
P
p
.002 w
.61966 .29198 m .58587 .25779 L .56719 .25763 L p
1 g
F P
s
P
p
.002 w
.64171 .55363 m .6754 .50975 L .67222 .49507 L p
1 g
F P
s
P
p
.002 w
.69179 .44386 m .67222 .49507 L .6754 .50975 L p
1 g
F P
s
P
p
.002 w
.67222 .49507 m .69179 .44386 L .68431 .42724 L p
1 g
F P
s
P
p
.002 w
.68562 .37423 m .68431 .42724 L .69179 .44386 L p
1 g
F P
s
P
p
.002 w
.68431 .42724 m .68562 .37423 L .6733 .3588 L p
1 g
F P
s
P
p
.002 w
.32944 .52953 m .36522 .56729 L .3584 .54869 L p
1 g
F P
s
P
p
.002 w
.3584 .54869 m .32307 .51111 L .32944 .52953 L p
1 g
F P
s
P
p
.002 w
.56719 .25763 m .5243 .23932 L .51011 .24625 L p
1 g
F P
s
P
p
.002 w
.46662 .24379 m .51011 .24625 L .5243 .23932 L p
1 g
F P
s
P
p
.002 w
.55161 .61809 m .60042 .59632 L .5967 .58867 L p
1 g
F P
s
P
p
.002 w
.5967 .58867 m .5444 .61197 L .55161 .61809 L p
1 g
F P
s
P
p
.002 w
.64171 .55363 m .5967 .58867 L .60042 .59632 L p
1 g
F P
s
P
p
.002 w
.5243 .23932 m .56719 .25763 L .58587 .25779 L p
1 g
F P
s
P
p
.002 w
.5003 .62694 m .55161 .61809 L .5444 .61197 L p
1 g
F P
s
P
p
.002 w
.5444 .61197 m .48932 .6214 L .5003 .62694 L p
1 g
F P
s
P
p
.002 w
.65489 .31064 m .6733 .3588 L .68562 .37423 L p
1 g
F P
s
P
p
.002 w
.6733 .3588 m .65489 .31064 L .63884 .29939 L p
1 g
F P
s
P
p
.002 w
.60042 .59632 m .64245 .56364 L .64171 .55363 L p
1 g
F P
s
P
p
.002 w
.6754 .50975 m .64171 .55363 L .64245 .56364 L p
1 g
F P
s
P
p
.002 w
.30512 .46168 m .32307 .51111 L .32163 .49117 L p
1 g
F P
s
P
p
.002 w
.32163 .49117 m .30445 .44347 L .30512 .46168 L p
1 g
F P
s
P
p
.002 w
.3759 .27791 m .34077 .31731 L .35195 .31347 L p
1 g
F P
s
P
p
.002 w
.35195 .31347 m .38225 .27955 L .3759 .27791 L p
1 g
F P
s
P
p
.002 w
.5243 .23932 m .47396 .23637 L .46662 .24379 L p
1 g
F P
s
P
p
.002 w
.42214 .2553 m .46662 .24379 L .47396 .23637 L p
1 g
F P
s
P
p
.002 w
.39058 .59464 m .43634 .61569 L .42383 .60494 L p
1 g
F P
s
P
p
.002 w
.42383 .60494 m .37598 .58281 L .39058 .59464 L p
1 g
F P
s
P
p
.002 w
.60287 .26271 m .63884 .29939 L .65489 .31064 L p
1 g
F P
s
P
p
.002 w
.63884 .29939 m .60287 .26271 L .58587 .25779 L p
1 g
F P
s
P
p
.002 w
.30717 .38928 m .30445 .44347 L .30905 .42555 L p
1 g
F P
s
P
p
.002 w
.30905 .42555 m .31167 .37498 L .30717 .38928 L p
1 g
F P
s
P
p
.002 w
.4511 .62171 m .5003 .62694 L .48932 .6214 L p
1 g
F P
s
P
p
.002 w
.48932 .6214 m .43634 .61569 L .4511 .62171 L p
1 g
F P
s
P
p
.002 w
.33355 .32446 m .31167 .37498 L .32105 .36271 L p
1 g
F P
s
P
p
.002 w
.32105 .36271 m .34077 .31731 L .33355 .32446 L p
1 g
F P
s
P
p
.002 w
.42228 .24971 m .3759 .27791 L .38225 .27955 L p
1 g
F P
s
P
p
.002 w
.38225 .27955 m .42214 .2553 L .42228 .24971 L p
1 g
F P
s
P
p
.002 w
.47396 .23637 m .42228 .24971 L .42214 .2553 L p
1 g
F P
s
P
p
.002 w
.34084 .54583 m .37598 .58281 L .36522 .56729 L p
1 g
F P
s
P
p
.002 w
.36522 .56729 m .32944 .52953 L .34084 .54583 L p
1 g
F P
s
P
p
.002 w
.6754 .50975 m .69428 .46072 L .69179 .44386 L p
1 g
F P
s
P
p
.002 w
.69326 .39176 m .69179 .44386 L .69428 .46072 L p
1 g
F P
s
P
p
.002 w
.69179 .44386 m .69326 .39176 L .68562 .37423 L p
1 g
F P
s
P
p
.002 w
.64245 .56364 m .67388 .52283 L .6754 .50975 L p
1 g
F P
s
P
p
.002 w
.69428 .46072 m .6754 .50975 L .67388 .52283 L p
1 g
F P
s
P
p
.002 w
.58587 .25779 m .53838 .23737 L .5243 .23932 L p
1 g
F P
s
P
p
.002 w
.47396 .23637 m .5243 .23932 L .53838 .23737 L p
1 g
F P
s
P
p
.002 w
.53838 .23737 m .58587 .25779 L .60287 .26271 L p
1 g
F P
s
P
p
.002 w
.5577 .61927 m .60153 .59971 L .60042 .59632 L p
1 g
F P
s
P
p
.002 w
.60042 .59632 m .55161 .61809 L .5577 .61927 L p
1 g
F P
s
P
p
.002 w
.64245 .56364 m .60042 .59632 L .60153 .59971 L p
1 g
F P
s
P
p
.002 w
.6672 .32562 m .68562 .37423 L .69326 .39176 L p
1 g
F P
s
P
p
.002 w
.68562 .37423 m .6672 .32562 L .65489 .31064 L p
1 g
F P
s
P
p
.002 w
.31134 .47969 m .32944 .52953 L .32307 .51111 L p
1 g
F P
s
P
p
.002 w
.32307 .51111 m .30512 .46168 L .31134 .47969 L p
1 g
F P
s
P
p
.002 w
.51173 .62722 m .5577 .61927 L .55161 .61809 L p
1 g
F P
s
P
p
.002 w
.55161 .61809 m .5003 .62694 L .51173 .62722 L p
1 g
F P
s
P
p
.002 w
.60153 .59971 m .63927 .57039 L .64245 .56364 L p
1 g
F P
s
P
p
.002 w
.67388 .52283 m .64245 .56364 L .63927 .57039 L p
1 g
F P
s
P
p
.002 w
.37276 .28047 m .33355 .32446 L .34077 .31731 L p
1 g
F P
s
P
p
.002 w
.34077 .31731 m .3759 .27791 L .37276 .28047 L p
1 g
F P
s
P
p
.002 w
.40883 .60224 m .4511 .62171 L .43634 .61569 L p
1 g
F P
s
P
p
.002 w
.43634 .61569 m .39058 .59464 L .40883 .60224 L p
1 g
F P
s
P
p
.002 w
.65489 .31064 m .61763 .27251 L .60287 .26271 L p
1 g
F P
s
P
p
.002 w
.61763 .27251 m .65489 .31064 L .6672 .32562 L p
1 g
F P
s
P
p
.002 w
.53838 .23737 m .48233 .23405 L .47396 .23637 L p
1 g
F P
s
P
p
.002 w
.42228 .24971 m .47396 .23637 L .48233 .23405 L p
1 g
F P
s
P
p
.002 w
.30799 .40532 m .30512 .46168 L .30445 .44347 L p
1 g
F P
s
P
p
.002 w
.30445 .44347 m .30717 .38928 L .30799 .40532 L p
1 g
F P
s
P
p
.002 w
.33074 .33492 m .30717 .38928 L .31167 .37498 L p
1 g
F P
s
P
p
.002 w
.31167 .37498 m .33355 .32446 L .33074 .33492 L p
1 g
F P
s
P
p
.002 w
.35718 .5594 m .39058 .59464 L .37598 .58281 L p
1 g
F P
s
P
p
.002 w
.37598 .58281 m .34084 .54583 L .35718 .5594 L p
1 g
F P
s
P
p
.002 w
.46782 .62254 m .51173 .62722 L .5003 .62694 L p
1 g
F P
s
P
p
.002 w
.5003 .62694 m .4511 .62171 L .46782 .62254 L p
1 g
F P
s
P
p
.002 w
.67388 .52283 m .69144 .47738 L .69428 .46072 L p
1 g
F P
s
P
p
.002 w
.69428 .46072 m .69576 .41101 L .69326 .39176 L p
1 g
F P
s
P
p
.002 w
.69576 .41101 m .69428 .46072 L .69144 .47738 L p
1 g
F P
s
P
p
.002 w
.48233 .23405 m .4246 .24894 L .42228 .24971 L p
1 g
F P
s
P
p
.002 w
.4246 .24894 m .37276 .28047 L .3759 .27791 L p
1 g
F P
s
P
p
.002 w
.3759 .27791 m .42228 .24971 L .4246 .24894 L p
1 g
F P
s
P
p
.002 w
.60287 .26271 m .55195 .24077 L .53838 .23737 L p
1 g
F P
s
P
p
.002 w
.55195 .24077 m .60287 .26271 L .61763 .27251 L p
1 g
F P
s
P
p
.002 w
.63927 .57039 m .66741 .53386 L .67388 .52283 L p
1 g
F P
s
P
p
.002 w
.69144 .47738 m .67388 .52283 L .66741 .53386 L p
1 g
F P
s
P
p
.002 w
.48233 .23405 m .53838 .23737 L .55195 .24077 L p
1 g
F P
s
P
p
.002 w
.69326 .39176 m .67523 .3441 L .6672 .32562 L p
1 g
F P
s
P
p
.002 w
.67523 .3441 m .69326 .39176 L .69576 .41101 L p
1 g
F P
s
P
p
.002 w
.32321 .49693 m .34084 .54583 L .32944 .52953 L p
1 g
F P
s
P
p
.002 w
.32944 .52953 m .31134 .47969 L .32321 .49693 L p
1 g
F P
s
P
p
.002 w
.56243 .61515 m .59981 .59847 L .60153 .59971 L p
1 g
F P
s
P
p
.002 w
.60153 .59971 m .5577 .61927 L .56243 .61515 L p
1 g
F P
s
P
p
.002 w
.63927 .57039 m .60153 .59971 L .59981 .59847 L p
1 g
F P
s
P
p
.002 w
.52329 .6219 m .56243 .61515 L .5577 .61927 L p
1 g
F P
s
P
p
.002 w
.5577 .61927 m .51173 .62722 L .52329 .6219 L p
1 g
F P
s
P
p
.002 w
.59981 .59847 m .63199 .57346 L .63927 .57039 L p
1 g
F P
s
P
p
.002 w
.66741 .53386 m .63927 .57039 L .63199 .57346 L p
1 g
F P
s
P
p
.002 w
.62958 .28718 m .6672 .32562 L .67523 .3441 L p
1 g
F P
s
P
p
.002 w
.6672 .32562 m .62958 .28718 L .61763 .27251 L p
1 g
F P
s
P
p
.002 w
.37312 .28745 m .33074 .33492 L .33355 .32446 L p
1 g
F P
s
P
p
.002 w
.33355 .32446 m .37276 .28047 L .37312 .28745 L p
1 g
F P
s
P
p
.002 w
.3144 .4227 m .31134 .47969 L .30512 .46168 L p
1 g
F P
s
P
p
.002 w
.30512 .46168 m .30799 .40532 L .3144 .4227 L p
1 g
F P
s
P
p
.002 w
.43034 .60516 m .46782 .62254 L .4511 .62171 L p
1 g
F P
s
P
p
.002 w
.4511 .62171 m .40883 .60224 L .43034 .60516 L p
1 g
F P
s
P
p
.002 w
.37821 .56969 m .40883 .60224 L .39058 .59464 L p
1 g
F P
s
P
p
.002 w
.39058 .59464 m .35718 .5594 L .37821 .56969 L p
1 g
F P
s
P
p
.002 w
.55195 .24077 m .49156 .23722 L .48233 .23405 L p
1 g
F P
s
P
p
.002 w
.4246 .24894 m .48233 .23405 L .49156 .23722 L p
1 g
F P
s
P
p
.002 w
.33272 .34859 m .30799 .40532 L .30717 .38928 L p
1 g
F P
s
P
p
.002 w
.30717 .38928 m .33074 .33492 L .33272 .34859 L p
1 g
F P
s
P
p
.002 w
.66741 .53386 m .68304 .49334 L .69144 .47738 L p
1 g
F P
s
P
p
.002 w
.69275 .4315 m .69144 .47738 L .68304 .49334 L p
1 g
F P
s
P
p
.002 w
.69144 .47738 m .69275 .4315 L .69576 .41101 L p
1 g
F P
s
P
p
.002 w
.4861 .61785 m .52329 .6219 L .51173 .62722 L p
1 g
F P
s
P
p
.002 w
.51173 .62722 m .46782 .62254 L .4861 .61785 L p
1 g
F P
s
P
p
.002 w
.56457 .24972 m .61763 .27251 L .62958 .28718 L p
1 g
F P
s
P
p
.002 w
.61763 .27251 m .56457 .24972 L .55195 .24077 L p
1 g
F P
s
P
p
.002 w
.63199 .57346 m .6559 .54238 L .66741 .53386 L p
1 g
F P
s
P
p
.002 w
.68304 .49334 m .66741 .53386 L .6559 .54238 L p
1 g
F P
s
P
p
.002 w
.4292 .25336 m .37312 .28745 L .37276 .28047 L p
1 g
F P
s
P
p
.002 w
.37276 .28047 m .4246 .24894 L .4292 .25336 L p
1 g
F P
s
P
p
.002 w
.49156 .23722 m .55195 .24077 L .56457 .24972 L p
1 g
F P
s
P
p
.002 w
.6785 .3657 m .69576 .41101 L .69275 .4315 L p
1 g
F P
s
P
p
.002 w
.69576 .41101 m .6785 .3657 L .67523 .3441 L p
1 g
F P
s
P
p
.002 w
.49156 .23722 m .4292 .25336 L .4246 .24894 L p
1 g
F P
s
P
p
.002 w
.34067 .5128 m .35718 .5594 L .34084 .54583 L p
1 g
F P
s
P
p
.002 w
.34084 .54583 m .32321 .49693 L .34067 .5128 L p
1 g
F P
s
P
p
.002 w
.56555 .60552 m .59514 .59233 L .59981 .59847 L p
1 g
F P
s
P
p
.002 w
.59981 .59847 m .56243 .61515 L .56555 .60552 L p
1 g
F P
s
P
p
.002 w
.63199 .57346 m .59981 .59847 L .59514 .59233 L p
1 g
F P
s
P
p
.002 w
.63821 .30653 m .67523 .3441 L .6785 .3657 L p
1 g
F P
s
P
p
.002 w
.67523 .3441 m .63821 .30653 L .62958 .28718 L p
1 g
F P
s
P
p
.002 w
.32652 .44094 m .32321 .49693 L .31134 .47969 L p
1 g
F P
s
P
p
.002 w
.31134 .47969 m .3144 .4227 L .32652 .44094 L p
1 g
F P
s
P
p
.002 w
.53465 .61079 m .56555 .60552 L .56243 .61515 L p
1 g
F P
s
P
p
.002 w
.56243 .61515 m .52329 .6219 L .53465 .61079 L p
1 g
F P
s
P
p
.002 w
.4546 .60304 m .4861 .61785 L .46782 .62254 L p
1 g
F P
s
P
p
.002 w
.46782 .62254 m .43034 .60516 L .4546 .60304 L p
1 g
F P
s
P
p
.002 w
.59514 .59233 m .62058 .57253 L .63199 .57346 L p
1 g
F P
s
P
p
.002 w
.6559 .54238 m .63199 .57346 L .62058 .57253 L p
1 g
F P
s
P
p
.002 w
.40348 .57619 m .43034 .60516 L .40883 .60224 L p
1 g
F P
s
P
p
.002 w
.40883 .60224 m .37821 .56969 L .40348 .57619 L p
1 g
F P
s
P
p
.002 w
.37721 .29891 m .33272 .34859 L .33074 .33492 L p
1 g
F P
s
P
p
.002 w
.33074 .33492 m .37312 .28745 L .37721 .29891 L p
1 g
F P
s
P
p
.002 w
.33972 .36521 m .3144 .4227 L .30799 .40532 L p
1 g
F P
s
P
p
.002 w
.30799 .40532 m .33272 .34859 L .33972 .36521 L p
1 g
F P
s
P
p
.002 w
.6559 .54238 m .66903 .50807 L .68304 .49334 L p
1 g
F P
s
P
p
.002 w
.68406 .45265 m .68304 .49334 L .66903 .50807 L p
1 g
F P
s
P
p
.002 w
.68304 .49334 m .68406 .45265 L .69275 .4315 L p
1 g
F P
s
P
p
.002 w
.56457 .24972 m .50143 .24615 L .49156 .23722 L p
1 g
F P
s
P
p
.002 w
.4292 .25336 m .49156 .23722 L .50143 .24615 L p
1 g
F P
s
P
p
.002 w
.5758 .26429 m .62958 .28718 L .63821 .30653 L p
1 g
F P
s
P
p
.002 w
.62958 .28718 m .5758 .26429 L .56457 .24972 L p
1 g
F P
s
P
p
.002 w
.50545 .6075 m .53465 .61079 L .52329 .6219 L p
1 g
F P
s
P
p
.002 w
.52329 .6219 m .4861 .61785 L .50545 .6075 L p
1 g
F P
s
P
p
.002 w
.67666 .38991 m .69275 .4315 L .68406 .45265 L p
1 g
F P
s
P
p
.002 w
.69275 .4315 m .67666 .38991 L .6785 .3657 L p
1 g
F P
s
P
p
.002 w
.36338 .52671 m .37821 .56969 L .35718 .5594 L p
1 g
F P
s
P
p
.002 w
.35718 .5594 m .34067 .5128 L .36338 .52671 L p
1 g
F P
s
P
p
.002 w
.50143 .24615 m .56457 .24972 L .5758 .26429 L p
1 g
F P
s
P
p
.002 w
.62058 .57253 m .63938 .54798 L .6559 .54238 L p
1 g
F P
s
P
p
.002 w
.66903 .50807 m .6559 .54238 L .63938 .54798 L p
1 g
F P
s
P
p
.002 w
.43606 .26315 m .37721 .29891 L .37312 .28745 L p
1 g
F P
s
P
p
.002 w
.37312 .28745 m .4292 .25336 L .43606 .26315 L p
1 g
F P
s
P
p
.002 w
.50143 .24615 m .43606 .26315 L .4292 .25336 L p
1 g
F P
s
P
p
.002 w
.64305 .33018 m .6785 .3657 L .67666 .38991 L p
1 g
F P
s
P
p
.002 w
.6785 .3657 m .64305 .33018 L .63821 .30653 L p
1 g
F P
s
P
p
.002 w
.34423 .45946 m .34067 .5128 L .32321 .49693 L p
1 g
F P
s
P
p
.002 w
.32321 .49693 m .32652 .44094 L .34423 .45946 L p
1 g
F P
s
P
p
.002 w
.43232 .57852 m .4546 .60304 L .43034 .60516 L p
1 g
F P
s
P
p
.002 w
.43034 .60516 m .40348 .57619 L .43232 .57852 L p
1 g
F P
s
P
p
.002 w
.48093 .59574 m .50545 .6075 L .4861 .61785 L p
1 g
F P
s
P
p
.002 w
.4861 .61785 m .4546 .60304 L .48093 .59574 L p
1 g
F P
s
P
p
.002 w
.56687 .59032 m .58747 .58115 L .59514 .59233 L p
1 g
F P
s
P
p
.002 w
.59514 .59233 m .56555 .60552 L .56687 .59032 L p
1 g
F P
s
P
p
.002 w
.62058 .57253 m .59514 .59233 L .58747 .58115 L p
1 g
F P
s
P
p
.004 w
.58985 .59127 m
.60131 .61178 L
s
P
p
.002 w
.54541 .59392 m .56687 .59032 L .56555 .60552 L p
1 g
F P
s
P
p
.002 w
.56555 .60552 m .53465 .61079 L .54541 .59392 L p
1 g
F P
s
P
p
.002 w
.58747 .58115 m .60515 .56736 L .62058 .57253 L p
1 g
F P
s
P
p
.002 w
.63938 .54798 m .62058 .57253 L .60515 .56736 L p
1 g
F P
s
P
p
.002 w
.38513 .31476 m .33972 .36521 L .33272 .34859 L p
1 g
F P
s
P
p
.002 w
.33272 .34859 m .37721 .29891 L .38513 .31476 L p
1 g
F P
s
P
p
.002 w
.63938 .54798 m .64956 .52101 L .66903 .50807 L p
1 g
F P
s
P
p
.002 w
.66967 .47383 m .66903 .50807 L .64956 .52101 L p
1 g
F P
s
P
p
.002 w
.66903 .50807 m .66967 .47383 L .68406 .45265 L p
1 g
F P
s
P
p
.002 w
.35178 .3844 m .32652 .44094 L .3144 .4227 L p
1 g
F P
s
P
p
.002 w
.3144 .4227 m .33972 .36521 L .35178 .3844 L p
1 g
F P
s
P
p
.002 w
.58519 .28431 m .63821 .30653 L .64305 .33018 L p
1 g
F P
s
P
p
.002 w
.63821 .30653 m .58519 .28431 L .5758 .26429 L p
1 g
F P
s
P
p
.002 w
.66954 .41603 m .68406 .45265 L .66967 .47383 L p
1 g
F P
s
P
p
.002 w
.68406 .45265 m .66954 .41603 L .67666 .38991 L p
1 g
F P
s
P
p
.002 w
.39081 .5381 m .40348 .57619 L .37821 .56969 L p
1 g
F P
s
P
p
.002 w
.37821 .56969 m .36338 .52671 L .39081 .5381 L p
1 g
F P
s
P
p
.002 w
.5758 .26429 m .51165 .26089 L .50143 .24615 L p
1 g
F P
s
P
p
.002 w
.43606 .26315 m .50143 .24615 L .51165 .26089 L p
1 g
F P
s
P
p
.002 w
.52526 .59153 m .54541 .59392 L .53465 .61079 L p
1 g
F P
s
P
p
.002 w
.53465 .61079 m .50545 .6075 L .52526 .59153 L p
1 g
F P
s
P
p
.002 w
.51165 .26089 m .5758 .26429 L .58519 .28431 L p
1 g
F P
s
P
p
.002 w
.60515 .56736 m .61813 .55029 L .63938 .54798 L p
1 g
F P
s
P
p
.002 w
.64956 .52101 m .63938 .54798 L .61813 .55029 L p
1 g
F P
s
P
p
.002 w
.64376 .35753 m .67666 .38991 L .66954 .41603 L p
1 g
F P
s
P
p
.002 w
.67666 .38991 m .64376 .35753 L .64305 .33018 L p
1 g
F P
s
P
p
.002 w
.44511 .27833 m .38513 .31476 L .37721 .29891 L p
1 g
F P
s
P
p
.002 w
.37721 .29891 m .43606 .26315 L .44511 .27833 L p
1 g
F P
s
P
p
.002 w
.36715 .47762 m .36338 .52671 L .34067 .5128 L p
1 g
F P
s
P
p
.002 w
.34067 .5128 m .34423 .45946 L .36715 .47762 L p
1 g
F P
s
P
p
.002 w
.51165 .26089 m .44511 .27833 L .43606 .26315 L p
1 g
F P
s
P
p
.002 w
.46384 .57645 m .48093 .59574 L .4546 .60304 L p
1 g
F P
s
P
p
.002 w
.4546 .60304 m .43232 .57852 L .46384 .57645 L p
1 g
F P
s
P
p
.002 w
.50851 .58328 m .52526 .59153 L .50545 .6075 L p
1 g
F P
s
P
p
.002 w
.50545 .6075 m .48093 .59574 L .50851 .58328 L p
1 g
F P
s
P
p
.002 w
.64956 .52101 m .64981 .4943 L .66967 .47383 L p
1 g
F P
s
P
p
.002 w
.65715 .44326 m .66967 .47383 L .64981 .4943 L p
1 g
F P
s
P
p
.002 w
.66967 .47383 m .65715 .44326 L .66954 .41603 L p
1 g
F P
s
P
p
.002 w
.61813 .55029 m .62502 .53165 L .64956 .52101 L p
1 g
F P
s
P
p
.002 w
.64981 .4943 m .64956 .52101 L .62502 .53165 L p
1 g
F P
s
P
p
.002 w
.42214 .54646 m .43232 .57852 L .40348 .57619 L p
1 g
F P
s
P
p
.002 w
.40348 .57619 m .39081 .5381 L .42214 .54646 L p
1 g
F P
s
P
p
.002 w
.59232 .30938 m .64305 .33018 L .64376 .35753 L p
1 g
F P
s
P
p
.002 w
.64305 .33018 m .59232 .30938 L .58519 .28431 L p
1 g
F P
s
P
p
.002 w
.56623 .56974 m .57686 .56502 L .58747 .58115 L p
1 g
F P
s
P
p
.002 w
.58747 .58115 m .56687 .59032 L .56623 .56974 L p
1 g
F P
s
P
p
.002 w
.60515 .56736 m .58747 .58115 L .57686 .56502 L p
1 g
F P
s
P
p
.002 w
.36873 .40559 m .34423 .45946 L .32652 .44094 L p
1 g
F P
s
P
p
.002 w
.32652 .44094 m .35178 .3844 L .36873 .40559 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.55518 .57155 m .56623 .56974 L .56687 .59032 L p
1 g
F P
s
P
p
.002 w
.56687 .59032 m .54541 .59392 L .55518 .57155 L p
1 g
F P
s
P
p
.002 w
.39681 .33469 m .35178 .3844 L .33972 .36521 L p
1 g
F P
s
P
p
.002 w
.33972 .36521 m .38513 .31476 L .39681 .33469 L p
1 g
F P
s
P
p
.002 w
.57686 .56502 m .58598 .55789 L .60515 .56736 L p
1 g
F P
s
P
p
.002 w
.61813 .55029 m .60515 .56736 L .58598 .55789 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.64015 .38778 m .66954 .41603 L .65715 .44326 L p
1 g
F P
s
P
p
.002 w
.66954 .41603 m .64015 .38778 L .64376 .35753 L p
1 g
F P
s
P
p
.002 w
.58519 .28431 m .52188 .28126 L .51165 .26089 L p
1 g
F P
s
P
p
.002 w
.44511 .27833 m .51165 .26089 L .52188 .28126 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54486 .57025 m .55518 .57155 L .54541 .59392 L p
1 g
F P
s
P
p
.002 w
.54541 .59392 m .52526 .59153 L .54486 .57025 L p
1 g
F P
s
P
p
.002 w
.52188 .28126 m .58519 .28431 L .59232 .30938 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.58598 .55789 m .59261 .54908 L .61813 .55029 L p
1 g
F P
s
P
p
.002 w
.62502 .53165 m .61813 .55029 L .59261 .54908 L p
1 g
F P
s
P
p
.002 w
.39465 .49475 m .39081 .5381 L .36338 .52671 L p
1 g
F P
s
P
p
.002 w
.36338 .52671 m .36715 .47762 L .39465 .49475 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50558 .5846 m .48093 .59574 L p
.49032 .58066 L 1 g
F P
s
P
p
.002 w
.48908 .58034 m .48921 .57862 L p
.47925 .5778 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.43232 .57852 m .44817 .56064 L .45449 .56701 L 1 g
F
P
p
.002 w
.45094 .5627 m .45146 .56129 L p
.44555 .55616 L 1 g
F P
s
P
p
.46872 .57265 m .4592 .56885 L .46055 .56985 L 1 g
F
P
p
.002 w
.46384 .57645 m .46234 .57655 L p
.45449 .56701 L 1 g
F P
s
P
p
.002 w
.46234 .57655 m .43232 .57852 L p
.45449 .56701 L 1 g
F P
s
P
p
.002 w
.46224 .57111 m .46384 .57645 L p
.44817 .56064 L 1 g
F P
s
P
p
.002 w
.46911 .57541 m .46384 .57645 L p
.46644 .57427 L 1 g
F P
s
P
p
.46644 .57427 m .46681 .57397 L .46824 .57486 L 1 g
F
P
p
.46644 .57427 m .46824 .57486 L .46911 .57541 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46824 .57486 L p
1 g
F P
s
P
p
.48921 .57862 m .46824 .57486 L .46885 .57506 L 1 g
F
P
p
.002 w
.46824 .57486 m .46872 .57265 L p
.45984 .5696 L 1 g
F P
s
P
p
.48921 .57862 m .46885 .57506 L .47925 .5778 L 1 g
F
P
p
.46824 .57486 m .46931 .57521 L .46911 .57541 L 1 g
F
P
p
.46885 .57506 m .46822 .57495 L .46961 .57531 L 1 g
F
P
p
.46885 .57506 m .46961 .57531 L .47925 .5778 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.49218 .55273 m .49702 .56991 L .46961 .57531 L p
1 g
F P
s
P
p
.002 w
.46961 .57531 m .46911 .57541 L p
.46931 .57521 L 1 g
F P
s
P
p
.46931 .57521 m .49218 .55273 L .46961 .57531 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45053 .56378 L p
1 g
F P
s
P
p
.002 w
.45053 .56378 m .45002 .56518 L p
.45762 .56821 L 1 g
F P
s
P
p
.46872 .57265 m .45053 .56378 L .45762 .56821 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45633 .55142 m .49218 .55273 L p
.46681 .57397 L 1 g
F P
s
P
p
.002 w
.46384 .57645 m .46224 .57111 L p
.46681 .57397 L 1 g
F P
s
P
p
.002 w
.46224 .57111 m .45633 .55142 L p
.46681 .57397 L 1 g
F P
s
P
p
.46681 .57397 m .49218 .55273 L .46931 .57521 L 1 g
F
P
p
.46681 .57397 m .46931 .57521 L .46824 .57486 L 1 g
F
P
p
.002 w
.48093 .59574 m .46384 .57645 L .46911 .57541 L p
1 g
F P
s
P
p
.002 w
.46911 .57541 m .46961 .57531 L p
.46988 .5758 L 1 g
F P
s
P
p
.48093 .59574 m .46911 .57541 L .46988 .5758 L 1 g
F
P
p
.48093 .59574 m .4719 .57945 L .49032 .58066 L 1 g
F
P
p
.4719 .57945 m .46961 .57531 L .48908 .58034 L 1 g
F
P
p
.4719 .57945 m .48908 .58034 L .49032 .58066 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58034 L p
1 g
F P
s
P
p
.51079 .57862 m .48908 .58034 L .49949 .58088 L 1 g
F
P
p
.002 w
.46961 .57531 m .49702 .56991 L p
.49032 .58066 L 1 g
F P
s
P
p
.49032 .58066 m .49048 .58041 L .50558 .5846 L 1 g
F
P
p
.51079 .57862 m .49949 .58088 L .50676 .58125 L 1 g
F
P
p
.002 w
.51231 .58092 m .50851 .58328 L p
.51046 .58115 L 1 g
F P
s
P
p
.51046 .58115 m .51057 .58102 L .51097 .581 L 1 g
F
P
p
.51046 .58115 m .51097 .581 L .51231 .58092 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .581 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .581 L .51322 .58035 L 1 g
F
P
p
.52526 .59153 m .51643 .58333 L .53277 .57424 L 1 g
F
P
p
.51643 .58333 m .51322 .58035 L .5317 .57457 L 1 g
F
P
p
.51643 .58333 m .5317 .57457 L .53277 .57424 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57457 L p
1 g
F P
s
P
p
.54854 .56129 m .5317 .57457 L .53898 .5704 L 1 g
F
P
p
.53128 .57265 m .51322 .58035 L .52103 .57791 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.52526 .59153 m .50851 .58328 L .51322 .58035 L p
1 g
F P
s
P
p
.002 w
.54459 .57054 m .52526 .59153 L p
.53277 .57424 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5317 .57457 L p
1 g
F P
s
P
p
.002 w
.5317 .57457 m .53128 .57265 L p
.52103 .57791 L 1 g
F P
s
P
p
.52103 .57791 m .51111 .583 L .5317 .57457 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54486 .57025 m .54459 .57054 L p
.54163 .56888 L 1 g
F P
s
P
p
.002 w
.54188 .56874 m .54486 .57025 L p
.54163 .56888 L 1 g
F P
s
P
p
.54854 .56129 m .53898 .5704 L .54188 .56874 L 1 g
F
P
p
.54854 .56129 m .54188 .56874 L .54263 .56818 L 1 g
F
P
p
.002 w
.55066 .56217 m .54486 .57025 L .54401 .56981 L p
1 g
F P
s
P
p
.002 w
.54401 .56981 m .54188 .56874 L p
.54926 .56322 L 1 g
F P
s
P
p
.54401 .56981 m .54926 .56322 L .55066 .56217 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56322 L p
1 g
F P
s
P
p
.56075 .54566 m .54926 .56322 L .55514 .55583 L 1 g
F
P
p
.002 w
.54926 .56323 m .54926 .56322 L p
.54241 .56843 L 1 g
F P
s
P
p
.002 w
.54926 .56322 m .54854 .56129 L p
.54263 .56818 L 1 g
F P
s
P
p
.54263 .56818 m .54241 .56843 L .54926 .56322 L 1 g
F
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55518 .57155 m .54486 .57025 L .55066 .56217 L p
1 g
F P
s
P
p
.002 w
.55066 .56217 m .55587 .55492 L p
.56029 .55486 L 1 g
F P
s
P
p
.002 w
.56174 .54753 m .56075 .54566 L p
.55587 .55492 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56174 .54753 L p
1 g
F P
s
P
p
.002 w
.56355 .54422 m .56304 .54589 L p
.56174 .54753 L 1 g
F P
s
P
p
.002 w
.56242 .54579 m .56355 .54422 L p
.56174 .54753 L 1 g
F P
s
P
p
.002 w
.56304 .54589 m .56029 .55486 L p
.55587 .55492 L 1 g
F P
s
P
p
.56654 .52734 m .56174 .54753 L .56268 .54513 L 1 g
F
P
p
.56654 .52734 m .56268 .54513 L .56295 .5444 L 1 g
F
P
p
.56654 .52734 m .56295 .5444 L .56299 .5443 L 1 g
F
P
p
.56654 .52734 m .56298 .54432 L .56309 .544 L 1 g
F
P
p
.56654 .52734 m .56309 .544 L .56312 .5439 L 1 g
F
P
p
.56654 .52734 m .56312 .54391 L .56326 .54343 L 1 g
F
P
p
.56654 .52734 m .56326 .54343 L .56338 .54303 L 1 g
F
P
p
.56654 .52734 m .56337 .54306 L .5642 .54014 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55323 .51652 m .56453 .5132 L .56361 .54221 L p
1 g
F P
s
P
p
.002 w
.56361 .54221 m .56355 .54422 L .56326 .54343 L p
1 g
F P
s
P
p
.002 w
.56326 .54343 m .55323 .51652 L p
.56361 .54221 L 1 g
F P
s
P
p
.56338 .54303 m .56326 .54343 L .56337 .54306 L 1 g
F
P
p
.002 w
.57192 .51312 m .57557 .51309 L p
.56767 .53233 L 1 g
F P
s
P
p
.56747 .5287 m .56767 .53233 L .56361 .54221 L 1 g
F
P
p
.57192 .51312 m .56767 .53233 L .56747 .5287 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.002 w
.56355 .54422 m .56361 .54221 L p
.56767 .53233 L 1 g
F P
s
P
p
.002 w
.57557 .51309 m .56773 .5334 L p
.56767 .53233 L 1 g
F P
s
P
p
.002 w
.56773 .5334 m .56355 .54422 L p
.56767 .53233 L 1 g
F P
s
P
p
.56515 .50826 m .56702 .52036 L .56662 .51318 L 1 g
F
P
p
.002 w
.57557 .51309 m .56796 .51316 L p
.56352 .479 L 1 g
F P
s
P
p
.002 w
.56796 .51316 m .56662 .51318 L p
.56631 .50972 L 1 g
F P
s
P
p
.56352 .479 m .56796 .51316 L .56631 .50972 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56622 .50953 L p
1 g
F P
s
P
p
.55661 .4905 m .56622 .50953 L .5643 .50555 L 1 g
F
P
p
.002 w
.5529 .48208 m .56352 .479 L .56407 .4978 L p
1 g
F P
s
P
p
.002 w
.56407 .4978 m .5643 .50555 L p
.55739 .49133 L 1 g
F P
s
P
p
.5529 .48208 m .56407 .4978 L .55739 .49133 L 1 g
F
P
p
.55661 .4905 m .5643 .50555 L .56202 .50086 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .56702 .52036 L 1 g
F
P
p
.002 w
.56662 .51318 m .56453 .5132 L .5643 .50555 L p
1 g
F P
s
P
p
.002 w
.5643 .50555 m .56377 .4875 L p
.56622 .50953 L 1 g
F P
s
P
p
.002 w
.56622 .50953 m .56515 .50826 L p
.56662 .51318 L 1 g
F P
s
P
p
.56622 .50953 m .56662 .51318 L .5643 .50555 L 1 g
F
P
p
.002 w
.56377 .4875 m .56352 .479 L p
.56662 .51318 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55756 .49151 L p
1 g
F P
s
P
p
.002 w
.55756 .49151 m .55661 .4905 L p
.56235 .50148 L 1 g
F P
s
P
p
.56235 .50148 m .56713 .51061 L .55756 .49151 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55109 .48523 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54102 .48553 m .549 .48321 L p
.56453 .5132 L 1 g
F P
s
P
p
.54174 .47608 m .55109 .48523 L .549 .48321 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.549 .48321 m .54102 .48553 L .53619 .47383 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54234 .47673 L .53619 .47383 L 1 g
F
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53619 .47383 m .54102 .48553 L p
.51723 .4664 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46713 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46713 L .5114 .46559 L 1 g
F
P
p
.51158 .46186 m .52241 .46713 L .51723 .4664 L 1 g
F
P
p
.52241 .46713 m .53619 .47383 L .51723 .4664 L 1 g
F
P
p
.002 w
.49719 .47054 m .50652 .46491 L p
.54102 .48553 L 1 g
F P
s
P
p
.5 .4634 m .5114 .46559 L .50652 .46491 L 1 g
F
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50652 .46491 m .49719 .47054 L .49272 .46505 L p
1 g
F P
s
P
p
.5 .46388 m .50652 .46491 L .49272 .46505 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.46655 .47239 m .46962 .47091 L .49719 .47054 L 1 g
F
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.49272 .46505 m .49719 .47054 L p
.46962 .47091 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47764 .46705 L p
1 g
F P
s
P
p
.45826 .47608 m .47764 .46705 L .46536 .47297 L 1 g
F
P
p
.44603 .47123 m .47764 .46705 L .46962 .47091 L 1 g
F
P
p
.47764 .46705 m .49272 .46505 L .46962 .47091 L 1 g
F
P
p
.002 w
.45775 .47664 m .45826 .47608 L p
.46536 .47297 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.49719 .47054 m .47371 .49519 L .45348 .4808 L p
1 g
F P
s
P
p
.46181 .47268 m .49719 .47054 L .45348 .4808 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45751 .4769 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43765 .50172 L 1 g
F P
s
P
p
.42829 .50516 m .44278 .49114 L .43689 .50328 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44278 .49114 L p
1 g
F P
s
P
p
.002 w
.44278 .49114 m .44166 .49233 L p
.43765 .50172 L 1 g
F P
s
P
p
.43485 .50826 m .44278 .49114 L .43765 .50172 L 1 g
F
P
p
.002 w
.42585 .51017 m .42829 .50516 L p
.43689 .50328 L 1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43492 .50733 m .43689 .50328 L .47371 .49519 L 1 g
F
P
p
.42585 .51017 m .43689 .50328 L .43492 .50733 L 1 g
F
P
p
.002 w
.45348 .4808 m .47371 .49519 L p
.43689 .50328 L 1 g
F P
s
P
p
.44278 .49114 m .45348 .4808 L .43689 .50328 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43353 .51315 m .42585 .51017 L p
.43414 .50757 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43369 .50964 L p
1 g
F P
s
P
p
.002 w
.42214 .54646 m .42585 .51017 L .43353 .51315 L p
1 g
F P
s
P
p
.42214 .54646 m .43072 .52136 L .43223 .54022 L 1 g
F
P
p
.43072 .52136 m .43353 .51315 L .4328 .5283 L 1 g
F
P
p
.43072 .52136 m .4328 .5283 L .43223 .54022 L 1 g
F
P
p
.43346 .52734 m .43369 .50964 L .4332 .51991 L 1 g
F
P
p
.002 w
.43166 .52995 m .43346 .52734 L p
.4331 .517 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4328 .5283 L p
1 g
F P
s
P
p
.43925 .54566 m .4328 .5283 L .43618 .53958 L 1 g
F
P
p
.002 w
.43353 .51315 m .45962 .52328 L p
.43572 .53806 L 1 g
F P
s
P
p
.43223 .54022 m .4328 .5283 L .43572 .53806 L 1 g
F
P
p
.4328 .5283 m .43353 .51315 L .43572 .53806 L 1 g
F
P
p
.002 w
.43845 .54717 m .43925 .54566 L p
.43618 .53958 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43845 .54717 L p
1 g
F P
s
P
p
.002 w
.45633 .55142 m .46224 .57111 L p
.45094 .5627 L 1 g
F P
s
P
p
.44817 .56064 m .44872 .56001 L .45094 .5627 L 1 g
F
P
p
.45146 .56129 m .43845 .54717 L .43967 .54901 L 1 g
F
P
p
.45146 .56129 m .43967 .54901 L .44555 .55616 L 1 g
F
P
p
.44872 .56001 m .45633 .55142 L .45094 .5627 L 1 g
F
P
p
.002 w
.43232 .57852 m .42214 .54646 L .43967 .54901 L p
1 g
F P
s
P
p
.002 w
.43967 .54901 m .45633 .55142 L p
.44872 .56001 L 1 g
F P
s
P
p
.43232 .57852 m .43967 .54901 L .44872 .56001 L 1 g
F
P
p
.44286 .55381 m .43967 .54901 L .43743 .5491 L 1 g
F
P
p
.002 w
.43967 .54901 m .42214 .54646 L p
.43337 .53952 L 1 g
F P
s
P
p
.002 w
.43845 .54717 m .43833 .54739 L p
.43967 .54901 L 1 g
F P
s
P
p
.002 w
.43833 .54739 m .43743 .5491 L p
.43967 .54901 L 1 g
F P
s
P
p
.44555 .55616 m .43967 .54901 L .44286 .55381 L 1 g
F
P
p
.002 w
.45962 .52328 m .45633 .55142 L .43967 .54901 L p
1 g
F P
s
P
p
.43337 .53952 m .45962 .52328 L .43967 .54901 L 1 g
F
P
p
.002 w
.4328 .5283 m .43146 .53025 L p
.43618 .53958 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43845 .54717 L p
1 g
F P
s
P
p
.43618 .53958 m .43146 .53025 L .43845 .54717 L 1 g
F
P
p
.002 w
.43369 .50964 m .43287 .51061 L p
.4332 .51991 L 1 g
F P
s
P
p
.002 w
.47371 .49519 m .45962 .52328 L .43353 .51315 L p
1 g
F P
s
P
p
.43414 .50757 m .47371 .49519 L .43353 .51315 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43166 .52995 L p
1 g
F P
s
P
p
.4331 .517 m .43287 .51061 L .43166 .52995 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43765 .50172 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.002 w
.45751 .4769 m .45698 .47747 L p
.44965 .4845 L 1 g
F P
s
P
p
.44339 .4905 m .45751 .4769 L .44965 .4845 L 1 g
F
P
p
.002 w
.44191 .49207 m .44339 .4905 L p
.45133 .48289 L 1 g
F P
s
P
p
.002 w
.42829 .50516 m .44363 .47378 L .45348 .4808 L p
1 g
F P
s
P
p
.002 w
.45348 .4808 m .44363 .47378 L p
.46181 .47268 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44191 .49207 L p
1 g
F P
s
P
p
.45133 .48289 m .45698 .47747 L .44191 .49207 L 1 g
F
P
p
.002 w
.47764 .46705 m .47718 .46778 L p
.46536 .47297 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45775 .47664 L p
1 g
F P
s
P
p
.46536 .47297 m .47718 .46778 L .45775 .47664 L 1 g
F
P
p
.002 w
.44363 .47378 m .44603 .47123 L p
.46962 .47091 L 1 g
F P
s
P
p
.44363 .47378 m .46962 .47091 L .46655 .47239 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .49081 .46535 L 1 g
F
P
p
.002 w
.47735 .4675 m .47786 .46667 L p
.49081 .46535 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.44603 .47123 m .47376 .44178 L .49272 .46505 L p
1 g
F P
s
P
p
.49081 .46535 m .49272 .46505 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46388 m .5 .46408 L p
.49272 .46505 L 1 g
F P
s
P
p
.002 w
.5 .46408 m .5 .46442 L p
.49272 .46505 L 1 g
F P
s
P
p
.002 w
.49055 .46239 m .47376 .44178 L p
.50412 .46322 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.50652 .46491 L 1 g
F P
s
P
p
.50412 .46322 m .50652 .46491 L .5 .46388 L 1 g
F
P
p
.50412 .46322 m .5 .46388 L .49055 .46239 L 1 g
F
P
p
.002 w
.49272 .46505 m .49055 .46239 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47735 .4675 L p
1 g
F P
s
P
p
.49081 .46535 m .5 .46442 L .47735 .4675 L 1 g
F
P
p
.002 w
.5 .464 m .5 .46388 L p
.50652 .46491 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52734 .45236 m .50652 .46491 L p
.47376 .44178 L 1 g
F P
s
P
p
.002 w
.50652 .46491 m .51158 .46186 L p
.51723 .4664 L 1 g
F P
s
P
p
.50652 .46491 m .51723 .4664 L .54102 .48553 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .464 L p
1 g
F P
s
P
p
.5114 .46559 m .52282 .46778 L .5 .464 L 1 g
F
P
p
.002 w
.52241 .46713 m .52282 .46778 L p
.5114 .46559 L 1 g
F P
s
P
p
.53241 .47199 m .53619 .47383 L .53354 .47257 L 1 g
F
P
p
.52214 .46667 m .53619 .47383 L .53241 .47199 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.54234 .47673 m .549 .48321 L .53619 .47383 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.51158 .46186 m .52734 .45236 L .53619 .47383 L p
1 g
F P
s
P
p
.002 w
.53619 .47383 m .53408 .4687 L p
.54234 .47673 L 1 g
F P
s
P
p
.002 w
.54234 .47673 m .54302 .47747 L p
.53354 .47257 L 1 g
F P
s
P
p
.002 w
.54264 .47706 m .54234 .47673 L p
.549 .48321 L 1 g
F P
s
P
p
.002 w
.54234 .47673 m .54174 .47608 L p
.549 .48321 L 1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.56352 .479 m .549 .48321 L p
.52734 .45236 L 1 g
F P
s
P
p
.002 w
.53408 .4687 m .52734 .45236 L p
.549 .48321 L 1 g
F P
s
P
p
.002 w
.549 .48321 m .5529 .48208 L p
.55577 .48976 L 1 g
F P
s
P
p
.549 .48321 m .55577 .48976 L .56453 .5132 L 1 g
F
P
p
.002 w
.5643 .50555 m .56453 .5132 L p
.5529 .48208 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54264 .47706 L p
1 g
F P
s
P
p
.55109 .48523 m .55834 .49233 L .54264 .47706 L 1 g
F
P
p
.002 w
.55739 .49133 m .55834 .49233 L p
.55109 .48523 L 1 g
F P
s
P
p
.56202 .50086 m .5643 .50555 L .56235 .50148 L 1 g
F
P
p
.002 w
.56622 .50953 m .56713 .51061 L p
.56235 .50148 L 1 g
F P
s
P
p
.002 w
.56644 .5098 m .56622 .50953 L p
.56662 .51318 L 1 g
F P
s
P
p
.002 w
.56315 .5438 m .56355 .54422 L .56309 .544 L p
1 g
F P
s
P
p
.002 w
.56326 .54343 m .56355 .54422 L .56315 .5438 L p
1 g
F P
s
P
p
.002 w
.56303 .54416 m .56355 .54422 L .56298 .54431 L p
1 g
F P
s
P
p
.002 w
.56309 .544 m .56355 .54422 L .56303 .54416 L p
1 g
F P
s
P
p
.002 w
.56298 .54431 m .56355 .54422 L .56291 .5445 L p
1 g
F P
s
P
p
.002 w
.56291 .5445 m .56355 .54422 L .56279 .54482 L p
1 g
F P
s
P
p
.002 w
.56279 .54482 m .56355 .54422 L .56242 .54579 L p
1 g
F P
s
P
p
.002 w
.57686 .56502 m .56623 .56974 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.58598 .55789 m .57686 .56502 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.56623 .56974 m .55518 .57155 L .56304 .54589 L p
1 g
F P
s
P
p
.002 w
.56304 .54589 m .56355 .54422 L .56364 .54512 L p
1 g
F P
s
P
p
.002 w
.56364 .54512 m .56623 .56974 L p
.56304 .54589 L 1 g
F P
s
P
p
.002 w
.56029 .55486 m .55518 .57155 L p
.55066 .56217 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56175 .54754 L p
1 g
F P
s
P
p
.002 w
.56175 .54754 m .56174 .54753 L p
.56171 .54759 L 1 g
F P
s
P
p
.56171 .54759 m .54998 .56518 L .56175 .54754 L 1 g
F
P
p
.002 w
.59261 .54908 m .58598 .55789 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.59605 .53951 m .59261 .54908 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.59591 .53019 m .59605 .53951 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.59214 .52212 m .59591 .53019 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.58512 .51619 m .59214 .52212 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.57557 .51309 m .58512 .51619 L .56355 .54422 L closepath p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56361 .54221 m .56453 .5132 L .57192 .51312 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56644 .5098 L p
1 g
F P
s
P
p
.56702 .52036 m .56854 .53025 L .56644 .5098 L 1 g
F
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.56702 .52036 L 1 g
F P
s
P
p
.5642 .54014 m .56337 .54306 L .56415 .54045 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53483 .53105 m .54294 .52271 L .56315 .5438 L p
1 g
F P
s
P
p
.002 w
.56309 .544 m .53483 .53105 L p
.56315 .5438 L 1 g
F P
s
P
p
.56312 .5439 m .56309 .544 L .56312 .54391 L 1 g
F
P
p
.56415 .54045 m .56312 .54391 L .56402 .54114 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54294 .52271 m .55323 .51652 L .56326 .54343 L p
1 g
F P
s
P
p
.002 w
.56315 .5438 m .54294 .52271 L p
.56326 .54343 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52837 .55029 m .5298 .5406 L .56303 .54416 L p
1 g
F P
s
P
p
.002 w
.56298 .54431 m .52837 .55029 L p
.56303 .54416 L 1 g
F P
s
P
p
.56299 .5443 m .56295 .5444 L .56298 .54432 L 1 g
F
P
p
.56402 .54114 m .56298 .54432 L .56387 .54196 L 1 g
F
P
p
.002 w
.5298 .5406 m .53483 .53105 L .56309 .544 L p
1 g
F P
s
P
p
.002 w
.56303 .54416 m .5298 .5406 L p
.56309 .544 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53066 .55905 m .52837 .55029 L .56298 .54431 L p
1 g
F P
s
P
p
.002 w
.56291 .5445 m .53066 .55905 L p
.56298 .54431 L 1 g
F P
s
P
p
.56387 .54196 m .56291 .5445 L .56383 .5422 L 1 g
F
P
p
.56291 .5445 m .56268 .54513 L .5628 .54483 L 1 g
F
P
p
.56291 .5445 m .5628 .54483 L .56383 .5422 L 1 g
F
P
p
.56075 .54566 m .55514 .55583 L .55587 .55492 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53638 .56594 m .53066 .55905 L .56291 .5445 L p
1 g
F P
s
P
p
.002 w
.56279 .54482 m .53638 .56594 L p
.56291 .5445 L 1 g
F P
s
P
p
.002 w
.53638 .56594 m .56279 .54482 L p
.55587 .55492 L 1 g
F P
s
P
p
.002 w
.56242 .54579 m .55587 .55492 L p
.56279 .54482 L 1 g
F P
s
P
p
.56383 .5422 m .56242 .54579 L .56257 .5491 L 1 g
F
P
p
.002 w
.56174 .54753 m .56174 .54753 L p
.56242 .54579 L 1 g
F P
s
P
p
.002 w
.56174 .54753 m .56257 .5491 L p
.56242 .54579 L 1 g
F P
s
P
p
.002 w
.55587 .55492 m .56242 .54579 L p
.56174 .54753 L 1 g
F P
s
P
p
.002 w
.56174 .54753 m .56174 .54753 L p
.55587 .55492 L 1 g
F P
s
P
p
.002 w
.55587 .55492 m .55066 .56217 L p
.54994 .56236 L 1 g
F P
s
P
p
.55514 .55583 m .54998 .56518 L .56174 .54753 L 1 g
F
P
p
.54994 .56236 m .53638 .56594 L .55587 .55492 L 1 g
F
P
p
.002 w
.54188 .56874 m .53638 .56594 L p
.55066 .56217 L 1 g
F P
s
P
p
.002 w
.54926 .56322 m .54998 .56518 L p
.55514 .55583 L 1 g
F P
s
P
p
.54263 .56818 m .54188 .56874 L .54241 .56843 L 1 g
F
P
p
.002 w
.54965 .56428 m .54926 .56323 L p
.54241 .56843 L 1 g
F P
s
P
p
.53277 .57424 m .53638 .56594 L .54459 .57054 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54965 .56428 L p
1 g
F P
s
P
p
.53898 .5704 m .5322 .57686 L .54965 .56428 L 1 g
F
P
p
.002 w
.53638 .56594 m .54188 .56874 L p
.54163 .56888 L 1 g
F P
s
P
p
.002 w
.51322 .58035 m .53638 .56594 L p
.53277 .57424 L 1 g
F P
s
P
p
.002 w
.5317 .57457 m .5322 .57686 L p
.53898 .5704 L 1 g
F P
s
P
p
.52103 .57791 m .51322 .58035 L .52019 .57834 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.53066 .55905 m .53638 .56594 L .51231 .58092 L p
1 g
F P
s
P
p
.002 w
.51097 .581 m .51079 .57862 L p
.50676 .58125 L 1 g
F P
s
P
p
.51057 .58102 m .53066 .55905 L .51231 .58092 L 1 g
F
P
p
.002 w
.51097 .581 m .51111 .583 L p
.52019 .57834 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.49702 .56991 m .53066 .55905 L p
.51057 .58102 L 1 g
F P
s
P
p
.002 w
.50851 .58328 m .50676 .58125 L p
.51057 .58102 L 1 g
F P
s
P
p
.002 w
.50676 .58125 m .49702 .56991 L p
.51057 .58102 L 1 g
F P
s
P
p
.49048 .58041 m .50353 .58109 L .50558 .5846 L 1 g
F
P
p
.002 w
.49702 .56991 m .50851 .58328 L .50558 .5846 L p
1 g
F P
s
P
p
.50676 .58125 m .48889 .583 L .511 .58147 L 1 g
F
P
p
.49949 .58088 m .49363 .58205 L .50676 .58125 L 1 g
F
P
p
.49363 .58205 m .48889 .583 L .50676 .58125 L 1 g
F
P
p
.002 w
.511 .58147 m .51097 .581 L p
.50676 .58125 L 1 g
F P
s
P
p
.49048 .58041 m .49702 .56991 L .50353 .58109 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58147 L p
1 g
F P
s
P
p
.002 w
.48908 .58034 m .48889 .583 L p
.49949 .58088 L 1 g
F P
s
P
p
.002 w
.46822 .57495 m .4678 .57686 L p
.47649 .57758 L 1 g
F P
s
P
p
.47925 .5778 m .46961 .57531 L .47649 .57758 L 1 g
F
P
p
.46961 .57531 m .46822 .57495 L .47649 .57758 L 1 g
F
P
p
.002 w
.46824 .57486 m .46822 .57495 L p
.46885 .57506 L 1 g
F P
s
P
p
.002 w
.46822 .57495 m .46824 .57486 L p
.45339 .56739 L 1 g
F P
s
P
p
.45984 .5696 m .45339 .56739 L .46824 .57486 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45094 .5627 L p
1 g
F P
s
P
p
.44555 .55616 m .43743 .5491 L .45094 .5627 L 1 g
F
P
p
.002 w
.45002 .56518 m .45339 .56739 L p
.46055 .56985 L 1 g
F P
s
P
p
.4592 .56885 m .45002 .56518 L .46055 .56985 L 1 g
F
P
p
.002 w
.45339 .56739 m .4678 .57686 L .46822 .57495 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58034 L p
1 g
F P
s
P
p
.47925 .5778 m .4678 .57686 L .48908 .58034 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51033 .449 L
s
P
p
.004 w
.52832 .48119 m
.54936 .51883 L
s
P
p
.002 w
.45616 .29868 m .39681 .33469 L .38513 .31476 L p
1 g
F P
s
P
p
.002 w
.38513 .31476 m .44511 .27833 L .45616 .29868 L p
1 g
F P
s
P
p
.002 w
.62502 .53165 m .62498 .51333 L .64981 .4943 L p
1 g
F P
s
P
p
.002 w
.63976 .47068 m .64981 .4943 L .62498 .51333 L p
1 g
F P
s
P
p
.002 w
.64981 .4943 m .63976 .47068 L .65715 .44326 L p
1 g
F P
s
P
p
.002 w
.52188 .28126 m .45616 .29868 L .44511 .27833 L p
1 g
F P
s
P
p
.002 w
.59684 .33882 m .64376 .35753 L .64015 .38778 L p
1 g
F P
s
P
p
.002 w
.64376 .35753 m .59684 .33882 L .59232 .30938 L p
1 g
F P
s
P
p
.002 w
.59261 .54908 m .59605 .53951 L .62502 .53165 L p
1 g
F P
s
P
p
.002 w
.62498 .51333 m .62502 .53165 L .59605 .53951 L p
1 g
F P
s
P
p
.002 w
.39017 .4281 m .36715 .47762 L .34423 .45946 L p
1 g
F P
s
P
p
.002 w
.34423 .45946 m .36873 .40559 L .39017 .4281 L p
1 g
F P
s
P
p
.002 w
.6322 .41994 m .65715 .44326 L .63976 .47068 L p
1 g
F P
s
P
p
.002 w
.65715 .44326 m .6322 .41994 L .64015 .38778 L p
1 g
F P
s
P
p
.002 w
.41204 .35818 m .36873 .40559 L .35178 .3844 L p
1 g
F P
s
P
p
.002 w
.35178 .3844 m .39681 .33469 L .41204 .35818 L p
1 g
F P
s
P
p
.002 w
.42585 .51017 m .42214 .54646 L .39081 .5381 L p
1 g
F P
s
P
p
.002 w
.39081 .5381 m .39465 .49475 L .42585 .51017 L p
1 g
F P
s
P
p
.002 w
.53177 .30684 m .59232 .30938 L .59684 .33882 L p
1 g
F P
s
P
p
.002 w
.59232 .30938 m .53177 .30684 L .52188 .28126 L p
1 g
F P
s
P
p
.002 w
.45616 .29868 m .52188 .28126 L .53177 .30684 L p
1 g
F P
s
P
p
.002 w
.59605 .53951 m .59591 .53019 L .62498 .51333 L p
1 g
F P
s
P
p
.002 w
.61785 .49729 m .62498 .51333 L .59591 .53019 L p
1 g
F P
s
P
p
.002 w
.62498 .51333 m .61785 .49729 L .63976 .47068 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59847 .37171 m .64015 .38778 L .6322 .41994 L p
1 g
F P
s
P
p
.002 w
.64015 .38778 m .59847 .37171 L .59684 .33882 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.62009 .45287 m .63976 .47068 L .61785 .49729 L p
1 g
F P
s
P
p
.002 w
.63976 .47068 m .62009 .45287 L .6322 .41994 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41543 .45112 m .39465 .49475 L .36715 .47762 L p
1 g
F P
s
P
p
.002 w
.36715 .47762 m .39017 .4281 L .41543 .45112 L p
1 g
F P
s
P
p
.002 w
.46889 .32372 m .41204 .35818 L .39681 .33469 L p
1 g
F P
s
P
p
.002 w
.39681 .33469 m .45616 .29868 L .46889 .32372 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52837 .55029 m .53066 .55905 L .49702 .56991 L p
1 g
F P
s
P
p
.002 w
.49702 .56991 m .49218 .55273 L .52837 .55029 L p
1 g
F P
s
P
p
.002 w
.53177 .30684 m .46889 .32372 L .45616 .29868 L p
1 g
F P
s
P
p
.002 w
.59591 .53019 m .59214 .52212 L .61785 .49729 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60421 .48536 m .61785 .49729 L .59214 .52212 L p
1 g
F P
s
P
p
.002 w
.61785 .49729 m .60421 .48536 L .62009 .45287 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.43037 .3845 m .39017 .4281 L .36873 .40559 L p
1 g
F P
s
P
p
.002 w
.36873 .40559 m .41204 .35818 L .43037 .3845 L p
1 g
F P
s
P
p
.002 w
.54093 .33689 m .59684 .33882 L .59847 .37171 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.56075 .34888 L
s
P
p
.002 w
.59684 .33882 m .54093 .33689 L .53177 .30684 L p
1 g
F P
s
P
p
.004 w
.57621 .3281 m
.60178 .29376 L
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.59709 .40692 m .6322 .41994 L .62009 .45287 L p
1 g
F P
s
P
p
.002 w
.6322 .41994 m .59709 .40692 L .59847 .37171 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59214 .52212 m .58512 .51619 L .60421 .48536 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.49472 .53355 m .49218 .55273 L .45633 .55142 L p
1 g
F P
s
P
p
.002 w
.45633 .55142 m .45962 .52328 L .49472 .53355 L p
1 g
F P
s
P
p
.002 w
.46889 .32372 m .53177 .30684 L .54093 .33689 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44363 .47378 m .42585 .51017 L .39465 .49475 L p
1 g
F P
s
P
p
.002 w
.39465 .49475 m .41543 .45112 L .44363 .47378 L p
1 g
F P
s
P
p
.002 w
.5298 .5406 m .52837 .55029 L .49218 .55273 L p
1 g
F P
s
P
p
.002 w
.49218 .55273 m .49472 .53355 L .5298 .5406 L p
1 g
F P
s
P
p
.002 w
.59269 .44313 m .62009 .45287 L .60421 .48536 L p
1 g
F P
s
P
p
.002 w
.62009 .45287 m .59269 .44313 L .59709 .40692 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58512 .51619 m .57557 .51309 L .58542 .47898 L p
1 g
F P
s
P
p
.002 w
.58542 .47898 m .60421 .48536 L .58512 .51619 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.60421 .48536 m .58542 .47898 L .59269 .44313 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54899 .37042 m .59847 .37171 L .59709 .40692 L p
1 g
F P
s
P
p
.002 w
.59847 .37171 m .54899 .37042 L .54093 .33689 L p
1 g
F P
s
P
p
.004 w
.56316 .34564 m
.57621 .3281 L
s
P
p
.004 w
.56265 .34633 m
.56316 .34564 L
s
P
p
.002 w
.53483 .53105 m .5298 .5406 L .49472 .53355 L p
1 g
F P
s
P
p
.002 w
.48291 .35269 m .43037 .3845 L .41204 .35818 L p
1 g
F P
s
P
p
.002 w
.41204 .35818 m .46889 .32372 L .48291 .35269 L p
1 g
F P
s
P
p
.002 w
.56352 .479 m .58542 .47898 L .57557 .51309 L p
1 g
F P
s
P
p
.002 w
.54093 .33689 m .48291 .35269 L .46889 .32372 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.4512 .41273 m .41543 .45112 L .39017 .4281 L p
1 g
F P
s
P
p
.002 w
.39017 .4281 m .43037 .3845 L .4512 .41273 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54294 .52271 m .53483 .53105 L .50451 .51452 L p
1 g
F P
s
P
p
.002 w
.49472 .53355 m .50451 .51452 L .53483 .53105 L p
1 g
F P
s
P
p
.002 w
.56453 .5132 m .55323 .51652 L .54102 .48553 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50451 .51452 m .49472 .53355 L .45962 .52328 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48291 .35269 m .54093 .33689 L .54899 .37042 L p
1 g
F P
s
P
p
.002 w
.55323 .51652 m .54294 .52271 L .52055 .49786 L p
1 g
F P
s
P
p
.002 w
.50451 .51452 m .52055 .49786 L .54294 .52271 L p
1 g
F P
s
P
p
.002 w
.45962 .52328 m .47371 .49519 L .50451 .51452 L p
1 g
F P
s
P
p
.002 w
.52055 .49786 m .54102 .48553 L .55323 .51652 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55561 .4062 m .59709 .40692 L .59269 .44313 L p
1 g
F P
s
P
p
.002 w
.59709 .40692 m .55561 .4062 L .54899 .37042 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58542 .47898 m .56352 .479 L .56052 .44287 L p
1 g
F P
s
P
p
.002 w
.56052 .44287 m .59269 .44313 L .58542 .47898 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.59269 .44313 m .56052 .44287 L .55561 .4062 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.47376 .44178 m .44363 .47378 L .41543 .45112 L p
1 g
F P
s
P
p
.002 w
.41543 .45112 m .4512 .41273 L .47376 .44178 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52055 .49786 m .50451 .51452 L .47371 .49519 L p
1 g
F P
s
P
p
.002 w
.4977 .38461 m .4512 .41273 L .43037 .3845 L p
1 g
F P
s
P
p
.002 w
.43037 .3845 m .48291 .35269 L .4977 .38461 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52734 .45236 m .56052 .44287 L .56352 .479 L p
1 g
F P
s
P
p
.002 w
.54899 .37042 m .4977 .38461 L .48291 .35269 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.4977 .38461 m .54899 .37042 L .55561 .4062 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.54102 .48553 m .52055 .49786 L .49719 .47054 L p
1 g
F P
s
P
p
.002 w
.47371 .49519 m .49719 .47054 L .52055 .49786 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.56052 .44287 m .52734 .45236 L .51271 .41827 L p
1 g
F P
s
P
p
.002 w
.51271 .41827 m .55561 .4062 L .56052 .44287 L p
1 g
F P
s
P
p
.002 w
.55561 .4062 m .51271 .41827 L .4977 .38461 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51271 .41827 m .47376 .44178 L .4512 .41273 L p
1 g
F P
s
P
p
.002 w
.4512 .41273 m .4977 .38461 L .51271 .41827 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47376 .44178 m .51271 .41827 L .52734 .45236 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.58514 .58285 m
.58985 .59127 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .60178 .29376 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60131 .61178 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.07)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.07)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44688 .46074 m .48795 .45584 L .48093 .42814 L p
1 g
F P
s
P
p
.002 w
.48093 .42814 m .44667 .43209 L .44688 .46074 L p
1 g
F P
s
P
p
.002 w
.51355 .41547 m .48093 .42814 L .48795 .45584 L p
1 g
F P
s
P
p
.002 w
.44667 .43209 m .48093 .42814 L .47436 .40046 L p
1 g
F P
s
P
p
.002 w
.48093 .42814 m .51355 .41547 L .49969 .39062 L p
1 g
F P
s
P
p
.002 w
.49969 .39062 m .47436 .40046 L .48093 .42814 L p
1 g
F P
s
P
p
.002 w
.48795 .45584 m .52705 .44066 L .51355 .41547 L p
1 g
F P
s
P
p
.002 w
.54146 .39528 m .51355 .41547 L .52705 .44066 L p
1 g
F P
s
P
p
.002 w
.51355 .41547 m .54146 .39528 L .52129 .37485 L p
1 g
F P
s
P
p
.002 w
.52129 .37485 m .49969 .39062 L .51355 .41547 L p
1 g
F P
s
P
p
.002 w
.44839 .48884 m .4953 .48305 L .48795 .45584 L p
1 g
F P
s
P
p
.002 w
.48795 .45584 m .44688 .46074 L .44839 .48884 L p
1 g
F P
s
P
p
.002 w
.52705 .44066 m .48795 .45584 L .4953 .48305 L p
1 g
F P
s
P
p
.002 w
.4953 .48305 m .53997 .46571 L .52705 .44066 L p
1 g
F P
s
P
p
.002 w
.56063 .41657 m .52705 .44066 L .53997 .46571 L p
1 g
F P
s
P
p
.002 w
.52705 .44066 m .56063 .41657 L .54146 .39528 L p
1 g
F P
s
P
p
.002 w
.47436 .40046 m .44775 .40342 L .44667 .43209 L p
1 g
F P
s
P
p
.002 w
.44775 .40342 m .47436 .40046 L .46836 .37329 L p
1 g
F P
s
P
p
.002 w
.47436 .40046 m .49969 .39062 L .48574 .36654 L p
1 g
F P
s
P
p
.002 w
.48574 .36654 m .46836 .37329 L .47436 .40046 L p
1 g
F P
s
P
p
.002 w
.49969 .39062 m .52129 .37485 L .5005 .35567 L p
1 g
F P
s
P
p
.002 w
.5005 .35567 m .48574 .36654 L .49969 .39062 L p
1 g
F P
s
P
p
.002 w
.45119 .51586 m .50284 .50929 L .4953 .48305 L p
1 g
F P
s
P
p
.002 w
.4953 .48305 m .44839 .48884 L .45119 .51586 L p
1 g
F P
s
P
p
.002 w
.53997 .46571 m .4953 .48305 L .50284 .50929 L p
1 g
F P
s
P
p
.002 w
.50284 .50929 m .55205 .49019 L .53997 .46571 L p
1 g
F P
s
P
p
.002 w
.57845 .43835 m .53997 .46571 L .55205 .49019 L p
1 g
F P
s
P
p
.002 w
.53997 .46571 m .57845 .43835 L .56063 .41657 L p
1 g
F P
s
P
p
.002 w
.40762 .45473 m .44688 .46074 L .44667 .43209 L p
1 g
F P
s
P
p
.002 w
.44667 .43209 m .41401 .42682 L .40762 .45473 L p
1 g
F P
s
P
p
.002 w
.41401 .42682 m .44667 .43209 L .44775 .40342 L p
1 g
F P
s
P
p
.002 w
.56193 .36936 m .54146 .39528 L .56063 .41657 L p
1 g
F P
s
P
p
.002 w
.54146 .39528 m .56193 .36936 L .53699 .35464 L p
1 g
F P
s
P
p
.002 w
.53699 .35464 m .52129 .37485 L .54146 .39528 L p
1 g
F P
s
P
p
.002 w
.44775 .40342 m .42248 .39913 L .41401 .42682 L p
1 g
F P
s
P
p
.002 w
.42248 .39913 m .44775 .40342 L .45012 .37525 L p
1 g
F P
s
P
p
.002 w
.46836 .37329 m .45012 .37525 L .44775 .40342 L p
1 g
F P
s
P
p
.002 w
.52129 .37485 m .53699 .35464 L .51112 .34176 L p
1 g
F P
s
P
p
.002 w
.51112 .34176 m .5005 .35567 L .52129 .37485 L p
1 g
F P
s
P
p
.002 w
.40345 .48233 m .44839 .48884 L .44688 .46074 L p
1 g
F P
s
P
p
.002 w
.44688 .46074 m .40762 .45473 L .40345 .48233 L p
1 g
F P
s
P
p
.002 w
.58547 .38566 m .56063 .41657 L .57845 .43835 L p
1 g
F P
s
P
p
.002 w
.56063 .41657 m .58547 .38566 L .56193 .36936 L p
1 g
F P
s
P
p
.002 w
.45012 .37525 m .46836 .37329 L .46305 .34715 L p
1 g
F P
s
P
p
.002 w
.46836 .37329 m .48574 .36654 L .47194 .3437 L p
1 g
F P
s
P
p
.002 w
.47194 .3437 m .46305 .34715 L .46836 .37329 L p
1 g
F P
s
P
p
.002 w
.48574 .36654 m .5005 .35567 L .47945 .33812 L p
1 g
F P
s
P
p
.002 w
.47945 .33812 m .47194 .3437 L .48574 .36654 L p
1 g
F P
s
P
p
.002 w
.45012 .37525 m .43285 .37217 L .42248 .39913 L p
1 g
F P
s
P
p
.002 w
.43285 .37217 m .45012 .37525 L .45373 .34811 L p
1 g
F P
s
P
p
.002 w
.46305 .34715 m .45373 .34811 L .45012 .37525 L p
1 g
F P
s
P
p
.002 w
.5005 .35567 m .51112 .34176 L .48481 .33099 L p
1 g
F P
s
P
p
.002 w
.48481 .33099 m .47945 .33812 L .5005 .35567 L p
1 g
F P
s
P
p
.002 w
.40162 .50906 m .45119 .51586 L .44839 .48884 L p
1 g
F P
s
P
p
.002 w
.44839 .48884 m .40345 .48233 L .40162 .50906 L p
1 g
F P
s
P
p
.002 w
.45525 .54126 m .51044 .53403 L .50284 .50929 L p
1 g
F P
s
P
p
.002 w
.50284 .50929 m .45119 .51586 L .45525 .54126 L p
1 g
F P
s
P
p
.002 w
.55205 .49019 m .50284 .50929 L .51044 .53403 L p
1 g
F P
s
P
p
.002 w
.55205 .49019 m .59457 .46021 L .57845 .43835 L p
1 g
F P
s
P
p
.002 w
.60713 .40323 m .57845 .43835 L .59457 .46021 L p
1 g
F P
s
P
p
.002 w
.57845 .43835 m .60713 .40323 L .58547 .38566 L p
1 g
F P
s
P
p
.002 w
.51044 .53403 m .56306 .51361 L .55205 .49019 L p
1 g
F P
s
P
p
.002 w
.59457 .46021 m .55205 .49019 L .56306 .51361 L p
1 g
F P
s
P
p
.002 w
.38621 .41259 m .41401 .42682 L .42248 .39913 L p
1 g
F P
s
P
p
.002 w
.42248 .39913 m .4011 .38787 L .38621 .41259 L p
1 g
F P
s
P
p
.002 w
.4011 .38787 m .42248 .39913 L .43285 .37217 L p
1 g
F P
s
P
p
.002 w
.54508 .33192 m .53699 .35464 L .56193 .36936 L p
1 g
F P
s
P
p
.002 w
.53699 .35464 m .54508 .33192 L .51646 .32619 L p
1 g
F P
s
P
p
.002 w
.51646 .32619 m .51112 .34176 L .53699 .35464 L p
1 g
F P
s
P
p
.002 w
.37401 .43802 m .40762 .45473 L .41401 .42682 L p
1 g
F P
s
P
p
.002 w
.41401 .42682 m .38621 .41259 L .37401 .43802 L p
1 g
F P
s
P
p
.002 w
.57275 .34012 m .56193 .36936 L .58547 .38566 L p
1 g
F P
s
P
p
.002 w
.56193 .36936 m .57275 .34012 L .54508 .33192 L p
1 g
F P
s
P
p
.002 w
.43285 .37217 m .41836 .36431 L .4011 .38787 L p
1 g
F P
s
P
p
.002 w
.41836 .36431 m .43285 .37217 L .44495 .34648 L p
1 g
F P
s
P
p
.002 w
.45373 .34811 m .44495 .34648 L .43285 .37217 L p
1 g
F P
s
P
p
.002 w
.51112 .34176 m .51646 .32619 L .48742 .32305 L p
1 g
F P
s
P
p
.002 w
.48742 .32305 m .48481 .33099 L .51112 .34176 L p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .45373 .34811 L .46305 .34715 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .46305 .34715 L .47194 .3437 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .47194 .3437 L .47945 .33812 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .44495 .34648 L .45373 .34811 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .47945 .33812 L .48481 .33099 L closepath p
1 g
F P
s
P
p
.002 w
.36479 .46365 m .40345 .48233 L .40762 .45473 L p
1 g
F P
s
P
p
.002 w
.40762 .45473 m .37401 .43802 L .36479 .46365 L p
1 g
F P
s
P
p
.002 w
.59888 .35067 m .58547 .38566 L .60713 .40323 L p
1 g
F P
s
P
p
.002 w
.58547 .38566 m .59888 .35067 L .57275 .34012 L p
1 g
F P
s
P
p
.002 w
.40224 .53437 m .45525 .54126 L .45119 .51586 L p
1 g
F P
s
P
p
.002 w
.45119 .51586 m .40162 .50906 L .40224 .53437 L p
1 g
F P
s
P
p
.002 w
.56306 .51361 m .60863 .48173 L .59457 .46021 L p
1 g
F P
s
P
p
.002 w
.62647 .42176 m .59457 .46021 L .60863 .48173 L p
1 g
F P
s
P
p
.002 w
.59457 .46021 m .62647 .42176 L .60713 .40323 L p
1 g
F P
s
P
p
.002 w
.44495 .34648 m .43763 .3424 L .41836 .36431 L p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .43763 .3424 L .44495 .34648 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .48481 .33099 L .48742 .32305 L closepath p
1 g
F P
s
P
p
.002 w
.46053 .56447 m .51796 .55675 L .51044 .53403 L p
1 g
F P
s
P
p
.002 w
.51044 .53403 m .45525 .54126 L .46053 .56447 L p
1 g
F P
s
P
p
.002 w
.56306 .51361 m .51044 .53403 L .51796 .55675 L p
1 g
F P
s
P
p
.002 w
.51796 .55675 m .57275 .53549 L .56306 .51361 L p
1 g
F P
s
P
p
.002 w
.60863 .48173 m .56306 .51361 L .57275 .53549 L p
1 g
F P
s
P
p
.002 w
.38595 .37059 m .4011 .38787 L .41836 .36431 L p
1 g
F P
s
P
p
.002 w
.41836 .36431 m .40822 .3524 L .38595 .37059 L p
1 g
F P
s
P
p
.002 w
.40822 .3524 m .41836 .36431 L .43763 .3424 L p
1 g
F P
s
P
p
.002 w
.51583 .31058 m .51646 .32619 L .54508 .33192 L p
1 g
F P
s
P
p
.002 w
.51646 .32619 m .51583 .31058 L .48699 .31514 L p
1 g
F P
s
P
p
.002 w
.48699 .31514 m .48742 .32305 L .51646 .32619 L p
1 g
F P
s
P
p
.002 w
.36629 .39052 m .38621 .41259 L .4011 .38787 L p
1 g
F P
s
P
p
.002 w
.4011 .38787 m .38595 .37059 L .36629 .39052 L p
1 g
F P
s
P
p
.002 w
.43763 .3424 m .43258 .33628 L .40822 .3524 L p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .43258 .33628 L .43763 .3424 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .48742 .32305 L .48699 .31514 L closepath p
1 g
F P
s
P
p
.002 w
.5445 .30898 m .54508 .33192 L .57275 .34012 L p
1 g
F P
s
P
p
.002 w
.54508 .33192 m .5445 .30898 L .51583 .31058 L p
1 g
F P
s
P
p
.002 w
.35883 .48894 m .40162 .50906 L .40345 .48233 L p
1 g
F P
s
P
p
.002 w
.40345 .48233 m .36479 .46365 L .35883 .48894 L p
1 g
F P
s
P
p
.002 w
.62293 .36339 m .60713 .40323 L .62647 .42176 L p
1 g
F P
s
P
p
.002 w
.60713 .40323 m .62293 .36339 L .59888 .35067 L p
1 g
F P
s
P
p
.002 w
.34969 .4118 m .37401 .43802 L .38621 .41259 L p
1 g
F P
s
P
p
.002 w
.38621 .41259 m .36629 .39052 L .34969 .4118 L p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .43037 .32877 L .43258 .33628 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .45977 .29923 L .45031 .30149 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .45031 .30149 L .44181 .30621 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .44181 .30621 L .43522 .31285 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .43522 .31285 L .43127 .32066 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .43127 .32066 L .43037 .32877 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .48699 .31514 L .48352 .30811 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .48352 .30811 L .47735 .30275 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .47735 .30275 L .46913 .29967 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32255 m .46913 .29967 L .45977 .29923 L closepath p
1 g
F P
s
P
p
.002 w
.40362 .33761 m .40822 .3524 L .43258 .33628 L p
1 g
F P
s
P
p
.002 w
.43258 .33628 m .43037 .32877 L .40362 .33761 L p
1 g
F P
s
P
p
.002 w
.57242 .31042 m .57275 .34012 L .59888 .35067 L p
1 g
F P
s
P
p
.002 w
.57275 .34012 m .57242 .31042 L .5445 .30898 L p
1 g
F P
s
P
p
.002 w
.48352 .30811 m .48699 .31514 L .51583 .31058 L p
1 g
F P
s
P
p
.002 w
.40537 .55766 m .46053 .56447 L .45525 .54126 L p
1 g
F P
s
P
p
.002 w
.45525 .54126 m .40224 .53437 L .40537 .55766 L p
1 g
F P
s
P
p
.002 w
.57275 .53549 m .62029 .50248 L .60863 .48173 L p
1 g
F P
s
P
p
.002 w
.64301 .4409 m .60863 .48173 L .62029 .50248 L p
1 g
F P
s
P
p
.002 w
.60863 .48173 m .64301 .4409 L .62647 .42176 L p
1 g
F P
s
P
p
.002 w
.37888 .34895 m .38595 .37059 L .40822 .3524 L p
1 g
F P
s
P
p
.002 w
.40822 .3524 m .40362 .33761 L .37888 .34895 L p
1 g
F P
s
P
p
.002 w
.50917 .29659 m .51583 .31058 L .5445 .30898 L p
1 g
F P
s
P
p
.002 w
.51583 .31058 m .50917 .29659 L .48352 .30811 L p
1 g
F P
s
P
p
.002 w
.40521 .32152 m .40362 .33761 L .43037 .32877 L p
1 g
F P
s
P
p
.002 w
.43037 .32877 m .43127 .32066 L .40521 .32152 L p
1 g
F P
s
P
p
.002 w
.47735 .30275 m .48352 .30811 L .50917 .29659 L p
1 g
F P
s
P
p
.002 w
.35636 .51333 m .40224 .53437 L .40162 .50906 L p
1 g
F P
s
P
p
.002 w
.40162 .50906 m .35883 .48894 L .35636 .51333 L p
1 g
F P
s
P
p
.002 w
.3366 .43401 m .36479 .46365 L .37401 .43802 L p
1 g
F P
s
P
p
.002 w
.37401 .43802 m .34969 .4118 L .3366 .43401 L p
1 g
F P
s
P
p
.002 w
.64432 .37807 m .62647 .42176 L .64301 .4409 L p
1 g
F P
s
P
p
.002 w
.62647 .42176 m .64432 .37807 L .62293 .36339 L p
1 g
F P
s
P
p
.002 w
.59898 .31494 m .59888 .35067 L .62293 .36339 L p
1 g
F P
s
P
p
.002 w
.59888 .35067 m .59898 .31494 L .57242 .31042 L p
1 g
F P
s
P
p
.002 w
.46698 .58493 m .52523 .57692 L .51796 .55675 L p
1 g
F P
s
P
p
.002 w
.51796 .55675 m .46053 .56447 L .46698 .58493 L p
1 g
F P
s
P
p
.002 w
.57275 .53549 m .51796 .55675 L .52523 .57692 L p
1 g
F P
s
P
p
.002 w
.52523 .57692 m .58086 .55534 L .57275 .53549 L p
1 g
F P
s
P
p
.002 w
.62029 .50248 m .57275 .53549 L .58086 .55534 L p
1 g
F P
s
P
p
.002 w
.35674 .3626 m .36629 .39052 L .38595 .37059 L p
1 g
F P
s
P
p
.002 w
.38595 .37059 m .37888 .34895 L .35674 .3626 L p
1 g
F P
s
P
p
.002 w
.53501 .28826 m .5445 .30898 L .57242 .31042 L p
1 g
F P
s
P
p
.002 w
.5445 .30898 m .53501 .28826 L .50917 .29659 L p
1 g
F P
s
P
p
.002 w
.41294 .3059 m .40521 .32152 L .43127 .32066 L p
1 g
F P
s
P
p
.002 w
.43127 .32066 m .43522 .31285 L .41294 .3059 L p
1 g
F P
s
P
p
.002 w
.50917 .29659 m .49707 .28581 L .47735 .30275 L p
1 g
F P
s
P
p
.002 w
.46913 .29967 m .47735 .30275 L .49707 .28581 L p
1 g
F P
s
P
p
.002 w
.38095 .32518 m .37888 .34895 L .40362 .33761 L p
1 g
F P
s
P
p
.002 w
.40362 .33761 m .40521 .32152 L .38095 .32518 L p
1 g
F P
s
P
p
.002 w
.49707 .28581 m .50917 .29659 L .53501 .28826 L p
1 g
F P
s
P
p
.002 w
.42605 .29256 m .41294 .3059 L .43522 .31285 L p
1 g
F P
s
P
p
.002 w
.43522 .31285 m .44181 .30621 L .42605 .29256 L p
1 g
F P
s
P
p
.002 w
.49707 .28581 m .48076 .27954 L .46913 .29967 L p
1 g
F P
s
P
p
.002 w
.45977 .29923 m .46913 .29967 L .48076 .27954 L p
1 g
F P
s
P
p
.002 w
.44308 .28308 m .42605 .29256 L .44181 .30621 L p
1 g
F P
s
P
p
.002 w
.44181 .30621 m .45031 .30149 L .44308 .28308 L p
1 g
F P
s
P
p
.002 w
.45031 .30149 m .45977 .29923 L .46205 .27857 L p
1 g
F P
s
P
p
.002 w
.48076 .27954 m .46205 .27857 L .45977 .29923 L p
1 g
F P
s
P
p
.002 w
.46205 .27857 m .44308 .28308 L .45031 .30149 L p
1 g
F P
s
P
p
.002 w
.32744 .45669 m .35883 .48894 L .36479 .46365 L p
1 g
F P
s
P
p
.002 w
.36479 .46365 m .3366 .43401 L .32744 .45669 L p
1 g
F P
s
P
p
.002 w
.33777 .37834 m .34969 .4118 L .36629 .39052 L p
1 g
F P
s
P
p
.002 w
.36629 .39052 m .35674 .3626 L .33777 .37834 L p
1 g
F P
s
P
p
.002 w
.41105 .57834 m .46698 .58493 L .46053 .56447 L p
1 g
F P
s
P
p
.002 w
.46053 .56447 m .40537 .55766 L .41105 .57834 L p
1 g
F P
s
P
p
.002 w
.62355 .32253 m .62293 .36339 L .64432 .37807 L p
1 g
F P
s
P
p
.002 w
.62293 .36339 m .62355 .32253 L .59898 .31494 L p
1 g
F P
s
P
p
.002 w
.58086 .55534 m .62921 .52198 L .62029 .50248 L p
1 g
F P
s
P
p
.002 w
.65631 .46026 m .62029 .50248 L .62921 .52198 L p
1 g
F P
s
P
p
.002 w
.62029 .50248 m .65631 .46026 L .64301 .4409 L p
1 g
F P
s
P
p
.002 w
.56048 .28341 m .57242 .31042 L .59898 .31494 L p
1 g
F P
s
P
p
.002 w
.57242 .31042 m .56048 .28341 L .53501 .28826 L p
1 g
F P
s
P
p
.002 w
.35758 .53624 m .40537 .55766 L .40224 .53437 L p
1 g
F P
s
P
p
.002 w
.40224 .53437 m .35636 .51333 L .35758 .53624 L p
1 g
F P
s
P
p
.002 w
.66251 .39446 m .64301 .4409 L .65631 .46026 L p
1 g
F P
s
P
p
.002 w
.64301 .4409 m .66251 .39446 L .64432 .37807 L p
1 g
F P
s
P
p
.002 w
.39225 .30196 m .38095 .32518 L .40521 .32152 L p
1 g
F P
s
P
p
.002 w
.40521 .32152 m .41294 .3059 L .39225 .30196 L p
1 g
F P
s
P
p
.002 w
.53501 .28826 m .51734 .27217 L .49707 .28581 L p
1 g
F P
s
P
p
.002 w
.48076 .27954 m .49707 .28581 L .51734 .27217 L p
1 g
F P
s
P
p
.002 w
.35912 .33169 m .35674 .3626 L .37888 .34895 L p
1 g
F P
s
P
p
.002 w
.37888 .34895 m .38095 .32518 L .35912 .33169 L p
1 g
F P
s
P
p
.002 w
.51734 .27217 m .53501 .28826 L .56048 .28341 L p
1 g
F P
s
P
p
.002 w
.4745 .60205 m .53209 .59398 L .52523 .57692 L p
1 g
F P
s
P
p
.002 w
.52523 .57692 m .46698 .58493 L .4745 .60205 L p
1 g
F P
s
P
p
.002 w
.58086 .55534 m .52523 .57692 L .53209 .59398 L p
1 g
F P
s
P
p
.002 w
.53209 .59398 m .58716 .57262 L .58086 .55534 L p
1 g
F P
s
P
p
.002 w
.62921 .52198 m .58086 .55534 L .58716 .57262 L p
1 g
F P
s
P
p
.002 w
.32254 .39589 m .3366 .43401 L .34969 .4118 L p
1 g
F P
s
P
p
.002 w
.34969 .4118 m .33777 .37834 L .32254 .39589 L p
1 g
F P
s
P
p
.002 w
.41168 .28204 m .39225 .30196 L .41294 .3059 L p
1 g
F P
s
P
p
.002 w
.41294 .3059 m .42605 .29256 L .41168 .28204 L p
1 g
F P
s
P
p
.002 w
.58501 .28225 m .59898 .31494 L .62355 .32253 L p
1 g
F P
s
P
p
.002 w
.59898 .31494 m .58501 .28225 L .56048 .28341 L p
1 g
F P
s
P
p
.002 w
.51734 .27217 m .49324 .2627 L .48076 .27954 L p
1 g
F P
s
P
p
.002 w
.46205 .27857 m .48076 .27954 L .49324 .2627 L p
1 g
F P
s
P
p
.002 w
.32258 .47932 m .35636 .51333 L .35883 .48894 L p
1 g
F P
s
P
p
.002 w
.35883 .48894 m .32744 .45669 L .32258 .47932 L p
1 g
F P
s
P
p
.002 w
.64553 .33313 m .64432 .37807 L .66251 .39446 L p
1 g
F P
s
P
p
.002 w
.64432 .37807 m .64553 .33313 L .62355 .32253 L p
1 g
F P
s
P
p
.002 w
.43707 .26785 m .41168 .28204 L .42605 .29256 L p
1 g
F P
s
P
p
.002 w
.42605 .29256 m .44308 .28308 L .43707 .26785 L p
1 g
F P
s
P
p
.002 w
.44308 .28308 m .46205 .27857 L .4654 .26115 L p
1 g
F P
s
P
p
.002 w
.49324 .2627 m .4654 .26115 L .46205 .27857 L p
1 g
F P
s
P
p
.002 w
.41928 .59581 m .4745 .60205 L .46698 .58493 L p
1 g
F P
s
P
p
.002 w
.46698 .58493 m .41105 .57834 L .41928 .59581 L p
1 g
F P
s
P
p
.002 w
.4654 .26115 m .43707 .26785 L .44308 .28308 L p
1 g
F P
s
P
p
.002 w
.58716 .57262 m .63507 .53975 L .62921 .52198 L p
1 g
F P
s
P
p
.002 w
.66595 .47942 m .62921 .52198 L .63507 .53975 L p
1 g
F P
s
P
p
.002 w
.62921 .52198 m .66595 .47942 L .65631 .46026 L p
1 g
F P
s
P
p
.002 w
.36263 .55705 m .41105 .57834 L .40537 .55766 L p
1 g
F P
s
P
p
.002 w
.40537 .55766 m .35758 .53624 L .36263 .55705 L p
1 g
F P
s
P
p
.002 w
.34032 .341 m .33777 .37834 L .35674 .3626 L p
1 g
F P
s
P
p
.002 w
.35674 .3626 m .35912 .33169 L .34032 .341 L p
1 g
F P
s
P
p
.002 w
.37368 .30127 m .35912 .33169 L .38095 .32518 L p
1 g
F P
s
P
p
.002 w
.38095 .32518 m .39225 .30196 L .37368 .30127 L p
1 g
F P
s
P
p
.002 w
.53772 .26226 m .56048 .28341 L .58501 .28225 L p
1 g
F P
s
P
p
.002 w
.56048 .28341 m .53772 .26226 L .51734 .27217 L p
1 g
F P
s
P
p
.002 w
.67696 .41225 m .65631 .46026 L .66595 .47942 L p
1 g
F P
s
P
p
.002 w
.65631 .46026 m .67696 .41225 L .66251 .39446 L p
1 g
F P
s
P
p
.002 w
.49324 .2627 m .51734 .27217 L .53772 .26226 L p
1 g
F P
s
P
p
.002 w
.31159 .4149 m .32744 .45669 L .3366 .43401 L p
1 g
F P
s
P
p
.002 w
.3366 .43401 m .32254 .39589 L .31159 .4149 L p
1 g
F P
s
P
p
.002 w
.60798 .28497 m .62355 .32253 L .64553 .33313 L p
1 g
F P
s
P
p
.002 w
.62355 .32253 m .60798 .28497 L .58501 .28225 L p
1 g
F P
s
P
p
.002 w
.32234 .50134 m .35758 .53624 L .35636 .51333 L p
1 g
F P
s
P
p
.002 w
.35636 .51333 m .32258 .47932 L .32234 .50134 L p
1 g
F P
s
P
p
.002 w
.66428 .34661 m .66251 .39446 L .67696 .41225 L p
1 g
F P
s
P
p
.002 w
.66251 .39446 m .66428 .34661 L .64553 .33313 L p
1 g
F P
s
P
p
.002 w
.48297 .61525 m .53837 .60738 L .53209 .59398 L p
1 g
F P
s
P
p
.002 w
.53209 .59398 m .4745 .60205 L .48297 .61525 L p
1 g
F P
s
P
p
.002 w
.58716 .57262 m .53209 .59398 L .53837 .60738 L p
1 g
F P
s
P
p
.002 w
.53837 .60738 m .5914 .58681 L .58716 .57262 L p
1 g
F P
s
P
p
.002 w
.63507 .53975 m .58716 .57262 L .5914 .58681 L p
1 g
F P
s
P
p
.002 w
.39911 .27505 m .37368 .30127 L .39225 .30196 L p
1 g
F P
s
P
p
.002 w
.39225 .30196 m .41168 .28204 L .39911 .27505 L p
1 g
F P
s
P
p
.002 w
.53772 .26226 m .50632 .2497 L .49324 .2627 L p
1 g
F P
s
P
p
.002 w
.4654 .26115 m .49324 .2627 L .50632 .2497 L p
1 g
F P
s
P
p
.002 w
.32517 .35304 m .32254 .39589 L .33777 .37834 L p
1 g
F P
s
P
p
.002 w
.33777 .37834 m .34032 .341 L .32517 .35304 L p
1 g
F P
s
P
p
.002 w
.55774 .25648 m .58501 .28225 L .60798 .28497 L p
1 g
F P
s
P
p
.002 w
.58501 .28225 m .55774 .25648 L .53772 .26226 L p
1 g
F P
s
P
p
.002 w
.35781 .30402 m .34032 .341 L .35912 .33169 L p
1 g
F P
s
P
p
.002 w
.35912 .33169 m .37368 .30127 L .35781 .30402 L p
1 g
F P
s
P
p
.002 w
.50632 .2497 m .53772 .26226 L .55774 .25648 L p
1 g
F P
s
P
p
.002 w
.37155 .57514 m .41928 .59581 L .41105 .57834 L p
1 g
F P
s
P
p
.002 w
.41105 .57834 m .36263 .55705 L .37155 .57514 L p
1 g
F P
s
P
p
.002 w
.4325 .25635 m .39911 .27505 L .41168 .28204 L p
1 g
F P
s
P
p
.002 w
.41168 .28204 m .43707 .26785 L .4325 .25635 L p
1 g
F P
s
P
p
.002 w
.43707 .26785 m .4654 .26115 L .46978 .24757 L p
1 g
F P
s
P
p
.002 w
.50632 .2497 m .46978 .24757 L .4654 .26115 L p
1 g
F P
s
P
p
.002 w
.63507 .53975 m .67151 .49793 L .66595 .47942 L p
1 g
F P
s
P
p
.002 w
.68715 .43108 m .66595 .47942 L .67151 .49793 L p
1 g
F P
s
P
p
.002 w
.66595 .47942 m .68715 .43108 L .67696 .41225 L p
1 g
F P
s
P
p
.002 w
.42997 .60945 m .48297 .61525 L .4745 .60205 L p
1 g
F P
s
P
p
.002 w
.4745 .60205 m .41928 .59581 L .42997 .60945 L p
1 g
F P
s
P
p
.002 w
.5914 .58681 m .63756 .55529 L .63507 .53975 L p
1 g
F P
s
P
p
.002 w
.67151 .49793 m .63507 .53975 L .63756 .55529 L p
1 g
F P
s
P
p
.002 w
.46978 .24757 m .4325 .25635 L .43707 .26785 L p
1 g
F P
s
P
p
.002 w
.30539 .43496 m .32258 .47932 L .32744 .45669 L p
1 g
F P
s
P
p
.002 w
.32744 .45669 m .31159 .4149 L .30539 .43496 L p
1 g
F P
s
P
p
.002 w
.62878 .29165 m .64553 .33313 L .66428 .34661 L p
1 g
F P
s
P
p
.002 w
.64553 .33313 m .62878 .29165 L .60798 .28497 L p
1 g
F P
s
P
p
.002 w
.32694 .52214 m .36263 .55705 L .35758 .53624 L p
1 g
F P
s
P
p
.002 w
.35758 .53624 m .32234 .50134 L .32694 .52214 L p
1 g
F P
s
P
p
.002 w
.67919 .36275 m .67696 .41225 L .68715 .43108 L p
1 g
F P
s
P
p
.002 w
.67696 .41225 m .67919 .36275 L .66428 .34661 L p
1 g
F P
s
P
p
.002 w
.38874 .27198 m .35781 .30402 L .37368 .30127 L p
1 g
F P
s
P
p
.002 w
.37368 .30127 m .39911 .27505 L .38874 .27198 L p
1 g
F P
s
P
p
.002 w
.31426 .36762 m .31159 .4149 L .32254 .39589 L p
1 g
F P
s
P
p
.002 w
.32254 .39589 m .32517 .35304 L .31426 .36762 L p
1 g
F P
s
P
p
.002 w
.55774 .25648 m .51972 .24107 L .50632 .2497 L p
1 g
F P
s
P
p
.002 w
.46978 .24757 m .50632 .2497 L .51972 .24107 L p
1 g
F P
s
P
p
.002 w
.49224 .62398 m .54387 .61657 L .53837 .60738 L p
1 g
F P
s
P
p
.002 w
.53837 .60738 m .48297 .61525 L .49224 .62398 L p
1 g
F P
s
P
p
.002 w
.5914 .58681 m .53837 .60738 L .54387 .61657 L p
1 g
F P
s
P
p
.002 w
.54387 .61657 m .59336 .59738 L .5914 .58681 L p
1 g
F P
s
P
p
.002 w
.63756 .55529 m .5914 .58681 L .59336 .59738 L p
1 g
F P
s
P
p
.002 w
.57691 .25519 m .60798 .28497 L .62878 .29165 L p
1 g
F P
s
P
p
.002 w
.60798 .28497 m .57691 .25519 L .55774 .25648 L p
1 g
F P
s
P
p
.002 w
.34521 .31033 m .32517 .35304 L .34032 .341 L p
1 g
F P
s
P
p
.002 w
.34032 .341 m .35781 .30402 L .34521 .31033 L p
1 g
F P
s
P
p
.002 w
.51972 .24107 m .55774 .25648 L .57691 .25519 L p
1 g
F P
s
P
p
.002 w
.38433 .58988 m .42997 .60945 L .41928 .59581 L p
1 g
F P
s
P
p
.002 w
.41928 .59581 m .37155 .57514 L .38433 .58988 L p
1 g
F P
s
P
p
.002 w
.30436 .45557 m .32234 .50134 L .32258 .47932 L p
1 g
F P
s
P
p
.002 w
.32258 .47932 m .30539 .43496 L .30436 .45557 L p
1 g
F P
s
P
p
.002 w
.63756 .55529 m .67266 .51529 L .67151 .49793 L p
1 g
F P
s
P
p
.002 w
.69262 .45052 m .67151 .49793 L .67266 .51529 L p
1 g
F P
s
P
p
.002 w
.67151 .49793 m .69262 .45052 L .68715 .43108 L p
1 g
F P
s
P
p
.002 w
.64676 .30233 m .66428 .34661 L .67919 .36275 L p
1 g
F P
s
P
p
.002 w
.66428 .34661 m .64676 .30233 L .62878 .29165 L p
1 g
F P
s
P
p
.002 w
.42957 .24909 m .38874 .27198 L .39911 .27505 L p
1 g
F P
s
P
p
.002 w
.39911 .27505 m .4325 .25635 L .42957 .24909 L p
1 g
F P
s
P
p
.002 w
.4325 .25635 m .46978 .24757 L .47517 .23837 L p
1 g
F P
s
P
p
.002 w
.51972 .24107 m .47517 .23837 L .46978 .24757 L p
1 g
F P
s
P
p
.002 w
.44299 .61871 m .49224 .62398 L .48297 .61525 L p
1 g
F P
s
P
p
.002 w
.48297 .61525 m .42997 .60945 L .44299 .61871 L p
1 g
F P
s
P
p
.002 w
.59336 .59738 m .63642 .56806 L .63756 .55529 L p
1 g
F P
s
P
p
.002 w
.67266 .51529 m .63756 .55529 L .63642 .56806 L p
1 g
F P
s
P
p
.002 w
.33649 .54109 m .37155 .57514 L .36263 .55705 L p
1 g
F P
s
P
p
.002 w
.36263 .55705 m .32694 .52214 L .33649 .54109 L p
1 g
F P
s
P
p
.002 w
.47517 .23837 m .42957 .24909 L .4325 .25635 L p
1 g
F P
s
P
p
.002 w
.6897 .38128 m .68715 .43108 L .69262 .45052 L p
1 g
F P
s
P
p
.002 w
.68715 .43108 m .6897 .38128 L .67919 .36275 L p
1 g
F P
s
P
p
.002 w
.30811 .3845 m .30539 .43496 L .31159 .4149 L p
1 g
F P
s
P
p
.002 w
.31159 .4149 m .31426 .36762 L .30811 .3845 L p
1 g
F P
s
P
p
.002 w
.59465 .25864 m .62878 .29165 L .64676 .30233 L p
1 g
F P
s
P
p
.002 w
.62878 .29165 m .59465 .25864 L .57691 .25519 L p
1 g
F P
s
P
p
.002 w
.38102 .27316 m .34521 .31033 L .35781 .30402 L p
1 g
F P
s
P
p
.002 w
.35781 .30402 m .38874 .27198 L .38102 .27316 L p
1 g
F P
s
P
p
.002 w
.57691 .25519 m .5331 .23727 L .51972 .24107 L p
1 g
F P
s
P
p
.002 w
.47517 .23837 m .51972 .24107 L .5331 .23727 L p
1 g
F P
s
P
p
.002 w
.50211 .62774 m .54841 .62105 L .54387 .61657 L p
1 g
F P
s
P
p
.002 w
.54387 .61657 m .49224 .62398 L .50211 .62774 L p
1 g
F P
s
P
p
.002 w
.59336 .59738 m .54387 .61657 L .54841 .62105 L p
1 g
F P
s
P
p
.002 w
.54841 .62105 m .59284 .60382 L .59336 .59738 L p
1 g
F P
s
P
p
.002 w
.63642 .56806 m .59336 .59738 L .59284 .60382 L p
1 g
F P
s
P
p
.002 w
.33641 .32024 m .31426 .36762 L .32517 .35304 L p
1 g
F P
s
P
p
.002 w
.32517 .35304 m .34521 .31033 L .33641 .32024 L p
1 g
F P
s
P
p
.002 w
.30879 .47619 m .32694 .52214 L .32234 .50134 L p
1 g
F P
s
P
p
.002 w
.32234 .50134 m .30436 .45557 L .30879 .47619 L p
1 g
F P
s
P
p
.002 w
.5331 .23727 m .57691 .25519 L .59465 .25864 L p
1 g
F P
s
P
p
.002 w
.6613 .31691 m .67919 .36275 L .6897 .38128 L p
1 g
F P
s
P
p
.002 w
.67919 .36275 m .6613 .31691 L .64676 .30233 L p
1 g
F P
s
P
p
.002 w
.40079 .60068 m .44299 .61871 L .42997 .60945 L p
1 g
F P
s
P
p
.002 w
.42997 .60945 m .38433 .58988 L .40079 .60068 L p
1 g
F P
s
P
p
.002 w
.63642 .56806 m .66911 .53098 L .67266 .51529 L p
1 g
F P
s
P
p
.002 w
.69297 .4701 m .67266 .51529 L .66911 .53098 L p
1 g
F P
s
P
p
.002 w
.67266 .51529 m .69297 .4701 L .69262 .45052 L p
1 g
F P
s
P
p
.002 w
.35099 .55756 m .38433 .58988 L .37155 .57514 L p
1 g
F P
s
P
p
.002 w
.37155 .57514 m .33649 .54109 L .35099 .55756 L p
1 g
F P
s
P
p
.002 w
.45812 .62306 m .50211 .62774 L .49224 .62398 L p
1 g
F P
s
P
p
.002 w
.49224 .62398 m .44299 .61871 L .45812 .62306 L p
1 g
F P
s
P
p
.002 w
.69528 .40179 m .69262 .45052 L .69297 .4701 L p
1 g
F P
s
P
p
.002 w
.69262 .45052 m .69528 .40179 L .6897 .38128 L p
1 g
F P
s
P
p
.002 w
.42846 .24654 m .38102 .27316 L .38874 .27198 L p
1 g
F P
s
P
p
.002 w
.38874 .27198 m .42957 .24909 L .42846 .24654 L p
1 g
F P
s
P
p
.002 w
.59284 .60382 m .63147 .57756 L .63642 .56806 L p
1 g
F P
s
P
p
.002 w
.66911 .53098 m .63642 .56806 L .63147 .57756 L p
1 g
F P
s
P
p
.002 w
.42957 .24909 m .47517 .23837 L .48147 .2341 L p
1 g
F P
s
P
p
.002 w
.5331 .23727 m .48147 .2341 L .47517 .23837 L p
1 g
F P
s
P
p
.002 w
.48147 .2341 m .42846 .24654 L .42957 .24909 L p
1 g
F P
s
P
p
.002 w
.30718 .40331 m .30436 .45557 L .30539 .43496 L p
1 g
F P
s
P
p
.002 w
.30539 .43496 m .30811 .3845 L .30718 .40331 L p
1 g
F P
s
P
p
.002 w
.64676 .30233 m .61042 .26701 L .59465 .25864 L p
1 g
F P
s
P
p
.002 w
.61042 .26701 m .64676 .30233 L .6613 .31691 L p
1 g
F P
s
P
p
.002 w
.31882 .49621 m .33649 .54109 L .32694 .52214 L p
1 g
F P
s
P
p
.002 w
.32694 .52214 m .30879 .47619 L .31882 .49621 L p
1 g
F P
s
P
p
.002 w
.37631 .27883 m .33641 .32024 L .34521 .31033 L p
1 g
F P
s
P
p
.002 w
.34521 .31033 m .38102 .27316 L .37631 .27883 L p
1 g
F P
s
P
p
.002 w
.6897 .38128 m .6718 .33519 L .6613 .31691 L p
1 g
F P
s
P
p
.002 w
.6718 .33519 m .6897 .38128 L .69528 .40179 L p
1 g
F P
s
P
p
.002 w
.59465 .25864 m .54611 .23871 L .5331 .23727 L p
1 g
F P
s
P
p
.002 w
.48147 .2341 m .5331 .23727 L .54611 .23871 L p
1 g
F P
s
P
p
.002 w
.3319 .33369 m .30811 .3845 L .31426 .36762 L p
1 g
F P
s
P
p
.002 w
.31426 .36762 m .33641 .32024 L .3319 .33369 L p
1 g
F P
s
P
p
.002 w
.54611 .23871 m .59465 .25864 L .61042 .26701 L p
1 g
F P
s
P
p
.002 w
.59284 .60382 m .54841 .62105 L .55178 .62039 L p
1 g
F P
s
P
p
.002 w
.51234 .62609 m .55178 .62039 L .54841 .62105 L p
1 g
F P
s
P
p
.002 w
.54841 .62105 m .50211 .62774 L .51234 .62609 L p
1 g
F P
s
P
p
.002 w
.55178 .62039 m .58969 .60569 L .59284 .60382 L p
1 g
F P
s
P
p
.002 w
.63147 .57756 m .59284 .60382 L .58969 .60569 L p
1 g
F P
s
P
p
.002 w
.42066 .60702 m .45812 .62306 L .44299 .61871 L p
1 g
F P
s
P
p
.002 w
.44299 .61871 m .40079 .60068 L .42066 .60702 L p
1 g
F P
s
P
p
.002 w
.63147 .57756 m .66069 .54447 L .66911 .53098 L p
1 g
F P
s
P
p
.002 w
.66911 .53098 m .68794 .48926 L .69297 .4701 L p
1 g
F P
s
P
p
.002 w
.68794 .48926 m .66911 .53098 L .66069 .54447 L p
1 g
F P
s
P
p
.002 w
.37022 .57093 m .40079 .60068 L .38433 .58988 L p
1 g
F P
s
P
p
.002 w
.38433 .58988 m .35099 .55756 L .37022 .57093 L p
1 g
F P
s
P
p
.002 w
.69297 .4701 m .69554 .42381 L .69528 .40179 L p
1 g
F P
s
P
p
.002 w
.69554 .42381 m .69297 .4701 L .68794 .48926 L p
1 g
F P
s
P
p
.002 w
.47503 .62209 m .51234 .62609 L .50211 .62774 L p
1 g
F P
s
P
p
.002 w
.50211 .62774 m .45812 .62306 L .47503 .62209 L p
1 g
F P
s
P
p
.002 w
.31177 .42357 m .30879 .47619 L .30436 .45557 L p
1 g
F P
s
P
p
.002 w
.30436 .45557 m .30718 .40331 L .31177 .42357 L p
1 g
F P
s
P
p
.002 w
.58969 .60569 m .62261 .58332 L .63147 .57756 L p
1 g
F P
s
P
p
.002 w
.66069 .54447 m .63147 .57756 L .62261 .58332 L p
1 g
F P
s
P
p
.002 w
.42934 .2491 m .37631 .27883 L .38102 .27316 L p
1 g
F P
s
P
p
.002 w
.38102 .27316 m .42846 .24654 L .42934 .2491 L p
1 g
F P
s
P
p
.002 w
.62365 .28033 m .6613 .31691 L .6718 .33519 L p
1 g
F P
s
P
p
.002 w
.6613 .31691 m .62365 .28033 L .61042 .26701 L p
1 g
F P
s
P
p
.002 w
.42846 .24654 m .48147 .2341 L .48857 .23518 L p
1 g
F P
s
P
p
.002 w
.54611 .23871 m .48857 .23518 L .48147 .2341 L p
1 g
F P
s
P
p
.002 w
.48857 .23518 m .42934 .2491 L .42846 .24654 L p
1 g
F P
s
P
p
.002 w
.33443 .51496 m .35099 .55756 L .33649 .54109 L p
1 g
F P
s
P
p
.002 w
.33649 .54109 m .31882 .49621 L .33443 .51496 L p
1 g
F P
s
P
p
.002 w
.67775 .35681 m .69528 .40179 L .69554 .42381 L p
1 g
F P
s
P
p
.002 w
.69528 .40179 m .67775 .35681 L .6718 .33519 L p
1 g
F P
s
P
p
.002 w
.33208 .35048 m .30718 .40331 L .30811 .3845 L p
1 g
F P
s
P
p
.002 w
.30811 .3845 m .3319 .33369 L .33208 .35048 L p
1 g
F P
s
P
p
.002 w
.55833 .24567 m .61042 .26701 L .62365 .28033 L p
1 g
F P
s
P
p
.002 w
.61042 .26701 m .55833 .24567 L .54611 .23871 L p
1 g
F P
s
P
p
.002 w
.37496 .28912 m .3319 .33369 L .33641 .32024 L p
1 g
F P
s
P
p
.002 w
.33641 .32024 m .37631 .27883 L .37496 .28912 L p
1 g
F P
s
P
p
.002 w
.48857 .23518 m .54611 .23871 L .55833 .24567 L p
1 g
F P
s
P
p
.002 w
.4435 .60847 m .47503 .62209 L .45812 .62306 L p
1 g
F P
s
P
p
.002 w
.45812 .62306 m .42066 .60702 L .4435 .60847 L p
1 g
F P
s
P
p
.002 w
.62261 .58332 m .64737 .55524 L .66069 .54447 L p
1 g
F P
s
P
p
.002 w
.67737 .50742 m .66069 .54447 L .64737 .55524 L p
1 g
F P
s
P
p
.002 w
.66069 .54447 m .67737 .50742 L .68794 .48926 L p
1 g
F P
s
P
p
.002 w
.39383 .58062 m .42066 .60702 L .40079 .60068 L p
1 g
F P
s
P
p
.002 w
.40079 .60068 m .37022 .57093 L .39383 .58062 L p
1 g
F P
s
P
p
.002 w
.6902 .44673 m .68794 .48926 L .67737 .50742 L p
1 g
F P
s
P
p
.002 w
.68794 .48926 m .6902 .44673 L .69554 .42381 L p
1 g
F P
s
P
p
.002 w
.52265 .61874 m .55383 .61427 L .55178 .62039 L p
1 g
F P
s
P
p
.002 w
.55178 .62039 m .51234 .62609 L .52265 .61874 L p
1 g
F P
s
P
p
.002 w
.58969 .60569 m .55178 .62039 L .55383 .61427 L p
1 g
F P
s
P
p
.004 w
.57142 .61656 m
.58044 .64006 L
s
P
p
.002 w
.55383 .61427 m .58384 .60263 L .58969 .60569 L p
1 g
F P
s
P
p
.002 w
.62261 .58332 m .58969 .60569 L .58384 .60263 L p
1 g
F P
s
P
p
.002 w
.32204 .44473 m .31882 .49621 L .30879 .47619 L p
1 g
F P
s
P
p
.002 w
.30879 .47619 m .31177 .42357 L .32204 .44473 L p
1 g
F P
s
P
p
.002 w
.63378 .29846 m .6718 .33519 L .67775 .35681 L p
1 g
F P
s
P
p
.002 w
.6718 .33519 m .63378 .29846 L .62365 .28033 L p
1 g
F P
s
P
p
.002 w
.4933 .61552 m .52265 .61874 L .51234 .62609 L p
1 g
F P
s
P
p
.002 w
.51234 .62609 m .47503 .62209 L .4933 .61552 L p
1 g
F P
s
P
p
.002 w
.58384 .60263 m .60984 .58492 L .62261 .58332 L p
1 g
F P
s
P
p
.002 w
.64737 .55524 m .62261 .58332 L .60984 .58492 L p
1 g
F P
s
P
p
.002 w
.35537 .53178 m .37022 .57093 L .35099 .55756 L p
1 g
F P
s
P
p
.002 w
.35099 .55756 m .33443 .51496 L .35537 .53178 L p
1 g
F P
s
P
p
.002 w
.4323 .25702 m .37496 .28912 L .37631 .27883 L p
1 g
F P
s
P
p
.002 w
.37631 .27883 m .42934 .2491 L .4323 .25702 L p
1 g
F P
s
P
p
.002 w
.55833 .24567 m .49631 .24194 L .48857 .23518 L p
1 g
F P
s
P
p
.002 w
.42934 .2491 m .48857 .23518 L .49631 .24194 L p
1 g
F P
s
P
p
.002 w
.67873 .38126 m .69554 .42381 L .6902 .44673 L p
1 g
F P
s
P
p
.002 w
.69554 .42381 m .67873 .38126 L .67775 .35681 L p
1 g
F P
s
P
p
.002 w
.33723 .37026 m .31177 .42357 L .30718 .40331 L p
1 g
F P
s
P
p
.002 w
.30718 .40331 m .33208 .35048 L .33723 .37026 L p
1 g
F P
s
P
p
.002 w
.49631 .24194 m .4323 .25702 L .42934 .2491 L p
1 g
F P
s
P
p
.002 w
.56935 .25826 m .62365 .28033 L .63378 .29846 L p
1 g
F P
s
P
p
.002 w
.62365 .28033 m .56935 .25826 L .55833 .24567 L p
1 g
F P
s
P
p
.002 w
.37724 .30399 m .33208 .35048 L .3319 .33369 L p
1 g
F P
s
P
p
.002 w
.3319 .33369 m .37496 .28912 L .37724 .30399 L p
1 g
F P
s
P
p
.002 w
.49631 .24194 m .55833 .24567 L .56935 .25826 L p
1 g
F P
s
P
p
.002 w
.42122 .58617 m .4435 .60847 L .42066 .60702 L p
1 g
F P
s
P
p
.002 w
.42066 .60702 m .39383 .58062 L .42122 .58617 L p
1 g
F P
s
P
p
.002 w
.64737 .55524 m .66131 .52396 L .67737 .50742 L p
1 g
F P
s
P
p
.002 w
.67916 .46989 m .67737 .50742 L .66131 .52396 L p
1 g
F P
s
P
p
.002 w
.67737 .50742 m .67916 .46989 L .6902 .44673 L p
1 g
F P
s
P
p
.002 w
.46873 .60473 m .4933 .61552 L .47503 .62209 L p
1 g
F P
s
P
p
.002 w
.47503 .62209 m .4435 .60847 L .46873 .60473 L p
1 g
F P
s
P
p
.002 w
.60984 .58492 m .62926 .56278 L .64737 .55524 L p
1 g
F P
s
P
p
.002 w
.66131 .52396 m .64737 .55524 L .62926 .56278 L p
1 g
F P
s
P
p
.002 w
.33792 .46612 m .33443 .51496 L .31882 .49621 L p
1 g
F P
s
P
p
.002 w
.31882 .49621 m .32204 .44473 L .33792 .46612 L p
1 g
F P
s
P
p
.002 w
.64032 .32109 m .67775 .35681 L .67873 .38126 L p
1 g
F P
s
P
p
.002 w
.67775 .35681 m .64032 .32109 L .63378 .29846 L p
1 g
F P
s
P
p
.002 w
.5327 .60558 m .55438 .6025 L .55383 .61427 L p
1 g
F P
s
P
p
.002 w
.55383 .61427 m .52265 .61874 L .5327 .60558 L p
1 g
F P
s
P
p
.002 w
.58384 .60263 m .55383 .61427 L .55438 .6025 L p
1 g
F P
s
P
p
.002 w
.55438 .6025 m .57529 .5944 L .58384 .60263 L p
1 g
F P
s
P
p
.002 w
.60984 .58492 m .58384 .60263 L .57529 .5944 L p
1 g
F P
s
P
p
.002 w
.38115 .54603 m .39383 .58062 L .37022 .57093 L p
1 g
F P
s
P
p
.002 w
.37022 .57093 m .35537 .53178 L .38115 .54603 L p
1 g
F P
s
P
p
.002 w
.67448 .40788 m .6902 .44673 L .67916 .46989 L p
1 g
F P
s
P
p
.002 w
.6902 .44673 m .67448 .40788 L .67873 .38126 L p
1 g
F P
s
P
p
.002 w
.5124 .60326 m .5327 .60558 L .52265 .61874 L p
1 g
F P
s
P
p
.002 w
.52265 .61874 m .4933 .61552 L .5124 .60326 L p
1 g
F P
s
P
p
.002 w
.57529 .5944 m .59334 .58206 L .60984 .58492 L p
1 g
F P
s
P
p
.002 w
.62926 .56278 m .60984 .58492 L .59334 .58206 L p
1 g
F P
s
P
p
.002 w
.43738 .27041 m .37724 .30399 L .37496 .28912 L p
1 g
F P
s
P
p
.002 w
.37496 .28912 m .4323 .25702 L .43738 .27041 L p
1 g
F P
s
P
p
.002 w
.56935 .25826 m .50447 .25453 L .49631 .24194 L p
1 g
F P
s
P
p
.002 w
.4323 .25702 m .49631 .24194 L .50447 .25453 L p
1 g
F P
s
P
p
.002 w
.34742 .39252 m .32204 .44473 L .31177 .42357 L p
1 g
F P
s
P
p
.002 w
.31177 .42357 m .33723 .37026 L .34742 .39252 L p
1 g
F P
s
P
p
.002 w
.57874 .2764 m .63378 .29846 L .64032 .32109 L p
1 g
F P
s
P
p
.002 w
.63378 .29846 m .57874 .2764 L .56935 .25826 L p
1 g
F P
s
P
p
.002 w
.45163 .58721 m .46873 .60473 L .4435 .60847 L p
1 g
F P
s
P
p
.002 w
.4435 .60847 m .42122 .58617 L .45163 .58721 L p
1 g
F P
s
P
p
.002 w
.62926 .56278 m .64 .53828 L .66131 .52396 L p
1 g
F P
s
P
p
.002 w
.66253 .49253 m .66131 .52396 L .64 .53828 L p
1 g
F P
s
P
p
.002 w
.66131 .52396 m .66253 .49253 L .67916 .46989 L p
1 g
F P
s
P
p
.002 w
.50447 .25453 m .43738 .27041 L .4323 .25702 L p
1 g
F P
s
P
p
.002 w
.38328 .32323 m .33723 .37026 L .33208 .35048 L p
1 g
F P
s
P
p
.002 w
.33208 .35048 m .37724 .30399 L .38328 .32323 L p
1 g
F P
s
P
p
.002 w
.35909 .487 m .35537 .53178 L .33443 .51496 L p
1 g
F P
s
P
p
.002 w
.33443 .51496 m .33792 .46612 L .35909 .487 L p
1 g
F P
s
P
p
.002 w
.50447 .25453 m .56935 .25826 L .57874 .2764 L p
1 g
F P
s
P
p
.002 w
.6429 .34766 m .67873 .38126 L .67448 .40788 L p
1 g
F P
s
P
p
.002 w
.67873 .38126 m .6429 .34766 L .64032 .32109 L p
1 g
F P
s
P
p
.004 w
.6641 .34766 m
.67784 .34072 L
s
P
p
.002 w
.49558 .59571 m .5124 .60326 L .4933 .61552 L p
1 g
F P
s
P
p
.002 w
.4933 .61552 m .46873 .60473 L .49558 .59571 L p
1 g
F P
s
P
p
.002 w
.59334 .58206 m .6067 .56668 L .62926 .56278 L p
1 g
F P
s
P
p
.002 w
.64 .53828 m .62926 .56278 L .6067 .56668 L p
1 g
F P
s
P
p
.002 w
.41105 .55711 m .42122 .58617 L .39383 .58062 L p
1 g
F P
s
P
p
.002 w
.39383 .58062 m .38115 .54603 L .41105 .55711 L p
1 g
F P
s
P
p
.002 w
.66494 .43586 m .67916 .46989 L .66253 .49253 L p
1 g
F P
s
P
p
.002 w
.67916 .46989 m .66494 .43586 L .67448 .40788 L p
1 g
F P
s
P
p
.002 w
.54216 .5867 m .55334 .58514 L .55438 .6025 L p
1 g
F P
s
P
p
.002 w
.55438 .6025 m .5327 .60558 L .54216 .5867 L p
1 g
F P
s
P
p
.002 w
.57529 .5944 m .55438 .6025 L .55334 .58514 L p
1 g
F P
s
P
p
.002 w
.55334 .58514 m .56414 .58095 L .57529 .5944 L p
1 g
F P
s
P
p
.002 w
.59334 .58206 m .57529 .5944 L .56414 .58095 L p
1 g
F P
s
P
p
.002 w
.36255 .41659 m .33792 .46612 L .32204 .44473 L p
1 g
F P
s
P
p
.002 w
.32204 .44473 m .34742 .39252 L .36255 .41659 L p
1 g
F P
s
P
p
.002 w
.53175 .58545 m .54216 .5867 L .5327 .60558 L p
1 g
F P
s
P
p
.002 w
.5327 .60558 m .5124 .60326 L .53175 .58545 L p
1 g
F P
s
P
p
.002 w
.56414 .58095 m .57343 .57456 L .59334 .58206 L p
1 g
F P
s
P
p
.002 w
.6067 .56668 m .59334 .58206 L .57343 .57456 L p
1 g
F P
s
P
p
.002 w
.58608 .29978 m .64032 .32109 L .6429 .34766 L p
1 g
F P
s
P
p
.002 w
.64032 .32109 m .58608 .29978 L .57874 .2764 L p
1 g
F P
s
P
p
.002 w
.48408 .58356 m .49558 .59571 L .46873 .60473 L p
1 g
F P
s
P
p
.002 w
.46873 .60473 m .45163 .58721 L .48408 .58356 L p
1 g
F P
s
P
p
.002 w
.6067 .56668 m .61394 .54979 L .64 .53828 L p
1 g
F P
s
P
p
.002 w
.64066 .51386 m .64 .53828 L .61394 .54979 L p
1 g
F P
s
P
p
.002 w
.64 .53828 m .64066 .51386 L .66253 .49253 L p
1 g
F P
s
P
p
.002 w
.385 .50661 m .38115 .54603 L .35537 .53178 L p
1 g
F P
s
P
p
.002 w
.35537 .53178 m .35909 .487 L .385 .50661 L p
1 g
F P
s
P
p
.002 w
.44454 .28913 m .38328 .32323 L .37724 .30399 L p
1 g
F P
s
P
p
.002 w
.37724 .30399 m .43738 .27041 L .44454 .28913 L p
1 g
F P
s
P
p
.002 w
.57874 .2764 m .51282 .27287 L .50447 .25453 L p
1 g
F P
s
P
p
.002 w
.43738 .27041 m .50447 .25453 L .51282 .27287 L p
1 g
F P
s
P
p
.002 w
.64123 .37743 m .67448 .40788 L .66494 .43586 L p
1 g
F P
s
P
p
.002 w
.67448 .40788 m .64123 .37743 L .6429 .34766 L p
1 g
F P
s
P
p
.002 w
.44414 .56456 m .45163 .58721 L .42122 .58617 L p
1 g
F P
s
P
p
.002 w
.42122 .58617 m .41105 .55711 L .44414 .56456 L p
1 g
F P
s
P
p
.002 w
.65023 .46428 m .66253 .49253 L .64066 .51386 L p
1 g
F P
s
P
p
.002 w
.66253 .49253 m .65023 .46428 L .66494 .43586 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.39307 .34637 m .34742 .39252 L .33723 .37026 L p
1 g
F P
s
P
p
.002 w
.33723 .37026 m .38328 .32323 L .39307 .34637 L p
1 g
F P
s
P
p
.002 w
.52321 .5815 m .53175 .58545 L .5124 .60326 L p
1 g
F P
s
P
p
.002 w
.5124 .60326 m .49558 .59571 L .52321 .5815 L p
1 g
F P
s
P
p
.002 w
.51282 .27287 m .57874 .2764 L .58608 .29978 L p
1 g
F P
s
P
p
.002 w
.57343 .57456 m .58025 .56663 L .6067 .56668 L p
1 g
F P
s
P
p
.002 w
.61394 .54979 m .6067 .56668 L .58025 .56663 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.51282 .27287 m .44454 .28913 L .43738 .27041 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53955 .53355 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.38226 .44166 m .35909 .487 L .33792 .46612 L p
1 g
F P
s
P
p
.002 w
.33792 .46612 m .36255 .41659 L .38226 .44166 L p
1 g
F P
s
P
p
.002 w
.41482 .5242 m .41105 .55711 L .38115 .54603 L p
1 g
F P
s
P
p
.002 w
.38115 .54603 m .385 .50661 L .41482 .5242 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52321 .5815 m .49558 .59571 L p
.51166 .58068 L 1 g
F P
s
P
p
.002 w
.51094 .58069 m .51079 .57862 L p
.49965 .58085 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.49558 .59571 m .48408 .58356 L .49209 .58157 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58087 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58087 L .49011 .58088 L 1 g
F
P
p
.002 w
.4947 .58091 m .49209 .58157 L p
.48924 .58087 L 1 g
F P
s
P
p
.002 w
.49209 .58157 m .48408 .58356 L p
.48918 .5809 L 1 g
F P
s
P
p
.48918 .5809 m .48924 .58087 L .49209 .58157 L 1 g
F
P
p
.002 w
.4834 .58364 m .45163 .58721 L p
.4693 .57494 L 1 g
F P
s
P
p
.002 w
.46835 .57435 m .46872 .57265 L p
.45985 .56911 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46835 .57435 L p
1 g
F P
s
P
p
.48921 .57862 m .46835 .57435 L .47784 .57769 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45075 .5632 L p
1 g
F P
s
P
p
.46872 .57265 m .45075 .5632 L .45221 .56423 L 1 g
F
P
p
.44414 .56456 m .44975 .56249 L .45075 .5632 L 1 g
F
P
p
.002 w
.45405 .56553 m .45254 .56538 L p
.45075 .5632 L 1 g
F P
s
P
p
.002 w
.45254 .56538 m .44414 .56456 L p
.45075 .5632 L 1 g
F P
s
P
p
.002 w
.45075 .5632 m .45146 .56129 L p
.44419 .55497 L 1 g
F P
s
P
p
.43676 .5444 m .43856 .54696 L .44414 .56456 L 1 g
F
P
p
.002 w
.44522 .55644 m .44427 .56363 L p
.43856 .54696 L 1 g
F P
s
P
p
.002 w
.44427 .56363 m .44414 .56456 L p
.43856 .54696 L 1 g
F P
s
P
p
.002 w
.44414 .56456 m .41105 .55711 L p
.43676 .5444 L 1 g
F P
s
P
p
.002 w
.43856 .54696 m .43925 .54566 L p
.43574 .53871 L 1 g
F P
s
P
p
.44419 .55497 m .44522 .55644 L .45075 .5632 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43813 .54778 L p
1 g
F P
s
P
p
.002 w
.43813 .54778 m .43743 .5491 L p
.44359 .55446 L 1 g
F P
s
P
p
.45146 .56129 m .43813 .54778 L .44359 .55446 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44753 .53908 m .48192 .55067 L p
.45008 .56237 L 1 g
F P
s
P
p
.002 w
.44414 .56456 m .44522 .55644 L p
.45008 .56237 L 1 g
F P
s
P
p
.002 w
.44522 .55644 m .44753 .53908 L p
.45008 .56237 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44753 .53908 m .44522 .55644 L p
.43856 .54696 L 1 g
F P
s
P
p
.43676 .5444 m .43755 .54401 L .43856 .54696 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43264 .52854 L p
1 g
F P
s
P
p
.41482 .5242 m .43065 .52064 L .43264 .52854 L 1 g
F
P
p
.002 w
.43371 .53279 m .43235 .53217 L p
.43264 .52854 L 1 g
F P
s
P
p
.002 w
.43235 .53217 m .41482 .5242 L p
.43264 .52854 L 1 g
F P
s
P
p
.002 w
.43264 .52854 m .43346 .52734 L p
.43324 .52098 L 1 g
F P
s
P
p
.43925 .54566 m .43264 .52854 L .43329 .53113 L 1 g
F
P
p
.43925 .54566 m .43238 .52891 L .43574 .53871 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43264 .52854 m .46183 .51363 L .43371 .53279 L 1 g
F
P
p
.43065 .52064 m .43331 .52004 L .43264 .52854 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43419 .50905 L p
1 g
F P
s
P
p
.43346 .52734 m .43419 .50905 L .43324 .52098 L 1 g
F
P
p
.43331 .52004 m .46183 .51363 L .43264 .52854 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.41482 .5242 m .43281 .49113 L .43996 .49668 L p
1 g
F P
s
P
p
.002 w
.43419 .50905 m .43485 .50826 L p
.43808 .50072 L 1 g
F P
s
P
p
.41482 .5242 m .43996 .49668 L .42856 .52111 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44265 .49129 L p
1 g
F P
s
P
p
.43281 .49113 m .44272 .49115 L .44265 .49129 L 1 g
F
P
p
.002 w
.43996 .49668 m .43837 .49544 L p
.44265 .49129 L 1 g
F P
s
P
p
.002 w
.43837 .49544 m .43281 .49113 L p
.44265 .49129 L 1 g
F P
s
P
p
.002 w
.44265 .49129 m .44166 .49233 L p
.43886 .49889 L 1 g
F P
s
P
p
.43485 .50826 m .44265 .49129 L .43886 .49889 L 1 g
F
P
p
.002 w
.44265 .49129 m .44339 .4905 L p
.44884 .48528 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.44272 .49115 m .48569 .49125 L .43996 .49668 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.43281 .49113 m .4634 .46197 L .46742 .46725 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44279 .49115 m .4578 .47659 L .48569 .49125 L 1 g
F
P
p
.002 w
.47012 .47081 m .48569 .49125 L p
.4578 .47659 L 1 g
F P
s
P
p
.002 w
.51639 .47475 m .48569 .49125 L .47012 .47081 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47761 .46709 m .51639 .47475 L .47012 .47081 L 1 g
F
P
p
.002 w
.47761 .46709 m .47786 .46667 L p
.48599 .46584 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .48599 .46584 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.4634 .46197 m .46935 .45875 L p
.51639 .47475 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46716 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51639 .47475 m .51294 .46587 L p
.52243 .46716 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54228 .47667 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.53061 .47116 m .54228 .47667 L .55197 .50142 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56608 .50936 L p
1 g
F P
s
P
p
.002 w
.57425 .5015 m .56928 .5162 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56238 .50146 m .56545 .50147 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56545 .50147 m .57425 .5015 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56608 .50936 m .56515 .50826 L p
.56689 .51955 L 1 g
F P
s
P
p
.55661 .4905 m .56608 .50936 L .56274 .50223 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56756 .52883 L p
1 g
F P
s
P
p
.002 w
.56713 .52255 m .57425 .5015 L p
.57338 .50623 L 1 g
F P
s
P
p
.57338 .50623 m .568 .53524 L .56756 .52883 L 1 g
F
P
p
.57338 .50623 m .56756 .52883 L .56713 .52255 L 1 g
F
P
p
.002 w
.56756 .52883 m .56654 .52734 L p
.56429 .53967 L 1 g
F P
s
P
p
.002 w
.57298 .53672 m .56008 .55159 L p
.5616 .54727 L 1 g
F P
s
P
p
.002 w
.56606 .53466 m .57004 .53584 L p
.5616 .54727 L 1 g
F P
s
P
p
.002 w
.57004 .53584 m .57298 .53672 L p
.5616 .54727 L 1 g
F P
s
P
p
.002 w
.5616 .54727 m .56075 .54566 L p
.55473 .55657 L 1 g
F P
s
P
p
.56429 .53967 m .56606 .53466 L .56756 .52883 L 1 g
F
P
p
.002 w
.56008 .55159 m .55065 .56245 L p
.55144 .56103 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54937 .56352 L p
1 g
F P
s
P
p
.002 w
.53175 .58545 m .52968 .58449 L p
.55003 .5631 L 1 g
F P
s
P
p
.002 w
.55065 .56245 m .55021 .56299 L p
.55003 .5631 L 1 g
F P
s
P
p
.002 w
.55021 .56299 m .53175 .58545 L p
.55003 .5631 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54854 .56129 L p
.53995 .56948 L 1 g
F P
s
P
p
.002 w
.52321 .5815 m .52237 .58059 L p
.53172 .57468 L 1 g
F P
s
P
p
.002 w
.54642 .56539 m .5344 .57374 L p
.53172 .57468 L 1 g
F P
s
P
p
.002 w
.5344 .57374 m .52321 .5815 L p
.53172 .57468 L 1 g
F P
s
P
p
.002 w
.53172 .57468 m .53128 .57265 L p
.519 .57895 L 1 g
F P
s
P
p
.002 w
.52057 .57861 m .52233 .58053 L p
.51186 .58049 L 1 g
F P
s
P
p
.519 .57895 m .51767 .57963 L .52057 .57861 L 1 g
F
P
p
.519 .57895 m .52057 .57861 L .53172 .57468 L 1 g
F
P
p
.51166 .58068 m .51186 .58049 L .52233 .58053 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58069 L p
1 g
F P
s
P
p
.51166 .58068 m .51094 .58069 L .51186 .58049 L 1 g
F
P
p
.50759 .58449 m .4947 .58091 L .51166 .58068 L 1 g
F
P
p
.002 w
.52233 .58053 m .52321 .5815 L p
.51166 .58068 L 1 g
F P
s
P
p
.002 w
.51094 .58069 m .51104 .58197 L p
.51636 .57952 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .58069 L .51636 .57952 L 1 g
F
P
p
.51079 .57862 m .49855 .57996 L .49996 .58079 L 1 g
F
P
p
.49855 .57996 m .48903 .58099 L .49996 .58079 L 1 g
F
P
p
.49996 .58079 m .48903 .58099 L .49965 .58085 L 1 g
F
P
p
.002 w
.4947 .58091 m .51748 .57524 L p
.51186 .58049 L 1 g
F P
s
P
p
.51094 .58069 m .4947 .58091 L .51186 .58049 L 1 g
F
P
p
.53128 .57265 m .51104 .58197 L .51767 .57963 L 1 g
F
P
p
.53995 .56948 m .54642 .56539 L .54937 .56352 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.52968 .58449 m .52321 .5815 L .5344 .57374 L p
1 g
F P
s
P
p
.002 w
.52237 .58059 m .52057 .57861 L p
.53172 .57468 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53173 .5747 L p
1 g
F P
s
P
p
.002 w
.53173 .5747 m .53172 .57468 L p
.53119 .57489 L 1 g
F P
s
P
p
.53119 .57489 m .51111 .583 L .53173 .5747 L 1 g
F
P
p
.002 w
.5344 .57374 m .54642 .56539 L p
.54128 .57125 L 1 g
F P
s
P
p
.52968 .58449 m .5344 .57374 L .54128 .57125 L 1 g
F
P
p
.56075 .54566 m .54937 .56352 L .54985 .56301 L 1 g
F
P
p
.002 w
.55021 .56262 m .55065 .56245 L .54985 .56301 L p
1 g
F P
s
P
p
.54999 .56286 m .54985 .56301 L .54999 .56286 L 1 g
F
P
p
.56075 .54566 m .54985 .56301 L .54999 .56286 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .5747 L p
1 g
F P
s
P
p
.54854 .56129 m .53173 .5747 L .53991 .56951 L 1 g
F
P
p
.002 w
.54985 .56301 m .55065 .56245 L p
.52968 .58449 L 1 g
F P
s
P
p
.56075 .54566 m .54998 .56288 L .55473 .55657 L 1 g
F
P
p
.54998 .56288 m .55032 .5625 L .55473 .55657 L 1 g
F
P
p
.55032 .5625 m .55036 .56245 L .55473 .55657 L 1 g
F
P
p
.55036 .56246 m .55044 .56236 L .55473 .55657 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51522 .5673 m .51673 .55854 L .55039 .56242 L p
1 g
F P
s
P
p
.002 w
.55039 .56242 m .55065 .56245 L .55032 .5625 L p
1 g
F P
s
P
p
.002 w
.55032 .5625 m .51522 .5673 L p
.55039 .56242 L 1 g
F P
s
P
p
.55032 .5625 m .55036 .56246 L .55036 .56245 L 1 g
F
P
p
.002 w
.55044 .56236 m .55065 .56245 L .55039 .56242 L p
1 g
F P
s
P
p
.55036 .56246 m .55041 .5624 L .55044 .56236 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.51673 .55854 m .52188 .54992 L .55044 .56236 L p
1 g
F P
s
P
p
.002 w
.55039 .56242 m .51673 .55854 L p
.55044 .56236 L 1 g
F P
s
P
p
.55041 .5624 m .5505 .56229 L .55473 .55657 L 1 g
F
P
p
.55044 .56237 m .55067 .56207 L .55473 .55657 L 1 g
F
P
p
.002 w
.55104 .56157 m .55065 .56245 L .55067 .56207 L p
1 g
F P
s
P
p
.55067 .56207 m .55078 .56192 L .55104 .56157 L 1 g
F
P
p
.55067 .56207 m .55104 .56157 L .55473 .55657 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5521 .53388 m .56331 .53384 L .55104 .56157 L p
1 g
F P
s
P
p
.002 w
.55067 .56207 m .5521 .53388 L p
.55104 .56157 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.53015 .5424 m .54061 .53684 L .55055 .56222 L p
1 g
F P
s
P
p
.002 w
.55055 .56222 m .55065 .56245 L .55049 .5623 L p
1 g
F P
s
P
p
.002 w
.55049 .5623 m .53015 .5424 L p
.55055 .56222 L 1 g
F P
s
P
p
.002 w
.55049 .5623 m .55065 .56245 L .55044 .56236 L p
1 g
F P
s
P
p
.55041 .5624 m .55044 .56237 L .5505 .56229 L 1 g
F
P
p
.002 w
.55067 .56207 m .55065 .56245 L .55055 .56222 L p
1 g
F P
s
P
p
.55044 .56237 m .55049 .56231 L .55078 .56192 L 1 g
F
P
p
.002 w
.54061 .53684 m .5521 .53388 L .55067 .56207 L p
1 g
F P
s
P
p
.002 w
.55055 .56222 m .54061 .53684 L p
.55067 .56207 L 1 g
F P
s
P
p
.002 w
.52188 .54992 m .53015 .5424 L .55049 .5623 L p
1 g
F P
s
P
p
.002 w
.55044 .56236 m .52188 .54992 L p
.55049 .5623 L 1 g
F P
s
P
p
.55039 .56243 m .54945 .56373 L .55049 .56231 L 1 g
F
P
p
.54998 .56288 m .54984 .5631 L .55039 .56243 L 1 g
F
P
p
.54984 .5631 m .54945 .56373 L .55039 .56243 L 1 g
F
P
p
.002 w
.51748 .57524 m .51522 .5673 L .55032 .5625 L p
1 g
F P
s
P
p
.002 w
.55032 .5625 m .55065 .56245 L .55021 .56262 L p
1 g
F P
s
P
p
.002 w
.55021 .56262 m .51748 .57524 L p
.55032 .5625 L 1 g
F P
s
P
p
.002 w
.51748 .57524 m .55021 .56262 L p
.54642 .56539 L 1 g
F P
s
P
p
.002 w
.54985 .56301 m .54642 .56539 L p
.55021 .56262 L 1 g
F P
s
P
p
.002 w
.54642 .56539 m .54985 .56301 L p
.54937 .56352 L 1 g
F P
s
P
p
.52968 .58449 m .54642 .56539 L .54937 .56352 L 1 g
F
P
p
.002 w
.53173 .5747 m .5322 .57686 L p
.53991 .56951 L 1 g
F P
s
P
p
.53172 .57468 m .51748 .57524 L .54642 .56539 L 1 g
F
P
p
.002 w
.52057 .57861 m .51748 .57524 L p
.53172 .57468 L 1 g
F P
s
P
p
.002 w
.51104 .58197 m .51111 .583 L p
.51767 .57963 L 1 g
F P
s
P
p
.002 w
.51748 .57524 m .52057 .57861 L p
.51186 .58049 L 1 g
F P
s
P
p
.51767 .57963 m .51111 .583 L .53172 .57468 L 1 g
F
P
p
.53995 .56948 m .53991 .56951 L .54642 .56539 L 1 g
F
P
p
.002 w
.55334 .58514 m .54216 .5867 L .55053 .56278 L p
1 g
F P
s
P
p
.002 w
.55053 .56278 m .55065 .56245 L .55068 .56269 L p
1 g
F P
s
P
p
.002 w
.55068 .56269 m .55334 .58514 L p
.55053 .56278 L 1 g
F P
s
P
p
.002 w
.54216 .5867 m .53175 .58545 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54938 .56355 L p
1 g
F P
s
P
p
.002 w
.54938 .56355 m .54937 .56352 L p
.54909 .56374 L 1 g
F P
s
P
p
.54909 .56374 m .5322 .57686 L .54938 .56355 L 1 g
F
P
p
.53991 .56951 m .5322 .57686 L .54937 .56352 L 1 g
F
P
p
.002 w
.54937 .56352 m .54945 .56373 L p
.54999 .56286 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56242 .54881 L p
1 g
F P
s
P
p
.56654 .52734 m .56242 .54881 L .56312 .54608 L 1 g
F
P
p
.56515 .50826 m .56756 .52883 L .56747 .52755 L 1 g
F
P
p
.56515 .50826 m .56764 .52894 L .56689 .51955 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56331 .53384 m .56713 .52255 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.568 .53524 m .56606 .53466 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.56606 .53466 m .56331 .53384 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.57298 .53672 m .58005 .54215 L .55798 .55739 L p
1 g
F P
s
P
p
.002 w
.55798 .55739 m .55065 .56245 L .56008 .55159 L p
1 g
F P
s
P
p
.002 w
.56008 .55159 m .57298 .53672 L p
.55798 .55739 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56804 .52952 L p
1 g
F P
s
P
p
.002 w
.56804 .52952 m .56756 .52883 L p
.566 .53517 L 1 g
F P
s
P
p
.566 .53517 m .56257 .5491 L .56804 .52952 L 1 g
F
P
p
.002 w
.56242 .54881 m .56257 .5491 L p
.56312 .54608 L 1 g
F P
s
P
p
.56606 .53466 m .5616 .54727 L .55144 .56103 L 1 g
F
P
p
.5616 .54727 m .56008 .55159 L .55144 .56103 L 1 g
F
P
p
.002 w
.55065 .56245 m .56331 .53384 L .56606 .53466 L p
1 g
F P
s
P
p
.002 w
.56414 .58095 m .55334 .58514 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.57343 .57456 m .56414 .58095 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.58025 .56663 m .57343 .57456 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.58384 .55798 m .58025 .56663 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.58379 .54951 m .58384 .55798 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.58005 .54215 m .58379 .54951 L .55065 .56245 L closepath p
1 g
F P
s
P
p
.002 w
.54945 .56373 m .54998 .56518 L p
.55473 .55657 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5616 .54727 L p
1 g
F P
s
P
p
.55473 .55657 m .54998 .56518 L .5616 .54727 L 1 g
F
P
p
.56429 .53967 m .56312 .54608 L .56606 .53466 L 1 g
F
P
p
.56312 .54608 m .56257 .5491 L .56756 .52883 L 1 g
F
P
p
.002 w
.56756 .52883 m .56764 .52894 L p
.56747 .52755 L 1 g
F P
s
P
p
.002 w
.57298 .53672 m .568 .53524 L p
.57425 .5015 L 1 g
F P
s
P
p
.002 w
.57425 .5015 m .56238 .50146 L p
.55022 .4662 L 1 g
F P
s
P
p
.002 w
.55737 .49131 m .55661 .4905 L p
.5631 .50291 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55737 .49131 L p
1 g
F P
s
P
p
.55964 .4935 m .56238 .50146 L .55737 .49131 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55737 .49131 L p
1 g
F P
s
P
p
.5631 .50291 m .56713 .51061 L .55737 .49131 L 1 g
F
P
p
.54174 .47608 m .55737 .49131 L .55467 .48869 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56238 .50146 m .55197 .50142 L .55117 .48531 L p
1 g
F P
s
P
p
.55737 .49131 m .56238 .50146 L .55117 .48531 L 1 g
F
P
p
.54174 .47608 m .55762 .49157 L .55019 .48435 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55117 .48531 m .55081 .47802 L p
.55737 .49131 L 1 g
F P
s
P
p
.002 w
.55117 .48531 m .55197 .50142 L p
.54228 .47667 L 1 g
F P
s
P
p
.002 w
.55762 .49157 m .55834 .49233 L p
.55049 .48465 L 1 g
F P
s
P
p
.55019 .48435 m .55117 .48531 L .55049 .48465 L 1 g
F
P
p
.55117 .48531 m .55762 .49157 L .55049 .48465 L 1 g
F
P
p
.002 w
.55737 .49131 m .55762 .49157 L p
.55467 .48869 L 1 g
F P
s
P
p
.002 w
.55081 .47802 m .55022 .4662 L p
.55964 .4935 L 1 g
F P
s
P
p
.55964 .4935 m .55737 .49131 L .55081 .47802 L 1 g
F
P
p
.56238 .50146 m .56608 .50936 L .56331 .53384 L 1 g
F
P
p
.002 w
.56928 .5162 m .56713 .52255 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56713 .52255 m .56331 .53384 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56764 .52894 m .56854 .53025 L p
.56689 .51955 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56608 .50936 L p
1 g
F P
s
P
p
.56689 .51955 m .56854 .53025 L .56608 .50936 L 1 g
F
P
p
.002 w
.56608 .50936 m .56713 .51061 L p
.56274 .50223 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55197 .50142 m .56238 .50146 L p
.56331 .53384 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54228 .47667 L p
1 g
F P
s
P
p
.002 w
.54228 .47667 m .54174 .47608 L p
.55019 .48435 L 1 g
F P
s
P
p
.55019 .48435 m .55834 .49233 L .54228 .47667 L 1 g
F
P
p
.002 w
.55022 .4662 m .55095 .48077 L p
.54228 .47667 L 1 g
F P
s
P
p
.52214 .46667 m .54228 .47667 L .53669 .47403 L 1 g
F
P
p
.52214 .46667 m .5426 .47702 L .53413 .47288 L 1 g
F
P
p
.002 w
.51639 .47475 m .53061 .47116 L p
.55197 .50142 L 1 g
F P
s
P
p
.002 w
.53061 .47116 m .51639 .47475 L p
.52243 .46716 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46716 L p
1 g
F P
s
P
p
.002 w
.52243 .46716 m .52214 .46667 L p
.53413 .47288 L 1 g
F P
s
P
p
.53413 .47288 m .54302 .47747 L .52243 .46716 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.50307 .4405 m .53804 .46928 L .52243 .46716 L 1 g
F
P
p
.5 .4634 m .52243 .46716 L .51642 .46634 L 1 g
F
P
p
.5 .4634 m .52261 .46745 L .51224 .46575 L 1 g
F
P
p
.002 w
.51294 .46587 m .51133 .46173 L p
.52243 .46716 L 1 g
F P
s
P
p
.002 w
.51133 .46173 m .50307 .4405 L p
.52243 .46716 L 1 g
F P
s
P
p
.002 w
.53061 .47116 m .53537 .46995 L p
.54228 .47667 L 1 g
F P
s
P
p
.002 w
.53537 .46995 m .55022 .4662 L p
.54228 .47667 L 1 g
F P
s
P
p
.002 w
.55095 .48077 m .55117 .48531 L p
.54228 .47667 L 1 g
F P
s
P
p
.002 w
.54228 .47667 m .5426 .47702 L p
.53669 .47403 L 1 g
F P
s
P
p
.002 w
.53804 .46928 m .53061 .47116 L p
.52243 .46716 L 1 g
F P
s
P
p
.002 w
.5426 .47702 m .54302 .47747 L p
.53413 .47288 L 1 g
F P
s
P
p
.002 w
.52243 .46716 m .52261 .46745 L p
.51642 .46634 L 1 g
F P
s
P
p
.002 w
.55022 .4662 m .53804 .46928 L p
.50307 .4405 L 1 g
F P
s
P
p
.002 w
.51294 .46587 m .51639 .47475 L p
.46935 .45875 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.46935 .45875 m .50307 .4405 L .51294 .46587 L p
1 g
F P
s
P
p
.002 w
.52261 .46745 m .52282 .46778 L p
.51224 .46575 L 1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .46442 L p
.48599 .46584 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47761 .46709 L p
1 g
F P
s
P
p
.002 w
.47761 .46709 m .47718 .46778 L p
.46887 .47143 L 1 g
F P
s
P
p
.43281 .49113 m .44559 .48231 L .44279 .49115 L 1 g
F
P
p
.45826 .47608 m .47761 .46709 L .47012 .47081 L 1 g
F
P
p
.45826 .47608 m .47012 .47081 L .46775 .47192 L 1 g
F
P
p
.002 w
.4578 .47659 m .45826 .47608 L p
.46775 .47192 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4578 .47659 L p
1 g
F P
s
P
p
.44559 .48231 m .46742 .46725 L .4578 .47659 L 1 g
F
P
p
.44339 .4905 m .4578 .47659 L .44884 .48528 L 1 g
F
P
p
.44559 .48231 m .4578 .47659 L .44279 .49115 L 1 g
F
P
p
.46775 .47192 m .47012 .47081 L .46887 .47143 L 1 g
F
P
p
.4634 .46197 m .47991 .46595 L .47761 .46709 L 1 g
F
P
p
.002 w
.47012 .47081 m .46835 .46848 L p
.47761 .46709 L 1 g
F P
s
P
p
.002 w
.46835 .46848 m .4634 .46197 L p
.47761 .46709 L 1 g
F P
s
P
p
.47991 .46595 m .48196 .46644 L .47761 .46709 L 1 g
F
P
p
.48196 .46644 m .51639 .47475 L .47761 .46709 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47761 .46709 L p
1 g
F P
s
P
p
.48599 .46584 m .5 .46442 L .47761 .46709 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45723 .4772 L p
1 g
F P
s
P
p
.002 w
.45723 .4772 m .4578 .47659 L p
.46577 .47296 L 1 g
F P
s
P
p
.46577 .47296 m .47718 .46778 L .45723 .4772 L 1 g
F
P
p
.46775 .47192 m .47718 .46778 L .4578 .47659 L 1 g
F
P
p
.002 w
.46742 .46725 m .47012 .47081 L p
.4578 .47659 L 1 g
F P
s
P
p
.002 w
.4578 .47659 m .45698 .47747 L p
.44884 .48528 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44265 .49129 L p
1 g
F P
s
P
p
.44884 .48528 m .45698 .47747 L .44265 .49129 L 1 g
F
P
p
.002 w
.48569 .49125 m .46183 .51363 L .43996 .49668 L p
1 g
F P
s
P
p
.002 w
.43996 .49668 m .46183 .51363 L p
.42856 .52111 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43419 .50905 L p
1 g
F P
s
P
p
.43808 .50072 m .44166 .49233 L .43419 .50905 L 1 g
F
P
p
.002 w
.43419 .50905 m .43287 .51061 L p
.43324 .52098 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43264 .52854 L p
1 g
F P
s
P
p
.43324 .52098 m .43287 .51061 L .43264 .52854 L 1 g
F
P
p
.002 w
.43264 .52854 m .43238 .52891 L p
.43329 .53113 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.46183 .51363 m .44753 .53908 L .43371 .53279 L p
1 g
F P
s
P
p
.43755 .54401 m .44753 .53908 L .43856 .54696 L 1 g
F
P
p
.002 w
.41105 .55711 m .41482 .5242 L .44753 .53908 L p
1 g
F P
s
P
p
.002 w
.43238 .52891 m .43146 .53025 L p
.43574 .53871 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43856 .54696 L p
1 g
F P
s
P
p
.43574 .53871 m .43146 .53025 L .43856 .54696 L 1 g
F
P
p
.44419 .55497 m .44359 .55446 L .44522 .55644 L 1 g
F
P
p
.46872 .57265 m .45221 .56423 L .45985 .56911 L 1 g
F
P
p
.45221 .56423 m .45066 .56344 L .45405 .56553 L 1 g
F
P
p
.45221 .56423 m .45405 .56553 L .45985 .56911 L 1 g
F
P
p
.44975 .56249 m .48192 .55067 L .45405 .56553 L 1 g
F
P
p
.002 w
.44414 .56456 m .45405 .56553 L p
.46807 .57418 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45075 .5632 L p
1 g
F P
s
P
p
.44359 .55446 m .43743 .5491 L .45075 .5632 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48192 .55067 m .47928 .56801 L .45405 .56553 L p
1 g
F P
s
P
p
.002 w
.45075 .5632 m .45066 .56344 L p
.45221 .56423 L 1 g
F P
s
P
p
.002 w
.45066 .56344 m .45002 .56518 L p
.45985 .56911 L 1 g
F P
s
P
p
.46954 .57477 m .46807 .57418 L .47928 .56801 L 1 g
F
P
p
.002 w
.45405 .56553 m .47928 .56801 L p
.46807 .57418 L 1 g
F P
s
P
p
.002 w
.45163 .58721 m .44463 .56602 L p
.46954 .57477 L 1 g
F P
s
P
p
.002 w
.44463 .56602 m .44414 .56456 L p
.46954 .57477 L 1 g
F P
s
P
p
.002 w
.48408 .58356 m .4834 .58364 L p
.46954 .57477 L 1 g
F P
s
P
p
.4693 .57494 m .46954 .57477 L .4834 .58364 L 1 g
F
P
p
.002 w
.48281 .57943 m .48408 .58356 L p
.46954 .57477 L 1 g
F P
s
P
p
.002 w
.46835 .57435 m .4678 .57686 L p
.47784 .57769 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46835 .57435 L p
1 g
F P
s
P
p
.45985 .56911 m .45002 .56518 L .46835 .57435 L 1 g
F
P
p
.002 w
.48904 .58087 m .48921 .57862 L p
.47509 .57765 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .46911 .57724 L p
.47509 .57765 L 1 g
F P
s
P
p
.48921 .57862 m .47379 .57735 L .47509 .57765 L 1 g
F
P
p
.47379 .57735 m .4678 .57686 L .47509 .57765 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47928 .56801 m .51522 .5673 L p
.48918 .5809 L 1 g
F P
s
P
p
.002 w
.48408 .58356 m .48281 .57943 L p
.48918 .5809 L 1 g
F P
s
P
p
.002 w
.48281 .57943 m .47928 .56801 L p
.48918 .5809 L 1 g
F P
s
P
p
.002 w
.47928 .56801 m .48281 .57943 L p
.46954 .57477 L 1 g
F P
s
P
p
.002 w
.48903 .58099 m .48904 .58087 L p
.48459 .58006 L 1 g
F P
s
P
p
.48459 .58006 m .46911 .57724 L .4852 .58027 L 1 g
F
P
p
.48459 .58006 m .4852 .58027 L .48903 .58099 L 1 g
F
P
p
.47509 .57765 m .46911 .57724 L .48904 .58087 L 1 g
F
P
p
.002 w
.51522 .5673 m .51748 .57524 L .4947 .58091 L p
1 g
F P
s
P
p
.48924 .58087 m .51522 .5673 L .4947 .58091 L 1 g
F
P
p
.002 w
.48904 .58087 m .48903 .58099 L p
.49011 .58088 L 1 g
F P
s
P
p
.002 w
.49209 .58157 m .4947 .58091 L p
.50759 .58449 L 1 g
F P
s
P
p
.49558 .59571 m .49209 .58157 L .50759 .58449 L 1 g
F
P
p
.002 w
.48903 .58099 m .48889 .583 L p
.49965 .58085 L 1 g
F P
s
P
p
.002 w
.46911 .57724 m .48889 .583 L .48903 .58099 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58069 L p
1 g
F P
s
P
p
.49965 .58085 m .48889 .583 L .51094 .58069 L 1 g
F
P
p
.002 w
.59103 .32783 m .6429 .34766 L .64123 .37743 L p
1 g
F P
s
P
p
.002 w
.6429 .34766 m .59103 .32783 L .58608 .29978 L p
1 g
F P
s
P
p
.002 w
.63525 .40945 m .66494 .43586 L .65023 .46428 L p
1 g
F P
s
P
p
.002 w
.66494 .43586 m .63525 .40945 L .64123 .37743 L p
1 g
F P
s
P
p
.002 w
.58025 .56663 m .58384 .55798 L .61394 .54979 L p
1 g
F P
s
P
p
.002 w
.61414 .5331 m .61394 .54979 L .58384 .55798 L p
1 g
F P
s
P
p
.002 w
.61394 .54979 m .61414 .5331 L .64066 .51386 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.63074 .49214 m .64066 .51386 L .61414 .5331 L p
1 g
F P
s
P
p
.002 w
.64066 .51386 m .63074 .49214 L .65023 .46428 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45365 .31281 m .39307 .34637 L .38328 .32323 L p
1 g
F P
s
P
p
.002 w
.38328 .32323 m .44454 .28913 L .45365 .31281 L p
1 g
F P
s
P
p
.002 w
.44454 .28913 m .51282 .27287 L .52106 .29663 L p
1 g
F P
s
P
p
.002 w
.58608 .29978 m .52106 .29663 L .51282 .27287 L p
1 g
F P
s
P
p
.002 w
.40644 .37278 m .36255 .41659 L .34742 .39252 L p
1 g
F P
s
P
p
.002 w
.34742 .39252 m .39307 .34637 L .40644 .37278 L p
1 g
F P
s
P
p
.002 w
.52106 .29663 m .58608 .29978 L .59103 .32783 L p
1 g
F P
s
P
p
.002 w
.62503 .4426 m .65023 .46428 L .63074 .49214 L p
1 g
F P
s
P
p
.002 w
.65023 .46428 m .62503 .4426 L .63525 .40945 L p
1 g
F P
s
P
p
.002 w
.58384 .55798 m .58379 .54951 L .61414 .5331 L p
1 g
F P
s
P
p
.002 w
.60707 .51842 m .61414 .5331 L .58379 .54951 L p
1 g
F P
s
P
p
.002 w
.61414 .5331 m .60707 .51842 L .63074 .49214 L p
1 g
F P
s
P
p
.002 w
.52106 .29663 m .45365 .31281 L .44454 .28913 L p
1 g
F P
s
P
p
.002 w
.40595 .46683 m .385 .50661 L .35909 .487 L p
1 g
F P
s
P
p
.002 w
.35909 .487 m .38226 .44166 L .40595 .46683 L p
1 g
F P
s
P
p
.002 w
.59329 .35969 m .64123 .37743 L .63525 .40945 L p
1 g
F P
s
P
p
.002 w
.64123 .37743 m .59329 .35969 L .59103 .32783 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.58379 .54951 m .58005 .54215 L .60707 .51842 L p
1 g
F P
s
P
p
.002 w
.61089 .47567 m .63074 .49214 L .60707 .51842 L p
1 g
F P
s
P
p
.002 w
.63074 .49214 m .61089 .47567 L .62503 .4426 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51673 .55854 m .51522 .5673 L .47928 .56801 L p
1 g
F P
s
P
p
.002 w
.47928 .56801 m .48192 .55067 L .51673 .55854 L p
1 g
F P
s
P
p
.002 w
.59332 .50744 m .60707 .51842 L .58005 .54215 L p
1 g
F P
s
P
p
.002 w
.60707 .51842 m .59332 .50744 L .61089 .47567 L p
1 g
F P
s
P
p
.002 w
.42301 .40156 m .38226 .44166 L .36255 .41659 L p
1 g
F P
s
P
p
.002 w
.36255 .41659 m .40644 .37278 L .42301 .40156 L p
1 g
F P
s
P
p
.002 w
.43281 .49113 m .41482 .5242 L .385 .50661 L p
1 g
F P
s
P
p
.002 w
.385 .50661 m .40595 .46683 L .43281 .49113 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58005 .54215 m .57298 .53672 L .59332 .50744 L p
1 g
F P
s
P
p
.002 w
.52889 .32519 m .59103 .32783 L .59329 .35969 L p
1 g
F P
s
P
p
.002 w
.59103 .32783 m .52889 .32519 L .52106 .29663 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59272 .3943 m .63525 .40945 L .62503 .4426 L p
1 g
F P
s
P
p
.002 w
.63525 .40945 m .59272 .3943 L .59329 .35969 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.59289 .38361 L
s
P
p
.004 w
.63361 .36306 m
.6641 .34766 L
s
P
p
.004 w
.61001 .37497 m
.61091 .37452 L
s
P
p
.004 w
.61091 .37452 m
.63361 .36306 L
s
P
p
.002 w
.46445 .3408 m .40644 .37278 L .39307 .34637 L p
1 g
F P
s
P
p
.002 w
.39307 .34637 m .45365 .31281 L .46445 .3408 L p
1 g
F P
s
P
p
.002 w
.45365 .31281 m .52106 .29663 L .52889 .32519 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52188 .54992 m .51673 .55854 L .48192 .55067 L p
1 g
F P
s
P
p
.002 w
.57425 .5015 m .59332 .50744 L .57298 .53672 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.52889 .32519 m .46445 .3408 L .45365 .31281 L p
1 g
F P
s
P
p
.002 w
.58926 .43038 m .62503 .4426 L .61089 .47567 L p
1 g
F P
s
P
p
.002 w
.62503 .4426 m .58926 .43038 L .59272 .3943 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.48192 .55067 m .4919 .53346 L .52188 .54992 L p
1 g
F P
s
P
p
.002 w
.4919 .53346 m .48192 .55067 L .44753 .53908 L p
1 g
F P
s
P
p
.002 w
.53015 .5424 m .52188 .54992 L .4919 .53346 L p
1 g
F P
s
P
p
.002 w
.56331 .53384 m .5521 .53388 L .55197 .50142 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59332 .50744 m .57425 .5015 L .58302 .46658 L p
1 g
F P
s
P
p
.002 w
.58302 .46658 m .61089 .47567 L .59332 .50744 L p
1 g
F P
s
P
p
.002 w
.44753 .53908 m .46183 .51363 L .4919 .53346 L p
1 g
F P
s
P
p
.002 w
.61089 .47567 m .58302 .46658 L .58926 .43038 L p
1 g
F P
s
P
p
.002 w
.44223 .43167 m .40595 .46683 L .38226 .44166 L p
1 g
F P
s
P
p
.002 w
.38226 .44166 m .42301 .40156 L .44223 .43167 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53599 .35766 m .59329 .35969 L .59272 .3943 L p
1 g
F P
s
P
p
.002 w
.59329 .35969 m .53599 .35766 L .52889 .32519 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.54061 .53684 m .53015 .5424 L .50823 .5184 L p
1 g
F P
s
P
p
.002 w
.4919 .53346 m .50823 .5184 L .53015 .5424 L p
1 g
F P
s
P
p
.002 w
.5521 .53388 m .54061 .53684 L .52906 .50727 L p
1 g
F P
s
P
p
.002 w
.52906 .50727 m .55197 .50142 L .5521 .53388 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.50823 .5184 m .52906 .50727 L .54061 .53684 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.47658 .3722 m .42301 .40156 L .40644 .37278 L p
1 g
F P
s
P
p
.002 w
.40644 .37278 m .46445 .3408 L .47658 .3722 L p
1 g
F P
s
P
p
.002 w
.46445 .3408 m .52889 .32519 L .53599 .35766 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50823 .5184 m .4919 .53346 L .46183 .51363 L p
1 g
F P
s
P
p
.002 w
.55022 .4662 m .58302 .46658 L .57425 .5015 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.4634 .46197 m .43281 .49113 L .40595 .46683 L p
1 g
F P
s
P
p
.002 w
.40595 .46683 m .44223 .43167 L .4634 .46197 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54207 .39289 m .59272 .3943 L .58926 .43038 L p
1 g
F P
s
P
p
.002 w
.59272 .3943 m .54207 .39289 L .53599 .35766 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53599 .35766 m .47658 .3722 L .46445 .3408 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46183 .51363 m .48569 .49125 L .50823 .5184 L p
1 g
F P
s
P
p
.002 w
.58302 .46658 m .55022 .4662 L .54688 .42955 L p
1 g
F P
s
P
p
.002 w
.54688 .42955 m .58926 .43038 L .58302 .46658 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.58926 .43038 m .54688 .42955 L .54207 .39289 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52906 .50727 m .50823 .5184 L .48569 .49125 L p
1 g
F P
s
P
p
.002 w
.55197 .50142 m .52906 .50727 L .51639 .47475 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.48963 .40587 m .44223 .43167 L .42301 .40156 L p
1 g
F P
s
P
p
.002 w
.42301 .40156 m .47658 .3722 L .48963 .40587 L p
1 g
F P
s
P
p
.002 w
.48569 .49125 m .51639 .47475 L .52906 .50727 L p
1 g
F P
s
P
p
.002 w
.47658 .3722 m .53599 .35766 L .54207 .39289 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.54207 .39289 m .48963 .40587 L .47658 .3722 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.50307 .4405 m .54688 .42955 L .55022 .4662 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.50307 .4405 m .4634 .46197 L .44223 .43167 L p
1 g
F P
s
P
p
.002 w
.44223 .43167 m .48963 .40587 L .50307 .4405 L p
1 g
F P
s
P
p
.002 w
.48963 .40587 m .54207 .39289 L .54688 .42955 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54688 .42955 m .50307 .4405 L .48963 .40587 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.56797 .60757 m
.57142 .61656 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .67784 .34072 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58044 .64006 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[TextData[{
  StyleBox["\tAfter the computer generated all of the plots, we have asked ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " to only show the first plot, and hide the rest.  The little white \
rectangle to the lower right of the graphics cell tells the user that there \
is more hidden information.  To the right of that box, there is a vertical \
line, like an extended \"]\", and to the right of that, another vertical line \
with half an arrowhead at the bottom.  To view all of the plots, simply \
double click on that second vertical bar or bracket.  If for some reason you \
wish to recompress the series of graphics, double click the same second \
vertical bar, and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " will group the plots together.  To animate the series of plots, select \
the graphs by clicking on that second vertical bracket, and then select, in \
the ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Graph",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" menu, the option named ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Animate Selected Graphics",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  This will start ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["'s animation facility.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\tIt is very interesting to watch what happens when ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " (in its animation process) finishes going through the series of plots \
once, and then loops back to the beginning and starts over again.  That \
discontinuity where the vector  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " (or, imagining the object to be a pulsar, the radio emission beam vector) \
jumps from its last position to its first position is fascinating, for it \
illustrates what has happened to the position of  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " in one spin period.  The jump is fairly small, but if examined carefully, \
one can see that ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " jumps a bit ahead in its orbit (where moving ahead is motion \
counterclockwise), and also moves down.  The symmetry axis vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", also jumps a bit back in its \"orbit,\" but not nearly as much as ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " seems to.  Thus, one can tell that in one spin period, the vector ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " has angled up a bit from it's original position, and has also fallen a \
bit behind.  Meanwhile, the symmetry axis vector seems to have moved forward \
in its \"orbit\", relative to what we might expect if free precession were \
not occuring. ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["One Precession Period"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData[
"Alpha = Pi/7, Beta = Pi/5, Omega = 10, OmegaP = 100, Theta = Pi/10"], 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData[
"PrecessionMovie[0, 0.7, 130, alpha, beta, omegap, omega, theta]"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47437 .46387 m .50591 .44905 L .49026 .42515 L p
1 g
F P
s
P
p
.002 w
.49026 .42515 m .46581 .43658 L .47437 .46387 L p
1 g
F P
s
P
p
.002 w
.51061 .40729 m .49026 .42515 L .50591 .44905 L p
1 g
F P
s
P
p
.002 w
.46581 .43658 m .49026 .42515 L .4748 .40134 L p
1 g
F P
s
P
p
.002 w
.49026 .42515 m .51061 .40729 L .48871 .3891 L p
1 g
F P
s
P
p
.002 w
.48871 .3891 m .4748 .40134 L .49026 .42515 L p
1 g
F P
s
P
p
.002 w
.4836 .49051 m .52149 .47259 L .50591 .44905 L p
1 g
F P
s
P
p
.002 w
.50591 .44905 m .47437 .46387 L .4836 .49051 L p
1 g
F P
s
P
p
.002 w
.53222 .426 m .50591 .44905 L .52149 .47259 L p
1 g
F P
s
P
p
.002 w
.50591 .44905 m .53222 .426 L .51061 .40729 L p
1 g
F P
s
P
p
.002 w
.52482 .38474 m .51061 .40729 L .53222 .426 L p
1 g
F P
s
P
p
.002 w
.51061 .40729 m .52482 .38474 L .49835 .37365 L p
1 g
F P
s
P
p
.002 w
.49835 .37365 m .48871 .3891 L .51061 .40729 L p
1 g
F P
s
P
p
.002 w
.52149 .47259 m .55315 .44492 L .53222 .426 L p
1 g
F P
s
P
p
.002 w
.55071 .39694 m .53222 .426 L .55315 .44492 L p
1 g
F P
s
P
p
.002 w
.53222 .426 m .55071 .39694 L .52482 .38474 L p
1 g
F P
s
P
p
.002 w
.44061 .46897 m .47437 .46387 L .46581 .43658 L p
1 g
F P
s
P
p
.002 w
.46581 .43658 m .43967 .44038 L .44061 .46897 L p
1 g
F P
s
P
p
.002 w
.43967 .44038 m .46581 .43658 L .45806 .40911 L p
1 g
F P
s
P
p
.002 w
.4748 .40134 m .45806 .40911 L .46581 .43658 L p
1 g
F P
s
P
p
.002 w
.45806 .40911 m .4748 .40134 L .45983 .37803 L p
1 g
F P
s
P
p
.002 w
.4748 .40134 m .48871 .3891 L .46691 .37178 L p
1 g
F P
s
P
p
.002 w
.46691 .37178 m .45983 .37803 L .4748 .40134 L p
1 g
F P
s
P
p
.002 w
.44301 .49686 m .4836 .49051 L .47437 .46387 L p
1 g
F P
s
P
p
.002 w
.47437 .46387 m .44061 .46897 L .44301 .49686 L p
1 g
F P
s
P
p
.002 w
.48871 .3891 m .49835 .37365 L .47179 .36389 L p
1 g
F P
s
P
p
.002 w
.47179 .36389 m .46691 .37178 L .48871 .3891 L p
1 g
F P
s
P
p
.002 w
.45806 .40911 m .4402 .41161 L .43967 .44038 L p
1 g
F P
s
P
p
.002 w
.4402 .41161 m .45806 .40911 L .45129 .38197 L p
1 g
F P
s
P
p
.002 w
.45983 .37803 m .45129 .38197 L .45806 .40911 L p
1 g
F P
s
P
p
.002 w
.49334 .51597 m .53671 .49536 L .52149 .47259 L p
1 g
F P
s
P
p
.002 w
.52149 .47259 m .4836 .49051 L .49334 .51597 L p
1 g
F P
s
P
p
.002 w
.55315 .44492 m .52149 .47259 L .53671 .49536 L p
1 g
F P
s
P
p
.002 w
.53139 .35972 m .52482 .38474 L .55071 .39694 L p
1 g
F P
s
P
p
.002 w
.52482 .38474 m .53139 .35972 L .50271 .35655 L p
1 g
F P
s
P
p
.002 w
.50271 .35655 m .49835 .37365 L .52482 .38474 L p
1 g
F P
s
P
p
.002 w
.53671 .49536 m .57301 .46369 L .55315 .44492 L p
1 g
F P
s
P
p
.002 w
.57554 .41006 m .55315 .44492 L .57301 .46369 L p
1 g
F P
s
P
p
.002 w
.55315 .44492 m .57554 .41006 L .55071 .39694 L p
1 g
F P
s
P
p
.002 w
.49835 .37365 m .50271 .35655 L .47394 .35519 L p
1 g
F P
s
P
p
.002 w
.47394 .35519 m .47179 .36389 L .49835 .37365 L p
1 g
F P
s
P
p
.002 w
.55945 .36464 m .55071 .39694 L .57554 .41006 L p
1 g
F P
s
P
p
.002 w
.55071 .39694 m .55945 .36464 L .53139 .35972 L p
1 g
F P
s
P
p
.002 w
.40796 .46365 m .44061 .46897 L .43967 .44038 L p
1 g
F P
s
P
p
.002 w
.43967 .44038 m .41448 .43606 L .40796 .46365 L p
1 g
F P
s
P
p
.002 w
.41448 .43606 m .43967 .44038 L .4402 .41161 L p
1 g
F P
s
P
p
.002 w
.44685 .5235 m .49334 .51597 L .4836 .49051 L p
1 g
F P
s
P
p
.002 w
.4836 .49051 m .44301 .49686 L .44685 .5235 L p
1 g
F P
s
P
p
.002 w
.4402 .41161 m .42305 .40853 L .41448 .43606 L p
1 g
F P
s
P
p
.002 w
.42305 .40853 m .4402 .41161 L .44219 .3832 L p
1 g
F P
s
P
p
.002 w
.45129 .38197 m .44219 .3832 L .4402 .41161 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .45129 .38197 L .45983 .37803 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .45983 .37803 L .46691 .37178 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .46691 .37178 L .47179 .36389 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .44219 .3832 L .45129 .38197 L closepath p
1 g
F P
s
P
p
.002 w
.40363 .49076 m .44301 .49686 L .44061 .46897 L p
1 g
F P
s
P
p
.002 w
.44061 .46897 m .40796 .46365 L .40363 .49076 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .47179 .36389 L .47394 .35519 L closepath p
1 g
F P
s
P
p
.002 w
.50125 .33957 m .50271 .35655 L .53139 .35972 L p
1 g
F P
s
P
p
.002 w
.50271 .35655 m .50125 .33957 L .47311 .34659 L p
1 g
F P
s
P
p
.002 w
.47311 .34659 m .47394 .35519 L .50271 .35655 L p
1 g
F P
s
P
p
.002 w
.50341 .53978 m .55128 .51691 L .53671 .49536 L p
1 g
F P
s
P
p
.002 w
.53671 .49536 m .49334 .51597 L .50341 .53978 L p
1 g
F P
s
P
p
.002 w
.57301 .46369 m .53671 .49536 L .55128 .51691 L p
1 g
F P
s
P
p
.002 w
.44219 .3832 m .4335 .38156 L .42305 .40853 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .4335 .38156 L .44219 .3832 L closepath p
1 g
F P
s
P
p
.002 w
.52949 .33476 m .53139 .35972 L .55945 .36464 L p
1 g
F P
s
P
p
.002 w
.53139 .35972 m .52949 .33476 L .50125 .33957 L p
1 g
F P
s
P
p
.002 w
.57301 .46369 m .59884 .42384 L .57554 .41006 L p
1 g
F P
s
P
p
.002 w
.58634 .37123 m .57554 .41006 L .59884 .42384 L p
1 g
F P
s
P
p
.002 w
.57554 .41006 m .58634 .37123 L .55945 .36464 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .47394 .35519 L .47311 .34659 L closepath p
1 g
F P
s
P
p
.002 w
.39287 .42389 m .41448 .43606 L .42305 .40853 L p
1 g
F P
s
P
p
.002 w
.42305 .40853 m .40843 .40009 L .39287 .42389 L p
1 g
F P
s
P
p
.002 w
.40843 .40009 m .42305 .40853 L .4335 .38156 L p
1 g
F P
s
P
p
.002 w
.55128 .51691 m .59141 .48196 L .57301 .46369 L p
1 g
F P
s
P
p
.002 w
.59884 .42384 m .57301 .46369 L .59141 .48196 L p
1 g
F P
s
P
p
.002 w
.4335 .38156 m .42613 .3772 L .40843 .40009 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42613 .3772 L .4335 .38156 L closepath p
1 g
F P
s
P
p
.002 w
.37977 .44816 m .40796 .46365 L .41448 .43606 L p
1 g
F P
s
P
p
.002 w
.41448 .43606 m .39287 .42389 L .37977 .44816 L p
1 g
F P
s
P
p
.002 w
.4521 .54833 m .50341 .53978 L .49334 .51597 L p
1 g
F P
s
P
p
.002 w
.49334 .51597 m .44685 .5235 L .4521 .54833 L p
1 g
F P
s
P
p
.002 w
.40163 .51685 m .44685 .5235 L .44301 .49686 L p
1 g
F P
s
P
p
.002 w
.44301 .49686 m .40363 .49076 L .40163 .51685 L p
1 g
F P
s
P
p
.002 w
.46937 .33901 m .47311 .34659 L .50125 .33957 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .47311 .34659 L .46937 .33901 L closepath p
1 g
F P
s
P
p
.002 w
.5573 .33227 m .55945 .36464 L .58634 .37123 L p
1 g
F P
s
P
p
.002 w
.55945 .36464 m .5573 .33227 L .52949 .33476 L p
1 g
F P
s
P
p
.002 w
.49402 .32452 m .50125 .33957 L .52949 .33476 L p
1 g
F P
s
P
p
.002 w
.50125 .33957 m .49402 .32452 L .46937 .33901 L p
1 g
F P
s
P
p
.002 w
.39795 .38712 m .40843 .40009 L .42613 .3772 L p
1 g
F P
s
P
p
.002 w
.42613 .3772 m .42091 .37059 L .39795 .38712 L p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42091 .37059 L .42613 .3772 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .44581 .32976 L .4367 .33236 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .4367 .33236 L .42862 .33762 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42862 .33762 L .42247 .34495 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .42247 .34495 L .41895 .35353 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .41895 .35353 L .41842 .3624 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .41842 .3624 L .42091 .37059 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .46937 .33901 L .4631 .3333 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .4631 .3333 L .45495 .33009 L closepath p
1 g
F P
s
P
p
.002 w
.44562 .35566 m .45495 .33009 L .44581 .32976 L closepath p
1 g
F P
s
P
p
.002 w
.37723 .40496 m .39287 .42389 L .40843 .40009 L p
1 g
F P
s
P
p
.002 w
.40843 .40009 m .39795 .38712 L .37723 .40496 L p
1 g
F P
s
P
p
.002 w
.4631 .3333 m .46937 .33901 L .49402 .32452 L p
1 g
F P
s
P
p
.002 w
.36946 .47241 m .40363 .49076 L .40796 .46365 L p
1 g
F P
s
P
p
.002 w
.40796 .46365 m .37977 .44816 L .36946 .47241 L p
1 g
F P
s
P
p
.002 w
.59141 .48196 m .62012 .43805 L .59884 .42384 L p
1 g
F P
s
P
p
.002 w
.61153 .37941 m .59884 .42384 L .62012 .43805 L p
1 g
F P
s
P
p
.002 w
.59884 .42384 m .61153 .37941 L .58634 .37123 L p
1 g
F P
s
P
p
.002 w
.39284 .37094 m .39795 .38712 L .42091 .37059 L p
1 g
F P
s
P
p
.002 w
.42091 .37059 m .41842 .3624 L .39284 .37094 L p
1 g
F P
s
P
p
.002 w
.51911 .3125 m .52949 .33476 L .5573 .33227 L p
1 g
F P
s
P
p
.002 w
.52949 .33476 m .51911 .3125 L .49402 .32452 L p
1 g
F P
s
P
p
.002 w
.51363 .5614 m .56489 .53678 L .55128 .51691 L p
1 g
F P
s
P
p
.002 w
.55128 .51691 m .50341 .53978 L .51363 .5614 L p
1 g
F P
s
P
p
.002 w
.59141 .48196 m .55128 .51691 L .56489 .53678 L p
1 g
F P
s
P
p
.002 w
.49402 .32452 m .48172 .31307 L .4631 .3333 L p
1 g
F P
s
P
p
.002 w
.45495 .33009 m .4631 .3333 L .48172 .31307 L p
1 g
F P
s
P
p
.002 w
.58411 .3322 m .58634 .37123 L .61153 .37941 L p
1 g
F P
s
P
p
.002 w
.58634 .37123 m .58411 .3322 L .5573 .33227 L p
1 g
F P
s
P
p
.002 w
.56489 .53678 m .60795 .49937 L .59141 .48196 L p
1 g
F P
s
P
p
.002 w
.62012 .43805 m .59141 .48196 L .60795 .49937 L p
1 g
F P
s
P
p
.002 w
.48172 .31307 m .49402 .32452 L .51911 .3125 L p
1 g
F P
s
P
p
.002 w
.39376 .35328 m .39284 .37094 L .41842 .3624 L p
1 g
F P
s
P
p
.002 w
.41842 .3624 m .41895 .35353 L .39376 .35328 L p
1 g
F P
s
P
p
.002 w
.40209 .54135 m .4521 .54833 L .44685 .5235 L p
1 g
F P
s
P
p
.002 w
.44685 .5235 m .40163 .51685 L .40209 .54135 L p
1 g
F P
s
P
p
.002 w
.3592 .42378 m .37977 .44816 L .39287 .42389 L p
1 g
F P
s
P
p
.002 w
.39287 .42389 m .37723 .40496 L .3592 .42378 L p
1 g
F P
s
P
p
.002 w
.45868 .57081 m .51363 .5614 L .50341 .53978 L p
1 g
F P
s
P
p
.002 w
.50341 .53978 m .4521 .54833 L .45868 .57081 L p
1 g
F P
s
P
p
.002 w
.48172 .31307 m .46558 .30655 L .45495 .33009 L p
1 g
F P
s
P
p
.002 w
.44581 .32976 m .45495 .33009 L .46558 .30655 L p
1 g
F P
s
P
p
.002 w
.36945 .38114 m .37723 .40496 L .39795 .38712 L p
1 g
F P
s
P
p
.002 w
.39795 .38712 m .39284 .37094 L .36945 .38114 L p
1 g
F P
s
P
p
.002 w
.40071 .33613 m .39376 .35328 L .41895 .35353 L p
1 g
F P
s
P
p
.002 w
.41895 .35353 m .42247 .34495 L .40071 .33613 L p
1 g
F P
s
P
p
.002 w
.36225 .49614 m .40163 .51685 L .40363 .49076 L p
1 g
F P
s
P
p
.002 w
.40363 .49076 m .36946 .47241 L .36225 .49614 L p
1 g
F P
s
P
p
.002 w
.54412 .30324 m .5573 .33227 L .58411 .3322 L p
1 g
F P
s
P
p
.002 w
.5573 .33227 m .54412 .30324 L .51911 .3125 L p
1 g
F P
s
P
p
.002 w
.4367 .33236 m .44581 .32976 L .44737 .30579 L p
1 g
F P
s
P
p
.002 w
.46558 .30655 m .44737 .30579 L .44581 .32976 L p
1 g
F P
s
P
p
.002 w
.41296 .32145 m .40071 .33613 L .42247 .34495 L p
1 g
F P
s
P
p
.002 w
.42247 .34495 m .42862 .33762 L .41296 .32145 L p
1 g
F P
s
P
p
.002 w
.44737 .30579 m .42914 .31093 L .4367 .33236 L p
1 g
F P
s
P
p
.002 w
.42862 .33762 m .4367 .33236 L .42914 .31093 L p
1 g
F P
s
P
p
.002 w
.42914 .31093 m .41296 .32145 L .42862 .33762 L p
1 g
F P
s
P
p
.002 w
.51911 .3125 m .50113 .29542 L .48172 .31307 L p
1 g
F P
s
P
p
.002 w
.46558 .30655 m .48172 .31307 L .50113 .29542 L p
1 g
F P
s
P
p
.002 w
.50113 .29542 m .51911 .3125 L .54412 .30324 L p
1 g
F P
s
P
p
.002 w
.60795 .49937 m .63888 .45242 L .62012 .43805 L p
1 g
F P
s
P
p
.002 w
.63445 .38906 m .62012 .43805 L .63888 .45242 L p
1 g
F P
s
P
p
.002 w
.62012 .43805 m .63445 .38906 L .61153 .37941 L p
1 g
F P
s
P
p
.002 w
.34435 .44322 m .36946 .47241 L .37977 .44816 L p
1 g
F P
s
P
p
.002 w
.37977 .44816 m .3592 .42378 L .34435 .44322 L p
1 g
F P
s
P
p
.002 w
.37063 .35499 m .36945 .38114 L .39284 .37094 L p
1 g
F P
s
P
p
.002 w
.39284 .37094 m .39376 .35328 L .37063 .35499 L p
1 g
F P
s
P
p
.002 w
.60936 .33462 m .61153 .37941 L .63445 .38906 L p
1 g
F P
s
P
p
.002 w
.61153 .37941 m .60936 .33462 L .58411 .3322 L p
1 g
F P
s
P
p
.002 w
.52379 .5803 m .57725 .55453 L .56489 .53678 L p
1 g
F P
s
P
p
.002 w
.56489 .53678 m .51363 .5614 L .52379 .5803 L p
1 g
F P
s
P
p
.002 w
.60795 .49937 m .56489 .53678 L .57725 .55453 L p
1 g
F P
s
P
p
.002 w
.34881 .39286 m .3592 .42378 L .37723 .40496 L p
1 g
F P
s
P
p
.002 w
.37723 .40496 m .36945 .38114 L .34881 .39286 L p
1 g
F P
s
P
p
.002 w
.40507 .56367 m .45868 .57081 L .4521 .54833 L p
1 g
F P
s
P
p
.002 w
.4521 .54833 m .40209 .54135 L .40507 .56367 L p
1 g
F P
s
P
p
.002 w
.57725 .55453 m .62222 .51552 L .60795 .49937 L p
1 g
F P
s
P
p
.002 w
.63888 .45242 m .60795 .49937 L .62222 .51552 L p
1 g
F P
s
P
p
.002 w
.50113 .29542 m .47734 .28559 L .46558 .30655 L p
1 g
F P
s
P
p
.002 w
.44737 .30579 m .46558 .30655 L .47734 .28559 L p
1 g
F P
s
P
p
.002 w
.56856 .29701 m .58411 .3322 L .60936 .33462 L p
1 g
F P
s
P
p
.002 w
.58411 .3322 m .56856 .29701 L .54412 .30324 L p
1 g
F P
s
P
p
.002 w
.35839 .51882 m .40209 .54135 L .40163 .51685 L p
1 g
F P
s
P
p
.002 w
.40163 .51685 m .36225 .49614 L .35839 .51882 L p
1 g
F P
s
P
p
.002 w
.38085 .32946 m .37063 .35499 L .39376 .35328 L p
1 g
F P
s
P
p
.002 w
.39376 .35328 m .40071 .33613 L .38085 .32946 L p
1 g
F P
s
P
p
.002 w
.46653 .59035 m .52379 .5803 L .51363 .5614 L p
1 g
F P
s
P
p
.002 w
.51363 .5614 m .45868 .57081 L .46653 .59035 L p
1 g
F P
s
P
p
.002 w
.52095 .28081 m .54412 .30324 L .56856 .29701 L p
1 g
F P
s
P
p
.002 w
.54412 .30324 m .52095 .28081 L .50113 .29542 L p
1 g
F P
s
P
p
.002 w
.47734 .28559 m .50113 .29542 L .52095 .28081 L p
1 g
F P
s
P
p
.002 w
.42914 .31093 m .44737 .30579 L .45032 .28431 L p
1 g
F P
s
P
p
.002 w
.47734 .28559 m .45032 .28431 L .44737 .30579 L p
1 g
F P
s
P
p
.002 w
.39905 .30756 m .38085 .32946 L .40071 .33613 L p
1 g
F P
s
P
p
.002 w
.40071 .33613 m .41296 .32145 L .39905 .30756 L p
1 g
F P
s
P
p
.002 w
.33312 .46286 m .36225 .49614 L .36946 .47241 L p
1 g
F P
s
P
p
.002 w
.36946 .47241 m .34435 .44322 L .33312 .46286 L p
1 g
F P
s
P
p
.002 w
.45032 .28431 m .42316 .2919 L .42914 .31093 L p
1 g
F P
s
P
p
.002 w
.41296 .32145 m .42914 .31093 L .42316 .2919 L p
1 g
F P
s
P
p
.002 w
.42316 .2919 m .39905 .30756 L .41296 .32145 L p
1 g
F P
s
P
p
.002 w
.35014 .3587 m .34881 .39286 L .36945 .38114 L p
1 g
F P
s
P
p
.002 w
.36945 .38114 m .37063 .35499 L .35014 .3587 L p
1 g
F P
s
P
p
.002 w
.62222 .51552 m .65465 .46664 L .63888 .45242 L p
1 g
F P
s
P
p
.002 w
.65454 .40002 m .63888 .45242 L .65465 .46664 L p
1 g
F P
s
P
p
.002 w
.63888 .45242 m .65454 .40002 L .63445 .38906 L p
1 g
F P
s
P
p
.002 w
.63244 .33955 m .63445 .38906 L .65454 .40002 L p
1 g
F P
s
P
p
.002 w
.63445 .38906 m .63244 .33955 L .60936 .33462 L p
1 g
F P
s
P
p
.002 w
.33148 .4059 m .34435 .44322 L .3592 .42378 L p
1 g
F P
s
P
p
.002 w
.3592 .42378 m .34881 .39286 L .33148 .4059 L p
1 g
F P
s
P
p
.002 w
.59186 .29405 m .60936 .33462 L .63244 .33955 L p
1 g
F P
s
P
p
.002 w
.60936 .33462 m .59186 .29405 L .56856 .29701 L p
1 g
F P
s
P
p
.002 w
.53368 .59596 m .58802 .56967 L .57725 .55453 L p
1 g
F P
s
P
p
.002 w
.57725 .55453 m .52379 .5803 L .53368 .59596 L p
1 g
F P
s
P
p
.002 w
.62222 .51552 m .57725 .55453 L .58802 .56967 L p
1 g
F P
s
P
p
.002 w
.41063 .58321 m .46653 .59035 L .45868 .57081 L p
1 g
F P
s
P
p
.002 w
.45868 .57081 m .40507 .56367 L .41063 .58321 L p
1 g
F P
s
P
p
.002 w
.52095 .28081 m .49001 .26776 L .47734 .28559 L p
1 g
F P
s
P
p
.002 w
.45032 .28431 m .47734 .28559 L .49001 .26776 L p
1 g
F P
s
P
p
.002 w
.35813 .53988 m .40507 .56367 L .40209 .54135 L p
1 g
F P
s
P
p
.002 w
.40209 .54135 m .35839 .51882 L .35813 .53988 L p
1 g
F P
s
P
p
.002 w
.58802 .56967 m .6338 .53 L .62222 .51552 L p
1 g
F P
s
P
p
.002 w
.65465 .46664 m .62222 .51552 L .6338 .53 L p
1 g
F P
s
P
p
.002 w
.3634 .32519 m .35014 .3587 L .37063 .35499 L p
1 g
F P
s
P
p
.002 w
.37063 .35499 m .38085 .32946 L .3634 .32519 L p
1 g
F P
s
P
p
.002 w
.54078 .26965 m .56856 .29701 L .59186 .29405 L p
1 g
F P
s
P
p
.002 w
.56856 .29701 m .54078 .26965 L .52095 .28081 L p
1 g
F P
s
P
p
.002 w
.49001 .26776 m .52095 .28081 L .54078 .26965 L p
1 g
F P
s
P
p
.002 w
.47551 .60636 m .53368 .59596 L .52379 .5803 L p
1 g
F P
s
P
p
.002 w
.52379 .5803 m .46653 .59035 L .47551 .60636 L p
1 g
F P
s
P
p
.002 w
.32593 .48227 m .35839 .51882 L .36225 .49614 L p
1 g
F P
s
P
p
.002 w
.36225 .49614 m .33312 .46286 L .32593 .48227 L p
1 g
F P
s
P
p
.002 w
.42316 .2919 m .45032 .28431 L .45465 .26592 L p
1 g
F P
s
P
p
.002 w
.49001 .26776 m .45465 .26592 L .45032 .28431 L p
1 g
F P
s
P
p
.002 w
.33288 .36441 m .33148 .4059 L .34881 .39286 L p
1 g
F P
s
P
p
.002 w
.34881 .39286 m .35014 .3587 L .33288 .36441 L p
1 g
F P
s
P
p
.002 w
.31802 .42002 m .33312 .46286 L .34435 .44322 L p
1 g
F P
s
P
p
.002 w
.34435 .44322 m .33148 .4059 L .31802 .42002 L p
1 g
F P
s
P
p
.002 w
.38727 .29639 m .3634 .32519 L .38085 .32946 L p
1 g
F P
s
P
p
.002 w
.38085 .32946 m .39905 .30756 L .38727 .29639 L p
1 g
F P
s
P
p
.002 w
.65465 .46664 m .67124 .41211 L .65454 .40002 L p
1 g
F P
s
P
p
.002 w
.65276 .347 m .65454 .40002 L .67124 .41211 L p
1 g
F P
s
P
p
.002 w
.65454 .40002 m .65276 .347 L .63244 .33955 L p
1 g
F P
s
P
p
.002 w
.45465 .26592 m .41897 .27581 L .42316 .2919 L p
1 g
F P
s
P
p
.002 w
.39905 .30756 m .42316 .2919 L .41897 .27581 L p
1 g
F P
s
P
p
.002 w
.6338 .53 m .66691 .4804 L .65465 .46664 L p
1 g
F P
s
P
p
.002 w
.67124 .41211 m .65465 .46664 L .66691 .4804 L p
1 g
F P
s
P
p
.002 w
.41897 .27581 m .38727 .29639 L .39905 .30756 L p
1 g
F P
s
P
p
.002 w
.61346 .29458 m .63244 .33955 L .65276 .347 L p
1 g
F P
s
P
p
.002 w
.63244 .33955 m .61346 .29458 L .59186 .29405 L p
1 g
F P
s
P
p
.002 w
.54078 .26965 m .50336 .2536 L .49001 .26776 L p
1 g
F P
s
P
p
.002 w
.45465 .26592 m .49001 .26776 L .50336 .2536 L p
1 g
F P
s
P
p
.002 w
.41876 .59937 m .47551 .60636 L .46653 .59035 L p
1 g
F P
s
P
p
.002 w
.46653 .59035 m .41063 .58321 L .41876 .59937 L p
1 g
F P
s
P
p
.002 w
.36164 .55874 m .41063 .58321 L .40507 .56367 L p
1 g
F P
s
P
p
.002 w
.40507 .56367 m .35813 .53988 L .36164 .55874 L p
1 g
F P
s
P
p
.002 w
.56015 .26236 m .59186 .29405 L .61346 .29458 L p
1 g
F P
s
P
p
.002 w
.59186 .29405 m .56015 .26236 L .54078 .26965 L p
1 g
F P
s
P
p
.002 w
.54305 .60784 m .59688 .58171 L .58802 .56967 L p
1 g
F P
s
P
p
.002 w
.58802 .56967 m .53368 .59596 L .54305 .60784 L p
1 g
F P
s
P
p
.002 w
.6338 .53 m .58802 .56967 L .59688 .58171 L p
1 g
F P
s
P
p
.002 w
.50336 .2536 m .54078 .26965 L .56015 .26236 L p
1 g
F P
s
P
p
.002 w
.34892 .32355 m .33288 .36441 L .35014 .3587 L p
1 g
F P
s
P
p
.002 w
.35014 .3587 m .3634 .32519 L .34892 .32355 L p
1 g
F P
s
P
p
.002 w
.59688 .58171 m .64229 .54241 L .6338 .53 L p
1 g
F P
s
P
p
.002 w
.66691 .4804 m .6338 .53 L .64229 .54241 L p
1 g
F P
s
P
p
.002 w
.32315 .50096 m .35813 .53988 L .35839 .51882 L p
1 g
F P
s
P
p
.002 w
.35839 .51882 m .32593 .48227 L .32315 .50096 L p
1 g
F P
s
P
p
.002 w
.48548 .61829 m .54305 .60784 L .53368 .59596 L p
1 g
F P
s
P
p
.002 w
.53368 .59596 m .47551 .60636 L .48548 .61829 L p
1 g
F P
s
P
p
.002 w
.30897 .43492 m .32593 .48227 L .33312 .46286 L p
1 g
F P
s
P
p
.002 w
.33312 .46286 m .31802 .42002 L .30897 .43492 L p
1 g
F P
s
P
p
.002 w
.31944 .37211 m .31802 .42002 L .33148 .4059 L p
1 g
F P
s
P
p
.002 w
.33148 .4059 m .33288 .36441 L .31944 .37211 L p
1 g
F P
s
P
p
.002 w
.41897 .27581 m .45465 .26592 L .46034 .25121 L p
1 g
F P
s
P
p
.002 w
.50336 .2536 m .46034 .25121 L .45465 .26592 L p
1 g
F P
s
P
p
.002 w
.66691 .4804 m .68399 .4251 L .67124 .41211 L p
1 g
F P
s
P
p
.002 w
.66971 .3569 m .67124 .41211 L .68399 .4251 L p
1 g
F P
s
P
p
.002 w
.67124 .41211 m .66971 .3569 L .65276 .347 L p
1 g
F P
s
P
p
.002 w
.37803 .28834 m .34892 .32355 L .3634 .32519 L p
1 g
F P
s
P
p
.002 w
.3634 .32519 m .38727 .29639 L .37803 .28834 L p
1 g
F P
s
P
p
.002 w
.63276 .29874 m .65276 .347 L .66971 .3569 L p
1 g
F P
s
P
p
.002 w
.65276 .347 m .63276 .29874 L .61346 .29458 L p
1 g
F P
s
P
p
.002 w
.64229 .54241 m .6752 .49335 L .66691 .4804 L p
1 g
F P
s
P
p
.002 w
.68399 .4251 m .66691 .4804 L .6752 .49335 L p
1 g
F P
s
P
p
.002 w
.46034 .25121 m .41677 .2632 L .41897 .27581 L p
1 g
F P
s
P
p
.002 w
.38727 .29639 m .41897 .27581 L .41677 .2632 L p
1 g
F P
s
P
p
.002 w
.41677 .2632 m .37803 .28834 L .38727 .29639 L p
1 g
F P
s
P
p
.002 w
.36904 .57479 m .41876 .59937 L .41063 .58321 L p
1 g
F P
s
P
p
.002 w
.41063 .58321 m .36164 .55874 L .36904 .57479 L p
1 g
F P
s
P
p
.002 w
.56015 .26236 m .5171 .24364 L .50336 .2536 L p
1 g
F P
s
P
p
.002 w
.46034 .25121 m .50336 .2536 L .5171 .24364 L p
1 g
F P
s
P
p
.002 w
.57859 .25931 m .61346 .29458 L .63276 .29874 L p
1 g
F P
s
P
p
.002 w
.61346 .29458 m .57859 .25931 L .56015 .26236 L p
1 g
F P
s
P
p
.002 w
.4294 .61156 m .48548 .61829 L .47551 .60636 L p
1 g
F P
s
P
p
.002 w
.47551 .60636 m .41876 .59937 L .4294 .61156 L p
1 g
F P
s
P
p
.002 w
.5171 .24364 m .56015 .26236 L .57859 .25931 L p
1 g
F P
s
P
p
.002 w
.3251 .51841 m .36164 .55874 L .35813 .53988 L p
1 g
F P
s
P
p
.002 w
.35813 .53988 m .32315 .50096 L .3251 .51841 L p
1 g
F P
s
P
p
.002 w
.55163 .61543 m .60351 .59019 L .59688 .58171 L p
1 g
F P
s
P
p
.002 w
.59688 .58171 m .54305 .60784 L .55163 .61543 L p
1 g
F P
s
P
p
.002 w
.64229 .54241 m .59688 .58171 L .60351 .59019 L p
1 g
F P
s
P
p
.002 w
.33793 .32474 m .31944 .37211 L .33288 .36441 L p
1 g
F P
s
P
p
.002 w
.33288 .36441 m .34892 .32355 L .33793 .32474 L p
1 g
F P
s
P
p
.002 w
.60351 .59019 m .64731 .55232 L .64229 .54241 L p
1 g
F P
s
P
p
.002 w
.6752 .49335 m .64229 .54241 L .64731 .55232 L p
1 g
F P
s
P
p
.002 w
.3048 .45027 m .32315 .50096 L .32593 .48227 L p
1 g
F P
s
P
p
.002 w
.32593 .48227 m .30897 .43492 L .3048 .45027 L p
1 g
F P
s
P
p
.002 w
.3104 .38171 m .30897 .43492 L .31802 .42002 L p
1 g
F P
s
P
p
.002 w
.31802 .42002 m .31944 .37211 L .3104 .38171 L p
1 g
F P
s
P
p
.002 w
.49625 .62558 m .55163 .61543 L .54305 .60784 L p
1 g
F P
s
P
p
.002 w
.54305 .60784 m .48548 .61829 L .49625 .62558 L p
1 g
F P
s
P
p
.002 w
.5171 .24364 m .46732 .24074 L .46034 .25121 L p
1 g
F P
s
P
p
.002 w
.41677 .2632 m .46034 .25121 L .46732 .24074 L p
1 g
F P
s
P
p
.002 w
.6752 .49335 m .69225 .43873 L .68399 .4251 L p
1 g
F P
s
P
p
.002 w
.68268 .36915 m .68399 .4251 L .69225 .43873 L p
1 g
F P
s
P
p
.002 w
.68399 .4251 m .68268 .36915 L .66971 .3569 L p
1 g
F P
s
P
p
.002 w
.64915 .30661 m .66971 .3569 L .68268 .36915 L p
1 g
F P
s
P
p
.002 w
.66971 .3569 m .64915 .30661 L .63276 .29874 L p
1 g
F P
s
P
p
.002 w
.37171 .28381 m .33793 .32474 L .34892 .32355 L p
1 g
F P
s
P
p
.002 w
.34892 .32355 m .37803 .28834 L .37171 .28381 L p
1 g
F P
s
P
p
.002 w
.64731 .55232 m .67907 .50511 L .6752 .49335 L p
1 g
F P
s
P
p
.002 w
.69225 .43873 m .6752 .49335 L .67907 .50511 L p
1 g
F P
s
P
p
.002 w
.46732 .24074 m .41674 .2546 L .41677 .2632 L p
1 g
F P
s
P
p
.002 w
.37803 .28834 m .41677 .2632 L .41674 .2546 L p
1 g
F P
s
P
p
.002 w
.59557 .26079 m .63276 .29874 L .64915 .30661 L p
1 g
F P
s
P
p
.002 w
.63276 .29874 m .59557 .26079 L .57859 .25931 L p
1 g
F P
s
P
p
.002 w
.41674 .2546 m .37171 .28381 L .37803 .28834 L p
1 g
F P
s
P
p
.002 w
.38035 .58745 m .4294 .61156 L .41876 .59937 L p
1 g
F P
s
P
p
.002 w
.41876 .59937 m .36904 .57479 L .38035 .58745 L p
1 g
F P
s
P
p
.002 w
.57859 .25931 m .5309 .23837 L .5171 .24364 L p
1 g
F P
s
P
p
.002 w
.46732 .24074 m .5171 .24364 L .5309 .23837 L p
1 g
F P
s
P
p
.002 w
.4424 .61922 m .49625 .62558 L .48548 .61829 L p
1 g
F P
s
P
p
.002 w
.48548 .61829 m .4294 .61156 L .4424 .61922 L p
1 g
F P
s
P
p
.002 w
.5309 .23837 m .57859 .25931 L .59557 .26079 L p
1 g
F P
s
P
p
.002 w
.33198 .53408 m .36904 .57479 L .36164 .55874 L p
1 g
F P
s
P
p
.002 w
.36164 .55874 m .3251 .51841 L .33198 .53408 L p
1 g
F P
s
P
p
.002 w
.33094 .32889 m .3104 .38171 L .31944 .37211 L p
1 g
F P
s
P
p
.002 w
.31944 .37211 m .33793 .32474 L .33094 .32889 L p
1 g
F P
s
P
p
.002 w
.55917 .61825 m .60759 .59467 L .60351 .59019 L p
1 g
F P
s
P
p
.002 w
.60351 .59019 m .55163 .61543 L .55917 .61825 L p
1 g
F P
s
P
p
.002 w
.64731 .55232 m .60351 .59019 L .60759 .59467 L p
1 g
F P
s
P
p
.002 w
.3059 .46567 m .3251 .51841 L .32315 .50096 L p
1 g
F P
s
P
p
.002 w
.32315 .50096 m .3048 .45027 L .3059 .46567 L p
1 g
F P
s
P
p
.002 w
.30627 .39307 m .3048 .45027 L .30897 .43492 L p
1 g
F P
s
P
p
.002 w
.30897 .43492 m .3104 .38171 L .30627 .39307 L p
1 g
F P
s
P
p
.002 w
.60759 .59467 m .6485 .55931 L .64731 .55232 L p
1 g
F P
s
P
p
.002 w
.67907 .50511 m .64731 .55232 L .6485 .55931 L p
1 g
F P
s
P
p
.002 w
.50756 .62775 m .55917 .61825 L .55163 .61543 L p
1 g
F P
s
P
p
.002 w
.55163 .61543 m .49625 .62558 L .50756 .62775 L p
1 g
F P
s
P
p
.002 w
.67907 .50511 m .69556 .45266 L .69225 .43873 L p
1 g
F P
s
P
p
.002 w
.69112 .38354 m .69225 .43873 L .69556 .45266 L p
1 g
F P
s
P
p
.002 w
.69225 .43873 m .69112 .38354 L .68268 .36915 L p
1 g
F P
s
P
p
.002 w
.5309 .23837 m .47549 .23506 L .46732 .24074 L p
1 g
F P
s
P
p
.002 w
.41674 .2546 m .46732 .24074 L .47549 .23506 L p
1 g
F P
s
P
p
.002 w
.66203 .31819 m .68268 .36915 L .69112 .38354 L p
1 g
F P
s
P
p
.002 w
.68268 .36915 m .66203 .31819 L .64915 .30661 L p
1 g
F P
s
P
p
.002 w
.36867 .28316 m .33094 .32889 L .33793 .32474 L p
1 g
F P
s
P
p
.002 w
.33793 .32474 m .37171 .28381 L .36867 .28316 L p
1 g
F P
s
P
p
.002 w
.61055 .26703 m .64915 .30661 L .66203 .31819 L p
1 g
F P
s
P
p
.002 w
.64915 .30661 m .61055 .26703 L .59557 .26079 L p
1 g
F P
s
P
p
.002 w
.6485 .55931 m .67816 .5153 L .67907 .50511 L p
1 g
F P
s
P
p
.002 w
.69556 .45266 m .67907 .50511 L .67816 .5153 L p
1 g
F P
s
P
p
.002 w
.39546 .59617 m .4424 .61922 L .4294 .61156 L p
1 g
F P
s
P
p
.002 w
.4294 .61156 m .38035 .58745 L .39546 .59617 L p
1 g
F P
s
P
p
.002 w
.59557 .26079 m .5444 .23821 L .5309 .23837 L p
1 g
F P
s
P
p
.002 w
.47549 .23506 m .5309 .23837 L .5444 .23821 L p
1 g
F P
s
P
p
.002 w
.47549 .23506 m .41901 .2505 L .41674 .2546 L p
1 g
F P
s
P
p
.002 w
.37171 .28381 m .41674 .2546 L .41901 .2505 L p
1 g
F P
s
P
p
.002 w
.5444 .23821 m .59557 .26079 L .61055 .26703 L p
1 g
F P
s
P
p
.002 w
.34389 .54741 m .38035 .58745 L .36904 .57479 L p
1 g
F P
s
P
p
.002 w
.36904 .57479 m .33198 .53408 L .34389 .54741 L p
1 g
F P
s
P
p
.002 w
.41901 .2505 m .36867 .28316 L .37171 .28381 L p
1 g
F P
s
P
p
.002 w
.45755 .62186 m .50756 .62775 L .49625 .62558 L p
1 g
F P
s
P
p
.002 w
.49625 .62558 m .4424 .61922 L .45755 .62186 L p
1 g
F P
s
P
p
.002 w
.31257 .48068 m .33198 .53408 L .3251 .51841 L p
1 g
F P
s
P
p
.002 w
.3251 .51841 m .3059 .46567 L .31257 .48068 L p
1 g
F P
s
P
p
.002 w
.32843 .33609 m .30627 .39307 L .3104 .38171 L p
1 g
F P
s
P
p
.002 w
.3104 .38171 m .33094 .32889 L .32843 .33609 L p
1 g
F P
s
P
p
.002 w
.30747 .40596 m .3059 .46567 L .3048 .45027 L p
1 g
F P
s
P
p
.002 w
.3048 .45027 m .30627 .39307 L .30747 .40596 L p
1 g
F P
s
P
p
.002 w
.56536 .61593 m .60884 .59476 L .60759 .59467 L p
1 g
F P
s
P
p
.002 w
.60759 .59467 m .55917 .61825 L .56536 .61593 L p
1 g
F P
s
P
p
.002 w
.6485 .55931 m .60759 .59467 L .60884 .59476 L p
1 g
F P
s
P
p
.002 w
.60884 .59476 m .64558 .563 L .6485 .55931 L p
1 g
F P
s
P
p
.002 w
.67816 .5153 m .6485 .55931 L .64558 .563 L p
1 g
F P
s
P
p
.002 w
.69556 .45266 m .69453 .3998 L .69112 .38354 L p
1 g
F P
s
P
p
.002 w
.69112 .38354 m .67085 .33337 L .66203 .31819 L p
1 g
F P
s
P
p
.002 w
.67085 .33337 m .69112 .38354 L .69453 .3998 L p
1 g
F P
s
P
p
.002 w
.67816 .5153 m .69352 .46653 L .69556 .45266 L p
1 g
F P
s
P
p
.002 w
.69453 .3998 m .69556 .45266 L .69352 .46653 L p
1 g
F P
s
P
p
.002 w
.51913 .62443 m .56536 .61593 L .55917 .61825 L p
1 g
F P
s
P
p
.002 w
.55917 .61825 m .50756 .62775 L .51913 .62443 L p
1 g
F P
s
P
p
.002 w
.5444 .23821 m .4847 .23463 L .47549 .23506 L p
1 g
F P
s
P
p
.002 w
.41901 .2505 m .47549 .23506 L .4847 .23463 L p
1 g
F P
s
P
p
.002 w
.66203 .31819 m .62299 .27813 L .61055 .26703 L p
1 g
F P
s
P
p
.002 w
.62299 .27813 m .66203 .31819 L .67085 .33337 L p
1 g
F P
s
P
p
.002 w
.36923 .28666 m .32843 .33609 L .33094 .32889 L p
1 g
F P
s
P
p
.002 w
.33094 .32889 m .36867 .28316 L .36923 .28666 L p
1 g
F P
s
P
p
.002 w
.41414 .60046 m .45755 .62186 L .4424 .61922 L p
1 g
F P
s
P
p
.002 w
.4424 .61922 m .39546 .59617 L .41414 .60046 L p
1 g
F P
s
P
p
.002 w
.64558 .563 m .67217 .52354 L .67816 .5153 L p
1 g
F P
s
P
p
.002 w
.69352 .46653 m .67816 .5153 L .67217 .52354 L p
1 g
F P
s
P
p
.002 w
.61055 .26703 m .5572 .24348 L .5444 .23821 L p
1 g
F P
s
P
p
.002 w
.5572 .24348 m .61055 .26703 L .62299 .27813 L p
1 g
F P
s
P
p
.002 w
.36073 .55785 m .39546 .59617 L .38035 .58745 L p
1 g
F P
s
P
p
.002 w
.38035 .58745 m .34389 .54741 L .36073 .55785 L p
1 g
F P
s
P
p
.002 w
.4847 .23463 m .5444 .23821 L .5572 .24348 L p
1 g
F P
s
P
p
.002 w
.4847 .23463 m .42369 .25133 L .41901 .2505 L p
1 g
F P
s
P
p
.002 w
.36867 .28316 m .41901 .2505 L .42369 .25133 L p
1 g
F P
s
P
p
.002 w
.4745 .6191 m .51913 .62443 L .50756 .62775 L p
1 g
F P
s
P
p
.002 w
.50756 .62775 m .45755 .62186 L .4745 .6191 L p
1 g
F P
s
P
p
.002 w
.42369 .25133 m .36923 .28666 L .36867 .28316 L p
1 g
F P
s
P
p
.002 w
.32492 .4948 m .34389 .54741 L .33198 .53408 L p
1 g
F P
s
P
p
.002 w
.33198 .53408 m .31257 .48068 L .32492 .4948 L p
1 g
F P
s
P
p
.002 w
.33075 .34633 m .30747 .40596 L .30627 .39307 L p
1 g
F P
s
P
p
.002 w
.30627 .39307 m .32843 .33609 L .33075 .34633 L p
1 g
F P
s
P
p
.002 w
.3143 .42008 m .31257 .48068 L .3059 .46567 L p
1 g
F P
s
P
p
.002 w
.3059 .46567 m .30747 .40596 L .3143 .42008 L p
1 g
F P
s
P
p
.002 w
.56996 .60819 m .60703 .59015 L .60884 .59476 L p
1 g
F P
s
P
p
.002 w
.60884 .59476 m .56536 .61593 L .56996 .60819 L p
1 g
F P
s
P
p
.002 w
.64558 .563 m .60884 .59476 L .60703 .59015 L p
1 g
F P
s
P
p
.002 w
.69352 .46653 m .69253 .41755 L .69453 .3998 L p
1 g
F P
s
P
p
.002 w
.67511 .35189 m .69453 .3998 L .69253 .41755 L p
1 g
F P
s
P
p
.002 w
.69453 .3998 m .67511 .35189 L .67085 .33337 L p
1 g
F P
s
P
p
.002 w
.60703 .59015 m .63837 .56306 L .64558 .563 L p
1 g
F P
s
P
p
.002 w
.67217 .52354 m .64558 .563 L .63837 .56306 L p
1 g
F P
s
P
p
.002 w
.67217 .52354 m .68587 .47994 L .69352 .46653 L p
1 g
F P
s
P
p
.002 w
.69253 .41755 m .69352 .46653 L .68587 .47994 L p
1 g
F P
s
P
p
.002 w
.53063 .61537 m .56996 .60819 L .56536 .61593 L p
1 g
F P
s
P
p
.002 w
.56536 .61593 m .51913 .62443 L .53063 .61537 L p
1 g
F P
s
P
p
.002 w
.63238 .29402 m .67085 .33337 L .67511 .35189 L p
1 g
F P
s
P
p
.002 w
.67085 .33337 m .63238 .29402 L .62299 .27813 L p
1 g
F P
s
P
p
.004 w
.66333 .28778 m
.67671 .27609 L
s
P
p
.002 w
.5572 .24348 m .49475 .2398 L .4847 .23463 L p
1 g
F P
s
P
p
.002 w
.42369 .25133 m .4847 .23463 L .49475 .2398 L p
1 g
F P
s
P
p
.002 w
.43599 .59993 m .4745 .6191 L .45755 .62186 L p
1 g
F P
s
P
p
.002 w
.45755 .62186 m .41414 .60046 L .43599 .59993 L p
1 g
F P
s
P
p
.002 w
.38224 .56493 m .41414 .60046 L .39546 .59617 L p
1 g
F P
s
P
p
.002 w
.39546 .59617 m .36073 .55785 L .38224 .56493 L p
1 g
F P
s
P
p
.002 w
.3736 .29449 m .33075 .34633 L .32843 .33609 L p
1 g
F P
s
P
p
.002 w
.32843 .33609 m .36923 .28666 L .3736 .29449 L p
1 g
F P
s
P
p
.002 w
.56886 .25434 m .62299 .27813 L .63238 .29402 L p
1 g
F P
s
P
p
.002 w
.62299 .27813 m .56886 .25434 L .5572 .24348 L p
1 g
F P
s
P
p
.002 w
.63837 .56306 m .66098 .52943 L .67217 .52354 L p
1 g
F P
s
P
p
.002 w
.68587 .47994 m .67217 .52354 L .66098 .52943 L p
1 g
F P
s
P
p
.002 w
.49475 .2398 m .5572 .24348 L .56886 .25434 L p
1 g
F P
s
P
p
.002 w
.34287 .50753 m .36073 .55785 L .34389 .54741 L p
1 g
F P
s
P
p
.002 w
.34389 .54741 m .32492 .4948 L .34287 .50753 L p
1 g
F P
s
P
p
.002 w
.49283 .61073 m .53063 .61537 L .51913 .62443 L p
1 g
F P
s
P
p
.002 w
.51913 .62443 m .4745 .6191 L .49283 .61073 L p
1 g
F P
s
P
p
.002 w
.49475 .2398 m .43077 .25739 L .42369 .25133 L p
1 g
F P
s
P
p
.002 w
.36923 .28666 m .42369 .25133 L .43077 .25739 L p
1 g
F P
s
P
p
.002 w
.43077 .25739 m .3736 .29449 L .36923 .28666 L p
1 g
F P
s
P
p
.002 w
.33814 .35946 m .3143 .42008 L .30747 .40596 L p
1 g
F P
s
P
p
.002 w
.30747 .40596 m .33075 .34633 L .33814 .35946 L p
1 g
F P
s
P
p
.002 w
.32687 .43505 m .32492 .4948 L .31257 .48068 L p
1 g
F P
s
P
p
.002 w
.31257 .48068 m .3143 .42008 L .32687 .43505 L p
1 g
F P
s
P
p
.002 w
.68587 .47994 m .68486 .43633 L .69253 .41755 L p
1 g
F P
s
P
p
.002 w
.67443 .37336 m .69253 .41755 L .68486 .43633 L p
1 g
F P
s
P
p
.002 w
.69253 .41755 m .67443 .37336 L .67511 .35189 L p
1 g
F P
s
P
p
.002 w
.66098 .52943 m .67251 .49242 L .68587 .47994 L p
1 g
F P
s
P
p
.002 w
.68486 .43633 m .68587 .47994 L .67251 .49242 L p
1 g
F P
s
P
p
.002 w
.5727 .59492 m .60202 .58068 L .60703 .59015 L p
1 g
F P
s
P
p
.002 w
.60703 .59015 m .56996 .60819 L .5727 .59492 L p
1 g
F P
s
P
p
.002 w
.63837 .56306 m .60703 .59015 L .60202 .58068 L p
1 g
F P
s
P
p
.002 w
.63823 .31448 m .67511 .35189 L .67443 .37336 L p
1 g
F P
s
P
p
.002 w
.67511 .35189 m .63823 .31448 L .63238 .29402 L p
1 g
F P
s
P
p
.004 w
.65076 .29877 m
.66333 .28778 L
s
P
p
.002 w
.60202 .58068 m .6268 .55924 L .63837 .56306 L p
1 g
F P
s
P
p
.002 w
.66098 .52943 m .63837 .56306 L .6268 .55924 L p
1 g
F P
s
P
p
.002 w
.54167 .6005 m .5727 .59492 L .56996 .60819 L p
1 g
F P
s
P
p
.002 w
.56996 .60819 m .53063 .61537 L .54167 .6005 L p
1 g
F P
s
P
p
.002 w
.56886 .25434 m .50536 .25077 L .49475 .2398 L p
1 g
F P
s
P
p
.002 w
.43077 .25739 m .49475 .2398 L .50536 .25077 L p
1 g
F P
s
P
p
.002 w
.40794 .56824 m .43599 .59993 L .41414 .60046 L p
1 g
F P
s
P
p
.002 w
.41414 .60046 m .38224 .56493 L .40794 .56824 L p
1 g
F P
s
P
p
.002 w
.46045 .59436 m .49283 .61073 L .4745 .6191 L p
1 g
F P
s
P
p
.002 w
.4745 .6191 m .43599 .59993 L .46045 .59436 L p
1 g
F P
s
P
p
.002 w
.57894 .27079 m .63238 .29402 L .63823 .31448 L p
1 g
F P
s
P
p
.002 w
.63238 .29402 m .57894 .27079 L .56886 .25434 L p
1 g
F P
s
P
p
.002 w
.50536 .25077 m .56886 .25434 L .57894 .27079 L p
1 g
F P
s
P
p
.002 w
.3819 .30667 m .33814 .35946 L .33075 .34633 L p
1 g
F P
s
P
p
.002 w
.33075 .34633 m .3736 .29449 L .3819 .30667 L p
1 g
F P
s
P
p
.002 w
.6268 .55924 m .6446 .53266 L .66098 .52943 L p
1 g
F P
s
P
p
.002 w
.67251 .49242 m .66098 .52943 L .6446 .53266 L p
1 g
F P
s
P
p
.002 w
.3661 .51838 m .38224 .56493 L .36073 .55785 L p
1 g
F P
s
P
p
.002 w
.36073 .55785 m .34287 .50753 L .3661 .51838 L p
1 g
F P
s
P
p
.002 w
.51201 .59672 m .54167 .6005 L .53063 .61537 L p
1 g
F P
s
P
p
.002 w
.53063 .61537 m .49283 .61073 L .51201 .59672 L p
1 g
F P
s
P
p
.002 w
.34507 .4504 m .34287 .50753 L .32492 .4948 L p
1 g
F P
s
P
p
.002 w
.32492 .4948 m .32687 .43505 L .34507 .4504 L p
1 g
F P
s
P
p
.002 w
.50536 .25077 m .4402 .2688 L .43077 .25739 L p
1 g
F P
s
P
p
.002 w
.3736 .29449 m .43077 .25739 L .4402 .2688 L p
1 g
F P
s
P
p
.002 w
.35065 .37522 m .32687 .43505 L .3143 .42008 L p
1 g
F P
s
P
p
.002 w
.3143 .42008 m .33814 .35946 L .35065 .37522 L p
1 g
F P
s
P
p
.002 w
.4402 .2688 m .3819 .30667 L .3736 .29449 L p
1 g
F P
s
P
p
.002 w
.67251 .49242 m .67147 .45559 L .68486 .43633 L p
1 g
F P
s
P
p
.002 w
.66856 .39723 m .68486 .43633 L .67147 .45559 L p
1 g
F P
s
P
p
.002 w
.68486 .43633 m .66856 .39723 L .67443 .37336 L p
1 g
F P
s
P
p
.002 w
.64017 .33906 m .67443 .37336 L .66856 .39723 L p
1 g
F P
s
P
p
.002 w
.67443 .37336 m .64017 .33906 L .63823 .31448 L p
1 g
F P
s
P
p
.002 w
.6446 .53266 m .65356 .50351 L .67251 .49242 L p
1 g
F P
s
P
p
.002 w
.67147 .45559 m .67251 .49242 L .65356 .50351 L p
1 g
F P
s
P
p
.002 w
.57338 .57623 m .59377 .56636 L .60202 .58068 L p
1 g
F P
s
P
p
.002 w
.60202 .58068 m .5727 .59492 L .57338 .57623 L p
1 g
F P
s
P
p
.002 w
.6268 .55924 m .60202 .58068 L .59377 .56636 L p
1 g
F P
s
P
p
.002 w
.43712 .56749 m .46045 .59436 L .43599 .59993 L p
1 g
F P
s
P
p
.002 w
.43599 .59993 m .40794 .56824 L .43712 .56749 L p
1 g
F P
s
P
p
.002 w
.59377 .56636 m .61099 .55144 L .6268 .55924 L p
1 g
F P
s
P
p
.002 w
.6446 .53266 m .6268 .55924 L .61099 .55144 L p
1 g
F P
s
P
p
.002 w
.58703 .29257 m .63823 .31448 L .64017 .33906 L p
1 g
F P
s
P
p
.002 w
.63823 .31448 m .58703 .29257 L .57894 .27079 L p
1 g
F P
s
P
p
.002 w
.4868 .58371 m .51201 .59672 L .49283 .61073 L p
1 g
F P
s
P
p
.002 w
.49283 .61073 m .46045 .59436 L .4868 .58371 L p
1 g
F P
s
P
p
.002 w
.4402 .2688 m .50536 .25077 L .51621 .26751 L p
1 g
F P
s
P
p
.002 w
.57894 .27079 m .51621 .26751 L .50536 .25077 L p
1 g
F P
s
P
p
.002 w
.55186 .58002 m .57338 .57623 L .5727 .59492 L p
1 g
F P
s
P
p
.002 w
.5727 .59492 m .54167 .6005 L .55186 .58002 L p
1 g
F P
s
P
p
.002 w
.39403 .52686 m .40794 .56824 L .38224 .56493 L p
1 g
F P
s
P
p
.002 w
.38224 .56493 m .3661 .51838 L .39403 .52686 L p
1 g
F P
s
P
p
.002 w
.51621 .26751 m .57894 .27079 L .58703 .29257 L p
1 g
F P
s
P
p
.002 w
.61099 .55144 m .6233 .53296 L .6446 .53266 L p
1 g
F P
s
P
p
.002 w
.65356 .50351 m .6446 .53266 L .6233 .53296 L p
1 g
F P
s
P
p
.002 w
.39407 .32304 m .35065 .37522 L .33814 .35946 L p
1 g
F P
s
P
p
.002 w
.33814 .35946 m .3819 .30667 L .39407 .32304 L p
1 g
F P
s
P
p
.002 w
.5314 .57727 m .55186 .58002 L .54167 .6005 L p
1 g
F P
s
P
p
.002 w
.54167 .6005 m .51201 .59672 L .5314 .57727 L p
1 g
F P
s
P
p
.002 w
.36853 .46562 m .3661 .51838 L .34287 .50753 L p
1 g
F P
s
P
p
.002 w
.34287 .50753 m .34507 .4504 L .36853 .46562 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.65356 .50351 m .65254 .47469 L .67147 .45559 L p
1 g
F P
s
P
p
.002 w
.65748 .4228 m .67147 .45559 L .65254 .47469 L p
1 g
F P
s
P
p
.002 w
.67147 .45559 m .65748 .4228 L .66856 .39723 L p
1 g
F P
s
P
p
.002 w
.36813 .3932 m .34507 .4504 L .32687 .43505 L p
1 g
F P
s
P
p
.002 w
.32687 .43505 m .35065 .37522 L .36813 .3932 L p
1 g
F P
s
P
p
.002 w
.51621 .26751 m .45179 .28552 L .4402 .2688 L p
1 g
F P
s
P
p
.002 w
.3819 .30667 m .4402 .2688 L .45179 .28552 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63795 .36712 m .66856 .39723 L .65748 .4228 L p
1 g
F P
s
P
p
.002 w
.66856 .39723 m .63795 .36712 L .64017 .33906 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45179 .28552 m .39407 .32304 L .3819 .30667 L p
1 g
F P
s
P
p
.002 w
.6233 .53296 m .62937 .51278 L .65356 .50351 L p
1 g
F P
s
P
p
.002 w
.65254 .47469 m .65356 .50351 L .62937 .51278 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46045 .59436 m .46601 .57332 L .47147 .57605 L 1 g
F
P
p
.002 w
.4868 .58371 m .48509 .5844 L p
.47147 .57605 L 1 g
F P
s
P
p
.002 w
.48509 .5844 m .46045 .59436 L p
.47147 .57605 L 1 g
F P
s
P
p
.002 w
.46839 .57416 m .46872 .57265 L p
.46074 .56946 L 1 g
F P
s
P
p
.48921 .57862 m .47854 .57774 L .48311 .57936 L 1 g
F
P
p
.002 w
.49086 .5814 m .4868 .58371 L p
.48822 .5809 L 1 g
F P
s
P
p
.48822 .5809 m .48831 .58073 L .48904 .58092 L 1 g
F
P
p
.48822 .5809 m .48904 .58092 L .49086 .5814 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58092 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58092 L .49156 .581 L 1 g
F
P
p
.51201 .59672 m .49551 .58403 L .51326 .58025 L 1 g
F
P
p
.49551 .58403 m .49156 .581 L .51092 .58033 L 1 g
F
P
p
.49551 .58403 m .51092 .58033 L .51326 .58025 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58033 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58033 L .52106 .57789 L 1 g
F
P
p
.51079 .57862 m .49156 .581 L .50041 .5807 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51201 .59672 m .4868 .58371 L .49156 .581 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.49156 .581 m .51417 .56816 L p
.51326 .58025 L 1 g
F P
s
P
p
.002 w
.5314 .57727 m .51201 .59672 L p
.51329 .57976 L 1 g
F P
s
P
p
.53128 .57265 m .52106 .57789 L .52898 .57599 L 1 g
F
P
p
.002 w
.5314 .57727 m .52968 .57636 L p
.53227 .5748 L 1 g
F P
s
P
p
.002 w
.52968 .57636 m .52898 .57599 L p
.53179 .57498 L 1 g
F P
s
P
p
.52968 .57636 m .53179 .57498 L .53227 .5748 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53179 .57498 L p
1 g
F P
s
P
p
.54854 .56129 m .53179 .57498 L .53464 .5731 L 1 g
F
P
p
.55186 .58002 m .53894 .57483 L .55084 .56191 L 1 g
F
P
p
.53894 .57483 m .53464 .5731 L .54919 .56304 L 1 g
F
P
p
.53894 .57483 m .54919 .56304 L .55084 .56191 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .55457 .55687 L 1 g
F
P
p
.54854 .56129 m .53464 .5731 L .54013 .56931 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55186 .58002 m .5314 .57727 L .53373 .57428 L p
1 g
F P
s
P
p
.002 w
.53373 .57428 m .53464 .5731 L p
.53564 .5735 L 1 g
F P
s
P
p
.55186 .58002 m .53373 .57428 L .53564 .5735 L 1 g
F
P
p
.002 w
.52898 .57599 m .5314 .57727 L p
.51329 .57976 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54161 .54811 m .55033 .55286 L .5314 .57727 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .53186 .5753 L p
.52422 .57813 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51504 .58185 L p
.52422 .57813 L 1 g
F P
s
P
p
.002 w
.51504 .58185 m .5322 .57686 L p
.52422 .57813 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53464 .5731 m .55033 .55286 L p
.55084 .56191 L 1 g
F P
s
P
p
.002 w
.56079 .55435 m .55186 .58002 L p
.5508 .5612 L 1 g
F P
s
P
p
.56075 .54566 m .55457 .55687 L .5572 .55384 L 1 g
F
P
p
.002 w
.56291 .54561 m .56079 .55435 L .5595 .55417 L p
1 g
F P
s
P
p
.002 w
.5595 .55417 m .5572 .55384 L p
.56167 .54739 L 1 g
F P
s
P
p
.5595 .55417 m .56167 .54739 L .56291 .54561 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .54739 L p
1 g
F P
s
P
p
.56654 .52734 m .56167 .54739 L .56447 .53865 L 1 g
F
P
p
.002 w
.56167 .54739 m .56075 .54566 L p
.5572 .55384 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56654 .52734 m .56447 .53865 L .56495 .53718 L 1 g
F
P
p
.002 w
.56838 .52644 m .57186 .55246 L p
.56806 .54407 L 1 g
F P
s
P
p
.56806 .54407 m .56495 .53718 L .5676 .52888 L 1 g
F
P
p
.56806 .54407 m .5676 .52888 L .56838 .52644 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5676 .52888 L p
1 g
F P
s
P
p
.56515 .50826 m .5676 .52888 L .56753 .52652 L 1 g
F
P
p
.56515 .50826 m .56753 .52652 L .56747 .52495 L 1 g
F
P
p
.002 w
.56725 .52207 m .56808 .52422 L .56737 .52347 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .52495 L .56746 .52454 L 1 g
F
P
p
.002 w
.56744 .52435 m .56808 .52422 L .56746 .52454 L p
1 g
F P
s
P
p
.56745 .52443 m .56746 .52454 L .56745 .52444 L 1 g
F
P
p
.56515 .50826 m .56746 .52454 L .56745 .52443 L 1 g
F
P
p
.56515 .50826 m .56745 .52444 L .56744 .52432 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53557 .54057 m .53292 .53103 L .56744 .52435 L p
1 g
F P
s
P
p
.002 w
.56746 .52454 m .53557 .54057 L p
.56744 .52435 L 1 g
F P
s
P
p
.56515 .50826 m .56745 .52435 L .56744 .52421 L 1 g
F
P
p
.56515 .50826 m .56744 .52426 L .56741 .52392 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.53292 .53103 m .53398 .52051 L .56743 .52415 L p
1 g
F P
s
P
p
.002 w
.56743 .52415 m .56808 .52422 L .56744 .52435 L p
1 g
F P
s
P
p
.002 w
.56744 .52435 m .53292 .53103 L p
.56743 .52415 L 1 g
F P
s
P
p
.56744 .52432 m .56745 .52444 L .56745 .52435 L 1 g
F
P
p
.56744 .52421 m .56745 .52435 L .56744 .52426 L 1 g
F
P
p
.56515 .50826 m .56743 .52405 L .5672 .52158 L 1 g
F
P
p
.002 w
.53398 .52051 m .53866 .51019 L .56741 .5239 L p
1 g
F P
s
P
p
.002 w
.56741 .5239 m .56808 .52422 L .56743 .52415 L p
1 g
F P
s
P
p
.002 w
.56743 .52415 m .53398 .52051 L p
.56741 .5239 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53866 .51019 m .54648 .5012 L .56737 .52347 L p
1 g
F P
s
P
p
.002 w
.56737 .52347 m .56808 .52422 L .56741 .5239 L p
1 g
F P
s
P
p
.002 w
.56741 .5239 m .53866 .51019 L p
.56737 .52347 L 1 g
F P
s
P
p
.56741 .52392 m .56744 .52426 L .56743 .52405 L 1 g
F
P
p
.5672 .52158 m .56743 .52405 L .56736 .52262 L 1 g
F
P
p
.002 w
.56778 .49106 m .56808 .52422 L .56725 .52207 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56448 .4921 m .56778 .49106 L p
.56742 .5122 L 1 g
F P
s
P
p
.56607 .50936 m .56742 .5122 L .56725 .52207 L 1 g
F
P
p
.56448 .4921 m .56742 .5122 L .56607 .50936 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50936 L p
1 g
F P
s
P
p
.55661 .4905 m .56607 .50936 L .56232 .50142 L 1 g
F
P
p
.002 w
.56746 .52454 m .56808 .52422 L .56747 .52478 L p
1 g
F P
s
P
p
.002 w
.56747 .52478 m .56808 .52422 L .56748 .52519 L p
1 g
F P
s
P
p
.002 w
.56748 .52519 m .56808 .52422 L .56753 .52652 L p
1 g
F P
s
P
p
.002 w
.56808 .52422 m .56838 .52644 L p
.5676 .52888 L 1 g
F P
s
P
p
.002 w
.5676 .52888 m .56654 .52734 L p
.56495 .53718 L 1 g
F P
s
P
p
.002 w
.56495 .53718 m .56753 .52652 L p
.5676 .52888 L 1 g
F P
s
P
p
.002 w
.56753 .52652 m .56808 .52422 L p
.5676 .52888 L 1 g
F P
s
P
p
.002 w
.58238 .54739 m .57186 .55246 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.59125 .53969 m .58238 .54739 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.59754 .53016 m .59125 .53969 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.60059 .51979 m .59754 .53016 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.60003 .50968 m .60059 .51979 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.5959 .50091 m .60003 .50968 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.58858 .49444 m .5959 .50091 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.57886 .49103 m .58858 .49444 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.56778 .49106 m .57886 .49103 L .56808 .52422 L closepath p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56704 .51051 L p
1 g
F P
s
P
p
.002 w
.56704 .51051 m .56607 .50936 L p
.56733 .51999 L 1 g
F P
s
P
p
.56733 .51999 m .56854 .53025 L .56704 .51051 L 1 g
F
P
p
.002 w
.56607 .50936 m .56515 .50826 L p
.5672 .52158 L 1 g
F P
s
P
p
.5672 .52158 m .56854 .53025 L .56607 .50936 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55876 .49389 m .56448 .4921 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.54363 .46374 m .54307 .4624 L p
.55758 .49153 L 1 g
F P
s
P
p
.55758 .49153 m .55876 .49389 L .55756 .49151 L 1 g
F
P
p
.55758 .49153 m .55756 .49151 L .54363 .46374 L 1 g
F
P
p
.55677 .49082 m .56232 .50142 L .55775 .49176 L 1 g
F
P
p
.55677 .49082 m .55775 .49176 L .5577 .49166 L 1 g
F
P
p
.002 w
.5577 .49166 m .55661 .4905 L p
.55677 .49082 L 1 g
F P
s
P
p
.002 w
.55971 .4936 m .55876 .49389 L p
.55758 .49153 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55756 .49151 L p
1 g
F P
s
P
p
.54174 .47608 m .55756 .49151 L .55371 .48778 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55371 .48778 m .55657 .49458 L p
.54009 .47566 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .47671 L p
1 g
F P
s
P
p
.52214 .46667 m .54231 .47671 L .53369 .47265 L 1 g
F
P
p
.53383 .46846 m .54231 .47671 L .54009 .47566 L 1 g
F
P
p
.54231 .47671 m .55371 .48778 L .54009 .47566 L 1 g
F
P
p
.002 w
.52303 .47555 m .53005 .47094 L p
.55657 .49458 L 1 g
F P
s
P
p
.52214 .46667 m .53369 .47265 L .53005 .47094 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53005 .47094 m .52303 .47555 L .51458 .46609 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .51458 .46609 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51458 .46609 m .52303 .47555 L p
.4945 .46467 L 1 g
F P
s
P
p
.5 .46382 m .51458 .46609 L .4945 .46467 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.4829 .46647 m .4945 .46467 L .52303 .47555 L 1 g
F
P
p
.002 w
.5 .46382 m .5 .46442 L p
.48875 .46556 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .48875 .46556 L 1 g
F
P
p
.002 w
.47595 .47457 m .4829 .46647 L p
.52303 .47555 L 1 g
F P
s
P
p
.47786 .46667 m .48875 .46556 L .4829 .46647 L 1 g
F
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.4829 .46647 m .47595 .47457 L .47019 .4708 L p
1 g
F P
s
P
p
.47754 .4672 m .4829 .46647 L .47019 .4708 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44882 .4853 m .45177 .48243 L .47595 .47457 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47019 .4708 m .47595 .47457 L p
.45177 .48243 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47656 L p
1 g
F P
s
P
p
.44339 .4905 m .45782 .47656 L .44843 .48568 L 1 g
F
P
p
.43006 .48949 m .45782 .47656 L .45177 .48243 L 1 g
F
P
p
.45782 .47656 m .47019 .4708 L .45177 .48243 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44272 .49121 L p
1 g
F P
s
P
p
.43485 .50826 m .44272 .49121 L .43975 .49714 L 1 g
F
P
p
.002 w
.42627 .52591 m .42841 .49337 L .43524 .49564 L p
1 g
F P
s
P
p
.002 w
.43524 .49564 m .43975 .49714 L p
.43415 .50909 L 1 g
F P
s
P
p
.42627 .52591 m .43524 .49564 L .43415 .50909 L 1 g
F
P
p
.002 w
.43257 .52863 m .43346 .52734 L p
.43322 .52056 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42583 .5326 m .42627 .52591 L p
.43311 .52195 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43415 .50909 L p
1 g
F P
s
P
p
.43346 .52734 m .43415 .50909 L .43322 .52056 L 1 g
F
P
p
.43267 .52745 m .43311 .52195 L .46277 .5048 L 1 g
F
P
p
.42583 .5326 m .43311 .52195 L .43267 .52745 L 1 g
F
P
p
.43485 .50826 m .43975 .49714 L .43808 .50072 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43975 .49714 m .42841 .49337 L p
.44491 .48684 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43975 .49714 m .46277 .5048 L p
.42627 .52591 L 1 g
F P
s
P
p
.002 w
.43415 .50909 m .43287 .51061 L p
.43322 .52056 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43374 .53321 m .42583 .5326 L p
.43234 .5277 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43225 .5291 L p
1 g
F P
s
P
p
.002 w
.43712 .56749 m .42583 .5326 L .43374 .53321 L p
1 g
F P
s
P
p
.43712 .56749 m .43454 .54139 L .44311 .55921 L 1 g
F
P
p
.43454 .54139 m .43374 .53321 L .43864 .54681 L 1 g
F
P
p
.43454 .54139 m .43864 .54681 L .44311 .55921 L 1 g
F
P
p
.43925 .54566 m .43225 .5291 L .43567 .53859 L 1 g
F
P
p
.002 w
.43766 .54866 m .43925 .54566 L p
.43452 .53631 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .54681 L p
1 g
F P
s
P
p
.45146 .56129 m .43864 .54681 L .446 .55654 L 1 g
F
P
p
.002 w
.43374 .53321 m .46042 .53528 L p
.44551 .55589 L 1 g
F P
s
P
p
.44311 .55921 m .43864 .54681 L .44551 .55589 L 1 g
F
P
p
.43864 .54681 m .43374 .53321 L .44551 .55589 L 1 g
F
P
p
.002 w
.45084 .56295 m .45146 .56129 L p
.446 .55654 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45339 .56496 m .43712 .56749 L p
.44418 .55773 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45071 .56331 L p
1 g
F P
s
P
p
.46872 .57265 m .45071 .56331 L .46074 .56946 L 1 g
F
P
p
.002 w
.48311 .57936 m .4868 .58371 L p
.46601 .57332 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46812 .57541 L p
1 g
F P
s
P
p
.002 w
.46812 .57541 m .4678 .57686 L p
.47627 .57756 L 1 g
F P
s
P
p
.48921 .57862 m .46812 .57541 L .47627 .57756 L 1 g
F
P
p
.002 w
.48904 .58092 m .48921 .57862 L p
.48311 .57936 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46886 .56255 m .50208 .5535 L p
.48831 .58073 L 1 g
F P
s
P
p
.002 w
.4868 .58371 m .48311 .57936 L p
.48831 .58073 L 1 g
F P
s
P
p
.002 w
.48311 .57936 m .46886 .56255 L p
.48831 .58073 L 1 g
F P
s
P
p
.002 w
.46886 .56255 m .48311 .57936 L p
.46839 .57416 L 1 g
F P
s
P
p
.46601 .57332 m .46615 .57278 L .46839 .57416 L 1 g
F
P
p
.46615 .57278 m .46886 .56255 L .46839 .57416 L 1 g
F
P
p
.002 w
.46045 .59436 m .43712 .56749 L .46886 .56255 L p
1 g
F P
s
P
p
.002 w
.45071 .56331 m .45002 .56518 L p
.46074 .56946 L 1 g
F P
s
P
p
.002 w
.46042 .53528 m .46886 .56255 L .45339 .56496 L p
1 g
F P
s
P
p
.44418 .55773 m .46042 .53528 L .45339 .56496 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46791 .57635 L p
1 g
F P
s
P
p
.002 w
.46791 .57635 m .46839 .57416 L p
.45972 .56992 L 1 g
F P
s
P
p
.45972 .56992 m .45002 .56518 L .46791 .57635 L 1 g
F
P
p
.002 w
.43864 .54681 m .43743 .5491 L p
.446 .55654 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45084 .56295 L p
1 g
F P
s
P
p
.446 .55654 m .43743 .5491 L .45084 .56295 L 1 g
F
P
p
.002 w
.43225 .5291 m .43146 .53025 L p
.43567 .53859 L 1 g
F P
s
P
p
.002 w
.46277 .5048 m .46042 .53528 L .43374 .53321 L p
1 g
F P
s
P
p
.43234 .5277 m .46277 .5048 L .43374 .53321 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43766 .54866 L p
1 g
F P
s
P
p
.43452 .53631 m .43146 .53025 L .43766 .54866 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43257 .52863 L p
1 g
F P
s
P
p
.43322 .52056 m .43287 .51061 L .43257 .52863 L 1 g
F
P
p
.43808 .50072 m .43975 .49714 L .43875 .49915 L 1 g
F
P
p
.002 w
.47595 .47457 m .46277 .5048 L .43975 .49714 L p
1 g
F P
s
P
p
.002 w
.44272 .49121 m .44339 .4905 L p
.44843 .48568 L 1 g
F P
s
P
p
.44272 .49121 m .47595 .47457 L .43975 .49714 L 1 g
F
P
p
.44491 .48684 m .44882 .4853 L .44272 .49121 L 1 g
F
P
p
.44882 .4853 m .47595 .47457 L .44272 .49121 L 1 g
F
P
p
.002 w
.44272 .49121 m .44166 .49233 L p
.43875 .49915 L 1 g
F P
s
P
p
.002 w
.45782 .47656 m .45698 .47747 L p
.44843 .48568 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44272 .49121 L p
1 g
F P
s
P
p
.44843 .48568 m .45698 .47747 L .44272 .49121 L 1 g
F
P
p
.002 w
.42841 .49337 m .43006 .48949 L p
.45177 .48243 L 1 g
F P
s
P
p
.42841 .49337 m .45177 .48243 L .44882 .4853 L 1 g
F
P
p
.45826 .47608 m .47754 .4672 L .46919 .47129 L 1 g
F
P
p
.002 w
.45733 .47709 m .45826 .47608 L p
.46919 .47129 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.43006 .48949 m .44506 .45431 L .47019 .4708 L p
1 g
F P
s
P
p
.46919 .47129 m .47019 .4708 L .47718 .46778 L 1 g
F
P
p
.002 w
.47754 .4672 m .47739 .46744 L p
.47019 .4708 L 1 g
F P
s
P
p
.002 w
.47739 .46744 m .47718 .46778 L p
.47019 .4708 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46691 .46864 m .44506 .45431 L p
.48056 .46572 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.4829 .46647 L 1 g
F P
s
P
p
.48056 .46572 m .4829 .46647 L .47754 .4672 L 1 g
F
P
p
.48056 .46572 m .47754 .4672 L .46691 .46864 L 1 g
F
P
p
.002 w
.47019 .4708 m .46691 .46864 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45733 .47709 L p
1 g
F P
s
P
p
.46919 .47129 m .47718 .46778 L .45733 .47709 L 1 g
F
P
p
.002 w
.47747 .46731 m .47754 .4672 L p
.4829 .46647 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.49859 .4482 m .4829 .46647 L p
.44506 .45431 L 1 g
F P
s
P
p
.002 w
.4829 .46647 m .48693 .46178 L p
.4945 .46467 L 1 g
F P
s
P
p
.48693 .46178 m .5 .46382 L .4945 .46467 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46731 L p
1 g
F P
s
P
p
.48875 .46556 m .5 .46442 L .47747 .46731 L 1 g
F
P
p
.51143 .4656 m .51458 .46609 L .51235 .46577 L 1 g
F
P
p
.5 .4634 m .51458 .46609 L .51143 .4656 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.52246 .4672 m .53005 .47094 L .51458 .46609 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48693 .46178 m .49859 .4482 L .51458 .46609 L p
1 g
F P
s
P
p
.002 w
.51458 .46609 m .51016 .46114 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52282 .46778 L p
.51235 .46577 L 1 g
F P
s
P
p
.002 w
.5226 .46743 m .52246 .4672 L p
.53005 .47094 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53005 .47094 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54307 .4624 m .53005 .47094 L p
.49859 .4482 L 1 g
F P
s
P
p
.002 w
.51016 .46114 m .49859 .4482 L p
.53005 .47094 L 1 g
F P
s
P
p
.002 w
.53005 .47094 m .53383 .46846 L p
.54009 .47566 L 1 g
F P
s
P
p
.53005 .47094 m .54009 .47566 L .55657 .49458 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5226 .46743 L p
1 g
F P
s
P
p
.53369 .47265 m .54302 .47747 L .5226 .46743 L 1 g
F
P
p
.002 w
.54231 .47671 m .54302 .47747 L p
.53369 .47265 L 1 g
F P
s
P
p
.5504 .48456 m .55371 .48778 L .55083 .48498 L 1 g
F
P
p
.54174 .47608 m .55371 .48778 L .5504 .48456 L 1 g
F
P
p
.002 w
.54243 .47683 m .54174 .47608 L p
.55083 .48498 L 1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53383 .46846 m .54307 .4624 L .55371 .48778 L p
1 g
F P
s
P
p
.002 w
.55876 .49389 m .55657 .49458 L .54363 .46374 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .5577 .49166 L p
.56488 .5061 L 1 g
F P
s
P
p
.56232 .50142 m .56713 .51061 L .5577 .49166 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54243 .47683 L p
1 g
F P
s
P
p
.55083 .48498 m .55834 .49233 L .54243 .47683 L 1 g
F
P
p
.002 w
.55756 .49151 m .55834 .49233 L p
.55083 .48498 L 1 g
F P
s
P
p
.002 w
.56778 .49106 m .55971 .4936 L p
.54307 .4624 L 1 g
F P
s
P
p
.54307 .4624 m .55971 .4936 L .55758 .49153 L 1 g
F
P
p
.002 w
.56713 .51061 m .56666 .50965 L p
.56488 .5061 L 1 g
F P
s
P
p
.002 w
.56666 .50965 m .55834 .49233 L p
.56488 .5061 L 1 g
F P
s
P
p
.002 w
.56725 .52207 m .55657 .49458 L .55876 .49389 L p
1 g
F P
s
P
p
.55876 .49389 m .56607 .50936 L .56725 .52207 L 1 g
F
P
p
.002 w
.56607 .50936 m .56713 .51061 L p
.56232 .50142 L 1 g
F P
s
P
p
.002 w
.54648 .5012 m .55657 .49458 L .56725 .52207 L p
1 g
F P
s
P
p
.002 w
.56737 .52347 m .54648 .5012 L p
.56725 .52207 L 1 g
F P
s
P
p
.56736 .52262 m .56744 .52416 L .56741 .5229 L 1 g
F
P
p
.56744 .52416 m .56747 .52495 L .56746 .52436 L 1 g
F
P
p
.56744 .52416 m .56746 .52436 L .56741 .5229 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54161 .54811 m .53557 .54057 L .56746 .52454 L p
1 g
F P
s
P
p
.002 w
.56747 .52478 m .54161 .54811 L p
.56746 .52454 L 1 g
F P
s
P
p
.002 w
.55033 .55286 m .54161 .54811 L .56747 .52478 L p
1 g
F P
s
P
p
.002 w
.56748 .52519 m .55033 .55286 L p
.56747 .52478 L 1 g
F P
s
P
p
.56741 .5229 m .56748 .52519 L .56742 .52298 L 1 g
F
P
p
.56748 .52519 m .56753 .52652 L .5675 .5256 L 1 g
F
P
p
.56748 .52519 m .5675 .5256 L .56742 .52298 L 1 g
F
P
p
.002 w
.55033 .55286 m .56748 .52519 L p
.56495 .53718 L 1 g
F P
s
P
p
.002 w
.56753 .52652 m .56495 .53718 L p
.56748 .52519 L 1 g
F P
s
P
p
.002 w
.5676 .52888 m .56854 .53025 L p
.56742 .52298 L 1 g
F P
s
P
p
.002 w
.56761 .52889 m .5676 .52888 L p
.56495 .53718 L 1 g
F P
s
P
p
.002 w
.57186 .55246 m .56079 .55435 L .56495 .53718 L p
1 g
F P
s
P
p
.002 w
.56495 .53718 m .56291 .54561 L p
.56209 .54608 L 1 g
F P
s
P
p
.56209 .54608 m .55033 .55286 L .56495 .53718 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56761 .52889 L p
1 g
F P
s
P
p
.56447 .53865 m .56257 .5491 L .56761 .52889 L 1 g
F
P
p
.002 w
.5572 .55384 m .55033 .55286 L p
.56291 .54561 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56257 .5491 L p
.56447 .53865 L 1 g
F P
s
P
p
.002 w
.5621 .54822 m .56167 .54739 L p
.5572 .55384 L 1 g
F P
s
P
p
.002 w
.55033 .55286 m .5572 .55384 L p
.5508 .5612 L 1 g
F P
s
P
p
.002 w
.5572 .55384 m .56079 .55435 L p
.5508 .5612 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5621 .54822 L p
1 g
F P
s
P
p
.55457 .55687 m .54998 .56518 L .5621 .54822 L 1 g
F
P
p
.002 w
.54919 .56304 m .54998 .56518 L p
.55457 .55687 L 1 g
F P
s
P
p
.54013 .56931 m .53464 .5731 L .53952 .56988 L 1 g
F
P
p
.002 w
.53179 .57498 m .53128 .57265 L p
.52898 .57599 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51417 .56816 m .54161 .54811 L p
.53227 .5748 L 1 g
F P
s
P
p
.002 w
.52898 .57599 m .51417 .56816 L p
.53227 .5748 L 1 g
F P
s
P
p
.002 w
.53179 .57498 m .5322 .57686 L p
.53952 .56988 L 1 g
F P
s
P
p
.002 w
.53186 .5753 m .53179 .57498 L p
.52898 .57599 L 1 g
F P
s
P
p
.002 w
.51417 .56816 m .52898 .57599 L p
.51329 .57976 L 1 g
F P
s
P
p
.52106 .57789 m .51111 .583 L .53186 .5753 L 1 g
F
P
p
.002 w
.51092 .58033 m .51111 .583 L p
.52106 .57789 L 1 g
F P
s
P
p
.50041 .5807 m .49156 .581 L .49786 .5812 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50208 .5535 m .51417 .56816 L .49086 .5814 L p
1 g
F P
s
P
p
.48831 .58073 m .50208 .5535 L .49086 .5814 L 1 g
F
P
p
.002 w
.48904 .58092 m .48889 .583 L p
.49786 .5812 L 1 g
F P
s
P
p
.002 w
.489 .58144 m .48904 .58092 L p
.48311 .57936 L 1 g
F P
s
P
p
.46074 .56946 m .45002 .56518 L .46839 .57416 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .489 .58144 L p
1 g
F P
s
P
p
.47854 .57774 m .4678 .57686 L .489 .58144 L 1 g
F
P
p
.002 w
.59274 .31921 m .64017 .33906 L .63795 .36712 L p
1 g
F P
s
P
p
.002 w
.64017 .33906 m .59274 .31921 L .58703 .29257 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.60839 .33579 L
s
P
p
.004 w
.63347 .31387 m
.65076 .29877 L
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51716 .45413 L
s
P
p
.004 w
.53952 .48491 m
.54979 .49904 L
s
P
p
.002 w
.42583 .5326 m .43712 .56749 L .40794 .56824 L p
1 g
F P
s
P
p
.002 w
.40794 .56824 m .39403 .52686 L .42583 .5326 L p
1 g
F P
s
P
p
.002 w
.57186 .55246 m .58238 .54739 L .59377 .56636 L p
1 g
F P
s
P
p
.002 w
.59377 .56636 m .57338 .57623 L .57186 .55246 L p
1 g
F P
s
P
p
.002 w
.61099 .55144 m .59377 .56636 L .58238 .54739 L p
1 g
F P
s
P
p
.004 w
.59654 .56338 m
.60899 .58053 L
s
P
p
.002 w
.58238 .54739 m .59125 .53969 L .61099 .55144 L p
1 g
F P
s
P
p
.002 w
.6233 .53296 m .61099 .55144 L .59125 .53969 L p
1 g
F P
s
P
p
.002 w
.45179 .28552 m .51621 .26751 L .52695 .28976 L p
1 g
F P
s
P
p
.002 w
.58703 .29257 m .52695 .28976 L .51621 .26751 L p
1 g
F P
s
P
p
.002 w
.56079 .55435 m .57186 .55246 L .57338 .57623 L p
1 g
F P
s
P
p
.002 w
.57338 .57623 m .55186 .58002 L .56079 .55435 L p
1 g
F P
s
P
p
.002 w
.52695 .28976 m .58703 .29257 L .59274 .31921 L p
1 g
F P
s
P
p
.002 w
.59125 .53969 m .59754 .53016 L .6233 .53296 L p
1 g
F P
s
P
p
.002 w
.62937 .51278 m .6233 .53296 L .59754 .53016 L p
1 g
F P
s
P
p
.002 w
.39661 .48013 m .39403 .52686 L .3661 .51838 L p
1 g
F P
s
P
p
.002 w
.3661 .51838 m .36853 .46562 L .39661 .48013 L p
1 g
F P
s
P
p
.002 w
.40989 .34326 m .36813 .3932 L .35065 .37522 L p
1 g
F P
s
P
p
.002 w
.35065 .37522 m .39407 .32304 L .40989 .34326 L p
1 g
F P
s
P
p
.002 w
.62937 .51278 m .6285 .49295 L .65254 .47469 L p
1 g
F P
s
P
p
.002 w
.64135 .44923 m .65254 .47469 L .6285 .49295 L p
1 g
F P
s
P
p
.002 w
.65254 .47469 m .64135 .44923 L .65748 .4228 L p
1 g
F P
s
P
p
.002 w
.63148 .39778 m .65748 .4228 L .64135 .44923 L p
1 g
F P
s
P
p
.002 w
.65748 .4228 m .63148 .39778 L .63795 .36712 L p
1 g
F P
s
P
p
.002 w
.39017 .41284 m .36853 .46562 L .34507 .4504 L p
1 g
F P
s
P
p
.002 w
.34507 .4504 m .36813 .3932 L .39017 .41284 L p
1 g
F P
s
P
p
.002 w
.59754 .53016 m .60059 .51979 L .62937 .51278 L p
1 g
F P
s
P
p
.002 w
.6285 .49295 m .62937 .51278 L .60059 .51979 L p
1 g
F P
s
P
p
.002 w
.52695 .28976 m .46524 .30724 L .45179 .28552 L p
1 g
F P
s
P
p
.002 w
.39407 .32304 m .45179 .28552 L .46524 .30724 L p
1 g
F P
s
P
p
.002 w
.59575 .34993 m .63795 .36712 L .63148 .39778 L p
1 g
F P
s
P
p
.002 w
.63795 .36712 m .59575 .34993 L .59274 .31921 L p
1 g
F P
s
P
p
.004 w
.62314 .3229 m
.63347 .31387 L
s
P
p
.004 w
.61022 .33419 m
.6111 .33342 L
s
P
p
.004 w
.6111 .33342 m
.62314 .3229 L
s
P
p
.002 w
.46524 .30724 m .40989 .34326 L .39407 .32304 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.53718 .31697 m .59274 .31921 L .59575 .34993 L p
1 g
F P
s
P
p
.002 w
.59274 .31921 m .53718 .31697 L .52695 .28976 L p
1 g
F P
s
P
p
.002 w
.46524 .30724 m .52695 .28976 L .53718 .31697 L p
1 g
F P
s
P
p
.002 w
.42841 .49337 m .42583 .5326 L .39403 .52686 L p
1 g
F P
s
P
p
.002 w
.39403 .52686 m .39661 .48013 L .42841 .49337 L p
1 g
F P
s
P
p
.002 w
.60059 .51979 m .60003 .50968 L .6285 .49295 L p
1 g
F P
s
P
p
.002 w
.62061 .47559 m .6285 .49295 L .60003 .50968 L p
1 g
F P
s
P
p
.002 w
.6285 .49295 m .62061 .47559 L .64135 .44923 L p
1 g
F P
s
P
p
.002 w
.62086 .43001 m .64135 .44923 L .62061 .47559 L p
1 g
F P
s
P
p
.002 w
.64135 .44923 m .62086 .43001 L .63148 .39778 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.53557 .54057 m .54161 .54811 L .51417 .56816 L p
1 g
F P
s
P
p
.002 w
.51417 .56816 m .50208 .5535 L .53557 .54057 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42894 .36674 m .39017 .41284 L .36813 .3932 L p
1 g
F P
s
P
p
.002 w
.36813 .3932 m .40989 .34326 L .42894 .36674 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41611 .43347 m .39661 .48013 L .36853 .46562 L p
1 g
F P
s
P
p
.002 w
.36853 .46562 m .39017 .41284 L .41611 .43347 L p
1 g
F P
s
P
p
.002 w
.49657 .53476 m .50208 .5535 L .46886 .56255 L p
1 g
F P
s
P
p
.002 w
.46886 .56255 m .46042 .53528 L .49657 .53476 L p
1 g
F P
s
P
p
.002 w
.59588 .38373 m .63148 .39778 L .62086 .43001 L p
1 g
F P
s
P
p
.002 w
.63148 .39778 m .59588 .38373 L .59575 .34993 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60003 .50968 m .5959 .50091 L .62061 .47559 L p
1 g
F P
s
P
p
.002 w
.6064 .46264 m .62061 .47559 L .5959 .50091 L p
1 g
F P
s
P
p
.002 w
.62061 .47559 m .6064 .46264 L .62086 .43001 L p
1 g
F P
s
P
p
.002 w
.53718 .31697 m .48015 .33337 L .46524 .30724 L p
1 g
F P
s
P
p
.002 w
.40989 .34326 m .46524 .30724 L .48015 .33337 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48015 .33337 m .42894 .36674 L .40989 .34326 L p
1 g
F P
s
P
p
.002 w
.54649 .34833 m .59575 .34993 L .59588 .38373 L p
1 g
F P
s
P
p
.002 w
.59575 .34993 m .54649 .34833 L .53718 .31697 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53292 .53103 m .53557 .54057 L .50208 .5535 L p
1 g
F P
s
P
p
.002 w
.50208 .5535 m .49657 .53476 L .53292 .53103 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59303 .41942 m .62086 .43001 L .6064 .46264 L p
1 g
F P
s
P
p
.002 w
.62086 .43001 m .59303 .41942 L .59588 .38373 L p
1 g
F P
s
P
p
.002 w
.48015 .33337 m .53718 .31697 L .54649 .34833 L p
1 g
F P
s
P
p
.002 w
.5959 .50091 m .58858 .49444 L .6064 .46264 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44506 .45431 m .42841 .49337 L .39661 .48013 L p
1 g
F P
s
P
p
.002 w
.39661 .48013 m .41611 .43347 L .44506 .45431 L p
1 g
F P
s
P
p
.002 w
.49842 .51397 m .49657 .53476 L .46042 .53528 L p
1 g
F P
s
P
p
.002 w
.46042 .53528 m .46277 .5048 L .49842 .51397 L p
1 g
F P
s
P
p
.002 w
.45062 .39271 m .41611 .43347 L .39017 .41284 L p
1 g
F P
s
P
p
.002 w
.39017 .41284 m .42894 .36674 L .45062 .39271 L p
1 g
F P
s
P
p
.002 w
.58729 .45564 m .6064 .46264 L .58858 .49444 L p
1 g
F P
s
P
p
.002 w
.6064 .46264 m .58729 .45564 L .59303 .41942 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58858 .49444 m .57886 .49103 L .58729 .45564 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5545 .38275 m .59588 .38373 L .59303 .41942 L p
1 g
F P
s
P
p
.002 w
.59588 .38373 m .5545 .38275 L .54649 .34833 L p
1 g
F P
s
P
p
.002 w
.53398 .52051 m .53292 .53103 L .49657 .53476 L p
1 g
F P
s
P
p
.002 w
.49657 .53476 m .49842 .51397 L .53398 .52051 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57886 .49103 m .56778 .49106 L .56535 .45552 L p
1 g
F P
s
P
p
.002 w
.56535 .45552 m .58729 .45564 L .57886 .49103 L p
1 g
F P
s
P
p
.002 w
.54649 .34833 m .49599 .3631 L .48015 .33337 L p
1 g
F P
s
P
p
.002 w
.42894 .36674 m .48015 .33337 L .49599 .3631 L p
1 g
F P
s
P
p
.002 w
.53866 .51019 m .53398 .52051 L .49842 .51397 L p
1 g
F P
s
P
p
.002 w
.49599 .3631 m .45062 .39271 L .42894 .36674 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49599 .3631 m .54649 .34833 L .5545 .38275 L p
1 g
F P
s
P
p
.002 w
.56087 .41895 m .59303 .41942 L .58729 .45564 L p
1 g
F P
s
P
p
.002 w
.59303 .41942 m .56087 .41895 L .5545 .38275 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.54307 .4624 m .56535 .45552 L .56778 .49106 L p
1 g
F P
s
P
p
.002 w
.58729 .45564 m .56535 .45552 L .56087 .41895 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54648 .5012 m .53866 .51019 L .50756 .49343 L p
1 g
F P
s
P
p
.002 w
.49842 .51397 m .50756 .49343 L .53866 .51019 L p
1 g
F P
s
P
p
.002 w
.55657 .49458 m .54648 .5012 L .52303 .47555 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.50756 .49343 m .52303 .47555 L .54648 .5012 L p
1 g
F P
s
P
p
.002 w
.47413 .42021 m .44506 .45431 L .41611 .43347 L p
1 g
F P
s
P
p
.002 w
.41611 .43347 m .45062 .39271 L .47413 .42021 L p
1 g
F P
s
P
p
.002 w
.50756 .49343 m .49842 .51397 L .46277 .5048 L p
1 g
F P
s
P
p
.002 w
.46277 .5048 m .47595 .47457 L .50756 .49343 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51218 .39535 m .5545 .38275 L .56087 .41895 L p
1 g
F P
s
P
p
.002 w
.5545 .38275 m .51218 .39535 L .49599 .3631 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56535 .45552 m .54307 .4624 L .52808 .42889 L p
1 g
F P
s
P
p
.002 w
.52808 .42889 m .56087 .41895 L .56535 .45552 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.45062 .39271 m .49599 .3631 L .51218 .39535 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.52303 .47555 m .50756 .49343 L .47595 .47457 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.51218 .39535 m .47413 .42021 L .45062 .39271 L p
1 g
F P
s
P
p
.002 w
.56087 .41895 m .52808 .42889 L .51218 .39535 L p
1 g
F P
s
P
p
.002 w
.44506 .45431 m .47413 .42021 L .49859 .4482 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49859 .4482 m .52808 .42889 L .54307 .4624 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47413 .42021 m .51218 .39535 L .52808 .42889 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.52808 .42889 m .49859 .4482 L .47413 .42021 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59095 .55569 m
.59654 .56338 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .67671 .27609 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60899 .58053 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.00542636)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.00542636)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46704 .46725 m .50713 .45558 L .49571 .42943 L p
1 g
F P
s
P
p
.002 w
.49571 .42943 m .46226 .43908 L .46704 .46725 L p
1 g
F P
s
P
p
.002 w
.52565 .41148 m .49571 .42943 L .50713 .45558 L p
1 g
F P
s
P
p
.002 w
.46226 .43908 m .49571 .42943 L .48438 .4033 L p
1 g
F P
s
P
p
.002 w
.49571 .42943 m .52565 .41148 L .5076 .38933 L p
1 g
F P
s
P
p
.002 w
.5076 .38933 m .48438 .4033 L .49571 .42943 L p
1 g
F P
s
P
p
.002 w
.47264 .49471 m .51845 .48126 L .50713 .45558 L p
1 g
F P
s
P
p
.002 w
.50713 .45558 m .46704 .46725 L .47264 .49471 L p
1 g
F P
s
P
p
.002 w
.54308 .4341 m .50713 .45558 L .51845 .48126 L p
1 g
F P
s
P
p
.002 w
.50713 .45558 m .54308 .4341 L .52565 .41148 L p
1 g
F P
s
P
p
.002 w
.48438 .4033 m .45841 .41073 L .46226 .43908 L p
1 g
F P
s
P
p
.002 w
.45841 .41073 m .48438 .4033 L .47336 .37764 L p
1 g
F P
s
P
p
.002 w
.48438 .4033 m .5076 .38933 L .48926 .36805 L p
1 g
F P
s
P
p
.002 w
.48926 .36805 m .47336 .37764 L .48438 .4033 L p
1 g
F P
s
P
p
.002 w
.54922 .38689 m .52565 .41148 L .54308 .4341 L p
1 g
F P
s
P
p
.002 w
.52565 .41148 m .54922 .38689 L .52577 .37016 L p
1 g
F P
s
P
p
.002 w
.52577 .37016 m .5076 .38933 L .52565 .41148 L p
1 g
F P
s
P
p
.002 w
.42645 .46795 m .46704 .46725 L .46226 .43908 L p
1 g
F P
s
P
p
.002 w
.46226 .43908 m .42846 .43945 L .42645 .46795 L p
1 g
F P
s
P
p
.002 w
.42846 .43945 m .46226 .43908 L .45841 .41073 L p
1 g
F P
s
P
p
.002 w
.5076 .38933 m .52577 .37016 L .50162 .35486 L p
1 g
F P
s
P
p
.002 w
.50162 .35486 m .48926 .36805 L .5076 .38933 L p
1 g
F P
s
P
p
.002 w
.51845 .48126 m .55958 .45678 L .54308 .4341 L p
1 g
F P
s
P
p
.002 w
.57154 .40474 m .54308 .4341 L .55958 .45678 L p
1 g
F P
s
P
p
.002 w
.54308 .4341 m .57154 .40474 L .54922 .38689 L p
1 g
F P
s
P
p
.002 w
.45841 .41073 m .4322 .41085 L .42846 .43945 L p
1 g
F P
s
P
p
.002 w
.4322 .41085 m .45841 .41073 L .45554 .3827 L p
1 g
F P
s
P
p
.002 w
.47336 .37764 m .45554 .3827 L .45841 .41073 L p
1 g
F P
s
P
p
.002 w
.42623 .49579 m .47264 .49471 L .46704 .46725 L p
1 g
F P
s
P
p
.002 w
.46704 .46725 m .42645 .46795 L .42623 .49579 L p
1 g
F P
s
P
p
.002 w
.47899 .52096 m .52945 .50602 L .51845 .48126 L p
1 g
F P
s
P
p
.002 w
.51845 .48126 m .47264 .49471 L .47899 .52096 L p
1 g
F P
s
P
p
.002 w
.55958 .45678 m .51845 .48126 L .52945 .50602 L p
1 g
F P
s
P
p
.002 w
.45554 .3827 m .47336 .37764 L .46284 .35295 L p
1 g
F P
s
P
p
.002 w
.47336 .37764 m .48926 .36805 L .47095 .34803 L p
1 g
F P
s
P
p
.002 w
.47095 .34803 m .46284 .35295 L .47336 .37764 L p
1 g
F P
s
P
p
.002 w
.48926 .36805 m .50162 .35486 L .47723 .34127 L p
1 g
F P
s
P
p
.002 w
.47723 .34127 m .47095 .34803 L .48926 .36805 L p
1 g
F P
s
P
p
.002 w
.52945 .50602 m .57483 .4791 L .55958 .45678 L p
1 g
F P
s
P
p
.002 w
.59231 .42338 m .55958 .45678 L .57483 .4791 L p
1 g
F P
s
P
p
.002 w
.55958 .45678 m .59231 .42338 L .57154 .40474 L p
1 g
F P
s
P
p
.002 w
.45554 .3827 m .43761 .38267 L .4322 .41085 L p
1 g
F P
s
P
p
.002 w
.43761 .38267 m .45554 .3827 L .45373 .35551 L p
1 g
F P
s
P
p
.002 w
.46284 .35295 m .45373 .35551 L .45554 .3827 L p
1 g
F P
s
P
p
.002 w
.53702 .34762 m .52577 .37016 L .54922 .38689 L p
1 g
F P
s
P
p
.002 w
.52577 .37016 m .53702 .34762 L .50916 .33939 L p
1 g
F P
s
P
p
.002 w
.50916 .33939 m .50162 .35486 L .52577 .37016 L p
1 g
F P
s
P
p
.002 w
.56402 .35792 m .54922 .38689 L .57154 .40474 L p
1 g
F P
s
P
p
.002 w
.54922 .38689 m .56402 .35792 L .53702 .34762 L p
1 g
F P
s
P
p
.002 w
.42784 .52245 m .47899 .52096 L .47264 .49471 L p
1 g
F P
s
P
p
.002 w
.47264 .49471 m .42623 .49579 L .42784 .52245 L p
1 g
F P
s
P
p
.002 w
.39759 .4303 m .42846 .43945 L .4322 .41085 L p
1 g
F P
s
P
p
.002 w
.4322 .41085 m .40838 .40352 L .39759 .4303 L p
1 g
F P
s
P
p
.002 w
.40838 .40352 m .4322 .41085 L .43761 .38267 L p
1 g
F P
s
P
p
.002 w
.38923 .45731 m .42645 .46795 L .42846 .43945 L p
1 g
F P
s
P
p
.002 w
.42846 .43945 m .39759 .4303 L .38923 .45731 L p
1 g
F P
s
P
p
.002 w
.50162 .35486 m .50916 .33939 L .48099 .33337 L p
1 g
F P
s
P
p
.002 w
.48099 .33337 m .47723 .34127 L .50162 .35486 L p
1 g
F P
s
P
p
.002 w
.58965 .37008 m .57154 .40474 L .59231 .42338 L p
1 g
F P
s
P
p
.002 w
.57154 .40474 m .58965 .37008 L .56402 .35792 L p
1 g
F P
s
P
p
.002 w
.43761 .38267 m .4214 .3775 L .40838 .40352 L p
1 g
F P
s
P
p
.002 w
.4214 .3775 m .43761 .38267 L .44459 .35544 L p
1 g
F P
s
P
p
.002 w
.45373 .35551 m .44459 .35544 L .43761 .38267 L p
1 g
F P
s
P
p
.002 w
.48599 .54545 m .53993 .52936 L .52945 .50602 L p
1 g
F P
s
P
p
.002 w
.52945 .50602 m .47899 .52096 L .48599 .54545 L p
1 g
F P
s
P
p
.002 w
.57483 .4791 m .52945 .50602 L .53993 .52936 L p
1 g
F P
s
P
p
.002 w
.38353 .48403 m .42623 .49579 L .42645 .46795 L p
1 g
F P
s
P
p
.002 w
.42645 .46795 m .38923 .45731 L .38353 .48403 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .45373 .35551 L .46284 .35295 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .46284 .35295 L .47095 .34803 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .47095 .34803 L .47723 .34127 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .44459 .35544 L .45373 .35551 L closepath p
1 g
F P
s
P
p
.002 w
.53993 .52936 m .58851 .50063 L .57483 .4791 L p
1 g
F P
s
P
p
.002 w
.6111 .44247 m .57483 .4791 L .58851 .50063 L p
1 g
F P
s
P
p
.002 w
.57483 .4791 m .6111 .44247 L .59231 .42338 L p
1 g
F P
s
P
p
.002 w
.54002 .32393 m .53702 .34762 L .56402 .35792 L p
1 g
F P
s
P
p
.002 w
.53702 .34762 m .54002 .32393 L .51101 .32321 L p
1 g
F P
s
P
p
.002 w
.51101 .32321 m .50916 .33939 L .53702 .34762 L p
1 g
F P
s
P
p
.002 w
.50916 .33939 m .51101 .32321 L .48182 .32515 L p
1 g
F P
s
P
p
.002 w
.48182 .32515 m .48099 .33337 L .50916 .33939 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .47723 .34127 L .48099 .33337 L closepath p
1 g
F P
s
P
p
.002 w
.61338 .38391 m .59231 .42338 L .6111 .44247 L p
1 g
F P
s
P
p
.002 w
.59231 .42338 m .61338 .38391 L .58965 .37008 L p
1 g
F P
s
P
p
.002 w
.43129 .54735 m .48599 .54545 L .47899 .52096 L p
1 g
F P
s
P
p
.002 w
.47899 .52096 m .42784 .52245 L .43129 .54735 L p
1 g
F P
s
P
p
.002 w
.44459 .35544 m .43637 .35273 L .4214 .3775 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .43637 .35273 L .44459 .35544 L closepath p
1 g
F P
s
P
p
.002 w
.38945 .38931 m .40838 .40352 L .4214 .3775 L p
1 g
F P
s
P
p
.002 w
.4214 .3775 m .40862 .36765 L .38945 .38931 L p
1 g
F P
s
P
p
.002 w
.40862 .36765 m .4214 .3775 L .43637 .35273 L p
1 g
F P
s
P
p
.002 w
.37285 .41222 m .39759 .4303 L .40838 .40352 L p
1 g
F P
s
P
p
.002 w
.40838 .40352 m .38945 .38931 L .37285 .41222 L p
1 g
F P
s
P
p
.002 w
.56829 .32731 m .56402 .35792 L .58965 .37008 L p
1 g
F P
s
P
p
.002 w
.56402 .35792 m .56829 .32731 L .54002 .32393 L p
1 g
F P
s
P
p
.002 w
.38065 .5099 m .42784 .52245 L .42623 .49579 L p
1 g
F P
s
P
p
.002 w
.42623 .49579 m .38353 .48403 L .38065 .5099 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .48099 .33337 L .48182 .32515 L closepath p
1 g
F P
s
P
p
.002 w
.43637 .35273 m .42996 .34765 L .40862 .36765 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .42996 .34765 L .43637 .35273 L closepath p
1 g
F P
s
P
p
.002 w
.3592 .43593 m .38923 .45731 L .39759 .4303 L p
1 g
F P
s
P
p
.002 w
.39759 .4303 m .37285 .41222 L .3592 .43593 L p
1 g
F P
s
P
p
.002 w
.4935 .56765 m .54965 .55078 L .53993 .52936 L p
1 g
F P
s
P
p
.002 w
.53993 .52936 m .48599 .54545 L .4935 .56765 L p
1 g
F P
s
P
p
.002 w
.58851 .50063 m .53993 .52936 L .54965 .55078 L p
1 g
F P
s
P
p
.002 w
.4796 .3175 m .48182 .32515 L .51101 .32321 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .48182 .32515 L .4796 .3175 L closepath p
1 g
F P
s
P
p
.002 w
.50684 .30804 m .51101 .32321 L .54002 .32393 L p
1 g
F P
s
P
p
.002 w
.51101 .32321 m .50684 .30804 L .4796 .3175 L p
1 g
F P
s
P
p
.002 w
.59523 .33333 m .58965 .37008 L .61338 .38391 L p
1 g
F P
s
P
p
.002 w
.58965 .37008 m .59523 .33333 L .56829 .32731 L p
1 g
F P
s
P
p
.002 w
.40073 .35406 m .40862 .36765 L .42996 .34765 L p
1 g
F P
s
P
p
.002 w
.42996 .34765 m .42607 .34071 L .40073 .35406 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .42607 .34071 L .42996 .34765 L closepath p
1 g
F P
s
P
p
.002 w
.37757 .3695 m .38945 .38931 L .40862 .36765 L p
1 g
F P
s
P
p
.002 w
.40862 .36765 m .40073 .35406 L .37757 .3695 L p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .46714 .3071 L .45822 .30554 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .45822 .30554 L .44877 .30676 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .44877 .30676 L .43982 .31064 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .43982 .31064 L .4324 .31673 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .4324 .31673 L .42733 .32436 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .42733 .32436 L .42514 .33266 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .42514 .33266 L .42607 .34071 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .4796 .3175 L .47453 .31125 L closepath p
1 g
F P
s
P
p
.002 w
.45303 .32969 m .47453 .31125 L .46714 .3071 L closepath p
1 g
F P
s
P
p
.002 w
.58851 .50063 m .62749 .46164 L .6111 .44247 L p
1 g
F P
s
P
p
.002 w
.63469 .39916 m .6111 .44247 L .62749 .46164 L p
1 g
F P
s
P
p
.002 w
.6111 .44247 m .63469 .39916 L .61338 .38391 L p
1 g
F P
s
P
p
.002 w
.54965 .55078 m .6003 .52093 L .58851 .50063 L p
1 g
F P
s
P
p
.002 w
.62749 .46164 m .58851 .50063 L .6003 .52093 L p
1 g
F P
s
P
p
.002 w
.53421 .30154 m .54002 .32393 L .56829 .32731 L p
1 g
F P
s
P
p
.002 w
.54002 .32393 m .53421 .30154 L .50684 .30804 L p
1 g
F P
s
P
p
.002 w
.34887 .45997 m .38353 .48403 L .38923 .45731 L p
1 g
F P
s
P
p
.002 w
.38923 .45731 m .3592 .43593 L .34887 .45997 L p
1 g
F P
s
P
p
.002 w
.47453 .31125 m .4796 .3175 L .50684 .30804 L p
1 g
F P
s
P
p
.002 w
.43658 .56991 m .4935 .56765 L .48599 .54545 L p
1 g
F P
s
P
p
.002 w
.48599 .54545 m .43129 .54735 L .43658 .56991 L p
1 g
F P
s
P
p
.002 w
.3987 .33813 m .40073 .35406 L .42607 .34071 L p
1 g
F P
s
P
p
.002 w
.42607 .34071 m .42514 .33266 L .3987 .33813 L p
1 g
F P
s
P
p
.002 w
.38076 .53436 m .43129 .54735 L .42784 .52245 L p
1 g
F P
s
P
p
.002 w
.42784 .52245 m .38065 .5099 L .38076 .53436 L p
1 g
F P
s
P
p
.002 w
.3571 .38676 m .37285 .41222 L .38945 .38931 L p
1 g
F P
s
P
p
.002 w
.38945 .38931 m .37757 .3695 L .3571 .38676 L p
1 g
F P
s
P
p
.002 w
.50684 .30804 m .49697 .29553 L .47453 .31125 L p
1 g
F P
s
P
p
.002 w
.46714 .3071 m .47453 .31125 L .49697 .29553 L p
1 g
F P
s
P
p
.002 w
.62025 .34192 m .61338 .38391 L .63469 .39916 L p
1 g
F P
s
P
p
.002 w
.61338 .38391 m .62025 .34192 L .59523 .33333 L p
1 g
F P
s
P
p
.002 w
.49697 .29553 m .50684 .30804 L .53421 .30154 L p
1 g
F P
s
P
p
.002 w
.40288 .32159 m .3987 .33813 L .42514 .33266 L p
1 g
F P
s
P
p
.002 w
.42514 .33266 m .42733 .32436 L .40288 .32159 L p
1 g
F P
s
P
p
.002 w
.56116 .2982 m .56829 .32731 L .59523 .33333 L p
1 g
F P
s
P
p
.002 w
.56829 .32731 m .56116 .2982 L .53421 .30154 L p
1 g
F P
s
P
p
.002 w
.37428 .34607 m .37757 .3695 L .40073 .35406 L p
1 g
F P
s
P
p
.002 w
.40073 .35406 m .3987 .33813 L .37428 .34607 L p
1 g
F P
s
P
p
.002 w
.45822 .30554 m .46714 .3071 L .48238 .28714 L p
1 g
F P
s
P
p
.002 w
.49697 .29553 m .48238 .28714 L .46714 .3071 L p
1 g
F P
s
P
p
.002 w
.3422 .48381 m .38065 .5099 L .38353 .48403 L p
1 g
F P
s
P
p
.002 w
.38353 .48403 m .34887 .45997 L .3422 .48381 L p
1 g
F P
s
P
p
.002 w
.33986 .40551 m .3592 .43593 L .37285 .41222 L p
1 g
F P
s
P
p
.002 w
.37285 .41222 m .3571 .38676 L .33986 .40551 L p
1 g
F P
s
P
p
.002 w
.41292 .30631 m .40288 .32159 L .42733 .32436 L p
1 g
F P
s
P
p
.002 w
.42733 .32436 m .4324 .31673 L .41292 .30631 L p
1 g
F P
s
P
p
.002 w
.5014 .58701 m .5584 .56977 L .54965 .55078 L p
1 g
F P
s
P
p
.002 w
.54965 .55078 m .4935 .56765 L .5014 .58701 L p
1 g
F P
s
P
p
.002 w
.6003 .52093 m .54965 .55078 L .5584 .56977 L p
1 g
F P
s
P
p
.002 w
.6003 .52093 m .64106 .48052 L .62749 .46164 L p
1 g
F P
s
P
p
.002 w
.65306 .41555 m .62749 .46164 L .64106 .48052 L p
1 g
F P
s
P
p
.002 w
.62749 .46164 m .65306 .41555 L .63469 .39916 L p
1 g
F P
s
P
p
.002 w
.48238 .28714 m .46461 .28392 L .45822 .30554 L p
1 g
F P
s
P
p
.002 w
.44877 .30676 m .45822 .30554 L .46461 .28392 L p
1 g
F P
s
P
p
.002 w
.42775 .29406 m .41292 .30631 L .4324 .31673 L p
1 g
F P
s
P
p
.002 w
.4324 .31673 m .43982 .31064 L .42775 .29406 L p
1 g
F P
s
P
p
.002 w
.51992 .28293 m .53421 .30154 L .56116 .2982 L p
1 g
F P
s
P
p
.002 w
.53421 .30154 m .51992 .28293 L .49697 .29553 L p
1 g
F P
s
P
p
.002 w
.46461 .28392 m .44568 .2863 L .44877 .30676 L p
1 g
F P
s
P
p
.002 w
.43982 .31064 m .44877 .30676 L .44568 .2863 L p
1 g
F P
s
P
p
.002 w
.44568 .2863 m .42775 .29406 L .43982 .31064 L p
1 g
F P
s
P
p
.002 w
.48238 .28714 m .49697 .29553 L .51992 .28293 L p
1 g
F P
s
P
p
.002 w
.5584 .56977 m .60988 .53951 L .6003 .52093 L p
1 g
F P
s
P
p
.002 w
.64106 .48052 m .6003 .52093 L .60988 .53951 L p
1 g
F P
s
P
p
.002 w
.38397 .55681 m .43658 .56991 L .43129 .54735 L p
1 g
F P
s
P
p
.002 w
.43129 .54735 m .38076 .53436 L .38397 .55681 L p
1 g
F P
s
P
p
.002 w
.5871 .29818 m .59523 .33333 L .62025 .34192 L p
1 g
F P
s
P
p
.002 w
.59523 .33333 m .5871 .29818 L .56116 .2982 L p
1 g
F P
s
P
p
.002 w
.3525 .35637 m .3571 .38676 L .37757 .3695 L p
1 g
F P
s
P
p
.002 w
.37757 .3695 m .37428 .34607 L .3525 .35637 L p
1 g
F P
s
P
p
.002 w
.38026 .32154 m .37428 .34607 L .3987 .33813 L p
1 g
F P
s
P
p
.002 w
.3987 .33813 m .40288 .32159 L .38026 .32154 L p
1 g
F P
s
P
p
.002 w
.44367 .58956 m .5014 .58701 L .4935 .56765 L p
1 g
F P
s
P
p
.002 w
.4935 .56765 m .43658 .56991 L .44367 .58956 L p
1 g
F P
s
P
p
.002 w
.64275 .35298 m .63469 .39916 L .65306 .41555 L p
1 g
F P
s
P
p
.002 w
.63469 .39916 m .64275 .35298 L .62025 .34192 L p
1 g
F P
s
P
p
.002 w
.32635 .4254 m .34887 .45997 L .3592 .43593 L p
1 g
F P
s
P
p
.002 w
.3592 .43593 m .33986 .40551 L .32635 .4254 L p
1 g
F P
s
P
p
.002 w
.33947 .50692 m .38076 .53436 L .38065 .5099 L p
1 g
F P
s
P
p
.002 w
.38065 .5099 m .3422 .48381 L .33947 .50692 L p
1 g
F P
s
P
p
.002 w
.51992 .28293 m .49847 .27034 L .48238 .28714 L p
1 g
F P
s
P
p
.002 w
.46461 .28392 m .48238 .28714 L .49847 .27034 L p
1 g
F P
s
P
p
.002 w
.5429 .27384 m .56116 .2982 L .5871 .29818 L p
1 g
F P
s
P
p
.002 w
.56116 .2982 m .5429 .27384 L .51992 .28293 L p
1 g
F P
s
P
p
.002 w
.39507 .29876 m .38026 .32154 L .40288 .32159 L p
1 g
F P
s
P
p
.002 w
.40288 .32159 m .41292 .30631 L .39507 .29876 L p
1 g
F P
s
P
p
.002 w
.49847 .27034 m .51992 .28293 L .5429 .27384 L p
1 g
F P
s
P
p
.002 w
.61141 .30159 m .62025 .34192 L .64275 .35298 L p
1 g
F P
s
P
p
.002 w
.62025 .34192 m .61141 .30159 L .5871 .29818 L p
1 g
F P
s
P
p
.002 w
.33395 .36891 m .33986 .40551 L .3571 .38676 L p
1 g
F P
s
P
p
.002 w
.3571 .38676 m .3525 .35637 L .33395 .36891 L p
1 g
F P
s
P
p
.002 w
.60988 .53951 m .6514 .49867 L .64106 .48052 L p
1 g
F P
s
P
p
.002 w
.66798 .43279 m .64106 .48052 L .6514 .49867 L p
1 g
F P
s
P
p
.002 w
.64106 .48052 m .66798 .43279 L .65306 .41555 L p
1 g
F P
s
P
p
.002 w
.49847 .27034 m .47212 .2654 L .46461 .28392 L p
1 g
F P
s
P
p
.002 w
.44568 .2863 m .46461 .28392 L .47212 .2654 L p
1 g
F P
s
P
p
.002 w
.50954 .60296 m .56594 .58581 L .5584 .56977 L p
1 g
F P
s
P
p
.002 w
.5584 .56977 m .5014 .58701 L .50954 .60296 L p
1 g
F P
s
P
p
.002 w
.60988 .53951 m .5584 .56977 L .56594 .58581 L p
1 g
F P
s
P
p
.002 w
.36005 .32434 m .3525 .35637 L .37428 .34607 L p
1 g
F P
s
P
p
.002 w
.37428 .34607 m .38026 .32154 L .36005 .32434 L p
1 g
F P
s
P
p
.002 w
.41714 .28046 m .39507 .29876 L .41292 .30631 L p
1 g
F P
s
P
p
.002 w
.41292 .30631 m .42775 .29406 L .41714 .28046 L p
1 g
F P
s
P
p
.002 w
.39034 .57662 m .44367 .58956 L .43658 .56991 L p
1 g
F P
s
P
p
.002 w
.43658 .56991 m .38397 .55681 L .39034 .57662 L p
1 g
F P
s
P
p
.002 w
.66213 .36636 m .65306 .41555 L .66798 .43279 L p
1 g
F P
s
P
p
.002 w
.65306 .41555 m .66213 .36636 L .64275 .35298 L p
1 g
F P
s
P
p
.002 w
.31702 .446 m .3422 .48381 L .34887 .45997 L p
1 g
F P
s
P
p
.002 w
.34887 .45997 m .32635 .4254 L .31702 .446 L p
1 g
F P
s
P
p
.002 w
.47212 .2654 m .44389 .26888 L .44568 .2863 L p
1 g
F P
s
P
p
.002 w
.42775 .29406 m .44568 .2863 L .44389 .26888 L p
1 g
F P
s
P
p
.002 w
.44389 .26888 m .41714 .28046 L .42775 .29406 L p
1 g
F P
s
P
p
.002 w
.56594 .58581 m .61693 .5559 L .60988 .53951 L p
1 g
F P
s
P
p
.002 w
.6514 .49867 m .60988 .53951 L .61693 .5559 L p
1 g
F P
s
P
p
.002 w
.45249 .60568 m .50954 .60296 L .5014 .58701 L p
1 g
F P
s
P
p
.002 w
.5014 .58701 m .44367 .58956 L .45249 .60568 L p
1 g
F P
s
P
p
.002 w
.34093 .5287 m .38397 .55681 L .38076 .53436 L p
1 g
F P
s
P
p
.002 w
.38076 .53436 m .33947 .50692 L .34093 .5287 L p
1 g
F P
s
P
p
.002 w
.56538 .26857 m .5871 .29818 L .61141 .30159 L p
1 g
F P
s
P
p
.002 w
.5871 .29818 m .56538 .26857 L .5429 .27384 L p
1 g
F P
s
P
p
.002 w
.47212 .2654 m .49847 .27034 L .51508 .2572 L p
1 g
F P
s
P
p
.002 w
.5429 .27384 m .51508 .2572 L .49847 .27034 L p
1 g
F P
s
P
p
.002 w
.37933 .29441 m .36005 .32434 L .38026 .32154 L p
1 g
F P
s
P
p
.002 w
.38026 .32154 m .39507 .29876 L .37933 .29441 L p
1 g
F P
s
P
p
.002 w
.31921 .38349 m .32635 .4254 L .33986 .40551 L p
1 g
F P
s
P
p
.002 w
.33986 .40551 m .33395 .36891 L .31921 .38349 L p
1 g
F P
s
P
p
.002 w
.51508 .2572 m .5429 .27384 L .56538 .26857 L p
1 g
F P
s
P
p
.002 w
.63347 .30848 m .64275 .35298 L .66213 .36636 L p
1 g
F P
s
P
p
.002 w
.64275 .35298 m .63347 .30848 L .61141 .30159 L p
1 g
F P
s
P
p
.002 w
.34286 .33005 m .33395 .36891 L .3525 .35637 L p
1 g
F P
s
P
p
.002 w
.3525 .35637 m .36005 .32434 L .34286 .33005 L p
1 g
F P
s
P
p
.002 w
.61693 .5559 m .65812 .51565 L .6514 .49867 L p
1 g
F P
s
P
p
.002 w
.67895 .4505 m .6514 .49867 L .65812 .51565 L p
1 g
F P
s
P
p
.002 w
.6514 .49867 m .67895 .4505 L .66798 .43279 L p
1 g
F P
s
P
p
.002 w
.31232 .46684 m .33947 .50692 L .3422 .48381 L p
1 g
F P
s
P
p
.002 w
.3422 .48381 m .31702 .446 L .31232 .46684 L p
1 g
F P
s
P
p
.002 w
.51508 .2572 m .48062 .25058 L .47212 .2654 L p
1 g
F P
s
P
p
.002 w
.44389 .26888 m .47212 .2654 L .48062 .25058 L p
1 g
F P
s
P
p
.002 w
.6778 .38183 m .66798 .43279 L .67895 .4505 L p
1 g
F P
s
P
p
.002 w
.66798 .43279 m .6778 .38183 L .66213 .36636 L p
1 g
F P
s
P
p
.002 w
.4083 .2703 m .37933 .29441 L .39507 .29876 L p
1 g
F P
s
P
p
.002 w
.39507 .29876 m .41714 .28046 L .4083 .2703 L p
1 g
F P
s
P
p
.002 w
.51773 .61494 m .57202 .59837 L .56594 .58581 L p
1 g
F P
s
P
p
.002 w
.56594 .58581 m .50954 .60296 L .51773 .61494 L p
1 g
F P
s
P
p
.002 w
.61693 .5559 m .56594 .58581 L .57202 .59837 L p
1 g
F P
s
P
p
.002 w
.39987 .5932 m .45249 .60568 L .44367 .58956 L p
1 g
F P
s
P
p
.002 w
.44367 .58956 m .39034 .57662 L .39987 .5932 L p
1 g
F P
s
P
p
.002 w
.58683 .26743 m .61141 .30159 L .63347 .30848 L p
1 g
F P
s
P
p
.002 w
.61141 .30159 m .58683 .26743 L .56538 .26857 L p
1 g
F P
s
P
p
.002 w
.48062 .25058 m .44352 .25507 L .44389 .26888 L p
1 g
F P
s
P
p
.002 w
.41714 .28046 m .44389 .26888 L .44352 .25507 L p
1 g
F P
s
P
p
.002 w
.44352 .25507 m .4083 .2703 L .41714 .28046 L p
1 g
F P
s
P
p
.002 w
.57202 .59837 m .62116 .5696 L .61693 .5559 L p
1 g
F P
s
P
p
.002 w
.65812 .51565 m .61693 .5559 L .62116 .5696 L p
1 g
F P
s
P
p
.002 w
.34674 .54854 m .39034 .57662 L .38397 .55681 L p
1 g
F P
s
P
p
.002 w
.38397 .55681 m .34093 .5287 L .34674 .54854 L p
1 g
F P
s
P
p
.002 w
.46291 .61771 m .51773 .61494 L .50954 .60296 L p
1 g
F P
s
P
p
.002 w
.50954 .60296 m .45249 .60568 L .46291 .61771 L p
1 g
F P
s
P
p
.002 w
.30887 .39984 m .31702 .446 L .32635 .4254 L p
1 g
F P
s
P
p
.002 w
.32635 .4254 m .31921 .38349 L .30887 .39984 L p
1 g
F P
s
P
p
.002 w
.48062 .25058 m .51508 .2572 L .53185 .24821 L p
1 g
F P
s
P
p
.002 w
.56538 .26857 m .53185 .24821 L .51508 .2572 L p
1 g
F P
s
P
p
.002 w
.65265 .31884 m .66213 .36636 L .6778 .38183 L p
1 g
F P
s
P
p
.002 w
.66213 .36636 m .65265 .31884 L .63347 .30848 L p
1 g
F P
s
P
p
.002 w
.53185 .24821 m .56538 .26857 L .58683 .26743 L p
1 g
F P
s
P
p
.002 w
.36622 .29355 m .34286 .33005 L .36005 .32434 L p
1 g
F P
s
P
p
.002 w
.36005 .32434 m .37933 .29441 L .36622 .29355 L p
1 g
F P
s
P
p
.002 w
.32928 .33869 m .31921 .38349 L .33395 .36891 L p
1 g
F P
s
P
p
.002 w
.33395 .36891 m .34286 .33005 L .32928 .33869 L p
1 g
F P
s
P
p
.002 w
.31258 .48738 m .34093 .5287 L .33947 .50692 L p
1 g
F P
s
P
p
.002 w
.33947 .50692 m .31232 .46684 L .31258 .48738 L p
1 g
F P
s
P
p
.002 w
.62116 .5696 m .66086 .53099 L .65812 .51565 L p
1 g
F P
s
P
p
.002 w
.68552 .46828 m .65812 .51565 L .66086 .53099 L p
1 g
F P
s
P
p
.002 w
.65812 .51565 m .68552 .46828 L .67895 .4505 L p
1 g
F P
s
P
p
.002 w
.6892 .39912 m .67895 .4505 L .68552 .46828 L p
1 g
F P
s
P
p
.002 w
.67895 .4505 m .6892 .39912 L .6778 .38183 L p
1 g
F P
s
P
p
.002 w
.60665 .27064 m .63347 .30848 L .65265 .31884 L p
1 g
F P
s
P
p
.002 w
.63347 .30848 m .60665 .27064 L .58683 .26743 L p
1 g
F P
s
P
p
.002 w
.53185 .24821 m .48997 .24 L .48062 .25058 L p
1 g
F P
s
P
p
.002 w
.44352 .25507 m .48062 .25058 L .48997 .24 L p
1 g
F P
s
P
p
.002 w
.41249 .60593 m .46291 .61771 L .45249 .60568 L p
1 g
F P
s
P
p
.002 w
.45249 .60568 m .39987 .5932 L .41249 .60593 L p
1 g
F P
s
P
p
.002 w
.40158 .26405 m .36622 .29355 L .37933 .29441 L p
1 g
F P
s
P
p
.002 w
.37933 .29441 m .4083 .2703 L .40158 .26405 L p
1 g
F P
s
P
p
.002 w
.52577 .62242 m .57641 .60692 L .57202 .59837 L p
1 g
F P
s
P
p
.002 w
.57202 .59837 m .51773 .61494 L .52577 .62242 L p
1 g
F P
s
P
p
.002 w
.62116 .5696 m .57202 .59837 L .57641 .60692 L p
1 g
F P
s
P
p
.002 w
.35696 .56581 m .39987 .5932 L .39034 .57662 L p
1 g
F P
s
P
p
.002 w
.39034 .57662 m .34674 .54854 L .35696 .56581 L p
1 g
F P
s
P
p
.002 w
.30341 .41762 m .31232 .46684 L .31702 .446 L p
1 g
F P
s
P
p
.002 w
.31702 .446 m .30887 .39984 L .30341 .41762 L p
1 g
F P
s
P
p
.002 w
.48997 .24 m .44466 .24542 L .44352 .25507 L p
1 g
F P
s
P
p
.002 w
.4083 .2703 m .44352 .25507 L .44466 .24542 L p
1 g
F P
s
P
p
.002 w
.66831 .33258 m .6778 .38183 L .6892 .39912 L p
1 g
F P
s
P
p
.002 w
.6778 .38183 m .66831 .33258 L .65265 .31884 L p
1 g
F P
s
P
p
.002 w
.57641 .60692 m .62229 .58009 L .62116 .5696 L p
1 g
F P
s
P
p
.002 w
.66086 .53099 m .62116 .5696 L .62229 .58009 L p
1 g
F P
s
P
p
.002 w
.44466 .24542 m .40158 .26405 L .4083 .2703 L p
1 g
F P
s
P
p
.002 w
.54838 .24381 m .58683 .26743 L .60665 .27064 L p
1 g
F P
s
P
p
.002 w
.58683 .26743 m .54838 .24381 L .53185 .24821 L p
1 g
F P
s
P
p
.002 w
.48997 .24 m .53185 .24821 L .54838 .24381 L p
1 g
F P
s
P
p
.002 w
.47475 .62509 m .52577 .62242 L .51773 .61494 L p
1 g
F P
s
P
p
.002 w
.51773 .61494 m .46291 .61771 L .47475 .62509 L p
1 g
F P
s
P
p
.002 w
.35624 .2964 m .32928 .33869 L .34286 .33005 L p
1 g
F P
s
P
p
.002 w
.34286 .33005 m .36622 .29355 L .35624 .2964 L p
1 g
F P
s
P
p
.002 w
.31988 .35021 m .30887 .39984 L .31921 .38349 L p
1 g
F P
s
P
p
.002 w
.31921 .38349 m .32928 .33869 L .31988 .35021 L p
1 g
F P
s
P
p
.002 w
.31806 .50706 m .34674 .54854 L .34093 .5287 L p
1 g
F P
s
P
p
.002 w
.34093 .5287 m .31258 .48738 L .31806 .50706 L p
1 g
F P
s
P
p
.002 w
.62425 .27835 m .65265 .31884 L .66831 .33258 L p
1 g
F P
s
P
p
.002 w
.65265 .31884 m .62425 .27835 L .60665 .27064 L p
1 g
F P
s
P
p
.002 w
.66086 .53099 m .68727 .48569 L .68552 .46828 L p
1 g
F P
s
P
p
.002 w
.69581 .41786 m .68552 .46828 L .68727 .48569 L p
1 g
F P
s
P
p
.002 w
.68552 .46828 m .69581 .41786 L .6892 .39912 L p
1 g
F P
s
P
p
.002 w
.62229 .58009 m .65932 .5442 L .66086 .53099 L p
1 g
F P
s
P
p
.002 w
.68727 .48569 m .66086 .53099 L .65932 .5442 L p
1 g
F P
s
P
p
.002 w
.54838 .24381 m .49998 .23422 L .48997 .24 L p
1 g
F P
s
P
p
.002 w
.44466 .24542 m .48997 .24 L .49998 .23422 L p
1 g
F P
s
P
p
.002 w
.42801 .61425 m .47475 .62509 L .46291 .61771 L p
1 g
F P
s
P
p
.002 w
.46291 .61771 m .41249 .60593 L .42801 .61425 L p
1 g
F P
s
P
p
.002 w
.37154 .57991 m .41249 .60593 L .39987 .5932 L p
1 g
F P
s
P
p
.002 w
.39987 .5932 m .35696 .56581 L .37154 .57991 L p
1 g
F P
s
P
p
.002 w
.30326 .43641 m .31258 .48738 L .31232 .46684 L p
1 g
F P
s
P
p
.002 w
.31232 .46684 m .30341 .41762 L .30326 .43641 L p
1 g
F P
s
P
p
.002 w
.39729 .26212 m .35624 .2964 L .36622 .29355 L p
1 g
F P
s
P
p
.002 w
.36622 .29355 m .40158 .26405 L .39729 .26212 L p
1 g
F P
s
P
p
.002 w
.67985 .34949 m .6892 .39912 L .69581 .41786 L p
1 g
F P
s
P
p
.002 w
.6892 .39912 m .67985 .34949 L .66831 .33258 L p
1 g
F P
s
P
p
.002 w
.5642 .24437 m .60665 .27064 L .62425 .27835 L p
1 g
F P
s
P
p
.002 w
.60665 .27064 m .5642 .24437 L .54838 .24381 L p
1 g
F P
s
P
p
.002 w
.53344 .62492 m .5789 .61099 L .57641 .60692 L p
1 g
F P
s
P
p
.002 w
.57641 .60692 m .52577 .62242 L .53344 .62492 L p
1 g
F P
s
P
p
.002 w
.62229 .58009 m .57641 .60692 L .5789 .61099 L p
1 g
F P
s
P
p
.002 w
.49998 .23422 m .54838 .24381 L .5642 .24437 L p
1 g
F P
s
P
p
.002 w
.49998 .23422 m .44737 .24047 L .44466 .24542 L p
1 g
F P
s
P
p
.002 w
.40158 .26405 m .44466 .24542 L .44737 .24047 L p
1 g
F P
s
P
p
.002 w
.5789 .61099 m .62009 .58692 L .62229 .58009 L p
1 g
F P
s
P
p
.002 w
.65932 .5442 m .62229 .58009 L .62009 .58692 L p
1 g
F P
s
P
p
.002 w
.44737 .24047 m .39729 .26212 L .40158 .26405 L p
1 g
F P
s
P
p
.002 w
.32887 .52525 m .35696 .56581 L .34674 .54854 L p
1 g
F P
s
P
p
.002 w
.34674 .54854 m .31806 .50706 L .32887 .52525 L p
1 g
F P
s
P
p
.002 w
.31518 .36445 m .30341 .41762 L .30887 .39984 L p
1 g
F P
s
P
p
.002 w
.30887 .39984 m .31988 .35021 L .31518 .36445 L p
1 g
F P
s
P
p
.002 w
.48778 .62734 m .53344 .62492 L .52577 .62242 L p
1 g
F P
s
P
p
.002 w
.52577 .62242 m .47475 .62509 L .48778 .62734 L p
1 g
F P
s
P
p
.002 w
.34985 .30314 m .31988 .35021 L .32928 .33869 L p
1 g
F P
s
P
p
.002 w
.32928 .33869 m .35624 .2964 L .34985 .30314 L p
1 g
F P
s
P
p
.002 w
.66831 .33258 m .63902 .29057 L .62425 .27835 L p
1 g
F P
s
P
p
.002 w
.63902 .29057 m .66831 .33258 L .67985 .34949 L p
1 g
F P
s
P
p
.002 w
.65932 .5442 m .6839 .50222 L .68727 .48569 L p
1 g
F P
s
P
p
.002 w
.69721 .43761 m .68727 .48569 L .6839 .50222 L p
1 g
F P
s
P
p
.002 w
.68727 .48569 m .69721 .43761 L .69581 .41786 L p
1 g
F P
s
P
p
.004 w
.70085 .39397 m
.72053 .39039 L
s
P
p
.004 w
.72053 .39039 m
.7639 .3825 L
s
P
p
.002 w
.62009 .58692 m .65328 .55478 L .65932 .5442 L p
1 g
F P
s
P
p
.002 w
.6839 .50222 m .65932 .5442 L .65328 .55478 L p
1 g
F P
s
P
p
.002 w
.30872 .45572 m .31806 .50706 L .31258 .48738 L p
1 g
F P
s
P
p
.002 w
.31258 .48738 m .30326 .43641 L .30872 .45572 L p
1 g
F P
s
P
p
.002 w
.39028 .59024 m .42801 .61425 L .41249 .60593 L p
1 g
F P
s
P
p
.002 w
.41249 .60593 m .37154 .57991 L .39028 .59024 L p
1 g
F P
s
P
p
.002 w
.44615 .61767 m .48778 .62734 L .47475 .62509 L p
1 g
F P
s
P
p
.002 w
.47475 .62509 m .42801 .61425 L .44615 .61767 L p
1 g
F P
s
P
p
.002 w
.69581 .41786 m .68675 .36927 L .67985 .34949 L p
1 g
F P
s
P
p
.002 w
.68675 .36927 m .69581 .41786 L .69721 .43761 L p
1 g
F P
s
P
p
.002 w
.5642 .24437 m .51041 .23367 L .49998 .23422 L p
1 g
F P
s
P
p
.002 w
.44737 .24047 m .49998 .23422 L .51041 .23367 L p
1 g
F P
s
P
p
.002 w
.62425 .27835 m .57885 .25018 L .5642 .24437 L p
1 g
F P
s
P
p
.002 w
.57885 .25018 m .62425 .27835 L .63902 .29057 L p
1 g
F P
s
P
p
.002 w
.3957 .26486 m .34985 .30314 L .35624 .2964 L p
1 g
F P
s
P
p
.002 w
.35624 .2964 m .39729 .26212 L .3957 .26486 L p
1 g
F P
s
P
p
.002 w
.34495 .54133 m .37154 .57991 L .35696 .56581 L p
1 g
F P
s
P
p
.002 w
.35696 .56581 m .32887 .52525 L .34495 .54133 L p
1 g
F P
s
P
p
.002 w
.51041 .23367 m .5642 .24437 L .57885 .25018 L p
1 g
F P
s
P
p
.002 w
.54051 .62204 m .57927 .61016 L .5789 .61099 L p
1 g
F P
s
P
p
.002 w
.5789 .61099 m .53344 .62492 L .54051 .62204 L p
1 g
F P
s
P
p
.002 w
.62009 .58692 m .5789 .61099 L .57927 .61016 L p
1 g
F P
s
P
p
.002 w
.31559 .38114 m .30326 .43641 L .30341 .41762 L p
1 g
F P
s
P
p
.002 w
.30341 .41762 m .31518 .36445 L .31559 .38114 L p
1 g
F P
s
P
p
.002 w
.57927 .61016 m .61441 .58963 L .62009 .58692 L p
1 g
F P
s
P
p
.002 w
.65328 .55478 m .62009 .58692 L .61441 .58963 L p
1 g
F P
s
P
p
.002 w
.51041 .23367 m .45169 .24065 L .44737 .24047 L p
1 g
F P
s
P
p
.002 w
.39729 .26212 m .44737 .24047 L .45169 .24065 L p
1 g
F P
s
P
p
.002 w
.34749 .31381 m .31518 .36445 L .31988 .35021 L p
1 g
F P
s
P
p
.002 w
.31988 .35021 m .34985 .30314 L .34749 .31381 L p
1 g
F P
s
P
p
.002 w
.45169 .24065 m .3957 .26486 L .39729 .26212 L p
1 g
F P
s
P
p
.002 w
.65036 .30721 m .67985 .34949 L .68675 .36927 L p
1 g
F P
s
P
p
.002 w
.67985 .34949 m .65036 .30721 L .63902 .29057 L p
1 g
F P
s
P
p
.002 w
.50168 .62408 m .54051 .62204 L .53344 .62492 L p
1 g
F P
s
P
p
.002 w
.53344 .62492 m .48778 .62734 L .50168 .62408 L p
1 g
F P
s
P
p
.002 w
.65328 .55478 m .6752 .51735 L .6839 .50222 L p
1 g
F P
s
P
p
.002 w
.6839 .50222 m .69307 .45786 L .69721 .43761 L p
1 g
F P
s
P
p
.002 w
.69307 .45786 m .6839 .50222 L .6752 .51735 L p
1 g
F P
s
P
p
.002 w
.31992 .47496 m .32887 .52525 L .31806 .50706 L p
1 g
F P
s
P
p
.002 w
.31806 .50706 m .30872 .45572 L .31992 .47496 L p
1 g
F P
s
P
p
.002 w
.41282 .5963 m .44615 .61767 L .42801 .61425 L p
1 g
F P
s
P
p
.002 w
.42801 .61425 m .39028 .59024 L .41282 .5963 L p
1 g
F P
s
P
p
.002 w
.68854 .39146 m .69721 .43761 L .69307 .45786 L p
1 g
F P
s
P
p
.002 w
.69721 .43761 m .68854 .39146 L .68675 .36927 L p
1 g
F P
s
P
p
.002 w
.61441 .58963 m .64264 .56228 L .65328 .55478 L p
1 g
F P
s
P
p
.002 w
.6752 .51735 m .65328 .55478 L .64264 .56228 L p
1 g
F P
s
P
p
.002 w
.59181 .26136 m .63902 .29057 L .65036 .30721 L p
1 g
F P
s
P
p
.002 w
.63902 .29057 m .59181 .26136 L .57885 .25018 L p
1 g
F P
s
P
p
.002 w
.4665 .61582 m .50168 .62408 L .48778 .62734 L p
1 g
F P
s
P
p
.002 w
.48778 .62734 m .44615 .61767 L .4665 .61582 L p
1 g
F P
s
P
p
.002 w
.57885 .25018 m .52098 .23871 L .51041 .23367 L p
1 g
F P
s
P
p
.002 w
.45169 .24065 m .51041 .23367 L .52098 .23871 L p
1 g
F P
s
P
p
.002 w
.36606 .55469 m .39028 .59024 L .37154 .57991 L p
1 g
F P
s
P
p
.002 w
.37154 .57991 m .34495 .54133 L .36606 .55469 L p
1 g
F P
s
P
p
.002 w
.39705 .2725 m .34749 .31381 L .34985 .30314 L p
1 g
F P
s
P
p
.002 w
.34985 .30314 m .3957 .26486 L .39705 .2725 L p
1 g
F P
s
P
p
.002 w
.32141 .3999 m .30872 .45572 L .30326 .43641 L p
1 g
F P
s
P
p
.002 w
.30326 .43641 m .31559 .38114 L .32141 .3999 L p
1 g
F P
s
P
p
.002 w
.52098 .23871 m .57885 .25018 L .59181 .26136 L p
1 g
F P
s
P
p
.002 w
.65777 .32799 m .68675 .36927 L .68854 .39146 L p
1 g
F P
s
P
p
.002 w
.68675 .36927 m .65777 .32799 L .65036 .30721 L p
1 g
F P
s
P
p
.002 w
.54671 .61352 m .57738 .60413 L .57927 .61016 L p
1 g
F P
s
P
p
.002 w
.57927 .61016 m .54051 .62204 L .54671 .61352 L p
1 g
F P
s
P
p
.002 w
.61441 .58963 m .57927 .61016 L .57738 .60413 L p
1 g
F P
s
P
p
.002 w
.34948 .32832 m .31559 .38114 L .31518 .36445 L p
1 g
F P
s
P
p
.002 w
.31518 .36445 m .34749 .31381 L .34948 .32832 L p
1 g
F P
s
P
p
.002 w
.57738 .60413 m .60519 .58787 L .61441 .58963 L p
1 g
F P
s
P
p
.002 w
.64264 .56228 m .61441 .58963 L .60519 .58787 L p
1 g
F P
s
P
p
.002 w
.52098 .23871 m .45759 .24631 L .45169 .24065 L p
1 g
F P
s
P
p
.002 w
.3957 .26486 m .45169 .24065 L .45759 .24631 L p
1 g
F P
s
P
p
.002 w
.51609 .61506 m .54671 .61352 L .54051 .62204 L p
1 g
F P
s
P
p
.002 w
.54051 .62204 m .50168 .62408 L .51609 .61506 L p
1 g
F P
s
P
p
.002 w
.45759 .24631 m .39705 .2725 L .3957 .26486 L p
1 g
F P
s
P
p
.002 w
.33678 .49352 m .34495 .54133 L .32887 .52525 L p
1 g
F P
s
P
p
.002 w
.32887 .52525 m .31992 .47496 L .33678 .49352 L p
1 g
F P
s
P
p
.002 w
.64264 .56228 m .66114 .53055 L .6752 .51735 L p
1 g
F P
s
P
p
.002 w
.68322 .47801 m .6752 .51735 L .66114 .53055 L p
1 g
F P
s
P
p
.002 w
.6752 .51735 m .68322 .47801 L .69307 .45786 L p
1 g
F P
s
P
p
.002 w
.68492 .4155 m .69307 .45786 L .68322 .47801 L p
1 g
F P
s
P
p
.002 w
.69307 .45786 m .68492 .4155 L .68854 .39146 L p
1 g
F P
s
P
p
.002 w
.43861 .59768 m .4665 .61582 L .44615 .61767 L p
1 g
F P
s
P
p
.002 w
.44615 .61767 m .41282 .5963 L .43861 .59768 L p
1 g
F P
s
P
p
.002 w
.60259 .27788 m .65036 .30721 L .65777 .32799 L p
1 g
F P
s
P
p
.002 w
.65036 .30721 m .60259 .27788 L .59181 .26136 L p
1 g
F P
s
P
p
.002 w
.60519 .58787 m .62744 .56625 L .64264 .56228 L p
1 g
F P
s
P
p
.002 w
.66114 .53055 m .64264 .56228 L .62744 .56625 L p
1 g
F P
s
P
p
.002 w
.39173 .56477 m .41282 .5963 L .39028 .59024 L p
1 g
F P
s
P
p
.002 w
.39028 .59024 m .36606 .55469 L .39173 .56477 L p
1 g
F P
s
P
p
.002 w
.48854 .60847 m .51609 .61506 L .50168 .62408 L p
1 g
F P
s
P
p
.002 w
.50168 .62408 m .4665 .61582 L .48854 .60847 L p
1 g
F P
s
P
p
.002 w
.59181 .26136 m .53137 .24955 L .52098 .23871 L p
1 g
F P
s
P
p
.002 w
.45759 .24631 m .52098 .23871 L .53137 .24955 L p
1 g
F P
s
P
p
.002 w
.33272 .42022 m .31992 .47496 L .30872 .45572 L p
1 g
F P
s
P
p
.002 w
.30872 .45572 m .32141 .3999 L .33272 .42022 L p
1 g
F P
s
P
p
.002 w
.66079 .35244 m .68854 .39146 L .68492 .4155 L p
1 g
F P
s
P
p
.004 w
.68564 .39674 m
.70085 .39397 L
s
P
p
.002 w
.68854 .39146 m .66079 .35244 L .65777 .32799 L p
1 g
F P
s
P
p
.002 w
.53137 .24955 m .59181 .26136 L .60259 .27788 L p
1 g
F P
s
P
p
.002 w
.40149 .28511 m .34948 .32832 L .34749 .31381 L p
1 g
F P
s
P
p
.002 w
.34749 .31381 m .39705 .2725 L .40149 .28511 L p
1 g
F P
s
P
p
.002 w
.35602 .34643 m .32141 .3999 L .31559 .38114 L p
1 g
F P
s
P
p
.002 w
.31559 .38114 m .34948 .32832 L .35602 .34643 L p
1 g
F P
s
P
p
.002 w
.359 .51072 m .36606 .55469 L .34495 .54133 L p
1 g
F P
s
P
p
.002 w
.34495 .54133 m .33678 .49352 L .359 .51072 L p
1 g
F P
s
P
p
.002 w
.55179 .59926 m .57315 .59276 L .57738 .60413 L p
1 g
F P
s
P
p
.002 w
.57738 .60413 m .54671 .61352 L .55179 .59926 L p
1 g
F P
s
P
p
.002 w
.60519 .58787 m .57738 .60413 L .57315 .59276 L p
1 g
F P
s
P
p
.002 w
.62744 .56625 m .64186 .54129 L .66114 .53055 L p
1 g
F P
s
P
p
.002 w
.66771 .49742 m .66114 .53055 L .64186 .54129 L p
1 g
F P
s
P
p
.002 w
.66114 .53055 m .66771 .49742 L .68322 .47801 L p
1 g
F P
s
P
p
.002 w
.67575 .4407 m .68322 .47801 L .66771 .49742 L p
1 g
F P
s
P
p
.002 w
.68322 .47801 m .67575 .4407 L .68492 .4155 L p
1 g
F P
s
P
p
.002 w
.57315 .59276 m .59249 .58142 L .60519 .58787 L p
1 g
F P
s
P
p
.002 w
.62744 .56625 m .60519 .58787 L .59249 .58142 L p
1 g
F P
s
P
p
.002 w
.53137 .24955 m .46499 .25763 L .45759 .24631 L p
1 g
F P
s
P
p
.002 w
.39705 .2725 m .45759 .24631 L .46499 .25763 L p
1 g
F P
s
P
p
.002 w
.53056 .60027 m .55179 .59926 L .54671 .61352 L p
1 g
F P
s
P
p
.002 w
.54671 .61352 m .51609 .61506 L .53056 .60027 L p
1 g
F P
s
P
p
.002 w
.46499 .25763 m .40149 .28511 L .39705 .2725 L p
1 g
F P
s
P
p
.002 w
.46693 .59414 m .48854 .60847 L .4665 .61582 L p
1 g
F P
s
P
p
.002 w
.4665 .61582 m .43861 .59768 L .46693 .59414 L p
1 g
F P
s
P
p
.002 w
.6107 .29949 m .65777 .32799 L .66079 .35244 L p
1 g
F P
s
P
p
.002 w
.65777 .32799 m .6107 .29949 L .60259 .27788 L p
1 g
F P
s
P
p
.002 w
.42127 .57109 m .43861 .59768 L .41282 .5963 L p
1 g
F P
s
P
p
.002 w
.41282 .5963 m .39173 .56477 L .42127 .57109 L p
1 g
F P
s
P
p
.002 w
.59249 .58142 m .60789 .56638 L .62744 .56625 L p
1 g
F P
s
P
p
.002 w
.64186 .54129 m .62744 .56625 L .60789 .56638 L p
1 g
F P
s
P
p
.002 w
.65912 .37993 m .68492 .4155 L .67575 .4407 L p
1 g
F P
s
P
p
.002 w
.68492 .4155 m .65912 .37993 L .66079 .35244 L p
1 g
F P
s
P
p
.004 w
.67749 .39822 m
.68564 .39674 L
s
P
p
.002 w
.34943 .44148 m .33678 .49352 L .31992 .47496 L p
1 g
F P
s
P
p
.002 w
.31992 .47496 m .33272 .42022 L .34943 .44148 L p
1 g
F P
s
P
p
.002 w
.51159 .59559 m .53056 .60027 L .51609 .61506 L p
1 g
F P
s
P
p
.002 w
.51609 .61506 m .48854 .60847 L .51159 .59559 L p
1 g
F P
s
P
p
.002 w
.54124 .26616 m .60259 .27788 L .6107 .29949 L p
1 g
F P
s
P
p
.002 w
.60259 .27788 m .54124 .26616 L .53137 .24955 L p
1 g
F P
s
P
p
.002 w
.46499 .25763 m .53137 .24955 L .54124 .26616 L p
1 g
F P
s
P
p
.002 w
.38601 .52593 m .39173 .56477 L .36606 .55469 L p
1 g
F P
s
P
p
.002 w
.36606 .55469 m .359 .51072 L .38601 .52593 L p
1 g
F P
s
P
p
.002 w
.40905 .30258 m .35602 .34643 L .34948 .32832 L p
1 g
F P
s
P
p
.002 w
.34948 .32832 m .40149 .28511 L .40905 .30258 L p
1 g
F P
s
P
p
.002 w
.36714 .36771 m .33272 .42022 L .32141 .3999 L p
1 g
F P
s
P
p
.002 w
.32141 .3999 m .35602 .34643 L .36714 .36771 L p
1 g
F P
s
P
p
.002 w
.64186 .54129 m .64678 .51541 L .66771 .49742 L p
1 g
F P
s
P
p
.002 w
.66112 .46625 m .66771 .49742 L .64678 .51541 L p
1 g
F P
s
P
p
.002 w
.66771 .49742 m .66112 .46625 L .67575 .4407 L p
1 g
F P
s
P
p
.002 w
.60789 .56638 m .61775 .54909 L .64186 .54129 L p
1 g
F P
s
P
p
.002 w
.64678 .51541 m .64186 .54129 L .61775 .54909 L p
1 g
F P
s
P
p
.002 w
.61576 .3257 m .66079 .35244 L .65912 .37993 L p
1 g
F P
s
P
p
.002 w
.66079 .35244 m .61576 .3257 L .6107 .29949 L p
1 g
F P
s
P
p
.002 w
.49691 .5856 m .51159 .59559 L .48854 .60847 L p
1 g
F P
s
P
p
.002 w
.48854 .60847 m .46693 .59414 L .49691 .5856 L p
1 g
F P
s
P
p
.002 w
.45379 .5733 m .46693 .59414 L .43861 .59768 L p
1 g
F P
s
P
p
.002 w
.43861 .59768 m .42127 .57109 L .45379 .5733 L p
1 g
F P
s
P
p
.002 w
.55552 .57941 m .56655 .57607 L .57315 .59276 L p
1 g
F P
s
P
p
.002 w
.57315 .59276 m .55179 .59926 L .55552 .57941 L p
1 g
F P
s
P
p
.002 w
.59249 .58142 m .57315 .59276 L .56655 .57607 L p
1 g
F P
s
P
p
.002 w
.56655 .57607 m .57653 .57021 L .59249 .58142 L p
1 g
F P
s
P
p
.002 w
.60789 .56638 m .59249 .58142 L .57653 .57021 L p
1 g
F P
s
P
p
.002 w
.5446 .57988 m .55552 .57941 L .55179 .59926 L p
1 g
F P
s
P
p
.002 w
.55179 .59926 m .53056 .60027 L .5446 .57988 L p
1 g
F P
s
P
p
.002 w
.54124 .26616 m .47373 .27457 L .46499 .25763 L p
1 g
F P
s
P
p
.002 w
.40149 .28511 m .46499 .25763 L .47373 .27457 L p
1 g
F P
s
P
p
.002 w
.65263 .40962 m .67575 .4407 L .66112 .46625 L p
1 g
F P
s
P
p
.002 w
.67575 .4407 m .65263 .40962 L .65912 .37993 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.65419 .40246 L
s
P
p
.004 w
.66655 .40021 m
.66786 .39997 L
s
P
p
.004 w
.66786 .39997 m
.675 .39867 L
s
P
p
.004 w
.675 .39867 m
.67749 .39822 L
s
P
p
.002 w
.47373 .27457 m .40905 .30258 L .40149 .28511 L p
1 g
F P
s
P
p
.002 w
.37116 .46296 m .359 .51072 L .33678 .49352 L p
1 g
F P
s
P
p
.002 w
.33678 .49352 m .34943 .44148 L .37116 .46296 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.57653 .57021 m .58443 .56243 L .60789 .56638 L p
1 g
F P
s
P
p
.002 w
.61775 .54909 m .60789 .56638 L .58443 .56243 L p
1 g
F P
s
P
p
.002 w
.53492 .57741 m .5446 .57988 L .53056 .60027 L p
1 g
F P
s
P
p
.002 w
.53056 .60027 m .51159 .59559 L .53492 .57741 L p
1 g
F P
s
P
p
.002 w
.41698 .53852 m .42127 .57109 L .39173 .56477 L p
1 g
F P
s
P
p
.002 w
.39173 .56477 m .38601 .52593 L .41698 .53852 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.55021 .2883 m .6107 .29949 L .61576 .3257 L p
1 g
F P
s
P
p
.002 w
.6107 .29949 m .55021 .2883 L .54124 .26616 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.61775 .54909 m .62093 .5313 L .64678 .51541 L p
1 g
F P
s
P
p
.002 w
.64133 .49128 m .64678 .51541 L .62093 .5313 L p
1 g
F P
s
P
p
.002 w
.64678 .51541 m .64133 .49128 L .66112 .46625 L p
1 g
F P
s
P
p
.002 w
.47373 .27457 m .54124 .26616 L .55021 .2883 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.54482 .52672 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.38265 .39156 m .34943 .44148 L .33272 .42022 L p
1 g
F P
s
P
p
.002 w
.33272 .42022 m .36714 .36771 L .38265 .39156 L p
1 g
F P
s
P
p
.002 w
.58443 .56243 m .58941 .55354 L .61775 .54909 L p
1 g
F P
s
P
p
.002 w
.62093 .5313 m .61775 .54909 L .58941 .55354 L p
1 g
F P
s
P
p
.002 w
.61743 .35579 m .65912 .37993 L .65263 .40962 L p
1 g
F P
s
P
p
.002 w
.65912 .37993 m .61743 .35579 L .61576 .3257 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49691 .5856 m .46693 .59414 L p
.48014 .57989 L 1 g
F P
s
P
p
.48014 .57989 m .48148 .57845 L .4857 .58041 L 1 g
F
P
p
.48014 .57989 m .4857 .58041 L .49691 .5856 L 1 g
F
P
p
.002 w
.49503 .58251 m .49691 .5856 L p
.4857 .58041 L 1 g
F P
s
P
p
.48148 .57845 m .48905 .58072 L .4857 .58041 L 1 g
F
P
p
.48905 .58072 m .49503 .58251 L .4857 .58041 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58072 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58072 L .49424 .5812 L 1 g
F
P
p
.51079 .57862 m .49424 .5812 L .49848 .58108 L 1 g
F
P
p
.002 w
.49691 .5856 m .49424 .5812 L p
.50279 .58096 L 1 g
F P
s
P
p
.002 w
.50784 .58083 m .49691 .5856 L p
.50279 .58096 L 1 g
F P
s
P
p
.51079 .57862 m .49674 .58143 L .49715 .58147 L 1 g
F
P
p
.002 w
.51159 .59559 m .49691 .5856 L .50784 .58083 L p
1 g
F P
s
P
p
.51159 .59559 m .50799 .58142 L .52225 .57996 L 1 g
F
P
p
.50799 .58142 m .50784 .58083 L .51094 .58064 L 1 g
F
P
p
.50799 .58142 m .51094 .58064 L .52225 .57996 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58064 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58064 L .52077 .57804 L 1 g
F
P
p
.002 w
.51094 .58064 m .51079 .57862 L p
.49715 .58147 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.53128 .57265 m .52077 .57804 L .53171 .57515 L 1 g
F
P
p
.002 w
.54063 .57163 m .53492 .57741 L .53173 .57517 L p
1 g
F P
s
P
p
.002 w
.53173 .57517 m .53171 .57515 L p
.53182 .57511 L 1 g
F P
s
P
p
.53173 .57517 m .53182 .57511 L .54063 .57163 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53182 .57511 L p
1 g
F P
s
P
p
.54854 .56129 m .53182 .57511 L .53978 .56964 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.54854 .56129 m .53978 .56964 L .54854 .56362 L 1 g
F
P
p
.002 w
.55537 .55888 m .5446 .57988 L p
.54843 .56406 L 1 g
F P
s
P
p
.54843 .56406 m .54854 .56362 L .54923 .56314 L 1 g
F
P
p
.54843 .56406 m .54923 .56314 L .55537 .55888 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54923 .56314 L p
1 g
F P
s
P
p
.56075 .54566 m .54923 .56314 L .55078 .56136 L 1 g
F
P
p
.002 w
.55592 .55541 m .55769 .55436 L .55078 .56136 L p
1 g
F P
s
P
p
.55441 .55716 m .55078 .56136 L .55439 .55719 L 1 g
F
P
p
.56075 .54566 m .55078 .56136 L .55441 .55716 L 1 g
F
P
p
.002 w
.54923 .56314 m .54854 .56129 L p
.54854 .56362 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55769 .55436 m .55537 .55888 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.54854 .56362 m .55078 .56136 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.55078 .56136 m .55769 .55436 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.56655 .57607 m .55552 .57941 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.57653 .57021 m .56655 .57607 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.58443 .56243 m .57653 .57021 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.55552 .57941 m .5446 .57988 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.58941 .55354 m .58443 .56243 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.59091 .54447 m .58941 .55354 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.58873 .53618 m .59091 .54447 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.58305 .52958 m .58873 .53618 L .55769 .55436 L closepath p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .54739 L p
1 g
F P
s
P
p
.56654 .52734 m .56167 .54739 L .56167 .54738 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56759 .52888 L p
1 g
F P
s
P
p
.002 w
.5689 .52479 m .57444 .52543 L .56785 .53681 L p
1 g
F P
s
P
p
.5689 .52479 m .56785 .53681 L .5676 .52898 L 1 g
F
P
p
.5689 .52479 m .56205 .54684 L .56167 .54739 L 1 g
F
P
p
.56515 .50826 m .56759 .52888 L .56746 .52463 L 1 g
F
P
p
.002 w
.56593 .5078 m .56813 .49057 L p
.56769 .5128 L 1 g
F P
s
P
p
.56769 .5128 m .56746 .52463 L .56608 .50936 L 1 g
F
P
p
.56769 .5128 m .56608 .50936 L .56593 .5078 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56608 .50936 L p
1 g
F P
s
P
p
.55661 .4905 m .56608 .50936 L .56581 .50879 L 1 g
F
P
p
.002 w
.5579 .49221 m .55823 .49215 L p
.56581 .50879 L 1 g
F P
s
P
p
.002 w
.55823 .49215 m .56813 .49057 L .56687 .50049 L p
1 g
F P
s
P
p
.002 w
.56687 .50049 m .56581 .50879 L p
.55823 .49215 L 1 g
F P
s
P
p
.55661 .4905 m .56581 .50879 L .56202 .50085 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56515 .50826 m .56746 .52463 L .56715 .52121 L 1 g
F
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.57444 .52543 m .56746 .52463 L p
.56813 .49057 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56075 .54566 L p
.55712 .55395 L 1 g
F P
s
P
p
.002 w
.55727 .55375 m .55769 .55436 L .5571 .55398 L p
1 g
F P
s
P
p
.55712 .55395 m .55712 .55397 L .55719 .55386 L 1 g
F
P
p
.55712 .55395 m .55719 .55386 L .56167 .54739 L 1 g
F
P
p
.55712 .55397 m .55738 .5536 L .56167 .54739 L 1 g
F
P
p
.56075 .54566 m .55439 .55719 L .55509 .55639 L 1 g
F
P
p
.56075 .54566 m .55509 .55639 L .55651 .55472 L 1 g
F
P
p
.002 w
.55677 .5544 m .55769 .55436 L .55651 .55472 L p
1 g
F P
s
P
p
.55666 .55453 m .55651 .55472 L .55666 .55454 L 1 g
F
P
p
.56075 .54566 m .55651 .55472 L .55666 .55453 L 1 g
F
P
p
.56075 .54566 m .55666 .55454 L .55678 .55439 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.52324 .56484 m .52258 .55604 L .55677 .5544 L p
1 g
F P
s
P
p
.002 w
.55651 .55472 m .52324 .56484 L p
.55677 .5544 L 1 g
F P
s
P
p
.56075 .54566 m .55677 .55441 L .55703 .55407 L 1 g
F
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.52258 .55604 m .52566 .54677 L .55695 .55418 L p
1 g
F P
s
P
p
.002 w
.55695 .55418 m .55769 .55436 L .55677 .5544 L p
1 g
F P
s
P
p
.002 w
.55677 .5544 m .52258 .55604 L p
.55695 .55418 L 1 g
F P
s
P
p
.55678 .55439 m .55666 .55454 L .55677 .55441 L 1 g
F
P
p
.55703 .55407 m .55677 .55441 L .557 .55414 L 1 g
F
P
p
.56075 .54566 m .55696 .55422 L .55707 .55406 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.52566 .54677 m .53218 .53806 L .5571 .55398 L p
1 g
F P
s
P
p
.002 w
.5571 .55398 m .55769 .55436 L .55695 .55418 L p
1 g
F P
s
P
p
.002 w
.55695 .55418 m .52566 .54677 L p
.5571 .55398 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.52753 .57222 m .52324 .56484 L .55651 .55472 L p
1 g
F P
s
P
p
.002 w
.55651 .55472 m .55769 .55436 L .55592 .55541 L p
1 g
F P
s
P
p
.002 w
.55592 .55541 m .52753 .57222 L p
.55651 .55472 L 1 g
F P
s
P
p
.557 .55414 m .55509 .55639 L .55696 .55422 L 1 g
F
P
p
.55707 .55406 m .55696 .55422 L .55705 .55413 L 1 g
F
P
p
.5571 .55401 m .55804 .55266 L .56167 .54739 L 1 g
F
P
p
.56449 .53859 m .56167 .54739 L .56444 .53883 L 1 g
F
P
p
.56654 .52734 m .56167 .54738 L .56449 .53859 L 1 g
F
P
p
.56167 .54738 m .56167 .54739 L .56449 .53859 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56785 .53681 m .56205 .54684 L p
.5676 .52898 L 1 g
F P
s
P
p
.002 w
.58305 .52958 m .56021 .5519 L p
.56205 .54684 L 1 g
F P
s
P
p
.002 w
.56205 .54684 m .57444 .52543 L .57617 .52626 L p
1 g
F P
s
P
p
.002 w
.57617 .52626 m .58305 .52958 L p
.56205 .54684 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56384 .52422 m .56746 .52463 L p
.55844 .55207 L 1 g
F P
s
P
p
.002 w
.55769 .55436 m .55804 .55266 L p
.55844 .55207 L 1 g
F P
s
P
p
.002 w
.55804 .55266 m .56384 .52422 L p
.55844 .55207 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.53218 .53806 m .54144 .5309 L .55727 .55375 L p
1 g
F P
s
P
p
.002 w
.5571 .55398 m .53218 .53806 L p
.55727 .55375 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54144 .5309 m .55241 .52611 L .55752 .55341 L p
1 g
F P
s
P
p
.002 w
.55752 .55341 m .55769 .55436 L .55727 .55375 L p
1 g
F P
s
P
p
.002 w
.55727 .55375 m .54144 .5309 L p
.55752 .55341 L 1 g
F P
s
P
p
.55712 .55397 m .5571 .55401 L .55738 .5536 L 1 g
F
P
p
.5571 .55401 m .55707 .55406 L .55804 .55266 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55241 .52611 m .56384 .52422 L .55804 .55266 L p
1 g
F P
s
P
p
.002 w
.55804 .55266 m .55769 .55436 L .55752 .55341 L p
1 g
F P
s
P
p
.002 w
.55752 .55341 m .55241 .52611 L p
.55804 .55266 L 1 g
F P
s
P
p
.002 w
.56746 .52463 m .5689 .52479 L p
.56758 .52829 L 1 g
F P
s
P
p
.55844 .55207 m .5587 .5517 L .55769 .55436 L 1 g
F
P
p
.002 w
.56159 .54762 m .55769 .55436 L p
.5689 .52479 L 1 g
F P
s
P
p
.002 w
.56021 .5519 m .55769 .55436 L .56159 .54762 L p
1 g
F P
s
P
p
.002 w
.56159 .54762 m .56205 .54684 L p
.56021 .5519 L 1 g
F P
s
P
p
.55696 .55422 m .54998 .56518 L .56213 .54826 L 1 g
F
P
p
.55439 .55719 m .55225 .56107 L .55696 .55422 L 1 g
F
P
p
.55225 .56107 m .54998 .56518 L .55696 .55422 L 1 g
F
P
p
.56746 .52463 m .56758 .52829 L .5587 .5517 L 1 g
F
P
p
.56746 .52463 m .5587 .5517 L .55844 .55207 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .567 .51046 L p
1 g
F P
s
P
p
.002 w
.567 .51046 m .56515 .50826 L p
.5674 .52284 L 1 g
F P
s
P
p
.5674 .52284 m .56854 .53025 L .567 .51046 L 1 g
F
P
p
.002 w
.56746 .52463 m .56384 .52422 L .56581 .50879 L p
1 g
F P
s
P
p
.002 w
.56581 .50879 m .56593 .5078 L p
.56608 .50936 L 1 g
F P
s
P
p
.56608 .50936 m .56746 .52463 L .56581 .50879 L 1 g
F
P
p
.002 w
.56813 .49057 m .55823 .49215 L p
.54624 .46907 L 1 g
F P
s
P
p
.002 w
.55823 .49215 m .5579 .49221 L p
.55753 .49148 L 1 g
F P
s
P
p
.54624 .46907 m .55823 .49215 L .55753 .49148 L 1 g
F
P
p
.002 w
.55757 .49152 m .55661 .4905 L p
.5567 .49067 L 1 g
F P
s
P
p
.5567 .49067 m .56262 .502 L .55757 .49152 L 1 g
F
P
p
.002 w
.55784 .4918 m .55757 .49152 L p
.56262 .502 L 1 g
F P
s
P
p
.54174 .47608 m .55681 .49078 L .54996 .48413 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55753 .49148 L p
1 g
F P
s
P
p
.54174 .47608 m .55753 .49148 L .55681 .49078 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.5579 .49221 m .54537 .49421 L p
.54586 .48015 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54174 .47608 L p
.54996 .48413 L 1 g
F P
s
P
p
.54624 .46907 m .55753 .49148 L .54586 .48015 L 1 g
F
P
p
.55753 .49148 m .5579 .49221 L .54586 .48015 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54537 .49421 m .54084 .47603 L p
.54586 .48015 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54232 .47671 L p
1 g
F P
s
P
p
.52214 .46667 m .54232 .47671 L .54084 .47603 L 1 g
F
P
p
.002 w
.54084 .47603 m .54537 .49421 L p
.52165 .46709 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .46719 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .46719 L .52047 .46693 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.52047 .46693 m .50455 .47387 L .49859 .46412 L p
1 g
F P
s
P
p
.5 .46388 m .52047 .46693 L .49859 .46412 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49859 .46412 m .50455 .47387 L p
.46887 .4713 L 1 g
F P
s
P
p
.47765 .46702 m .49859 .46412 L .46887 .4713 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47765 .46702 L p
1 g
F P
s
P
p
.45826 .47608 m .47765 .46702 L .46619 .4726 L 1 g
F
P
p
.45826 .47608 m .46619 .4726 L .45776 .47671 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45776 .47671 m .47756 .49511 L p
.44721 .48685 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44279 .49114 L p
1 g
F P
s
P
p
.42692 .50343 m .44516 .4863 L .43763 .50167 L 1 g
F
P
p
.002 w
.44279 .49114 m .44166 .49233 L p
.43792 .50108 L 1 g
F P
s
P
p
.43485 .50826 m .44279 .49114 L .43792 .50108 L 1 g
F
P
p
.002 w
.42692 .50343 m .44 .48489 L p
.44516 .4863 L 1 g
F P
s
P
p
.002 w
.44279 .49114 m .44339 .4905 L p
.44894 .48518 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.41698 .53852 m .42692 .50343 L .43404 .5073 L p
1 g
F P
s
P
p
.002 w
.43404 .5073 m .4347 .50766 L p
.43394 .50897 L 1 g
F P
s
P
p
.41698 .53852 m .43404 .5073 L .43394 .50897 L 1 g
F
P
p
.002 w
.43282 .52827 m .43346 .52734 L p
.43324 .52106 L 1 g
F P
s
P
p
.002 w
.43392 .50936 m .43485 .50826 L p
.43792 .50108 L 1 g
F P
s
P
p
.002 w
.4347 .50766 m .42692 .50343 L p
.43763 .50167 L 1 g
F P
s
P
p
.43792 .50108 m .44148 .49277 L .4347 .50766 L 1 g
F
P
p
.43792 .50108 m .4347 .50766 L .43392 .50936 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.47756 .49511 m .45901 .52086 L .4347 .50766 L p
1 g
F P
s
P
p
.43763 .50167 m .47756 .49511 L .4347 .50766 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.42152 .53661 m .42995 .51809 L .43373 .53148 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43282 .52827 L p
1 g
F P
s
P
p
.43925 .54566 m .43282 .52827 L .43553 .53784 L 1 g
F
P
p
.002 w
.43732 .54418 m .41698 .53852 L p
.43373 .53148 L 1 g
F P
s
P
p
.43925 .54566 m .43173 .52986 L .43332 .53393 L 1 g
F
P
p
.42127 .57109 m .43683 .54501 L .44162 .55521 L 1 g
F
P
p
.43683 .54501 m .43732 .54418 L .43847 .54713 L 1 g
F
P
p
.43683 .54501 m .43847 .54713 L .44162 .55521 L 1 g
F
P
p
.43925 .54566 m .43582 .53888 L .43732 .54418 L 1 g
F
P
p
.002 w
.43826 .54752 m .43847 .54713 L p
.43732 .54418 L 1 g
F P
s
P
p
.002 w
.43847 .54713 m .43925 .54566 L p
.43732 .54418 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43847 .54713 L p
1 g
F P
s
P
p
.44162 .55521 m .43847 .54713 L .44355 .5537 L 1 g
F
P
p
.45146 .56129 m .43847 .54713 L .44526 .5559 L 1 g
F
P
p
.002 w
.4508 .56306 m .45146 .56129 L p
.44526 .5559 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45379 .5733 m .42127 .57109 L p
.44128 .55548 L 1 g
F P
s
P
p
.002 w
.4528 .56466 m .45379 .5733 L p
.44128 .55548 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45072 .56329 L p
1 g
F P
s
P
p
.46872 .57265 m .45072 .56329 L .45735 .56765 L 1 g
F
P
p
.002 w
.45379 .5733 m .4528 .56466 L p
.46018 .56951 L 1 g
F P
s
P
p
.45911 .56881 m .45025 .56454 L .45508 .5672 L 1 g
F
P
p
.46872 .57265 m .45735 .56765 L .45911 .56881 L 1 g
F
P
p
.45735 .56765 m .45025 .56454 L .45911 .56881 L 1 g
F
P
p
.002 w
.46491 .57263 m .45379 .5733 L p
.46018 .56951 L 1 g
F P
s
P
p
.002 w
.46693 .59414 m .45379 .5733 L .46491 .57263 L p
1 g
F P
s
P
p
.46693 .59414 m .46499 .57351 L .47944 .58065 L 1 g
F
P
p
.46499 .57351 m .46491 .57263 L .46831 .57451 L 1 g
F
P
p
.46499 .57351 m .46831 .57451 L .47944 .58065 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57451 L p
1 g
F P
s
P
p
.48921 .57862 m .46831 .57451 L .47934 .57781 L 1 g
F
P
p
.46872 .57265 m .4569 .56793 L .45804 .56883 L 1 g
F
P
p
.002 w
.46784 .57665 m .46831 .57451 L p
.45804 .56883 L 1 g
F P
s
P
p
.002 w
.46831 .57451 m .46872 .57265 L p
.45804 .56883 L 1 g
F P
s
P
p
.002 w
.48905 .58072 m .48921 .57862 L p
.47934 .57781 L 1 g
F P
s
P
p
.002 w
.46491 .57263 m .48818 .57122 L p
.47944 .58065 L 1 g
F P
s
P
p
.002 w
.46831 .57451 m .4678 .57686 L p
.47934 .57781 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.4509 .54797 m .48653 .55389 L p
.46018 .56951 L 1 g
F P
s
P
p
.002 w
.4528 .56466 m .4509 .54797 L p
.46018 .56951 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48653 .55389 m .48818 .57122 L .46491 .57263 L p
1 g
F P
s
P
p
.46018 .56951 m .48653 .55389 L .46491 .57263 L 1 g
F
P
p
.002 w
.45072 .56329 m .45025 .56454 L p
.45735 .56765 L 1 g
F P
s
P
p
.002 w
.45025 .56454 m .45002 .56518 L p
.45508 .5672 L 1 g
F P
s
P
p
.002 w
.4509 .54797 m .4528 .56466 L p
.44128 .55548 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46784 .57665 L p
1 g
F P
s
P
p
.4569 .56793 m .45002 .56518 L .46784 .57665 L 1 g
F
P
p
.002 w
.43847 .54713 m .43743 .5491 L p
.44526 .5559 L 1 g
F P
s
P
p
.002 w
.43732 .54418 m .4509 .54797 L p
.44355 .5537 L 1 g
F P
s
P
p
.43847 .54713 m .43732 .54418 L .44355 .5537 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4508 .56306 L p
1 g
F P
s
P
p
.44526 .5559 m .43743 .5491 L .4508 .56306 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45901 .52086 m .4509 .54797 L .43732 .54418 L p
1 g
F P
s
P
p
.43373 .53148 m .45901 .52086 L .43732 .54418 L 1 g
F
P
p
.002 w
.43282 .52827 m .43173 .52986 L p
.43553 .53784 L 1 g
F P
s
P
p
.002 w
.43173 .52986 m .43146 .53025 L p
.43332 .53393 L 1 g
F P
s
P
p
.002 w
.42127 .57109 m .41698 .53852 L .43732 .54418 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43392 .50936 L p
1 g
F P
s
P
p
.42995 .51809 m .43392 .50936 L .43282 .52827 L 1 g
F
P
p
.41698 .53852 m .4347 .50766 L .42152 .53661 L 1 g
F
P
p
.002 w
.43392 .50936 m .43287 .51061 L p
.43324 .52106 L 1 g
F P
s
P
p
.43346 .52734 m .43392 .50936 L .43324 .52106 L 1 g
F
P
p
.43282 .52827 m .4347 .50766 L .43373 .53148 L 1 g
F
P
p
.43392 .50936 m .4347 .50766 L .43282 .52827 L 1 g
F
P
p
.002 w
.4347 .50766 m .45901 .52086 L p
.43373 .53148 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43826 .54752 L p
1 g
F P
s
P
p
.43582 .53888 m .43146 .53025 L .43826 .54752 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43282 .52827 L p
1 g
F P
s
P
p
.43324 .52106 m .43287 .51061 L .43282 .52827 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43392 .50936 L p
1 g
F P
s
P
p
.44148 .49277 m .44166 .49233 L .43392 .50936 L 1 g
F
P
p
.43763 .50167 m .44279 .49114 L .47756 .49511 L 1 g
F
P
p
.45763 .47677 m .45776 .47671 L .44721 .48685 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45763 .47677 L p
1 g
F P
s
P
p
.002 w
.45763 .47677 m .45698 .47747 L p
.44894 .48518 L 1 g
F P
s
P
p
.44339 .4905 m .45763 .47677 L .44894 .48518 L 1 g
F
P
p
.002 w
.44 .48489 m .45052 .46997 L .45773 .47667 L p
1 g
F P
s
P
p
.002 w
.45763 .47677 m .45826 .47608 L p
.45776 .47671 L 1 g
F P
s
P
p
.002 w
.45773 .47667 m .45776 .47671 L p
.45763 .47677 L 1 g
F P
s
P
p
.44 .48489 m .45773 .47667 L .45763 .47677 L 1 g
F
P
p
.44279 .49114 m .44516 .4863 L .44721 .48685 L 1 g
F
P
p
.44279 .49114 m .44721 .48685 L .47756 .49511 L 1 g
F
P
p
.44 .48489 m .45763 .47677 L .44721 .48685 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44279 .49114 L p
1 g
F P
s
P
p
.44894 .48518 m .45698 .47747 L .44279 .49114 L 1 g
F
P
p
.002 w
.45762 .47678 m .45763 .47677 L p
.45776 .47671 L 1 g
F P
s
P
p
.002 w
.50455 .47387 m .47756 .49511 L .45052 .46997 L p
1 g
F P
s
P
p
.002 w
.47765 .46702 m .47718 .46778 L p
.46619 .4726 L 1 g
F P
s
P
p
.45052 .46997 m .47861 .46655 L .45434 .47025 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .49859 .46412 L 1 g
F
P
p
.48654 .46579 m .49859 .46412 L .49189 .46524 L 1 g
F
P
p
.47786 .46667 m .49859 .46412 L .48654 .46579 L 1 g
F
P
p
.002 w
.47723 .4677 m .47786 .46667 L p
.49189 .46524 L 1 g
F P
s
P
p
.47861 .46655 m .49859 .46412 L .47765 .46702 L 1 g
F
P
p
.47861 .46655 m .47765 .46702 L .45434 .47025 L 1 g
F
P
p
.45434 .47025 m .47765 .46702 L .46887 .4713 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45762 .47678 L p
1 g
F P
s
P
p
.46619 .4726 m .47718 .46778 L .45762 .47678 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.45052 .46997 m .48528 .44236 L .49859 .46412 L p
1 g
F P
s
P
p
.49189 .46524 m .49859 .46412 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46388 m .5 .46392 L p
.49859 .46412 L 1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .46442 L p
.49859 .46412 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49829 .46363 m .48528 .44236 L p
.51298 .4617 L 1 g
F P
s
P
p
.5 .4634 m .52047 .46693 L .51109 .46553 L 1 g
F
P
p
.002 w
.50455 .47387 m .52047 .46693 L p
.54537 .49421 L 1 g
F P
s
P
p
.52047 .46693 m .52165 .46709 L .54537 .49421 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4642 L p
1 g
F P
s
P
p
.002 w
.5 .4642 m .5 .4634 L p
.51358 .46601 L 1 g
F P
s
P
p
.51358 .46601 m .52282 .46778 L .5 .4642 L 1 g
F
P
p
.002 w
.52047 .46693 m .52122 .4666 L p
.52165 .46709 L 1 g
F P
s
P
p
.51298 .4617 m .52047 .46693 L .5 .46388 L 1 g
F
P
p
.51298 .4617 m .5 .46388 L .49829 .46363 L 1 g
F
P
p
.002 w
.49859 .46412 m .49829 .46363 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47723 .4677 L p
1 g
F P
s
P
p
.49189 .46524 m .5 .46442 L .47723 .4677 L 1 g
F
P
p
.51109 .46553 m .52047 .46693 L .51358 .46601 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5368 .45981 m .52047 .46693 L p
.48528 .44236 L 1 g
F P
s
P
p
.52122 .4666 m .52246 .46719 L .52165 .46709 L 1 g
F
P
p
.52246 .46719 m .54084 .47603 L .52165 .46709 L 1 g
F
P
p
.002 w
.52246 .46719 m .52282 .46778 L p
.51358 .46601 L 1 g
F P
s
P
p
.53212 .47184 m .54084 .47603 L .53471 .47318 L 1 g
F
P
p
.52214 .46667 m .54084 .47603 L .53212 .47184 L 1 g
F
P
p
.54232 .47671 m .54586 .48015 L .54084 .47603 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52122 .4666 m .5368 .45981 L .54084 .47603 L p
1 g
F P
s
P
p
.002 w
.54084 .47603 m .5406 .47504 L p
.54232 .47671 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54302 .47747 L p
.53471 .47318 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .55784 .4918 L p
.5648 .5059 L 1 g
F P
s
P
p
.56262 .502 m .56713 .51061 L .55784 .4918 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54232 .47671 L p
1 g
F P
s
P
p
.54996 .48413 m .55834 .49233 L .54232 .47671 L 1 g
F
P
p
.54996 .48413 m .55757 .49152 L .55314 .48725 L 1 g
F
P
p
.55681 .49078 m .55757 .49152 L .54996 .48413 L 1 g
F
P
p
.002 w
.55753 .49148 m .55757 .49152 L p
.55681 .49078 L 1 g
F P
s
P
p
.5368 .45981 m .54624 .46907 L .54586 .48015 L 1 g
F
P
p
.002 w
.5406 .47504 m .5368 .45981 L p
.54586 .48015 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56613 .50855 L p
.5648 .5059 L 1 g
F P
s
P
p
.002 w
.56613 .50855 m .55834 .49233 L p
.5648 .5059 L 1 g
F P
s
P
p
.002 w
.55757 .49152 m .55834 .49233 L p
.55314 .48725 L 1 g
F P
s
P
p
.56202 .50085 m .56581 .50879 L .56262 .502 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.54537 .49421 m .5579 .49221 L p
.56384 .52422 L 1 g
F P
s
P
p
.002 w
.56581 .50879 m .56384 .52422 L p
.5579 .49221 L 1 g
F P
s
P
p
.002 w
.56608 .50936 m .56713 .51061 L p
.56262 .502 L 1 g
F P
s
P
p
.56715 .52121 m .56746 .52463 L .5674 .52284 L 1 g
F
P
p
.002 w
.56759 .52888 m .56854 .53025 L p
.5674 .52284 L 1 g
F P
s
P
p
.002 w
.56205 .54684 m .56159 .54762 L p
.56167 .54739 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56167 .54739 L p
.55705 .55413 L 1 g
F P
s
P
p
.55707 .55406 m .55705 .55413 L .56167 .54739 L 1 g
F
P
p
.002 w
.56167 .54739 m .56167 .54739 L p
.56167 .54738 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56257 .5491 L p
.56444 .53883 L 1 g
F P
s
P
p
.002 w
.56213 .54826 m .56167 .54739 L p
.55705 .55413 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56213 .54826 L p
1 g
F P
s
P
p
.002 w
.52753 .57222 m .55592 .55541 L p
.54854 .56362 L 1 g
F P
s
P
p
.002 w
.55078 .56136 m .54854 .56362 L p
.55592 .55541 L 1 g
F P
s
P
p
.002 w
.54923 .56314 m .54998 .56518 L p
.55439 .55719 L 1 g
F P
s
P
p
.002 w
.54923 .56315 m .54923 .56314 L p
.54854 .56362 L 1 g
F P
s
P
p
.002 w
.5446 .57988 m .53492 .57741 L .54854 .56362 L p
1 g
F P
s
P
p
.002 w
.54854 .56362 m .54063 .57163 L p
.53662 .57181 L 1 g
F P
s
P
p
.53662 .57181 m .52753 .57222 L .54854 .56362 L 1 g
F
P
p
.002 w
.53182 .57511 m .53128 .57265 L p
.53171 .57515 L 1 g
F P
s
P
p
.002 w
.53171 .57515 m .52753 .57222 L p
.54063 .57163 L 1 g
F P
s
P
p
.002 w
.53492 .57741 m .51159 .59559 L p
.52218 .58007 L 1 g
F P
s
P
p
.002 w
.52753 .57222 m .53173 .57517 L p
.52218 .58007 L 1 g
F P
s
P
p
.002 w
.53173 .57517 m .53492 .57741 L p
.52218 .58007 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .54923 .56315 L p
.53881 .57154 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54562 .56805 L p
.53881 .57154 L 1 g
F P
s
P
p
.002 w
.54562 .56805 m .54998 .56518 L p
.53881 .57154 L 1 g
F P
s
P
p
.53978 .56964 m .5322 .57686 L .54923 .56315 L 1 g
F
P
p
.002 w
.53182 .57511 m .5322 .57686 L p
.53978 .56964 L 1 g
F P
s
P
p
.002 w
.53182 .57512 m .53182 .57511 L p
.53171 .57515 L 1 g
F P
s
P
p
.002 w
.50784 .58083 m .52753 .57222 L p
.52417 .57714 L 1 g
F P
s
P
p
.52225 .57996 m .51094 .58064 L .52417 .57714 L 1 g
F
P
p
.51094 .58064 m .50784 .58083 L .52417 .57714 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53182 .57512 L p
1 g
F P
s
P
p
.52077 .57804 m .51111 .583 L .53182 .57512 L 1 g
F
P
p
.002 w
.51094 .58064 m .51111 .583 L p
.52077 .57804 L 1 g
F P
s
P
p
.002 w
.5111 .58276 m .51094 .58064 L p
.49715 .58147 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48818 .57122 m .52324 .56484 L p
.50279 .58096 L 1 g
F P
s
P
p
.002 w
.49424 .5812 m .48818 .57122 L p
.50279 .58096 L 1 g
F P
s
P
p
.002 w
.48818 .57122 m .49424 .5812 L p
.48148 .57845 L 1 g
F P
s
P
p
.002 w
.49424 .5812 m .49503 .58251 L p
.48905 .58072 L 1 g
F P
s
P
p
.48148 .57845 m .49424 .5812 L .48905 .58072 L 1 g
F
P
p
.49674 .58143 m .49424 .5812 L .48889 .583 L 1 g
F
P
p
.002 w
.48905 .58072 m .48901 .58134 L p
.49424 .5812 L 1 g
F P
s
P
p
.002 w
.48901 .58134 m .48889 .583 L p
.49424 .5812 L 1 g
F P
s
P
p
.49848 .58108 m .49424 .5812 L .49674 .58143 L 1 g
F
P
p
.002 w
.52324 .56484 m .52753 .57222 L .50784 .58083 L p
1 g
F P
s
P
p
.50279 .58096 m .52324 .56484 L .50784 .58083 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .5111 .58276 L p
1 g
F P
s
P
p
.49674 .58143 m .48889 .583 L .5111 .58276 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58072 L p
1 g
F P
s
P
p
.47934 .57781 m .4678 .57686 L .48905 .58072 L 1 g
F
P
p
.002 w
.41965 .32455 m .36714 .36771 L .35602 .34643 L p
1 g
F P
s
P
p
.002 w
.35602 .34643 m .40905 .30258 L .41965 .32455 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.64138 .44054 m .66112 .46625 L .64133 .49128 L p
1 g
F P
s
P
p
.002 w
.66112 .46625 m .64138 .44054 L .65263 .40962 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.39728 .48388 m .38601 .52593 L .359 .51072 L p
1 g
F P
s
P
p
.002 w
.359 .51072 m .37116 .46296 L .39728 .48388 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55021 .2883 m .48357 .29685 L .47373 .27457 L p
1 g
F P
s
P
p
.002 w
.40905 .30258 m .47373 .27457 L .48357 .29685 L p
1 g
F P
s
P
p
.002 w
.58941 .55354 m .59091 .54447 L .62093 .5313 L p
1 g
F P
s
P
p
.002 w
.61694 .51488 m .62093 .5313 L .59091 .54447 L p
1 g
F P
s
P
p
.002 w
.62093 .5313 m .61694 .51488 L .64133 .49128 L p
1 g
F P
s
P
p
.002 w
.48357 .29685 m .41965 .32455 L .40905 .30258 L p
1 g
F P
s
P
p
.002 w
.55792 .31546 m .61576 .3257 L .61743 .35579 L p
1 g
F P
s
P
p
.002 w
.61576 .3257 m .55792 .31546 L .55021 .2883 L p
1 g
F P
s
P
p
.002 w
.61554 .38879 m .65263 .40962 L .64138 .44054 L p
1 g
F P
s
P
p
.002 w
.65263 .40962 m .61554 .38879 L .61743 .35579 L p
1 g
F P
s
P
p
.002 w
.62567 .4716 m .64133 .49128 L .61694 .51488 L p
1 g
F P
s
P
p
.002 w
.64133 .49128 m .62567 .4716 L .64138 .44054 L p
1 g
F P
s
P
p
.002 w
.40217 .41718 m .37116 .46296 L .34943 .44148 L p
1 g
F P
s
P
p
.002 w
.34943 .44148 m .38265 .39156 L .40217 .41718 L p
1 g
F P
s
P
p
.002 w
.48357 .29685 m .55021 .2883 L .55792 .31546 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42692 .50343 m .41698 .53852 L .38601 .52593 L p
1 g
F P
s
P
p
.002 w
.38601 .52593 m .39728 .48388 L .42692 .50343 L p
1 g
F P
s
P
p
.002 w
.43304 .35045 m .38265 .39156 L .36714 .36771 L p
1 g
F P
s
P
p
.002 w
.36714 .36771 m .41965 .32455 L .43304 .35045 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.59091 .54447 m .58873 .53618 L .61694 .51488 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60599 .50165 m .61694 .51488 L .58873 .53618 L p
1 g
F P
s
P
p
.002 w
.61694 .51488 m .60599 .50165 L .62567 .4716 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.61007 .42355 m .64138 .44054 L .62567 .4716 L p
1 g
F P
s
P
p
.002 w
.64138 .44054 m .61007 .42355 L .61554 .38879 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.52258 .55604 m .52324 .56484 L .48818 .57122 L p
1 g
F P
s
P
p
.002 w
.48818 .57122 m .48653 .55389 L .52258 .55604 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.56403 .34682 m .61743 .35579 L .61554 .38879 L p
1 g
F P
s
P
p
.002 w
.61743 .35579 m .56403 .34682 L .55792 .31546 L p
1 g
F P
s
P
p
.002 w
.58873 .53618 m .58305 .52958 L .60599 .50165 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.55792 .31546 m .49421 .3239 L .48357 .29685 L p
1 g
F P
s
P
p
.002 w
.41965 .32455 m .48357 .29685 L .49421 .3239 L p
1 g
F P
s
P
p
.002 w
.49421 .3239 m .43304 .35045 L .41965 .32455 L p
1 g
F P
s
P
p
.002 w
.42506 .44365 m .39728 .48388 L .37116 .46296 L p
1 g
F P
s
P
p
.002 w
.37116 .46296 m .40217 .41718 L .42506 .44365 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.60116 .45879 m .62567 .4716 L .60599 .50165 L p
1 g
F P
s
P
p
.002 w
.62567 .4716 m .60116 .45879 L .61007 .42355 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58305 .52958 m .57444 .52543 L .58913 .49318 L p
1 g
F P
s
P
p
.002 w
.58913 .49318 m .60599 .50165 L .58305 .52958 L p
1 g
F P
s
P
p
.002 w
.49421 .3239 m .55792 .31546 L .56403 .34682 L p
1 g
F P
s
P
p
.002 w
.60599 .50165 m .58913 .49318 L .60116 .45879 L p
1 g
F P
s
P
p
.002 w
.52566 .54677 m .52258 .55604 L .48653 .55389 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.49235 .53548 m .48653 .55389 L .4509 .54797 L p
1 g
F P
s
P
p
.002 w
.4509 .54797 m .45901 .52086 L .49235 .53548 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.48653 .55389 m .49235 .53548 L .52566 .54677 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44883 .37943 m .40217 .41718 L .38265 .39156 L p
1 g
F P
s
P
p
.002 w
.38265 .39156 m .43304 .35045 L .44883 .37943 L p
1 g
F P
s
P
p
.002 w
.56825 .38133 m .61554 .38879 L .61007 .42355 L p
1 g
F P
s
P
p
.002 w
.61554 .38879 m .56825 .38133 L .56403 .34682 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.56813 .49057 m .58913 .49318 L .57444 .52543 L p
1 g
F P
s
P
p
.002 w
.53218 .53806 m .52566 .54677 L .49235 .53548 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45052 .46997 m .42692 .50343 L .39728 .48388 L p
1 g
F P
s
P
p
.002 w
.39728 .48388 m .42506 .44365 L .45052 .46997 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56384 .52422 m .55241 .52611 L .54537 .49421 L p
1 g
F P
s
P
p
.002 w
.54144 .5309 m .53218 .53806 L .50514 .51809 L p
1 g
F P
s
P
p
.002 w
.49235 .53548 m .50514 .51809 L .53218 .53806 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.5704 .41773 m .61007 .42355 L .60116 .45879 L p
1 g
F P
s
P
p
.002 w
.61007 .42355 m .5704 .41773 L .56825 .38133 L p
1 g
F P
s
P
p
.002 w
.55241 .52611 m .54144 .5309 L .52352 .50376 L p
1 g
F P
s
P
p
.002 w
.52352 .50376 m .54537 .49421 L .55241 .52611 L p
1 g
F P
s
P
p
.002 w
.58913 .49318 m .56813 .49057 L .57036 .45462 L p
1 g
F P
s
P
p
.002 w
.57036 .45462 m .60116 .45879 L .58913 .49318 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.50514 .51809 m .52352 .50376 L .54144 .5309 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.56403 .34682 m .50528 .3549 L .49421 .3239 L p
1 g
F P
s
P
p
.002 w
.43304 .35045 m .49421 .3239 L .50528 .3549 L p
1 g
F P
s
P
p
.002 w
.50528 .3549 m .56403 .34682 L .56825 .38133 L p
1 g
F P
s
P
p
.002 w
.50514 .51809 m .49235 .53548 L .45901 .52086 L p
1 g
F P
s
P
p
.002 w
.60116 .45879 m .57036 .45462 L .5704 .41773 L p
1 g
F P
s
P
p
.002 w
.50528 .3549 m .44883 .37943 L .43304 .35045 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.45901 .52086 m .47756 .49511 L .50514 .51809 L p
1 g
F P
s
P
p
.002 w
.46646 .41046 m .42506 .44365 L .40217 .41718 L p
1 g
F P
s
P
p
.002 w
.40217 .41718 m .44883 .37943 L .46646 .41046 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.5368 .45981 m .57036 .45462 L .56813 .49057 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52352 .50376 m .50514 .51809 L .47756 .49511 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51635 .38876 m .56825 .38133 L .5704 .41773 L p
1 g
F P
s
P
p
.002 w
.56825 .38133 m .51635 .38876 L .50528 .3549 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.54537 .49421 m .52352 .50376 L .50455 .47387 L p
1 g
F P
s
P
p
.002 w
.47756 .49511 m .50455 .47387 L .52352 .50376 L p
1 g
F P
s
P
p
.002 w
.48528 .44236 m .45052 .46997 L .42506 .44365 L p
1 g
F P
s
P
p
.002 w
.42506 .44365 m .46646 .41046 L .48528 .44236 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.44883 .37943 m .50528 .3549 L .51635 .38876 L p
1 g
F P
s
P
p
.002 w
.57036 .45462 m .5368 .45981 L .527 .42419 L p
1 g
F P
s
P
p
.002 w
.527 .42419 m .5704 .41773 L .57036 .45462 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51635 .38876 m .46646 .41046 L .44883 .37943 L p
1 g
F P
s
P
p
.002 w
.5704 .41773 m .527 .42419 L .51635 .38876 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48528 .44236 m .527 .42419 L .5368 .45981 L p
1 g
F P
s
P
p
.002 w
.46646 .41046 m .51635 .38876 L .527 .42419 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.57715 .59611 m
.58145 .60535 L
s
P
p
.004 w
.58145 .60535 m
.59178 .62753 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.527 .42419 m .48528 .44236 L .46646 .41046 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .7639 .3825 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .59178 .62753 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0108527)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0108527)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46181 .47488 m .50925 .47024 L .5032 .44254 L p
1 g
F P
s
P
p
.002 w
.5032 .44254 m .46163 .44652 L .46181 .47488 L p
1 g
F P
s
P
p
.002 w
.54262 .4288 m .5032 .44254 L .50925 .47024 L p
1 g
F P
s
P
p
.002 w
.46163 .44652 m .5032 .44254 L .49709 .41463 L p
1 g
F P
s
P
p
.002 w
.5032 .44254 m .54262 .4288 L .52997 .40309 L p
1 g
F P
s
P
p
.002 w
.52997 .40309 m .49709 .41463 L .5032 .44254 L p
1 g
F P
s
P
p
.002 w
.49709 .41463 m .46238 .41788 L .46163 .44652 L p
1 g
F P
s
P
p
.002 w
.46238 .41788 m .49709 .41463 L .49103 .38701 L p
1 g
F P
s
P
p
.002 w
.49709 .41463 m .52997 .40309 L .51657 .37798 L p
1 g
F P
s
P
p
.002 w
.51657 .37798 m .49103 .38701 L .49709 .41463 L p
1 g
F P
s
P
p
.002 w
.42165 .44029 m .46163 .44652 L .46238 .41788 L p
1 g
F P
s
P
p
.002 w
.46238 .41788 m .42907 .41247 L .42165 .44029 L p
1 g
F P
s
P
p
.002 w
.42907 .41247 m .46238 .41788 L .46404 .38948 L p
1 g
F P
s
P
p
.002 w
.49103 .38701 m .46404 .38948 L .46238 .41788 L p
1 g
F P
s
P
p
.002 w
.55792 .38426 m .52997 .40309 L .54262 .4288 L p
1 g
F P
s
P
p
.002 w
.52997 .40309 m .55792 .38426 L .53816 .36322 L p
1 g
F P
s
P
p
.002 w
.53816 .36322 m .51657 .37798 L .52997 .40309 L p
1 g
F P
s
P
p
.002 w
.46292 .50244 m .51513 .49722 L .50925 .47024 L p
1 g
F P
s
P
p
.002 w
.50925 .47024 m .46181 .47488 L .46292 .50244 L p
1 g
F P
s
P
p
.002 w
.55428 .45465 m .50925 .47024 L .51513 .49722 L p
1 g
F P
s
P
p
.002 w
.50925 .47024 m .55428 .45465 L .54262 .4288 L p
1 g
F P
s
P
p
.002 w
.4161 .46806 m .46181 .47488 L .46163 .44652 L p
1 g
F P
s
P
p
.002 w
.46163 .44652 m .42165 .44029 L .4161 .46806 L p
1 g
F P
s
P
p
.002 w
.57628 .40644 m .54262 .4288 L .55428 .45465 L p
1 g
F P
s
P
p
.002 w
.54262 .4288 m .57628 .40644 L .55792 .38426 L p
1 g
F P
s
P
p
.002 w
.46404 .38948 m .49103 .38701 L .48513 .36017 L p
1 g
F P
s
P
p
.002 w
.49103 .38701 m .51657 .37798 L .50264 .35393 L p
1 g
F P
s
P
p
.002 w
.50264 .35393 m .48513 .36017 L .49103 .38701 L p
1 g
F P
s
P
p
.002 w
.46404 .38948 m .43822 .38511 L .42907 .41247 L p
1 g
F P
s
P
p
.002 w
.43822 .38511 m .46404 .38948 L .4666 .36183 L p
1 g
F P
s
P
p
.002 w
.48513 .36017 m .4666 .36183 L .46404 .38948 L p
1 g
F P
s
P
p
.002 w
.51657 .37798 m .53816 .36322 L .51738 .34373 L p
1 g
F P
s
P
p
.002 w
.51738 .34373 m .50264 .35393 L .51657 .37798 L p
1 g
F P
s
P
p
.002 w
.41256 .49524 m .46292 .50244 L .46181 .47488 L p
1 g
F P
s
P
p
.002 w
.46181 .47488 m .4161 .46806 L .41256 .49524 L p
1 g
F P
s
P
p
.002 w
.51513 .49722 m .56473 .48017 L .55428 .45465 L p
1 g
F P
s
P
p
.002 w
.59289 .42937 m .55428 .45465 L .56473 .48017 L p
1 g
F P
s
P
p
.002 w
.55428 .45465 m .59289 .42937 L .57628 .40644 L p
1 g
F P
s
P
p
.002 w
.46496 .52866 m .52073 .52297 L .51513 .49722 L p
1 g
F P
s
P
p
.002 w
.51513 .49722 m .46292 .50244 L .46496 .52866 L p
1 g
F P
s
P
p
.002 w
.56473 .48017 m .51513 .49722 L .52073 .52297 L p
1 g
F P
s
P
p
.002 w
.4666 .36183 m .48513 .36017 L .47949 .33463 L p
1 g
F P
s
P
p
.002 w
.48513 .36017 m .50264 .35393 L .48845 .33142 L p
1 g
F P
s
P
p
.002 w
.48845 .33142 m .47949 .33463 L .48513 .36017 L p
1 g
F P
s
P
p
.002 w
.38705 .42416 m .42165 .44029 L .42907 .41247 L p
1 g
F P
s
P
p
.002 w
.42907 .41247 m .40039 .39872 L .38705 .42416 L p
1 g
F P
s
P
p
.002 w
.40039 .39872 m .42907 .41247 L .43822 .38511 L p
1 g
F P
s
P
p
.002 w
.57814 .35979 m .55792 .38426 L .57628 .40644 L p
1 g
F P
s
P
p
.002 w
.55792 .38426 m .57814 .35979 L .55362 .3441 L p
1 g
F P
s
P
p
.002 w
.55362 .3441 m .53816 .36322 L .55792 .38426 L p
1 g
F P
s
P
p
.002 w
.4666 .36183 m .44892 .35872 L .43822 .38511 L p
1 g
F P
s
P
p
.002 w
.44892 .35872 m .4666 .36183 L .47002 .33546 L p
1 g
F P
s
P
p
.002 w
.47949 .33463 m .47002 .33546 L .4666 .36183 L p
1 g
F P
s
P
p
.002 w
.50264 .35393 m .51738 .34373 L .49594 .32616 L p
1 g
F P
s
P
p
.002 w
.49594 .32616 m .48845 .33142 L .50264 .35393 L p
1 g
F P
s
P
p
.002 w
.43822 .38511 m .41612 .37422 L .40039 .39872 L p
1 g
F P
s
P
p
.002 w
.41612 .37422 m .43822 .38511 L .44892 .35872 L p
1 g
F P
s
P
p
.002 w
.53816 .36322 m .55362 .3441 L .5278 .33054 L p
1 g
F P
s
P
p
.002 w
.5278 .33054 m .51738 .34373 L .53816 .36322 L p
1 g
F P
s
P
p
.002 w
.37637 .45003 m .4161 .46806 L .42165 .44029 L p
1 g
F P
s
P
p
.002 w
.42165 .44029 m .38705 .42416 L .37637 .45003 L p
1 g
F P
s
P
p
.002 w
.60088 .37734 m .57628 .40644 L .59289 .42937 L p
1 g
F P
s
P
p
.002 w
.57628 .40644 m .60088 .37734 L .57814 .35979 L p
1 g
F P
s
P
p
.002 w
.41114 .52128 m .46496 .52866 L .46292 .50244 L p
1 g
F P
s
P
p
.002 w
.46292 .50244 m .41256 .49524 L .41114 .52128 L p
1 g
F P
s
P
p
.002 w
.52073 .52297 m .57375 .50486 L .56473 .48017 L p
1 g
F P
s
P
p
.002 w
.60741 .4526 m .56473 .48017 L .57375 .50486 L p
1 g
F P
s
P
p
.002 w
.56473 .48017 m .60741 .4526 L .59289 .42937 L p
1 g
F P
s
P
p
.002 w
.44892 .35872 m .4339 .35111 L .41612 .37422 L p
1 g
F P
s
P
p
.002 w
.4339 .35111 m .44892 .35872 L .461 .33382 L p
1 g
F P
s
P
p
.002 w
.47002 .33546 m .461 .33382 L .44892 .35872 L p
1 g
F P
s
P
p
.002 w
.51738 .34373 m .5278 .33054 L .50117 .3194 L p
1 g
F P
s
P
p
.002 w
.50117 .3194 m .49594 .32616 L .51738 .34373 L p
1 g
F P
s
P
p
.002 w
.36863 .47583 m .41256 .49524 L .4161 .46806 L p
1 g
F P
s
P
p
.002 w
.4161 .46806 m .37637 .45003 L .36863 .47583 L p
1 g
F P
s
P
p
.002 w
.62135 .3964 m .59289 .42937 L .60741 .4526 L p
1 g
F P
s
P
p
.002 w
.59289 .42937 m .62135 .3964 L .60088 .37734 L p
1 g
F P
s
P
p
.002 w
.46793 .55299 m .52593 .54698 L .52073 .52297 L p
1 g
F P
s
P
p
.002 w
.52073 .52297 m .46496 .52866 L .46793 .55299 L p
1 g
F P
s
P
p
.002 w
.57375 .50486 m .52073 .52297 L .52593 .54698 L p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .47002 .33546 L .47949 .33463 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .47949 .33463 L .48845 .33142 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .461 .33382 L .47002 .33546 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .48845 .33142 L .49594 .32616 L closepath p
1 g
F P
s
P
p
.002 w
.37937 .37771 m .40039 .39872 L .41612 .37422 L p
1 g
F P
s
P
p
.002 w
.41612 .37422 m .40009 .35773 L .37937 .37771 L p
1 g
F P
s
P
p
.002 w
.40009 .35773 m .41612 .37422 L .4339 .35111 L p
1 g
F P
s
P
p
.002 w
.5612 .32243 m .55362 .3441 L .57814 .35979 L p
1 g
F P
s
P
p
.002 w
.55362 .3441 m .5612 .32243 L .53274 .31569 L p
1 g
F P
s
P
p
.002 w
.53274 .31569 m .5278 .33054 L .55362 .3441 L p
1 g
F P
s
P
p
.002 w
.4339 .35111 m .42314 .33971 L .40009 .35773 L p
1 g
F P
s
P
p
.002 w
.42314 .33971 m .4339 .35111 L .4534 .32987 L p
1 g
F P
s
P
p
.002 w
.461 .33382 m .4534 .32987 L .4339 .35111 L p
1 g
F P
s
P
p
.002 w
.5278 .33054 m .53274 .31569 L .50356 .31183 L p
1 g
F P
s
P
p
.002 w
.50356 .31183 m .50117 .3194 L .5278 .33054 L p
1 g
F P
s
P
p
.002 w
.41193 .54563 m .46793 .55299 L .46496 .52866 L p
1 g
F P
s
P
p
.002 w
.46496 .52866 m .41114 .52128 L .41193 .54563 L p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .4534 .32987 L .461 .33382 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .49594 .32616 L .50117 .3194 L closepath p
1 g
F P
s
P
p
.002 w
.36143 .39927 m .38705 .42416 L .40039 .39872 L p
1 g
F P
s
P
p
.002 w
.40039 .39872 m .37937 .37771 L .36143 .39927 L p
1 g
F P
s
P
p
.002 w
.52593 .54698 m .58113 .52824 L .57375 .50486 L p
1 g
F P
s
P
p
.002 w
.6195 .4757 m .57375 .50486 L .58113 .52824 L p
1 g
F P
s
P
p
.002 w
.57375 .50486 m .6195 .4757 L .60741 .4526 L p
1 g
F P
s
P
p
.002 w
.58835 .33193 m .57814 .35979 L .60088 .37734 L p
1 g
F P
s
P
p
.002 w
.57814 .35979 m .58835 .33193 L .5612 .32243 L p
1 g
F P
s
P
p
.002 w
.36407 .50102 m .41114 .52128 L .41256 .49524 L p
1 g
F P
s
P
p
.002 w
.41256 .49524 m .36863 .47583 L .36407 .50102 L p
1 g
F P
s
P
p
.002 w
.6391 .41664 m .60741 .4526 L .6195 .4757 L p
1 g
F P
s
P
p
.002 w
.60741 .4526 m .6391 .41664 L .62135 .3964 L p
1 g
F P
s
P
p
.002 w
.4534 .32987 m .44802 .324 L .42314 .33971 L p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .44802 .324 L .4534 .32987 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .50117 .3194 L .50356 .31183 L closepath p
1 g
F P
s
P
p
.002 w
.34672 .42199 m .37637 .45003 L .38705 .42416 L p
1 g
F P
s
P
p
.002 w
.38705 .42416 m .36143 .39927 L .34672 .42199 L p
1 g
F P
s
P
p
.002 w
.61361 .34403 m .60088 .37734 L .62135 .3964 L p
1 g
F P
s
P
p
.002 w
.60088 .37734 m .61361 .34403 L .58835 .33193 L p
1 g
F P
s
P
p
.002 w
.41788 .32563 m .42314 .33971 L .44802 .324 L p
1 g
F P
s
P
p
.002 w
.44802 .324 m .44548 .31683 L .41788 .32563 L p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .44548 .31683 L .44802 .324 L closepath p
1 g
F P
s
P
p
.002 w
.50284 .30426 m .50356 .31183 L .53274 .31569 L p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .50356 .31183 L .50284 .30426 L closepath p
1 g
F P
s
P
p
.002 w
.39204 .33718 m .40009 .35773 L .42314 .33971 L p
1 g
F P
s
P
p
.002 w
.42314 .33971 m .41788 .32563 L .39204 .33718 L p
1 g
F P
s
P
p
.002 w
.47178 .57489 m .53062 .56869 L .52593 .54698 L p
1 g
F P
s
P
p
.002 w
.52593 .54698 m .46793 .55299 L .47178 .57489 L p
1 g
F P
s
P
p
.002 w
.58113 .52824 m .52593 .54698 L .53062 .56869 L p
1 g
F P
s
P
p
.002 w
.53156 .30072 m .53274 .31569 L .5612 .32243 L p
1 g
F P
s
P
p
.002 w
.53274 .31569 m .53156 .30072 L .50284 .30426 L p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .49902 .2975 L .4925 .29233 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .4925 .29233 L .48397 .28932 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .48397 .28932 L .47438 .28883 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .47438 .28883 L .46479 .29094 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .46479 .29094 L .45628 .29539 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .45628 .29539 L .44982 .30168 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .44982 .30168 L .44609 .30911 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .44609 .30911 L .44548 .31683 L closepath p
1 g
F P
s
P
p
.002 w
.47425 .31091 m .50284 .30426 L .49902 .2975 L closepath p
1 g
F P
s
P
p
.002 w
.36853 .35129 m .37937 .37771 L .40009 .35773 L p
1 g
F P
s
P
p
.002 w
.40009 .35773 m .39204 .33718 L .36853 .35129 L p
1 g
F P
s
P
p
.002 w
.55982 .30041 m .5612 .32243 L .58835 .33193 L p
1 g
F P
s
P
p
.002 w
.5612 .32243 m .55982 .30041 L .53156 .30072 L p
1 g
F P
s
P
p
.002 w
.33564 .44541 m .36863 .47583 L .37637 .45003 L p
1 g
F P
s
P
p
.002 w
.37637 .45003 m .34672 .42199 L .33564 .44541 L p
1 g
F P
s
P
p
.002 w
.63641 .35855 m .62135 .3964 L .6391 .41664 L p
1 g
F P
s
P
p
.002 w
.62135 .3964 m .63641 .35855 L .61361 .34403 L p
1 g
F P
s
P
p
.002 w
.41885 .31034 m .41788 .32563 L .44548 .31683 L p
1 g
F P
s
P
p
.002 w
.44548 .31683 m .44609 .30911 L .41885 .31034 L p
1 g
F P
s
P
p
.002 w
.49902 .2975 m .50284 .30426 L .53156 .30072 L p
1 g
F P
s
P
p
.002 w
.415 .5677 m .47178 .57489 L .46793 .55299 L p
1 g
F P
s
P
p
.002 w
.46793 .55299 m .41193 .54563 L .415 .5677 L p
1 g
F P
s
P
p
.002 w
.53062 .56869 m .58665 .54978 L .58113 .52824 L p
1 g
F P
s
P
p
.002 w
.62886 .49819 m .58113 .52824 L .58665 .54978 L p
1 g
F P
s
P
p
.002 w
.58113 .52824 m .62886 .49819 L .6195 .4757 L p
1 g
F P
s
P
p
.002 w
.36291 .52502 m .41193 .54563 L .41114 .52128 L p
1 g
F P
s
P
p
.002 w
.41114 .52128 m .36407 .50102 L .36291 .52502 L p
1 g
F P
s
P
p
.002 w
.65368 .43765 m .6195 .4757 L .62886 .49819 L p
1 g
F P
s
P
p
.002 w
.6195 .4757 m .65368 .43765 L .6391 .41664 L p
1 g
F P
s
P
p
.002 w
.34794 .36772 m .36143 .39927 L .37937 .37771 L p
1 g
F P
s
P
p
.002 w
.37937 .37771 m .36853 .35129 L .34794 .36772 L p
1 g
F P
s
P
p
.002 w
.58701 .30342 m .58835 .33193 L .61361 .34403 L p
1 g
F P
s
P
p
.002 w
.58835 .33193 m .58701 .30342 L .55982 .30041 L p
1 g
F P
s
P
p
.002 w
.42609 .29552 m .41885 .31034 L .44609 .30911 L p
1 g
F P
s
P
p
.002 w
.44609 .30911 m .44982 .30168 L .42609 .29552 L p
1 g
F P
s
P
p
.002 w
.4925 .29233 m .49902 .2975 L .52421 .28725 L p
1 g
F P
s
P
p
.002 w
.53156 .30072 m .52421 .28725 L .49902 .2975 L p
1 g
F P
s
P
p
.002 w
.39315 .31467 m .39204 .33718 L .41788 .32563 L p
1 g
F P
s
P
p
.002 w
.41788 .32563 m .41885 .31034 L .39315 .31467 L p
1 g
F P
s
P
p
.002 w
.52421 .28725 m .53156 .30072 L .55982 .30041 L p
1 g
F P
s
P
p
.002 w
.43891 .28288 m .42609 .29552 L .44982 .30168 L p
1 g
F P
s
P
p
.002 w
.44982 .30168 m .45628 .29539 L .43891 .28288 L p
1 g
F P
s
P
p
.002 w
.52421 .28725 m .51137 .27683 L .4925 .29233 L p
1 g
F P
s
P
p
.002 w
.48397 .28932 m .4925 .29233 L .51137 .27683 L p
1 g
F P
s
P
p
.002 w
.32858 .46902 m .36407 .50102 L .36863 .47583 L p
1 g
F P
s
P
p
.002 w
.36863 .47583 m .33564 .44541 L .32858 .46902 L p
1 g
F P
s
P
p
.002 w
.65619 .37523 m .6391 .41664 L .65368 .43765 L p
1 g
F P
s
P
p
.002 w
.6391 .41664 m .65619 .37523 L .63641 .35855 L p
1 g
F P
s
P
p
.002 w
.47649 .59376 m .53467 .58755 L .53062 .56869 L p
1 g
F P
s
P
p
.002 w
.53062 .56869 m .47178 .57489 L .47649 .59376 L p
1 g
F P
s
P
p
.002 w
.58665 .54978 m .53062 .56869 L .53467 .58755 L p
1 g
F P
s
P
p
.002 w
.45592 .2739 m .43891 .28288 L .45628 .29539 L p
1 g
F P
s
P
p
.002 w
.45628 .29539 m .46479 .29094 L .45592 .2739 L p
1 g
F P
s
P
p
.002 w
.33083 .38618 m .34672 .42199 L .36143 .39927 L p
1 g
F P
s
P
p
.002 w
.36143 .39927 m .34794 .36772 L .33083 .38618 L p
1 g
F P
s
P
p
.002 w
.51137 .27683 m .49439 .27071 L .48397 .28932 L p
1 g
F P
s
P
p
.002 w
.47438 .28883 m .48397 .28932 L .49439 .27071 L p
1 g
F P
s
P
p
.002 w
.36958 .3221 m .36853 .35129 L .39204 .33718 L p
1 g
F P
s
P
p
.002 w
.39204 .33718 m .39315 .31467 L .36958 .3221 L p
1 g
F P
s
P
p
.002 w
.61251 .30975 m .61361 .34403 L .63641 .35855 L p
1 g
F P
s
P
p
.002 w
.61361 .34403 m .61251 .30975 L .58701 .30342 L p
1 g
F P
s
P
p
.002 w
.54929 .28044 m .55982 .30041 L .58701 .30342 L p
1 g
F P
s
P
p
.002 w
.55982 .30041 m .54929 .28044 L .52421 .28725 L p
1 g
F P
s
P
p
.002 w
.47516 .26968 m .45592 .2739 L .46479 .29094 L p
1 g
F P
s
P
p
.002 w
.46479 .29094 m .47438 .28883 L .47516 .26968 L p
1 g
F P
s
P
p
.002 w
.49439 .27071 m .47516 .26968 L .47438 .28883 L p
1 g
F P
s
P
p
.002 w
.3653 .54724 m .415 .5677 L .41193 .54563 L p
1 g
F P
s
P
p
.002 w
.41193 .54563 m .36291 .52502 L .3653 .54724 L p
1 g
F P
s
P
p
.002 w
.40363 .29268 m .39315 .31467 L .41885 .31034 L p
1 g
F P
s
P
p
.002 w
.41885 .31034 m .42609 .29552 L .40363 .29268 L p
1 g
F P
s
P
p
.002 w
.51137 .27683 m .52421 .28725 L .54929 .28044 L p
1 g
F P
s
P
p
.002 w
.58665 .54978 m .63516 .51957 L .62886 .49819 L p
1 g
F P
s
P
p
.002 w
.66465 .45901 m .62886 .49819 L .63516 .51957 L p
1 g
F P
s
P
p
.002 w
.62886 .49819 m .66465 .45901 L .65368 .43765 L p
1 g
F P
s
P
p
.002 w
.42039 .5869 m .47649 .59376 L .47178 .57489 L p
1 g
F P
s
P
p
.002 w
.47178 .57489 m .415 .5677 L .42039 .5869 L p
1 g
F P
s
P
p
.002 w
.53467 .58755 m .59011 .56893 L .58665 .54978 L p
1 g
F P
s
P
p
.002 w
.63516 .51957 m .58665 .54978 L .59011 .56893 L p
1 g
F P
s
P
p
.002 w
.32585 .49228 m .36291 .52502 L .36407 .50102 L p
1 g
F P
s
P
p
.002 w
.36407 .50102 m .32858 .46902 L .32585 .49228 L p
1 g
F P
s
P
p
.002 w
.3488 .33259 m .34794 .36772 L .36853 .35129 L p
1 g
F P
s
P
p
.002 w
.36853 .35129 m .36958 .3221 L .3488 .33259 L p
1 g
F P
s
P
p
.002 w
.31772 .40631 m .33564 .44541 L .34672 .42199 L p
1 g
F P
s
P
p
.002 w
.34672 .42199 m .33083 .38618 L .31772 .40631 L p
1 g
F P
s
P
p
.002 w
.67237 .39377 m .65368 .43765 L .66465 .45901 L p
1 g
F P
s
P
p
.002 w
.65368 .43765 m .67237 .39377 L .65619 .37523 L p
1 g
F P
s
P
p
.002 w
.42256 .27379 m .40363 .29268 L .42609 .29552 L p
1 g
F P
s
P
p
.002 w
.42609 .29552 m .43891 .28288 L .42256 .27379 L p
1 g
F P
s
P
p
.002 w
.57371 .27736 m .58701 .30342 L .61251 .30975 L p
1 g
F P
s
P
p
.002 w
.58701 .30342 m .57371 .27736 L .54929 .28044 L p
1 g
F P
s
P
p
.002 w
.54929 .28044 m .53048 .26487 L .51137 .27683 L p
1 g
F P
s
P
p
.002 w
.49439 .27071 m .51137 .27683 L .53048 .26487 L p
1 g
F P
s
P
p
.002 w
.63569 .31939 m .63641 .35855 L .65619 .37523 L p
1 g
F P
s
P
p
.002 w
.63641 .35855 m .63569 .31939 L .61251 .30975 L p
1 g
F P
s
P
p
.002 w
.38298 .29337 m .36958 .3221 L .39315 .31467 L p
1 g
F P
s
P
p
.002 w
.39315 .31467 m .40363 .29268 L .38298 .29337 L p
1 g
F P
s
P
p
.002 w
.53048 .26487 m .54929 .28044 L .57371 .27736 L p
1 g
F P
s
P
p
.002 w
.44789 .26035 m .42256 .27379 L .43891 .28288 L p
1 g
F P
s
P
p
.002 w
.43891 .28288 m .45592 .2739 L .44789 .26035 L p
1 g
F P
s
P
p
.002 w
.53048 .26487 m .5053 .25565 L .49439 .27071 L p
1 g
F P
s
P
p
.002 w
.47516 .26968 m .49439 .27071 L .5053 .25565 L p
1 g
F P
s
P
p
.002 w
.48198 .60903 m .53796 .60299 L .53467 .58755 L p
1 g
F P
s
P
p
.002 w
.53467 .58755 m .47649 .59376 L .48198 .60903 L p
1 g
F P
s
P
p
.002 w
.59011 .56893 m .53467 .58755 L .53796 .60299 L p
1 g
F P
s
P
p
.002 w
.37135 .56706 m .42039 .5869 L .415 .5677 L p
1 g
F P
s
P
p
.002 w
.415 .5677 m .3653 .54724 L .37135 .56706 L p
1 g
F P
s
P
p
.002 w
.59011 .56893 m .63814 .5393 L .63516 .51957 L p
1 g
F P
s
P
p
.002 w
.67164 .48024 m .63516 .51957 L .63814 .5393 L p
1 g
F P
s
P
p
.002 w
.63516 .51957 m .67164 .48024 L .66465 .45901 L p
1 g
F P
s
P
p
.002 w
.47663 .25405 m .44789 .26035 L .45592 .2739 L p
1 g
F P
s
P
p
.002 w
.45592 .2739 m .47516 .26968 L .47663 .25405 L p
1 g
F P
s
P
p
.002 w
.5053 .25565 m .47663 .25405 L .47516 .26968 L p
1 g
F P
s
P
p
.002 w
.33141 .34601 m .33083 .38618 L .34794 .36772 L p
1 g
F P
s
P
p
.002 w
.34794 .36772 m .3488 .33259 L .33141 .34601 L p
1 g
F P
s
P
p
.002 w
.42808 .60262 m .48198 .60903 L .47649 .59376 L p
1 g
F P
s
P
p
.002 w
.47649 .59376 m .42039 .5869 L .42808 .60262 L p
1 g
F P
s
P
p
.002 w
.30913 .42767 m .32858 .46902 L .33564 .44541 L p
1 g
F P
s
P
p
.002 w
.33564 .44541 m .31772 .40631 L .30913 .42767 L p
1 g
F P
s
P
p
.002 w
.59686 .27822 m .61251 .30975 L .63569 .31939 L p
1 g
F P
s
P
p
.002 w
.61251 .30975 m .59686 .27822 L .57371 .27736 L p
1 g
F P
s
P
p
.002 w
.53796 .60299 m .59133 .58514 L .59011 .56893 L p
1 g
F P
s
P
p
.002 w
.63814 .5393 m .59011 .56893 L .59133 .58514 L p
1 g
F P
s
P
p
.002 w
.6559 .33223 m .65619 .37523 L .67237 .39377 L p
1 g
F P
s
P
p
.002 w
.65619 .37523 m .6559 .33223 L .63569 .31939 L p
1 g
F P
s
P
p
.002 w
.32773 .51457 m .3653 .54724 L .36291 .52502 L p
1 g
F P
s
P
p
.002 w
.36291 .52502 m .32585 .49228 L .32773 .51457 L p
1 g
F P
s
P
p
.002 w
.68444 .4138 m .66465 .45901 L .67164 .48024 L p
1 g
F P
s
P
p
.002 w
.66465 .45901 m .68444 .4138 L .67237 .39377 L p
1 g
F P
s
P
p
.002 w
.40766 .26854 m .38298 .29337 L .40363 .29268 L p
1 g
F P
s
P
p
.002 w
.40363 .29268 m .42256 .27379 L .40766 .26854 L p
1 g
F P
s
P
p
.002 w
.57371 .27736 m .54938 .25688 L .53048 .26487 L p
1 g
F P
s
P
p
.002 w
.5053 .25565 m .53048 .26487 L .54938 .25688 L p
1 g
F P
s
P
p
.002 w
.36476 .29775 m .3488 .33259 L .36958 .3221 L p
1 g
F P
s
P
p
.002 w
.36958 .3221 m .38298 .29337 L .36476 .29775 L p
1 g
F P
s
P
p
.002 w
.54938 .25688 m .57371 .27736 L .59686 .27822 L p
1 g
F P
s
P
p
.002 w
.44093 .2508 m .40766 .26854 L .42256 .27379 L p
1 g
F P
s
P
p
.002 w
.42256 .27379 m .44789 .26035 L .44093 .2508 L p
1 g
F P
s
P
p
.002 w
.31803 .36216 m .31772 .40631 L .33083 .38618 L p
1 g
F P
s
P
p
.002 w
.33083 .38618 m .33141 .34601 L .31803 .36216 L p
1 g
F P
s
P
p
.002 w
.54938 .25688 m .51648 .24468 L .5053 .25565 L p
1 g
F P
s
P
p
.002 w
.47663 .25405 m .5053 .25565 L .51648 .24468 L p
1 g
F P
s
P
p
.002 w
.61815 .28317 m .63569 .31939 L .6559 .33223 L p
1 g
F P
s
P
p
.002 w
.63569 .31939 m .61815 .28317 L .59686 .27822 L p
1 g
F P
s
P
p
.002 w
.3811 .58386 m .42808 .60262 L .42039 .5869 L p
1 g
F P
s
P
p
.002 w
.42039 .5869 m .37135 .56706 L .3811 .58386 L p
1 g
F P
s
P
p
.002 w
.30546 .44978 m .32585 .49228 L .32858 .46902 L p
1 g
F P
s
P
p
.002 w
.32858 .46902 m .30913 .42767 L .30546 .44978 L p
1 g
F P
s
P
p
.002 w
.59133 .58514 m .63755 .55684 L .63814 .5393 L p
1 g
F P
s
P
p
.002 w
.67427 .50082 m .63814 .5393 L .63755 .55684 L p
1 g
F P
s
P
p
.002 w
.63814 .5393 m .67427 .50082 L .67164 .48024 L p
1 g
F P
s
P
p
.002 w
.67252 .34809 m .67237 .39377 L .68444 .4138 L p
1 g
F P
s
P
p
.002 w
.67237 .39377 m .67252 .34809 L .6559 .33223 L p
1 g
F P
s
P
p
.002 w
.48817 .62013 m .54037 .61444 L .53796 .60299 L p
1 g
F P
s
P
p
.002 w
.53796 .60299 m .48198 .60903 L .48817 .62013 L p
1 g
F P
s
P
p
.002 w
.59133 .58514 m .53796 .60299 L .54037 .61444 L p
1 g
F P
s
P
p
.002 w
.47878 .2425 m .44093 .2508 L .44789 .26035 L p
1 g
F P
s
P
p
.002 w
.44789 .26035 m .47663 .25405 L .47878 .2425 L p
1 g
F P
s
P
p
.002 w
.51648 .24468 m .47878 .2425 L .47663 .25405 L p
1 g
F P
s
P
p
.002 w
.33438 .53529 m .37135 .56706 L .3653 .54724 L p
1 g
F P
s
P
p
.002 w
.3653 .54724 m .32773 .51457 L .33438 .53529 L p
1 g
F P
s
P
p
.002 w
.69192 .43489 m .67164 .48024 L .67427 .50082 L p
1 g
F P
s
P
p
.002 w
.67164 .48024 m .69192 .43489 L .68444 .4138 L p
1 g
F P
s
P
p
.002 w
.43802 .61428 m .48817 .62013 L .48198 .60903 L p
1 g
F P
s
P
p
.002 w
.48198 .60903 m .42808 .60262 L .43802 .61428 L p
1 g
F P
s
P
p
.002 w
.54037 .61444 m .59016 .59784 L .59133 .58514 L p
1 g
F P
s
P
p
.002 w
.63755 .55684 m .59133 .58514 L .59016 .59784 L p
1 g
F P
s
P
p
.002 w
.34955 .3059 m .33141 .34601 L .3488 .33259 L p
1 g
F P
s
P
p
.002 w
.3488 .33259 m .36476 .29775 L .34955 .3059 L p
1 g
F P
s
P
p
.002 w
.39467 .26746 m .36476 .29775 L .38298 .29337 L p
1 g
F P
s
P
p
.002 w
.38298 .29337 m .40766 .26854 L .39467 .26746 L p
1 g
F P
s
P
p
.002 w
.56762 .25327 m .59686 .27822 L .61815 .28317 L p
1 g
F P
s
P
p
.002 w
.59686 .27822 m .56762 .25327 L .54938 .25688 L p
1 g
F P
s
P
p
.002 w
.51648 .24468 m .54938 .25688 L .56762 .25327 L p
1 g
F P
s
P
p
.002 w
.30921 .38074 m .30913 .42767 L .31772 .40631 L p
1 g
F P
s
P
p
.002 w
.31772 .40631 m .31803 .36216 L .30921 .38074 L p
1 g
F P
s
P
p
.002 w
.63692 .29228 m .6559 .33223 L .67252 .34809 L p
1 g
F P
s
P
p
.002 w
.6559 .33223 m .63692 .29228 L .61815 .28317 L p
1 g
F P
s
P
p
.002 w
.30707 .47206 m .32773 .51457 L .32585 .49228 L p
1 g
F P
s
P
p
.002 w
.32585 .49228 m .30546 .44978 L .30707 .47206 L p
1 g
F P
s
P
p
.002 w
.68496 .36669 m .68444 .4138 L .69192 .43489 L p
1 g
F P
s
P
p
.002 w
.68444 .4138 m .68496 .36669 L .67252 .34809 L p
1 g
F P
s
P
p
.002 w
.43529 .24576 m .39467 .26746 L .40766 .26854 L p
1 g
F P
s
P
p
.002 w
.40766 .26854 m .44093 .2508 L .43529 .24576 L p
1 g
F P
s
P
p
.002 w
.39447 .59704 m .43802 .61428 L .42808 .60262 L p
1 g
F P
s
P
p
.002 w
.42808 .60262 m .3811 .58386 L .39447 .59704 L p
1 g
F P
s
P
p
.002 w
.56762 .25327 m .52765 .2383 L .51648 .24468 L p
1 g
F P
s
P
p
.002 w
.47878 .2425 m .51648 .24468 L .52765 .2383 L p
1 g
F P
s
P
p
.002 w
.59016 .59784 m .63321 .57163 L .63755 .55684 L p
1 g
F P
s
P
p
.002 w
.67227 .52021 m .63755 .55684 L .63321 .57163 L p
1 g
F P
s
P
p
.002 w
.63755 .55684 m .67227 .52021 L .67427 .50082 L p
1 g
F P
s
P
p
.002 w
.34584 .55378 m .3811 .58386 L .37135 .56706 L p
1 g
F P
s
P
p
.002 w
.37135 .56706 m .33438 .53529 L .34584 .55378 L p
1 g
F P
s
P
p
.002 w
.69439 .45654 m .67427 .50082 L .67227 .52021 L p
1 g
F P
s
P
p
.002 w
.67427 .50082 m .69439 .45654 L .69192 .43489 L p
1 g
F P
s
P
p
.002 w
.49494 .6265 m .54179 .62138 L .54037 .61444 L p
1 g
F P
s
P
p
.002 w
.54037 .61444 m .48817 .62013 L .49494 .6265 L p
1 g
F P
s
P
p
.002 w
.59016 .59784 m .54037 .61444 L .54179 .62138 L p
1 g
F P
s
P
p
.002 w
.33794 .31782 m .31803 .36216 L .33141 .34601 L p
1 g
F P
s
P
p
.002 w
.33141 .34601 m .34955 .3059 L .33794 .31782 L p
1 g
F P
s
P
p
.002 w
.58469 .25435 m .61815 .28317 L .63692 .29228 L p
1 g
F P
s
P
p
.002 w
.61815 .28317 m .58469 .25435 L .56762 .25327 L p
1 g
F P
s
P
p
.002 w
.4816 .2356 m .43529 .24576 L .44093 .2508 L p
1 g
F P
s
P
p
.002 w
.44093 .2508 m .47878 .2425 L .4816 .2356 L p
1 g
F P
s
P
p
.002 w
.52765 .2383 m .4816 .2356 L .47878 .2425 L p
1 g
F P
s
P
p
.002 w
.38406 .27085 m .34955 .3059 L .36476 .29775 L p
1 g
F P
s
P
p
.002 w
.36476 .29775 m .39467 .26746 L .38406 .27085 L p
1 g
F P
s
P
p
.002 w
.52765 .2383 m .56762 .25327 L .58469 .25435 L p
1 g
F P
s
P
p
.002 w
.45006 .62133 m .49494 .6265 L .48817 .62013 L p
1 g
F P
s
P
p
.002 w
.48817 .62013 m .43802 .61428 L .45006 .62133 L p
1 g
F P
s
P
p
.002 w
.54179 .62138 m .58647 .60651 L .59016 .59784 L p
1 g
F P
s
P
p
.002 w
.63321 .57163 m .59016 .59784 L .58647 .60651 L p
1 g
F P
s
P
p
.002 w
.30545 .40136 m .30546 .44978 L .30913 .42767 L p
1 g
F P
s
P
p
.002 w
.30913 .42767 m .30921 .38074 L .30545 .40136 L p
1 g
F P
s
P
p
.002 w
.65255 .30552 m .67252 .34809 L .68496 .36669 L p
1 g
F P
s
P
p
.002 w
.67252 .34809 m .65255 .30552 L .63692 .29228 L p
1 g
F P
s
P
p
.002 w
.31415 .49389 m .33438 .53529 L .32773 .51457 L p
1 g
F P
s
P
p
.002 w
.32773 .51457 m .30707 .47206 L .31415 .49389 L p
1 g
F P
s
P
p
.002 w
.69266 .38765 m .69192 .43489 L .69439 .45654 L p
1 g
F P
s
P
p
.002 w
.69192 .43489 m .69266 .38765 L .68496 .36669 L p
1 g
F P
s
P
p
.002 w
.4113 .60602 m .45006 .62133 L .43802 .61428 L p
1 g
F P
s
P
p
.002 w
.43802 .61428 m .39447 .59704 L .4113 .60602 L p
1 g
F P
s
P
p
.002 w
.36203 .5694 m .39447 .59704 L .3811 .58386 L p
1 g
F P
s
P
p
.002 w
.3811 .58386 m .34584 .55378 L .36203 .5694 L p
1 g
F P
s
P
p
.002 w
.58647 .60651 m .62502 .5831 L .63321 .57163 L p
1 g
F P
s
P
p
.002 w
.66544 .53781 m .63321 .57163 L .62502 .5831 L p
1 g
F P
s
P
p
.002 w
.63321 .57163 m .66544 .53781 L .67227 .52021 L p
1 g
F P
s
P
p
.002 w
.4312 .24564 m .38406 .27085 L .39467 .26746 L p
1 g
F P
s
P
p
.002 w
.39467 .26746 m .43529 .24576 L .4312 .24564 L p
1 g
F P
s
P
p
.002 w
.58469 .25435 m .53852 .23698 L .52765 .2383 L p
1 g
F P
s
P
p
.002 w
.4816 .2356 m .52765 .2383 L .53852 .23698 L p
1 g
F P
s
P
p
.002 w
.69154 .47818 m .67227 .52021 L .66544 .53781 L p
1 g
F P
s
P
p
.002 w
.67227 .52021 m .69154 .47818 L .69439 .45654 L p
1 g
F P
s
P
p
.002 w
.33047 .33339 m .30921 .38074 L .31803 .36216 L p
1 g
F P
s
P
p
.002 w
.31803 .36216 m .33794 .31782 L .33047 .33339 L p
1 g
F P
s
P
p
.002 w
.60006 .26036 m .63692 .29228 L .65255 .30552 L p
1 g
F P
s
P
p
.002 w
.63692 .29228 m .60006 .26036 L .58469 .25435 L p
1 g
F P
s
P
p
.002 w
.37627 .27889 m .33794 .31782 L .34955 .3059 L p
1 g
F P
s
P
p
.002 w
.34955 .3059 m .38406 .27085 L .37627 .27889 L p
1 g
F P
s
P
p
.002 w
.50215 .62768 m .5421 .6233 L .54179 .62138 L p
1 g
F P
s
P
p
.002 w
.54179 .62138 m .49494 .6265 L .50215 .62768 L p
1 g
F P
s
P
p
.002 w
.58647 .60651 m .54179 .62138 L .5421 .6233 L p
1 g
F P
s
P
p
.002 w
.53852 .23698 m .58469 .25435 L .60006 .26036 L p
1 g
F P
s
P
p
.002 w
.3071 .42351 m .30707 .47206 L .30546 .44978 L p
1 g
F P
s
P
p
.002 w
.30546 .44978 m .30545 .40136 L .3071 .42351 L p
1 g
F P
s
P
p
.002 w
.68496 .36669 m .66444 .32272 L .65255 .30552 L p
1 g
F P
s
P
p
.002 w
.66444 .32272 m .68496 .36669 L .69266 .38765 L p
1 g
F P
s
P
p
.004 w
.54392 .63451 m
.54943 .66009 L
s
P
p
.004 w
.6998 .48533 m
.7808 .50755 L
s
P
p
.002 w
.48506 .23383 m .4312 .24564 L .43529 .24576 L p
1 g
F P
s
P
p
.002 w
.43529 .24576 m .4816 .2356 L .48506 .23383 L p
1 g
F P
s
P
p
.002 w
.53852 .23698 m .48506 .23383 L .4816 .2356 L p
1 g
F P
s
P
p
.002 w
.32677 .5146 m .34584 .55378 L .33438 .53529 L p
1 g
F P
s
P
p
.002 w
.33438 .53529 m .31415 .49389 L .32677 .5146 L p
1 g
F P
s
P
p
.002 w
.46399 .62329 m .50215 .62768 L .49494 .6265 L p
1 g
F P
s
P
p
.002 w
.49494 .6265 m .45006 .62133 L .46399 .62329 L p
1 g
F P
s
P
p
.002 w
.5421 .6233 m .58021 .61063 L .58647 .60651 L p
1 g
F P
s
P
p
.002 w
.62502 .5831 m .58647 .60651 L .58021 .61063 L p
1 g
F P
s
P
p
.002 w
.69439 .45654 m .6952 .4105 L .69266 .38765 L p
1 g
F P
s
P
p
.002 w
.6952 .4105 m .69439 .45654 L .69154 .47818 L p
1 g
F P
s
P
p
.002 w
.3827 .58154 m .4113 .60602 L .39447 .59704 L p
1 g
F P
s
P
p
.002 w
.39447 .59704 m .36203 .5694 L .3827 .58154 L p
1 g
F P
s
P
p
.002 w
.32759 .35234 m .30545 .40136 L .30921 .38074 L p
1 g
F P
s
P
p
.002 w
.30921 .38074 m .33047 .33339 L .32759 .35234 L p
1 g
F P
s
P
p
.002 w
.62502 .5831 m .65372 .55304 L .66544 .53781 L p
1 g
F P
s
P
p
.002 w
.66544 .53781 m .68318 .49918 L .69154 .47818 L p
1 g
F P
s
P
p
.002 w
.68318 .49918 m .66544 .53781 L .65372 .55304 L p
1 g
F P
s
P
p
.002 w
.65255 .30552 m .61318 .27142 L .60006 .26036 L p
1 g
F P
s
P
p
.002 w
.61318 .27142 m .65255 .30552 L .66444 .32272 L p
1 g
F P
s
P
p
.002 w
.43126 .6103 m .46399 .62329 L .45006 .62133 L p
1 g
F P
s
P
p
.002 w
.45006 .62133 m .4113 .60602 L .43126 .6103 L p
1 g
F P
s
P
p
.002 w
.58021 .61063 m .61298 .59073 L .62502 .5831 L p
1 g
F P
s
P
p
.002 w
.65372 .55304 m .62502 .5831 L .61298 .59073 L p
1 g
F P
s
P
p
.002 w
.4289 .25078 m .37627 .27889 L .38406 .27085 L p
1 g
F P
s
P
p
.002 w
.38406 .27085 m .4312 .24564 L .4289 .25078 L p
1 g
F P
s
P
p
.002 w
.60006 .26036 m .54876 .24107 L .53852 .23698 L p
1 g
F P
s
P
p
.002 w
.48506 .23383 m .53852 .23698 L .54876 .24107 L p
1 g
F P
s
P
p
.002 w
.3144 .44658 m .31415 .49389 L .30707 .47206 L p
1 g
F P
s
P
p
.002 w
.30707 .47206 m .3071 .42351 L .3144 .44658 L p
1 g
F P
s
P
p
.002 w
.67204 .34359 m .69266 .38765 L .6952 .4105 L p
1 g
F P
s
P
p
.002 w
.69266 .38765 m .67204 .34359 L .66444 .32272 L p
1 g
F P
s
P
p
.002 w
.37172 .29164 m .33047 .33339 L .33794 .31782 L p
1 g
F P
s
P
p
.002 w
.33794 .31782 m .37627 .27889 L .37172 .29164 L p
1 g
F P
s
P
p
.002 w
.54876 .24107 m .60006 .26036 L .61318 .27142 L p
1 g
F P
s
P
p
.002 w
.34478 .53348 m .36203 .5694 L .34584 .55378 L p
1 g
F P
s
P
p
.002 w
.34584 .55378 m .32677 .5146 L .34478 .53348 L p
1 g
F P
s
P
p
.002 w
.69223 .43464 m .69154 .47818 L .68318 .49918 L p
1 g
F P
s
P
p
.002 w
.69154 .47818 m .69223 .43464 L .6952 .4105 L p
1 g
F P
s
P
p
.002 w
.50961 .62329 m .54123 .61983 L .5421 .6233 L p
1 g
F P
s
P
p
.002 w
.5421 .6233 m .50215 .62768 L .50961 .62329 L p
1 g
F P
s
P
p
.002 w
.58021 .61063 m .5421 .6233 L .54123 .61983 L p
1 g
F P
s
P
p
.002 w
.4891 .23758 m .4289 .25078 L .4312 .24564 L p
1 g
F P
s
P
p
.002 w
.4312 .24564 m .48506 .23383 L .4891 .23758 L p
1 g
F P
s
P
p
.002 w
.54876 .24107 m .4891 .23758 L .48506 .23383 L p
1 g
F P
s
P
p
.002 w
.47951 .61978 m .50961 .62329 L .50215 .62768 L p
1 g
F P
s
P
p
.002 w
.50215 .62768 m .46399 .62329 L .47951 .61978 L p
1 g
F P
s
P
p
.002 w
.54123 .61983 m .57139 .60979 L .58021 .61063 L p
1 g
F P
s
P
p
.002 w
.61298 .59073 m .58021 .61063 L .57139 .60979 L p
1 g
F P
s
P
p
.002 w
.32967 .37424 m .3071 .42351 L .30545 .40136 L p
1 g
F P
s
P
p
.002 w
.30545 .40136 m .32759 .35234 L .32967 .37424 L p
1 g
F P
s
P
p
.002 w
.40739 .58966 m .43126 .6103 L .4113 .60602 L p
1 g
F P
s
P
p
.002 w
.4113 .60602 m .3827 .58154 L .40739 .58966 L p
1 g
F P
s
P
p
.002 w
.62354 .28748 m .66444 .32272 L .67204 .34359 L p
1 g
F P
s
P
p
.002 w
.66444 .32272 m .62354 .28748 L .61318 .27142 L p
1 g
F P
s
P
p
.002 w
.61298 .59073 m .63718 .5653 L .65372 .55304 L p
1 g
F P
s
P
p
.002 w
.6693 .51889 m .65372 .55304 L .63718 .5653 L p
1 g
F P
s
P
p
.002 w
.65372 .55304 m .6693 .51889 L .68318 .49918 L p
1 g
F P
s
P
p
.002 w
.32736 .46986 m .32677 .5146 L .31415 .49389 L p
1 g
F P
s
P
p
.002 w
.31415 .49389 m .3144 .44658 L .32736 .46986 L p
1 g
F P
s
P
p
.002 w
.6749 .36765 m .6952 .4105 L .69223 .43464 L p
1 g
F P
s
P
p
.002 w
.6952 .4105 m .6749 .36765 L .67204 .34359 L p
1 g
F P
s
P
p
.002 w
.4539 .60952 m .47951 .61978 L .46399 .62329 L p
1 g
F P
s
P
p
.002 w
.46399 .62329 m .43126 .6103 L .4539 .60952 L p
1 g
F P
s
P
p
.002 w
.57139 .60979 m .59721 .59407 L .61298 .59073 L p
1 g
F P
s
P
p
.002 w
.63718 .5653 m .61298 .59073 L .59721 .59407 L p
1 g
F P
s
P
p
.002 w
.36782 .54986 m .3827 .58154 L .36203 .5694 L p
1 g
F P
s
P
p
.002 w
.36203 .5694 m .34478 .53348 L .36782 .54986 L p
1 g
F P
s
P
p
.002 w
.42856 .26138 m .37172 .29164 L .37627 .27889 L p
1 g
F P
s
P
p
.002 w
.37627 .27889 m .4289 .25078 L .42856 .26138 L p
1 g
F P
s
P
p
.002 w
.6836 .45937 m .68318 .49918 L .6693 .51889 L p
1 g
F P
s
P
p
.002 w
.68318 .49918 m .6836 .45937 L .69223 .43464 L p
1 g
F P
s
P
p
.004 w
.69126 .48298 m
.6998 .48533 L
s
P
p
.002 w
.61318 .27142 m .55803 .25079 L .54876 .24107 L p
1 g
F P
s
P
p
.002 w
.4891 .23758 m .54876 .24107 L .55803 .25079 L p
1 g
F P
s
P
p
.002 w
.37076 .30896 m .32759 .35234 L .33047 .33339 L p
1 g
F P
s
P
p
.002 w
.33047 .33339 m .37172 .29164 L .37076 .30896 L p
1 g
F P
s
P
p
.002 w
.55803 .25079 m .61318 .27142 L .62354 .28748 L p
1 g
F P
s
P
p
.002 w
.5171 .6131 m .53912 .6107 L .54123 .61983 L p
1 g
F P
s
P
p
.002 w
.54123 .61983 m .50961 .62329 L .5171 .6131 L p
1 g
F P
s
P
p
.002 w
.57139 .60979 m .54123 .61983 L .53912 .6107 L p
1 g
F P
s
P
p
.002 w
.49363 .24711 m .42856 .26138 L .4289 .25078 L p
1 g
F P
s
P
p
.002 w
.4289 .25078 m .4891 .23758 L .49363 .24711 L p
1 g
F P
s
P
p
.002 w
.55803 .25079 m .49363 .24711 L .4891 .23758 L p
1 g
F P
s
P
p
.002 w
.33687 .39853 m .3144 .44658 L .3071 .42351 L p
1 g
F P
s
P
p
.002 w
.3071 .42351 m .32967 .37424 L .33687 .39853 L p
1 g
F P
s
P
p
.002 w
.49623 .61061 m .5171 .6131 L .50961 .62329 L p
1 g
F P
s
P
p
.002 w
.50961 .62329 m .47951 .61978 L .49623 .61061 L p
1 g
F P
s
P
p
.002 w
.53912 .6107 m .56012 .6037 L .57139 .60979 L p
1 g
F P
s
P
p
.002 w
.59721 .59407 m .57139 .60979 L .56012 .6037 L p
1 g
F P
s
P
p
.002 w
.63065 .3083 m .67204 .34359 L .6749 .36765 L p
1 g
F P
s
P
p
.002 w
.67204 .34359 m .63065 .3083 L .62354 .28748 L p
1 g
F P
s
P
p
.002 w
.3458 .49259 m .34478 .53348 L .32677 .5146 L p
1 g
F P
s
P
p
.002 w
.32677 .5146 m .32736 .46986 L .3458 .49259 L p
1 g
F P
s
P
p
.002 w
.43549 .59331 m .4539 .60952 L .43126 .6103 L p
1 g
F P
s
P
p
.002 w
.43126 .6103 m .40739 .58966 L .43549 .59331 L p
1 g
F P
s
P
p
.002 w
.59721 .59407 m .6161 .57408 L .63718 .5653 L p
1 g
F P
s
P
p
.002 w
.65009 .53661 m .63718 .5653 L .6161 .57408 L p
1 g
F P
s
P
p
.002 w
.63718 .5653 m .65009 .53661 L .6693 .51889 L p
1 g
F P
s
P
p
.002 w
.6727 .39427 m .69223 .43464 L .6836 .45937 L p
1 g
F P
s
P
p
.002 w
.69223 .43464 m .6727 .39427 L .6749 .36765 L p
1 g
F P
s
P
p
.002 w
.39533 .56308 m .40739 .58966 L .3827 .58154 L p
1 g
F P
s
P
p
.002 w
.3827 .58154 m .36782 .54986 L .39533 .56308 L p
1 g
F P
s
P
p
.002 w
.66935 .48392 m .6693 .51889 L .65009 .53661 L p
1 g
F P
s
P
p
.002 w
.6693 .51889 m .66935 .48392 L .6836 .45937 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.67283 .47793 L
s
P
p
.004 w
.68114 .48021 m
.69126 .48298 L
s
P
p
.004 w
.67976 .47983 m
.68114 .48021 L
s
P
p
.002 w
.47863 .60344 m .49623 .61061 L .47951 .61978 L p
1 g
F P
s
P
p
.002 w
.47951 .61978 m .4539 .60952 L .47863 .60344 L p
1 g
F P
s
P
p
.002 w
.56012 .6037 m .578 .59275 L .59721 .59407 L p
1 g
F P
s
P
p
.002 w
.6161 .57408 m .59721 .59407 L .578 .59275 L p
1 g
F P
s
P
p
.002 w
.37363 .33056 m .32967 .37424 L .32759 .35234 L p
1 g
F P
s
P
p
.002 w
.32759 .35234 m .37076 .30896 L .37363 .33056 L p
1 g
F P
s
P
p
.002 w
.43033 .27744 m .37076 .30896 L .37172 .29164 L p
1 g
F P
s
P
p
.002 w
.37172 .29164 m .42856 .26138 L .43033 .27744 L p
1 g
F P
s
P
p
.002 w
.56595 .26617 m .62354 .28748 L .63065 .3083 L p
1 g
F P
s
P
p
.002 w
.62354 .28748 m .56595 .26617 L .55803 .25079 L p
1 g
F P
s
P
p
.002 w
.49363 .24711 m .55803 .25079 L .56595 .26617 L p
1 g
F P
s
P
p
.002 w
.34919 .42448 m .32736 .46986 L .3144 .44658 L p
1 g
F P
s
P
p
.002 w
.3144 .44658 m .33687 .39853 L .34919 .42448 L p
1 g
F P
s
P
p
.002 w
.36927 .51396 m .36782 .54986 L .34478 .53348 L p
1 g
F P
s
P
p
.002 w
.34478 .53348 m .3458 .49259 L .36927 .51396 L p
1 g
F P
s
P
p
.002 w
.66531 .42267 m .6836 .45937 L .66935 .48392 L p
1 g
F P
s
P
p
.002 w
.6836 .45937 m .66531 .42267 L .6727 .39427 L p
1 g
F P
s
P
p
.002 w
.6341 .33343 m .6749 .36765 L .6727 .39427 L p
1 g
F P
s
P
p
.002 w
.6749 .36765 m .6341 .33343 L .63065 .3083 L p
1 g
F P
s
P
p
.002 w
.46617 .5922 m .47863 .60344 L .4539 .60952 L p
1 g
F P
s
P
p
.002 w
.4539 .60952 m .43549 .59331 L .46617 .5922 L p
1 g
F P
s
P
p
.002 w
.578 .59275 m .59093 .57889 L .6161 .57408 L p
1 g
F P
s
P
p
.002 w
.62593 .55168 m .6161 .57408 L .59093 .57889 L p
1 g
F P
s
P
p
.002 w
.6161 .57408 m .62593 .55168 L .65009 .53661 L p
1 g
F P
s
P
p
.002 w
.52439 .59708 m .53577 .59586 L .53912 .6107 L p
1 g
F P
s
P
p
.002 w
.53912 .6107 m .5171 .6131 L .52439 .59708 L p
1 g
F P
s
P
p
.002 w
.56012 .6037 m .53912 .6107 L .53577 .59586 L p
1 g
F P
s
P
p
.002 w
.4265 .5726 m .43549 .59331 L .40739 .58966 L p
1 g
F P
s
P
p
.002 w
.40739 .58966 m .39533 .56308 L .4265 .5726 L p
1 g
F P
s
P
p
.002 w
.64975 .50745 m .65009 .53661 L .62593 .55168 L p
1 g
F P
s
P
p
.002 w
.65009 .53661 m .64975 .50745 L .66935 .48392 L p
1 g
F P
s
P
p
.002 w
.49853 .26248 m .43033 .27744 L .42856 .26138 L p
1 g
F P
s
P
p
.002 w
.42856 .26138 m .49363 .24711 L .49853 .26248 L p
1 g
F P
s
P
p
.002 w
.56595 .26617 m .49853 .26248 L .49363 .24711 L p
1 g
F P
s
P
p
.002 w
.51365 .59576 m .52439 .59708 L .5171 .6131 L p
1 g
F P
s
P
p
.002 w
.5171 .6131 m .49623 .61061 L .51365 .59576 L p
1 g
F P
s
P
p
.002 w
.53577 .59586 m .54661 .59222 L .56012 .6037 L p
1 g
F P
s
P
p
.002 w
.578 .59275 m .56012 .6037 L .54661 .59222 L p
1 g
F P
s
P
p
.002 w
.50468 .59202 m .51365 .59576 L .49623 .61061 L p
1 g
F P
s
P
p
.002 w
.49623 .61061 m .47863 .60344 L .50468 .59202 L p
1 g
F P
s
P
p
.002 w
.54661 .59222 m .55579 .58655 L .578 .59275 L p
1 g
F P
s
P
p
.002 w
.59093 .57889 m .578 .59275 L .55579 .58655 L p
1 g
F P
s
P
p
.002 w
.38041 .35588 m .33687 .39853 L .32967 .37424 L p
1 g
F P
s
P
p
.002 w
.32967 .37424 m .37363 .33056 L .38041 .35588 L p
1 g
F P
s
P
p
.002 w
.5722 .28704 m .63065 .3083 L .6341 .33343 L p
1 g
F P
s
P
p
.002 w
.63065 .3083 m .5722 .28704 L .56595 .26617 L p
1 g
F P
s
P
p
.002 w
.39708 .53316 m .39533 .56308 L .36782 .54986 L p
1 g
F P
s
P
p
.002 w
.36782 .54986 m .36927 .51396 L .39708 .53316 L p
1 g
F P
s
P
p
.002 w
.65279 .45193 m .66935 .48392 L .64975 .50745 L p
1 g
F P
s
P
p
.002 w
.66935 .48392 m .65279 .45193 L .66531 .42267 L p
1 g
F P
s
P
p
.002 w
.43426 .29871 m .37363 .33056 L .37076 .30896 L p
1 g
F P
s
P
p
.002 w
.37076 .30896 m .43033 .27744 L .43426 .29871 L p
1 g
F P
s
P
p
.002 w
.49853 .26248 m .56595 .26617 L .5722 .28704 L p
1 g
F P
s
P
p
.002 w
.36639 .45121 m .3458 .49259 L .32736 .46986 L p
1 g
F P
s
P
p
.002 w
.32736 .46986 m .34919 .42448 L .36639 .45121 L p
1 g
F P
s
P
p
.002 w
.6336 .3622 m .6727 .39427 L .66531 .42267 L p
1 g
F P
s
P
p
.002 w
.6727 .39427 m .6336 .3622 L .6341 .33343 L p
1 g
F P
s
P
p
.002 w
.46032 .57798 m .46617 .5922 L .43549 .59331 L p
1 g
F P
s
P
p
.002 w
.43549 .59331 m .4265 .5726 L .46032 .57798 L p
1 g
F P
s
P
p
.002 w
.59093 .57889 m .59746 .5635 L .62593 .55168 L p
1 g
F P
s
P
p
.002 w
.62529 .52914 m .62593 .55168 L .59746 .5635 L p
1 g
F P
s
P
p
.002 w
.62593 .55168 m .62529 .52914 L .64975 .50745 L p
1 g
F P
s
P
p
.002 w
.49844 .58622 m .50468 .59202 L .47863 .60344 L p
1 g
F P
s
P
p
.002 w
.47863 .60344 m .46617 .5922 L .49844 .58622 L p
1 g
F P
s
P
p
.002 w
.55579 .58655 m .56234 .57941 L .59093 .57889 L p
1 g
F P
s
P
p
.002 w
.59746 .5635 m .59093 .57889 L .56234 .57941 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52443 .54399 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.53577 .59586 m .52439 .59708 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.50468 .59202 m .49844 .58622 L .51606 .58043 L p
1 g
F P
s
P
p
.002 w
.51606 .58043 m .53121 .57546 L .52396 .57998 L p
1 g
F P
s
P
p
.002 w
.52396 .57998 m .50468 .59202 L p
.51606 .58043 L 1 g
F P
s
P
p
.002 w
.49844 .58622 m .46617 .5922 L p
.49057 .58123 L 1 g
F P
s
P
p
.002 w
.48905 .5808 m .48921 .57862 L p
.47827 .57772 L 1 g
F P
s
P
p
.002 w
.48097 .57855 m .47465 .57837 L p
.47185 .57576 L 1 g
F P
s
P
p
.002 w
.47465 .57837 m .46032 .57798 L p
.47058 .576 L 1 g
F P
s
P
p
.47058 .576 m .47185 .57576 L .47465 .57837 L 1 g
F
P
p
.002 w
.46032 .57798 m .4265 .5726 L p
.45328 .56476 L 1 g
F P
s
P
p
.002 w
.46109 .57048 m .46032 .57798 L p
.45328 .56476 L 1 g
F P
s
P
p
.002 w
.46828 .57467 m .46872 .57265 L p
.45622 .56766 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45084 .56297 L p
1 g
F P
s
P
p
.4265 .5726 m .4368 .55268 L .45084 .56297 L 1 g
F
P
p
.45252 .56498 m .45084 .56297 L .45328 .56476 L 1 g
F
P
p
.4265 .5726 m .45084 .56297 L .45252 .56498 L 1 g
F
P
p
.002 w
.45084 .56297 m .45146 .56129 L p
.44429 .55506 L 1 g
F P
s
P
p
.002 w
.44477 .5557 m .44088 .55423 L p
.43961 .54872 L 1 g
F P
s
P
p
.002 w
.44088 .55423 m .42834 .54946 L p
.439 .54876 L 1 g
F P
s
P
p
.439 .54876 m .43961 .54872 L .44088 .55423 L 1 g
F
P
p
.002 w
.42834 .54946 m .39708 .53316 L p
.4324 .52778 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.4324 .52778 m .43262 .52857 L .42834 .54946 L 1 g
F
P
p
.002 w
.4351 .53742 m .43191 .5431 L p
.43262 .52857 L 1 g
F P
s
P
p
.002 w
.43191 .5431 m .42834 .54946 L p
.43262 .52857 L 1 g
F P
s
P
p
.002 w
.43262 .52857 m .43346 .52734 L p
.43316 .51862 L 1 g
F P
s
P
p
.41324 .50316 m .43464 .50445 L .43415 .50909 L 1 g
F
P
p
.002 w
.43305 .5196 m .43023 .51726 L p
.43415 .50909 L 1 g
F P
s
P
p
.002 w
.43023 .51726 m .41324 .50316 L p
.43415 .50909 L 1 g
F P
s
P
p
.002 w
.43415 .50909 m .43485 .50826 L p
.43729 .50255 L 1 g
F P
s
P
p
.43316 .51862 m .43305 .5196 L .43262 .52857 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43353 .50983 L p
1 g
F P
s
P
p
.002 w
.43353 .50983 m .43287 .51061 L p
.43313 .51796 L 1 g
F P
s
P
p
.43346 .52734 m .43353 .50983 L .43313 .51796 L 1 g
F
P
p
.002 w
.39708 .53316 m .41324 .50316 L .43305 .5196 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43262 .52857 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43845 .54716 L p
1 g
F P
s
P
p
.439 .54876 m .43908 .54801 L .43961 .54872 L 1 g
F
P
p
.002 w
.42834 .54946 m .4351 .53742 L p
.439 .54876 L 1 g
F P
s
P
p
.45146 .56129 m .43845 .54716 L .44429 .55506 L 1 g
F
P
p
.43925 .54566 m .43262 .52857 L .43512 .53748 L 1 g
F
P
p
.002 w
.43845 .54716 m .43925 .54566 L p
.43513 .53751 L 1 g
F P
s
P
p
.002 w
.4351 .53742 m .44128 .52642 L p
.439 .54876 L 1 g
F P
s
P
p
.002 w
.43845 .54716 m .43743 .5491 L p
.44429 .55506 L 1 g
F P
s
P
p
.002 w
.44128 .52642 m .47104 .54668 L p
.43961 .54872 L 1 g
F P
s
P
p
.43908 .54801 m .44128 .52642 L .43961 .54872 L 1 g
F
P
p
.43512 .53748 m .4351 .53742 L .43146 .53025 L 1 g
F
P
p
.002 w
.43262 .52857 m .43224 .52912 L p
.4351 .53742 L 1 g
F P
s
P
p
.002 w
.43224 .52912 m .43146 .53025 L p
.4351 .53742 L 1 g
F P
s
P
p
.002 w
.43305 .5196 m .44128 .52642 L p
.43266 .52774 L 1 g
F P
s
P
p
.39708 .53316 m .43305 .5196 L .43266 .52774 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43415 .50909 m .46422 .50624 L .43305 .5196 L 1 g
F
P
p
.43464 .50445 m .43633 .50455 L .43415 .50909 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44275 .49118 L p
1 g
F P
s
P
p
.43485 .50826 m .44275 .49118 L .43729 .50255 L 1 g
F
P
p
.43633 .50455 m .46422 .50624 L .43415 .50909 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44275 .49118 m .44339 .4905 L p
.45033 .48385 L 1 g
F P
s
P
p
.45425 .48004 m .49466 .49144 L .44885 .48529 L 1 g
F
P
p
.45033 .48385 m .45184 .4824 L .44885 .48529 L 1 g
F
P
p
.45033 .48385 m .44885 .48529 L .44275 .49118 L 1 g
F
P
p
.002 w
.49466 .49144 m .46422 .50624 L .44885 .48529 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45779 .4766 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45425 .48004 m .45935 .47585 L .49466 .49144 L 1 g
F
P
p
.002 w
.45779 .4766 m .45826 .47608 L p
.4656 .47286 L 1 g
F P
s
P
p
.45935 .47585 m .47758 .46713 L .49466 .49144 L 1 g
F
P
p
.002 w
.47758 .46713 m .47786 .46667 L p
.48879 .46556 L 1 g
F P
s
P
p
.4947 .4646 m .52895 .48394 L .48516 .46614 L 1 g
F
P
p
.48879 .46556 m .49276 .46515 L .48516 .46614 L 1 g
F
P
p
.48879 .46556 m .48516 .46614 L .47758 .46713 L 1 g
F
P
p
.002 w
.52895 .48394 m .49466 .49144 L .48516 .46614 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48186 .45736 m .5263 .44764 L .52715 .45936 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.56286 .48466 m .55907 .48458 L p
.5263 .44764 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56596 .50923 L p
1 g
F P
s
P
p
.002 w
.55974 .4961 m .56286 .48466 L p
.56399 .48909 L 1 g
F P
s
P
p
.56399 .48909 m .57297 .52402 L .56596 .50923 L 1 g
F
P
p
.56399 .48909 m .56596 .50923 L .55974 .4961 L 1 g
F
P
p
.002 w
.56596 .50923 m .56515 .50826 L p
.56711 .52096 L 1 g
F P
s
P
p
.55661 .4905 m .56596 .50923 L .56173 .5003 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56754 .5288 L p
1 g
F P
s
P
p
.002 w
.5737 .52423 m .5677 .53229 L p
.56754 .5288 L 1 g
F P
s
P
p
.002 w
.56725 .52239 m .56933 .52298 L p
.56754 .5288 L 1 g
F P
s
P
p
.002 w
.56933 .52298 m .5737 .52423 L p
.56754 .5288 L 1 g
F P
s
P
p
.002 w
.56754 .5288 m .56654 .52734 L p
.56451 .53845 L 1 g
F P
s
P
p
.002 w
.5656 .53511 m .5737 .52423 L p
.56552 .54163 L 1 g
F P
s
P
p
.56552 .54163 m .55888 .55577 L .56163 .54732 L 1 g
F
P
p
.56552 .54163 m .56163 .54732 L .5656 .53511 L 1 g
F
P
p
.002 w
.5607 .55699 m .55888 .55577 L p
.5737 .52423 L 1 g
F P
s
P
p
.002 w
.56163 .54732 m .56075 .54566 L p
.55444 .55709 L 1 g
F P
s
P
p
.002 w
.5607 .55699 m .5473 .56538 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.55679 .55437 m .55941 .55613 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.55941 .55613 m .5607 .55699 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.54923 .56314 m .54854 .56129 L p
.53973 .56968 L 1 g
F P
s
P
p
.55444 .55709 m .55679 .55437 L .56163 .54732 L 1 g
F
P
p
.002 w
.49844 .58622 m .49765 .58416 L p
.51108 .58067 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51079 .57862 L p
.49709 .58136 L 1 g
F P
s
P
p
.002 w
.53182 .57513 m .53128 .57265 L p
.52253 .57765 L 1 g
F P
s
P
p
.52253 .57765 m .53076 .5755 L .53182 .57513 L 1 g
F
P
p
.002 w
.53121 .57546 m .51606 .58043 L p
.51108 .58067 L 1 g
F P
s
P
p
.002 w
.53076 .5755 m .53121 .57546 L p
.49765 .58416 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51532 .58177 L p
.53128 .57265 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51606 .58043 m .49844 .58622 L p
.51108 .58067 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.49664 .57099 m .50139 .5632 L .5311 .57541 L p
1 g
F P
s
P
p
.002 w
.5311 .57541 m .53121 .57546 L .53102 .57543 L p
1 g
F P
s
P
p
.002 w
.53102 .57543 m .49664 .57099 L p
.5311 .57541 L 1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50139 .5632 m .5094 .55646 L .53114 .5754 L p
1 g
F P
s
P
p
.002 w
.53114 .5754 m .53121 .57546 L .5311 .57541 L p
1 g
F P
s
P
p
.002 w
.5311 .57541 m .50139 .5632 L p
.53114 .5754 L 1 g
F P
s
P
p
.53106 .57542 m .53115 .5754 L .53116 .57539 L 1 g
F
P
p
.53102 .57543 m .53105 .57542 L .53106 .57542 L 1 g
F
P
p
.53105 .57542 m .53115 .5754 L .53106 .57542 L 1 g
F
P
p
.002 w
.53102 .57543 m .53121 .57546 L .53076 .5755 L p
1 g
F P
s
P
p
.53076 .5755 m .53094 .57545 L .53102 .57543 L 1 g
F
P
p
.53094 .57545 m .53115 .5754 L .53102 .57543 L 1 g
F
P
p
.53123 .57536 m .53156 .57524 L .53182 .57513 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.5198 .55153 m .53142 .54899 L .53121 .57537 L p
1 g
F P
s
P
p
.002 w
.53121 .57537 m .53121 .57546 L .53117 .57539 L p
1 g
F P
s
P
p
.002 w
.53117 .57539 m .5198 .55153 L p
.53121 .57537 L 1 g
F P
s
P
p
.002 w
.53125 .57536 m .53121 .57546 L .53121 .57537 L p
1 g
F P
s
P
p
.53122 .57537 m .53128 .57535 L .53123 .57536 L 1 g
F
P
p
.002 w
.5094 .55646 m .5198 .55153 L .53117 .57539 L p
1 g
F P
s
P
p
.002 w
.53117 .57539 m .53121 .57546 L .53114 .5754 L p
1 g
F P
s
P
p
.002 w
.53114 .5754 m .5094 .55646 L p
.53117 .57539 L 1 g
F P
s
P
p
.53121 .57537 m .53125 .57536 L .53122 .57537 L 1 g
F
P
p
.51588 .58145 m .53123 .57537 L .53121 .57537 L 1 g
F
P
p
.53123 .57537 m .53125 .57536 L .53121 .57537 L 1 g
F
P
p
.002 w
.53133 .57533 m .53121 .57546 L .53125 .57536 L p
1 g
F P
s
P
p
.53125 .57536 m .53128 .57535 L .53122 .57537 L 1 g
F
P
p
.53128 .57535 m .53156 .57524 L .53123 .57536 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53182 .57513 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53142 .54899 m .54296 .54912 L .53125 .57536 L p
1 g
F P
s
P
p
.53076 .5755 m .53116 .57539 L .53182 .57513 L 1 g
F
P
p
.002 w
.53121 .57537 m .53142 .54899 L p
.53125 .57536 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54296 .54912 m .55309 .5519 L .53133 .57533 L p
1 g
F P
s
P
p
.002 w
.53125 .57536 m .54296 .54912 L p
.53133 .57533 L 1 g
F P
s
P
p
.53116 .57539 m .53116 .57539 L .53121 .57537 L 1 g
F
P
p
.53116 .57539 m .53121 .57537 L .53182 .57513 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .5808 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .5808 L .49331 .58113 L 1 g
F
P
p
.47827 .57772 m .48097 .57855 L .48905 .5808 L 1 g
F
P
p
.002 w
.46032 .57798 m .49564 .57895 L p
.49116 .58097 L 1 g
F P
s
P
p
.002 w
.46617 .5922 m .46058 .57862 L p
.49116 .58097 L 1 g
F P
s
P
p
.002 w
.46058 .57862 m .46032 .57798 L p
.49116 .58097 L 1 g
F P
s
P
p
.49057 .58123 m .49116 .58097 L .49213 .58167 L 1 g
F
P
p
.49057 .58123 m .49213 .58167 L .49844 .58622 L 1 g
F
P
p
.002 w
.49658 .58138 m .49844 .58622 L p
.49116 .58097 L 1 g
F P
s
P
p
.002 w
.48905 .5808 m .48898 .58176 L p
.49331 .58113 L 1 g
F P
s
P
p
.51079 .57862 m .48898 .58176 L .49709 .58136 L 1 g
F
P
p
.002 w
.49564 .57895 m .53076 .5755 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.49765 .58416 m .49658 .58138 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.49658 .58138 m .49564 .57895 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.48898 .58176 m .48889 .583 L p
.49709 .58136 L 1 g
F P
s
P
p
.002 w
.49564 .57895 m .49664 .57099 L .53102 .57543 L p
1 g
F P
s
P
p
.002 w
.53076 .5755 m .49564 .57895 L p
.53102 .57543 L 1 g
F P
s
P
p
.002 w
.51095 .58072 m .51094 .58068 L p
.49596 .58158 L 1 g
F P
s
P
p
.49709 .58136 m .49596 .58158 L .51094 .58068 L 1 g
F
P
p
.52253 .57765 m .51588 .58145 L .53115 .5754 L 1 g
F
P
p
.51588 .58145 m .51532 .58177 L .53156 .57524 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54924 .56317 L p
1 g
F P
s
P
p
.5607 .55699 m .54254 .57082 L .54723 .56546 L 1 g
F
P
p
.002 w
.5328 .57446 m .5473 .56538 L p
.53149 .57536 L 1 g
F P
s
P
p
.002 w
.5473 .56538 m .5607 .55699 L p
.54723 .56546 L 1 g
F P
s
P
p
.54723 .56546 m .53149 .57536 L .5473 .56538 L 1 g
F
P
p
.55426 .55742 m .54977 .56461 L .55247 .56068 L 1 g
F
P
p
.56075 .54566 m .5533 .55853 L .55426 .55742 L 1 g
F
P
p
.5533 .55853 m .54977 .56461 L .55426 .55742 L 1 g
F
P
p
.002 w
.54924 .56317 m .54977 .56461 L p
.5533 .55853 L 1 g
F P
s
P
p
.56075 .54566 m .54924 .56317 L .5533 .55853 L 1 g
F
P
p
.002 w
.5607 .55699 m .56398 .56219 L p
.54254 .57082 L 1 g
F P
s
P
p
.54723 .56546 m .54254 .57082 L .53191 .5751 L 1 g
F
P
p
.56451 .53845 m .5656 .53511 L .56754 .5288 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56176 .54757 L p
1 g
F P
s
P
p
.56654 .52734 m .56176 .54757 L .56443 .53892 L 1 g
F
P
p
.56515 .50826 m .56754 .5288 L .56737 .52514 L 1 g
F
P
p
.56515 .50826 m .56793 .52936 L .56711 .52096 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56725 .52239 m .56754 .5288 L .55309 .5519 L 1 g
F
P
p
.002 w
.5677 .53229 m .5656 .53511 L p
.56754 .5288 L 1 g
F P
s
P
p
.002 w
.5656 .53511 m .55309 .5519 L p
.56754 .5288 L 1 g
F P
s
P
p
.002 w
.56176 .54757 m .56257 .5491 L p
.56443 .53892 L 1 g
F P
s
P
p
.002 w
.55309 .5519 m .5656 .53511 L p
.56163 .54732 L 1 g
F P
s
P
p
.002 w
.55888 .55577 m .55679 .55437 L p
.56163 .54732 L 1 g
F P
s
P
p
.002 w
.55679 .55437 m .55309 .5519 L p
.56163 .54732 L 1 g
F P
s
P
p
.002 w
.54977 .56461 m .54998 .56518 L p
.55247 .56068 L 1 g
F P
s
P
p
.002 w
.55309 .5519 m .55679 .55437 L p
.53139 .5753 L 1 g
F P
s
P
p
.002 w
.53121 .57546 m .53133 .57533 L p
.53139 .5753 L 1 g
F P
s
P
p
.002 w
.53133 .57533 m .55309 .5519 L p
.53139 .5753 L 1 g
F P
s
P
p
.54854 .56129 m .53182 .57513 L .53223 .57485 L 1 g
F
P
p
.002 w
.5473 .56538 m .5328 .57446 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.56499 .56379 m .53149 .57536 L p
.53191 .5751 L 1 g
F P
s
P
p
.002 w
.56398 .56219 m .56499 .56379 L p
.53191 .5751 L 1 g
F P
s
P
p
.53973 .56968 m .53183 .57518 L .5372 .5721 L 1 g
F
P
p
.54854 .56129 m .53222 .57486 L .53973 .56968 L 1 g
F
P
p
.53222 .57486 m .53183 .57518 L .53973 .56968 L 1 g
F
P
p
.55679 .55437 m .54923 .56314 L .53156 .57524 L 1 g
F
P
p
.002 w
.5328 .57446 m .53156 .57524 L p
.54923 .56314 L 1 g
F P
s
P
p
.002 w
.53156 .57524 m .53121 .57546 L p
.53139 .5753 L 1 g
F P
s
P
p
.55679 .55437 m .53156 .57524 L .53139 .5753 L 1 g
F
P
p
.002 w
.54661 .59222 m .53577 .59586 L .53122 .57553 L p
1 g
F P
s
P
p
.002 w
.53122 .57553 m .53121 .57546 L .53126 .57551 L p
1 g
F P
s
P
p
.002 w
.53126 .57551 m .54661 .59222 L p
.53122 .57553 L 1 g
F P
s
P
p
.002 w
.52439 .59708 m .51365 .59576 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.55579 .58655 m .54661 .59222 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.51365 .59576 m .50468 .59202 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.56234 .57941 m .55579 .58655 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.56554 .57155 m .56234 .57941 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.56499 .56379 m .56554 .57155 L .53121 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.51532 .58177 m .5322 .57686 L .53182 .57513 L p
1 g
F P
s
P
p
.002 w
.53149 .57536 m .53121 .57546 L .5328 .57446 L p
1 g
F P
s
P
p
.002 w
.53182 .57513 m .53182 .57513 L p
.53156 .57524 L 1 g
F P
s
P
p
.53156 .57524 m .51532 .58177 L .53182 .57513 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54923 .56314 L p
1 g
F P
s
P
p
.53973 .56968 m .5322 .57686 L .54923 .56314 L 1 g
F
P
p
.55444 .55709 m .55247 .56068 L .55679 .55437 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56163 .54732 L p
1 g
F P
s
P
p
.55247 .56068 m .54998 .56518 L .56163 .54732 L 1 g
F
P
p
.56451 .53845 m .56443 .53892 L .5656 .53511 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56754 .5288 L p
1 g
F P
s
P
p
.56443 .53892 m .56257 .5491 L .56754 .5288 L 1 g
F
P
p
.002 w
.56754 .5288 m .56793 .52936 L p
.56737 .52514 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55365 .51851 m .56725 .52239 L p
.55309 .5519 L 1 g
F P
s
P
p
.002 w
.55406 .48447 m .56286 .48466 L .56028 .49413 L p
1 g
F P
s
P
p
.002 w
.56028 .49413 m .55974 .4961 L p
.55743 .49137 L 1 g
F P
s
P
p
.55406 .48447 m .56028 .49413 L .55743 .49137 L 1 g
F
P
p
.002 w
.55743 .49137 m .55661 .4905 L p
.56272 .50219 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55743 .49137 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55743 .49137 L p
1 g
F P
s
P
p
.56272 .50219 m .56713 .51061 L .55743 .49137 L 1 g
F
P
p
.54174 .47608 m .55743 .49137 L .5537 .48776 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.52895 .48394 m .55022 .48439 L p
.55365 .51851 L 1 g
F P
s
P
p
.54174 .47608 m .5537 .48776 L .55064 .4848 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.55022 .48439 m .55401 .48806 L .55365 .51851 L 1 g
F
P
p
.002 w
.55974 .4961 m .55365 .51851 L p
.55401 .48806 L 1 g
F P
s
P
p
.55743 .49137 m .55974 .4961 L .55401 .48806 L 1 g
F
P
p
.002 w
.55022 .48439 m .52895 .48394 L p
.54223 .47662 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54251 .47693 L p
1 g
F P
s
P
p
.54174 .47608 m .55064 .4848 L .55022 .48439 L 1 g
F
P
p
.002 w
.54223 .47662 m .54174 .47608 L p
.55022 .48439 L 1 g
F P
s
P
p
.5263 .44764 m .55907 .48458 L .54223 .47662 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47662 L p
1 g
F P
s
P
p
.52214 .46667 m .54223 .47662 L .53371 .47259 L 1 g
F
P
p
.002 w
.52895 .48394 m .52792 .46985 L p
.54223 .47662 L 1 g
F P
s
P
p
.52214 .46667 m .5428 .47724 L .53681 .47426 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52792 .46985 m .52895 .48394 L p
.51502 .466 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46711 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46711 L .50823 .46498 L 1 g
F
P
p
.51179 .46184 m .52241 .46711 L .51502 .466 L 1 g
F
P
p
.52241 .46711 m .52792 .46985 L .51502 .466 L 1 g
F
P
p
.4947 .4646 m .5 .46375 L .52895 .48394 L 1 g
F
P
p
.002 w
.5 .46375 m .5 .4634 L p
.50823 .46498 L 1 g
F P
s
P
p
.5 .46375 m .51179 .46184 L .51502 .466 L 1 g
F
P
p
.5 .46375 m .51502 .466 L .52895 .48394 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.50823 .46498 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.52241 .46711 m .52282 .46778 L p
.50823 .46498 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52792 .46985 m .52736 .46215 L p
.54223 .47662 L 1 g
F P
s
P
p
.002 w
.52736 .46215 m .5263 .44764 L p
.54223 .47662 L 1 g
F P
s
P
p
.002 w
.54251 .47693 m .54223 .47662 L p
.55022 .48439 L 1 g
F P
s
P
p
.55064 .4848 m .55834 .49233 L .54251 .47693 L 1 g
F
P
p
.55406 .48447 m .55743 .49137 L .55401 .48806 L 1 g
F
P
p
.002 w
.55022 .48439 m .55406 .48447 L p
.55401 .48806 L 1 g
F P
s
P
p
.55064 .4848 m .55779 .49175 L .55092 .48507 L 1 g
F
P
p
.5537 .48776 m .55779 .49175 L .55064 .4848 L 1 g
F
P
p
.002 w
.55743 .49137 m .55779 .49175 L p
.5537 .48776 L 1 g
F P
s
P
p
.002 w
.55365 .51851 m .55974 .4961 L p
.56596 .50923 L 1 g
F P
s
P
p
.002 w
.57297 .52402 m .56725 .52239 L p
.56596 .50923 L 1 g
F P
s
P
p
.002 w
.56725 .52239 m .55365 .51851 L p
.56596 .50923 L 1 g
F P
s
P
p
.002 w
.56793 .52936 m .56854 .53025 L p
.56711 .52096 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56596 .50923 L p
1 g
F P
s
P
p
.56711 .52096 m .56854 .53025 L .56596 .50923 L 1 g
F
P
p
.002 w
.56596 .50923 m .56713 .51061 L p
.56173 .5003 L 1 g
F P
s
P
p
.002 w
.5737 .52423 m .57297 .52402 L p
.56286 .48466 L 1 g
F P
s
P
p
.002 w
.55779 .49175 m .55834 .49233 L p
.55092 .48507 L 1 g
F P
s
P
p
.002 w
.55907 .48458 m .55022 .48439 L p
.54223 .47662 L 1 g
F P
s
P
p
.002 w
.54223 .47662 m .5428 .47724 L p
.53371 .47259 L 1 g
F P
s
P
p
.002 w
.5428 .47724 m .54302 .47747 L p
.53681 .47426 L 1 g
F P
s
P
p
.002 w
.52715 .45936 m .52792 .46985 L p
.51179 .46184 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .49081 .46523 L 1 g
F
P
p
.48186 .45736 m .52715 .45936 L .4947 .4646 L 1 g
F
P
p
.002 w
.5 .46375 m .5 .46421 L p
.49081 .46523 L 1 g
F P
s
P
p
.002 w
.5 .46421 m .5 .46442 L p
.49276 .46515 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46421 L .49276 .46515 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47758 .46713 L p
1 g
F P
s
P
p
.002 w
.47758 .46713 m .47718 .46778 L p
.4656 .47286 L 1 g
F P
s
P
p
.45826 .47608 m .47758 .46713 L .4656 .47286 L 1 g
F
P
p
.002 w
.48186 .45736 m .48432 .46391 L p
.47758 .46713 L 1 g
F P
s
P
p
.45935 .47585 m .46852 .46831 L .47758 .46713 L 1 g
F
P
p
.46852 .46831 m .48186 .45736 L .47758 .46713 L 1 g
F
P
p
.002 w
.48516 .46614 m .48186 .45736 L p
.4947 .4646 L 1 g
F P
s
P
p
.002 w
.48432 .46391 m .48516 .46614 L p
.47758 .46713 L 1 g
F P
s
P
p
.002 w
.48516 .46614 m .49466 .49144 L p
.47758 .46713 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47758 .46713 L p
1 g
F P
s
P
p
.49276 .46515 m .5 .46442 L .47758 .46713 L 1 g
F
P
p
.002 w
.47314 .46166 m .48186 .45736 L p
.45425 .48004 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45779 .4766 L p
1 g
F P
s
P
p
.4656 .47286 m .47718 .46778 L .45779 .4766 L 1 g
F
P
p
.002 w
.45779 .4766 m .45698 .47747 L p
.45033 .48385 L 1 g
F P
s
P
p
.44339 .4905 m .45779 .4766 L .45033 .48385 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44257 .47674 m .47314 .46166 L p
.45425 .48004 L 1 g
F P
s
P
p
.002 w
.44885 .48529 m .44257 .47674 L p
.45425 .48004 L 1 g
F P
s
P
p
.002 w
.41324 .50316 m .44257 .47674 L .44885 .48529 L p
1 g
F P
s
P
p
.002 w
.44885 .48529 m .46422 .50624 L p
.42934 .50413 L 1 g
F P
s
P
p
.41324 .50316 m .44885 .48529 L .42934 .50413 L 1 g
F
P
p
.002 w
.44275 .49118 m .44166 .49233 L p
.43729 .50255 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44275 .49118 L p
1 g
F P
s
P
p
.45184 .4824 m .45698 .47747 L .44275 .49118 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43415 .50909 L p
1 g
F P
s
P
p
.43729 .50255 m .44166 .49233 L .43415 .50909 L 1 g
F
P
p
.43316 .51862 m .43313 .51796 L .43305 .5196 L 1 g
F
P
p
.002 w
.46422 .50624 m .44128 .52642 L .43305 .5196 L p
1 g
F P
s
P
p
.002 w
.44128 .52642 m .4351 .53742 L p
.4324 .52778 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43262 .52857 L p
1 g
F P
s
P
p
.43313 .51796 m .43287 .51061 L .43262 .52857 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43804 .54794 L p
1 g
F P
s
P
p
.002 w
.43804 .54794 m .43845 .54716 L p
.43652 .54248 L 1 g
F P
s
P
p
.43652 .54248 m .43146 .53025 L .43804 .54794 L 1 g
F
P
p
.43513 .53751 m .43146 .53025 L .43845 .54716 L 1 g
F
P
p
.44429 .55506 m .44406 .55486 L .44477 .5557 L 1 g
F
P
p
.44429 .55506 m .44477 .5557 L .45084 .56297 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47104 .54668 m .46193 .56223 L .44477 .5557 L p
1 g
F P
s
P
p
.43961 .54872 m .47104 .54668 L .44477 .5557 L 1 g
F
P
p
.46872 .57265 m .45084 .56297 L .45844 .56854 L 1 g
F
P
p
.002 w
.4368 .55268 m .46193 .56223 L p
.45328 .56476 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45084 .56297 L p
1 g
F P
s
P
p
.44406 .55486 m .43743 .5491 L .45084 .56297 L 1 g
F
P
p
.002 w
.45084 .56297 m .45002 .56518 L p
.45844 .56854 L 1 g
F P
s
P
p
.002 w
.4265 .5726 m .42834 .54946 L .4368 .55268 L p
1 g
F P
s
P
p
.002 w
.46193 .56223 m .46109 .57048 L p
.45328 .56476 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46828 .57467 L p
1 g
F P
s
P
p
.48921 .57862 m .46828 .57467 L .47827 .57772 L 1 g
F
P
p
.002 w
.46193 .56223 m .49664 .57099 L p
.47185 .57576 L 1 g
F P
s
P
p
.002 w
.46032 .57798 m .46089 .57241 L p
.47185 .57576 L 1 g
F P
s
P
p
.002 w
.46089 .57241 m .46193 .56223 L p
.47185 .57576 L 1 g
F P
s
P
p
.002 w
.46828 .57467 m .4678 .57686 L p
.47827 .57772 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46807 .57561 L p
1 g
F P
s
P
p
.002 w
.46807 .57561 m .46828 .57467 L p
.46317 .57201 L 1 g
F P
s
P
p
.46317 .57201 m .45002 .56518 L .46807 .57561 L 1 g
F
P
p
.45622 .56766 m .45002 .56518 L .46828 .57467 L 1 g
F
P
p
.47827 .57772 m .47792 .57769 L .48097 .57855 L 1 g
F
P
p
.002 w
.49664 .57099 m .49564 .57895 L .48097 .57855 L p
1 g
F P
s
P
p
.47185 .57576 m .49664 .57099 L .48097 .57855 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .5808 L p
1 g
F P
s
P
p
.47792 .57769 m .4678 .57686 L .48905 .5808 L 1 g
F
P
p
.002 w
.49564 .57895 m .49658 .58138 L p
.49116 .58097 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51108 .5825 L p
1 g
F P
s
P
p
.002 w
.51108 .5825 m .51095 .58072 L p
.50114 .58173 L 1 g
F P
s
P
p
.50114 .58173 m .48889 .583 L .51108 .5825 L 1 g
F
P
p
.49596 .58158 m .48889 .583 L .51095 .58072 L 1 g
F
P
p
.002 w
.53182 .57513 m .53183 .57518 L p
.53223 .57485 L 1 g
F P
s
P
p
.002 w
.53183 .57518 m .5322 .57686 L p
.5372 .5721 L 1 g
F P
s
P
p
.002 w
.42834 .54946 m .4265 .5726 L .39533 .56308 L p
1 g
F P
s
P
p
.002 w
.39533 .56308 m .39708 .53316 L .42834 .54946 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.63544 .48102 m .64975 .50745 L .62529 .52914 L p
1 g
F P
s
P
p
.002 w
.64975 .50745 m .63544 .48102 L .65279 .45193 L p
1 g
F P
s
P
p
.002 w
.50366 .2835 m .43426 .29871 L .43033 .27744 L p
1 g
F P
s
P
p
.002 w
.43033 .27744 m .49853 .26248 L .50366 .2835 L p
1 g
F P
s
P
p
.002 w
.5722 .28704 m .50366 .2835 L .49853 .26248 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.38797 .47776 m .36927 .51396 L .3458 .49259 L p
1 g
F P
s
P
p
.002 w
.3458 .49259 m .36639 .45121 L .38797 .47776 L p
1 g
F P
s
P
p
.002 w
.39106 .38419 m .34919 .42448 L .33687 .39853 L p
1 g
F P
s
P
p
.002 w
.33687 .39853 m .38041 .35588 L .39106 .38419 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.57646 .31293 m .6341 .33343 L .6336 .3622 L p
1 g
F P
s
P
p
.002 w
.6341 .33343 m .57646 .31293 L .5722 .28704 L p
1 g
F P
s
P
p
.002 w
.62903 .39371 m .66531 .42267 L .65279 .45193 L p
1 g
F P
s
P
p
.002 w
.66531 .42267 m .62903 .39371 L .6336 .3622 L p
1 g
F P
s
P
p
.002 w
.56234 .57941 m .56554 .57155 L .59746 .5635 L p
1 g
F P
s
P
p
.002 w
.59673 .54816 m .59746 .5635 L .56554 .57155 L p
1 g
F P
s
P
p
.002 w
.59746 .5635 m .59673 .54816 L .62529 .52914 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.44034 .32472 m .38041 .35588 L .37363 .33056 L p
1 g
F P
s
P
p
.002 w
.37363 .33056 m .43426 .29871 L .44034 .32472 L p
1 g
F P
s
P
p
.002 w
.50366 .2835 m .5722 .28704 L .57646 .31293 L p
1 g
F P
s
P
p
.002 w
.61379 .5089 m .62529 .52914 L .59673 .54816 L p
1 g
F P
s
P
p
.002 w
.62529 .52914 m .61379 .5089 L .63544 .48102 L p
1 g
F P
s
P
p
.002 w
.56554 .57155 m .56499 .56379 L .59673 .54816 L p
1 g
F P
s
P
p
.002 w
.41324 .50316 m .39708 .53316 L .36927 .51396 L p
1 g
F P
s
P
p
.002 w
.36927 .51396 m .38797 .47776 L .41324 .50316 L p
1 g
F P
s
P
p
.002 w
.62043 .42689 m .65279 .45193 L .63544 .48102 L p
1 g
F P
s
P
p
.002 w
.65279 .45193 m .62043 .42689 L .62903 .39371 L p
1 g
F P
s
P
p
.002 w
.58858 .53454 m .59673 .54816 L .56499 .56379 L p
1 g
F P
s
P
p
.002 w
.59673 .54816 m .58858 .53454 L .61379 .5089 L p
1 g
F P
s
P
p
.002 w
.40529 .41452 m .36639 .45121 L .34919 .42448 L p
1 g
F P
s
P
p
.002 w
.34919 .42448 m .39106 .38419 L .40529 .41452 L p
1 g
F P
s
P
p
.002 w
.57849 .34313 m .6336 .3622 L .62903 .39371 L p
1 g
F P
s
P
p
.002 w
.6336 .3622 m .57849 .34313 L .57646 .31293 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.56499 .56379 m .5607 .55699 L .58858 .53454 L p
1 g
F P
s
P
p
.002 w
.50885 .3097 m .44034 .32472 L .43426 .29871 L p
1 g
F P
s
P
p
.002 w
.43426 .29871 m .50366 .2835 L .50885 .3097 L p
1 g
F P
s
P
p
.002 w
.57646 .31293 m .50885 .3097 L .50366 .2835 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60803 .46055 m .63544 .48102 L .61379 .5089 L p
1 g
F P
s
P
p
.002 w
.63544 .48102 m .60803 .46055 L .62043 .42689 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.44843 .35469 m .39106 .38419 L .38041 .35588 L p
1 g
F P
s
P
p
.002 w
.38041 .35588 m .44034 .32472 L .44843 .35469 L p
1 g
F P
s
P
p
.002 w
.50139 .5632 m .49664 .57099 L .46193 .56223 L p
1 g
F P
s
P
p
.002 w
.5737 .52423 m .58858 .53454 L .5607 .55699 L p
1 g
F P
s
P
p
.002 w
.50885 .3097 m .57646 .31293 L .57849 .34313 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59226 .4934 m .61379 .5089 L .58858 .53454 L p
1 g
F P
s
P
p
.002 w
.61379 .5089 m .59226 .4934 L .60803 .46055 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46193 .56223 m .47104 .54668 L .50139 .5632 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.58858 .53454 m .5737 .52423 L .59226 .4934 L p
1 g
F P
s
P
p
.002 w
.42267 .44577 m .38797 .47776 L .36639 .45121 L p
1 g
F P
s
P
p
.002 w
.36639 .45121 m .40529 .41452 L .42267 .44577 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.57814 .37667 m .62903 .39371 L .62043 .42689 L p
1 g
F P
s
P
p
.002 w
.62903 .39371 m .57814 .37667 L .57849 .34313 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.5094 .55646 m .50139 .5632 L .47104 .54668 L p
1 g
F P
s
P
p
.002 w
.55309 .5519 m .54296 .54912 L .55365 .51851 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5198 .55153 m .5094 .55646 L .48679 .53313 L p
1 g
F P
s
P
p
.002 w
.47104 .54668 m .48679 .53313 L .5094 .55646 L p
1 g
F P
s
P
p
.002 w
.54296 .54912 m .53142 .54899 L .53067 .51814 L p
1 g
F P
s
P
p
.002 w
.53067 .51814 m .55365 .51851 L .54296 .54912 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53142 .54899 m .5198 .55153 L .50747 .52321 L p
1 g
F P
s
P
p
.002 w
.48679 .53313 m .50747 .52321 L .5198 .55153 L p
1 g
F P
s
P
p
.002 w
.50747 .52321 m .53067 .51814 L .53142 .54899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.44257 .47674 m .41324 .50316 L .38797 .47776 L p
1 g
F P
s
P
p
.002 w
.38797 .47776 m .42267 .44577 L .44257 .47674 L p
1 g
F P
s
P
p
.002 w
.5139 .34035 m .44843 .35469 L .44034 .32472 L p
1 g
F P
s
P
p
.002 w
.44034 .32472 m .50885 .3097 L .5139 .34035 L p
1 g
F P
s
P
p
.002 w
.57849 .34313 m .5139 .34035 L .50885 .3097 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57534 .41235 m .62043 .42689 L .60803 .46055 L p
1 g
F P
s
P
p
.002 w
.62043 .42689 m .57534 .41235 L .57814 .37667 L p
1 g
F P
s
P
p
.002 w
.48679 .53313 m .47104 .54668 L .44128 .52642 L p
1 g
F P
s
P
p
.002 w
.56286 .48466 m .59226 .4934 L .5737 .52423 L p
1 g
F P
s
P
p
.002 w
.45829 .38762 m .40529 .41452 L .39106 .38419 L p
1 g
F P
s
P
p
.002 w
.39106 .38419 m .44843 .35469 L .45829 .38762 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5139 .34035 m .57849 .34313 L .57814 .37667 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44128 .52642 m .46422 .50624 L .48679 .53313 L p
1 g
F P
s
P
p
.002 w
.57019 .44882 m .60803 .46055 L .59226 .4934 L p
1 g
F P
s
P
p
.002 w
.60803 .46055 m .57019 .44882 L .57534 .41235 L p
1 g
F P
s
P
p
.002 w
.59226 .4934 m .56286 .48466 L .57019 .44882 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.50747 .52321 m .48679 .53313 L .46422 .50624 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55365 .51851 m .53067 .51814 L .52895 .48394 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46958 .42229 m .42267 .44577 L .40529 .41452 L p
1 g
F P
s
P
p
.002 w
.40529 .41452 m .45829 .38762 L .46958 .42229 L p
1 g
F P
s
P
p
.002 w
.51862 .37441 m .57814 .37667 L .57534 .41235 L p
1 g
F P
s
P
p
.002 w
.57814 .37667 m .51862 .37441 L .5139 .34035 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.53067 .51814 m .50747 .52321 L .49466 .49144 L p
1 g
F P
s
P
p
.002 w
.46422 .50624 m .49466 .49144 L .50747 .52321 L p
1 g
F P
s
P
p
.002 w
.49466 .49144 m .52895 .48394 L .53067 .51814 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.51862 .37441 m .45829 .38762 L .44843 .35469 L p
1 g
F P
s
P
p
.002 w
.44843 .35469 m .5139 .34035 L .51862 .37441 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5263 .44764 m .57019 .44882 L .56286 .48466 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.54188 .625 m
.54392 .63451 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.48186 .45736 m .44257 .47674 L .42267 .44577 L p
1 g
F P
s
P
p
.002 w
.42267 .44577 m .46958 .42229 L .48186 .45736 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52281 .41064 m .57534 .41235 L .57019 .44882 L p
1 g
F P
s
P
p
.002 w
.57534 .41235 m .52281 .41064 L .51862 .37441 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.57019 .44882 m .5263 .44764 L .52281 .41064 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.52281 .41064 m .46958 .42229 L .45829 .38762 L p
1 g
F P
s
P
p
.002 w
.45829 .38762 m .51862 .37441 L .52281 .41064 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5263 .44764 m .48186 .45736 L .46958 .42229 L p
1 g
F P
s
P
p
.002 w
.46958 .42229 m .52281 .41064 L .5263 .44764 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .7808 .50755 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .54943 .66009 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0162791)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0162791)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45799 .46225 m .50542 .46749 L .50535 .43908 L p
1 g
F P
s
P
p
.002 w
.50535 .43908 m .46378 .43442 L .45799 .46225 L p
1 g
F P
s
P
p
.002 w
.54666 .43393 m .50535 .43908 L .50542 .46749 L p
1 g
F P
s
P
p
.002 w
.46378 .43442 m .50535 .43908 L .50515 .41051 L p
1 g
F P
s
P
p
.002 w
.50535 .43908 m .54666 .43393 L .53964 .40612 L p
1 g
F P
s
P
p
.002 w
.53964 .40612 m .50515 .41051 L .50535 .43908 L p
1 g
F P
s
P
p
.002 w
.50515 .41051 m .47044 .40657 L .46378 .43442 L p
1 g
F P
s
P
p
.002 w
.47044 .40657 m .50515 .41051 L .50483 .38231 L p
1 g
F P
s
P
p
.002 w
.50515 .41051 m .53964 .40612 L .53163 .37882 L p
1 g
F P
s
P
p
.002 w
.53163 .37882 m .50483 .38231 L .50515 .41051 L p
1 g
F P
s
P
p
.002 w
.41443 .4464 m .45799 .46225 L .46378 .43442 L p
1 g
F P
s
P
p
.002 w
.46378 .43442 m .42571 .42031 L .41443 .4464 L p
1 g
F P
s
P
p
.002 w
.42571 .42031 m .46378 .43442 L .47044 .40657 L p
1 g
F P
s
P
p
.002 w
.45316 .48955 m .50535 .49523 L .50542 .46749 L p
1 g
F P
s
P
p
.002 w
.50542 .46749 m .45799 .46225 L .45316 .48955 L p
1 g
F P
s
P
p
.002 w
.55257 .46174 m .50542 .46749 L .50535 .49523 L p
1 g
F P
s
P
p
.002 w
.50542 .46749 m .55257 .46174 L .54666 .43393 L p
1 g
F P
s
P
p
.002 w
.47044 .40657 m .43875 .3946 L .42571 .42031 L p
1 g
F P
s
P
p
.002 w
.43875 .3946 m .47044 .40657 L .47784 .3792 L p
1 g
F P
s
P
p
.002 w
.50483 .38231 m .47784 .3792 L .47044 .40657 L p
1 g
F P
s
P
p
.002 w
.57067 .3937 m .53964 .40612 L .54666 .43393 L p
1 g
F P
s
P
p
.002 w
.53964 .40612 m .57067 .3937 L .55565 .369 L p
1 g
F P
s
P
p
.002 w
.55565 .369 m .53163 .37882 L .53964 .40612 L p
1 g
F P
s
P
p
.002 w
.58397 .41932 m .54666 .43393 L .55257 .46174 L p
1 g
F P
s
P
p
.002 w
.54666 .43393 m .58397 .41932 L .57067 .3937 L p
1 g
F P
s
P
p
.002 w
.47784 .3792 m .50483 .38231 L .50438 .35498 L p
1 g
F P
s
P
p
.002 w
.50483 .38231 m .53163 .37882 L .52278 .35253 L p
1 g
F P
s
P
p
.002 w
.52278 .35253 m .50438 .35498 L .50483 .38231 L p
1 g
F P
s
P
p
.002 w
.40513 .4724 m .45316 .48955 L .45799 .46225 L p
1 g
F P
s
P
p
.002 w
.45799 .46225 m .41443 .4464 L .40513 .4724 L p
1 g
F P
s
P
p
.002 w
.47784 .3792 m .45328 .36975 L .43875 .3946 L p
1 g
F P
s
P
p
.002 w
.45328 .36975 m .47784 .3792 L .48586 .35281 L p
1 g
F P
s
P
p
.002 w
.50438 .35498 m .48586 .35281 L .47784 .3792 L p
1 g
F P
s
P
p
.002 w
.53163 .37882 m .55565 .369 L .53919 .34569 L p
1 g
F P
s
P
p
.002 w
.53919 .34569 m .52278 .35253 L .53163 .37882 L p
1 g
F P
s
P
p
.002 w
.50535 .49523 m .55725 .48905 L .55257 .46174 L p
1 g
F P
s
P
p
.002 w
.5953 .44537 m .55257 .46174 L .55725 .48905 L p
1 g
F P
s
P
p
.002 w
.55257 .46174 m .5953 .44537 L .58397 .41932 L p
1 g
F P
s
P
p
.002 w
.44942 .51581 m .50516 .52179 L .50535 .49523 L p
1 g
F P
s
P
p
.002 w
.50535 .49523 m .45316 .48955 L .44942 .51581 L p
1 g
F P
s
P
p
.002 w
.55725 .48905 m .50535 .49523 L .50516 .52179 L p
1 g
F P
s
P
p
.002 w
.39475 .3978 m .42571 .42031 L .43875 .3946 L p
1 g
F P
s
P
p
.002 w
.43875 .3946 m .41315 .37557 L .39475 .3978 L p
1 g
F P
s
P
p
.002 w
.41315 .37557 m .43875 .3946 L .45328 .36975 L p
1 g
F P
s
P
p
.002 w
.3788 .42107 m .41443 .4464 L .42571 .42031 L p
1 g
F P
s
P
p
.002 w
.42571 .42031 m .39475 .3978 L .3788 .42107 L p
1 g
F P
s
P
p
.002 w
.39804 .49778 m .44942 .51581 L .45316 .48955 L p
1 g
F P
s
P
p
.002 w
.45316 .48955 m .40513 .4724 L .39804 .49778 L p
1 g
F P
s
P
p
.002 w
.48586 .35281 m .50438 .35498 L .50382 .32904 L p
1 g
F P
s
P
p
.002 w
.50438 .35498 m .52278 .35253 L .51323 .32777 L p
1 g
F P
s
P
p
.002 w
.51323 .32777 m .50382 .32904 L .50438 .35498 L p
1 g
F P
s
P
p
.002 w
.45328 .36975 m .4336 .35479 L .41315 .37557 L p
1 g
F P
s
P
p
.002 w
.4336 .35479 m .45328 .36975 L .46905 .34623 L p
1 g
F P
s
P
p
.002 w
.48586 .35281 m .46905 .34623 L .45328 .36975 L p
1 g
F P
s
P
p
.002 w
.46905 .34623 m .48586 .35281 L .49434 .32792 L p
1 g
F P
s
P
p
.002 w
.50382 .32904 m .49434 .32792 L .48586 .35281 L p
1 g
F P
s
P
p
.002 w
.59519 .37427 m .57067 .3937 L .58397 .41932 L p
1 g
F P
s
P
p
.002 w
.57067 .3937 m .59519 .37427 L .57447 .35372 L p
1 g
F P
s
P
p
.002 w
.57447 .35372 m .55565 .369 L .57067 .3937 L p
1 g
F P
s
P
p
.002 w
.52278 .35253 m .53919 .34569 L .52159 .32422 L p
1 g
F P
s
P
p
.002 w
.52159 .32422 m .51323 .32777 L .52278 .35253 L p
1 g
F P
s
P
p
.002 w
.50516 .52179 m .5606 .51534 L .55725 .48905 L p
1 g
F P
s
P
p
.002 w
.60439 .47137 m .55725 .48905 L .5606 .51534 L p
1 g
F P
s
P
p
.002 w
.55725 .48905 m .60439 .47137 L .5953 .44537 L p
1 g
F P
s
P
p
.002 w
.55565 .369 m .57447 .35372 L .55193 .3351 L p
1 g
F P
s
P
p
.002 w
.55193 .3351 m .53919 .34569 L .55565 .369 L p
1 g
F P
s
P
p
.002 w
.61368 .39633 m .58397 .41932 L .5953 .44537 L p
1 g
F P
s
P
p
.002 w
.58397 .41932 m .61368 .39633 L .59519 .37427 L p
1 g
F P
s
P
p
.002 w
.36565 .44491 m .40513 .4724 L .41443 .4464 L p
1 g
F P
s
P
p
.002 w
.41443 .4464 m .3788 .42107 L .36565 .44491 L p
1 g
F P
s
P
p
.002 w
.46905 .34623 m .4557 .33586 L .4336 .35479 L p
1 g
F P
s
P
p
.002 w
.4557 .33586 m .46905 .34623 L .48578 .32451 L p
1 g
F P
s
P
p
.002 w
.49434 .32792 m .48578 .32451 L .46905 .34623 L p
1 g
F P
s
P
p
.002 w
.44685 .54049 m .50483 .54663 L .50516 .52179 L p
1 g
F P
s
P
p
.002 w
.50516 .52179 m .44942 .51581 L .44685 .54049 L p
1 g
F P
s
P
p
.002 w
.5606 .51534 m .50516 .52179 L .50483 .54663 L p
1 g
F P
s
P
p
.002 w
.53919 .34569 m .55193 .3351 L .528 .31876 L p
1 g
F P
s
P
p
.002 w
.528 .31876 m .52159 .32422 L .53919 .34569 L p
1 g
F P
s
P
p
.002 w
.62953 .4195 m .5953 .44537 L .60439 .47137 L p
1 g
F P
s
P
p
.002 w
.5953 .44537 m .62953 .4195 L .61368 .39633 L p
1 g
F P
s
P
p
.002 w
.39336 .52203 m .44685 .54049 L .44942 .51581 L p
1 g
F P
s
P
p
.002 w
.44942 .51581 m .39804 .49778 L .39336 .52203 L p
1 g
F P
s
P
p
.002 w
.39639 .35113 m .41315 .37557 L .4336 .35479 L p
1 g
F P
s
P
p
.002 w
.4336 .35479 m .42091 .33569 L .39639 .35113 L p
1 g
F P
s
P
p
.002 w
.42091 .33569 m .4336 .35479 L .4557 .33586 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .49434 .32792 L .50382 .32904 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .50382 .32904 L .51323 .32777 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .48578 .32451 L .49434 .32792 L closepath p
1 g
F P
s
P
p
.002 w
.3742 .36874 m .39475 .3978 L .41315 .37557 L p
1 g
F P
s
P
p
.002 w
.41315 .37557 m .39639 .35113 L .3742 .36874 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .51323 .32777 L .52159 .32422 L closepath p
1 g
F P
s
P
p
.002 w
.35565 .46886 m .39804 .49778 L .40513 .4724 L p
1 g
F P
s
P
p
.002 w
.40513 .4724 m .36565 .44491 L .35565 .46886 L p
1 g
F P
s
P
p
.002 w
.50483 .54663 m .5625 .54006 L .5606 .51534 L p
1 g
F P
s
P
p
.002 w
.61104 .49679 m .5606 .51534 L .5625 .54006 L p
1 g
F P
s
P
p
.002 w
.5606 .51534 m .61104 .49679 L .60439 .47137 L p
1 g
F P
s
P
p
.002 w
.4557 .33586 m .44724 .3227 L .42091 .33569 L p
1 g
F P
s
P
p
.002 w
.44724 .3227 m .4557 .33586 L .47903 .31916 L p
1 g
F P
s
P
p
.002 w
.48578 .32451 m .47903 .31916 L .4557 .33586 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .47903 .31916 L .48578 .32451 L closepath p
1 g
F P
s
P
p
.002 w
.586 .33437 m .57447 .35372 L .59519 .37427 L p
1 g
F P
s
P
p
.002 w
.57447 .35372 m .586 .33437 L .55958 .32178 L p
1 g
F P
s
P
p
.002 w
.55958 .32178 m .55193 .3351 L .57447 .35372 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .52159 .32422 L .528 .31876 L closepath p
1 g
F P
s
P
p
.002 w
.55193 .3351 m .55958 .32178 L .53178 .31194 L p
1 g
F P
s
P
p
.002 w
.53178 .31194 m .528 .31876 L .55193 .3351 L p
1 g
F P
s
P
p
.002 w
.35487 .38819 m .3788 .42107 L .39475 .3978 L p
1 g
F P
s
P
p
.002 w
.39475 .3978 m .3742 .36874 L .35487 .38819 L p
1 g
F P
s
P
p
.002 w
.61049 .34948 m .59519 .37427 L .61368 .39633 L p
1 g
F P
s
P
p
.002 w
.59519 .37427 m .61049 .34948 L .586 .33437 L p
1 g
F P
s
P
p
.002 w
.64236 .44332 m .60439 .47137 L .61104 .49679 L p
1 g
F P
s
P
p
.002 w
.60439 .47137 m .64236 .44332 L .62953 .4195 L p
1 g
F P
s
P
p
.002 w
.47903 .31916 m .47484 .31242 L .44724 .3227 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .47484 .31242 L .47903 .31916 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .528 .31876 L .53178 .31194 L closepath p
1 g
F P
s
P
p
.002 w
.44556 .56304 m .50438 .56919 L .50483 .54663 L p
1 g
F P
s
P
p
.002 w
.50483 .54663 m .44685 .54049 L .44556 .56304 L p
1 g
F P
s
P
p
.002 w
.5625 .54006 m .50483 .54663 L .50438 .56919 L p
1 g
F P
s
P
p
.002 w
.6325 .36685 m .61368 .39633 L .62953 .4195 L p
1 g
F P
s
P
p
.002 w
.61368 .39633 m .6325 .36685 L .61049 .34948 L p
1 g
F P
s
P
p
.002 w
.41679 .31429 m .42091 .33569 L .44724 .3227 L p
1 g
F P
s
P
p
.002 w
.44724 .3227 m .44468 .30808 L .41679 .31429 L p
1 g
F P
s
P
p
.002 w
.44468 .30808 m .44724 .3227 L .47484 .31242 L p
1 g
F P
s
P
p
.002 w
.47484 .31242 m .47367 .30499 L .44468 .30808 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .47367 .30499 L .47484 .31242 L closepath p
1 g
F P
s
P
p
.002 w
.33888 .40912 m .36565 .44491 L .3788 .42107 L p
1 g
F P
s
P
p
.002 w
.3788 .42107 m .35487 .38819 L .33888 .40912 L p
1 g
F P
s
P
p
.002 w
.39128 .5446 m .44556 .56304 L .44685 .54049 L p
1 g
F P
s
P
p
.002 w
.44685 .54049 m .39336 .52203 L .39128 .5446 L p
1 g
F P
s
P
p
.002 w
.34912 .4924 m .39336 .52203 L .39804 .49778 L p
1 g
F P
s
P
p
.002 w
.39804 .49778 m .35565 .46886 L .34912 .4924 L p
1 g
F P
s
P
p
.002 w
.53248 .30449 m .53178 .31194 L .55958 .32178 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .53178 .31194 L .53248 .30449 L closepath p
1 g
F P
s
P
p
.002 w
.3906 .32355 m .39639 .35113 L .42091 .33569 L p
1 g
F P
s
P
p
.002 w
.42091 .33569 m .41679 .31429 L .3906 .32355 L p
1 g
F P
s
P
p
.002 w
.56122 .30708 m .55958 .32178 L .586 .33437 L p
1 g
F P
s
P
p
.002 w
.55958 .32178 m .56122 .30708 L .53248 .30449 L p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .53248 .30449 L .52998 .2972 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .52998 .2972 L .52452 .29088 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .52452 .29088 L .51668 .28625 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .51668 .28625 L .50732 .28384 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .50732 .28384 L .49748 .28393 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .49748 .28393 L .48828 .2865 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .48828 .2865 L .48075 .29127 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .48075 .29127 L .4757 .29767 L closepath p
1 g
F P
s
P
p
.002 w
.50316 .30505 m .4757 .29767 L .47367 .30499 L closepath p
1 g
F P
s
P
p
.002 w
.50438 .56919 m .56286 .56266 L .5625 .54006 L p
1 g
F P
s
P
p
.002 w
.61502 .52111 m .5625 .54006 L .56286 .56266 L p
1 g
F P
s
P
p
.002 w
.5625 .54006 m .61502 .52111 L .61104 .49679 L p
1 g
F P
s
P
p
.002 w
.44846 .29354 m .44468 .30808 L .47367 .30499 L p
1 g
F P
s
P
p
.002 w
.47367 .30499 m .4757 .29767 L .44846 .29354 L p
1 g
F P
s
P
p
.002 w
.58878 .31284 m .586 .33437 L .61049 .34948 L p
1 g
F P
s
P
p
.002 w
.586 .33437 m .58878 .31284 L .56122 .30708 L p
1 g
F P
s
P
p
.002 w
.65183 .4673 m .61104 .49679 L .61502 .52111 L p
1 g
F P
s
P
p
.002 w
.61104 .49679 m .65183 .4673 L .64236 .44332 L p
1 g
F P
s
P
p
.002 w
.6515 .38614 m .62953 .4195 L .64236 .44332 L p
1 g
F P
s
P
p
.002 w
.62953 .4195 m .6515 .38614 L .6325 .36685 L p
1 g
F P
s
P
p
.002 w
.52998 .2972 m .53248 .30449 L .56122 .30708 L p
1 g
F P
s
P
p
.002 w
.36674 .33573 m .3742 .36874 L .39639 .35113 L p
1 g
F P
s
P
p
.002 w
.39639 .35113 m .3906 .32355 L .36674 .33573 L p
1 g
F P
s
P
p
.002 w
.42202 .29284 m .41679 .31429 L .44468 .30808 L p
1 g
F P
s
P
p
.002 w
.44468 .30808 m .44846 .29354 L .42202 .29284 L p
1 g
F P
s
P
p
.002 w
.45832 .28072 m .44846 .29354 L .4757 .29767 L p
1 g
F P
s
P
p
.002 w
.4757 .29767 m .48075 .29127 L .45832 .28072 L p
1 g
F P
s
P
p
.002 w
.3267 .4311 m .35565 .46886 L .36565 .44491 L p
1 g
F P
s
P
p
.002 w
.36565 .44491 m .33888 .40912 L .3267 .4311 L p
1 g
F P
s
P
p
.002 w
.56122 .30708 m .5565 .29259 L .52998 .2972 L p
1 g
F P
s
P
p
.002 w
.52452 .29088 m .52998 .2972 L .5565 .29259 L p
1 g
F P
s
P
p
.002 w
.61453 .3217 m .61049 .34948 L .6325 .36685 L p
1 g
F P
s
P
p
.002 w
.61049 .34948 m .61453 .3217 L .58878 .31284 L p
1 g
F P
s
P
p
.002 w
.5565 .29259 m .56122 .30708 L .58878 .31284 L p
1 g
F P
s
P
p
.002 w
.44563 .5829 m .50379 .58891 L .50438 .56919 L p
1 g
F P
s
P
p
.002 w
.50438 .56919 m .44556 .56304 L .44563 .5829 L p
1 g
F P
s
P
p
.002 w
.56286 .56266 m .50438 .56919 L .50379 .58891 L p
1 g
F P
s
P
p
.002 w
.34581 .35065 m .35487 .38819 L .3742 .36874 L p
1 g
F P
s
P
p
.002 w
.3742 .36874 m .36674 .33573 L .34581 .35065 L p
1 g
F P
s
P
p
.002 w
.34634 .51498 m .39128 .5446 L .39336 .52203 L p
1 g
F P
s
P
p
.002 w
.39336 .52203 m .34912 .4924 L .34634 .51498 L p
1 g
F P
s
P
p
.002 w
.47328 .27111 m .45832 .28072 L .48075 .29127 L p
1 g
F P
s
P
p
.002 w
.48075 .29127 m .48828 .2865 L .47328 .27111 L p
1 g
F P
s
P
p
.002 w
.5565 .29259 m .54579 .27992 L .52452 .29088 L p
1 g
F P
s
P
p
.002 w
.51668 .28625 m .52452 .29088 L .54579 .27992 L p
1 g
F P
s
P
p
.002 w
.66699 .40699 m .64236 .44332 L .65183 .4673 L p
1 g
F P
s
P
p
.002 w
.64236 .44332 m .66699 .40699 L .6515 .38614 L p
1 g
F P
s
P
p
.002 w
.39698 .29569 m .3906 .32355 L .41679 .31429 L p
1 g
F P
s
P
p
.002 w
.41679 .31429 m .42202 .29284 L .39698 .29569 L p
1 g
F P
s
P
p
.002 w
.39195 .5649 m .44563 .5829 L .44556 .56304 L p
1 g
F P
s
P
p
.002 w
.44556 .56304 m .39128 .5446 L .39195 .5649 L p
1 g
F P
s
P
p
.002 w
.49169 .26589 m .47328 .27111 L .48828 .2865 L p
1 g
F P
s
P
p
.002 w
.48828 .2865 m .49748 .28393 L .49169 .26589 L p
1 g
F P
s
P
p
.002 w
.54579 .27992 m .53019 .27058 L .51668 .28625 L p
1 g
F P
s
P
p
.002 w
.50732 .28384 m .51668 .28625 L .53019 .27058 L p
1 g
F P
s
P
p
.002 w
.50379 .58891 m .56163 .58256 L .56286 .56266 L p
1 g
F P
s
P
p
.002 w
.61616 .54377 m .56286 .56266 L .56163 .58256 L p
1 g
F P
s
P
p
.002 w
.56286 .56266 m .61616 .54377 L .61502 .52111 L p
1 g
F P
s
P
p
.002 w
.43637 .27376 m .42202 .29284 L .44846 .29354 L p
1 g
F P
s
P
p
.002 w
.44846 .29354 m .45832 .28072 L .43637 .27376 L p
1 g
F P
s
P
p
.002 w
.6576 .49093 m .61502 .52111 L .61616 .54377 L p
1 g
F P
s
P
p
.002 w
.61502 .52111 m .6576 .49093 L .65183 .4673 L p
1 g
F P
s
P
p
.002 w
.51143 .2657 m .49169 .26589 L .49748 .28393 L p
1 g
F P
s
P
p
.002 w
.49748 .28393 m .50732 .28384 L .51143 .2657 L p
1 g
F P
s
P
p
.002 w
.53019 .27058 m .51143 .2657 L .50732 .28384 L p
1 g
F P
s
P
p
.002 w
.63786 .33356 m .6325 .36685 L .6515 .38614 L p
1 g
F P
s
P
p
.002 w
.6325 .36685 m .63786 .33356 L .61453 .3217 L p
1 g
F P
s
P
p
.002 w
.58214 .29142 m .58878 .31284 L .61453 .3217 L p
1 g
F P
s
P
p
.002 w
.58878 .31284 m .58214 .29142 L .5565 .29259 L p
1 g
F P
s
P
p
.002 w
.54579 .27992 m .5565 .29259 L .58214 .29142 L p
1 g
F P
s
P
p
.002 w
.31877 .45365 m .34912 .4924 L .35565 .46886 L p
1 g
F P
s
P
p
.002 w
.35565 .46886 m .3267 .4311 L .31877 .45365 L p
1 g
F P
s
P
p
.002 w
.32841 .36806 m .33888 .40912 L .35487 .38819 L p
1 g
F P
s
P
p
.002 w
.35487 .38819 m .34581 .35065 L .32841 .36806 L p
1 g
F P
s
P
p
.002 w
.37398 .30215 m .36674 .33573 L .3906 .32355 L p
1 g
F P
s
P
p
.002 w
.3906 .32355 m .39698 .29569 L .37398 .30215 L p
1 g
F P
s
P
p
.002 w
.45848 .25937 m .43637 .27376 L .45832 .28072 L p
1 g
F P
s
P
p
.002 w
.45832 .28072 m .47328 .27111 L .45848 .25937 L p
1 g
F P
s
P
p
.002 w
.67849 .42898 m .65183 .4673 L .6576 .49093 L p
1 g
F P
s
P
p
.002 w
.65183 .4673 m .67849 .42898 L .66699 .40699 L p
1 g
F P
s
P
p
.002 w
.58214 .29142 m .56648 .27256 L .54579 .27992 L p
1 g
F P
s
P
p
.002 w
.53019 .27058 m .54579 .27992 L .56648 .27256 L p
1 g
F P
s
P
p
.002 w
.34755 .53604 m .39195 .5649 L .39128 .5446 L p
1 g
F P
s
P
p
.002 w
.39128 .5446 m .34634 .51498 L .34755 .53604 L p
1 g
F P
s
P
p
.002 w
.65814 .34825 m .6515 .38614 L .66699 .40699 L p
1 g
F P
s
P
p
.002 w
.6515 .38614 m .65814 .34825 L .63786 .33356 L p
1 g
F P
s
P
p
.002 w
.60628 .29384 m .61453 .3217 L .63786 .33356 L p
1 g
F P
s
P
p
.002 w
.61453 .3217 m .60628 .29384 L .58214 .29142 L p
1 g
F P
s
P
p
.002 w
.41541 .27072 m .39698 .29569 L .42202 .29284 L p
1 g
F P
s
P
p
.002 w
.42202 .29284 m .43637 .27376 L .41541 .27072 L p
1 g
F P
s
P
p
.002 w
.44712 .59947 m .50309 .6052 L .50379 .58891 L p
1 g
F P
s
P
p
.002 w
.50379 .58891 m .44563 .5829 L .44712 .59947 L p
1 g
F P
s
P
p
.002 w
.56163 .58256 m .50379 .58891 L .50309 .6052 L p
1 g
F P
s
P
p
.002 w
.56648 .27256 m .58214 .29142 L .60628 .29384 L p
1 g
F P
s
P
p
.002 w
.4859 .25151 m .45848 .25937 L .47328 .27111 L p
1 g
F P
s
P
p
.002 w
.47328 .27111 m .49169 .26589 L .4859 .25151 L p
1 g
F P
s
P
p
.002 w
.39552 .58236 m .44712 .59947 L .44563 .5829 L p
1 g
F P
s
P
p
.002 w
.44563 .5829 m .39195 .5649 L .39552 .58236 L p
1 g
F P
s
P
p
.002 w
.56163 .58256 m .61431 .56418 L .61616 .54377 L p
1 g
F P
s
P
p
.002 w
.6594 .51364 m .61616 .54377 L .61431 .56418 L p
1 g
F P
s
P
p
.002 w
.61616 .54377 m .6594 .51364 L .6576 .49093 L p
1 g
F P
s
P
p
.002 w
.31511 .38763 m .3267 .4311 L .33888 .40912 L p
1 g
F P
s
P
p
.002 w
.33888 .40912 m .32841 .36806 L .31511 .38763 L p
1 g
F P
s
P
p
.002 w
.56648 .27256 m .54336 .25856 L .53019 .27058 L p
1 g
F P
s
P
p
.002 w
.51143 .2657 m .53019 .27058 L .54336 .25856 L p
1 g
F P
s
P
p
.002 w
.31546 .47625 m .34634 .51498 L .34912 .4924 L p
1 g
F P
s
P
p
.002 w
.34912 .4924 m .31877 .45365 L .31546 .47625 L p
1 g
F P
s
P
p
.002 w
.35367 .31222 m .34581 .35065 L .36674 .33573 L p
1 g
F P
s
P
p
.002 w
.36674 .33573 m .37398 .30215 L .35367 .31222 L p
1 g
F P
s
P
p
.002 w
.50309 .6052 m .55873 .59919 L .56163 .58256 L p
1 g
F P
s
P
p
.002 w
.61431 .56418 m .56163 .58256 L .55873 .59919 L p
1 g
F P
s
P
p
.002 w
.51539 .25122 m .4859 .25151 L .49169 .26589 L p
1 g
F P
s
P
p
.002 w
.49169 .26589 m .51143 .2657 L .51539 .25122 L p
1 g
F P
s
P
p
.002 w
.54336 .25856 m .51539 .25122 L .51143 .2657 L p
1 g
F P
s
P
p
.002 w
.62832 .29994 m .63786 .33356 L .65814 .34825 L p
1 g
F P
s
P
p
.002 w
.63786 .33356 m .62832 .29994 L .60628 .29384 L p
1 g
F P
s
P
p
.002 w
.67478 .36552 m .66699 .40699 L .67849 .42898 L p
1 g
F P
s
P
p
.002 w
.66699 .40699 m .67478 .36552 L .65814 .34825 L p
1 g
F P
s
P
p
.002 w
.68557 .45161 m .6576 .49093 L .6594 .51364 L p
1 g
F P
s
P
p
.002 w
.6576 .49093 m .68557 .45161 L .67849 .42898 L p
1 g
F P
s
P
p
.002 w
.44424 .25175 m .41541 .27072 L .43637 .27376 L p
1 g
F P
s
P
p
.002 w
.43637 .27376 m .45848 .25937 L .44424 .25175 L p
1 g
F P
s
P
p
.002 w
.39601 .27184 m .37398 .30215 L .39698 .29569 L p
1 g
F P
s
P
p
.002 w
.39698 .29569 m .41541 .27072 L .39601 .27184 L p
1 g
F P
s
P
p
.002 w
.60628 .29384 m .58609 .26912 L .56648 .27256 L p
1 g
F P
s
P
p
.002 w
.54336 .25856 m .56648 .27256 L .58609 .26912 L p
1 g
F P
s
P
p
.002 w
.35291 .55496 m .39552 .58236 L .39195 .5649 L p
1 g
F P
s
P
p
.002 w
.39195 .5649 m .34755 .53604 L .35291 .55496 L p
1 g
F P
s
P
p
.002 w
.58609 .26912 m .60628 .29384 L .62832 .29994 L p
1 g
F P
s
P
p
.002 w
.30643 .40896 m .31877 .45365 L .3267 .4311 L p
1 g
F P
s
P
p
.002 w
.3267 .4311 m .31511 .38763 L .30643 .40896 L p
1 g
F P
s
P
p
.002 w
.33667 .32581 m .32841 .36806 L .34581 .35065 L p
1 g
F P
s
P
p
.002 w
.34581 .35065 m .35367 .31222 L .33667 .32581 L p
1 g
F P
s
P
p
.002 w
.45008 .61219 m .50228 .6175 L .50309 .6052 L p
1 g
F P
s
P
p
.002 w
.50309 .6052 m .44712 .59947 L .45008 .61219 L p
1 g
F P
s
P
p
.002 w
.55873 .59919 m .50309 .6052 L .50228 .6175 L p
1 g
F P
s
P
p
.002 w
.31706 .49831 m .34755 .53604 L .34634 .51498 L p
1 g
F P
s
P
p
.002 w
.34634 .51498 m .31546 .47625 L .31706 .49831 L p
1 g
F P
s
P
p
.002 w
.55873 .59919 m .60935 .58174 L .61431 .56418 L p
1 g
F P
s
P
p
.002 w
.657 .53484 m .61431 .56418 L .60935 .58174 L p
1 g
F P
s
P
p
.002 w
.61431 .56418 m .657 .53484 L .6594 .51364 L p
1 g
F P
s
P
p
.002 w
.48026 .24134 m .44424 .25175 L .45848 .25937 L p
1 g
F P
s
P
p
.002 w
.45848 .25937 m .4859 .25151 L .48026 .24134 L p
1 g
F P
s
P
p
.002 w
.40203 .59638 m .45008 .61219 L .44712 .59947 L p
1 g
F P
s
P
p
.002 w
.44712 .59947 m .39552 .58236 L .40203 .59638 L p
1 g
F P
s
P
p
.002 w
.58609 .26912 m .55589 .25067 L .54336 .25856 L p
1 g
F P
s
P
p
.002 w
.51539 .25122 m .54336 .25856 L .55589 .25067 L p
1 g
F P
s
P
p
.002 w
.6476 .30972 m .65814 .34825 L .67478 .36552 L p
1 g
F P
s
P
p
.002 w
.65814 .34825 m .6476 .30972 L .62832 .29994 L p
1 g
F P
s
P
p
.002 w
.68719 .38506 m .67849 .42898 L .68557 .45161 L p
1 g
F P
s
P
p
.002 w
.67849 .42898 m .68719 .38506 L .67478 .36552 L p
1 g
F P
s
P
p
.002 w
.50228 .6175 m .55415 .61195 L .55873 .59919 L p
1 g
F P
s
P
p
.002 w
.60935 .58174 m .55873 .59919 L .55415 .61195 L p
1 g
F P
s
P
p
.002 w
.5191 .24096 m .48026 .24134 L .4859 .25151 L p
1 g
F P
s
P
p
.002 w
.4859 .25151 m .51539 .25122 L .5191 .24096 L p
1 g
F P
s
P
p
.002 w
.68784 .47435 m .6594 .51364 L .657 .53484 L p
1 g
F P
s
P
p
.002 w
.6594 .51364 m .68784 .47435 L .68557 .45161 L p
1 g
F P
s
P
p
.002 w
.37875 .27732 m .35367 .31222 L .37398 .30215 L p
1 g
F P
s
P
p
.002 w
.37398 .30215 m .39601 .27184 L .37875 .27732 L p
1 g
F P
s
P
p
.002 w
.55589 .25067 m .5191 .24096 L .51539 .25122 L p
1 g
F P
s
P
p
.002 w
.43095 .24869 m .39601 .27184 L .41541 .27072 L p
1 g
F P
s
P
p
.002 w
.41541 .27072 m .44424 .25175 L .43095 .24869 L p
1 g
F P
s
P
p
.002 w
.32362 .34274 m .31511 .38763 L .32841 .36806 L p
1 g
F P
s
P
p
.002 w
.32841 .36806 m .33667 .32581 L .32362 .34274 L p
1 g
F P
s
P
p
.002 w
.30282 .43154 m .31546 .47625 L .31877 .45365 L p
1 g
F P
s
P
p
.002 w
.31877 .45365 m .30643 .40896 L .30282 .43154 L p
1 g
F P
s
P
p
.002 w
.62832 .29994 m .60409 .2699 L .58609 .26912 L p
1 g
F P
s
P
p
.002 w
.55589 .25067 m .58609 .26912 L .60409 .2699 L p
1 g
F P
s
P
p
.002 w
.60409 .2699 m .62832 .29994 L .6476 .30972 L p
1 g
F P
s
P
p
.002 w
.3625 .57114 m .40203 .59638 L .39552 .58236 L p
1 g
F P
s
P
p
.002 w
.39552 .58236 m .35291 .55496 L .3625 .57114 L p
1 g
F P
s
P
p
.002 w
.32377 .51922 m .35291 .55496 L .34755 .53604 L p
1 g
F P
s
P
p
.002 w
.34755 .53604 m .31706 .49831 L .32377 .51922 L p
1 g
F P
s
P
p
.002 w
.66349 .32313 m .67478 .36552 L .68719 .38506 L p
1 g
F P
s
P
p
.002 w
.67478 .36552 m .66349 .32313 L .6476 .30972 L p
1 g
F P
s
P
p
.002 w
.55415 .61195 m .60125 .59586 L .60935 .58174 L p
1 g
F P
s
P
p
.002 w
.65027 .55393 m .60935 .58174 L .60125 .59586 L p
1 g
F P
s
P
p
.002 w
.60935 .58174 m .65027 .55393 L .657 .53484 L p
1 g
F P
s
P
p
.002 w
.69486 .40644 m .68557 .45161 L .68784 .47435 L p
1 g
F P
s
P
p
.002 w
.68557 .45161 m .69486 .40644 L .68719 .38506 L p
1 g
F P
s
P
p
.002 w
.45453 .62049 m .50137 .62523 L .50228 .6175 L p
1 g
F P
s
P
p
.002 w
.50228 .6175 m .45008 .61219 L .45453 .62049 L p
1 g
F P
s
P
p
.002 w
.55415 .61195 m .50228 .6175 L .50137 .62523 L p
1 g
F P
s
P
p
.002 w
.47492 .23592 m .43095 .24869 L .44424 .25175 L p
1 g
F P
s
P
p
.002 w
.44424 .25175 m .48026 .24134 L .47492 .23592 L p
1 g
F P
s
P
p
.002 w
.3642 .28726 m .33667 .32581 L .35367 .31222 L p
1 g
F P
s
P
p
.002 w
.35367 .31222 m .37875 .27732 L .3642 .28726 L p
1 g
F P
s
P
p
.002 w
.60409 .2699 m .56739 .24735 L .55589 .25067 L p
1 g
F P
s
P
p
.002 w
.5191 .24096 m .55589 .25067 L .56739 .24735 L p
1 g
F P
s
P
p
.002 w
.41149 .6064 m .45453 .62049 L .45008 .61219 L p
1 g
F P
s
P
p
.002 w
.45008 .61219 m .40203 .59638 L .41149 .6064 L p
1 g
F P
s
P
p
.002 w
.68505 .49661 m .657 .53484 L .65027 .55393 L p
1 g
F P
s
P
p
.002 w
.657 .53484 m .68505 .49661 L .68784 .47435 L p
1 g
F P
s
P
p
.002 w
.50137 .62523 m .54791 .62029 L .55415 .61195 L p
1 g
F P
s
P
p
.002 w
.60125 .59586 m .55415 .61195 L .54791 .62029 L p
1 g
F P
s
P
p
.002 w
.41903 .25053 m .37875 .27732 L .39601 .27184 L p
1 g
F P
s
P
p
.002 w
.39601 .27184 m .43095 .24869 L .41903 .25053 L p
1 g
F P
s
P
p
.002 w
.31506 .36269 m .30643 .40896 L .31511 .38763 L p
1 g
F P
s
P
p
.002 w
.31511 .38763 m .32362 .34274 L .31506 .36269 L p
1 g
F P
s
P
p
.002 w
.30463 .45481 m .31706 .49831 L .31546 .47625 L p
1 g
F P
s
P
p
.002 w
.31546 .47625 m .30282 .43154 L .30463 .45481 L p
1 g
F P
s
P
p
.002 w
.52245 .23545 m .47492 .23592 L .48026 .24134 L p
1 g
F P
s
P
p
.002 w
.48026 .24134 m .5191 .24096 L .52245 .23545 L p
1 g
F P
s
P
p
.002 w
.56739 .24735 m .52245 .23545 L .5191 .24096 L p
1 g
F P
s
P
p
.002 w
.6199 .2751 m .6476 .30972 L .66349 .32313 L p
1 g
F P
s
P
p
.002 w
.6476 .30972 m .6199 .2751 L .60409 .2699 L p
1 g
F P
s
P
p
.002 w
.56739 .24735 m .60409 .2699 L .6199 .2751 L p
1 g
F P
s
P
p
.002 w
.67539 .33997 m .68719 .38506 L .69486 .40644 L p
1 g
F P
s
P
p
.002 w
.68719 .38506 m .67539 .33997 L .66349 .32313 L p
1 g
F P
s
P
p
.002 w
.37627 .58397 m .41149 .6064 L .40203 .59638 L p
1 g
F P
s
P
p
.002 w
.40203 .59638 m .3625 .57114 L .37627 .58397 L p
1 g
F P
s
P
p
.002 w
.33565 .53832 m .3625 .57114 L .35291 .55496 L p
1 g
F P
s
P
p
.002 w
.35291 .55496 m .32377 .51922 L .33565 .53832 L p
1 g
F P
s
P
p
.002 w
.69736 .42917 m .68784 .47435 L .68505 .49661 L p
1 g
F P
s
P
p
.002 w
.68784 .47435 m .69736 .42917 L .69486 .40644 L p
1 g
F P
s
P
p
.002 w
.54791 .62029 m .59003 .60597 L .60125 .59586 L p
1 g
F P
s
P
p
.002 w
.63915 .57027 m .60125 .59586 L .59003 .60597 L p
1 g
F P
s
P
p
.002 w
.60125 .59586 m .63915 .57027 L .65027 .55393 L p
1 g
F P
s
P
p
.002 w
.35295 .30162 m .32362 .34274 L .33667 .32581 L p
1 g
F P
s
P
p
.002 w
.33667 .32581 m .3642 .28726 L .35295 .30162 L p
1 g
F P
s
P
p
.002 w
.677 .51773 m .65027 .55393 L .63915 .57027 L p
1 g
F P
s
P
p
.002 w
.65027 .55393 m .677 .51773 L .68505 .49661 L p
1 g
F P
s
P
p
.002 w
.47004 .23571 m .41903 .25053 L .43095 .24869 L p
1 g
F P
s
P
p
.002 w
.43095 .24869 m .47492 .23592 L .47004 .23571 L p
1 g
F P
s
P
p
.002 w
.46043 .62386 m .50038 .6279 L .50137 .62523 L p
1 g
F P
s
P
p
.002 w
.50137 .62523 m .45453 .62049 L .46043 .62386 L p
1 g
F P
s
P
p
.002 w
.54791 .62029 m .50137 .62523 L .50038 .6279 L p
1 g
F P
s
P
p
.002 w
.31148 .38522 m .30282 .43154 L .30643 .40896 L p
1 g
F P
s
P
p
.002 w
.30643 .40896 m .31506 .36269 L .31148 .38522 L p
1 g
F P
s
P
p
.002 w
.31204 .47811 m .32377 .51922 L .31706 .49831 L p
1 g
F P
s
P
p
.002 w
.31706 .49831 m .30463 .45481 L .31204 .47811 L p
1 g
F P
s
P
p
.002 w
.6199 .2751 m .57751 .24898 L .56739 .24735 L p
1 g
F P
s
P
p
.002 w
.52245 .23545 m .56739 .24735 L .57751 .24898 L p
1 g
F P
s
P
p
.002 w
.42382 .61189 m .46043 .62386 L .45453 .62049 L p
1 g
F P
s
P
p
.002 w
.45453 .62049 m .41149 .6064 L .42382 .61189 L p
1 g
F P
s
P
p
.002 w
.4089 .25753 m .3642 .28726 L .37875 .27732 L p
1 g
F P
s
P
p
.002 w
.37875 .27732 m .41903 .25053 L .4089 .25753 L p
1 g
F P
s
P
p
.002 w
.66349 .32313 m .63299 .28484 L .6199 .2751 L p
1 g
F P
s
P
p
.002 w
.63299 .28484 m .66349 .32313 L .67539 .33997 L p
1 g
F P
s
P
p
.004 w
.49398 .67002 m
.49464 .64342 L
s
P
p
.004 w
.69397 .58889 m
.73169 .61968 L
s
P
p
.002 w
.50038 .6279 m .54006 .6237 L .54791 .62029 L p
1 g
F P
s
P
p
.002 w
.59003 .60597 m .54791 .62029 L .54006 .6237 L p
1 g
F P
s
P
p
.002 w
.52531 .23515 m .47004 .23571 L .47492 .23592 L p
1 g
F P
s
P
p
.002 w
.47492 .23592 m .52245 .23545 L .52531 .23515 L p
1 g
F P
s
P
p
.002 w
.57751 .24898 m .6199 .2751 L .63299 .28484 L p
1 g
F P
s
P
p
.002 w
.69486 .40644 m .68276 .35995 L .67539 .33997 L p
1 g
F P
s
P
p
.002 w
.68276 .35995 m .69486 .40644 L .69736 .42917 L p
1 g
F P
s
P
p
.002 w
.57751 .24898 m .52531 .23515 L .52245 .23545 L p
1 g
F P
s
P
p
.002 w
.68505 .49661 m .69436 .45265 L .69736 .42917 L p
1 g
F P
s
P
p
.002 w
.69436 .45265 m .68505 .49661 L .677 .51773 L p
1 g
F P
s
P
p
.002 w
.35261 .55495 m .37627 .58397 L .3625 .57114 L p
1 g
F P
s
P
p
.002 w
.3625 .57114 m .33565 .53832 L .35261 .55495 L p
1 g
F P
s
P
p
.002 w
.39407 .59291 m .42382 .61189 L .41149 .6064 L p
1 g
F P
s
P
p
.002 w
.41149 .6064 m .37627 .58397 L .39407 .59291 L p
1 g
F P
s
P
p
.002 w
.34552 .32021 m .31506 .36269 L .32362 .34274 L p
1 g
F P
s
P
p
.002 w
.32362 .34274 m .35295 .30162 L .34552 .32021 L p
1 g
F P
s
P
p
.002 w
.31323 .40978 m .30463 .45481 L .30282 .43154 L p
1 g
F P
s
P
p
.002 w
.30282 .43154 m .31148 .38522 L .31323 .40978 L p
1 g
F P
s
P
p
.002 w
.54006 .6237 m .57584 .61154 L .59003 .60597 L p
1 g
F P
s
P
p
.002 w
.59003 .60597 m .62373 .58326 L .63915 .57027 L p
1 g
F P
s
P
p
.002 w
.62373 .58326 m .59003 .60597 L .57584 .61154 L p
1 g
F P
s
P
p
.002 w
.63915 .57027 m .6637 .53707 L .677 .51773 L p
1 g
F P
s
P
p
.002 w
.6637 .53707 m .63915 .57027 L .62373 .58326 L p
1 g
F P
s
P
p
.002 w
.3251 .50071 m .33565 .53832 L .32377 .51922 L p
1 g
F P
s
P
p
.002 w
.32377 .51922 m .31204 .47811 L .3251 .50071 L p
1 g
F P
s
P
p
.002 w
.46581 .24104 m .4089 .25753 L .41903 .25053 L p
1 g
F P
s
P
p
.002 w
.41903 .25053 m .47004 .23571 L .46581 .24104 L p
1 g
F P
s
P
p
.002 w
.64279 .2991 m .67539 .33997 L .68276 .35995 L p
1 g
F P
s
P
p
.002 w
.67539 .33997 m .64279 .2991 L .63299 .28484 L p
1 g
F P
s
P
p
.002 w
.40099 .26981 m .35295 .30162 L .3642 .28726 L p
1 g
F P
s
P
p
.002 w
.3642 .28726 m .4089 .25753 L .40099 .26981 L p
1 g
F P
s
P
p
.002 w
.46771 .62188 m .49934 .62509 L .50038 .6279 L p
1 g
F P
s
P
p
.002 w
.50038 .6279 m .46043 .62386 L .46771 .62188 L p
1 g
F P
s
P
p
.002 w
.54006 .6237 m .50038 .6279 L .49934 .62509 L p
1 g
F P
s
P
p
.002 w
.63299 .28484 m .58586 .25583 L .57751 .24898 L p
1 g
F P
s
P
p
.002 w
.52531 .23515 m .57751 .24898 L .58586 .25583 L p
1 g
F P
s
P
p
.002 w
.68513 .38261 m .69736 .42917 L .69436 .45265 L p
1 g
F P
s
P
p
.002 w
.69736 .42917 m .68513 .38261 L .68276 .35995 L p
1 g
F P
s
P
p
.002 w
.43883 .61241 m .46771 .62188 L .46043 .62386 L p
1 g
F P
s
P
p
.002 w
.46043 .62386 m .42382 .61189 L .43883 .61241 L p
1 g
F P
s
P
p
.002 w
.6857 .47622 m .677 .51773 L .6637 .53707 L p
1 g
F P
s
P
p
.002 w
.677 .51773 m .6857 .47622 L .69436 .45265 L p
1 g
F P
s
P
p
.002 w
.49934 .62509 m .53074 .62175 L .54006 .6237 L p
1 g
F P
s
P
p
.002 w
.57584 .61154 m .54006 .6237 L .53074 .62175 L p
1 g
F P
s
P
p
.002 w
.58586 .25583 m .63299 .28484 L .64279 .2991 L p
1 g
F P
s
P
p
.002 w
.37434 .56849 m .39407 .59291 L .37627 .58397 L p
1 g
F P
s
P
p
.002 w
.37627 .58397 m .35261 .55495 L .37434 .56849 L p
1 g
F P
s
P
p
.002 w
.52758 .24043 m .46581 .24104 L .47004 .23571 L p
1 g
F P
s
P
p
.002 w
.47004 .23571 m .52531 .23515 L .52758 .24043 L p
1 g
F P
s
P
p
.002 w
.58586 .25583 m .52758 .24043 L .52531 .23515 L p
1 g
F P
s
P
p
.002 w
.34235 .34267 m .31148 .38522 L .31506 .36269 L p
1 g
F P
s
P
p
.002 w
.31506 .36269 m .34552 .32021 L .34235 .34267 L p
1 g
F P
s
P
p
.002 w
.3205 .43566 m .31204 .47811 L .30463 .45481 L p
1 g
F P
s
P
p
.002 w
.30463 .45481 m .31323 .40978 L .3205 .43566 L p
1 g
F P
s
P
p
.002 w
.41555 .59746 m .43883 .61241 L .42382 .61189 L p
1 g
F P
s
P
p
.002 w
.42382 .61189 m .39407 .59291 L .41555 .59746 L p
1 g
F P
s
P
p
.002 w
.57584 .61154 m .60424 .59235 L .62373 .58326 L p
1 g
F P
s
P
p
.002 w
.64528 .55394 m .62373 .58326 L .60424 .59235 L p
1 g
F P
s
P
p
.002 w
.62373 .58326 m .64528 .55394 L .6637 .53707 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.64806 .5514 L
s
P
p
.004 w
.65024 .55318 m
.65137 .5541 L
s
P
p
.004 w
.65137 .5541 m
.65696 .55867 L
s
P
p
.004 w
.65696 .55867 m
.69397 .58889 L
s
P
p
.002 w
.34361 .52188 m .35261 .55495 L .33565 .53832 L p
1 g
F P
s
P
p
.002 w
.33565 .53832 m .3251 .50071 L .34361 .52188 L p
1 g
F P
s
P
p
.002 w
.53074 .62175 m .55892 .61214 L .57584 .61154 L p
1 g
F P
s
P
p
.002 w
.60424 .59235 m .57584 .61154 L .55892 .61214 L p
1 g
F P
s
P
p
.002 w
.64883 .31768 m .68276 .35995 L .68513 .38261 L p
1 g
F P
s
P
p
.002 w
.68276 .35995 m .64883 .31768 L .64279 .2991 L p
1 g
F P
s
P
p
.002 w
.6822 .40739 m .69436 .45265 L .6857 .47622 L p
1 g
F P
s
P
p
.002 w
.69436 .45265 m .6822 .40739 L .68513 .38261 L p
1 g
F P
s
P
p
.002 w
.39567 .28729 m .34552 .32021 L .35295 .30162 L p
1 g
F P
s
P
p
.002 w
.35295 .30162 m .40099 .26981 L .39567 .28729 L p
1 g
F P
s
P
p
.002 w
.46239 .25213 m .40099 .26981 L .4089 .25753 L p
1 g
F P
s
P
p
.002 w
.4089 .25753 m .46581 .24104 L .46239 .25213 L p
1 g
F P
s
P
p
.002 w
.67139 .49912 m .6637 .53707 L .64528 .55394 L p
1 g
F P
s
P
p
.002 w
.6637 .53707 m .67139 .49912 L .6857 .47622 L p
1 g
F P
s
P
p
.002 w
.64279 .2991 m .59207 .26803 L .58586 .25583 L p
1 g
F P
s
P
p
.002 w
.52758 .24043 m .58586 .25583 L .59207 .26803 L p
1 g
F P
s
P
p
.002 w
.47624 .61427 m .49827 .61651 L .49934 .62509 L p
1 g
F P
s
P
p
.002 w
.49934 .62509 m .46771 .62188 L .47624 .61427 L p
1 g
F P
s
P
p
.002 w
.53074 .62175 m .49934 .62509 L .49827 .61651 L p
1 g
F P
s
P
p
.002 w
.45621 .60765 m .47624 .61427 L .46771 .62188 L p
1 g
F P
s
P
p
.002 w
.46771 .62188 m .43883 .61241 L .45621 .60765 L p
1 g
F P
s
P
p
.002 w
.59207 .26803 m .64279 .2991 L .64883 .31768 L p
1 g
F P
s
P
p
.002 w
.40036 .57835 m .41555 .59746 L .39407 .59291 L p
1 g
F P
s
P
p
.002 w
.39407 .59291 m .37434 .56849 L .40036 .57835 L p
1 g
F P
s
P
p
.002 w
.33327 .46205 m .3251 .50071 L .31204 .47811 L p
1 g
F P
s
P
p
.002 w
.31204 .47811 m .3205 .43566 L .33327 .46205 L p
1 g
F P
s
P
p
.002 w
.34375 .36845 m .31323 .40978 L .31148 .38522 L p
1 g
F P
s
P
p
.002 w
.31148 .38522 m .34235 .34267 L .34375 .36845 L p
1 g
F P
s
P
p
.002 w
.49827 .61651 m .52013 .61417 L .53074 .62175 L p
1 g
F P
s
P
p
.002 w
.55892 .61214 m .53074 .62175 L .52013 .61417 L p
1 g
F P
s
P
p
.002 w
.36719 .54085 m .37434 .56849 L .35261 .55495 L p
1 g
F P
s
P
p
.002 w
.35261 .55495 m .34361 .52188 L .36719 .54085 L p
1 g
F P
s
P
p
.002 w
.52915 .25149 m .46239 .25213 L .46581 .24104 L p
1 g
F P
s
P
p
.002 w
.46581 .24104 m .52758 .24043 L .52915 .25149 L p
1 g
F P
s
P
p
.002 w
.55892 .61214 m .58107 .59703 L .60424 .59235 L p
1 g
F P
s
P
p
.002 w
.62212 .5677 m .60424 .59235 L .58107 .59703 L p
1 g
F P
s
P
p
.002 w
.60424 .59235 m .62212 .5677 L .64528 .55394 L p
1 g
F P
s
P
p
.002 w
.59207 .26803 m .52915 .25149 L .52758 .24043 L p
1 g
F P
s
P
p
.002 w
.44021 .59726 m .45621 .60765 L .43883 .61241 L p
1 g
F P
s
P
p
.002 w
.43883 .61241 m .41555 .59746 L .44021 .59726 L p
1 g
F P
s
P
p
.002 w
.6738 .43356 m .6857 .47622 L .67139 .49912 L p
1 g
F P
s
P
p
.002 w
.6857 .47622 m .6738 .43356 L .6822 .40739 L p
1 g
F P
s
P
p
.002 w
.6507 .34025 m .68513 .38261 L .6822 .40739 L p
1 g
F P
s
P
p
.002 w
.68513 .38261 m .6507 .34025 L .64883 .31768 L p
1 g
F P
s
P
p
.002 w
.52013 .61417 m .53964 .60745 L .55892 .61214 L p
1 g
F P
s
P
p
.002 w
.58107 .59703 m .55892 .61214 L .53964 .60745 L p
1 g
F P
s
P
p
.002 w
.65168 .5206 m .64528 .55394 L .62212 .5677 L p
1 g
F P
s
P
p
.002 w
.64528 .55394 m .65168 .5206 L .67139 .49912 L p
1 g
F P
s
P
p
.002 w
.39328 .30968 m .34235 .34267 L .34552 .32021 L p
1 g
F P
s
P
p
.002 w
.34552 .32021 m .39567 .28729 L .39328 .30968 L p
1 g
F P
s
P
p
.002 w
.45995 .26898 m .39567 .28729 L .40099 .26981 L p
1 g
F P
s
P
p
.002 w
.40099 .26981 m .46239 .25213 L .45995 .26898 L p
1 g
F P
s
P
p
.002 w
.35131 .48808 m .34361 .52188 L .3251 .50071 L p
1 g
F P
s
P
p
.002 w
.3251 .50071 m .33327 .46205 L .35131 .48808 L p
1 g
F P
s
P
p
.002 w
.34988 .3968 m .3205 .43566 L .31323 .40978 L p
1 g
F P
s
P
p
.002 w
.31323 .40978 m .34375 .36845 L .34988 .3968 L p
1 g
F P
s
P
p
.002 w
.42997 .58408 m .44021 .59726 L .41555 .59746 L p
1 g
F P
s
P
p
.002 w
.41555 .59746 m .40036 .57835 L .42997 .58408 L p
1 g
F P
s
P
p
.002 w
.59581 .28549 m .64883 .31768 L .6507 .34025 L p
1 g
F P
s
P
p
.002 w
.64883 .31768 m .59581 .28549 L .59207 .26803 L p
1 g
F P
s
P
p
.002 w
.52915 .25149 m .59207 .26803 L .59581 .28549 L p
1 g
F P
s
P
p
.002 w
.39518 .5569 m .40036 .57835 L .37434 .56849 L p
1 g
F P
s
P
p
.002 w
.37434 .56849 m .36719 .54085 L .39518 .5569 L p
1 g
F P
s
P
p
.002 w
.48582 .60091 m .49721 .60208 L .49827 .61651 L p
1 g
F P
s
P
p
.002 w
.49827 .61651 m .47624 .61427 L .48582 .60091 L p
1 g
F P
s
P
p
.002 w
.52013 .61417 m .49827 .61651 L .49721 .60208 L p
1 g
F P
s
P
p
.002 w
.47552 .59747 m .48582 .60091 L .47624 .61427 L p
1 g
F P
s
P
p
.002 w
.47624 .61427 m .45621 .60765 L .47552 .59747 L p
1 g
F P
s
P
p
.002 w
.53964 .60745 m .55482 .59696 L .58107 .59703 L p
1 g
F P
s
P
p
.002 w
.59476 .57778 m .58107 .59703 L .55482 .59696 L p
1 g
F P
s
P
p
.002 w
.58107 .59703 m .59476 .57778 L .62212 .5677 L p
1 g
F P
s
P
p
.002 w
.49721 .60208 m .5085 .60085 L .52013 .61417 L p
1 g
F P
s
P
p
.002 w
.53964 .60745 m .52013 .61417 L .5085 .60085 L p
1 g
F P
s
P
p
.002 w
.66002 .46029 m .67139 .49912 L .65168 .5206 L p
1 g
F P
s
P
p
.002 w
.67139 .49912 m .66002 .46029 L .6738 .43356 L p
1 g
F P
s
P
p
.002 w
.62704 .53987 m .62212 .5677 L .59476 .57778 L p
1 g
F P
s
P
p
.002 w
.62212 .5677 m .62704 .53987 L .65168 .5206 L p
1 g
F P
s
P
p
.002 w
.64813 .36622 m .6822 .40739 L .6738 .43356 L p
1 g
F P
s
P
p
.002 w
.6822 .40739 m .64813 .36622 L .6507 .34025 L p
1 g
F P
s
P
p
.002 w
.46737 .59209 m .47552 .59747 L .45621 .60765 L p
1 g
F P
s
P
p
.002 w
.45621 .60765 m .44021 .59726 L .46737 .59209 L p
1 g
F P
s
P
p
.002 w
.5299 .26832 m .45995 .26898 L .46239 .25213 L p
1 g
F P
s
P
p
.002 w
.46239 .25213 m .52915 .25149 L .5299 .26832 L p
1 g
F P
s
P
p
.002 w
.59581 .28549 m .5299 .26832 L .52915 .25149 L p
1 g
F P
s
P
p
.002 w
.5085 .60085 m .51852 .59736 L .53964 .60745 L p
1 g
F P
s
P
p
.002 w
.55482 .59696 m .53964 .60745 L .51852 .59736 L p
1 g
F P
s
P
p
.002 w
.37413 .51282 m .36719 .54085 L .34361 .52188 L p
1 g
F P
s
P
p
.002 w
.34361 .52188 m .35131 .48808 L .37413 .51282 L p
1 g
F P
s
P
p
.002 w
.39405 .33643 m .34375 .36845 L .34235 .34267 L p
1 g
F P
s
P
p
.002 w
.34235 .34267 m .39328 .30968 L .39405 .33643 L p
1 g
F P
s
P
p
.002 w
.36071 .42683 m .33327 .46205 L .3205 .43566 L p
1 g
F P
s
P
p
.002 w
.3205 .43566 m .34988 .3968 L .36071 .42683 L p
1 g
F P
s
P
p
.002 w
.42673 .56941 m .42997 .58408 L .40036 .57835 L p
1 g
F P
s
P
p
.002 w
.40036 .57835 m .39518 .5569 L .42673 .56941 L p
1 g
F P
s
P
p
.002 w
.45863 .29132 m .39328 .30968 L .39567 .28729 L p
1 g
F P
s
P
p
.002 w
.39567 .28729 m .45995 .26898 L .45863 .29132 L p
1 g
F P
s
P
p
.002 w
.46227 .58532 m .46737 .59209 L .44021 .59726 L p
1 g
F P
s
P
p
.002 w
.44021 .59726 m .42997 .58408 L .46227 .58532 L p
1 g
F P
s
P
p
.002 w
.64113 .48668 m .65168 .5206 L .62704 .53987 L p
1 g
F P
s
P
p
.002 w
.65168 .5206 m .64113 .48668 L .66002 .46029 L p
1 g
F P
s
P
p
.002 w
.59682 .30794 m .6507 .34025 L .64813 .36622 L p
1 g
F P
s
P
p
.002 w
.6507 .34025 m .59682 .30794 L .59581 .28549 L p
1 g
F P
s
P
p
.002 w
.51852 .59736 m .52622 .59193 L .55482 .59696 L p
1 g
F P
s
P
p
.002 w
.56398 .58369 m .55482 .59696 L .52622 .59193 L p
1 g
F P
s
P
p
.002 w
.55482 .59696 m .56398 .58369 L .59476 .57778 L p
1 g
F P
s
P
p
.002 w
.59817 .55621 m .59476 .57778 L .56398 .58369 L p
1 g
F P
s
P
p
.002 w
.59476 .57778 m .59817 .55621 L .62704 .53987 L p
1 g
F P
s
P
p
.002 w
.64101 .39484 m .6738 .43356 L .66002 .46029 L p
1 g
F P
s
P
p
.002 w
.6738 .43356 m .64101 .39484 L .64813 .36622 L p
1 g
F P
s
P
p
.002 w
.5299 .26832 m .59581 .28549 L .59682 .30794 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.49703 .54865 m
.5 .43051 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.40103 .53534 m .39518 .5569 L .36719 .54085 L p
1 g
F P
s
P
p
.002 w
.36719 .54085 m .37413 .51282 L .40103 .53534 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49721 .60208 m .48582 .60091 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.5085 .60085 m .49721 .60208 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.48582 .60091 m .47552 .59747 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.51852 .59736 m .5085 .60085 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.37598 .45747 m .35131 .48808 L .33327 .46205 L p
1 g
F P
s
P
p
.002 w
.33327 .46205 m .36071 .42683 L .37598 .45747 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.4608 .57787 m .46227 .58532 L .42997 .58408 L p
1 g
F P
s
P
p
.002 w
.42997 .58408 m .42673 .56941 L .4608 .57787 L p
1 g
F P
s
P
p
.002 w
.47552 .59747 m .46737 .59209 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.39808 .36678 m .34988 .3968 L .34375 .36845 L p
1 g
F P
s
P
p
.002 w
.34375 .36845 m .39405 .33643 L .39808 .36678 L p
1 g
F P
s
P
p
.002 w
.52622 .59193 m .51852 .59736 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.61769 .51176 m .62704 .53987 L .59817 .55621 L p
1 g
F P
s
P
p
.002 w
.62704 .53987 m .61769 .51176 L .64113 .48668 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52978 .29069 m .45863 .29132 L .45995 .26898 L p
1 g
F P
s
P
p
.002 w
.45995 .26898 m .5299 .26832 L .52978 .29069 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52622 .59193 m .53075 .58513 L .56398 .58369 L p
1 g
F P
s
P
p
.002 w
.56599 .56897 m .56398 .58369 L .53075 .58513 L p
1 g
F P
s
P
p
.002 w
.56398 .58369 m .56599 .56897 L .59817 .55621 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.59682 .30794 m .52978 .29069 L .5299 .26832 L p
1 g
F P
s
P
p
.002 w
.46737 .59209 m .46227 .58532 L .49361 .58218 L p
1 g
F P
s
P
p
.002 w
.49619 .58192 m .46227 .58532 L .46096 .57869 L p
1 g
F P
s
P
p
.002 w
.46096 .57869 m .4608 .57787 L .4829 .5804 L p
1 g
F P
s
P
p
.002 w
.4829 .5804 m .49619 .58192 L p
.46096 .57869 L 1 g
F P
s
P
p
.002 w
.49465 .58247 m .46737 .59209 L p
.49361 .58218 L 1 g
F P
s
P
p
.002 w
.53075 .58513 m .52622 .59193 L .49619 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58068 L p
1 g
F P
s
P
p
.002 w
.53075 .58513 m .50353 .5826 L p
.50716 .58166 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .58068 L .51484 .57968 L 1 g
F
P
p
.002 w
.5307 .5755 m .53159 .57766 L .51484 .57968 L p
1 g
F P
s
P
p
.52048 .57819 m .51484 .57968 L .52038 .57824 L 1 g
F
P
p
.53128 .57265 m .51484 .57968 L .52048 .57819 L 1 g
F
P
p
.002 w
.49619 .58192 m .49782 .58134 L p
.49985 .58124 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51079 .57862 L p
.49701 .58137 L 1 g
F P
s
P
p
.002 w
.49782 .58134 m .49619 .58192 L .49698 .58138 L p
1 g
F P
s
P
p
.49701 .58137 m .49697 .58138 L .49771 .58135 L 1 g
F
P
p
.49701 .58137 m .49771 .58135 L .51094 .58068 L 1 g
F
P
p
.49728 .58137 m .50319 .58108 L .51094 .58068 L 1 g
F
P
p
.49697 .58138 m .4973 .58137 L .49728 .58137 L 1 g
F
P
p
.4973 .58137 m .50319 .58108 L .49728 .58137 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49698 .58138 m .49619 .58192 L .49658 .58139 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58087 L p
1 g
F P
s
P
p
.002 w
.49433 .58128 m .49619 .58192 L .49035 .58126 L p
1 g
F P
s
P
p
.002 w
.49035 .58126 m .4829 .5804 L p
.48904 .58087 L 1 g
F P
s
P
p
.48904 .58087 m .49433 .58128 L .49035 .58126 L 1 g
F
P
p
.002 w
.48904 .58087 m .48921 .57862 L p
.47819 .57772 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58087 L .49433 .58128 L 1 g
F
P
p
.002 w
.49532 .58135 m .49619 .58192 L .49433 .58128 L p
1 g
F P
s
P
p
.49498 .58133 m .49433 .58128 L .49496 .58133 L 1 g
F
P
p
.51079 .57862 m .49433 .58128 L .49498 .58133 L 1 g
F
P
p
.51079 .57862 m .49496 .58133 L .49535 .58135 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46825 .57482 L p
1 g
F P
s
P
p
.48921 .57862 m .46825 .57482 L .47819 .57772 L 1 g
F
P
p
.002 w
.4608 .57787 m .46234 .5731 L p
.46825 .57482 L 1 g
F P
s
P
p
.4608 .57787 m .46825 .57482 L .47667 .57948 L 1 g
F
P
p
.002 w
.46825 .57482 m .46872 .57265 L p
.45798 .56836 L 1 g
F P
s
P
p
.002 w
.4608 .57787 m .42673 .56941 L p
.46091 .57046 L 1 g
F P
s
P
p
.002 w
.46277 .57179 m .4608 .57787 L p
.46091 .57046 L 1 g
F P
s
P
p
.45798 .56836 m .46277 .57179 L .46825 .57482 L 1 g
F
P
p
.002 w
.42673 .56941 m .43106 .55482 L .45262 .56536 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56309 L p
1 g
F P
s
P
p
.002 w
.45634 .56718 m .45262 .56536 L p
.45376 .56528 L 1 g
F P
s
P
p
.002 w
.45262 .56536 m .43106 .55482 L p
.44733 .55878 L 1 g
F P
s
P
p
.42673 .56941 m .45634 .56718 L .46091 .57046 L 1 g
F
P
p
.46872 .57265 m .45079 .56309 L .45788 .56832 L 1 g
F
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44443 .55518 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43827 .54752 L p
1 g
F P
s
P
p
.45146 .56129 m .43827 .54752 L .43861 .54795 L 1 g
F
P
p
.002 w
.43106 .55482 m .43798 .54717 L p
.43827 .54752 L 1 g
F P
s
P
p
.44217 .55753 m .43827 .54752 L .44733 .55878 L 1 g
F
P
p
.43106 .55482 m .43827 .54752 L .44217 .55753 L 1 g
F
P
p
.002 w
.43827 .54752 m .43925 .54566 L p
.43517 .5376 L 1 g
F P
s
P
p
.43364 .5405 m .43619 .5409 L .43798 .54717 L 1 g
F
P
p
.002 w
.43808 .54706 m .43798 .54717 L p
.43619 .5409 L 1 g
F P
s
P
p
.43517 .5376 m .43808 .54706 L .43827 .54752 L 1 g
F
P
p
.002 w
.40103 .53534 m .41774 .51612 L .43361 .53252 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.40103 .53534 m .43361 .53252 L .43619 .5409 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43257 .52863 L p
1 g
F P
s
P
p
.41774 .51612 m .43051 .52094 L .43257 .52863 L 1 g
F
P
p
.002 w
.43361 .53252 m .43239 .53125 L p
.43257 .52863 L 1 g
F P
s
P
p
.002 w
.43239 .53125 m .41774 .51612 L p
.43257 .52863 L 1 g
F P
s
P
p
.002 w
.43257 .52863 m .43346 .52734 L p
.4332 .51979 L 1 g
F P
s
P
p
.43925 .54566 m .43257 .52863 L .43474 .53674 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43257 .52863 m .46056 .53228 L .43361 .53252 L 1 g
F
P
p
.43051 .52094 m .43305 .5219 L .43257 .52863 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43394 .50935 L p
1 g
F P
s
P
p
.43346 .52734 m .43394 .50935 L .4332 .51979 L 1 g
F
P
p
.43305 .5219 m .46056 .53228 L .43257 .52863 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.4438 .50161 m .46056 .53228 L p
.42886 .52032 L 1 g
F P
s
P
p
.002 w
.41774 .51612 m .43534 .50632 L p
.42886 .52032 L 1 g
F P
s
P
p
.002 w
.43394 .50935 m .43485 .50826 L p
.4385 .49972 L 1 g
F P
s
P
p
.002 w
.41774 .51612 m .39522 .48761 L p
.43835 .50004 L 1 g
F P
s
P
p
.002 w
.43534 .50632 m .41774 .51612 L p
.43835 .50004 L 1 g
F P
s
P
p
.4385 .49972 m .43534 .50632 L .43394 .50935 L 1 g
F
P
p
.002 w
.39522 .48761 m .42863 .46844 L .44077 .49499 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.39522 .48761 m .44077 .49499 L .43835 .50004 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44262 .49132 L p
1 g
F P
s
P
p
.42863 .46844 m .44876 .47912 L .44262 .49132 L 1 g
F
P
p
.002 w
.44077 .49499 m .44018 .49369 L p
.44262 .49132 L 1 g
F P
s
P
p
.002 w
.44018 .49369 m .42863 .46844 L p
.44262 .49132 L 1 g
F P
s
P
p
.002 w
.44262 .49132 m .44166 .49233 L p
.43916 .49819 L 1 g
F P
s
P
p
.43485 .50826 m .44262 .49132 L .43916 .49819 L 1 g
F
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44262 .49132 m .44339 .4905 L p
.44876 .48536 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44262 .49132 m .4763 .49373 L .44077 .49499 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45785 .47652 L p
1 g
F P
s
P
p
.44339 .4905 m .45785 .47652 L .44876 .48536 L 1 g
F
P
p
.44876 .47912 m .45291 .48132 L .44262 .49132 L 1 g
F
P
p
.45291 .48132 m .4763 .49373 L .44262 .49132 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.4725 .46966 m .4763 .49373 L p
.45043 .48001 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47758 .46714 L p
1 g
F P
s
P
p
.002 w
.51135 .49356 m .4763 .49373 L .4725 .46966 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47758 .46714 m .51135 .49356 L .4725 .46966 L 1 g
F
P
p
.002 w
.47758 .46714 m .47786 .46667 L p
.48668 .46577 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46377 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46377 L .48668 .46577 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.52225 .4671 m .54459 .50115 L .51497 .46617 L 1 g
F
P
p
.5 .4634 m .52241 .46712 L .51754 .4665 L 1 g
F
P
p
.002 w
.51609 .45771 m .55911 .46776 L .55743 .47162 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56737 .52855 L p
1 g
F P
s
P
p
.572 .51546 m .56816 .54926 L .56745 .5307 L 1 g
F
P
p
.56515 .50826 m .56737 .52855 L .56707 .52073 L 1 g
F
P
p
.002 w
.56645 .51257 m .572 .51546 L .56707 .52073 L p
1 g
F P
s
P
p
.56707 .52069 m .56707 .52073 L .56707 .52071 L 1 g
F
P
p
.56515 .50826 m .56707 .52073 L .56707 .52069 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56599 .56897 m .53783 .57608 L p
.55688 .55774 L 1 g
F P
s
P
p
.002 w
.53783 .57608 m .53159 .57766 L p
.5481 .56431 L 1 g
F P
s
P
p
.56038 .55437 m .53783 .57608 L .5481 .56431 L 1 g
F
P
p
.002 w
.54919 .56305 m .54854 .56129 L p
.54014 .5693 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56305 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56305 L .55394 .5576 L 1 g
F
P
p
.002 w
.55831 .55229 m .56038 .55437 L .55394 .5576 L p
1 g
F P
s
P
p
.55428 .5572 m .55394 .5576 L .55424 .55726 L 1 g
F
P
p
.56075 .54566 m .55394 .5576 L .55428 .5572 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53159 .57766 m .53137 .57964 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.50319 .58108 m .51484 .57968 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.51484 .57968 m .53159 .57766 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.53137 .57964 m .53075 .58513 L p
.50319 .58108 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51489 .5819 L p
.52221 .57777 L 1 g
F P
s
P
p
.53128 .57265 m .52038 .57824 L .52221 .57777 L 1 g
F
P
p
.52038 .57824 m .51111 .583 L .52221 .57777 L 1 g
F
P
p
.002 w
.53159 .57766 m .5308 .57574 L p
.53671 .57306 L 1 g
F P
s
P
p
.002 w
.5308 .57574 m .5307 .5755 L p
.5318 .57505 L 1 g
F P
s
P
p
.53671 .57306 m .5308 .57574 L .5318 .57505 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5318 .57505 L p
1 g
F P
s
P
p
.54854 .56129 m .5318 .57505 L .54014 .5693 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.52858 .57032 m .55394 .5576 L p
.53671 .57306 L 1 g
F P
s
P
p
.002 w
.5318 .57505 m .53128 .57265 L p
.51489 .5819 L 1 g
F P
s
P
p
.002 w
.5307 .5755 m .52858 .57032 L p
.53671 .57306 L 1 g
F P
s
P
p
.002 w
.5318 .57505 m .5322 .57686 L p
.54014 .5693 L 1 g
F P
s
P
p
.002 w
.51489 .5819 m .5322 .57686 L .5318 .57505 L p
1 g
F P
s
P
p
.002 w
.55394 .5576 m .56038 .55437 L p
.5481 .56431 L 1 g
F P
s
P
p
.5481 .56431 m .53159 .57766 L .55394 .5576 L 1 g
F
P
p
.55454 .55691 m .54991 .56498 L .55102 .56331 L 1 g
F
P
p
.56075 .54566 m .55424 .55726 L .55454 .55691 L 1 g
F
P
p
.55424 .55726 m .54991 .56498 L .55454 .55691 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.56038 .55437 m .55967 .55366 L p
.56186 .54693 L 1 g
F P
s
P
p
.002 w
.55967 .55366 m .55831 .55229 L p
.56162 .5473 L 1 g
F P
s
P
p
.56186 .54693 m .55967 .55366 L .56162 .5473 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .5473 L p
1 g
F P
s
P
p
.56654 .52734 m .56162 .5473 L .56477 .53701 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56745 .5307 m .56038 .55437 L .56211 .54571 L 1 g
F
P
p
.002 w
.56737 .52855 m .56654 .52734 L p
.56477 .53701 L 1 g
F P
s
P
p
.56737 .52855 m .56211 .54571 L .56707 .52073 L 1 g
F
P
p
.56745 .5307 m .56211 .54571 L .56737 .52855 L 1 g
F
P
p
.002 w
.56707 .52073 m .572 .51546 L p
.56745 .5307 L 1 g
F P
s
P
p
.002 w
.56816 .54926 m .56038 .55437 L p
.56745 .5307 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56737 .52855 L p
1 g
F P
s
P
p
.56477 .53701 m .56257 .5491 L .56737 .52855 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56162 .5473 L p
1 g
F P
s
P
p
.002 w
.56162 .5473 m .56075 .54566 L p
.55102 .56331 L 1 g
F P
s
P
p
.55102 .56331 m .54998 .56518 L .56162 .5473 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.54758 .54154 m .56707 .52073 L p
.56186 .54693 L 1 g
F P
s
P
p
.002 w
.55831 .55229 m .54758 .54154 L p
.56186 .54693 L 1 g
F P
s
P
p
.002 w
.56162 .5473 m .56257 .5491 L p
.56477 .53701 L 1 g
F P
s
P
p
.002 w
.54758 .54154 m .55831 .55229 L p
.52858 .57032 L 1 g
F P
s
P
p
.002 w
.55394 .5576 m .52858 .57032 L p
.55831 .55229 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54919 .56305 L p
1 g
F P
s
P
p
.54014 .5693 m .5322 .57686 L .54919 .56305 L 1 g
F
P
p
.002 w
.56038 .55437 m .56067 .55513 L p
.55688 .55774 L 1 g
F P
s
P
p
.002 w
.56067 .55513 m .56599 .56897 L p
.55688 .55774 L 1 g
F P
s
P
p
.002 w
.54919 .56305 m .54991 .56498 L p
.55424 .55726 L 1 g
F P
s
P
p
.002 w
.54991 .56498 m .54998 .56518 L p
.55102 .56331 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50936 L p
1 g
F P
s
P
p
.56195 .50086 m .56571 .50633 L .56445 .50602 L 1 g
F
P
p
.002 w
.572 .51546 m .56645 .51257 L p
.56571 .50633 L 1 g
F P
s
P
p
.55661 .4905 m .56607 .50936 L .56096 .49883 L 1 g
F
P
p
.002 w
.56666 .51006 m .56515 .50826 L p
.56707 .52071 L 1 g
F P
s
P
p
.002 w
.56645 .51257 m .54459 .50115 L p
.56445 .50602 L 1 g
F P
s
P
p
.56571 .50633 m .56607 .50936 L .56445 .50602 L 1 g
F
P
p
.56607 .50936 m .56645 .51257 L .56445 .50602 L 1 g
F
P
p
.002 w
.55725 .49119 m .55661 .4905 L p
.56096 .49883 L 1 g
F P
s
P
p
.56833 .50189 m .572 .51546 L .55139 .48552 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55725 .49119 L p
1 g
F P
s
P
p
.56096 .49883 m .56713 .51061 L .55725 .49119 L 1 g
F
P
p
.002 w
.56607 .50936 m .56713 .51061 L p
.56096 .49883 L 1 g
F P
s
P
p
.002 w
.54459 .50115 m .55139 .48552 L p
.56195 .50086 L 1 g
F P
s
P
p
.56195 .50086 m .56445 .50602 L .54459 .50115 L 1 g
F
P
p
.002 w
.56713 .51061 m .56666 .51006 L p
.5685 .52985 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56852 .53003 L p
.5685 .52985 L 1 g
F P
s
P
p
.002 w
.56852 .53003 m .56713 .51061 L p
.5685 .52985 L 1 g
F P
s
P
p
.56707 .52071 m .56854 .53025 L .56666 .51006 L 1 g
F
P
p
.002 w
.54459 .50115 m .56645 .51257 L p
.54758 .54154 L 1 g
F P
s
P
p
.002 w
.56707 .52073 m .54758 .54154 L p
.56645 .51257 L 1 g
F P
s
P
p
.002 w
.56737 .52855 m .56854 .53025 L p
.56707 .52071 L 1 g
F P
s
P
p
.002 w
.572 .51546 m .59045 .53461 L .56816 .54926 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55725 .49119 L p
1 g
F P
s
P
p
.54174 .47608 m .55725 .49119 L .55344 .4875 L 1 g
F
P
p
.54174 .47608 m .55771 .49167 L .54986 .48403 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55139 .48552 m .55911 .46776 L p
.56833 .50189 L 1 g
F P
s
P
p
.002 w
.55725 .49119 m .55771 .49167 L p
.55344 .4875 L 1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55139 .48552 m .54459 .50115 L p
.53557 .4734 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54218 .47656 L p
1 g
F P
s
P
p
.52214 .46667 m .54218 .47656 L .53013 .47081 L 1 g
F
P
p
.53401 .46861 m .54218 .47656 L .53557 .4734 L 1 g
F
P
p
.54218 .47656 m .55139 .48552 L .53557 .4734 L 1 g
F
P
p
.52225 .4671 m .52241 .46712 L .54459 .50115 L 1 g
F
P
p
.002 w
.52241 .46712 m .52214 .46667 L p
.53013 .47081 L 1 g
F P
s
P
p
.52241 .46712 m .53401 .46861 L .53557 .4734 L 1 g
F
P
p
.52241 .46712 m .53557 .4734 L .54459 .50115 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52241 .46712 L p
1 g
F P
s
P
p
.53013 .47081 m .54302 .47747 L .52241 .46712 L 1 g
F
P
p
.002 w
.54218 .47656 m .54302 .47747 L p
.53013 .47081 L 1 g
F P
s
P
p
.002 w
.55771 .49167 m .55834 .49233 L p
.54986 .48403 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.55743 .47162 m .55139 .48552 L p
.53401 .46861 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.51609 .45771 m .55743 .47162 L .52225 .4671 L 1 g
F
P
p
.002 w
.54459 .50115 m .51135 .49356 L .51497 .46617 L p
1 g
F P
s
P
p
.002 w
.51497 .46617 m .51135 .49356 L p
.4722 .45932 L 1 g
F P
s
P
p
.002 w
.52257 .46739 m .52282 .46778 L p
.51328 .46595 L 1 g
F P
s
P
p
.51158 .46563 m .51497 .46617 L .51328 .46595 L 1 g
F
P
p
.51497 .46617 m .52257 .46739 L .51328 .46595 L 1 g
F
P
p
.002 w
.52241 .46712 m .52257 .46739 L p
.51754 .4665 L 1 g
F P
s
P
p
.5 .4634 m .52257 .46739 L .51158 .46563 L 1 g
F
P
p
.002 w
.51497 .46617 m .51609 .45771 L p
.52225 .4671 L 1 g
F P
s
P
p
.002 w
.47065 .45796 m .51609 .45771 L .51497 .46617 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.47065 .45796 m .51497 .46617 L .4722 .45932 L 1 g
F
P
p
.002 w
.5 .46377 m .5 .46442 L p
.48668 .46577 L 1 g
F P
s
P
p
.47065 .45796 m .47985 .46601 L .47758 .46714 L 1 g
F
P
p
.45826 .47608 m .47758 .46714 L .4693 .47124 L 1 g
F
P
p
.002 w
.4725 .46966 m .47223 .46795 L p
.47758 .46714 L 1 g
F P
s
P
p
.002 w
.47223 .46795 m .47065 .45796 L p
.47758 .46714 L 1 g
F P
s
P
p
.47985 .46601 m .48062 .46668 L .47758 .46714 L 1 g
F
P
p
.48062 .46668 m .51135 .49356 L .47758 .46714 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47758 .46714 L p
1 g
F P
s
P
p
.48668 .46577 m .5 .46442 L .47758 .46714 L 1 g
F
P
p
.002 w
.47758 .46714 m .47718 .46778 L p
.4693 .47124 L 1 g
F P
s
P
p
.002 w
.42863 .46844 m .47065 .45796 L .4725 .46966 L p
1 g
F P
s
P
p
.002 w
.45785 .47652 m .45826 .47608 L p
.46658 .47243 L 1 g
F P
s
P
p
.42863 .46844 m .4725 .46966 L .45043 .48001 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45785 .47652 L p
1 g
F P
s
P
p
.46658 .47243 m .47718 .46778 L .45785 .47652 L 1 g
F
P
p
.002 w
.45785 .47652 m .45698 .47747 L p
.44876 .48536 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44262 .49132 L p
1 g
F P
s
P
p
.44876 .48536 m .45698 .47747 L .44262 .49132 L 1 g
F
P
p
.002 w
.4763 .49373 m .4438 .50161 L .44077 .49499 L p
1 g
F P
s
P
p
.002 w
.44077 .49499 m .4438 .50161 L p
.43835 .50004 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43382 .50948 L p
1 g
F P
s
P
p
.002 w
.43382 .50948 m .43394 .50935 L p
.43482 .5074 L 1 g
F P
s
P
p
.43482 .5074 m .44166 .49233 L .43382 .50948 L 1 g
F
P
p
.4385 .49972 m .4398 .49668 L .43534 .50632 L 1 g
F
P
p
.002 w
.4438 .50161 m .43534 .50632 L p
.43835 .50004 L 1 g
F P
s
P
p
.002 w
.43534 .50632 m .4438 .50161 L p
.42886 .52032 L 1 g
F P
s
P
p
.4398 .49668 m .44166 .49233 L .43394 .50935 L 1 g
F
P
p
.002 w
.43394 .50935 m .43287 .51061 L p
.4332 .51979 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43257 .52863 L p
1 g
F P
s
P
p
.4332 .51979 m .43287 .51061 L .43257 .52863 L 1 g
F
P
p
.002 w
.43257 .52863 m .43146 .53025 L p
.43474 .53674 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46056 .53228 m .44272 .54193 L .43361 .53252 L p
1 g
F P
s
P
p
.002 w
.43361 .53252 m .44272 .54193 L p
.43619 .5409 L 1 g
F P
s
P
p
.44443 .55518 m .43824 .54756 L .44159 .55272 L 1 g
F
P
p
.45146 .56129 m .43861 .54795 L .44443 .55518 L 1 g
F
P
p
.43861 .54795 m .43824 .54756 L .44443 .55518 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.43827 .54752 m .44272 .54193 L .44733 .55878 L 1 g
F
P
p
.002 w
.43798 .54717 m .43808 .54706 L p
.43827 .54752 L 1 g
F P
s
P
p
.002 w
.43808 .54706 m .44272 .54193 L p
.43827 .54752 L 1 g
F P
s
P
p
.002 w
.43798 .54717 m .43106 .55482 L p
.43364 .5405 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43824 .54756 L p
1 g
F P
s
P
p
.002 w
.43824 .54756 m .43827 .54752 L p
.43809 .54708 L 1 g
F P
s
P
p
.43809 .54708 m .43146 .53025 L .43824 .54756 L 1 g
F
P
p
.43517 .5376 m .43174 .5308 L .43808 .54706 L 1 g
F
P
p
.002 w
.44272 .54193 m .43808 .54706 L p
.43619 .5409 L 1 g
F P
s
P
p
.43174 .5308 m .43146 .53025 L .43827 .54752 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44272 .54193 m .4692 .56411 L p
.44733 .55878 L 1 g
F P
s
P
p
.002 w
.43827 .54752 m .43824 .54756 L p
.43861 .54795 L 1 g
F P
s
P
p
.002 w
.43824 .54756 m .43743 .5491 L p
.44159 .55272 L 1 g
F P
s
P
p
.002 w
.43106 .55482 m .40103 .53534 L p
.43364 .5405 L 1 g
F P
s
P
p
.44733 .55878 m .4692 .56411 L .45262 .56536 L 1 g
F
P
p
.002 w
.45262 .56536 m .45634 .56718 L p
.45431 .56734 L 1 g
F P
s
P
p
.42673 .56941 m .45262 .56536 L .45431 .56734 L 1 g
F
P
p
.002 w
.45079 .56309 m .45002 .56518 L p
.45788 .56832 L 1 g
F P
s
P
p
.002 w
.4692 .56411 m .46318 .57053 L .45634 .56718 L p
1 g
F P
s
P
p
.45376 .56528 m .4692 .56411 L .45634 .56718 L 1 g
F
P
p
.002 w
.45075 .56319 m .45079 .56309 L p
.44238 .5534 L 1 g
F P
s
P
p
.44443 .55518 m .44238 .5534 L .45079 .56309 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45075 .56319 L p
1 g
F P
s
P
p
.44238 .5534 m .43743 .5491 L .45075 .56319 L 1 g
F
P
p
.002 w
.45634 .56718 m .46318 .57053 L p
.46091 .57046 L 1 g
F P
s
P
p
.46825 .57482 m .46318 .57053 L .48835 .58067 L 1 g
F
P
p
.002 w
.46234 .5731 m .46277 .57179 L p
.46825 .57482 L 1 g
F P
s
P
p
.002 w
.46277 .57179 m .46318 .57053 L p
.46825 .57482 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46808 .57559 L p
1 g
F P
s
P
p
.002 w
.46808 .57559 m .46825 .57482 L p
.46349 .57231 L 1 g
F P
s
P
p
.46349 .57231 m .45002 .56518 L .46808 .57559 L 1 g
F
P
p
.45798 .56836 m .45294 .56635 L .46277 .57179 L 1 g
F
P
p
.002 w
.46318 .57053 m .46277 .57179 L p
.46091 .57046 L 1 g
F P
s
P
p
.45294 .56635 m .45002 .56518 L .46825 .57482 L 1 g
F
P
p
.47667 .57948 m .46825 .57482 L .48835 .58067 L 1 g
F
P
p
.002 w
.46318 .57053 m .49433 .58128 L p
.48835 .58067 L 1 g
F P
s
P
p
.002 w
.46825 .57482 m .4678 .57686 L p
.47819 .57772 L 1 g
F P
s
P
p
.002 w
.46318 .57053 m .4692 .56411 L .49532 .58135 L p
1 g
F P
s
P
p
.002 w
.49433 .58128 m .46318 .57053 L p
.49532 .58135 L 1 g
F P
s
P
p
.51079 .57862 m .49532 .58136 L .49561 .58137 L 1 g
F
P
p
.51079 .57862 m .49557 .58138 L .49581 .58138 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.4692 .56411 m .47825 .55935 L .49575 .58137 L p
1 g
F P
s
P
p
.002 w
.49575 .58137 m .49619 .58192 L .49532 .58135 L p
1 g
F P
s
P
p
.002 w
.49532 .58135 m .4692 .56411 L p
.49575 .58137 L 1 g
F P
s
P
p
.49535 .58135 m .49496 .58133 L .49532 .58136 L 1 g
F
P
p
.49561 .58137 m .49532 .58136 L .49557 .58138 L 1 g
F
P
p
.51079 .57862 m .49575 .58139 L .49697 .58138 L 1 g
F
P
p
.002 w
.47825 .55935 m .48933 .5568 L .49604 .58138 L p
1 g
F P
s
P
p
.002 w
.49604 .58138 m .49619 .58192 L .49575 .58137 L p
1 g
F P
s
P
p
.002 w
.49575 .58137 m .47825 .55935 L p
.49604 .58138 L 1 g
F P
s
P
p
.002 w
.48933 .5568 m .5012 .55676 L .4963 .58139 L p
1 g
F P
s
P
p
.002 w
.4963 .58139 m .49619 .58192 L .49604 .58138 L p
1 g
F P
s
P
p
.002 w
.49604 .58138 m .48933 .5568 L p
.4963 .58139 L 1 g
F P
s
P
p
.49581 .58138 m .49557 .58138 L .49575 .58139 L 1 g
F
P
p
.002 w
.49658 .58139 m .49619 .58192 L .4963 .58139 L p
1 g
F P
s
P
p
.49697 .58138 m .49575 .58139 L .4966 .58146 L 1 g
F
P
p
.002 w
.5012 .55676 m .51251 .55924 L .49658 .58139 L p
1 g
F P
s
P
p
.002 w
.4963 .58139 m .5012 .55676 L p
.49658 .58139 L 1 g
F P
s
P
p
.002 w
.4829 .5804 m .4608 .57787 L p
.49433 .58128 L 1 g
F P
s
P
p
.002 w
.48904 .58094 m .48904 .58087 L p
.47679 .5776 L 1 g
F P
s
P
p
.47819 .57772 m .47679 .5776 L .48904 .58087 L 1 g
F
P
p
.002 w
.48904 .58087 m .48889 .583 L p
.4966 .58146 L 1 g
F P
s
P
p
.002 w
.51251 .55924 m .52199 .56394 L .49698 .58138 L p
1 g
F P
s
P
p
.002 w
.49658 .58139 m .51251 .55924 L p
.49698 .58138 L 1 g
F P
s
P
p
.002 w
.52199 .56394 m .52858 .57032 L .49782 .58134 L p
1 g
F P
s
P
p
.002 w
.49698 .58138 m .52199 .56394 L p
.49782 .58134 L 1 g
F P
s
P
p
.002 w
.51484 .57968 m .50319 .58108 L p
.5307 .5755 L 1 g
F P
s
P
p
.002 w
.50319 .58108 m .49619 .58192 L p
.49985 .58124 L 1 g
F P
s
P
p
.5307 .5755 m .50319 .58108 L .49985 .58124 L 1 g
F
P
p
.49697 .58138 m .49687 .5814 L .50319 .58108 L 1 g
F
P
p
.002 w
.49619 .58192 m .50319 .58108 L p
.50716 .58166 L 1 g
F P
s
P
p
.002 w
.50353 .5826 m .49619 .58192 L p
.50716 .58166 L 1 g
F P
s
P
p
.002 w
.51108 .5826 m .51095 .5807 L p
.49654 .58147 L 1 g
F P
s
P
p
.002 w
.51095 .5807 m .51094 .58068 L p
.50778 .58086 L 1 g
F P
s
P
p
.50778 .58086 m .49654 .58147 L .51095 .5807 L 1 g
F
P
p
.002 w
.52858 .57032 m .5307 .5755 L p
.49985 .58124 L 1 g
F P
s
P
p
.002 w
.49782 .58134 m .52858 .57032 L p
.49985 .58124 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51111 .583 L p
.52038 .57824 L 1 g
F P
s
P
p
.49687 .5814 m .49654 .58147 L .51094 .58068 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51108 .5826 L p
1 g
F P
s
P
p
.002 w
.49361 .58218 m .49619 .58192 L .49465 .58247 L p
1 g
F P
s
P
p
.49654 .58147 m .48889 .583 L .51108 .5826 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58094 L p
1 g
F P
s
P
p
.47679 .5776 m .4678 .57686 L .48904 .58094 L 1 g
F
P
p
.002 w
.43106 .55482 m .42673 .56941 L .39518 .5569 L p
1 g
F P
s
P
p
.002 w
.39518 .5569 m .40103 .53534 L .43106 .55482 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62943 .42518 m .66002 .46029 L .64113 .48668 L p
1 g
F P
s
P
p
.002 w
.66002 .46029 m .62943 .42518 L .64101 .39484 L p
1 g
F P
s
P
p
.002 w
.59491 .33483 m .64813 .36622 L .64101 .39484 L p
1 g
F P
s
P
p
.002 w
.64813 .36622 m .59491 .33483 L .59682 .30794 L p
1 g
F P
s
P
p
.002 w
.45854 .31864 m .39405 .33643 L .39328 .30968 L p
1 g
F P
s
P
p
.002 w
.39328 .30968 m .45863 .29132 L .45854 .31864 L p
1 g
F P
s
P
p
.002 w
.59045 .53461 m .59817 .55621 L .56599 .56897 L p
1 g
F P
s
P
p
.002 w
.59817 .55621 m .59045 .53461 L .61769 .51176 L p
1 g
F P
s
P
p
.002 w
.39522 .48761 m .37413 .51282 L .35131 .48808 L p
1 g
F P
s
P
p
.002 w
.35131 .48808 m .37598 .45747 L .39522 .48761 L p
1 g
F P
s
P
p
.002 w
.53075 .58513 m .53159 .57766 L .56599 .56897 L p
1 g
F P
s
P
p
.002 w
.52978 .29069 m .59682 .30794 L .59491 .33483 L p
1 g
F P
s
P
p
.002 w
.40534 .39971 m .36071 .42683 L .34988 .3968 L p
1 g
F P
s
P
p
.002 w
.34988 .3968 m .39808 .36678 L .40534 .39971 L p
1 g
F P
s
P
p
.002 w
.56599 .56897 m .56038 .55437 L .59045 .53461 L p
1 g
F P
s
P
p
.002 w
.6137 .45617 m .64113 .48668 L .61769 .51176 L p
1 g
F P
s
P
p
.002 w
.64113 .48668 m .6137 .45617 L .62943 .42518 L p
1 g
F P
s
P
p
.002 w
.41774 .51612 m .40103 .53534 L .37413 .51282 L p
1 g
F P
s
P
p
.002 w
.37413 .51282 m .39522 .48761 L .41774 .51612 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59003 .36537 m .64101 .39484 L .62943 .42518 L p
1 g
F P
s
P
p
.002 w
.64101 .39484 m .59003 .36537 L .59491 .33483 L p
1 g
F P
s
P
p
.002 w
.52875 .31806 m .45854 .31864 L .45863 .29132 L p
1 g
F P
s
P
p
.002 w
.45863 .29132 m .52978 .29069 L .52875 .31806 L p
1 g
F P
s
P
p
.002 w
.59432 .48664 m .61769 .51176 L .59045 .53461 L p
1 g
F P
s
P
p
.002 w
.61769 .51176 m .59432 .48664 L .6137 .45617 L p
1 g
F P
s
P
p
.002 w
.59491 .33483 m .52875 .31806 L .52978 .29069 L p
1 g
F P
s
P
p
.002 w
.52858 .57032 m .52199 .56394 L .54758 .54154 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.45973 .35014 m .39808 .36678 L .39405 .33643 L p
1 g
F P
s
P
p
.002 w
.39405 .33643 m .45854 .31864 L .45973 .35014 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.004 w
.49582 .5968 m
.49583 .59627 L
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41564 .43403 m .37598 .45747 L .36071 .42683 L p
1 g
F P
s
P
p
.002 w
.36071 .42683 m .40534 .39971 L .41564 .43403 L p
1 g
F P
s
P
p
.002 w
.59045 .53461 m .572 .51546 L .59432 .48664 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.47825 .55935 m .4692 .56411 L .44272 .54193 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.52199 .56394 m .51251 .55924 L .52886 .53202 L p
1 g
F P
s
P
p
.002 w
.52886 .53202 m .54758 .54154 L .52199 .56394 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.52875 .31806 m .59491 .33483 L .59003 .36537 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.48933 .5568 m .47825 .55935 L .46056 .53228 L p
1 g
F P
s
P
p
.002 w
.44272 .54193 m .46056 .53228 L .47825 .55935 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58226 .39853 m .62943 .42518 L .6137 .45617 L p
1 g
F P
s
P
p
.002 w
.62943 .42518 m .58226 .39853 L .59003 .36537 L p
1 g
F P
s
P
p
.002 w
.51251 .55924 m .5012 .55676 L .50632 .52698 L p
1 g
F P
s
P
p
.002 w
.50632 .52698 m .52886 .53202 L .51251 .55924 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.42863 .46844 m .39522 .48761 L .37598 .45747 L p
1 g
F P
s
P
p
.002 w
.37598 .45747 m .41564 .43403 L .42863 .46844 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5012 .55676 m .48933 .5568 L .48262 .52708 L p
1 g
F P
s
P
p
.002 w
.46056 .53228 m .48262 .52708 L .48933 .5568 L p
1 g
F P
s
P
p
.002 w
.48262 .52708 m .50632 .52698 L .5012 .55676 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.004 w
.49538 .61438 m
.49538 .61431 L
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.54758 .54154 m .52886 .53202 L .54459 .50115 L p
1 g
F P
s
P
p
.002 w
.4622 .38474 m .40534 .39971 L .39808 .36678 L p
1 g
F P
s
P
p
.002 w
.39808 .36678 m .45973 .35014 L .4622 .38474 L p
1 g
F P
s
P
p
.002 w
.52679 .34963 m .45973 .35014 L .45854 .31864 L p
1 g
F P
s
P
p
.002 w
.45854 .31864 m .52875 .31806 L .52679 .34963 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57183 .4331 m .6137 .45617 L .59432 .48664 L p
1 g
F P
s
P
p
.002 w
.6137 .45617 m .57183 .4331 L .58226 .39853 L p
1 g
F P
s
P
p
.002 w
.59003 .36537 m .52679 .34963 L .52875 .31806 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.55911 .46776 m .59432 .48664 L .572 .51546 L p
1 g
F P
s
P
p
.002 w
.52679 .34963 m .59003 .36537 L .58226 .39853 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.59432 .48664 m .55911 .46776 L .57183 .4331 L p
1 g
F P
s
P
p
.002 w
.48262 .52708 m .46056 .53228 L .4438 .50161 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.52886 .53202 m .50632 .52698 L .51135 .49356 L p
1 g
F P
s
P
p
.002 w
.51135 .49356 m .54459 .50115 L .52886 .53202 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46589 .42115 m .41564 .43403 L .40534 .39971 L p
1 g
F P
s
P
p
.002 w
.40534 .39971 m .4622 .38474 L .46589 .42115 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50632 .52698 m .48262 .52708 L .4763 .49373 L p
1 g
F P
s
P
p
.002 w
.4438 .50161 m .4763 .49373 L .48262 .52708 L p
1 g
F P
s
P
p
.002 w
.4763 .49373 m .51135 .49356 L .50632 .52698 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.49464 .64342 m
.49491 .63276 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.52396 .38431 m .4622 .38474 L .45973 .35014 L p
1 g
F P
s
P
p
.002 w
.45973 .35014 m .52679 .34963 L .52396 .38431 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52396 .38431 m .58226 .39853 L .57183 .4331 L p
1 g
F P
s
P
p
.002 w
.58226 .39853 m .52396 .38431 L .52679 .34963 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.47065 .45796 m .42863 .46844 L .41564 .43403 L p
1 g
F P
s
P
p
.002 w
.41564 .43403 m .46589 .42115 L .47065 .45796 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52035 .42081 m .57183 .4331 L .55911 .46776 L p
1 g
F P
s
P
p
.002 w
.57183 .4331 m .52035 .42081 L .52396 .38431 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55911 .46776 m .51609 .45771 L .52035 .42081 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52035 .42081 m .46589 .42115 L .4622 .38474 L p
1 g
F P
s
P
p
.002 w
.4622 .38474 m .52396 .38431 L .52035 .42081 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51609 .45771 m .47065 .45796 L .46589 .42115 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.46589 .42115 m .52035 .42081 L .51609 .45771 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .73169 .61968 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .49398 .67002 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0217054)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0217054)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46675 .4337 m .50649 .44693 L .51217 .41892 L p
1 g
F P
s
P
p
.002 w
.51217 .41892 m .47901 .40784 L .46675 .4337 L p
1 g
F P
s
P
p
.002 w
.54675 .42152 m .51217 .41892 L .50649 .44693 L p
1 g
F P
s
P
p
.002 w
.47901 .40784 m .51217 .41892 L .51757 .39111 L p
1 g
F P
s
P
p
.002 w
.51217 .41892 m .54675 .42152 L .54444 .39304 L p
1 g
F P
s
P
p
.002 w
.54444 .39304 m .51757 .39111 L .51217 .41892 L p
1 g
F P
s
P
p
.002 w
.45524 .45957 m .50064 .47463 L .50649 .44693 L p
1 g
F P
s
P
p
.002 w
.50649 .44693 m .46675 .4337 L .45524 .45957 L p
1 g
F P
s
P
p
.002 w
.54792 .45017 m .50649 .44693 L .50064 .47463 L p
1 g
F P
s
P
p
.002 w
.50649 .44693 m .54792 .45017 L .54675 .42152 L p
1 g
F P
s
P
p
.002 w
.43229 .41164 m .46675 .4337 L .47901 .40784 L p
1 g
F P
s
P
p
.002 w
.47901 .40784 m .45037 .38929 L .43229 .41164 L p
1 g
F P
s
P
p
.002 w
.45037 .38929 m .47901 .40784 L .49181 .38247 L p
1 g
F P
s
P
p
.002 w
.51757 .39111 m .49181 .38247 L .47901 .40784 L p
1 g
F P
s
P
p
.002 w
.41576 .43459 m .45524 .45957 L .46675 .4337 L p
1 g
F P
s
P
p
.002 w
.46675 .4337 m .43229 .41164 L .41576 .43459 L p
1 g
F P
s
P
p
.002 w
.49181 .38247 m .51757 .39111 L .5226 .36399 L p
1 g
F P
s
P
p
.002 w
.51757 .39111 m .54444 .39304 L .54104 .36526 L p
1 g
F P
s
P
p
.002 w
.54104 .36526 m .5226 .36399 L .51757 .39111 L p
1 g
F P
s
P
p
.002 w
.44472 .485 m .49471 .50152 L .50064 .47463 L p
1 g
F P
s
P
p
.002 w
.50064 .47463 m .45524 .45957 L .44472 .485 L p
1 g
F P
s
P
p
.002 w
.54793 .47849 m .50064 .47463 L .49471 .50152 L p
1 g
F P
s
P
p
.002 w
.50064 .47463 m .54793 .47849 L .54792 .45017 L p
1 g
F P
s
P
p
.002 w
.5795 .4153 m .54675 .42152 L .54792 .45017 L p
1 g
F P
s
P
p
.002 w
.54675 .42152 m .5795 .4153 L .56981 .38803 L p
1 g
F P
s
P
p
.002 w
.56981 .38803 m .54444 .39304 L .54675 .42152 L p
1 g
F P
s
P
p
.002 w
.49181 .38247 m .46965 .36795 L .45037 .38929 L p
1 g
F P
s
P
p
.002 w
.46965 .36795 m .49181 .38247 L .50492 .35805 L p
1 g
F P
s
P
p
.002 w
.5226 .36399 m .50492 .35805 L .49181 .38247 L p
1 g
F P
s
P
p
.002 w
.58727 .44301 m .54792 .45017 L .54793 .47849 L p
1 g
F P
s
P
p
.002 w
.54792 .45017 m .58727 .44301 L .5795 .4153 L p
1 g
F P
s
P
p
.002 w
.40111 .45771 m .44472 .485 L .45524 .45957 L p
1 g
F P
s
P
p
.002 w
.45524 .45957 m .41576 .43459 L .40111 .45771 L p
1 g
F P
s
P
p
.002 w
.54444 .39304 m .56981 .38803 L .55838 .3617 L p
1 g
F P
s
P
p
.002 w
.55838 .3617 m .54104 .36526 L .54444 .39304 L p
1 g
F P
s
P
p
.002 w
.40645 .3826 m .43229 .41164 L .45037 .38929 L p
1 g
F P
s
P
p
.002 w
.45037 .38929 m .42908 .36489 L .40645 .3826 L p
1 g
F P
s
P
p
.002 w
.42908 .36489 m .45037 .38929 L .46965 .36795 L p
1 g
F P
s
P
p
.002 w
.49471 .50152 m .54677 .50593 L .54793 .47849 L p
1 g
F P
s
P
p
.002 w
.59294 .47063 m .54793 .47849 L .54677 .50593 L p
1 g
F P
s
P
p
.002 w
.54793 .47849 m .59294 .47063 L .58727 .44301 L p
1 g
F P
s
P
p
.002 w
.46965 .36795 m .45333 .34888 L .42908 .36489 L p
1 g
F P
s
P
p
.002 w
.45333 .34888 m .46965 .36795 L .48978 .34801 L p
1 g
F P
s
P
p
.002 w
.50492 .35805 m .48978 .34801 L .46965 .36795 L p
1 g
F P
s
P
p
.002 w
.50492 .35805 m .5226 .36399 L .52714 .33809 L p
1 g
F P
s
P
p
.002 w
.5226 .36399 m .54104 .36526 L .53657 .33872 L p
1 g
F P
s
P
p
.002 w
.53657 .33872 m .52714 .33809 L .5226 .36399 L p
1 g
F P
s
P
p
.002 w
.38592 .40168 m .41576 .43459 L .43229 .41164 L p
1 g
F P
s
P
p
.002 w
.43229 .41164 m .40645 .3826 L .38592 .40168 L p
1 g
F P
s
P
p
.002 w
.43539 .50949 m .48882 .52709 L .49471 .50152 L p
1 g
F P
s
P
p
.002 w
.49471 .50152 m .44472 .485 L .43539 .50949 L p
1 g
F P
s
P
p
.002 w
.54677 .50593 m .49471 .50152 L .48882 .52709 L p
1 g
F P
s
P
p
.002 w
.48978 .34801 m .50492 .35805 L .51811 .33504 L p
1 g
F P
s
P
p
.002 w
.52714 .33809 m .51811 .33504 L .50492 .35805 L p
1 g
F P
s
P
p
.002 w
.54104 .36526 m .55838 .3617 L .54541 .33684 L p
1 g
F P
s
P
p
.002 w
.54541 .33684 m .53657 .33872 L .54104 .36526 L p
1 g
F P
s
P
p
.002 w
.38865 .48057 m .43539 .50949 L .44472 .485 L p
1 g
F P
s
P
p
.002 w
.44472 .485 m .40111 .45771 L .38865 .48057 L p
1 g
F P
s
P
p
.002 w
.6072 .40064 m .5795 .4153 L .58727 .44301 L p
1 g
F P
s
P
p
.002 w
.5795 .4153 m .6072 .40064 L .59113 .37642 L p
1 g
F P
s
P
p
.002 w
.59113 .37642 m .56981 .38803 L .5795 .4153 L p
1 g
F P
s
P
p
.002 w
.56981 .38803 m .59113 .37642 L .57284 .35361 L p
1 g
F P
s
P
p
.002 w
.57284 .35361 m .55838 .3617 L .56981 .38803 L p
1 g
F P
s
P
p
.002 w
.48978 .34801 m .47875 .33487 L .45333 .34888 L p
1 g
F P
s
P
p
.002 w
.47875 .33487 m .48978 .34801 L .5104 .32988 L p
1 g
F P
s
P
p
.002 w
.51811 .33504 m .5104 .32988 L .48978 .34801 L p
1 g
F P
s
P
p
.002 w
.36792 .42178 m .40111 .45771 L .41576 .43459 L p
1 g
F P
s
P
p
.002 w
.41576 .43459 m .38592 .40168 L .36792 .42178 L p
1 g
F P
s
P
p
.002 w
.62074 .42578 m .58727 .44301 L .59294 .47063 L p
1 g
F P
s
P
p
.002 w
.58727 .44301 m .62074 .42578 L .6072 .40064 L p
1 g
F P
s
P
p
.002 w
.48882 .52709 m .54442 .53197 L .54677 .50593 L p
1 g
F P
s
P
p
.002 w
.59639 .49763 m .54677 .50593 L .54442 .53197 L p
1 g
F P
s
P
p
.002 w
.54677 .50593 m .59639 .49763 L .59294 .47063 L p
1 g
F P
s
P
p
.002 w
.55838 .3617 m .57284 .35361 L .55271 .33264 L p
1 g
F P
s
P
p
.002 w
.55271 .33264 m .54541 .33684 L .55838 .3617 L p
1 g
F P
s
P
p
.002 w
.41747 .33688 m .42908 .36489 L .45333 .34888 L p
1 g
F P
s
P
p
.002 w
.45333 .34888 m .44464 .32709 L .41747 .33688 L p
1 g
F P
s
P
p
.002 w
.44464 .32709 m .45333 .34888 L .47875 .33487 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .51811 .33504 L .52714 .33809 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .52714 .33809 L .53657 .33872 L closepath p
1 g
F P
s
P
p
.002 w
.39206 .34912 m .40645 .3826 L .42908 .36489 L p
1 g
F P
s
P
p
.002 w
.42908 .36489 m .41747 .33688 L .39206 .34912 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .5104 .32988 L .51811 .33504 L closepath p
1 g
F P
s
P
p
.002 w
.42746 .53255 m .48308 .55081 L .48882 .52709 L p
1 g
F P
s
P
p
.002 w
.48882 .52709 m .43539 .50949 L .42746 .53255 L p
1 g
F P
s
P
p
.002 w
.54442 .53197 m .48882 .52709 L .48308 .55081 L p
1 g
F P
s
P
p
.002 w
.47875 .33487 m .47303 .31992 L .44464 .32709 L p
1 g
F P
s
P
p
.002 w
.47303 .31992 m .47875 .33487 L .50484 .32314 L p
1 g
F P
s
P
p
.002 w
.5104 .32988 m .50484 .32314 L .47875 .33487 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .53657 .33872 L .54541 .33684 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .50484 .32314 L .5104 .32988 L closepath p
1 g
F P
s
P
p
.002 w
.63142 .45137 m .59294 .47063 L .59639 .49763 L p
1 g
F P
s
P
p
.002 w
.59294 .47063 m .63142 .45137 L .62074 .42578 L p
1 g
F P
s
P
p
.002 w
.37872 .50268 m .42746 .53255 L .43539 .50949 L p
1 g
F P
s
P
p
.002 w
.43539 .50949 m .38865 .48057 L .37872 .50268 L p
1 g
F P
s
P
p
.002 w
.35291 .4425 m .38865 .48057 L .40111 .45771 L p
1 g
F P
s
P
p
.002 w
.40111 .45771 m .36792 .42178 L .35291 .4425 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .54541 .33684 L .55271 .33264 L closepath p
1 g
F P
s
P
p
.002 w
.36898 .36363 m .38592 .40168 L .40645 .3826 L p
1 g
F P
s
P
p
.002 w
.40645 .3826 m .39206 .34912 L .36898 .36363 L p
1 g
F P
s
P
p
.002 w
.58285 .34173 m .57284 .35361 L .59113 .37642 L p
1 g
F P
s
P
p
.002 w
.57284 .35361 m .58285 .34173 L .5577 .32654 L p
1 g
F P
s
P
p
.002 w
.5577 .32654 m .55271 .33264 L .57284 .35361 L p
1 g
F P
s
P
p
.002 w
.60608 .35923 m .59113 .37642 L .6072 .40064 L p
1 g
F P
s
P
p
.002 w
.59113 .37642 m .60608 .35923 L .58285 .34173 L p
1 g
F P
s
P
p
.002 w
.50484 .32314 m .50204 .31551 L .47303 .31992 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .50204 .31551 L .50484 .32314 L closepath p
1 g
F P
s
P
p
.002 w
.48308 .55081 m .54092 .55604 L .54442 .53197 L p
1 g
F P
s
P
p
.002 w
.59748 .52346 m .54442 .53197 L .54092 .55604 L p
1 g
F P
s
P
p
.002 w
.54442 .53197 m .59748 .52346 L .59639 .49763 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .55271 .33264 L .5577 .32654 L closepath p
1 g
F P
s
P
p
.002 w
.62687 .37869 m .6072 .40064 L .62074 .42578 L p
1 g
F P
s
P
p
.002 w
.6072 .40064 m .62687 .37869 L .60608 .35923 L p
1 g
F P
s
P
p
.002 w
.44474 .30475 m .44464 .32709 L .47303 .31992 L p
1 g
F P
s
P
p
.002 w
.47303 .31992 m .47334 .30471 L .44474 .30475 L p
1 g
F P
s
P
p
.002 w
.47334 .30471 m .47303 .31992 L .50204 .31551 L p
1 g
F P
s
P
p
.002 w
.50204 .31551 m .50232 .30781 L .47334 .30471 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .50232 .30781 L .50204 .31551 L closepath p
1 g
F P
s
P
p
.002 w
.41715 .30797 m .41747 .33688 L .44464 .32709 L p
1 g
F P
s
P
p
.002 w
.44464 .32709 m .44474 .30475 L .41715 .30797 L p
1 g
F P
s
P
p
.002 w
.63897 .47688 m .59639 .49763 L .59748 .52346 L p
1 g
F P
s
P
p
.002 w
.59639 .49763 m .63897 .47688 L .63142 .45137 L p
1 g
F P
s
P
p
.002 w
.34879 .38013 m .36792 .42178 L .38592 .40168 L p
1 g
F P
s
P
p
.002 w
.38592 .40168 m .36898 .36363 L .34879 .38013 L p
1 g
F P
s
P
p
.002 w
.55979 .31918 m .5577 .32654 L .58285 .34173 L p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .5577 .32654 L .55979 .31918 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .55979 .31918 L .55874 .31134 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .55874 .31134 L .55461 .30389 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .55461 .30389 L .54784 .29765 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .54784 .29765 L .53916 .29334 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .53916 .29334 L .52955 .29144 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .52955 .29144 L .52009 .29218 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .52009 .29218 L .51184 .29545 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .51184 .29545 L .5057 .30086 L closepath p
1 g
F P
s
P
p
.002 w
.53111 .31394 m .5057 .30086 L .50232 .30781 L closepath p
1 g
F P
s
P
p
.002 w
.64475 .39975 m .62074 .42578 L .63142 .45137 L p
1 g
F P
s
P
p
.002 w
.62074 .42578 m .64475 .39975 L .62687 .37869 L p
1 g
F P
s
P
p
.002 w
.58724 .32726 m .58285 .34173 L .60608 .35923 L p
1 g
F P
s
P
p
.002 w
.58285 .34173 m .58724 .32726 L .55979 .31918 L p
1 g
F P
s
P
p
.002 w
.42116 .55365 m .47761 .57214 L .48308 .55081 L p
1 g
F P
s
P
p
.002 w
.48308 .55081 m .42746 .53255 L .42116 .55365 L p
1 g
F P
s
P
p
.002 w
.54092 .55604 m .48308 .55081 L .47761 .57214 L p
1 g
F P
s
P
p
.002 w
.34129 .46344 m .37872 .50268 L .38865 .48057 L p
1 g
F P
s
P
p
.002 w
.38865 .48057 m .35291 .4425 L .34129 .46344 L p
1 g
F P
s
P
p
.002 w
.4798 .29088 m .47334 .30471 L .50232 .30781 L p
1 g
F P
s
P
p
.002 w
.50232 .30781 m .5057 .30086 L .4798 .29088 L p
1 g
F P
s
P
p
.002 w
.39117 .3144 m .39206 .34912 L .41747 .33688 L p
1 g
F P
s
P
p
.002 w
.41747 .33688 m .41715 .30797 L .39117 .3144 L p
1 g
F P
s
P
p
.002 w
.37162 .52358 m .42116 .55365 L .42746 .53255 L p
1 g
F P
s
P
p
.002 w
.42746 .53255 m .37872 .50268 L .37162 .52358 L p
1 g
F P
s
P
p
.002 w
.55874 .31134 m .55979 .31918 L .58724 .32726 L p
1 g
F P
s
P
p
.002 w
.61285 .33807 m .60608 .35923 L .62687 .37869 L p
1 g
F P
s
P
p
.002 w
.60608 .35923 m .61285 .33807 L .58724 .32726 L p
1 g
F P
s
P
p
.002 w
.45395 .28427 m .44474 .30475 L .47334 .30471 L p
1 g
F P
s
P
p
.002 w
.47334 .30471 m .4798 .29088 L .45395 .28427 L p
1 g
F P
s
P
p
.002 w
.49186 .27999 m .4798 .29088 L .5057 .30086 L p
1 g
F P
s
P
p
.002 w
.5057 .30086 m .51184 .29545 L .49186 .27999 L p
1 g
F P
s
P
p
.002 w
.47761 .57214 m .53628 .57759 L .54092 .55604 L p
1 g
F P
s
P
p
.002 w
.59612 .54755 m .54092 .55604 L .53628 .57759 L p
1 g
F P
s
P
p
.002 w
.54092 .55604 m .59612 .54755 L .59748 .52346 L p
1 g
F P
s
P
p
.002 w
.33204 .39834 m .35291 .4425 L .36792 .42178 L p
1 g
F P
s
P
p
.002 w
.36792 .42178 m .34879 .38013 L .33204 .39834 L p
1 g
F P
s
P
p
.002 w
.58724 .32726 m .58536 .31172 L .55874 .31134 L p
1 g
F P
s
P
p
.002 w
.55461 .30389 m .55874 .31134 L .58536 .31172 L p
1 g
F P
s
P
p
.002 w
.65926 .42199 m .63142 .45137 L .63897 .47688 L p
1 g
F P
s
P
p
.002 w
.63142 .45137 m .65926 .42199 L .64475 .39975 L p
1 g
F P
s
P
p
.002 w
.64312 .50178 m .59748 .52346 L .59612 .54755 L p
1 g
F P
s
P
p
.002 w
.59748 .52346 m .64312 .50178 L .63897 .47688 L p
1 g
F P
s
P
p
.002 w
.58536 .31172 m .58724 .32726 L .61285 .33807 L p
1 g
F P
s
P
p
.002 w
.36742 .32397 m .36898 .36363 L .39206 .34912 L p
1 g
F P
s
P
p
.002 w
.39206 .34912 m .39117 .3144 L .36742 .32397 L p
1 g
F P
s
P
p
.002 w
.50826 .27336 m .49186 .27999 L .51184 .29545 L p
1 g
F P
s
P
p
.002 w
.51184 .29545 m .52009 .29218 L .50826 .27336 L p
1 g
F P
s
P
p
.002 w
.63605 .35144 m .62687 .37869 L .64475 .39975 L p
1 g
F P
s
P
p
.002 w
.62687 .37869 m .63605 .35144 L .61285 .33807 L p
1 g
F P
s
P
p
.002 w
.42871 .28128 m .41715 .30797 L .44474 .30475 L p
1 g
F P
s
P
p
.002 w
.44474 .30475 m .45395 .28427 L .42871 .28128 L p
1 g
F P
s
P
p
.002 w
.58536 .31172 m .5773 .29681 L .55461 .30389 L p
1 g
F P
s
P
p
.002 w
.54784 .29765 m .55461 .30389 L .5773 .29681 L p
1 g
F P
s
P
p
.002 w
.52718 .27182 m .50826 .27336 L .52009 .29218 L p
1 g
F P
s
P
p
.002 w
.52009 .29218 m .52955 .29144 L .52718 .27182 L p
1 g
F P
s
P
p
.002 w
.47156 .26801 m .45395 .28427 L .4798 .29088 L p
1 g
F P
s
P
p
.002 w
.4798 .29088 m .49186 .27999 L .47156 .26801 L p
1 g
F P
s
P
p
.002 w
.33348 .48413 m .37162 .52358 L .37872 .50268 L p
1 g
F P
s
P
p
.002 w
.37872 .50268 m .34129 .46344 L .33348 .48413 L p
1 g
F P
s
P
p
.002 w
.5773 .29681 m .56383 .28428 L .54784 .29765 L p
1 g
F P
s
P
p
.002 w
.53916 .29334 m .54784 .29765 L .56383 .28428 L p
1 g
F P
s
P
p
.002 w
.54646 .2756 m .52718 .27182 L .52955 .29144 L p
1 g
F P
s
P
p
.002 w
.52955 .29144 m .53916 .29334 L .54646 .2756 L p
1 g
F P
s
P
p
.002 w
.56383 .28428 m .54646 .2756 L .53916 .29334 L p
1 g
F P
s
P
p
.002 w
.41668 .57227 m .47254 .59052 L .47761 .57214 L p
1 g
F P
s
P
p
.002 w
.47761 .57214 m .42116 .55365 L .41668 .57227 L p
1 g
F P
s
P
p
.002 w
.53628 .57759 m .47761 .57214 L .47254 .59052 L p
1 g
F P
s
P
p
.002 w
.61039 .31514 m .61285 .33807 L .63605 .35144 L p
1 g
F P
s
P
p
.002 w
.61285 .33807 m .61039 .31514 L .58536 .31172 L p
1 g
F P
s
P
p
.002 w
.36762 .54272 m .41668 .57227 L .42116 .55365 L p
1 g
F P
s
P
p
.002 w
.42116 .55365 m .37162 .52358 L .36762 .54272 L p
1 g
F P
s
P
p
.002 w
.5773 .29681 m .58536 .31172 L .61039 .31514 L p
1 g
F P
s
P
p
.002 w
.66998 .44497 m .63897 .47688 L .64312 .50178 L p
1 g
F P
s
P
p
.002 w
.63897 .47688 m .66998 .44497 L .65926 .42199 L p
1 g
F P
s
P
p
.002 w
.34655 .33658 m .34879 .38013 L .36898 .36363 L p
1 g
F P
s
P
p
.002 w
.36898 .36363 m .36742 .32397 L .34655 .33658 L p
1 g
F P
s
P
p
.002 w
.31924 .4179 m .34129 .46344 L .35291 .4425 L p
1 g
F P
s
P
p
.002 w
.35291 .4425 m .33204 .39834 L .31924 .4179 L p
1 g
F P
s
P
p
.002 w
.40467 .28211 m .39117 .3144 L .41715 .30797 L p
1 g
F P
s
P
p
.002 w
.41715 .30797 m .42871 .28128 L .40467 .28211 L p
1 g
F P
s
P
p
.002 w
.65624 .36715 m .64475 .39975 L .65926 .42199 L p
1 g
F P
s
P
p
.002 w
.64475 .39975 m .65624 .36715 L .63605 .35144 L p
1 g
F P
s
P
p
.002 w
.49582 .25802 m .47156 .26801 L .49186 .27999 L p
1 g
F P
s
P
p
.002 w
.49186 .27999 m .50826 .27336 L .49582 .25802 L p
1 g
F P
s
P
p
.002 w
.53628 .57759 m .59225 .56929 L .59612 .54755 L p
1 g
F P
s
P
p
.002 w
.64367 .52547 m .59612 .54755 L .59225 .56929 L p
1 g
F P
s
P
p
.002 w
.59612 .54755 m .64367 .52547 L .64312 .50178 L p
1 g
F P
s
P
p
.002 w
.47254 .59052 m .53055 .59604 L .53628 .57759 L p
1 g
F P
s
P
p
.002 w
.59225 .56929 m .53628 .57759 L .53055 .59604 L p
1 g
F P
s
P
p
.002 w
.45141 .25993 m .42871 .28128 L .45395 .28427 L p
1 g
F P
s
P
p
.002 w
.45395 .28427 m .47156 .26801 L .45141 .25993 L p
1 g
F P
s
P
p
.002 w
.61039 .31514 m .59864 .293 L .5773 .29681 L p
1 g
F P
s
P
p
.002 w
.56383 .28428 m .5773 .29681 L .59864 .293 L p
1 g
F P
s
P
p
.002 w
.6332 .32165 m .63605 .35144 L .65624 .36715 L p
1 g
F P
s
P
p
.002 w
.63605 .35144 m .6332 .32165 L .61039 .31514 L p
1 g
F P
s
P
p
.002 w
.52402 .25563 m .49582 .25802 L .50826 .27336 L p
1 g
F P
s
P
p
.002 w
.50826 .27336 m .52718 .27182 L .52402 .25563 L p
1 g
F P
s
P
p
.002 w
.32983 .50406 m .36762 .54272 L .37162 .52358 L p
1 g
F P
s
P
p
.002 w
.37162 .52358 m .33348 .48413 L .32983 .50406 L p
1 g
F P
s
P
p
.002 w
.38247 .2869 m .36742 .32397 L .39117 .3144 L p
1 g
F P
s
P
p
.002 w
.39117 .3144 m .40467 .28211 L .38247 .2869 L p
1 g
F P
s
P
p
.002 w
.32917 .35206 m .33204 .39834 L .34879 .38013 L p
1 g
F P
s
P
p
.002 w
.34879 .38013 m .34655 .33658 L .32917 .35206 L p
1 g
F P
s
P
p
.002 w
.67286 .38492 m .65926 .42199 L .66998 .44497 L p
1 g
F P
s
P
p
.002 w
.65926 .42199 m .67286 .38492 L .65624 .36715 L p
1 g
F P
s
P
p
.002 w
.59864 .293 m .57871 .27426 L .56383 .28428 L p
1 g
F P
s
P
p
.002 w
.54646 .2756 m .56383 .28428 L .57871 .27426 L p
1 g
F P
s
P
p
.002 w
.59864 .293 m .61039 .31514 L .6332 .32165 L p
1 g
F P
s
P
p
.002 w
.67651 .46817 m .64312 .50178 L .64367 .52547 L p
1 g
F P
s
P
p
.002 w
.64312 .50178 m .67651 .46817 L .66998 .44497 L p
1 g
F P
s
P
p
.002 w
.55281 .26127 m .52402 .25563 L .52718 .27182 L p
1 g
F P
s
P
p
.002 w
.52718 .27182 m .54646 .2756 L .55281 .26127 L p
1 g
F P
s
P
p
.002 w
.57871 .27426 m .55281 .26127 L .54646 .2756 L p
1 g
F P
s
P
p
.002 w
.31088 .4384 m .33348 .48413 L .34129 .46344 L p
1 g
F P
s
P
p
.002 w
.34129 .46344 m .31924 .4179 L .31088 .4384 L p
1 g
F P
s
P
p
.002 w
.41422 .58785 m .46801 .60538 L .47254 .59052 L p
1 g
F P
s
P
p
.002 w
.47254 .59052 m .41668 .57227 L .41422 .58785 L p
1 g
F P
s
P
p
.002 w
.53055 .59604 m .47254 .59052 L .46801 .60538 L p
1 g
F P
s
P
p
.002 w
.36699 .55957 m .41422 .58785 L .41668 .57227 L p
1 g
F P
s
P
p
.002 w
.41668 .57227 m .36762 .54272 L .36699 .55957 L p
1 g
F P
s
P
p
.002 w
.48306 .24669 m .45141 .25993 L .47156 .26801 L p
1 g
F P
s
P
p
.002 w
.47156 .26801 m .49582 .25802 L .48306 .24669 L p
1 g
F P
s
P
p
.002 w
.43189 .25611 m .40467 .28211 L .42871 .28128 L p
1 g
F P
s
P
p
.002 w
.42871 .28128 m .45141 .25993 L .43189 .25611 L p
1 g
F P
s
P
p
.002 w
.53055 .59604 m .58582 .5881 L .59225 .56929 L p
1 g
F P
s
P
p
.002 w
.64044 .54736 m .59225 .56929 L .58582 .5881 L p
1 g
F P
s
P
p
.002 w
.59225 .56929 m .64044 .54736 L .64367 .52547 L p
1 g
F P
s
P
p
.002 w
.46801 .60538 m .52381 .61079 L .53055 .59604 L p
1 g
F P
s
P
p
.002 w
.58582 .5881 m .53055 .59604 L .52381 .61079 L p
1 g
F P
s
P
p
.002 w
.65318 .33123 m .65624 .36715 L .67286 .38492 L p
1 g
F P
s
P
p
.002 w
.65624 .36715 m .65318 .33123 L .6332 .32165 L p
1 g
F P
s
P
p
.002 w
.6332 .32165 m .6181 .29267 L .59864 .293 L p
1 g
F P
s
P
p
.002 w
.57871 .27426 m .59864 .293 L .6181 .29267 L p
1 g
F P
s
P
p
.002 w
.36273 .29571 m .34655 .33658 L .36742 .32397 L p
1 g
F P
s
P
p
.002 w
.36742 .32397 m .38247 .2869 L .36273 .29571 L p
1 g
F P
s
P
p
.002 w
.68535 .40441 m .66998 .44497 L .67651 .46817 L p
1 g
F P
s
P
p
.002 w
.66998 .44497 m .68535 .40441 L .67286 .38492 L p
1 g
F P
s
P
p
.002 w
.31588 .37014 m .31924 .4179 L .33204 .39834 L p
1 g
F P
s
P
p
.002 w
.33204 .39834 m .32917 .35206 L .31588 .37014 L p
1 g
F P
s
P
p
.002 w
.6181 .29267 m .6332 .32165 L .65318 .33123 L p
1 g
F P
s
P
p
.002 w
.67852 .49104 m .64367 .52547 L .64044 .54736 L p
1 g
F P
s
P
p
.002 w
.64367 .52547 m .67852 .49104 L .67651 .46817 L p
1 g
F P
s
P
p
.002 w
.52009 .24348 m .48306 .24669 L .49582 .25802 L p
1 g
F P
s
P
p
.002 w
.49582 .25802 m .52402 .25563 L .52009 .24348 L p
1 g
F P
s
P
p
.002 w
.33064 .5227 m .36699 .55957 L .36762 .54272 L p
1 g
F P
s
P
p
.002 w
.36762 .54272 m .32983 .50406 L .33064 .5227 L p
1 g
F P
s
P
p
.002 w
.30739 .45934 m .32983 .50406 L .33348 .48413 L p
1 g
F P
s
P
p
.002 w
.33348 .48413 m .31088 .4384 L .30739 .45934 L p
1 g
F P
s
P
p
.002 w
.6181 .29267 m .59206 .26802 L .57871 .27426 L p
1 g
F P
s
P
p
.002 w
.55281 .26127 m .57871 .27426 L .59206 .26802 L p
1 g
F P
s
P
p
.002 w
.41351 .25689 m .38247 .2869 L .40467 .28211 L p
1 g
F P
s
P
p
.002 w
.40467 .28211 m .43189 .25611 L .41351 .25689 L p
1 g
F P
s
P
p
.002 w
.558 .25088 m .52009 .24348 L .52402 .25563 L p
1 g
F P
s
P
p
.002 w
.52402 .25563 m .55281 .26127 L .558 .25088 L p
1 g
F P
s
P
p
.002 w
.59206 .26802 m .558 .25088 L .55281 .26127 L p
1 g
F P
s
P
p
.002 w
.47026 .23989 m .43189 .25611 L .45141 .25993 L p
1 g
F P
s
P
p
.002 w
.45141 .25993 m .48306 .24669 L .47026 .23989 L p
1 g
F P
s
P
p
.002 w
.41396 .59983 m .46415 .61617 L .46801 .60538 L p
1 g
F P
s
P
p
.002 w
.46801 .60538 m .41422 .58785 L .41396 .59983 L p
1 g
F P
s
P
p
.002 w
.52381 .61079 m .46801 .60538 L .46415 .61617 L p
1 g
F P
s
P
p
.002 w
.6697 .34377 m .67286 .38492 L .68535 .40441 L p
1 g
F P
s
P
p
.002 w
.67286 .38492 m .6697 .34377 L .65318 .33123 L p
1 g
F P
s
P
p
.002 w
.36993 .57359 m .41396 .59983 L .41422 .58785 L p
1 g
F P
s
P
p
.002 w
.41422 .58785 m .36699 .55957 L .36993 .57359 L p
1 g
F P
s
P
p
.002 w
.52381 .61079 m .57688 .60336 L .58582 .5881 L p
1 g
F P
s
P
p
.002 w
.63334 .56682 m .58582 .5881 L .57688 .60336 L p
1 g
F P
s
P
p
.002 w
.58582 .5881 m .63334 .56682 L .64044 .54736 L p
1 g
F P
s
P
p
.002 w
.34609 .3085 m .32917 .35206 L .34655 .33658 L p
1 g
F P
s
P
p
.002 w
.34655 .33658 m .36273 .29571 L .34609 .3085 L p
1 g
F P
s
P
p
.002 w
.69322 .42521 m .67651 .46817 L .67852 .49104 L p
1 g
F P
s
P
p
.002 w
.67651 .46817 m .69322 .42521 L .68535 .40441 L p
1 g
F P
s
P
p
.002 w
.30723 .39045 m .31088 .4384 L .31924 .4179 L p
1 g
F P
s
P
p
.002 w
.31924 .4179 m .31588 .37014 L .30723 .39045 L p
1 g
F P
s
P
p
.002 w
.65318 .33123 m .63508 .29603 L .6181 .29267 L p
1 g
F P
s
P
p
.002 w
.59206 .26802 m .6181 .29267 L .63508 .29603 L p
1 g
F P
s
P
p
.002 w
.46415 .61617 m .51616 .62127 L .52381 .61079 L p
1 g
F P
s
P
p
.002 w
.57688 .60336 m .52381 .61079 L .51616 .62127 L p
1 g
F P
s
P
p
.002 w
.63508 .29603 m .65318 .33123 L .6697 .34377 L p
1 g
F P
s
P
p
.002 w
.67576 .51298 m .64044 .54736 L .63334 .56682 L p
1 g
F P
s
P
p
.002 w
.64044 .54736 m .67576 .51298 L .67852 .49104 L p
1 g
F P
s
P
p
.002 w
.51545 .2359 m .47026 .23989 L .48306 .24669 L p
1 g
F P
s
P
p
.002 w
.48306 .24669 m .52009 .24348 L .51545 .2359 L p
1 g
F P
s
P
p
.002 w
.33613 .5395 m .36993 .57359 L .36699 .55957 L p
1 g
F P
s
P
p
.002 w
.36699 .55957 m .33064 .5227 L .33613 .5395 L p
1 g
F P
s
P
p
.002 w
.30911 .48019 m .33064 .5227 L .32983 .50406 L p
1 g
F P
s
P
p
.002 w
.32983 .50406 m .30739 .45934 L .30911 .48019 L p
1 g
F P
s
P
p
.002 w
.39685 .26248 m .36273 .29571 L .38247 .2869 L p
1 g
F P
s
P
p
.002 w
.38247 .2869 m .41351 .25689 L .39685 .26248 L p
1 g
F P
s
P
p
.002 w
.63508 .29603 m .60345 .26594 L .59206 .26802 L p
1 g
F P
s
P
p
.002 w
.558 .25088 m .59206 .26802 L .60345 .26594 L p
1 g
F P
s
P
p
.002 w
.68215 .35911 m .68535 .40441 L .69322 .42521 L p
1 g
F P
s
P
p
.002 w
.68535 .40441 m .68215 .35911 L .6697 .34377 L p
1 g
F P
s
P
p
.002 w
.45776 .23807 m .41351 .25689 L .43189 .25611 L p
1 g
F P
s
P
p
.002 w
.43189 .25611 m .47026 .23989 L .45776 .23807 L p
1 g
F P
s
P
p
.002 w
.33318 .32513 m .31588 .37014 L .32917 .35206 L p
1 g
F P
s
P
p
.002 w
.32917 .35206 m .34609 .3085 L .33318 .32513 L p
1 g
F P
s
P
p
.002 w
.56184 .24495 m .51545 .2359 L .52009 .24348 L p
1 g
F P
s
P
p
.002 w
.52009 .24348 m .558 .25088 L .56184 .24495 L p
1 g
F P
s
P
p
.002 w
.69605 .44683 m .67852 .49104 L .67576 .51298 L p
1 g
F P
s
P
p
.002 w
.67852 .49104 m .69605 .44683 L .69322 .42521 L p
1 g
F P
s
P
p
.002 w
.60345 .26594 m .56184 .24495 L .558 .25088 L p
1 g
F P
s
P
p
.002 w
.41604 .6077 m .4611 .62235 L .46415 .61617 L p
1 g
F P
s
P
p
.002 w
.46415 .61617 m .41396 .59983 L .41604 .6077 L p
1 g
F P
s
P
p
.002 w
.51616 .62127 m .46415 .61617 L .4611 .62235 L p
1 g
F P
s
P
p
.002 w
.51616 .62127 m .56551 .6145 L .57688 .60336 L p
1 g
F P
s
P
p
.002 w
.62236 .58324 m .57688 .60336 L .56551 .6145 L p
1 g
F P
s
P
p
.002 w
.57688 .60336 m .62236 .58324 L .63334 .56682 L p
1 g
F P
s
P
p
.002 w
.30368 .41255 m .30739 .45934 L .31088 .4384 L p
1 g
F P
s
P
p
.002 w
.31088 .4384 m .30723 .39045 L .30368 .41255 L p
1 g
F P
s
P
p
.002 w
.37657 .58424 m .41604 .6077 L .41396 .59983 L p
1 g
F P
s
P
p
.002 w
.41396 .59983 m .36993 .57359 L .37657 .58424 L p
1 g
F P
s
P
p
.002 w
.64903 .30319 m .6697 .34377 L .68215 .35911 L p
1 g
F P
s
P
p
.002 w
.6697 .34377 m .64903 .30319 L .63508 .29603 L p
1 g
F P
s
P
p
.002 w
.60345 .26594 m .63508 .29603 L .64903 .30319 L p
1 g
F P
s
P
p
.002 w
.66807 .53336 m .63334 .56682 L .62236 .58324 L p
1 g
F P
s
P
p
.002 w
.63334 .56682 m .66807 .53336 L .67576 .51298 L p
1 g
F P
s
P
p
.002 w
.4611 .62235 m .50775 .62697 L .51616 .62127 L p
1 g
F P
s
P
p
.002 w
.56551 .6145 m .51616 .62127 L .50775 .62697 L p
1 g
F P
s
P
p
.002 w
.38246 .273 m .34609 .3085 L .36273 .29571 L p
1 g
F P
s
P
p
.002 w
.36273 .29571 m .39685 .26248 L .38246 .273 L p
1 g
F P
s
P
p
.002 w
.31624 .50035 m .33613 .5395 L .33064 .5227 L p
1 g
F P
s
P
p
.002 w
.33064 .5227 m .30911 .48019 L .31624 .50035 L p
1 g
F P
s
P
p
.002 w
.51018 .23341 m .45776 .23807 L .47026 .23989 L p
1 g
F P
s
P
p
.002 w
.47026 .23989 m .51545 .2359 L .51018 .23341 L p
1 g
F P
s
P
p
.002 w
.68999 .37698 m .69322 .42521 L .69605 .44683 L p
1 g
F P
s
P
p
.002 w
.69322 .42521 m .68999 .37698 L .68215 .35911 L p
1 g
F P
s
P
p
.002 w
.34642 .55387 m .37657 .58424 L .36993 .57359 L p
1 g
F P
s
P
p
.002 w
.36993 .57359 m .33613 .5395 L .34642 .55387 L p
1 g
F P
s
P
p
.002 w
.32456 .3453 m .30723 .39045 L .31588 .37014 L p
1 g
F P
s
P
p
.002 w
.31588 .37014 m .33318 .32513 L .32456 .3453 L p
1 g
F P
s
P
p
.002 w
.44594 .24158 m .39685 .26248 L .41351 .25689 L p
1 g
F P
s
P
p
.002 w
.41351 .25689 m .45776 .23807 L .44594 .24158 L p
1 g
F P
s
P
p
.002 w
.69349 .4687 m .67576 .51298 L .66807 .53336 L p
1 g
F P
s
P
p
.002 w
.67576 .51298 m .69349 .4687 L .69605 .44683 L p
1 g
F P
s
P
p
.002 w
.64903 .30319 m .61246 .26832 L .60345 .26594 L p
1 g
F P
s
P
p
.002 w
.56184 .24495 m .60345 .26594 L .61246 .26832 L p
1 g
F P
s
P
p
.002 w
.30559 .43587 m .30911 .48019 L .30739 .45934 L p
1 g
F P
s
P
p
.002 w
.30739 .45934 m .30368 .41255 L .30559 .43587 L p
1 g
F P
s
P
p
.002 w
.56412 .24392 m .51018 .23341 L .51545 .2359 L p
1 g
F P
s
P
p
.002 w
.51545 .2359 m .56184 .24495 L .56412 .24392 L p
1 g
F P
s
P
p
.002 w
.50775 .62697 m .55187 .62096 L .56551 .6145 L p
1 g
F P
s
P
p
.002 w
.6076 .59599 m .56551 .6145 L .55187 .62096 L p
1 g
F P
s
P
p
.002 w
.56551 .6145 m .6076 .59599 L .62236 .58324 L p
1 g
F P
s
P
p
.002 w
.61246 .26832 m .56412 .24392 L .56184 .24495 L p
1 g
F P
s
P
p
.002 w
.68215 .35911 m .65937 .31418 L .64903 .30319 L p
1 g
F P
s
P
p
.002 w
.65937 .31418 m .68215 .35911 L .68999 .37698 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.588 .60473 L
s
P
p
.004 w
.58801 .60477 m
.58865 .60602 L
s
P
p
.004 w
.6043 .63702 m
.63453 .69686 L
s
P
p
.002 w
.62236 .58324 m .65542 .55154 L .66807 .53336 L p
1 g
F P
s
P
p
.002 w
.65542 .55154 m .62236 .58324 L .6076 .59599 L p
1 g
F P
s
P
p
.002 w
.42056 .61096 m .459 .62346 L .4611 .62235 L p
1 g
F P
s
P
p
.004 w
.4401 .65493 m
.44679 .62988 L
s
P
p
.002 w
.4611 .62235 m .41604 .6077 L .42056 .61096 L p
1 g
F P
s
P
p
.002 w
.50775 .62697 m .4611 .62235 L .459 .62346 L p
1 g
F P
s
P
p
.002 w
.61246 .26832 m .64903 .30319 L .65937 .31418 L p
1 g
F P
s
P
p
.002 w
.38697 .59099 m .42056 .61096 L .41604 .6077 L p
1 g
F P
s
P
p
.002 w
.41604 .6077 m .37657 .58424 L .38697 .59099 L p
1 g
F P
s
P
p
.002 w
.3709 .28842 m .33318 .32513 L .34609 .3085 L p
1 g
F P
s
P
p
.002 w
.34609 .3085 m .38246 .273 L .3709 .28842 L p
1 g
F P
s
P
p
.002 w
.459 .62346 m .49877 .6274 L .50775 .62697 L p
1 g
F P
s
P
p
.002 w
.55187 .62096 m .50775 .62697 L .49877 .6274 L p
1 g
F P
s
P
p
.002 w
.69605 .44683 m .69274 .39699 L .68999 .37698 L p
1 g
F P
s
P
p
.002 w
.69274 .39699 m .69605 .44683 L .69349 .4687 L p
1 g
F P
s
P
p
.002 w
.32886 .5192 m .34642 .55387 L .33613 .5395 L p
1 g
F P
s
P
p
.002 w
.33613 .5395 m .31624 .50035 L .32886 .5192 L p
1 g
F P
s
P
p
.002 w
.3207 .36859 m .30368 .41255 L .30723 .39045 L p
1 g
F P
s
P
p
.002 w
.30723 .39045 m .32456 .3453 L .3207 .36859 L p
1 g
F P
s
P
p
.002 w
.50439 .23641 m .44594 .24158 L .45776 .23807 L p
1 g
F P
s
P
p
.002 w
.45776 .23807 m .51018 .23341 L .50439 .23641 L p
1 g
F P
s
P
p
.002 w
.66807 .53336 m .68536 .49021 L .69349 .4687 L p
1 g
F P
s
P
p
.002 w
.68536 .49021 m .66807 .53336 L .65542 .55154 L p
1 g
F P
s
P
p
.002 w
.36146 .56527 m .38697 .59099 L .37657 .58424 L p
1 g
F P
s
P
p
.002 w
.37657 .58424 m .34642 .55387 L .36146 .56527 L p
1 g
F P
s
P
p
.002 w
.43517 .25065 m .38246 .273 L .39685 .26248 L p
1 g
F P
s
P
p
.002 w
.39685 .26248 m .44594 .24158 L .43517 .25065 L p
1 g
F P
s
P
p
.002 w
.31316 .45975 m .31624 .50035 L .30911 .48019 L p
1 g
F P
s
P
p
.002 w
.30911 .48019 m .30559 .43587 L .31316 .45975 L p
1 g
F P
s
P
p
.002 w
.65937 .31418 m .61867 .2754 L .61246 .26832 L p
1 g
F P
s
P
p
.002 w
.56412 .24392 m .61246 .26832 L .61867 .2754 L p
1 g
F P
s
P
p
.002 w
.66559 .32891 m .68999 .37698 L .69274 .39699 L p
1 g
F P
s
P
p
.002 w
.68999 .37698 m .66559 .32891 L .65937 .31418 L p
1 g
F P
s
P
p
.002 w
.49877 .6274 m .53622 .62229 L .55187 .62096 L p
1 g
F P
s
P
p
.002 w
.55187 .62096 m .58927 .60453 L .6076 .59599 L p
1 g
F P
s
P
p
.002 w
.58927 .60453 m .55187 .62096 L .53622 .62229 L p
1 g
F P
s
P
p
.004 w
.58983 .60836 m
.6043 .63702 L
s
P
p
.004 w
.58865 .60602 m
.58983 .60836 L
s
P
p
.002 w
.63794 .56686 m .6076 .59599 L .58927 .60453 L p
1 g
F P
s
P
p
.002 w
.6076 .59599 m .63794 .56686 L .65542 .55154 L p
1 g
F P
s
P
p
.002 w
.56467 .24817 m .50439 .23641 L .51018 .23341 L p
1 g
F P
s
P
p
.002 w
.51018 .23341 m .56412 .24392 L .56467 .24817 L p
1 g
F P
s
P
p
.002 w
.36268 .30852 m .32456 .3453 L .33318 .32513 L p
1 g
F P
s
P
p
.002 w
.33318 .32513 m .3709 .28842 L .36268 .30852 L p
1 g
F P
s
P
p
.002 w
.61867 .2754 m .65937 .31418 L .66559 .32891 L p
1 g
F P
s
P
p
.002 w
.61867 .2754 m .56467 .24817 L .56412 .24392 L p
1 g
F P
s
P
p
.002 w
.42754 .60921 m .45797 .61911 L .459 .62346 L p
1 g
F P
s
P
p
.002 w
.459 .62346 m .42056 .61096 L .42754 .60921 L p
1 g
F P
s
P
p
.002 w
.49877 .6274 m .459 .62346 L .45797 .61911 L p
1 g
F P
s
P
p
.002 w
.69005 .41866 m .69349 .4687 L .68536 .49021 L p
1 g
F P
s
P
p
.002 w
.69349 .4687 m .69005 .41866 L .69274 .39699 L p
1 g
F P
s
P
p
.002 w
.40103 .59342 m .42754 .60921 L .42056 .61096 L p
1 g
F P
s
P
p
.002 w
.42056 .61096 m .38697 .59099 L .40103 .59342 L p
1 g
F P
s
P
p
.002 w
.32196 .39439 m .30559 .43587 L .30368 .41255 L p
1 g
F P
s
P
p
.002 w
.30368 .41255 m .3207 .36859 L .32196 .39439 L p
1 g
F P
s
P
p
.002 w
.34683 .53607 m .36146 .56527 L .34642 .55387 L p
1 g
F P
s
P
p
.002 w
.34642 .55387 m .32886 .5192 L .34683 .53607 L p
1 g
F P
s
P
p
.002 w
.67164 .51067 m .65542 .55154 L .63794 .56686 L p
1 g
F P
s
P
p
.002 w
.65542 .55154 m .67164 .51067 L .68536 .49021 L p
1 g
F P
s
P
p
.002 w
.45797 .61911 m .48943 .62221 L .49877 .6274 L p
1 g
F P
s
P
p
.002 w
.53622 .62229 m .49877 .6274 L .48943 .62221 L p
1 g
F P
s
P
p
.002 w
.3264 .48346 m .32886 .5192 L .31624 .50035 L p
1 g
F P
s
P
p
.002 w
.31624 .50035 m .31316 .45975 L .3264 .48346 L p
1 g
F P
s
P
p
.002 w
.42588 .26533 m .3709 .28842 L .38246 .273 L p
1 g
F P
s
P
p
.002 w
.38246 .273 m .43517 .25065 L .42588 .26533 L p
1 g
F P
s
P
p
.002 w
.49822 .24517 m .43517 .25065 L .44594 .24158 L p
1 g
F P
s
P
p
.002 w
.44594 .24158 m .50439 .23641 L .49822 .24517 L p
1 g
F P
s
P
p
.002 w
.38107 .57317 m .40103 .59342 L .38697 .59099 L p
1 g
F P
s
P
p
.002 w
.38697 .59099 m .36146 .56527 L .38107 .57317 L p
1 g
F P
s
P
p
.002 w
.66725 .34715 m .69274 .39699 L .69005 .41866 L p
1 g
F P
s
P
p
.002 w
.69274 .39699 m .66725 .34715 L .66559 .32891 L p
1 g
F P
s
P
p
.002 w
.53622 .62229 m .56774 .60836 L .58927 .60453 L p
1 g
F P
s
P
p
.002 w
.61593 .57873 m .58927 .60453 L .56774 .60836 L p
1 g
F P
s
P
p
.002 w
.58927 .60453 m .61593 .57873 L .63794 .56686 L p
1 g
F P
s
P
p
.002 w
.66559 .32891 m .62172 .28725 L .61867 .2754 L p
1 g
F P
s
P
p
.002 w
.56467 .24817 m .61867 .2754 L .62172 .28725 L p
1 g
F P
s
P
p
.002 w
.48943 .62221 m .51893 .61814 L .53622 .62229 L p
1 g
F P
s
P
p
.002 w
.56774 .60836 m .53622 .62229 L .51893 .61814 L p
1 g
F P
s
P
p
.002 w
.35826 .33289 m .3207 .36859 L .32456 .3453 L p
1 g
F P
s
P
p
.002 w
.32456 .3453 m .36268 .30852 L .35826 .33289 L p
1 g
F P
s
P
p
.002 w
.68174 .44139 m .68536 .49021 L .67164 .51067 L p
1 g
F P
s
P
p
.002 w
.68536 .49021 m .68174 .44139 L .69005 .41866 L p
1 g
F P
s
P
p
.002 w
.32851 .42198 m .31316 .45975 L .30559 .43587 L p
1 g
F P
s
P
p
.002 w
.30559 .43587 m .32196 .39439 L .32851 .42198 L p
1 g
F P
s
P
p
.002 w
.62172 .28725 m .66559 .32891 L .66725 .34715 L p
1 g
F P
s
P
p
.002 w
.56337 .2579 m .49822 .24517 L .50439 .23641 L p
1 g
F P
s
P
p
.002 w
.50439 .23641 m .56467 .24817 L .56337 .2579 L p
1 g
F P
s
P
p
.002 w
.65252 .52939 m .63794 .56686 L .61593 .57873 L p
1 g
F P
s
P
p
.002 w
.63794 .56686 m .65252 .52939 L .67164 .51067 L p
1 g
F P
s
P
p
.002 w
.62172 .28725 m .56337 .2579 L .56467 .24817 L p
1 g
F P
s
P
p
.002 w
.36983 .55033 m .38107 .57317 L .36146 .56527 L p
1 g
F P
s
P
p
.002 w
.36146 .56527 m .34683 .53607 L .36983 .55033 L p
1 g
F P
s
P
p
.002 w
.43694 .60218 m .45813 .60909 L .45797 .61911 L p
1 g
F P
s
P
p
.002 w
.45797 .61911 m .42754 .60921 L .43694 .60218 L p
1 g
F P
s
P
p
.002 w
.48943 .62221 m .45797 .61911 L .45813 .60909 L p
1 g
F P
s
P
p
.002 w
.41854 .59118 m .43694 .60218 L .42754 .60921 L p
1 g
F P
s
P
p
.002 w
.42754 .60921 m .40103 .59342 L .41854 .59118 L p
1 g
F P
s
P
p
.002 w
.34511 .50621 m .34683 .53607 L .32886 .5192 L p
1 g
F P
s
P
p
.002 w
.32886 .5192 m .3264 .48346 L .34511 .50621 L p
1 g
F P
s
P
p
.002 w
.45813 .60909 m .48002 .61122 L .48943 .62221 L p
1 g
F P
s
P
p
.002 w
.51893 .61814 m .48943 .62221 L .48002 .61122 L p
1 g
F P
s
P
p
.002 w
.41845 .28546 m .36268 .30852 L .3709 .28842 L p
1 g
F P
s
P
p
.002 w
.3709 .28842 m .42588 .26533 L .41845 .28546 L p
1 g
F P
s
P
p
.002 w
.49185 .25977 m .42588 .26533 L .43517 .25065 L p
1 g
F P
s
P
p
.002 w
.43517 .25065 m .49822 .24517 L .49185 .25977 L p
1 g
F P
s
P
p
.002 w
.40483 .57712 m .41854 .59118 L .40103 .59342 L p
1 g
F P
s
P
p
.002 w
.40103 .59342 m .38107 .57317 L .40483 .57712 L p
1 g
F P
s
P
p
.002 w
.66406 .3685 m .69005 .41866 L .68174 .44139 L p
1 g
F P
s
P
p
.002 w
.69005 .41866 m .66406 .3685 L .66725 .34715 L p
1 g
F P
s
P
p
.002 w
.51893 .61814 m .54353 .60713 L .56774 .60836 L p
1 g
F P
s
P
p
.002 w
.58991 .5866 m .56774 .60836 L .54353 .60713 L p
1 g
F P
s
P
p
.002 w
.56774 .60836 m .58991 .5866 L .61593 .57873 L p
1 g
F P
s
P
p
.002 w
.35794 .36088 m .32196 .39439 L .3207 .36859 L p
1 g
F P
s
P
p
.002 w
.3207 .36859 m .35826 .33289 L .35794 .36088 L p
1 g
F P
s
P
p
.002 w
.66779 .46447 m .67164 .51067 L .65252 .52939 L p
1 g
F P
s
P
p
.002 w
.67164 .51067 m .66779 .46447 L .68174 .44139 L p
1 g
F P
s
P
p
.002 w
.34034 .45046 m .3264 .48346 L .31316 .45975 L p
1 g
F P
s
P
p
.002 w
.31316 .45975 m .32851 .42198 L .34034 .45046 L p
1 g
F P
s
P
p
.002 w
.48002 .61122 m .50044 .60833 L .51893 .61814 L p
1 g
F P
s
P
p
.002 w
.54353 .60713 m .51893 .61814 L .50044 .60833 L p
1 g
F P
s
P
p
.002 w
.62839 .54567 m .61593 .57873 L .58991 .5866 L p
1 g
F P
s
P
p
.002 w
.61593 .57873 m .62839 .54567 L .65252 .52939 L p
1 g
F P
s
P
p
.002 w
.66725 .34715 m .62131 .3038 L .62172 .28725 L p
1 g
F P
s
P
p
.002 w
.56337 .2579 m .62172 .28725 L .62131 .3038 L p
1 g
F P
s
P
p
.002 w
.62131 .3038 m .66725 .34715 L .66406 .3685 L p
1 g
F P
s
P
p
.002 w
.36883 .52719 m .36983 .55033 L .34683 .53607 L p
1 g
F P
s
P
p
.002 w
.34683 .53607 m .34511 .50621 L .36883 .52719 L p
1 g
F P
s
P
p
.002 w
.39729 .5614 m .40483 .57712 L .38107 .57317 L p
1 g
F P
s
P
p
.002 w
.38107 .57317 m .36983 .55033 L .39729 .5614 L p
1 g
F P
s
P
p
.002 w
.56013 .27316 m .49185 .25977 L .49822 .24517 L p
1 g
F P
s
P
p
.002 w
.49822 .24517 m .56337 .2579 L .56013 .27316 L p
1 g
F P
s
P
p
.002 w
.62131 .3038 m .56013 .27316 L .56337 .2579 L p
1 g
F P
s
P
p
.002 w
.41323 .31063 m .35826 .33289 L .36268 .30852 L p
1 g
F P
s
P
p
.002 w
.36268 .30852 m .41845 .28546 L .41323 .31063 L p
1 g
F P
s
P
p
.002 w
.44858 .58977 m .45953 .59335 L .45813 .60909 L p
1 g
F P
s
P
p
.002 w
.45813 .60909 m .43694 .60218 L .44858 .58977 L p
1 g
F P
s
P
p
.002 w
.48002 .61122 m .45813 .60909 L .45953 .59335 L p
1 g
F P
s
P
p
.002 w
.43912 .58407 m .44858 .58977 L .43694 .60218 L p
1 g
F P
s
P
p
.002 w
.43694 .60218 m .41854 .59118 L .43912 .58407 L p
1 g
F P
s
P
p
.002 w
.65586 .3924 m .68174 .44139 L .66779 .46447 L p
1 g
F P
s
P
p
.002 w
.68174 .44139 m .65586 .3924 L .66406 .3685 L p
1 g
F P
s
P
p
.002 w
.50044 .60833 m .51731 .60063 L .54353 .60713 L p
1 g
F P
s
P
p
.002 w
.56056 .59005 m .54353 .60713 L .51731 .60063 L p
1 g
F P
s
P
p
.002 w
.54353 .60713 m .56056 .59005 L .58991 .5866 L p
1 g
F P
s
P
p
.002 w
.45953 .59335 m .47084 .59443 L .48002 .61122 L p
1 g
F P
s
P
p
.002 w
.50044 .60833 m .48002 .61122 L .47084 .59443 L p
1 g
F P
s
P
p
.002 w
.64847 .48713 m .65252 .52939 L .62839 .54567 L p
1 g
F P
s
P
p
.002 w
.65252 .52939 m .64847 .48713 L .66779 .46447 L p
1 g
F P
s
P
p
.002 w
.36192 .39167 m .32851 .42198 L .32196 .39439 L p
1 g
F P
s
P
p
.002 w
.32196 .39439 m .35794 .36088 L .36192 .39167 L p
1 g
F P
s
P
p
.002 w
.3572 .47888 m .34511 .50621 L .3264 .48346 L p
1 g
F P
s
P
p
.002 w
.3264 .48346 m .34034 .45046 L .3572 .47888 L p
1 g
F P
s
P
p
.002 w
.48549 .28006 m .41845 .28546 L .42588 .26533 L p
1 g
F P
s
P
p
.002 w
.42588 .26533 m .49185 .25977 L .48549 .28006 L p
1 g
F P
s
P
p
.002 w
.43215 .57682 m .43912 .58407 L .41854 .59118 L p
1 g
F P
s
P
p
.002 w
.41854 .59118 m .40483 .57712 L .43215 .57682 L p
1 g
F P
s
P
p
.002 w
.5999 .55889 m .58991 .5866 L .56056 .59005 L p
1 g
F P
s
P
p
.002 w
.58991 .5866 m .5999 .55889 L .62839 .54567 L p
1 g
F P
s
P
p
.002 w
.47084 .59443 m .48133 .59289 L .50044 .60833 L p
1 g
F P
s
P
p
.002 w
.51731 .60063 m .50044 .60833 L .48133 .59289 L p
1 g
F P
s
P
p
.002 w
.39689 .54561 m .39729 .5614 L .36983 .55033 L p
1 g
F P
s
P
p
.002 w
.36983 .55033 m .36883 .52719 L .39689 .54561 L p
1 g
F P
s
P
p
.002 w
.66406 .3685 m .61725 .32476 L .62131 .3038 L p
1 g
F P
s
P
p
.002 w
.56013 .27316 m .62131 .3038 L .61725 .32476 L p
1 g
F P
s
P
p
.002 w
.61725 .32476 m .66406 .3685 L .65586 .3924 L p
1 g
F P
s
P
p
.002 w
.42842 .56878 m .43215 .57682 L .40483 .57712 L p
1 g
F P
s
P
p
.002 w
.40483 .57712 m .39729 .5614 L .42842 .56878 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.62425 .50856 m .62839 .54567 L .5999 .55889 L p
1 g
F P
s
P
p
.002 w
.62839 .54567 m .62425 .50856 L .64847 .48713 L p
1 g
F P
s
P
p
.002 w
.37861 .50622 m .36883 .52719 L .34511 .50621 L p
1 g
F P
s
P
p
.002 w
.34511 .50621 m .3572 .47888 L .37861 .50622 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.47055 .54083 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.41052 .34016 m .35794 .36088 L .35826 .33289 L p
1 g
F P
s
P
p
.002 w
.35826 .33289 m .41323 .31063 L .41052 .34016 L p
1 g
F P
s
P
p
.002 w
.37019 .42422 m .34034 .45046 L .32851 .42198 L p
1 g
F P
s
P
p
.002 w
.32851 .42198 m .36192 .39167 L .37019 .42422 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.6427 .41813 m .66779 .46447 L .64847 .48713 L p
1 g
F P
s
P
p
.002 w
.66779 .46447 m .6427 .41813 L .65586 .3924 L p
1 g
F P
s
P
p
.002 w
.48133 .59289 m .4899 .58888 L .51731 .60063 L p
1 g
F P
s
P
p
.002 w
.52878 .58881 m .51731 .60063 L .4899 .58888 L p
1 g
F P
s
P
p
.002 w
.51731 .60063 m .52878 .58881 L .56056 .59005 L p
1 g
F P
s
P
p
.002 w
.55496 .29375 m .48549 .28006 L .49185 .25977 L p
1 g
F P
s
P
p
.002 w
.49185 .25977 m .56013 .27316 L .55496 .29375 L p
1 g
F P
s
P
p
.002 w
.56791 .56847 m .56056 .59005 L .52878 .58881 L p
1 g
F P
s
P
p
.002 w
.56056 .59005 m .56791 .56847 L .5999 .55889 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.61725 .32476 m .55496 .29375 L .56013 .27316 L p
1 g
F P
s
P
p
.002 w
.45953 .59335 m .44858 .58977 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.47084 .59443 m .45953 .59335 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.44858 .58977 m .43912 .58407 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.48133 .59289 m .47084 .59443 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.47935 .30562 m .41323 .31063 L .41845 .28546 L p
1 g
F P
s
P
p
.002 w
.41845 .28546 m .48549 .28006 L .47935 .30562 L p
1 g
F P
s
P
p
.002 w
.42837 .56078 m .42842 .56878 L .39729 .5614 L p
1 g
F P
s
P
p
.002 w
.39729 .5614 m .39689 .54561 L .42837 .56078 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.43912 .58407 m .43215 .57682 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4899 .58888 m .48133 .59289 L .46341 .5734 L p
1 g
F P
s
P
p
.002 w
.46529 .57397 m .4899 .58888 L p
.46341 .5734 L 1 g
F P
s
P
p
.002 w
.48904 .58089 m .48921 .57862 L p
.47815 .57771 L 1 g
F P
s
P
p
.002 w
.4956 .5828 m .4899 .58888 L .47484 .57976 L p
1 g
F P
s
P
p
.002 w
.47484 .57976 m .46529 .57397 L p
.46824 .57483 L 1 g
F P
s
P
p
.002 w
.46824 .57483 m .46872 .57265 L p
.458 .56837 L 1 g
F P
s
P
p
.002 w
.46002 .56983 m .46221 .5721 L p
.45162 .56414 L 1 g
F P
s
P
p
.4349 .55156 m .45078 .56312 L .45162 .56414 L 1 g
F
P
p
.45078 .56312 m .46002 .56983 L .45162 .56414 L 1 g
F
P
p
.002 w
.46221 .5721 m .43208 .55369 L .4349 .55156 L p
1 g
F P
s
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44376 .5546 L 1 g
F P
s
P
p
.458 .56837 m .4581 .56844 L .46824 .57483 L 1 g
F
P
p
.45796 .56835 m .45842 .56868 L .46824 .57483 L 1 g
F
P
p
.45777 .56828 m .45867 .56891 L .46824 .57483 L 1 g
F
P
p
.45741 .56813 m .45893 .56917 L .46824 .57483 L 1 g
F
P
p
.002 w
.46168 .57104 m .46221 .5721 L .46002 .56983 L p
1 g
F P
s
P
p
.45687 .56791 m .4593 .56951 L .46824 .57483 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.42837 .56078 m .43208 .55369 L .45411 .56715 L p
1 g
F P
s
P
p
.002 w
.45411 .56715 m .46221 .5721 L .45671 .57026 L p
1 g
F P
s
P
p
.002 w
.45671 .57026 m .42837 .56078 L p
.45411 .56715 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56312 L p
1 g
F P
s
P
p
.002 w
.45078 .56312 m .45002 .56518 L p
.458 .56837 L 1 g
F P
s
P
p
.46872 .57265 m .45078 .56312 L .458 .56837 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.4349 .55156 m .43881 .5486 L p
.45078 .56312 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43819 .54766 L p
1 g
F P
s
P
p
.002 w
.43208 .55369 m .40387 .53147 L p
.43826 .54788 L 1 g
F P
s
P
p
.43826 .54788 m .43838 .54794 L .4383 .54801 L 1 g
F
P
p
.43826 .54788 m .4383 .54801 L .43208 .55369 L 1 g
F
P
p
.002 w
.43881 .5486 m .43208 .55369 L p
.43838 .54794 L 1 g
F P
s
P
p
.002 w
.43819 .54766 m .43925 .54566 L p
.43527 .53779 L 1 g
F P
s
P
p
.002 w
.43787 .54663 m .41769 .5206 L p
.43401 .53349 L 1 g
F P
s
P
p
.43527 .53779 m .43482 .53691 L .43787 .54663 L 1 g
F
P
p
.43527 .53779 m .43787 .54663 L .43819 .54766 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44893 .54528 m .43918 .54832 L .43787 .54663 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43258 .52863 L p
1 g
F P
s
P
p
.002 w
.41769 .5206 m .42913 .51689 L p
.43258 .52863 L 1 g
F P
s
P
p
.4324 .53222 m .43258 .52863 L .43401 .53349 L 1 g
F
P
p
.41769 .5206 m .43258 .52863 L .4324 .53222 L 1 g
F
P
p
.002 w
.43258 .52863 m .43346 .52734 L p
.43312 .51766 L 1 g
F P
s
P
p
.43925 .54566 m .43258 .52863 L .43527 .53779 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43384 .50947 L p
1 g
F P
s
P
p
.002 w
.41769 .5206 m .39857 .48991 L p
.43356 .51219 L 1 g
F P
s
P
p
.002 w
.43323 .51556 m .41769 .5206 L p
.43356 .51219 L 1 g
F P
s
P
p
.43346 .52734 m .43384 .50947 L .4335 .5128 L 1 g
F
P
p
.002 w
.39857 .48991 m .42675 .48036 L .43425 .50535 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43425 .50535 m .43484 .50733 L p
.43384 .50947 L 1 g
F P
s
P
p
.39857 .48991 m .43425 .50535 L .43356 .51219 L 1 g
F
P
p
.002 w
.43484 .50733 m .42675 .48036 L p
.44098 .49477 L 1 g
F P
s
P
p
.002 w
.43384 .50947 m .43485 .50826 L p
.43911 .4983 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44271 .49122 L p
1 g
F P
s
P
p
.002 w
.42675 .48036 m .44847 .47943 L p
.44271 .49122 L 1 g
F P
s
P
p
.44003 .49381 m .44271 .49122 L .44098 .49477 L 1 g
F
P
p
.42675 .48036 m .44271 .49122 L .44003 .49381 L 1 g
F
P
p
.002 w
.44271 .49122 m .44166 .49233 L p
.43808 .5007 L 1 g
F P
s
P
p
.43485 .50826 m .44271 .49122 L .43808 .5007 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44271 .49122 m .44339 .4905 L p
.45012 .48405 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44271 .49122 m .46 .47894 L .44098 .49477 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45758 .47683 L p
1 g
F P
s
P
p
.002 w
.46 .47894 m .45519 .47914 L p
.45752 .47688 L 1 g
F P
s
P
p
.44339 .4905 m .45758 .47683 L .45637 .478 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45758 .47683 m .45826 .47608 L p
.46726 .47213 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47764 .46703 m .49433 .48597 L .46016 .47562 L 1 g
F
P
p
.002 w
.47764 .46703 m .47786 .46667 L p
.48613 .46583 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46386 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46386 L .48613 .46583 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46705 L p
1 g
F P
s
P
p
.51175 .46556 m .52549 .50062 L .50185 .46418 L 1 g
F
P
p
.5 .4634 m .52237 .46705 L .51003 .46532 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56602 .50929 L p
1 g
F P
s
P
p
.57756 .49728 m .57108 .52041 L .56602 .50929 L 1 g
F
P
p
.002 w
.56531 .50773 m .56589 .50723 L p
.56602 .50929 L 1 g
F P
s
P
p
.002 w
.56589 .50723 m .57756 .49728 L p
.56602 .50929 L 1 g
F P
s
P
p
.002 w
.56602 .50929 m .56515 .50826 L p
.56653 .51718 L 1 g
F P
s
P
p
.55661 .4905 m .56602 .50929 L .56531 .50773 L 1 g
F
P
p
.55661 .4905 m .56531 .50773 L .56085 .49861 L 1 g
F
P
p
.002 w
.57011 .50363 m .56531 .50773 L p
.55718 .49111 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55718 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55718 .49111 L .54894 .48313 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56531 .50773 m .54973 .52101 L p
.54809 .48231 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.54894 .48313 L 1 g
F P
s
P
p
.54764 .47159 m .55718 .49111 L .54809 .48231 L 1 g
F
P
p
.55718 .49111 m .56531 .50773 L .54809 .48231 L 1 g
F
P
p
.002 w
.54651 .47062 m .54764 .47159 L p
.54973 .52101 L 1 g
F P
s
P
p
.002 w
.54973 .52101 m .52549 .50062 L .54223 .47672 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.52214 .46667 m .54239 .47679 L .54223 .47672 L 1 g
F
P
p
.002 w
.54223 .47672 m .52549 .50062 L p
.52254 .46713 L 1 g
F P
s
P
p
.53081 .47116 m .54223 .47672 L .53629 .474 L 1 g
F
P
p
.52214 .46667 m .54223 .47672 L .53081 .47116 L 1 g
F
P
p
.51175 .46556 m .52254 .46713 L .52549 .50062 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.54704 .47892 m .54973 .52101 L .54223 .47672 L 1 g
F
P
p
.002 w
.52237 .46705 m .52214 .46667 L p
.53081 .47116 L 1 g
F P
s
P
p
.002 w
.54594 .47035 m .54651 .47062 L p
.51175 .46556 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46705 L p
1 g
F P
s
P
p
.53081 .47116 m .54302 .47747 L .52237 .46705 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.50623 .45149 m .54594 .47035 L p
.52237 .46705 L 1 g
F P
s
P
p
.50996 .46101 m .52237 .46705 L .51175 .46556 L 1 g
F
P
p
.50623 .45149 m .52237 .46705 L .50996 .46101 L 1 g
F
P
p
.002 w
.54651 .47062 m .54223 .47672 L p
.52254 .46713 L 1 g
F P
s
P
p
.002 w
.54223 .47672 m .54651 .47062 L p
.54704 .47892 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54302 .47747 L p
.53629 .474 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54239 .47679 L p
1 g
F P
s
P
p
.54894 .48313 m .55834 .49233 L .54239 .47679 L 1 g
F
P
p
.002 w
.55718 .49111 m .55834 .49233 L p
.54894 .48313 L 1 g
F P
s
P
p
.002 w
.54764 .47159 m .57756 .49728 L .57011 .50363 L p
1 g
F P
s
P
p
.54764 .47159 m .57011 .50363 L .55718 .49111 L 1 g
F
P
p
.56085 .49861 m .56531 .50773 L .56322 .50315 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56724 .52836 L p
1 g
F P
s
P
p
.57108 .52041 m .56754 .53305 L .56739 .53068 L 1 g
F
P
p
.56515 .50826 m .56724 .52836 L .56653 .51718 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56171 .54747 L p
1 g
F P
s
P
p
.56432 .54457 m .55215 .571 L .56171 .54747 L 1 g
F
P
p
.56332 .54552 m .56171 .54747 L .56199 .54679 L 1 g
F
P
p
.56432 .54457 m .56171 .54747 L .56332 .54552 L 1 g
F
P
p
.002 w
.56432 .54457 m .56791 .56847 L .55215 .571 L p
1 g
F P
s
P
p
.002 w
.56171 .54747 m .56075 .54566 L p
.55576 .55471 L 1 g
F P
s
P
p
.56654 .52734 m .56171 .54747 L .56262 .54523 L 1 g
F
P
p
.002 w
.56335 .54301 m .56432 .54457 L .56262 .54523 L p
1 g
F P
s
P
p
.56265 .54514 m .56262 .54523 L .56264 .54518 L 1 g
F
P
p
.56654 .52734 m .56262 .54523 L .56265 .54514 L 1 g
F
P
p
.56654 .52734 m .56264 .54518 L .56439 .53911 L 1 g
F
P
p
.002 w
.56262 .54523 m .56432 .54457 L p
.56199 .54679 L 1 g
F P
s
P
p
.56264 .54518 m .56202 .54805 L .56304 .54422 L 1 g
F
P
p
.56264 .54518 m .56304 .54422 L .56439 .53911 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5318 .57504 L p
1 g
F P
s
P
p
.002 w
.52878 .58881 m .51143 .58566 L p
.5318 .57504 L 1 g
F P
s
P
p
.002 w
.53342 .57419 m .53328 .57465 L p
.5318 .57504 L 1 g
F P
s
P
p
.002 w
.53328 .57465 m .52878 .58881 L p
.5318 .57504 L 1 g
F P
s
P
p
.002 w
.5318 .57504 m .53128 .57265 L p
.52109 .57788 L 1 g
F P
s
P
p
.54854 .56129 m .5318 .57504 L .53297 .57443 L 1 g
F
P
p
.54854 .56129 m .53271 .57465 L .53998 .56945 L 1 g
F
P
p
.002 w
.52878 .58881 m .53342 .57419 L p
.56791 .56847 L 1 g
F P
s
P
p
.002 w
.5338 .57395 m .56791 .56847 L p
.53342 .57419 L 1 g
F P
s
P
p
.53271 .57465 m .53187 .57536 L .5338 .57395 L 1 g
F
P
p
.53271 .57465 m .5338 .57395 L .53998 .56945 L 1 g
F
P
p
.002 w
.53342 .57419 m .53348 .574 L .5338 .57395 L p
1 g
F P
s
P
p
.002 w
.51143 .58566 m .49561 .58279 L p
.50357 .58098 L 1 g
F P
s
P
p
.002 w
.51094 .58057 m .51079 .57862 L p
.49725 .58133 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58057 L p
1 g
F P
s
P
p
.5318 .57504 m .5224 .57994 L .51094 .58057 L 1 g
F
P
p
.5224 .57994 m .51143 .58566 L .50357 .58098 L 1 g
F
P
p
.002 w
.51094 .58057 m .51111 .583 L p
.52109 .57788 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .58057 L .52109 .57788 L 1 g
F
P
p
.53342 .57419 m .5318 .57504 L .50357 .58098 L 1 g
F
P
p
.5318 .57504 m .51094 .58057 L .50357 .58098 L 1 g
F
P
p
.002 w
.53348 .574 m .53342 .57419 L p
.49561 .58279 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49561 .58279 m .4956 .5828 L p
.48983 .58095 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58089 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58089 L .48908 .58089 L 1 g
F
P
p
.4956 .5828 m .47484 .57976 L .48904 .58089 L 1 g
F
P
p
.51079 .57862 m .48908 .58089 L .49311 .58118 L 1 g
F
P
p
.4956 .5828 m .48904 .58089 L .48983 .58095 L 1 g
F
P
p
.48908 .58089 m .48904 .58089 L .48988 .58095 L 1 g
F
P
p
.48908 .58089 m .48988 .58095 L .49311 .58118 L 1 g
F
P
p
.45612 .56762 m .45992 .56999 L .46824 .57483 L 1 g
F
P
p
.002 w
.46216 .57137 m .46221 .5721 L .46168 .57104 L p
1 g
F P
s
P
p
.45519 .56724 m .46094 .57068 L .46824 .57483 L 1 g
F
P
p
.002 w
.46242 .57155 m .46221 .5721 L .46216 .57137 L p
1 g
F P
s
P
p
.45415 .56683 m .4625 .57163 L .46824 .57483 L 1 g
F
P
p
.002 w
.46263 .57169 m .46221 .5721 L .46242 .57155 L p
1 g
F P
s
P
p
.002 w
.46283 .57181 m .46221 .5721 L .46263 .57169 L p
1 g
F P
s
P
p
.002 w
.46309 .57197 m .46221 .5721 L .46283 .57181 L p
1 g
F P
s
P
p
.4532 .56645 m .46479 .57292 L .46824 .57483 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46824 .57483 L p
1 g
F P
s
P
p
.48904 .58089 m .47759 .57998 L .46824 .57483 L 1 g
F
P
p
.47759 .57998 m .47484 .57976 L .46824 .57483 L 1 g
F
P
p
.002 w
.46824 .57483 m .4678 .57686 L p
.47815 .57771 L 1 g
F P
s
P
p
.48921 .57862 m .46824 .57483 L .47815 .57771 L 1 g
F
P
p
.002 w
.46529 .57397 m .46221 .5721 L p
.48983 .58095 L 1 g
F P
s
P
p
.48904 .58089 m .46529 .57397 L .48983 .58095 L 1 g
F
P
p
.002 w
.46221 .5721 m .48988 .58095 L p
.48983 .58095 L 1 g
F P
s
P
p
.002 w
.48988 .58095 m .49561 .58279 L p
.48983 .58095 L 1 g
F P
s
P
p
.002 w
.48904 .58089 m .48904 .58089 L p
.48908 .58089 L 1 g
F P
s
P
p
.002 w
.49602 .58139 m .49561 .58279 L .48988 .58095 L p
1 g
F P
s
P
p
.002 w
.48904 .58089 m .48898 .58178 L p
.49311 .58118 L 1 g
F P
s
P
p
.51079 .57862 m .48898 .58178 L .49725 .58133 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49782 .57524 m .49602 .58139 L p
.46479 .57292 L 1 g
F P
s
P
p
.002 w
.48988 .58095 m .46479 .57292 L p
.49602 .58139 L 1 g
F P
s
P
p
.002 w
.49782 .57524 m .53348 .574 L p
.50336 .58099 L 1 g
F P
s
P
p
.002 w
.49561 .58279 m .49602 .58139 L p
.50336 .58099 L 1 g
F P
s
P
p
.002 w
.49602 .58139 m .49782 .57524 L p
.50336 .58099 L 1 g
F P
s
P
p
.002 w
.48898 .58178 m .48889 .583 L p
.49725 .58133 L 1 g
F P
s
P
p
.002 w
.51109 .58264 m .51094 .58057 L p
.49649 .58148 L 1 g
F P
s
P
p
.49725 .58133 m .49649 .58148 L .51094 .58057 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5318 .57504 L p
1 g
F P
s
P
p
.52109 .57788 m .51111 .583 L .5318 .57504 L 1 g
F
P
p
.002 w
.5318 .57504 m .53187 .57536 L p
.53297 .57443 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.55215 .571 m .54086 .57282 L p
.55817 .5562 L 1 g
F P
s
P
p
.002 w
.54086 .57282 m .5338 .57395 L p
.5491 .5628 L 1 g
F P
s
P
p
.55817 .5562 m .54086 .57282 L .5491 .5628 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5491 .5628 L p
1 g
F P
s
P
p
.56075 .54566 m .5491 .5628 L .55576 .55471 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5491 .5628 L p
1 g
F P
s
P
p
.002 w
.5491 .5628 m .54854 .56129 L p
.53998 .56945 L 1 g
F P
s
P
p
.53998 .56945 m .5322 .57686 L .5491 .5628 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56199 .54679 m .55817 .5562 L .53348 .574 L 1 g
F
P
p
.002 w
.5338 .57395 m .53348 .574 L p
.55817 .5562 L 1 g
F P
s
P
p
.002 w
.5491 .5628 m .54998 .56518 L p
.55576 .55471 L 1 g
F P
s
P
p
.002 w
.53187 .57536 m .5322 .57686 L p
.53998 .56945 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.53348 .574 m .53069 .55775 L .56262 .54523 L p
1 g
F P
s
P
p
.56199 .54679 m .53348 .574 L .56262 .54523 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54973 .52101 m .56335 .54301 L p
.53069 .55775 L 1 g
F P
s
P
p
.002 w
.56262 .54523 m .53069 .55775 L p
.56335 .54301 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56171 .54747 L p
1 g
F P
s
P
p
.55576 .55471 m .54998 .56518 L .56171 .54747 L 1 g
F
P
p
.002 w
.56171 .54747 m .56202 .54805 L p
.56264 .54518 L 1 g
F P
s
P
p
.56739 .53068 m .56432 .54457 L .56447 .5388 L 1 g
F
P
p
.56754 .53305 m .56432 .54457 L .56739 .53068 L 1 g
F
P
p
.57108 .52041 m .56447 .5388 L .56999 .51801 L 1 g
F
P
p
.002 w
.56432 .54457 m .56335 .54301 L p
.56447 .5388 L 1 g
F P
s
P
p
.002 w
.57756 .49728 m .59588 .52796 L .56432 .54457 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56724 .52836 L p
1 g
F P
s
P
p
.002 w
.56724 .52836 m .56654 .52734 L p
.56439 .53911 L 1 g
F P
s
P
p
.56439 .53911 m .56257 .5491 L .56724 .52836 L 1 g
F
P
p
.002 w
.54973 .52101 m .56531 .50773 L p
.56447 .5388 L 1 g
F P
s
P
p
.002 w
.56335 .54301 m .54973 .52101 L p
.56447 .5388 L 1 g
F P
s
P
p
.56999 .51801 m .56447 .5388 L .56531 .50773 L 1 g
F
P
p
.002 w
.56724 .52836 m .56854 .53025 L p
.56653 .51718 L 1 g
F P
s
P
p
.002 w
.56202 .54805 m .56257 .5491 L p
.56439 .53911 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56602 .50929 L p
1 g
F P
s
P
p
.56653 .51718 m .56854 .53025 L .56602 .50929 L 1 g
F
P
p
.002 w
.56602 .50929 m .56713 .51061 L p
.56322 .50315 L 1 g
F P
s
P
p
.50989 .4653 m .5228 .46776 L .52196 .46762 L 1 g
F
P
p
.5 .4634 m .51003 .46532 L .50989 .4653 L 1 g
F
P
p
.51003 .46532 m .5228 .46776 L .50989 .4653 L 1 g
F
P
p
.002 w
.52237 .46705 m .5228 .46776 L p
.51003 .46532 L 1 g
F P
s
P
p
.002 w
.52549 .50062 m .49433 .48597 L .50185 .46418 L p
1 g
F P
s
P
p
.002 w
.50185 .46418 m .49433 .48597 L p
.47451 .4595 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50185 .46418 m .50623 .45149 L p
.51175 .46556 L 1 g
F P
s
P
p
.002 w
.46175 .44244 m .50623 .45149 L .50185 .46418 L p
1 g
F P
s
P
p
.46175 .44244 m .50185 .46418 L .47451 .4595 L 1 g
F
P
p
.002 w
.5228 .46776 m .52282 .46778 L p
.52196 .46762 L 1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .46442 L p
.48613 .46583 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.46175 .44244 m .47948 .46613 L .47764 .46703 L 1 g
F
P
p
.46726 .47213 m .46016 .47562 L .45758 .47683 L 1 g
F
P
p
.002 w
.46016 .47562 m .46045 .46948 L p
.47764 .46703 L 1 g
F P
s
P
p
.002 w
.46045 .46948 m .46175 .44244 L p
.47764 .46703 L 1 g
F P
s
P
p
.47948 .46613 m .47991 .46671 L .47764 .46703 L 1 g
F
P
p
.47991 .46671 m .49433 .48597 L .47764 .46703 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46703 L p
1 g
F P
s
P
p
.48613 .46583 m .5 .46442 L .47764 .46703 L 1 g
F
P
p
.46726 .47213 m .47329 .46949 L .46016 .47562 L 1 g
F
P
p
.002 w
.49433 .48597 m .46 .47894 L .46016 .47562 L p
1 g
F P
s
P
p
.002 w
.41874 .44458 m .46175 .44244 L .46016 .47562 L p
1 g
F P
s
P
p
.002 w
.46016 .47562 m .46 .47894 L p
.4575 .47686 L 1 g
F P
s
P
p
.41874 .44458 m .46016 .47562 L .4575 .47686 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45758 .47683 L p
1 g
F P
s
P
p
.47329 .46949 m .47718 .46778 L .45758 .47683 L 1 g
F
P
p
.002 w
.45758 .47683 m .45749 .47692 L p
.45637 .478 L 1 g
F P
s
P
p
.002 w
.42675 .48036 m .41874 .44458 L p
.45752 .47688 L 1 g
F P
s
P
p
.44339 .4905 m .45749 .47692 L .45012 .48405 L 1 g
F
P
p
.002 w
.45519 .47914 m .42675 .48036 L p
.45752 .47688 L 1 g
F P
s
P
p
.002 w
.44847 .47943 m .45519 .47914 L p
.44271 .49122 L 1 g
F P
s
P
p
.002 w
.45519 .47914 m .46 .47894 L p
.44271 .49122 L 1 g
F P
s
P
p
.002 w
.45749 .47692 m .45698 .47747 L p
.45012 .48405 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44271 .49122 L p
1 g
F P
s
P
p
.45012 .48405 m .45698 .47747 L .44271 .49122 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.46 .47894 m .45951 .51353 L p
.44098 .49477 L 1 g
F P
s
P
p
.002 w
.45951 .51353 m .43695 .51435 L .43484 .50733 L p
1 g
F P
s
P
p
.44098 .49477 m .45951 .51353 L .43484 .50733 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43375 .50957 L p
1 g
F P
s
P
p
.002 w
.43375 .50957 m .43384 .50947 L p
.43433 .50838 L 1 g
F P
s
P
p
.43433 .50838 m .44166 .49233 L .43375 .50957 L 1 g
F
P
p
.43911 .4983 m .44166 .49233 L .43384 .50947 L 1 g
F
P
p
.43356 .51219 m .43384 .50947 L .43695 .51435 L 1 g
F
P
p
.002 w
.43484 .50733 m .43695 .51435 L p
.43384 .50947 L 1 g
F P
s
P
p
.002 w
.42913 .51689 m .43323 .51556 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.43351 .50986 m .43287 .51061 L p
.43309 .51687 L 1 g
F P
s
P
p
.43312 .51766 m .43323 .51556 L .43309 .51687 L 1 g
F
P
p
.43323 .51556 m .43351 .50986 L .43309 .51687 L 1 g
F
P
p
.002 w
.43384 .50947 m .43351 .50986 L p
.4335 .5128 L 1 g
F P
s
P
p
.43346 .52734 m .43351 .50986 L .43312 .51766 L 1 g
F
P
p
.002 w
.43695 .51435 m .43323 .51556 L p
.43356 .51219 L 1 g
F P
s
P
p
.43258 .52863 m .43695 .51435 L .43401 .53349 L 1 g
F
P
p
.002 w
.43323 .51556 m .43695 .51435 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43258 .52863 L p
1 g
F P
s
P
p
.43312 .51766 m .43287 .51061 L .43258 .52863 L 1 g
F
P
p
.002 w
.43258 .52863 m .43146 .53025 L p
.43527 .53779 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43695 .51435 m .44893 .54528 L p
.43401 .53349 L 1 g
F P
s
P
p
.43401 .53349 m .44893 .54528 L .43787 .54663 L 1 g
F
P
p
.45146 .56129 m .43819 .54766 L .44144 .55258 L 1 g
F
P
p
.002 w
.40387 .53147 m .41769 .5206 L .43918 .54832 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43819 .54766 L p
1 g
F P
s
P
p
.43482 .53691 m .43146 .53025 L .43819 .54766 L 1 g
F
P
p
.002 w
.43819 .54766 m .43743 .5491 L p
.44144 .55258 L 1 g
F P
s
P
p
.002 w
.43918 .54832 m .43881 .5486 L p
.43838 .54794 L 1 g
F P
s
P
p
.002 w
.43918 .54832 m .46002 .56983 L p
.45078 .56312 L 1 g
F P
s
P
p
.002 w
.43881 .5486 m .43918 .54832 L p
.45078 .56312 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45076 .56316 L p
1 g
F P
s
P
p
.002 w
.45076 .56316 m .45078 .56312 L p
.45033 .56264 L 1 g
F P
s
P
p
.45033 .56264 m .43743 .5491 L .45076 .56316 L 1 g
F
P
p
.44376 .5546 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.458 .56837 m .45796 .56835 L .4581 .56844 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43918 .54832 m .44893 .54528 L .46168 .57104 L p
1 g
F P
s
P
p
.002 w
.46002 .56983 m .43918 .54832 L p
.46168 .57104 L 1 g
F P
s
P
p
.45796 .56835 m .45777 .56828 L .45842 .56868 L 1 g
F
P
p
.45777 .56828 m .45741 .56813 L .45867 .56891 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44893 .54528 m .46027 .54494 L .46216 .57137 L p
1 g
F P
s
P
p
.002 w
.46168 .57104 m .44893 .54528 L p
.46216 .57137 L 1 g
F P
s
P
p
.002 w
.46027 .54494 m .47191 .54735 L .46242 .57155 L p
1 g
F P
s
P
p
.002 w
.46216 .57137 m .46027 .54494 L p
.46242 .57155 L 1 g
F P
s
P
p
.45741 .56813 m .45687 .56791 L .45893 .56917 L 1 g
F
P
p
.45687 .56791 m .45612 .56762 L .4593 .56951 L 1 g
F
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47191 .54735 m .48254 .55225 L .46263 .57169 L p
1 g
F P
s
P
p
.002 w
.46242 .57155 m .47191 .54735 L p
.46263 .57169 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48254 .55225 m .49095 .55907 L .46283 .57181 L p
1 g
F P
s
P
p
.002 w
.46263 .57169 m .48254 .55225 L p
.46283 .57181 L 1 g
F P
s
P
p
.45612 .56762 m .45519 .56724 L .45992 .56999 L 1 g
F
P
p
.45519 .56724 m .45415 .56683 L .46094 .57068 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.49095 .55907 m .49623 .56703 L .46309 .57197 L p
1 g
F P
s
P
p
.002 w
.46283 .57181 m .49095 .55907 L p
.46309 .57197 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49623 .56703 m .49782 .57524 L .46352 .57221 L p
1 g
F P
s
P
p
.002 w
.46352 .57221 m .46221 .5721 L .46309 .57197 L p
1 g
F P
s
P
p
.002 w
.46309 .57197 m .49623 .56703 L p
.46352 .57221 L 1 g
F P
s
P
p
.45415 .56683 m .4532 .56645 L .4625 .57163 L 1 g
F
P
p
.4532 .56645 m .45262 .56622 L .46479 .57292 L 1 g
F
P
p
.002 w
.46479 .57292 m .46221 .5721 L .46352 .57221 L p
1 g
F P
s
P
p
.002 w
.46352 .57221 m .49782 .57524 L p
.46479 .57292 L 1 g
F P
s
P
p
.002 w
.46341 .5734 m .46221 .5721 L .46529 .57397 L p
1 g
F P
s
P
p
.002 w
.43215 .57682 m .42842 .56878 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.42842 .56878 m .42837 .56078 L .46221 .5721 L closepath p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46824 .57483 L p
1 g
F P
s
P
p
.45262 .56622 m .45002 .56518 L .46824 .57483 L 1 g
F
P
p
.002 w
.4899 .58888 m .49561 .58279 L .52878 .58881 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51109 .58264 L p
1 g
F P
s
P
p
.49649 .58148 m .48889 .583 L .51109 .58264 L 1 g
F
P
p
.002 w
.48903 .58108 m .48904 .58089 L p
.47766 .57767 L 1 g
F P
s
P
p
.47815 .57771 m .47766 .57767 L .48904 .58089 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58108 L p
1 g
F P
s
P
p
.47766 .57767 m .4678 .57686 L .48903 .58108 L 1 g
F
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.40387 .53147 m .39689 .54561 L .36883 .52719 L p
1 g
F P
s
P
p
.002 w
.36883 .52719 m .37861 .50622 L .40387 .53147 L p
1 g
F P
s
P
p
.002 w
.59588 .52796 m .5999 .55889 L .56791 .56847 L p
1 g
F P
s
P
p
.002 w
.5999 .55889 m .59588 .52796 L .62425 .50856 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.38254 .45738 m .3572 .47888 L .34034 .45046 L p
1 g
F P
s
P
p
.002 w
.34034 .45046 m .37019 .42422 L .38254 .45738 L p
1 g
F P
s
P
p
.002 w
.6095 .34962 m .65586 .3924 L .6427 .41813 L p
1 g
F P
s
P
p
.002 w
.65586 .3924 m .6095 .34962 L .61725 .32476 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.62489 .44484 m .64847 .48713 L .62425 .50856 L p
1 g
F P
s
P
p
.002 w
.64847 .48713 m .62489 .44484 L .6427 .41813 L p
1 g
F P
s
P
p
.002 w
.4105 .37313 m .36192 .39167 L .35794 .36088 L p
1 g
F P
s
P
p
.002 w
.35794 .36088 m .41052 .34016 L .4105 .37313 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55496 .29375 m .61725 .32476 L .6095 .34962 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.43208 .55369 m .42837 .56078 L .39689 .54561 L p
1 g
F P
s
P
p
.002 w
.39689 .54561 m .40387 .53147 L .43208 .55369 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.56791 .56847 m .56432 .54457 L .59588 .52796 L p
1 g
F P
s
P
p
.002 w
.54793 .3192 m .47935 .30562 L .48549 .28006 L p
1 g
F P
s
P
p
.002 w
.48549 .28006 m .55496 .29375 L .54793 .3192 L p
1 g
F P
s
P
p
.002 w
.39857 .48991 m .37861 .50622 L .3572 .47888 L p
1 g
F P
s
P
p
.002 w
.3572 .47888 m .38254 .45738 L .39857 .48991 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.47369 .33574 m .41052 .34016 L .41323 .31063 L p
1 g
F P
s
P
p
.002 w
.41323 .31063 m .47935 .30562 L .47369 .33574 L p
1 g
F P
s
P
p
.002 w
.6095 .34962 m .54793 .3192 L .55496 .29375 L p
1 g
F P
s
P
p
.002 w
.53069 .55775 m .53348 .574 L .49782 .57524 L p
1 g
F P
s
P
p
.002 w
.60292 .47156 m .62425 .50856 L .59588 .52796 L p
1 g
F P
s
P
p
.002 w
.62425 .50856 m .60292 .47156 L .62489 .44484 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.49782 .57524 m .49623 .56703 L .53069 .55775 L p
1 g
F P
s
P
p
.002 w
.41327 .40837 m .37019 .42422 L .36192 .39167 L p
1 g
F P
s
P
p
.002 w
.36192 .39167 m .4105 .37313 L .41327 .40837 L p
1 g
F P
s
P
p
.002 w
.59816 .37766 m .6427 .41813 L .62489 .44484 L p
1 g
F P
s
P
p
.002 w
.6427 .41813 m .59816 .37766 L .6095 .34962 L p
1 g
F P
s
P
p
.002 w
.41769 .5206 m .40387 .53147 L .37861 .50622 L p
1 g
F P
s
P
p
.002 w
.37861 .50622 m .39857 .48991 L .41769 .5206 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59588 .52796 m .57756 .49728 L .60292 .47156 L p
1 g
F P
s
P
p
.002 w
.49623 .56703 m .49095 .55907 L .52049 .54185 L p
1 g
F P
s
P
p
.002 w
.52049 .54185 m .53069 .55775 L .49623 .56703 L p
1 g
F P
s
P
p
.002 w
.54793 .3192 m .6095 .34962 L .59816 .37766 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.53069 .55775 m .52049 .54185 L .54973 .52101 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41874 .44458 m .38254 .45738 L .37019 .42422 L p
1 g
F P
s
P
p
.002 w
.37019 .42422 m .41327 .40837 L .41874 .44458 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.49095 .55907 m .48254 .55225 L .50389 .52816 L p
1 g
F P
s
P
p
.002 w
.50389 .52816 m .52049 .54185 L .49095 .55907 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46874 .36942 m .4105 .37313 L .41052 .34016 L p
1 g
F P
s
P
p
.002 w
.41052 .34016 m .47369 .33574 L .46874 .36942 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.53923 .34879 m .47369 .33574 L .47935 .30562 L p
1 g
F P
s
P
p
.002 w
.47935 .30562 m .54793 .3192 L .53923 .34879 L p
1 g
F P
s
P
p
.002 w
.58354 .40793 m .62489 .44484 L .60292 .47156 L p
1 g
F P
s
P
p
.002 w
.62489 .44484 m .58354 .40793 L .59816 .37766 L p
1 g
F P
s
P
p
.002 w
.46027 .54494 m .44893 .54528 L .43695 .51435 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48254 .55225 m .47191 .54735 L .48274 .51832 L p
1 g
F P
s
P
p
.002 w
.48274 .51832 m .50389 .52816 L .48254 .55225 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.59816 .37766 m .53923 .34879 L .54793 .3192 L p
1 g
F P
s
P
p
.002 w
.47191 .54735 m .46027 .54494 L .45951 .51353 L p
1 g
F P
s
P
p
.002 w
.43695 .51435 m .45951 .51353 L .46027 .54494 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42675 .48036 m .39857 .48991 L .38254 .45738 L p
1 g
F P
s
P
p
.002 w
.38254 .45738 m .41874 .44458 L .42675 .48036 L p
1 g
F P
s
P
p
.002 w
.45951 .51353 m .48274 .51832 L .47191 .54735 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52049 .54185 m .50389 .52816 L .52549 .50062 L p
1 g
F P
s
P
p
.002 w
.52549 .50062 m .54973 .52101 L .52049 .54185 L p
1 g
F P
s
P
p
.002 w
.53923 .34879 m .59816 .37766 L .58354 .40793 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56611 .43932 m .60292 .47156 L .57756 .49728 L p
1 g
F P
s
P
p
.002 w
.60292 .47156 m .56611 .43932 L .58354 .40793 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4647 .40545 m .41327 .40837 L .4105 .37313 L p
1 g
F P
s
P
p
.002 w
.4105 .37313 m .46874 .36942 L .4647 .40545 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.57756 .49728 m .54651 .47062 L .56611 .43932 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52913 .38153 m .46874 .36942 L .47369 .33574 L p
1 g
F P
s
P
p
.002 w
.47369 .33574 m .53923 .34879 L .52913 .38153 L p
1 g
F P
s
P
p
.002 w
.50389 .52816 m .48274 .51832 L .49433 .48597 L p
1 g
F P
s
P
p
.002 w
.49433 .48597 m .52549 .50062 L .50389 .52816 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.48274 .51832 m .45951 .51353 L .46 .47894 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.58354 .40793 m .52913 .38153 L .53923 .34879 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.46175 .44244 m .41874 .44458 L .41327 .40837 L p
1 g
F P
s
P
p
.002 w
.41327 .40837 m .4647 .40545 L .46175 .44244 L p
1 g
F P
s
P
p
.002 w
.46 .47894 m .49433 .48597 L .48274 .51832 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52913 .38153 m .58354 .40793 L .56611 .43932 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.004 w
.44679 .62988 m
.44949 .61975 L
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.51798 .41621 m .4647 .40545 L .46874 .36942 L p
1 g
F P
s
P
p
.002 w
.46874 .36942 m .52913 .38153 L .51798 .41621 L p
1 g
F P
s
P
p
.002 w
.51798 .41621 m .56611 .43932 L .54651 .47062 L p
1 g
F P
s
P
p
.002 w
.56611 .43932 m .51798 .41621 L .52913 .38153 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54651 .47062 m .50623 .45149 L .51798 .41621 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50623 .45149 m .46175 .44244 L .4647 .40545 L p
1 g
F P
s
P
p
.002 w
.4647 .40545 m .51798 .41621 L .50623 .45149 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .63453 .69686 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4401 .65493 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0271318)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0271318)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4635 .44242 m .49999 .46315 L .51087 .43681 L p
1 g
F P
s
P
p
.002 w
.51087 .43681 m .48047 .41952 L .4635 .44242 L p
1 g
F P
s
P
p
.002 w
.54442 .44548 m .51087 .43681 L .49999 .46315 L p
1 g
F P
s
P
p
.002 w
.48047 .41952 m .51087 .43681 L .52148 .41033 L p
1 g
F P
s
P
p
.002 w
.51087 .43681 m .54442 .44548 L .54753 .41696 L p
1 g
F P
s
P
p
.002 w
.54753 .41696 m .52148 .41033 L .51087 .43681 L p
1 g
F P
s
P
p
.002 w
.43411 .41339 m .4635 .44242 L .48047 .41952 L p
1 g
F P
s
P
p
.002 w
.48047 .41952 m .4561 .39524 L .43411 .41339 L p
1 g
F P
s
P
p
.002 w
.4561 .39524 m .48047 .41952 L .4979 .3969 L p
1 g
F P
s
P
p
.002 w
.52148 .41033 m .4979 .3969 L .48047 .41952 L p
1 g
F P
s
P
p
.002 w
.4979 .3969 m .52148 .41033 L .53164 .38417 L p
1 g
F P
s
P
p
.002 w
.52148 .41033 m .54753 .41696 L .54949 .38866 L p
1 g
F P
s
P
p
.002 w
.54949 .38866 m .53164 .38417 L .52148 .41033 L p
1 g
F P
s
P
p
.002 w
.44729 .4652 m .48904 .48888 L .49999 .46315 L p
1 g
F P
s
P
p
.002 w
.49999 .46315 m .4635 .44242 L .44729 .4652 L p
1 g
F P
s
P
p
.002 w
.54023 .47369 m .49999 .46315 L .48904 .48888 L p
1 g
F P
s
P
p
.002 w
.49999 .46315 m .54023 .47369 L .54442 .44548 L p
1 g
F P
s
P
p
.002 w
.4979 .3969 m .47909 .37799 L .4561 .39524 L p
1 g
F P
s
P
p
.002 w
.47909 .37799 m .4979 .3969 L .51548 .37496 L p
1 g
F P
s
P
p
.002 w
.53164 .38417 m .51548 .37496 L .4979 .3969 L p
1 g
F P
s
P
p
.002 w
.41354 .43213 m .44729 .4652 L .4635 .44242 L p
1 g
F P
s
P
p
.002 w
.4635 .44242 m .43411 .41339 L .41354 .43213 L p
1 g
F P
s
P
p
.002 w
.57793 .4446 m .54442 .44548 L .54023 .47369 L p
1 g
F P
s
P
p
.002 w
.54442 .44548 m .57793 .4446 L .57348 .4161 L p
1 g
F P
s
P
p
.002 w
.57348 .4161 m .54753 .41696 L .54442 .44548 L p
1 g
F P
s
P
p
.002 w
.54753 .41696 m .57348 .4161 L .56723 .38795 L p
1 g
F P
s
P
p
.002 w
.56723 .38795 m .54949 .38866 L .54753 .41696 L p
1 g
F P
s
P
p
.002 w
.51548 .37496 m .53164 .38417 L .54114 .35884 L p
1 g
F P
s
P
p
.002 w
.53164 .38417 m .54949 .38866 L .55026 .3611 L p
1 g
F P
s
P
p
.002 w
.55026 .3611 m .54114 .35884 L .53164 .38417 L p
1 g
F P
s
P
p
.002 w
.41475 .37864 m .43411 .41339 L .4561 .39524 L p
1 g
F P
s
P
p
.002 w
.4561 .39524 m .44022 .36619 L .41475 .37864 L p
1 g
F P
s
P
p
.002 w
.44022 .36619 m .4561 .39524 L .47909 .37799 L p
1 g
F P
s
P
p
.002 w
.47909 .37799 m .46698 .3554 L .44022 .36619 L p
1 g
F P
s
P
p
.002 w
.46698 .3554 m .47909 .37799 L .50266 .36196 L p
1 g
F P
s
P
p
.002 w
.51548 .37496 m .50266 .36196 L .47909 .37799 L p
1 g
F P
s
P
p
.002 w
.50266 .36196 m .51548 .37496 L .53289 .35413 L p
1 g
F P
s
P
p
.002 w
.54114 .35884 m .53289 .35413 L .51548 .37496 L p
1 g
F P
s
P
p
.002 w
.48904 .48888 m .53502 .50108 L .54023 .47369 L p
1 g
F P
s
P
p
.002 w
.5805 .47291 m .54023 .47369 L .53502 .50108 L p
1 g
F P
s
P
p
.002 w
.54023 .47369 m .5805 .47291 L .57793 .4446 L p
1 g
F P
s
P
p
.002 w
.43217 .48742 m .47821 .51351 L .48904 .48888 L p
1 g
F P
s
P
p
.002 w
.48904 .48888 m .44729 .4652 L .43217 .48742 L p
1 g
F P
s
P
p
.002 w
.53502 .50108 m .48904 .48888 L .47821 .51351 L p
1 g
F P
s
P
p
.002 w
.3948 .45111 m .43217 .48742 L .44729 .4652 L p
1 g
F P
s
P
p
.002 w
.44729 .4652 m .41354 .43213 L .3948 .45111 L p
1 g
F P
s
P
p
.002 w
.54949 .38866 m .56723 .38795 L .5593 .36067 L p
1 g
F P
s
P
p
.002 w
.5593 .36067 m .55026 .3611 L .54949 .38866 L p
1 g
F P
s
P
p
.002 w
.39107 .39253 m .41354 .43213 L .43411 .41339 L p
1 g
F P
s
P
p
.002 w
.43411 .41339 m .41475 .37864 L .39107 .39253 L p
1 g
F P
s
P
p
.002 w
.50266 .36196 m .49451 .34646 L .46698 .3554 L p
1 g
F P
s
P
p
.002 w
.49451 .34646 m .50266 .36196 L .52638 .34747 L p
1 g
F P
s
P
p
.002 w
.53289 .35413 m .52638 .34747 L .50266 .36196 L p
1 g
F P
s
P
p
.002 w
.59672 .40767 m .57348 .4161 L .57793 .4446 L p
1 g
F P
s
P
p
.002 w
.57348 .4161 m .59672 .40767 L .58303 .38203 L p
1 g
F P
s
P
p
.002 w
.58303 .38203 m .56723 .38795 L .57348 .4161 L p
1 g
F P
s
P
p
.002 w
.47821 .51351 m .52888 .52712 L .53502 .50108 L p
1 g
F P
s
P
p
.002 w
.58111 .5005 m .53502 .50108 L .52888 .52712 L p
1 g
F P
s
P
p
.002 w
.53502 .50108 m .58111 .5005 L .5805 .47291 L p
1 g
F P
s
P
p
.002 w
.60811 .43401 m .57793 .4446 L .5805 .47291 L p
1 g
F P
s
P
p
.002 w
.57793 .4446 m .60811 .43401 L .59672 .40767 L p
1 g
F P
s
P
p
.002 w
.56723 .38795 m .58303 .38203 L .56729 .35758 L p
1 g
F P
s
P
p
.002 w
.56729 .35758 m .5593 .36067 L .56723 .38795 L p
1 g
F P
s
P
p
.002 w
.43464 .33514 m .44022 .36619 L .46698 .3554 L p
1 g
F P
s
P
p
.002 w
.46698 .3554 m .46293 .33135 L .43464 .33514 L p
1 g
F P
s
P
p
.002 w
.46293 .33135 m .46698 .3554 L .49451 .34646 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .53289 .35413 L .54114 .35884 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .54114 .35884 L .55026 .3611 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .52638 .34747 L .53289 .35413 L closepath p
1 g
F P
s
P
p
.002 w
.49451 .34646 m .49194 .33003 L .46293 .33135 L p
1 g
F P
s
P
p
.002 w
.49194 .33003 m .49451 .34646 L .52229 .33954 L p
1 g
F P
s
P
p
.002 w
.52638 .34747 m .52229 .33954 L .49451 .34646 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .55026 .3611 L .5593 .36067 L closepath p
1 g
F P
s
P
p
.002 w
.41843 .50866 m .46772 .53656 L .47821 .51351 L p
1 g
F P
s
P
p
.002 w
.47821 .51351 m .43217 .48742 L .41843 .50866 L p
1 g
F P
s
P
p
.002 w
.52888 .52712 m .47821 .51351 L .46772 .53656 L p
1 g
F P
s
P
p
.002 w
.36969 .40762 m .3948 .45111 L .41354 .43213 L p
1 g
F P
s
P
p
.002 w
.41354 .43213 m .39107 .39253 L .36969 .40762 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .52229 .33954 L .52638 .34747 L closepath p
1 g
F P
s
P
p
.002 w
.40762 .34136 m .41475 .37864 L .44022 .36619 L p
1 g
F P
s
P
p
.002 w
.44022 .36619 m .43464 .33514 L .40762 .34136 L p
1 g
F P
s
P
p
.002 w
.3783 .46997 m .41843 .50866 L .43217 .48742 L p
1 g
F P
s
P
p
.002 w
.43217 .48742 m .3948 .45111 L .3783 .46997 L p
1 g
F P
s
P
p
.002 w
.61692 .46056 m .5805 .47291 L .58111 .5005 L p
1 g
F P
s
P
p
.002 w
.5805 .47291 m .61692 .46056 L .60811 .43401 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .5593 .36067 L .56729 .35758 L closepath p
1 g
F P
s
P
p
.002 w
.52229 .33954 m .52108 .33119 L .49194 .33003 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .52108 .33119 L .52229 .33954 L closepath p
1 g
F P
s
P
p
.002 w
.59519 .37144 m .58303 .38203 L .59672 .40767 L p
1 g
F P
s
P
p
.002 w
.58303 .38203 m .59519 .37144 L .57338 .35213 L p
1 g
F P
s
P
p
.002 w
.57338 .35213 m .56729 .35758 L .58303 .38203 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .56729 .35758 L .57338 .35213 L closepath p
1 g
F P
s
P
p
.002 w
.61479 .39235 m .59672 .40767 L .60811 .43401 L p
1 g
F P
s
P
p
.002 w
.59672 .40767 m .61479 .39235 L .59519 .37144 L p
1 g
F P
s
P
p
.002 w
.38246 .34994 m .39107 .39253 L .41475 .37864 L p
1 g
F P
s
P
p
.002 w
.41475 .37864 m .40762 .34136 L .38246 .34994 L p
1 g
F P
s
P
p
.002 w
.46761 .30831 m .46293 .33135 L .49194 .33003 L p
1 g
F P
s
P
p
.002 w
.49194 .33003 m .49533 .3144 L .46761 .30831 L p
1 g
F P
s
P
p
.002 w
.49533 .3144 m .49194 .33003 L .52108 .33119 L p
1 g
F P
s
P
p
.002 w
.46772 .53656 m .52189 .55128 L .52888 .52712 L p
1 g
F P
s
P
p
.002 w
.57971 .52682 m .52888 .52712 L .52189 .55128 L p
1 g
F P
s
P
p
.002 w
.52888 .52712 m .57971 .52682 L .58111 .5005 L p
1 g
F P
s
P
p
.002 w
.52108 .33119 m .52291 .3233 L .49533 .3144 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .52291 .3233 L .52108 .33119 L closepath p
1 g
F P
s
P
p
.002 w
.44031 .30522 m .43464 .33514 L .46293 .33135 L p
1 g
F P
s
P
p
.002 w
.46293 .33135 m .46761 .30831 L .44031 .30522 L p
1 g
F P
s
P
p
.002 w
.62295 .48677 m .58111 .5005 L .57971 .52682 L p
1 g
F P
s
P
p
.002 w
.58111 .5005 m .62295 .48677 L .61692 .46056 L p
1 g
F P
s
P
p
.002 w
.35113 .42364 m .3783 .46997 L .3948 .45111 L p
1 g
F P
s
P
p
.002 w
.3948 .45111 m .36969 .40762 L .35113 .42364 L p
1 g
F P
s
P
p
.002 w
.57689 .34489 m .57338 .35213 L .59519 .37144 L p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .57338 .35213 L .57689 .34489 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .57689 .34489 L .57741 .33662 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .57741 .33662 L .57484 .32822 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .57484 .32822 L .56945 .32064 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .56945 .32064 L .56182 .31471 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .56182 .31471 L .55281 .31112 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .55281 .31112 L .54342 .31025 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .54342 .31025 L .5347 .3122 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .5347 .3122 L .52761 .31672 L closepath p
1 g
F P
s
P
p
.002 w
.54981 .3348 m .52761 .31672 L .52291 .3233 L closepath p
1 g
F P
s
P
p
.002 w
.63175 .41447 m .60811 .43401 L .61692 .46056 L p
1 g
F P
s
P
p
.002 w
.60811 .43401 m .63175 .41447 L .61479 .39235 L p
1 g
F P
s
P
p
.002 w
.50445 .30126 m .49533 .3144 L .52291 .3233 L p
1 g
F P
s
P
p
.002 w
.52291 .3233 m .52761 .31672 L .50445 .30126 L p
1 g
F P
s
P
p
.002 w
.4064 .52847 m .45778 .55751 L .46772 .53656 L p
1 g
F P
s
P
p
.002 w
.46772 .53656 m .41843 .50866 L .4064 .52847 L p
1 g
F P
s
P
p
.002 w
.52189 .55128 m .46772 .53656 L .45778 .55751 L p
1 g
F P
s
P
p
.002 w
.60233 .35721 m .59519 .37144 L .61479 .39235 L p
1 g
F P
s
P
p
.002 w
.59519 .37144 m .60233 .35721 L .57689 .34489 L p
1 g
F P
s
P
p
.002 w
.36446 .48831 m .4064 .52847 L .41843 .50866 L p
1 g
F P
s
P
p
.002 w
.41843 .50866 m .3783 .46997 L .36446 .48831 L p
1 g
F P
s
P
p
.002 w
.57741 .33662 m .57689 .34489 L .60233 .35721 L p
1 g
F P
s
P
p
.002 w
.35974 .36076 m .36969 .40762 L .39107 .39253 L p
1 g
F P
s
P
p
.002 w
.39107 .39253 m .38246 .34994 L .35974 .36076 L p
1 g
F P
s
P
p
.002 w
.414 .30525 m .40762 .34136 L .43464 .33514 L p
1 g
F P
s
P
p
.002 w
.43464 .33514 m .44031 .30522 L .414 .30525 L p
1 g
F P
s
P
p
.002 w
.48079 .28881 m .46761 .30831 L .49533 .3144 L p
1 g
F P
s
P
p
.002 w
.49533 .3144 m .50445 .30126 L .48079 .28881 L p
1 g
F P
s
P
p
.002 w
.51842 .29214 m .50445 .30126 L .52761 .31672 L p
1 g
F P
s
P
p
.002 w
.52761 .31672 m .5347 .3122 L .51842 .29214 L p
1 g
F P
s
P
p
.002 w
.64567 .43738 m .61692 .46056 L .62295 .48677 L p
1 g
F P
s
P
p
.002 w
.61692 .46056 m .64567 .43738 L .63175 .41447 L p
1 g
F P
s
P
p
.002 w
.62557 .37155 m .61479 .39235 L .63175 .41447 L p
1 g
F P
s
P
p
.002 w
.61479 .39235 m .62557 .37155 L .60233 .35721 L p
1 g
F P
s
P
p
.002 w
.60233 .35721 m .60354 .34082 L .57741 .33662 L p
1 g
F P
s
P
p
.002 w
.57484 .32822 m .57741 .33662 L .60354 .34082 L p
1 g
F P
s
P
p
.002 w
.45778 .55751 m .51418 .573 L .52189 .55128 L p
1 g
F P
s
P
p
.002 w
.57626 .55128 m .52189 .55128 L .51418 .573 L p
1 g
F P
s
P
p
.002 w
.52189 .55128 m .57626 .55128 L .57971 .52682 L p
1 g
F P
s
P
p
.002 w
.53577 .28813 m .51842 .29214 L .5347 .3122 L p
1 g
F P
s
P
p
.002 w
.5347 .3122 m .54342 .31025 L .53577 .28813 L p
1 g
F P
s
P
p
.002 w
.62597 .5121 m .57971 .52682 L .57626 .55128 L p
1 g
F P
s
P
p
.002 w
.57971 .52682 m .62597 .5121 L .62295 .48677 L p
1 g
F P
s
P
p
.002 w
.60354 .34082 m .60233 .35721 L .62557 .37155 L p
1 g
F P
s
P
p
.002 w
.45711 .2797 m .44031 .30522 L .46761 .30831 L p
1 g
F P
s
P
p
.002 w
.46761 .30831 m .48079 .28881 L .45711 .2797 L p
1 g
F P
s
P
p
.002 w
.60354 .34082 m .59858 .32407 L .57484 .32822 L p
1 g
F P
s
P
p
.002 w
.56945 .32064 m .57484 .32822 L .59858 .32407 L p
1 g
F P
s
P
p
.002 w
.55456 .28979 m .53577 .28813 L .54342 .31025 L p
1 g
F P
s
P
p
.002 w
.54342 .31025 m .55281 .31112 L .55456 .28979 L p
1 g
F P
s
P
p
.002 w
.3359 .44028 m .36446 .48831 L .3783 .46997 L p
1 g
F P
s
P
p
.002 w
.3783 .46997 m .35113 .42364 L .3359 .44028 L p
1 g
F P
s
P
p
.002 w
.3893 .30851 m .38246 .34994 L .40762 .34136 L p
1 g
F P
s
P
p
.002 w
.40762 .34136 m .414 .30525 L .3893 .30851 L p
1 g
F P
s
P
p
.002 w
.50129 .27512 m .48079 .28881 L .50445 .30126 L p
1 g
F P
s
P
p
.002 w
.50445 .30126 m .51842 .29214 L .50129 .27512 L p
1 g
F P
s
P
p
.002 w
.59858 .32407 m .58788 .30887 L .56945 .32064 L p
1 g
F P
s
P
p
.002 w
.56182 .31471 m .56945 .32064 L .58788 .30887 L p
1 g
F P
s
P
p
.002 w
.57263 .29697 m .55456 .28979 L .55281 .31112 L p
1 g
F P
s
P
p
.002 w
.55281 .31112 m .56182 .31471 L .57263 .29697 L p
1 g
F P
s
P
p
.002 w
.58788 .30887 m .57263 .29697 L .56182 .31471 L p
1 g
F P
s
P
p
.002 w
.34007 .37367 m .35113 .42364 L .36969 .40762 L p
1 g
F P
s
P
p
.002 w
.36969 .40762 m .35974 .36076 L .34007 .37367 L p
1 g
F P
s
P
p
.002 w
.64607 .38768 m .63175 .41447 L .64567 .43738 L p
1 g
F P
s
P
p
.002 w
.63175 .41447 m .64607 .38768 L .62557 .37155 L p
1 g
F P
s
P
p
.002 w
.3964 .54637 m .44862 .57586 L .45778 .55751 L p
1 g
F P
s
P
p
.002 w
.45778 .55751 m .4064 .52847 L .3964 .54637 L p
1 g
F P
s
P
p
.002 w
.51418 .573 m .45778 .55751 L .44862 .57586 L p
1 g
F P
s
P
p
.002 w
.65616 .46061 m .62295 .48677 L .62597 .5121 L p
1 g
F P
s
P
p
.002 w
.62295 .48677 m .65616 .46061 L .64567 .43738 L p
1 g
F P
s
P
p
.002 w
.35368 .50572 m .3964 .54637 L .4064 .52847 L p
1 g
F P
s
P
p
.002 w
.4064 .52847 m .36446 .48831 L .35368 .50572 L p
1 g
F P
s
P
p
.002 w
.62557 .37155 m .62763 .3474 L .60354 .34082 L p
1 g
F P
s
P
p
.002 w
.59858 .32407 m .60354 .34082 L .62763 .3474 L p
1 g
F P
s
P
p
.002 w
.62763 .3474 m .62557 .37155 L .64607 .38768 L p
1 g
F P
s
P
p
.002 w
.43392 .27426 m .414 .30525 L .44031 .30522 L p
1 g
F P
s
P
p
.002 w
.44031 .30522 m .45711 .2797 L .43392 .27426 L p
1 g
F P
s
P
p
.002 w
.52697 .26902 m .50129 .27512 L .51842 .29214 L p
1 g
F P
s
P
p
.002 w
.51842 .29214 m .53577 .28813 L .52697 .26902 L p
1 g
F P
s
P
p
.002 w
.36682 .31504 m .35974 .36076 L .38246 .34994 L p
1 g
F P
s
P
p
.002 w
.38246 .34994 m .3893 .30851 L .36682 .31504 L p
1 g
F P
s
P
p
.002 w
.51418 .573 m .57077 .57331 L .57626 .55128 L p
1 g
F P
s
P
p
.002 w
.62584 .53597 m .57626 .55128 L .57077 .57331 L p
1 g
F P
s
P
p
.002 w
.57626 .55128 m .62584 .53597 L .62597 .5121 L p
1 g
F P
s
P
p
.002 w
.48363 .26165 m .45711 .2797 L .48079 .28881 L p
1 g
F P
s
P
p
.002 w
.48079 .28881 m .50129 .27512 L .48363 .26165 L p
1 g
F P
s
P
p
.002 w
.44862 .57586 m .50586 .59173 L .51418 .573 L p
1 g
F P
s
P
p
.002 w
.57077 .57331 m .51418 .573 L .50586 .59173 L p
1 g
F P
s
P
p
.002 w
.62763 .3474 m .62045 .32254 L .59858 .32407 L p
1 g
F P
s
P
p
.002 w
.58788 .30887 m .59858 .32407 L .62045 .32254 L p
1 g
F P
s
P
p
.002 w
.66329 .4053 m .64567 .43738 L .65616 .46061 L p
1 g
F P
s
P
p
.002 w
.64567 .43738 m .66329 .4053 L .64607 .38768 L p
1 g
F P
s
P
p
.002 w
.55495 .27139 m .52697 .26902 L .53577 .28813 L p
1 g
F P
s
P
p
.002 w
.53577 .28813 m .55456 .28979 L .55495 .27139 L p
1 g
F P
s
P
p
.002 w
.32447 .45718 m .35368 .50572 L .36446 .48831 L p
1 g
F P
s
P
p
.002 w
.36446 .48831 m .3359 .44028 L .32447 .45718 L p
1 g
F P
s
P
p
.002 w
.32401 .38847 m .3359 .44028 L .35113 .42364 L p
1 g
F P
s
P
p
.002 w
.35113 .42364 m .34007 .37367 L .32401 .38847 L p
1 g
F P
s
P
p
.002 w
.62045 .32254 m .60464 .29985 L .58788 .30887 L p
1 g
F P
s
P
p
.002 w
.57263 .29697 m .58788 .30887 L .60464 .29985 L p
1 g
F P
s
P
p
.002 w
.66287 .48365 m .62597 .5121 L .62584 .53597 L p
1 g
F P
s
P
p
.002 w
.62597 .5121 m .66287 .48365 L .65616 .46061 L p
1 g
F P
s
P
p
.002 w
.58192 .28208 m .55495 .27139 L .55456 .28979 L p
1 g
F P
s
P
p
.002 w
.55456 .28979 m .57263 .29697 L .58192 .28208 L p
1 g
F P
s
P
p
.002 w
.4118 .27277 m .3893 .30851 L .414 .30525 L p
1 g
F P
s
P
p
.002 w
.414 .30525 m .43392 .27426 L .4118 .27277 L p
1 g
F P
s
P
p
.002 w
.60464 .29985 m .58192 .28208 L .57263 .29697 L p
1 g
F P
s
P
p
.002 w
.64906 .3563 m .64607 .38768 L .66329 .4053 L p
1 g
F P
s
P
p
.002 w
.64607 .38768 m .64906 .3563 L .62763 .3474 L p
1 g
F P
s
P
p
.002 w
.62045 .32254 m .62763 .3474 L .64906 .3563 L p
1 g
F P
s
P
p
.002 w
.38874 .56188 m .44047 .59108 L .44862 .57586 L p
1 g
F P
s
P
p
.002 w
.44862 .57586 m .3964 .54637 L .38874 .56188 L p
1 g
F P
s
P
p
.002 w
.50586 .59173 m .44862 .57586 L .44047 .59108 L p
1 g
F P
s
P
p
.002 w
.51718 .25348 m .48363 .26165 L .50129 .27512 L p
1 g
F P
s
P
p
.002 w
.50129 .27512 m .52697 .26902 L .51718 .25348 L p
1 g
F P
s
P
p
.002 w
.34637 .52176 m .38874 .56188 L .3964 .54637 L p
1 g
F P
s
P
p
.002 w
.3964 .54637 m .35368 .50572 L .34637 .52176 L p
1 g
F P
s
P
p
.002 w
.3472 .32483 m .34007 .37367 L .35974 .36076 L p
1 g
F P
s
P
p
.002 w
.35974 .36076 m .36682 .31504 L .3472 .32483 L p
1 g
F P
s
P
p
.002 w
.46584 .25218 m .43392 .27426 L .45711 .2797 L p
1 g
F P
s
P
p
.002 w
.45711 .2797 m .48363 .26165 L .46584 .25218 L p
1 g
F P
s
P
p
.002 w
.67673 .42406 m .65616 .46061 L .66287 .48365 L p
1 g
F P
s
P
p
.002 w
.65616 .46061 m .67673 .42406 L .66329 .4053 L p
1 g
F P
s
P
p
.002 w
.50586 .59173 m .56327 .59232 L .57077 .57331 L p
1 g
F P
s
P
p
.002 w
.62241 .55778 m .57077 .57331 L .56327 .59232 L p
1 g
F P
s
P
p
.002 w
.57077 .57331 m .62241 .55778 L .62584 .53597 L p
1 g
F P
s
P
p
.002 w
.44047 .59108 m .49711 .60689 L .50586 .59173 L p
1 g
F P
s
P
p
.002 w
.56327 .59232 m .50586 .59173 L .49711 .60689 L p
1 g
F P
s
P
p
.002 w
.64906 .3563 m .63989 .32377 L .62045 .32254 L p
1 g
F P
s
P
p
.002 w
.60464 .29985 m .62045 .32254 L .63989 .32377 L p
1 g
F P
s
P
p
.002 w
.55391 .25649 m .51718 .25348 L .52697 .26902 L p
1 g
F P
s
P
p
.002 w
.52697 .26902 m .55495 .27139 L .55391 .25649 L p
1 g
F P
s
P
p
.002 w
.66548 .50596 m .62584 .53597 L .62241 .55778 L p
1 g
F P
s
P
p
.002 w
.62584 .53597 m .66548 .50596 L .66287 .48365 L p
1 g
F P
s
P
p
.002 w
.31213 .40487 m .32447 .45718 L .3359 .44028 L p
1 g
F P
s
P
p
.002 w
.3359 .44028 m .32401 .38847 L .31213 .40487 L p
1 g
F P
s
P
p
.002 w
.31732 .47396 m .34637 .52176 L .35368 .50572 L p
1 g
F P
s
P
p
.002 w
.35368 .50572 m .32447 .45718 L .31732 .47396 L p
1 g
F P
s
P
p
.002 w
.39131 .27545 m .36682 .31504 L .3893 .30851 L p
1 g
F P
s
P
p
.002 w
.3893 .30851 m .4118 .27277 L .39131 .27545 L p
1 g
F P
s
P
p
.002 w
.66723 .36741 m .66329 .4053 L .67673 .42406 L p
1 g
F P
s
P
p
.002 w
.66329 .4053 m .66723 .36741 L .64906 .3563 L p
1 g
F P
s
P
p
.002 w
.63989 .32377 m .64906 .3563 L .66723 .36741 L p
1 g
F P
s
P
p
.002 w
.63989 .32377 m .61926 .29395 L .60464 .29985 L p
1 g
F P
s
P
p
.002 w
.58192 .28208 m .60464 .29985 L .61926 .29395 L p
1 g
F P
s
P
p
.002 w
.5894 .27054 m .55391 .25649 L .55495 .27139 L p
1 g
F P
s
P
p
.002 w
.55495 .27139 m .58192 .28208 L .5894 .27054 L p
1 g
F P
s
P
p
.002 w
.61926 .29395 m .5894 .27054 L .58192 .28208 L p
1 g
F P
s
P
p
.002 w
.44834 .24717 m .4118 .27277 L .43392 .27426 L p
1 g
F P
s
P
p
.002 w
.43392 .27426 m .46584 .25218 L .44834 .24717 L p
1 g
F P
s
P
p
.002 w
.50655 .24209 m .46584 .25218 L .48363 .26165 L p
1 g
F P
s
P
p
.002 w
.48363 .26165 m .51718 .25348 L .50655 .24209 L p
1 g
F P
s
P
p
.002 w
.33105 .33779 m .32401 .38847 L .34007 .37367 L p
1 g
F P
s
P
p
.002 w
.34007 .37367 m .3472 .32483 L .33105 .33779 L p
1 g
F P
s
P
p
.002 w
.38373 .57451 m .43358 .60263 L .44047 .59108 L p
1 g
F P
s
P
p
.002 w
.44047 .59108 m .38874 .56188 L .38373 .57451 L p
1 g
F P
s
P
p
.002 w
.49711 .60689 m .44047 .59108 L .43358 .60263 L p
1 g
F P
s
P
p
.002 w
.68589 .44357 m .66287 .48365 L .66548 .50596 L p
1 g
F P
s
P
p
.002 w
.66287 .48365 m .68589 .44357 L .67673 .42406 L p
1 g
F P
s
P
p
.002 w
.34288 .53598 m .38373 .57451 L .38874 .56188 L p
1 g
F P
s
P
p
.002 w
.38874 .56188 m .34637 .52176 L .34288 .53598 L p
1 g
F P
s
P
p
.002 w
.49711 .60689 m .55383 .60769 L .56327 .59232 L p
1 g
F P
s
P
p
.002 w
.61561 .57691 m .56327 .59232 L .55383 .60769 L p
1 g
F P
s
P
p
.002 w
.56327 .59232 m .61561 .57691 L .62241 .55778 L p
1 g
F P
s
P
p
.002 w
.66723 .36741 m .65632 .32789 L .63989 .32377 L p
1 g
F P
s
P
p
.002 w
.61926 .29395 m .63989 .32377 L .65632 .32789 L p
1 g
F P
s
P
p
.002 w
.37308 .28243 m .3472 .32483 L .36682 .31504 L p
1 g
F P
s
P
p
.002 w
.36682 .31504 m .39131 .27545 L .37308 .28243 L p
1 g
F P
s
P
p
.002 w
.43358 .60263 m .4881 .61794 L .49711 .60689 L p
1 g
F P
s
P
p
.002 w
.55383 .60769 m .49711 .60689 L .4881 .61794 L p
1 g
F P
s
P
p
.002 w
.66375 .52696 m .62241 .55778 L .61561 .57691 L p
1 g
F P
s
P
p
.002 w
.62241 .55778 m .66375 .52696 L .66548 .50596 L p
1 g
F P
s
P
p
.002 w
.68156 .38058 m .67673 .42406 L .68589 .44357 L p
1 g
F P
s
P
p
.002 w
.67673 .42406 m .68156 .38058 L .66723 .36741 L p
1 g
F P
s
P
p
.002 w
.30495 .42255 m .31732 .47396 L .32447 .45718 L p
1 g
F P
s
P
p
.002 w
.32447 .45718 m .31213 .40487 L .30495 .42255 L p
1 g
F P
s
P
p
.002 w
.55138 .24568 m .50655 .24209 L .51718 .25348 L p
1 g
F P
s
P
p
.002 w
.51718 .25348 m .55391 .25649 L .55138 .24568 L p
1 g
F P
s
P
p
.002 w
.31487 .49019 m .34288 .53598 L .34637 .52176 L p
1 g
F P
s
P
p
.002 w
.34637 .52176 m .31732 .47396 L .31487 .49019 L p
1 g
F P
s
P
p
.002 w
.65632 .32789 m .66723 .36741 L .68156 .38058 L p
1 g
F P
s
P
p
.002 w
.4316 .24697 m .39131 .27545 L .4118 .27277 L p
1 g
F P
s
P
p
.002 w
.4118 .27277 m .44834 .24717 L .4316 .24697 L p
1 g
F P
s
P
p
.002 w
.31899 .35374 m .31213 .40487 L .32401 .38847 L p
1 g
F P
s
P
p
.002 w
.32401 .38847 m .33105 .33779 L .31899 .35374 L p
1 g
F P
s
P
p
.002 w
.65632 .32789 m .63125 .29148 L .61926 .29395 L p
1 g
F P
s
P
p
.002 w
.5894 .27054 m .61926 .29395 L .63125 .29148 L p
1 g
F P
s
P
p
.002 w
.49533 .23537 m .44834 .24717 L .46584 .25218 L p
1 g
F P
s
P
p
.002 w
.46584 .25218 m .50655 .24209 L .49533 .23537 L p
1 g
F P
s
P
p
.002 w
.69033 .46337 m .66548 .50596 L .66375 .52696 L p
1 g
F P
s
P
p
.002 w
.66548 .50596 m .69033 .46337 L .68589 .44357 L p
1 g
F P
s
P
p
.002 w
.59478 .26284 m .55138 .24568 L .55391 .25649 L p
1 g
F P
s
P
p
.002 w
.55391 .25649 m .5894 .27054 L .59478 .26284 L p
1 g
F P
s
P
p
.002 w
.63125 .29148 m .59478 .26284 L .5894 .27054 L p
1 g
F P
s
P
p
.002 w
.38167 .58377 m .4282 .61001 L .43358 .60263 L p
1 g
F P
s
P
p
.002 w
.43358 .60263 m .38373 .57451 L .38167 .58377 L p
1 g
F P
s
P
p
.002 w
.4881 .61794 m .43358 .60263 L .4282 .61001 L p
1 g
F P
s
P
p
.002 w
.34353 .5479 m .38167 .58377 L .38373 .57451 L p
1 g
F P
s
P
p
.002 w
.38373 .57451 m .34288 .53598 L .34353 .5479 L p
1 g
F P
s
P
p
.002 w
.4881 .61794 m .54258 .61886 L .55383 .60769 L p
1 g
F P
s
P
p
.002 w
.60546 .59276 m .55383 .60769 L .54258 .61886 L p
1 g
F P
s
P
p
.002 w
.55383 .60769 m .60546 .59276 L .61561 .57691 L p
1 g
F P
s
P
p
.002 w
.35771 .29377 m .33105 .33779 L .3472 .32483 L p
1 g
F P
s
P
p
.002 w
.3472 .32483 m .37308 .28243 L .35771 .29377 L p
1 g
F P
s
P
p
.002 w
.69147 .39558 m .68589 .44357 L .69033 .46337 L p
1 g
F P
s
P
p
.002 w
.68589 .44357 m .69147 .39558 L .68156 .38058 L p
1 g
F P
s
P
p
.002 w
.65749 .54604 m .61561 .57691 L .60546 .59276 L p
1 g
F P
s
P
p
.002 w
.61561 .57691 m .65749 .54604 L .66375 .52696 L p
1 g
F P
s
P
p
.002 w
.68156 .38058 m .66913 .33495 L .65632 .32789 L p
1 g
F P
s
P
p
.002 w
.63125 .29148 m .65632 .32789 L .66913 .33495 L p
1 g
F P
s
P
p
.002 w
.30291 .44108 m .31487 .49019 L .31732 .47396 L p
1 g
F P
s
P
p
.002 w
.31732 .47396 m .30495 .42255 L .30291 .44108 L p
1 g
F P
s
P
p
.002 w
.4282 .61001 m .47904 .62434 L .4881 .61794 L p
1 g
F P
s
P
p
.002 w
.54258 .61886 m .4881 .61794 L .47904 .62434 L p
1 g
F P
s
P
p
.002 w
.66913 .33495 m .68156 .38058 L .69147 .39558 L p
1 g
F P
s
P
p
.002 w
.54733 .23948 m .49533 .23537 L .50655 .24209 L p
1 g
F P
s
P
p
.002 w
.50655 .24209 m .55138 .24568 L .54733 .23948 L p
1 g
F P
s
P
p
.002 w
.31744 .5054 m .34353 .5479 L .34288 .53598 L p
1 g
F P
s
P
p
.002 w
.34288 .53598 m .31487 .49019 L .31744 .5054 L p
1 g
F P
s
P
p
.002 w
.41612 .25187 m .37308 .28243 L .39131 .27545 L p
1 g
F P
s
P
p
.002 w
.39131 .27545 m .4316 .24697 L .41612 .25187 L p
1 g
F P
s
P
p
.002 w
.31155 .37239 m .30495 .42255 L .31213 .40487 L p
1 g
F P
s
P
p
.002 w
.31213 .40487 m .31899 .35374 L .31155 .37239 L p
1 g
F P
s
P
p
.002 w
.68969 .48297 m .66375 .52696 L .65749 .54604 L p
1 g
F P
s
P
p
.002 w
.66375 .52696 m .68969 .48297 L .69033 .46337 L p
1 g
F P
s
P
p
.002 w
.48378 .23379 m .4316 .24697 L .44834 .24717 L p
1 g
F P
s
P
p
.002 w
.44834 .24717 m .49533 .23537 L .48378 .23379 L p
1 g
F P
s
P
p
.002 w
.66913 .33495 m .64016 .29271 L .63125 .29148 L p
1 g
F P
s
P
p
.002 w
.59478 .26284 m .63125 .29148 L .64016 .29271 L p
1 g
F P
s
P
p
.002 w
.59779 .25941 m .54733 .23948 L .55138 .24568 L p
1 g
F P
s
P
p
.002 w
.55138 .24568 m .59478 .26284 L .59779 .25941 L p
1 g
F P
s
P
p
.002 w
.64016 .29271 m .59779 .25941 L .59478 .26284 L p
1 g
F P
s
P
p
.002 w
.3458 .30936 m .31899 .35374 L .33105 .33779 L p
1 g
F P
s
P
p
.002 w
.33105 .33779 m .35771 .29377 L .3458 .30936 L p
1 g
F P
s
P
p
.002 w
.47904 .62434 m .52972 .62528 L .54258 .61886 L p
1 g
F P
s
P
p
.002 w
.59203 .60472 m .54258 .61886 L .52972 .62528 L p
1 g
F P
s
P
p
.002 w
.54258 .61886 m .59203 .60472 L .60546 .59276 L p
1 g
F P
s
P
p
.002 w
.69645 .4121 m .69033 .46337 L .68969 .48297 L p
1 g
F P
s
P
p
.002 w
.69033 .46337 m .69645 .4121 L .69147 .39558 L p
1 g
F P
s
P
p
.002 w
.38278 .58919 m .42457 .61275 L .4282 .61001 L p
1 g
F P
s
P
p
.002 w
.4282 .61001 m .38167 .58377 L .38278 .58919 L p
1 g
F P
s
P
p
.002 w
.47904 .62434 m .4282 .61001 L .42457 .61275 L p
1 g
F P
s
P
p
.002 w
.64666 .5626 m .60546 .59276 L .59203 .60472 L p
1 g
F P
s
P
p
.002 w
.60546 .59276 m .64666 .5626 L .65749 .54604 L p
1 g
F P
s
P
p
.002 w
.34857 .55705 m .38278 .58919 L .38167 .58377 L p
1 g
F P
s
P
p
.002 w
.38167 .58377 m .34353 .5479 L .34857 .55705 L p
1 g
F P
s
P
p
.002 w
.69147 .39558 m .67779 .34493 L .66913 .33495 L p
1 g
F P
s
P
p
.002 w
.64016 .29271 m .66913 .33495 L .67779 .34493 L p
1 g
F P
s
P
p
.002 w
.30636 .45999 m .31744 .5054 L .31487 .49019 L p
1 g
F P
s
P
p
.002 w
.31487 .49019 m .30291 .44108 L .30636 .45999 L p
1 g
F P
s
P
p
.002 w
.67779 .34493 m .69147 .39558 L .69645 .4121 L p
1 g
F P
s
P
p
.002 w
.42457 .61275 m .47018 .62563 L .47904 .62434 L p
1 g
F P
s
P
p
.002 w
.52972 .62528 m .47904 .62434 L .47018 .62563 L p
1 g
F P
s
P
p
.002 w
.40242 .26203 m .35771 .29377 L .37308 .28243 L p
1 g
F P
s
P
p
.002 w
.37308 .28243 m .41612 .25187 L .40242 .26203 L p
1 g
F P
s
P
p
.002 w
.54177 .23837 m .48378 .23379 L .49533 .23537 L p
1 g
F P
s
P
p
.002 w
.49533 .23537 m .54733 .23948 L .54177 .23837 L p
1 g
F P
s
P
p
.002 w
.30921 .39335 m .30291 .44108 L .30495 .42255 L p
1 g
F P
s
P
p
.002 w
.30495 .42255 m .31155 .37239 L .30921 .39335 L p
1 g
F P
s
P
p
.002 w
.65749 .54604 m .68373 .50179 L .68969 .48297 L p
1 g
F P
s
P
p
.002 w
.68373 .50179 m .65749 .54604 L .64666 .5626 L p
1 g
F P
s
P
p
.002 w
.32526 .51909 m .34857 .55705 L .34353 .5479 L p
1 g
F P
s
P
p
.002 w
.34353 .5479 m .31744 .5054 L .32526 .51909 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50822 .62526 L
s
P
p
.004 w
.50828 .62669 m
.51253 .72742 L
s
P
p
.002 w
.4722 .23773 m .41612 .25187 L .4316 .24697 L p
1 g
F P
s
P
p
.002 w
.4316 .24697 m .48378 .23379 L .4722 .23773 L p
1 g
F P
s
P
p
.002 w
.67779 .34493 m .64552 .29786 L .64016 .29271 L p
1 g
F P
s
P
p
.002 w
.59779 .25941 m .64016 .29271 L .64552 .29786 L p
1 g
F P
s
P
p
.002 w
.33788 .32898 m .31155 .37239 L .31899 .35374 L p
1 g
F P
s
P
p
.002 w
.31899 .35374 m .3458 .30936 L .33788 .32898 L p
1 g
F P
s
P
p
.002 w
.59817 .26066 m .54177 .23837 L .54733 .23948 L p
1 g
F P
s
P
p
.002 w
.54733 .23948 m .59779 .25941 L .59817 .26066 L p
1 g
F P
s
P
p
.002 w
.68969 .48297 m .69609 .42977 L .69645 .4121 L p
1 g
F P
s
P
p
.002 w
.69609 .42977 m .68969 .48297 L .68373 .50179 L p
1 g
F P
s
P
p
.002 w
.52972 .62528 m .57552 .61223 L .59203 .60472 L p
1 g
F P
s
P
p
.002 w
.59203 .60472 m .63131 .57601 L .64666 .5626 L p
1 g
F P
s
P
p
.002 w
.63131 .57601 m .59203 .60472 L .57552 .61223 L p
1 g
F P
s
P
p
.002 w
.47018 .62563 m .5155 .62649 L .52972 .62528 L p
1 g
F P
s
P
p
.004 w
.50826 .62635 m
.50828 .62669 L
s
P
p
.002 w
.57552 .61223 m .52972 .62528 L .5155 .62649 L p
1 g
F P
s
P
p
.002 w
.64552 .29786 m .59817 .26066 L .59779 .25941 L p
1 g
F P
s
P
p
.002 w
.38725 .59037 m .42291 .61048 L .42457 .61275 L p
1 g
F P
s
P
p
.002 w
.42457 .61275 m .38278 .58919 L .38725 .59037 L p
1 g
F P
s
P
p
.002 w
.47018 .62563 m .42457 .61275 L .42291 .61048 L p
1 g
F P
s
P
p
.002 w
.35812 .56299 m .38725 .59037 L .38278 .58919 L p
1 g
F P
s
P
p
.002 w
.38278 .58919 m .34857 .55705 L .35812 .56299 L p
1 g
F P
s
P
p
.002 w
.69645 .4121 m .68178 .35774 L .67779 .34493 L p
1 g
F P
s
P
p
.002 w
.68178 .35774 m .69645 .4121 L .69609 .42977 L p
1 g
F P
s
P
p
.002 w
.64552 .29786 m .67779 .34493 L .68178 .35774 L p
1 g
F P
s
P
p
.002 w
.31549 .47873 m .32526 .51909 L .31744 .5054 L p
1 g
F P
s
P
p
.002 w
.31744 .5054 m .30636 .45999 L .31549 .47873 L p
1 g
F P
s
P
p
.002 w
.39103 .27744 m .3458 .30936 L .35771 .29377 L p
1 g
F P
s
P
p
.002 w
.35771 .29377 m .40242 .26203 L .39103 .27744 L p
1 g
F P
s
P
p
.002 w
.67233 .51925 m .64666 .5626 L .63131 .57601 L p
1 g
F P
s
P
p
.002 w
.64666 .5626 m .67233 .51925 L .68373 .50179 L p
1 g
F P
s
P
p
.002 w
.31229 .41608 m .30636 .45999 L .30291 .44108 L p
1 g
F P
s
P
p
.002 w
.30291 .44108 m .30921 .39335 L .31229 .41608 L p
1 g
F P
s
P
p
.002 w
.42291 .61048 m .46178 .62145 L .47018 .62563 L p
1 g
F P
s
P
p
.002 w
.5155 .62649 m .47018 .62563 L .46178 .62145 L p
1 g
F P
s
P
p
.002 w
.53478 .24273 m .4722 .23773 L .48378 .23379 L p
1 g
F P
s
P
p
.002 w
.48378 .23379 m .54177 .23837 L .53478 .24273 L p
1 g
F P
s
P
p
.002 w
.46095 .2474 m .40242 .26203 L .41612 .25187 L p
1 g
F P
s
P
p
.002 w
.41612 .25187 m .4722 .23773 L .46095 .2474 L p
1 g
F P
s
P
p
.002 w
.3384 .53076 m .35812 .56299 L .34857 .55705 L p
1 g
F P
s
P
p
.002 w
.34857 .55705 m .32526 .51909 L .3384 .53076 L p
1 g
F P
s
P
p
.002 w
.33442 .35221 m .30921 .39335 L .31155 .37239 L p
1 g
F P
s
P
p
.002 w
.31155 .37239 m .33788 .32898 L .33442 .35221 L p
1 g
F P
s
P
p
.002 w
.69009 .44811 m .68373 .50179 L .67233 .51925 L p
1 g
F P
s
P
p
.002 w
.68373 .50179 m .69009 .44811 L .69609 .42977 L p
1 g
F P
s
P
p
.002 w
.68178 .35774 m .64695 .30703 L .64552 .29786 L p
1 g
F P
s
P
p
.002 w
.59817 .26066 m .64552 .29786 L .64695 .30703 L p
1 g
F P
s
P
p
.002 w
.5155 .62649 m .55625 .61483 L .57552 .61223 L p
1 g
F P
s
P
p
.002 w
.61166 .58571 m .57552 .61223 L .55625 .61483 L p
1 g
F P
s
P
p
.002 w
.57552 .61223 m .61166 .58571 L .63131 .57601 L p
1 g
F P
s
P
p
.002 w
.59575 .26684 m .53478 .24273 L .54177 .23837 L p
1 g
F P
s
P
p
.002 w
.54177 .23837 m .59817 .26066 L .59575 .26684 L p
1 g
F P
s
P
p
.002 w
.46178 .62145 m .50028 .62214 L .5155 .62649 L p
1 g
F P
s
P
p
.002 w
.55625 .61483 m .5155 .62649 L .50028 .62214 L p
1 g
F P
s
P
p
.002 w
.64695 .30703 m .59575 .26684 L .59817 .26066 L p
1 g
F P
s
P
p
.002 w
.38242 .29789 m .33788 .32898 L .3458 .30936 L p
1 g
F P
s
P
p
.002 w
.3458 .30936 m .39103 .27744 L .38242 .29789 L p
1 g
F P
s
P
p
.002 w
.68071 .37315 m .69609 .42977 L .69009 .44811 L p
1 g
F P
s
P
p
.002 w
.69609 .42977 m .68071 .37315 L .68178 .35774 L p
1 g
F P
s
P
p
.002 w
.65556 .53473 m .63131 .57601 L .61166 .58571 L p
1 g
F P
s
P
p
.002 w
.63131 .57601 m .65556 .53473 L .67233 .51925 L p
1 g
F P
s
P
p
.002 w
.33031 .4967 m .3384 .53076 L .32526 .51909 L p
1 g
F P
s
P
p
.002 w
.32526 .51909 m .31549 .47873 L .33031 .4967 L p
1 g
F P
s
P
p
.002 w
.32097 .43995 m .31549 .47873 L .30636 .45999 L p
1 g
F P
s
P
p
.002 w
.30636 .45999 m .31229 .41608 L .32097 .43995 L p
1 g
F P
s
P
p
.002 w
.64695 .30703 m .68178 .35774 L .68071 .37315 L p
1 g
F P
s
P
p
.002 w
.39517 .587 m .42339 .60291 L .42291 .61048 L p
1 g
F P
s
P
p
.002 w
.42291 .61048 m .38725 .59037 L .39517 .587 L p
1 g
F P
s
P
p
.002 w
.46178 .62145 m .42291 .61048 L .42339 .60291 L p
1 g
F P
s
P
p
.002 w
.37219 .56533 m .39517 .587 L .38725 .59037 L p
1 g
F P
s
P
p
.002 w
.38725 .59037 m .35812 .56299 L .37219 .56533 L p
1 g
F P
s
P
p
.002 w
.52646 .25276 m .46095 .2474 L .4722 .23773 L p
1 g
F P
s
P
p
.002 w
.4722 .23773 m .53478 .24273 L .52646 .25276 L p
1 g
F P
s
P
p
.002 w
.42339 .60291 m .45414 .61156 L .46178 .62145 L p
1 g
F P
s
P
p
.002 w
.50028 .62214 m .46178 .62145 L .45414 .61156 L p
1 g
F P
s
P
p
.002 w
.45042 .26284 m .39103 .27744 L .40242 .26203 L p
1 g
F P
s
P
p
.002 w
.40242 .26203 m .46095 .2474 L .45042 .26284 L p
1 g
F P
s
P
p
.002 w
.33574 .37847 m .31229 .41608 L .30921 .39335 L p
1 g
F P
s
P
p
.002 w
.30921 .39335 m .33442 .35221 L .33574 .37847 L p
1 g
F P
s
P
p
.002 w
.35676 .53994 m .37219 .56533 L .35812 .56299 L p
1 g
F P
s
P
p
.002 w
.35812 .56299 m .3384 .53076 L .35676 .53994 L p
1 g
F P
s
P
p
.002 w
.67834 .46659 m .67233 .51925 L .65556 .53473 L p
1 g
F P
s
P
p
.002 w
.67233 .51925 m .67834 .46659 L .69009 .44811 L p
1 g
F P
s
P
p
.002 w
.50028 .62214 m .53466 .61218 L .55625 .61483 L p
1 g
F P
s
P
p
.002 w
.58812 .59122 m .55625 .61483 L .53466 .61218 L p
1 g
F P
s
P
p
.002 w
.55625 .61483 m .58812 .59122 L .61166 .58571 L p
1 g
F P
s
P
p
.002 w
.68071 .37315 m .64415 .32019 L .64695 .30703 L p
1 g
F P
s
P
p
.002 w
.59575 .26684 m .64695 .30703 L .64415 .32019 L p
1 g
F P
s
P
p
.002 w
.45414 .61156 m .48446 .61203 L .50028 .62214 L p
1 g
F P
s
P
p
.002 w
.53466 .61218 m .50028 .62214 L .48446 .61203 L p
1 g
F P
s
P
p
.002 w
.37705 .32295 m .33442 .35221 L .33788 .32898 L p
1 g
F P
s
P
p
.002 w
.33788 .32898 m .38242 .29789 L .37705 .32295 L p
1 g
F P
s
P
p
.002 w
.6337 .54765 m .61166 .58571 L .58812 .59122 L p
1 g
F P
s
P
p
.002 w
.61166 .58571 m .6337 .54765 L .65556 .53473 L p
1 g
F P
s
P
p
.002 w
.59042 .2781 m .52646 .25276 L .53478 .24273 L p
1 g
F P
s
P
p
.002 w
.53478 .24273 m .59575 .26684 L .59042 .2781 L p
1 g
F P
s
P
p
.002 w
.67429 .39085 m .69009 .44811 L .67834 .46659 L p
1 g
F P
s
P
p
.002 w
.69009 .44811 m .67429 .39085 L .68071 .37315 L p
1 g
F P
s
P
p
.002 w
.3352 .46421 m .33031 .4967 L .31549 .47873 L p
1 g
F P
s
P
p
.002 w
.31549 .47873 m .32097 .43995 L .3352 .46421 L p
1 g
F P
s
P
p
.002 w
.35061 .51327 m .35676 .53994 L .3384 .53076 L p
1 g
F P
s
P
p
.002 w
.3384 .53076 m .33031 .4967 L .35061 .51327 L p
1 g
F P
s
P
p
.002 w
.64415 .32019 m .59042 .2781 L .59575 .26684 L p
1 g
F P
s
P
p
.002 w
.64415 .32019 m .68071 .37315 L .67429 .39085 L p
1 g
F P
s
P
p
.002 w
.40651 .57887 m .42615 .58995 L .42339 .60291 L p
1 g
F P
s
P
p
.002 w
.42339 .60291 m .39517 .587 L .40651 .57887 L p
1 g
F P
s
P
p
.004 w
.40219 .61847 m
.41323 .59724 L
s
P
p
.002 w
.45414 .61156 m .42339 .60291 L .42615 .58995 L p
1 g
F P
s
P
p
.002 w
.39058 .56378 m .40651 .57887 L .39517 .587 L p
1 g
F P
s
P
p
.002 w
.39517 .587 m .37219 .56533 L .39058 .56378 L p
1 g
F P
s
P
p
.002 w
.34201 .407 m .32097 .43995 L .31229 .41608 L p
1 g
F P
s
P
p
.002 w
.31229 .41608 m .33574 .37847 L .34201 .407 L p
1 g
F P
s
P
p
.002 w
.44099 .28385 m .38242 .29789 L .39103 .27744 L p
1 g
F P
s
P
p
.002 w
.39103 .27744 m .45042 .26284 L .44099 .28385 L p
1 g
F P
s
P
p
.002 w
.66091 .48461 m .65556 .53473 L .6337 .54765 L p
1 g
F P
s
P
p
.002 w
.65556 .53473 m .66091 .48461 L .67834 .46659 L p
1 g
F P
s
P
p
.002 w
.51703 .2685 m .45042 .26284 L .46095 .2474 L p
1 g
F P
s
P
p
.002 w
.46095 .2474 m .52646 .25276 L .51703 .2685 L p
1 g
F P
s
P
p
.002 w
.42615 .58995 m .44754 .59593 L .45414 .61156 L p
1 g
F P
s
P
p
.002 w
.48446 .61203 m .45414 .61156 L .44754 .59593 L p
1 g
F P
s
P
p
.002 w
.37999 .54618 m .39058 .56378 L .37219 .56533 L p
1 g
F P
s
P
p
.002 w
.37219 .56533 m .35676 .53994 L .37999 .54618 L p
1 g
F P
s
P
p
.002 w
.48446 .61203 m .51134 .60408 L .53466 .61218 L p
1 g
F P
s
P
p
.002 w
.56128 .59214 m .53466 .61218 L .51134 .60408 L p
1 g
F P
s
P
p
.002 w
.53466 .61218 m .56128 .59214 L .58812 .59122 L p
1 g
F P
s
P
p
.002 w
.60725 .55744 m .58812 .59122 L .56128 .59214 L p
1 g
F P
s
P
p
.002 w
.58812 .59122 m .60725 .55744 L .6337 .54765 L p
1 g
F P
s
P
p
.002 w
.37524 .35195 m .33574 .37847 L .33442 .35221 L p
1 g
F P
s
P
p
.002 w
.33442 .35221 m .37705 .32295 L .37524 .35195 L p
1 g
F P
s
P
p
.002 w
.44754 .59593 m .46854 .59617 L .48446 .61203 L p
1 g
F P
s
P
p
.002 w
.51134 .60408 m .48446 .61203 L .46854 .59617 L p
1 g
F P
s
P
p
.002 w
.35471 .48804 m .35061 .51327 L .33031 .4967 L p
1 g
F P
s
P
p
.002 w
.33031 .4967 m .3352 .46421 L .35471 .48804 L p
1 g
F P
s
P
p
.002 w
.66246 .41035 m .67834 .46659 L .66091 .48461 L p
1 g
F P
s
P
p
.002 w
.67834 .46659 m .66246 .41035 L .67429 .39085 L p
1 g
F P
s
P
p
.002 w
.67429 .39085 m .63696 .33715 L .64415 .32019 L p
1 g
F P
s
P
p
.002 w
.59042 .2781 m .64415 .32019 L .63696 .33715 L p
1 g
F P
s
P
p
.002 w
.37594 .52781 m .37999 .54618 L .35676 .53994 L p
1 g
F P
s
P
p
.002 w
.35676 .53994 m .35061 .51327 L .37594 .52781 L p
1 g
F P
s
P
p
.002 w
.58216 .29437 m .51703 .2685 L .52646 .25276 L p
1 g
F P
s
P
p
.002 w
.52646 .25276 m .59042 .2781 L .58216 .29437 L p
1 g
F P
s
P
p
.002 w
.35319 .43686 m .3352 .46421 L .32097 .43995 L p
1 g
F P
s
P
p
.002 w
.32097 .43995 m .34201 .407 L .35319 .43686 L p
1 g
F P
s
P
p
.002 w
.63696 .33715 m .67429 .39085 L .66246 .41035 L p
1 g
F P
s
P
p
.002 w
.63816 .50151 m .6337 .54765 L .60725 .55744 L p
1 g
F P
s
P
p
.002 w
.6337 .54765 m .63816 .50151 L .66091 .48461 L p
1 g
F P
s
P
p
.002 w
.43306 .30998 m .37705 .32295 L .38242 .29789 L p
1 g
F P
s
P
p
.002 w
.38242 .29789 m .44099 .28385 L .43306 .30998 L p
1 g
F P
s
P
p
.002 w
.63696 .33715 m .58216 .29437 L .59042 .2781 L p
1 g
F P
s
P
p
.002 w
.4211 .56598 m .43124 .57171 L .42615 .58995 L p
1 g
F P
s
P
p
.002 w
.42615 .58995 m .40651 .57887 L .4211 .56598 L p
1 g
F P
s
P
p
.002 w
.44754 .59593 m .42615 .58995 L .43124 .57171 L p
1 g
F P
s
P
p
.002 w
.41291 .55818 m .4211 .56598 L .40651 .57887 L p
1 g
F P
s
P
p
.002 w
.40651 .57887 m .39058 .56378 L .41291 .55818 L p
1 g
F P
s
P
p
.002 w
.50675 .2897 m .44099 .28385 L .45042 .26284 L p
1 g
F P
s
P
p
.002 w
.45042 .26284 m .51703 .2685 L .50675 .2897 L p
1 g
F P
s
P
p
.002 w
.53191 .58826 m .51134 .60408 L .48701 .59056 L p
1 g
F P
s
P
p
.002 w
.46854 .59617 m .48701 .59056 L .51134 .60408 L p
1 g
F P
s
P
p
.002 w
.51134 .60408 m .53191 .58826 L .56128 .59214 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.43124 .57171 m .44227 .57477 L .44754 .59593 L p
1 g
F P
s
P
p
.002 w
.46854 .59617 m .44754 .59593 L .44227 .57477 L p
1 g
F P
s
P
p
.002 w
.57694 .56366 m .56128 .59214 L .53191 .58826 L p
1 g
F P
s
P
p
.002 w
.56128 .59214 m .57694 .56366 L .60725 .55744 L p
1 g
F P
s
P
p
.002 w
.40754 .54912 m .41291 .55818 L .39058 .56378 L p
1 g
F P
s
P
p
.002 w
.39058 .56378 m .37999 .54618 L .40754 .54912 L p
1 g
F P
s
P
p
.002 w
.37719 .38401 m .34201 .407 L .33574 .37847 L p
1 g
F P
s
P
p
.002 w
.33574 .37847 m .37524 .35195 L .37719 .38401 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37899 .51059 m .37594 .52781 L .35061 .51327 L p
1 g
F P
s
P
p
.002 w
.35061 .51327 m .35471 .48804 L .37899 .51059 L p
1 g
F P
s
P
p
.002 w
.64534 .43108 m .66091 .48461 L .63816 .50151 L p
1 g
F P
s
P
p
.002 w
.66091 .48461 m .64534 .43108 L .66246 .41035 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45205 .52265 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.44227 .57477 m .45306 .57483 L .46854 .59617 L p
1 g
F P
s
P
p
.002 w
.48701 .59056 m .46854 .59617 L .45306 .57483 L p
1 g
F P
s
P
p
.002 w
.36903 .46704 m .35471 .48804 L .3352 .46421 L p
1 g
F P
s
P
p
.002 w
.3352 .46421 m .35319 .43686 L .36903 .46704 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.40558 .53973 m .40754 .54912 L .37999 .54618 L p
1 g
F P
s
P
p
.002 w
.37999 .54618 m .37594 .52781 L .40558 .53973 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.61068 .51667 m .60725 .55744 L .57694 .56366 L p
1 g
F P
s
P
p
.002 w
.60725 .55744 m .61068 .51667 L .63816 .50151 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.66246 .41035 m .62536 .35754 L .63696 .33715 L p
1 g
F P
s
P
p
.002 w
.58216 .29437 m .63696 .33715 L .62536 .35754 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62536 .35754 m .66246 .41035 L .64534 .43108 L p
1 g
F P
s
P
p
.002 w
.42699 .34047 m .37524 .35195 L .37705 .32295 L p
1 g
F P
s
P
p
.002 w
.37705 .32295 m .43306 .30998 L .42699 .34047 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.57111 .31536 m .50675 .2897 L .51703 .2685 L p
1 g
F P
s
P
p
.002 w
.51703 .2685 m .58216 .29437 L .57111 .31536 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.48701 .59056 m .49869 .58133 L p
.53191 .58826 L 1 g
F P
s
P
p
.002 w
.50634 .58106 m .50806 .58155 L p
.49869 .58133 L 1 g
F P
s
P
p
.002 w
.50806 .58155 m .53191 .58826 L p
.50404 .58244 L 1 g
F P
s
P
p
.50404 .58244 m .49869 .58133 L .50806 .58155 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58067 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58067 L .51323 .57998 L 1 g
F
P
p
.002 w
.53191 .58826 m .50806 .58155 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .57439 L p
1 g
F P
s
P
p
.002 w
.54072 .57164 m .53711 .57847 L p
.52237 .57971 L 1 g
F P
s
P
p
.54072 .57164 m .52237 .57971 L .53166 .57439 L 1 g
F
P
p
.54854 .56129 m .53166 .57439 L .53951 .56989 L 1 g
F
P
p
.53166 .57439 m .52237 .57971 L .51094 .58067 L 1 g
F
P
p
.002 w
.53711 .57847 m .53191 .58826 L p
.51094 .58067 L 1 g
F P
s
P
p
.52243 .57719 m .51096 .5809 L .51845 .57923 L 1 g
F
P
p
.53128 .57265 m .51323 .57998 L .52243 .57719 L 1 g
F
P
p
.51323 .57998 m .51096 .5809 L .52243 .57719 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58067 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58067 L .49649 .58118 L 1 g
F
P
p
.002 w
.48701 .59056 m .47255 .57955 L p
.48906 .58067 L 1 g
F P
s
P
p
.002 w
.49869 .58133 m .49676 .58285 L p
.48906 .58067 L 1 g
F P
s
P
p
.002 w
.49676 .58285 m .48701 .59056 L p
.48906 .58067 L 1 g
F P
s
P
p
.002 w
.48906 .58067 m .48921 .57862 L p
.47874 .57776 L 1 g
F P
s
P
p
.49761 .58125 m .48892 .58253 L .49289 .5822 L 1 g
F
P
p
.51079 .57862 m .49649 .58118 L .49761 .58125 L 1 g
F
P
p
.49649 .58118 m .48892 .58253 L .49761 .58125 L 1 g
F
P
p
.51079 .57862 m .49694 .58139 L .50634 .58106 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46825 .5748 L p
1 g
F P
s
P
p
.002 w
.47255 .57955 m .46516 .57392 L p
.46825 .5748 L 1 g
F P
s
P
p
.48906 .58067 m .4776 .5799 L .46825 .5748 L 1 g
F
P
p
.4776 .5799 m .47255 .57955 L .46825 .5748 L 1 g
F
P
p
.002 w
.46825 .5748 m .46872 .57265 L p
.458 .56837 L 1 g
F P
s
P
p
.002 w
.45306 .57483 m .44384 .55807 L p
.45098 .56336 L 1 g
F P
s
P
p
.002 w
.46246 .57187 m .45892 .57299 L p
.45098 .56336 L 1 g
F P
s
P
p
.002 w
.45892 .57299 m .45306 .57483 L p
.45098 .56336 L 1 g
F P
s
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44376 .5546 L 1 g
F P
s
P
p
.458 .56837 m .46145 .57088 L .46825 .5748 L 1 g
F
P
p
.002 w
.46263 .57173 m .46246 .57187 L .46145 .57088 L p
1 g
F P
s
P
p
.46145 .57088 m .46259 .57171 L .46263 .57173 L 1 g
F
P
p
.46145 .57088 m .46263 .57173 L .46825 .5748 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46145 .57088 m .46246 .57187 L p
.44384 .55807 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45012 .56491 L p
1 g
F P
s
P
p
.002 w
.45012 .56491 m .45002 .56518 L p
.45225 .56607 L 1 g
F P
s
P
p
.46872 .57265 m .45012 .56491 L .45225 .56607 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46946 .56616 m .50095 .57954 L p
.46313 .572 L 1 g
F P
s
P
p
.002 w
.46246 .57187 m .46263 .57173 L p
.46313 .572 L 1 g
F P
s
P
p
.002 w
.46263 .57173 m .46946 .56616 L p
.46313 .572 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43818 .54767 L p
1 g
F P
s
P
p
.002 w
.4385 .54816 m .43859 .54852 L .43829 .54803 L p
1 g
F P
s
P
p
.002 w
.43829 .54803 m .43657 .54521 L p
.43818 .54767 L 1 g
F P
s
P
p
.43818 .54767 m .4385 .54816 L .43829 .54803 L 1 g
F
P
p
.002 w
.43818 .54767 m .43925 .54566 L p
.43515 .53756 L 1 g
F P
s
P
p
.45146 .56129 m .43818 .54767 L .4382 .54769 L 1 g
F
P
p
.45146 .56129 m .43818 .54767 L .43821 .54772 L 1 g
F
P
p
.45146 .56129 m .43818 .54768 L .43822 .54775 L 1 g
F
P
p
.45146 .56129 m .43817 .54769 L .43823 .54778 L 1 g
F
P
p
.45146 .56129 m .43816 .54771 L .43824 .54781 L 1 g
F
P
p
.45146 .56129 m .43815 .54773 L .43824 .54784 L 1 g
F
P
p
.45146 .56129 m .43815 .54774 L .43823 .54785 L 1 g
F
P
p
.45146 .56129 m .43814 .54776 L .4382 .54784 L 1 g
F
P
p
.002 w
.44384 .55807 m .43859 .54852 L .43939 .54929 L p
1 g
F P
s
P
p
.45146 .56129 m .43813 .54777 L .43939 .54929 L 1 g
F
P
p
.45146 .56129 m .43939 .54929 L .44376 .5546 L 1 g
F
P
p
.002 w
.43939 .54929 m .46145 .57088 L p
.45078 .56312 L 1 g
F P
s
P
p
.45078 .56312 m .44384 .55807 L .43939 .54929 L 1 g
F
P
p
.44376 .5546 m .43939 .54929 L .44368 .55453 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52873 L p
1 g
F P
s
P
p
.43925 .54566 m .43251 .52873 L .43515 .53756 L 1 g
F
P
p
.002 w
.43108 .51757 m .4327 .52426 L p
.4327 .52443 L 1 g
F P
s
P
p
.002 w
.42073 .51926 m .42925 .51787 L p
.43817 .54761 L 1 g
F P
s
P
p
.002 w
.43108 .51757 m .42557 .48338 L p
.43462 .50256 L 1 g
F P
s
P
p
.002 w
.43251 .52873 m .43346 .52734 L p
.4331 .51695 L 1 g
F P
s
P
p
.4331 .51695 m .43301 .5178 L .43251 .52873 L 1 g
F
P
p
.43308 .51632 m .4327 .52426 L .43251 .52873 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.433 .51783 m .43108 .51757 L p
.43215 .51303 L 1 g
F P
s
P
p
.43462 .50256 m .4339 .50939 L .43215 .51303 L 1 g
F
P
p
.4339 .50939 m .433 .51783 L .43215 .51303 L 1 g
F
P
p
.002 w
.4339 .50939 m .43485 .50826 L p
.43816 .50052 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4339 .50939 L p
1 g
F P
s
P
p
.002 w
.4339 .50939 m .43287 .51061 L p
.4331 .51695 L 1 g
F P
s
P
p
.43346 .52734 m .4339 .50939 L .4331 .51695 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44254 .4914 L p
1 g
F P
s
P
p
.43485 .50826 m .44254 .4914 L .43816 .50052 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44812 .48624 m .44242 .51908 L p
.43348 .50015 L 1 g
F P
s
P
p
.002 w
.47014 .49527 m .44812 .48624 L .44818 .48596 L p
1 g
F P
s
P
p
.002 w
.44254 .4914 m .44339 .4905 L p
.45116 .48305 L 1 g
F P
s
P
p
.45116 .48305 m .45008 .48411 L .44254 .4914 L 1 g
F
P
p
.45183 .48241 m .44792 .48621 L .44254 .4914 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45772 .47667 m .47014 .49527 L .44818 .48596 L 1 g
F
P
p
.002 w
.45772 .47667 m .45826 .47608 L p
.46644 .47249 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46717 L p
1 g
F P
s
P
p
.45826 .47608 m .47756 .46717 L .46644 .47249 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48801 .46443 m .5064 .43228 L p
.51163 .46186 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52238 .46708 L p
1 g
F P
s
P
p
.5123 .46561 m .5158 .48538 L .5 .46382 L 1 g
F
P
p
.5 .4634 m .52238 .46708 L .50892 .46512 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54218 .47656 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56586 .5091 L p
1 g
F P
s
P
p
.56745 .4933 m .57584 .53048 L .56586 .5091 L 1 g
F
P
p
.56502 .49832 m .56586 .5091 L .56288 .50273 L 1 g
F
P
p
.56745 .4933 m .56586 .5091 L .56502 .49832 L 1 g
F
P
p
.002 w
.56586 .5091 m .56515 .50826 L p
.56645 .51666 L 1 g
F P
s
P
p
.55661 .4905 m .56586 .5091 L .56245 .5018 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56737 .52855 L p
1 g
F P
s
P
p
.56586 .5091 m .57006 .5181 L .56678 .52091 L 1 g
F
P
p
.002 w
.57584 .53048 m .56615 .53329 L p
.57006 .5181 L 1 g
F P
s
P
p
.56515 .50826 m .56737 .52855 L .56645 .51666 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56134 .54677 L p
1 g
F P
s
P
p
.57931 .52947 m .55475 .5652 L .5607 .54856 L 1 g
F
P
p
.56654 .52734 m .56134 .54677 L .56424 .53864 L 1 g
F
P
p
.56654 .52734 m .56424 .53864 L .56472 .53729 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.51094 .58067 m .51079 .57862 L p
.50634 .58106 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.54072 .57164 m .51094 .58067 L .50095 .57954 L 1 g
F
P
p
.54854 .56129 m .53951 .56989 L .54037 .5694 L 1 g
F
P
p
.002 w
.54258 .56814 m .54072 .57164 L p
.5342 .57294 L 1 g
F P
s
P
p
.002 w
.54925 .56319 m .54854 .56129 L p
.5397 .57007 L 1 g
F P
s
P
p
.002 w
.53191 .58826 m .54258 .56814 L p
.57694 .56366 L 1 g
F P
s
P
p
.002 w
.54606 .5658 m .57694 .56366 L p
.54258 .56814 L 1 g
F P
s
P
p
.5397 .57007 m .53415 .57558 L .54606 .5658 L 1 g
F
P
p
.5397 .57007 m .54606 .5658 L .54925 .56319 L 1 g
F
P
p
.002 w
.54258 .56814 m .54373 .56596 L .54606 .5658 L p
1 g
F P
s
P
p
.002 w
.54373 .56596 m .54258 .56814 L p
.50095 .57954 L 1 g
F P
s
P
p
.54258 .56814 m .5342 .57294 L .50095 .57954 L 1 g
F
P
p
.002 w
.5322 .57686 m .53415 .57558 L p
.54037 .5694 L 1 g
F P
s
P
p
.53951 .56989 m .5322 .57686 L .54037 .5694 L 1 g
F
P
p
.002 w
.55475 .5652 m .54739 .56571 L p
.55805 .55596 L 1 g
F P
s
P
p
.002 w
.54739 .56571 m .54606 .5658 L p
.54925 .56319 L 1 g
F P
s
P
p
.55805 .55596 m .54739 .56571 L .54925 .56319 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .56319 L p
1 g
F P
s
P
p
.56075 .54566 m .54925 .56319 L .55657 .55325 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.5607 .54856 m .55805 .55596 L .55088 .56097 L 1 g
F
P
p
.002 w
.56134 .54677 m .56075 .54566 L p
.55657 .55325 L 1 g
F P
s
P
p
.55791 .55142 m .55088 .56097 L .54373 .56596 L 1 g
F
P
p
.5607 .54856 m .55088 .56097 L .55791 .55142 L 1 g
F
P
p
.002 w
.54606 .5658 m .54373 .56596 L p
.55805 .55596 L 1 g
F P
s
P
p
.002 w
.56615 .53329 m .57931 .52947 L p
.5607 .54856 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.5607 .54856 m .54373 .56596 L .56615 .53329 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56134 .54677 L p
1 g
F P
s
P
p
.55657 .55325 m .54998 .56518 L .56134 .54677 L 1 g
F
P
p
.002 w
.54925 .56319 m .54998 .56518 L p
.55657 .55325 L 1 g
F P
s
P
p
.002 w
.53415 .57558 m .54998 .56518 L .54925 .56319 L p
1 g
F P
s
P
p
.002 w
.54373 .56596 m .54514 .53939 L .56615 .53329 L p
1 g
F P
s
P
p
.56472 .53729 m .56224 .54848 L .56375 .5426 L 1 g
F
P
p
.56424 .53864 m .56224 .54848 L .56472 .53729 L 1 g
F
P
p
.002 w
.56134 .54677 m .56224 .54848 L p
.56424 .53864 L 1 g
F P
s
P
p
.002 w
.57931 .52947 m .57694 .56366 L .55475 .5652 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56615 .53329 m .54514 .53939 L p
.57006 .5181 L 1 g
F P
s
P
p
.002 w
.56737 .52855 m .56854 .53025 L p
.56645 .51666 L 1 g
F P
s
P
p
.56288 .50273 m .56586 .5091 L .54514 .53939 L 1 g
F
P
p
.56586 .5091 m .56678 .52091 L .54514 .53939 L 1 g
F
P
p
.002 w
.56224 .54848 m .56257 .5491 L p
.56375 .5426 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56586 .5091 L p
1 g
F P
s
P
p
.56645 .51666 m .56854 .53025 L .56586 .5091 L 1 g
F
P
p
.55661 .4905 m .56245 .5018 L .56187 .50057 L 1 g
F
P
p
.002 w
.56036 .49733 m .56745 .4933 L p
.56288 .50273 L 1 g
F P
s
P
p
.002 w
.56745 .4933 m .56036 .49733 L p
.55399 .48458 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54514 .53939 m .53556 .51143 L .56036 .49733 L p
1 g
F P
s
P
p
.56288 .50273 m .54514 .53939 L .56036 .49733 L 1 g
F
P
p
.56187 .50057 m .56681 .51023 L .56423 .50508 L 1 g
F
P
p
.56245 .5018 m .56681 .51023 L .56187 .50057 L 1 g
F
P
p
.002 w
.56586 .5091 m .56681 .51023 L p
.56245 .5018 L 1 g
F P
s
P
p
.002 w
.56745 .4933 m .57931 .52947 L .57584 .53048 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55733 .49127 L p
1 g
F P
s
P
p
.54331 .47766 m .55257 .48665 L .53556 .51143 L 1 g
F
P
p
.54174 .47608 m .55733 .49127 L .54798 .48219 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56036 .49733 m .53556 .51143 L p
.55399 .48458 L 1 g
F P
s
P
p
.002 w
.55733 .49127 m .55834 .49233 L p
.54798 .48219 L 1 g
F P
s
P
p
.54015 .47561 m .54331 .47766 L .53556 .51143 L 1 g
F
P
p
.002 w
.54218 .47656 m .54174 .47608 L p
.54798 .48219 L 1 g
F P
s
P
p
.002 w
.56184 .48577 m .56745 .4933 L p
.54015 .47561 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54218 .47656 L p
1 g
F P
s
P
p
.54798 .48219 m .55834 .49233 L .54218 .47656 L 1 g
F
P
p
.002 w
.54222 .45947 m .56184 .48577 L p
.54218 .47656 L 1 g
F P
s
P
p
.52214 .46667 m .54218 .47656 L .53465 .47303 L 1 g
F
P
p
.54027 .47471 m .54218 .47656 L .54015 .47561 L 1 g
F
P
p
.54222 .45947 m .54218 .47656 L .54027 .47471 L 1 g
F
P
p
.54331 .47766 m .55399 .48458 L .55257 .48665 L 1 g
F
P
p
.002 w
.56681 .51023 m .56713 .51061 L p
.56423 .50508 L 1 g
F P
s
P
p
.002 w
.53556 .51143 m .5158 .48538 L .53041 .47105 L p
1 g
F P
s
P
p
.52214 .46667 m .53465 .47303 L .53238 .47197 L 1 g
F
P
p
.54015 .47561 m .53556 .51143 L .53041 .47105 L 1 g
F
P
p
.002 w
.53041 .47105 m .5158 .48538 L p
.5123 .46561 L 1 g
F P
s
P
p
.51162 .46175 m .52238 .46708 L .5123 .46561 L 1 g
F
P
p
.52238 .46708 m .53041 .47105 L .5123 .46561 L 1 g
F
P
p
.002 w
.5158 .48538 m .48954 .46558 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .4634 L p
.50892 .46512 L 1 g
F P
s
P
p
.50892 .46512 m .52282 .46778 L .5 .46382 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53041 .47105 m .54222 .45947 L p
.54015 .47561 L 1 g
F P
s
P
p
.53238 .47197 m .5427 .47713 L .53464 .47314 L 1 g
F
P
p
.53465 .47303 m .5427 .47713 L .53238 .47197 L 1 g
F
P
p
.002 w
.54218 .47656 m .5427 .47713 L p
.53465 .47303 L 1 g
F P
s
P
p
.002 w
.5064 .43228 m .54222 .45947 L .53041 .47105 L p
1 g
F P
s
P
p
.5064 .43228 m .53041 .47105 L .51162 .46175 L 1 g
F
P
p
.002 w
.5427 .47713 m .54302 .47747 L p
.53464 .47314 L 1 g
F P
s
P
p
.002 w
.52238 .46708 m .52282 .46778 L p
.50892 .46512 L 1 g
F P
s
P
p
.51163 .46186 m .5123 .46561 L .5 .46382 L 1 g
F
P
p
.002 w
.47756 .46717 m .47786 .46667 L p
.491 .46533 L 1 g
F P
s
P
p
.491 .46533 m .49034 .46545 L .47756 .46717 L 1 g
F
P
p
.49168 .46526 m .48714 .46593 L .47756 .46717 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46404 L p
1 g
F P
s
P
p
.002 w
.5 .46404 m .5 .46442 L p
.49168 .46526 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46404 L .49168 .46526 L 1 g
F
P
p
.002 w
.5158 .48538 m .48904 .50943 L p
.48804 .4658 L 1 g
F P
s
P
p
.002 w
.48801 .46443 m .48954 .46558 L p
.48804 .4658 L 1 g
F P
s
P
p
.002 w
.48954 .46558 m .5158 .48538 L p
.48804 .4658 L 1 g
F P
s
P
p
.002 w
.48954 .46558 m .48801 .46443 L p
.51163 .46186 L 1 g
F P
s
P
p
.491 .46533 m .49168 .46526 L .49034 .46545 L 1 g
F
P
p
.48804 .4658 m .48904 .50943 L .48714 .46593 L 1 g
F
P
p
.49168 .46526 m .49476 .46495 L .48714 .46593 L 1 g
F
P
p
.002 w
.48904 .50943 m .47014 .49527 L .48714 .46593 L p
1 g
F P
s
P
p
.002 w
.48714 .46593 m .48801 .46443 L p
.48804 .4658 L 1 g
F P
s
P
p
.002 w
.45553 .45117 m .48801 .46443 L .48714 .46593 L p
1 g
F P
s
P
p
.002 w
.48714 .46593 m .47014 .49527 L p
.46152 .46924 L 1 g
F P
s
P
p
.45553 .45117 m .48714 .46593 L .46152 .46924 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46717 L p
1 g
F P
s
P
p
.49476 .46495 m .5 .46442 L .47756 .46717 L 1 g
F
P
p
.002 w
.47756 .46717 m .47718 .46778 L p
.46644 .47249 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45772 .47667 L p
1 g
F P
s
P
p
.002 w
.45772 .47667 m .45698 .47747 L p
.45116 .48305 L 1 g
F P
s
P
p
.44339 .4905 m .45772 .47667 L .45116 .48305 L 1 g
F
P
p
.45553 .45117 m .46245 .47206 L .45772 .47667 L 1 g
F
P
p
.002 w
.44818 .48596 m .44929 .48071 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.44929 .48071 m .45553 .45117 L p
.45772 .47667 L 1 g
F P
s
P
p
.46245 .47206 m .46312 .47408 L .45772 .47667 L 1 g
F
P
p
.46312 .47408 m .47014 .49527 L .45772 .47667 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45772 .47667 L p
1 g
F P
s
P
p
.46644 .47249 m .47718 .46778 L .45772 .47667 L 1 g
F
P
p
.45116 .48305 m .45183 .48241 L .45008 .48411 L 1 g
F
P
p
.002 w
.42232 .44718 m .45553 .45117 L .44818 .48596 L p
1 g
F P
s
P
p
.002 w
.44818 .48596 m .44812 .48624 L p
.44803 .4861 L 1 g
F P
s
P
p
.42232 .44718 m .44818 .48596 L .44803 .4861 L 1 g
F
P
p
.002 w
.44812 .48624 m .44792 .48621 L p
.44803 .4861 L 1 g
F P
s
P
p
.002 w
.44792 .48621 m .44812 .48624 L p
.43348 .50015 L 1 g
F P
s
P
p
.002 w
.44254 .4914 m .44166 .49233 L p
.43816 .50052 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44223 .49173 L p
1 g
F P
s
P
p
.002 w
.44223 .49173 m .44254 .4914 L p
.44695 .48715 L 1 g
F P
s
P
p
.44695 .48715 m .45698 .47747 L .44223 .49173 L 1 g
F
P
p
.45183 .48241 m .45468 .47968 L .44792 .48621 L 1 g
F
P
p
.002 w
.42557 .48338 m .42232 .44718 L p
.44803 .4861 L 1 g
F P
s
P
p
.002 w
.44792 .48621 m .42557 .48338 L p
.44803 .4861 L 1 g
F P
s
P
p
.002 w
.42557 .48338 m .44792 .48621 L p
.43348 .50015 L 1 g
F P
s
P
p
.45468 .47968 m .45698 .47747 L .44254 .4914 L 1 g
F
P
p
.002 w
.44242 .51908 m .433 .51783 L p
.4339 .50939 L 1 g
F P
s
P
p
.43462 .50256 m .43589 .50525 L .4339 .50939 L 1 g
F
P
p
.43589 .50525 m .44242 .51908 L .4339 .50939 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .4339 .50939 L p
1 g
F P
s
P
p
.43816 .50052 m .44166 .49233 L .4339 .50939 L 1 g
F
P
p
.4331 .51695 m .43308 .51632 L .43301 .5178 L 1 g
F
P
p
.002 w
.43108 .51757 m .433 .51783 L p
.43271 .52421 L 1 g
F P
s
P
p
.002 w
.4385 .54816 m .4327 .52426 L p
.43862 .54832 L 1 g
F P
s
P
p
.002 w
.4327 .52426 m .43108 .51757 L p
.43271 .52421 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43271 .52421 m .43862 .54832 L .4327 .52426 L 1 g
F
P
p
.002 w
.42925 .51787 m .43108 .51757 L p
.4327 .52443 L 1 g
F P
s
P
p
.43251 .52873 m .4327 .52443 L .43817 .54761 L 1 g
F
P
p
.42925 .51787 m .4327 .52443 L .43251 .52873 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43249 .52875 L p
1 g
F P
s
P
p
.002 w
.43249 .52875 m .43251 .52873 L p
.43252 .52826 L 1 g
F P
s
P
p
.43252 .52826 m .43287 .51061 L .43249 .52875 L 1 g
F
P
p
.43308 .51632 m .43307 .51604 L .4327 .52426 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44242 .51908 m .43862 .54832 L p
.43271 .52421 L 1 g
F P
s
P
p
.002 w
.433 .51783 m .44242 .51908 L p
.43271 .52421 L 1 g
F P
s
P
p
.43307 .51604 m .43287 .51061 L .43251 .52873 L 1 g
F
P
p
.43817 .54761 m .4327 .52443 L .4385 .54816 L 1 g
F
P
p
.002 w
.4327 .52426 m .4385 .54816 L p
.4327 .52443 L 1 g
F P
s
P
p
.002 w
.43251 .52873 m .43146 .53025 L p
.43515 .53756 L 1 g
F P
s
P
p
.002 w
.43657 .54521 m .42073 .51926 L p
.4385 .54816 L 1 g
F P
s
P
p
.002 w
.4211 .56598 m .41291 .55818 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.41291 .55818 m .40754 .54912 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.40754 .54912 m .40558 .53973 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.40558 .53973 m .40728 .53101 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.40728 .53101 m .4125 .52392 L .43838 .54832 L p
1 g
F P
s
P
p
.002 w
.43838 .54832 m .43859 .54852 L .43841 .54842 L p
1 g
F P
s
P
p
.002 w
.43841 .54842 m .40728 .53101 L p
.43838 .54832 L 1 g
F P
s
P
p
.002 w
.43859 .54852 m .4125 .52392 L .41989 .51973 L p
1 g
F P
s
P
p
.002 w
.41989 .51973 m .42073 .51926 L .43657 .54521 L p
1 g
F P
s
P
p
.002 w
.43657 .54521 m .43859 .54852 L p
.41989 .51973 L 1 g
F P
s
P
p
.002 w
.46145 .57088 m .43859 .54852 L p
.46263 .57173 L 1 g
F P
s
P
p
.002 w
.43124 .57171 m .4211 .56598 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.44227 .57477 m .43124 .57171 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.45306 .57483 m .44227 .57477 L .43859 .54852 L closepath p
1 g
F P
s
P
p
.002 w
.43813 .54777 m .43743 .5491 L p
.44134 .5525 L 1 g
F P
s
P
p
.002 w
.43859 .54852 m .43889 .54868 L p
.43935 .54925 L 1 g
F P
s
P
p
.44368 .55453 m .43869 .54845 L .44134 .5525 L 1 g
F
P
p
.002 w
.43862 .54832 m .43859 .54852 L .4385 .54816 L p
1 g
F P
s
P
p
.002 w
.43866 .54839 m .43859 .54852 L .43862 .54832 L p
1 g
F P
s
P
p
.002 w
.4387 .54844 m .43859 .54852 L .43866 .54839 L p
1 g
F P
s
P
p
.002 w
.43872 .54848 m .43859 .54852 L .4387 .54844 L p
1 g
F P
s
P
p
.002 w
.43875 .54852 m .43859 .54852 L .43872 .54848 L p
1 g
F P
s
P
p
.002 w
.4388 .54857 m .43859 .54852 L .43875 .54852 L p
1 g
F P
s
P
p
.002 w
.43889 .54868 m .43859 .54852 L .4388 .54857 L p
1 g
F P
s
P
p
.43869 .54845 m .43813 .54777 L .44134 .5525 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43818 .54768 L p
1 g
F P
s
P
p
.002 w
.43818 .54768 m .43818 .54767 L p
.43814 .54756 L 1 g
F P
s
P
p
.43814 .54756 m .43146 .53025 L .43818 .54768 L 1 g
F
P
p
.43515 .53756 m .43146 .53025 L .43818 .54767 L 1 g
F
P
p
.002 w
.43818 .54767 m .43818 .54767 L p
.4382 .54769 L 1 g
F P
s
P
p
.002 w
.43818 .54767 m .43818 .54768 L p
.43821 .54772 L 1 g
F P
s
P
p
.002 w
.43818 .54768 m .43817 .54769 L p
.43822 .54775 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44242 .51908 m .45347 .52363 L .43866 .54839 L p
1 g
F P
s
P
p
.002 w
.43862 .54832 m .44242 .51908 L p
.43866 .54839 L 1 g
F P
s
P
p
.002 w
.45347 .52363 m .46298 .53072 L .4387 .54844 L p
1 g
F P
s
P
p
.002 w
.43866 .54839 m .45347 .52363 L p
.4387 .54844 L 1 g
F P
s
P
p
.002 w
.43817 .54769 m .43816 .54771 L p
.43823 .54778 L 1 g
F P
s
P
p
.002 w
.43816 .54771 m .43815 .54773 L p
.43824 .54781 L 1 g
F P
s
P
p
.002 w
.46298 .53072 m .46989 .53953 L .43872 .54848 L p
1 g
F P
s
P
p
.002 w
.4387 .54844 m .46298 .53072 L p
.43872 .54848 L 1 g
F P
s
P
p
.002 w
.46989 .53953 m .47344 .54908 L .43875 .54852 L p
1 g
F P
s
P
p
.002 w
.43872 .54848 m .46989 .53953 L p
.43875 .54852 L 1 g
F P
s
P
p
.002 w
.43815 .54773 m .43815 .54774 L p
.43824 .54784 L 1 g
F P
s
P
p
.002 w
.43815 .54774 m .43814 .54776 L p
.43823 .54785 L 1 g
F P
s
P
p
.002 w
.47344 .54908 m .47328 .55829 L .4388 .54857 L p
1 g
F P
s
P
p
.002 w
.43875 .54852 m .47344 .54908 L p
.4388 .54857 L 1 g
F P
s
P
p
.002 w
.47328 .55829 m .46946 .56616 L .43889 .54868 L p
1 g
F P
s
P
p
.002 w
.4388 .54857 m .47328 .55829 L p
.43889 .54868 L 1 g
F P
s
P
p
.002 w
.43814 .54776 m .43813 .54777 L p
.4382 .54784 L 1 g
F P
s
P
p
.002 w
.46946 .56616 m .46263 .57173 L p
.43935 .54925 L 1 g
F P
s
P
p
.002 w
.43889 .54868 m .46946 .56616 L p
.43935 .54925 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.44376 .5546 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.458 .56837 m .45225 .56607 L .46259 .57171 L 1 g
F
P
p
.48921 .57862 m .46825 .5748 L .47874 .57776 L 1 g
F
P
p
.49869 .58133 m .48906 .58067 L .46246 .57187 L 1 g
F
P
p
.002 w
.46516 .57392 m .46246 .57187 L p
.48906 .58067 L 1 g
F P
s
P
p
.002 w
.50095 .57954 m .49869 .58133 L p
.46246 .57187 L 1 g
F P
s
P
p
.002 w
.45306 .57483 m .46055 .57247 L p
.48701 .59056 L 1 g
F P
s
P
p
.002 w
.46055 .57247 m .46246 .57187 L .46516 .57392 L p
1 g
F P
s
P
p
.002 w
.46516 .57392 m .48701 .59056 L p
.46055 .57247 L 1 g
F P
s
P
p
.002 w
.46825 .5748 m .46823 .57489 L p
.47874 .57776 L 1 g
F P
s
P
p
.002 w
.46823 .57489 m .4678 .57686 L p
.47683 .5776 L 1 g
F P
s
P
p
.47874 .57776 m .46823 .57489 L .47683 .5776 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46825 .5748 L p
1 g
F P
s
P
p
.45225 .56607 m .45002 .56518 L .46825 .5748 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .58067 L p
1 g
F P
s
P
p
.47874 .57776 m .4678 .57686 L .48906 .58067 L 1 g
F
P
p
.002 w
.48906 .58067 m .48892 .58253 L p
.49649 .58118 L 1 g
F P
s
P
p
.002 w
.48892 .58253 m .48889 .583 L p
.49289 .5822 L 1 g
F P
s
P
p
.002 w
.50806 .58155 m .50634 .58106 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.50634 .58106 m .50095 .57954 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.53166 .57439 m .5322 .57686 L p
.53951 .56989 L 1 g
F P
s
P
p
.002 w
.51096 .5809 m .51094 .58067 L p
.50634 .58106 L 1 g
F P
s
P
p
.002 w
.51094 .58067 m .51096 .5809 L p
.51323 .57998 L 1 g
F P
s
P
p
.002 w
.51096 .5809 m .51111 .583 L p
.51845 .57923 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .5809 L p
1 g
F P
s
P
p
.49694 .58139 m .48889 .583 L .51096 .5809 L 1 g
F
P
p
.002 w
.49869 .58133 m .50095 .57954 L .50634 .58106 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.38294 .41803 m .35319 .43686 L .34201 .407 L p
1 g
F P
s
P
p
.002 w
.34201 .407 m .37719 .38401 L .38294 .41803 L p
1 g
F P
s
P
p
.002 w
.62536 .35754 m .57111 .31536 L .58216 .29437 L p
1 g
F P
s
P
p
.002 w
.49594 .31588 m .43306 .30998 L .44099 .28385 L p
1 g
F P
s
P
p
.002 w
.44099 .28385 m .50675 .2897 L .49594 .31588 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.40728 .53101 m .40558 .53973 L .37594 .52781 L p
1 g
F P
s
P
p
.002 w
.37594 .52781 m .37899 .51059 L .40728 .53101 L p
1 g
F P
s
P
p
.002 w
.38902 .49642 m .37899 .51059 L .35471 .48804 L p
1 g
F P
s
P
p
.002 w
.35471 .48804 m .36903 .46704 L .38902 .49642 L p
1 g
F P
s
P
p
.002 w
.62332 .45233 m .63816 .50151 L .61068 .51667 L p
1 g
F P
s
P
p
.002 w
.63816 .50151 m .62332 .45233 L .64534 .43108 L p
1 g
F P
s
P
p
.002 w
.57694 .56366 m .57931 .52947 L .61068 .51667 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.50876 .56417 m .50095 .57954 L .46946 .56616 L p
1 g
F P
s
P
p
.002 w
.50095 .57954 m .50876 .56417 L .54373 .56596 L p
1 g
F P
s
P
p
.002 w
.42306 .37434 m .37719 .38401 L .37524 .35195 L p
1 g
F P
s
P
p
.002 w
.37524 .35195 m .42699 .34047 L .42306 .37434 L p
1 g
F P
s
P
p
.002 w
.39235 .45278 m .36903 .46704 L .35319 .43686 L p
1 g
F P
s
P
p
.002 w
.35319 .43686 m .38294 .41803 L .39235 .45278 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60957 .38079 m .64534 .43108 L .62332 .45233 L p
1 g
F P
s
P
p
.002 w
.64534 .43108 m .60957 .38079 L .62536 .35754 L p
1 g
F P
s
P
p
.002 w
.4125 .52392 m .40728 .53101 L .37899 .51059 L p
1 g
F P
s
P
p
.002 w
.37899 .51059 m .38902 .49642 L .4125 .52392 L p
1 g
F P
s
P
p
.002 w
.57111 .31536 m .62536 .35754 L .60957 .38079 L p
1 g
F P
s
P
p
.002 w
.54514 .53939 m .54373 .56596 L .50876 .56417 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.55754 .34053 m .49594 .31588 L .50675 .2897 L p
1 g
F P
s
P
p
.002 w
.50675 .2897 m .57111 .31536 L .55754 .34053 L p
1 g
F P
s
P
p
.002 w
.59707 .47334 m .61068 .51667 L .57931 .52947 L p
1 g
F P
s
P
p
.002 w
.61068 .51667 m .59707 .47334 L .62332 .45233 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46946 .56616 m .47328 .55829 L .50876 .56417 L p
1 g
F P
s
P
p
.002 w
.485 .34626 m .42699 .34047 L .43306 .30998 L p
1 g
F P
s
P
p
.002 w
.43306 .30998 m .49594 .31588 L .485 .34626 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40511 .48695 m .38902 .49642 L .36903 .46704 L p
1 g
F P
s
P
p
.002 w
.36903 .46704 m .39235 .45278 L .40511 .48695 L p
1 g
F P
s
P
p
.002 w
.60957 .38079 m .55754 .34053 L .57111 .31536 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5094 .54601 m .50876 .56417 L .47328 .55829 L p
1 g
F P
s
P
p
.002 w
.50876 .56417 m .5094 .54601 L .54514 .53939 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42147 .41036 m .38294 .41803 L .37719 .38401 L p
1 g
F P
s
P
p
.002 w
.37719 .38401 m .42306 .37434 L .42147 .41036 L p
1 g
F P
s
P
p
.002 w
.47328 .55829 m .47344 .54908 L .5094 .54601 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42073 .51926 m .4125 .52392 L .38902 .49642 L p
1 g
F P
s
P
p
.002 w
.38902 .49642 m .40511 .48695 L .42073 .51926 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.57931 .52947 m .56745 .4933 L .59707 .47334 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59 .40615 m .62332 .45233 L .59707 .47334 L p
1 g
F P
s
P
p
.002 w
.62332 .45233 m .59 .40615 L .60957 .38079 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.47344 .54908 m .46989 .53953 L .50262 .52704 L p
1 g
F P
s
P
p
.002 w
.50262 .52704 m .5094 .54601 L .47344 .54908 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55754 .34053 m .60957 .38079 L .59 .40615 L p
1 g
F P
s
P
p
.002 w
.43108 .51757 m .42073 .51926 L .40511 .48695 L p
1 g
F P
s
P
p
.002 w
.53556 .51143 m .54514 .53939 L .5094 .54601 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42232 .44718 m .39235 .45278 L .38294 .41803 L p
1 g
F P
s
P
p
.002 w
.38294 .41803 m .42147 .41036 L .42232 .44718 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.40511 .48695 m .42557 .48338 L .43108 .51757 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47434 .37979 m .42306 .37434 L .42699 .34047 L p
1 g
F P
s
P
p
.002 w
.42699 .34047 m .485 .34626 L .47434 .37979 L p
1 g
F P
s
P
p
.002 w
.5094 .54601 m .50262 .52704 L .53556 .51143 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54184 .36911 m .485 .34626 L .49594 .31588 L p
1 g
F P
s
P
p
.002 w
.49594 .31588 m .55754 .34053 L .54184 .36911 L p
1 g
F P
s
P
p
.002 w
.46989 .53953 m .46298 .53072 L .48904 .50943 L p
1 g
F P
s
P
p
.002 w
.48904 .50943 m .50262 .52704 L .46989 .53953 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42557 .48338 m .40511 .48695 L .39235 .45278 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.39235 .45278 m .42232 .44718 L .42557 .48338 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46298 .53072 m .45347 .52363 L .47014 .49527 L p
1 g
F P
s
P
p
.002 w
.47014 .49527 m .48904 .50943 L .46298 .53072 L p
1 g
F P
s
P
p
.002 w
.59 .40615 m .54184 .36911 L .55754 .34053 L p
1 g
F P
s
P
p
.002 w
.56728 .43271 m .59707 .47334 L .56745 .4933 L p
1 g
F P
s
P
p
.002 w
.59707 .47334 m .56728 .43271 L .59 .40615 L p
1 g
F P
s
P
p
.002 w
.45347 .52363 m .44242 .51908 L .44812 .48624 L p
1 g
F P
s
P
p
.002 w
.44812 .48624 m .47014 .49527 L .45347 .52363 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50262 .52704 m .48904 .50943 L .5158 .48538 L p
1 g
F P
s
P
p
.002 w
.5158 .48538 m .53556 .51143 L .50262 .52704 L p
1 g
F P
s
P
p
.002 w
.46438 .41522 m .42147 .41036 L .42306 .37434 L p
1 g
F P
s
P
p
.002 w
.42306 .37434 m .47434 .37979 L .46438 .41522 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54184 .36911 m .59 .40615 L .56728 .43271 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.56745 .4933 m .54222 .45947 L .56728 .43271 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52458 .40008 m .47434 .37979 L .485 .34626 L p
1 g
F P
s
P
p
.002 w
.485 .34626 m .54184 .36911 L .52458 .40008 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45553 .45117 m .42232 .44718 L .42147 .41036 L p
1 g
F P
s
P
p
.002 w
.42147 .41036 m .46438 .41522 L .45553 .45117 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56728 .43271 m .52458 .40008 L .54184 .36911 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52458 .40008 m .56728 .43271 L .54222 .45947 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.004 w
.41323 .59724 m
.41738 .58928 L
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.5064 .43228 m .46438 .41522 L .47434 .37979 L p
1 g
F P
s
P
p
.002 w
.47434 .37979 m .52458 .40008 L .5064 .43228 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54222 .45947 m .5064 .43228 L .52458 .40008 L p
1 g
F P
s
P
p
.002 w
.48801 .46443 m .45553 .45117 L .46438 .41522 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.46438 .41522 m .5064 .43228 L .48801 .46443 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .51253 .72742 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40219 .61847 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0325581)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0325581)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47028 .43552 m .49739 .45769 L .51221 .43329 L p
1 g
F P
s
P
p
.002 w
.51221 .43329 m .49123 .41613 L .47028 .43552 L p
1 g
F P
s
P
p
.002 w
.53702 .44369 m .51221 .43329 L .49739 .45769 L p
1 g
F P
s
P
p
.002 w
.49123 .41613 m .51221 .43329 L .52675 .4088 L p
1 g
F P
s
P
p
.002 w
.51221 .43329 m .53702 .44369 L .54372 .41586 L p
1 g
F P
s
P
p
.002 w
.54372 .41586 m .52675 .4088 L .51221 .43329 L p
1 g
F P
s
P
p
.002 w
.45074 .40687 m .47028 .43552 L .49123 .41613 L p
1 g
F P
s
P
p
.002 w
.49123 .41613 m .47619 .39391 L .45074 .40687 L p
1 g
F P
s
P
p
.002 w
.47619 .39391 m .49123 .41613 L .51241 .39707 L p
1 g
F P
s
P
p
.002 w
.52675 .4088 m .51241 .39707 L .49123 .41613 L p
1 g
F P
s
P
p
.002 w
.44993 .4549 m .48255 .48156 L .49739 .45769 L p
1 g
F P
s
P
p
.002 w
.49739 .45769 m .47028 .43552 L .44993 .4549 L p
1 g
F P
s
P
p
.002 w
.52942 .47122 m .49739 .45769 L .48255 .48156 L p
1 g
F P
s
P
p
.002 w
.49739 .45769 m .52942 .47122 L .53702 .44369 L p
1 g
F P
s
P
p
.002 w
.4263 .4205 m .44993 .4549 L .47028 .43552 L p
1 g
F P
s
P
p
.002 w
.47028 .43552 m .45074 .40687 L .4263 .4205 L p
1 g
F P
s
P
p
.002 w
.51241 .39707 m .52675 .4088 L .54074 .38467 L p
1 g
F P
s
P
p
.002 w
.52675 .4088 m .54372 .41586 L .5494 .38824 L p
1 g
F P
s
P
p
.002 w
.5494 .38824 m .54074 .38467 L .52675 .4088 L p
1 g
F P
s
P
p
.002 w
.51241 .39707 m .50219 .38186 L .47619 .39391 L p
1 g
F P
s
P
p
.002 w
.50219 .38186 m .51241 .39707 L .53344 .37869 L p
1 g
F P
s
P
p
.002 w
.54074 .38467 m .53344 .37869 L .51241 .39707 L p
1 g
F P
s
P
p
.002 w
.56321 .44623 m .53702 .44369 L .52942 .47122 L p
1 g
F P
s
P
p
.002 w
.53702 .44369 m .56321 .44623 L .5616 .41749 L p
1 g
F P
s
P
p
.002 w
.5616 .41749 m .54372 .41586 L .53702 .44369 L p
1 g
F P
s
P
p
.002 w
.44078 .37448 m .45074 .40687 L .47619 .39391 L p
1 g
F P
s
P
p
.002 w
.47619 .39391 m .46865 .36884 L .44078 .37448 L p
1 g
F P
s
P
p
.002 w
.46865 .36884 m .47619 .39391 L .50219 .38186 L p
1 g
F P
s
P
p
.002 w
.54372 .41586 m .5616 .41749 L .55849 .38902 L p
1 g
F P
s
P
p
.002 w
.55849 .38902 m .5494 .38824 L .54372 .41586 L p
1 g
F P
s
P
p
.002 w
.50219 .38186 m .49715 .36472 L .46865 .36884 L p
1 g
F P
s
P
p
.002 w
.49715 .36472 m .50219 .38186 L .52826 .37093 L p
1 g
F P
s
P
p
.002 w
.53344 .37869 m .52826 .37093 L .50219 .38186 L p
1 g
F P
s
P
p
.002 w
.48255 .48156 m .52105 .49796 L .52942 .47122 L p
1 g
F P
s
P
p
.002 w
.56328 .47471 m .52942 .47122 L .52105 .49796 L p
1 g
F P
s
P
p
.002 w
.52942 .47122 m .56328 .47471 L .56321 .44623 L p
1 g
F P
s
P
p
.002 w
.43057 .47391 m .46797 .50446 L .48255 .48156 L p
1 g
F P
s
P
p
.002 w
.48255 .48156 m .44993 .4549 L .43057 .47391 L p
1 g
F P
s
P
p
.002 w
.52105 .49796 m .48255 .48156 L .46797 .50446 L p
1 g
F P
s
P
p
.002 w
.41407 .38156 m .4263 .4205 L .45074 .40687 L p
1 g
F P
s
P
p
.002 w
.45074 .40687 m .44078 .37448 L .41407 .38156 L p
1 g
F P
s
P
p
.002 w
.40335 .43455 m .43057 .47391 L .44993 .4549 L p
1 g
F P
s
P
p
.002 w
.44993 .4549 m .4263 .4205 L .40335 .43455 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .53344 .37869 L .54074 .38467 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .54074 .38467 L .5494 .38824 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .52826 .37093 L .53344 .37869 L closepath p
1 g
F P
s
P
p
.002 w
.57853 .41346 m .5616 .41749 L .56321 .44623 L p
1 g
F P
s
P
p
.002 w
.5616 .41749 m .57853 .41346 L .56707 .3869 L p
1 g
F P
s
P
p
.002 w
.56707 .3869 m .55849 .38902 L .5616 .41749 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .5494 .38824 L .55849 .38902 L closepath p
1 g
F P
s
P
p
.002 w
.58811 .44053 m .56321 .44623 L .56328 .47471 L p
1 g
F P
s
P
p
.002 w
.56321 .44623 m .58811 .44053 L .57853 .41346 L p
1 g
F P
s
P
p
.002 w
.46952 .34342 m .46865 .36884 L .49715 .36472 L p
1 g
F P
s
P
p
.002 w
.49715 .36472 m .4979 .34742 L .46952 .34342 L p
1 g
F P
s
P
p
.002 w
.4979 .34742 m .49715 .36472 L .52575 .3622 L p
1 g
F P
s
P
p
.002 w
.52826 .37093 m .52575 .3622 L .49715 .36472 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .52575 .3622 L .52826 .37093 L closepath p
1 g
F P
s
P
p
.002 w
.44162 .34154 m .44078 .37448 L .46865 .36884 L p
1 g
F P
s
P
p
.002 w
.46865 .36884 m .46952 .34342 L .44162 .34154 L p
1 g
F P
s
P
p
.002 w
.46797 .50446 m .51205 .52338 L .52105 .49796 L p
1 g
F P
s
P
p
.002 w
.5618 .50238 m .52105 .49796 L .51205 .52338 L p
1 g
F P
s
P
p
.002 w
.52105 .49796 m .5618 .50238 L .56328 .47471 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .55849 .38902 L .56707 .3869 L closepath p
1 g
F P
s
P
p
.002 w
.52575 .3622 m .52621 .35343 L .4979 .34742 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .52621 .35343 L .52575 .3622 L closepath p
1 g
F P
s
P
p
.002 w
.38905 .38998 m .40335 .43455 L .4263 .4205 L p
1 g
F P
s
P
p
.002 w
.4263 .4205 m .41407 .38156 L .38905 .38998 L p
1 g
F P
s
P
p
.002 w
.5956 .46758 m .56328 .47471 L .5618 .50238 L p
1 g
F P
s
P
p
.002 w
.56328 .47471 m .5956 .46758 L .58811 .44053 L p
1 g
F P
s
P
p
.002 w
.57419 .3821 m .56707 .3869 L .57853 .41346 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .56707 .3869 L .57419 .3821 L closepath p
1 g
F P
s
P
p
.002 w
.5927 .40412 m .57853 .41346 L .58811 .44053 L p
1 g
F P
s
P
p
.002 w
.57853 .41346 m .5927 .40412 L .57419 .3821 L p
1 g
F P
s
P
p
.002 w
.41257 .49219 m .45391 .52595 L .46797 .50446 L p
1 g
F P
s
P
p
.002 w
.46797 .50446 m .43057 .47391 L .41257 .49219 L p
1 g
F P
s
P
p
.002 w
.51205 .52338 m .46797 .50446 L .45391 .52595 L p
1 g
F P
s
P
p
.002 w
.50443 .33179 m .4979 .34742 L .52621 .35343 L p
1 g
F P
s
P
p
.002 w
.52621 .35343 m .5296 .34555 L .50443 .33179 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .5296 .34555 L .52621 .35343 L closepath p
1 g
F P
s
P
p
.002 w
.41476 .34184 m .41407 .38156 L .44078 .37448 L p
1 g
F P
s
P
p
.002 w
.44078 .37448 m .44162 .34154 L .41476 .34184 L p
1 g
F P
s
P
p
.002 w
.38235 .44878 m .41257 .49219 L .43057 .47391 L p
1 g
F P
s
P
p
.002 w
.43057 .47391 m .40335 .43455 L .38235 .44878 L p
1 g
F P
s
P
p
.002 w
.4789 .32033 m .46952 .34342 L .4979 .34742 L p
1 g
F P
s
P
p
.002 w
.4979 .34742 m .50443 .33179 L .4789 .32033 L p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .57419 .3821 L .57909 .3751 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .57909 .3751 L .58121 .36665 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .58121 .36665 L .58029 .35767 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .58029 .35767 L .5764 .34915 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .5764 .34915 L .56998 .34203 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .56998 .34203 L .56173 .33712 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .56173 .33712 L .55257 .33495 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .55257 .33495 L .54352 .33576 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .54352 .33576 L .53558 .33944 L closepath p
1 g
F P
s
P
p
.002 w
.55393 .36133 m .53558 .33944 L .5296 .34555 L closepath p
1 g
F P
s
P
p
.002 w
.57909 .3751 m .57419 .3821 L .5927 .40412 L p
1 g
F P
s
P
p
.002 w
.60909 .42699 m .58811 .44053 L .5956 .46758 L p
1 g
F P
s
P
p
.002 w
.58811 .44053 m .60909 .42699 L .5927 .40412 L p
1 g
F P
s
P
p
.002 w
.51614 .31955 m .50443 .33179 L .5296 .34555 L p
1 g
F P
s
P
p
.002 w
.5296 .34555 m .53558 .33944 L .51614 .31955 L p
1 g
F P
s
P
p
.002 w
.4535 .31145 m .44162 .34154 L .46952 .34342 L p
1 g
F P
s
P
p
.002 w
.46952 .34342 m .4789 .32033 L .4535 .31145 L p
1 g
F P
s
P
p
.002 w
.45391 .52595 m .50259 .54699 L .51205 .52338 L p
1 g
F P
s
P
p
.002 w
.55876 .52871 m .51205 .52338 L .50259 .54699 L p
1 g
F P
s
P
p
.002 w
.51205 .52338 m .55876 .52871 L .5618 .50238 L p
1 g
F P
s
P
p
.002 w
.60082 .49411 m .5618 .50238 L .55876 .52871 L p
1 g
F P
s
P
p
.002 w
.5618 .50238 m .60082 .49411 L .5956 .46758 L p
1 g
F P
s
P
p
.002 w
.60255 .39037 m .5927 .40412 L .60909 .42699 L p
1 g
F P
s
P
p
.002 w
.5927 .40412 m .60255 .39037 L .57909 .3751 L p
1 g
F P
s
P
p
.002 w
.58121 .36665 m .57909 .3751 L .60255 .39037 L p
1 g
F P
s
P
p
.002 w
.36628 .39959 m .38235 .44878 L .40335 .43455 L p
1 g
F P
s
P
p
.002 w
.40335 .43455 m .38905 .38998 L .36628 .39959 L p
1 g
F P
s
P
p
.002 w
.53186 .31212 m .51614 .31955 L .53558 .33944 L p
1 g
F P
s
P
p
.002 w
.53558 .33944 m .54352 .33576 L .53186 .31212 L p
1 g
F P
s
P
p
.002 w
.49599 .30212 m .4789 .32033 L .50443 .33179 L p
1 g
F P
s
P
p
.002 w
.50443 .33179 m .51614 .31955 L .49599 .30212 L p
1 g
F P
s
P
p
.002 w
.38949 .34438 m .38905 .38998 L .41407 .38156 L p
1 g
F P
s
P
p
.002 w
.41407 .38156 m .41476 .34184 L .38949 .34438 L p
1 g
F P
s
P
p
.002 w
.623 .45028 m .5956 .46758 L .60082 .49411 L p
1 g
F P
s
P
p
.002 w
.5956 .46758 m .623 .45028 L .60909 .42699 L p
1 g
F P
s
P
p
.002 w
.60255 .39037 m .6069 .37364 L .58121 .36665 L p
1 g
F P
s
P
p
.002 w
.58029 .35767 m .58121 .36665 L .6069 .37364 L p
1 g
F P
s
P
p
.002 w
.54987 .31039 m .53186 .31212 L .54352 .33576 L p
1 g
F P
s
P
p
.002 w
.54352 .33576 m .55257 .33495 L .54987 .31039 L p
1 g
F P
s
P
p
.002 w
.39633 .50937 m .44068 .54556 L .45391 .52595 L p
1 g
F P
s
P
p
.002 w
.45391 .52595 m .41257 .49219 L .39633 .50937 L p
1 g
F P
s
P
p
.002 w
.50259 .54699 m .45391 .52595 L .44068 .54556 L p
1 g
F P
s
P
p
.002 w
.42876 .3054 m .41476 .34184 L .44162 .34154 L p
1 g
F P
s
P
p
.002 w
.44162 .34154 m .4535 .31145 L .42876 .3054 L p
1 g
F P
s
P
p
.002 w
.3638 .4629 m .39633 .50937 L .41257 .49219 L p
1 g
F P
s
P
p
.002 w
.41257 .49219 m .38235 .44878 L .3638 .4629 L p
1 g
F P
s
P
p
.002 w
.6069 .37364 m .60518 .35575 L .58029 .35767 L p
1 g
F P
s
P
p
.002 w
.5764 .34915 m .58029 .35767 L .60518 .35575 L p
1 g
F P
s
P
p
.002 w
.56818 .31465 m .54987 .31039 L .55257 .33495 L p
1 g
F P
s
P
p
.002 w
.55257 .33495 m .56173 .33712 L .56818 .31465 L p
1 g
F P
s
P
p
.002 w
.6238 .40687 m .60909 .42699 L .623 .45028 L p
1 g
F P
s
P
p
.002 w
.60909 .42699 m .6238 .40687 L .60255 .39037 L p
1 g
F P
s
P
p
.002 w
.6069 .37364 m .60255 .39037 L .6238 .40687 L p
1 g
F P
s
P
p
.002 w
.60518 .35575 m .59751 .33871 L .5764 .34915 L p
1 g
F P
s
P
p
.002 w
.56998 .34203 m .5764 .34915 L .59751 .33871 L p
1 g
F P
s
P
p
.002 w
.58469 .32446 m .56818 .31465 L .56173 .33712 L p
1 g
F P
s
P
p
.002 w
.56173 .33712 m .56998 .34203 L .58469 .32446 L p
1 g
F P
s
P
p
.002 w
.51913 .29094 m .49599 .30212 L .51614 .31955 L p
1 g
F P
s
P
p
.002 w
.51614 .31955 m .53186 .31212 L .51913 .29094 L p
1 g
F P
s
P
p
.002 w
.47551 .28756 m .4535 .31145 L .4789 .32033 L p
1 g
F P
s
P
p
.002 w
.4789 .32033 m .49599 .30212 L .47551 .28756 L p
1 g
F P
s
P
p
.002 w
.59751 .33871 m .58469 .32446 L .56998 .34203 L p
1 g
F P
s
P
p
.002 w
.60362 .51955 m .55876 .52871 L .55418 .55314 L p
1 g
F P
s
P
p
.002 w
.50259 .54699 m .55418 .55314 L .55876 .52871 L p
1 g
F P
s
P
p
.002 w
.55876 .52871 m .60362 .51955 L .60082 .49411 L p
1 g
F P
s
P
p
.002 w
.44068 .54556 m .49282 .56824 L .50259 .54699 L p
1 g
F P
s
P
p
.002 w
.55418 .55314 m .50259 .54699 L .49282 .56824 L p
1 g
F P
s
P
p
.002 w
.3664 .34919 m .36628 .39959 L .38905 .38998 L p
1 g
F P
s
P
p
.002 w
.38905 .38998 m .38949 .34438 L .3664 .34919 L p
1 g
F P
s
P
p
.002 w
.34631 .41026 m .3638 .4629 L .38235 .44878 L p
1 g
F P
s
P
p
.002 w
.38235 .44878 m .36628 .39959 L .34631 .41026 L p
1 g
F P
s
P
p
.002 w
.63408 .47353 m .60082 .49411 L .60362 .51955 L p
1 g
F P
s
P
p
.002 w
.60082 .49411 m .63408 .47353 L .623 .45028 L p
1 g
F P
s
P
p
.002 w
.6238 .40687 m .63045 .38221 L .6069 .37364 L p
1 g
F P
s
P
p
.002 w
.60518 .35575 m .6069 .37364 L .63045 .38221 L p
1 g
F P
s
P
p
.002 w
.54583 .28823 m .51913 .29094 L .53186 .31212 L p
1 g
F P
s
P
p
.002 w
.53186 .31212 m .54987 .31039 L .54583 .28823 L p
1 g
F P
s
P
p
.002 w
.40522 .30239 m .38949 .34438 L .41476 .34184 L p
1 g
F P
s
P
p
.002 w
.41476 .34184 m .42876 .3054 L .40522 .30239 L p
1 g
F P
s
P
p
.002 w
.64237 .42431 m .623 .45028 L .63408 .47353 L p
1 g
F P
s
P
p
.002 w
.623 .45028 m .64237 .42431 L .6238 .40687 L p
1 g
F P
s
P
p
.002 w
.63045 .38221 m .6238 .40687 L .64237 .42431 L p
1 g
F P
s
P
p
.002 w
.45513 .27629 m .42876 .3054 L .4535 .31145 L p
1 g
F P
s
P
p
.002 w
.4535 .31145 m .47551 .28756 L .45513 .27629 L p
1 g
F P
s
P
p
.002 w
.50558 .27276 m .47551 .28756 L .49599 .30212 L p
1 g
F P
s
P
p
.002 w
.49599 .30212 m .51913 .29094 L .50558 .27276 L p
1 g
F P
s
P
p
.002 w
.63045 .38221 m .62806 .35568 L .60518 .35575 L p
1 g
F P
s
P
p
.002 w
.59751 .33871 m .60518 .35575 L .62806 .35568 L p
1 g
F P
s
P
p
.002 w
.38225 .52503 m .42856 .56282 L .44068 .54556 L p
1 g
F P
s
P
p
.002 w
.44068 .54556 m .39633 .50937 L .38225 .52503 L p
1 g
F P
s
P
p
.002 w
.49282 .56824 m .44068 .54556 L .42856 .56282 L p
1 g
F P
s
P
p
.002 w
.57308 .29447 m .54583 .28823 L .54987 .31039 L p
1 g
F P
s
P
p
.002 w
.54987 .31039 m .56818 .31465 L .57308 .29447 L p
1 g
F P
s
P
p
.002 w
.34817 .47662 m .38225 .52503 L .39633 .50937 L p
1 g
F P
s
P
p
.002 w
.39633 .50937 m .3638 .4629 L .34817 .47662 L p
1 g
F P
s
P
p
.002 w
.62806 .35568 m .61674 .3303 L .59751 .33871 L p
1 g
F P
s
P
p
.002 w
.58469 .32446 m .59751 .33871 L .61674 .3303 L p
1 g
F P
s
P
p
.002 w
.60384 .54336 m .55418 .55314 L .54811 .5751 L p
1 g
F P
s
P
p
.002 w
.49282 .56824 m .54811 .5751 L .55418 .55314 L p
1 g
F P
s
P
p
.002 w
.55418 .55314 m .60384 .54336 L .60362 .51955 L p
1 g
F P
s
P
p
.002 w
.59768 .30906 m .57308 .29447 L .56818 .31465 L p
1 g
F P
s
P
p
.002 w
.56818 .31465 m .58469 .32446 L .59768 .30906 L p
1 g
F P
s
P
p
.002 w
.61674 .3303 m .59768 .30906 L .58469 .32446 L p
1 g
F P
s
P
p
.002 w
.642 .49625 m .60362 .51955 L .60384 .54336 L p
1 g
F P
s
P
p
.002 w
.60362 .51955 m .642 .49625 L .63408 .47353 L p
1 g
F P
s
P
p
.002 w
.3461 .35624 m .34631 .41026 L .36628 .39959 L p
1 g
F P
s
P
p
.002 w
.36628 .39959 m .3664 .34919 L .3461 .35624 L p
1 g
F P
s
P
p
.002 w
.42856 .56282 m .48295 .58661 L .49282 .56824 L p
1 g
F P
s
P
p
.002 w
.54811 .5751 m .49282 .56824 L .48295 .58661 L p
1 g
F P
s
P
p
.002 w
.64237 .42431 m .65128 .39223 L .63045 .38221 L p
1 g
F P
s
P
p
.002 w
.62806 .35568 m .63045 .38221 L .65128 .39223 L p
1 g
F P
s
P
p
.002 w
.3297 .42178 m .34817 .47662 L .3638 .4629 L p
1 g
F P
s
P
p
.002 w
.3638 .4629 m .34631 .41026 L .3297 .42178 L p
1 g
F P
s
P
p
.002 w
.38345 .30263 m .3664 .34919 L .38949 .34438 L p
1 g
F P
s
P
p
.002 w
.38949 .34438 m .40522 .30239 L .38345 .30263 L p
1 g
F P
s
P
p
.002 w
.65776 .44234 m .63408 .47353 L .642 .49625 L p
1 g
F P
s
P
p
.002 w
.63408 .47353 m .65776 .44234 L .64237 .42431 L p
1 g
F P
s
P
p
.002 w
.54048 .26904 m .50558 .27276 L .51913 .29094 L p
1 g
F P
s
P
p
.002 w
.51913 .29094 m .54583 .28823 L .54048 .26904 L p
1 g
F P
s
P
p
.002 w
.65128 .39223 m .64237 .42431 L .65776 .44234 L p
1 g
F P
s
P
p
.002 w
.4353 .26869 m .40522 .30239 L .42876 .3054 L p
1 g
F P
s
P
p
.002 w
.42876 .3054 m .45513 .27629 L .4353 .26869 L p
1 g
F P
s
P
p
.002 w
.49145 .25811 m .45513 .27629 L .47551 .28756 L p
1 g
F P
s
P
p
.002 w
.47551 .28756 m .50558 .27276 L .49145 .25811 L p
1 g
F P
s
P
p
.002 w
.65128 .39223 m .64835 .35753 L .62806 .35568 L p
1 g
F P
s
P
p
.002 w
.61674 .3303 m .62806 .35568 L .64835 .35753 L p
1 g
F P
s
P
p
.002 w
.57625 .27713 m .54048 .26904 L .54583 .28823 L p
1 g
F P
s
P
p
.002 w
.54583 .28823 m .57308 .29447 L .57625 .27713 L p
1 g
F P
s
P
p
.002 w
.37075 .53879 m .41789 .57723 L .42856 .56282 L p
1 g
F P
s
P
p
.002 w
.42856 .56282 m .38225 .52503 L .37075 .53879 L p
1 g
F P
s
P
p
.002 w
.48295 .58661 m .42856 .56282 L .41789 .57723 L p
1 g
F P
s
P
p
.002 w
.33597 .4896 m .37075 .53879 L .38225 .52503 L p
1 g
F P
s
P
p
.002 w
.38225 .52503 m .34817 .47662 L .33597 .4896 L p
1 g
F P
s
P
p
.002 w
.60139 .56494 m .54811 .5751 L .5406 .594 L p
1 g
F P
s
P
p
.002 w
.48295 .58661 m .5406 .594 L .54811 .5751 L p
1 g
F P
s
P
p
.002 w
.54811 .5751 m .60139 .56494 L .60384 .54336 L p
1 g
F P
s
P
p
.002 w
.64647 .51791 m .60384 .54336 L .60139 .56494 L p
1 g
F P
s
P
p
.002 w
.60384 .54336 m .64647 .51791 L .642 .49625 L p
1 g
F P
s
P
p
.002 w
.64835 .35753 m .6336 .3242 L .61674 .3303 L p
1 g
F P
s
P
p
.002 w
.59768 .30906 m .61674 .3303 L .6336 .3242 L p
1 g
F P
s
P
p
.002 w
.60859 .29627 m .57625 .27713 L .57308 .29447 L p
1 g
F P
s
P
p
.002 w
.57308 .29447 m .59768 .30906 L .60859 .29627 L p
1 g
F P
s
P
p
.002 w
.32919 .36549 m .3297 .42178 L .34631 .41026 L p
1 g
F P
s
P
p
.002 w
.34631 .41026 m .3461 .35624 L .32919 .36549 L p
1 g
F P
s
P
p
.002 w
.6336 .3242 m .60859 .29627 L .59768 .30906 L p
1 g
F P
s
P
p
.002 w
.65776 .44234 m .66882 .40356 L .65128 .39223 L p
1 g
F P
s
P
p
.002 w
.64835 .35753 m .65128 .39223 L .66882 .40356 L p
1 g
F P
s
P
p
.002 w
.36406 .30626 m .3461 .35624 L .3664 .34919 L p
1 g
F P
s
P
p
.002 w
.3664 .34919 m .38345 .30263 L .36406 .30626 L p
1 g
F P
s
P
p
.002 w
.6695 .4606 m .642 .49625 L .64647 .51791 L p
1 g
F P
s
P
p
.002 w
.642 .49625 m .6695 .4606 L .65776 .44234 L p
1 g
F P
s
P
p
.002 w
.41789 .57723 m .47319 .60154 L .48295 .58661 L p
1 g
F P
s
P
p
.002 w
.5406 .594 m .48295 .58661 L .47319 .60154 L p
1 g
F P
s
P
p
.002 w
.53388 .25341 m .49145 .25811 L .50558 .27276 L p
1 g
F P
s
P
p
.002 w
.50558 .27276 m .54048 .26904 L .53388 .25341 L p
1 g
F P
s
P
p
.002 w
.66882 .40356 m .65776 .44234 L .6695 .4606 L p
1 g
F P
s
P
p
.002 w
.317 .43393 m .33597 .4896 L .34817 .47662 L p
1 g
F P
s
P
p
.002 w
.34817 .47662 m .3297 .42178 L .317 .43393 L p
1 g
F P
s
P
p
.002 w
.41652 .26513 m .38345 .30263 L .40522 .30239 L p
1 g
F P
s
P
p
.002 w
.40522 .30239 m .4353 .26869 L .41652 .26513 L p
1 g
F P
s
P
p
.002 w
.47706 .24751 m .4353 .26869 L .45513 .27629 L p
1 g
F P
s
P
p
.002 w
.45513 .27629 m .49145 .25811 L .47706 .24751 L p
1 g
F P
s
P
p
.002 w
.66882 .40356 m .66545 .36136 L .64835 .35753 L p
1 g
F P
s
P
p
.002 w
.6336 .3242 m .64835 .35753 L .66545 .36136 L p
1 g
F P
s
P
p
.002 w
.57752 .26319 m .53388 .25341 L .54048 .26904 L p
1 g
F P
s
P
p
.002 w
.54048 .26904 m .57625 .27713 L .57752 .26319 L p
1 g
F P
s
P
p
.002 w
.36221 .5502 m .40898 .58833 L .41789 .57723 L p
1 g
F P
s
P
p
.002 w
.41789 .57723 m .37075 .53879 L .36221 .5502 L p
1 g
F P
s
P
p
.002 w
.47319 .60154 m .41789 .57723 L .40898 .58833 L p
1 g
F P
s
P
p
.002 w
.5406 .594 m .59619 .5837 L .60139 .56494 L p
1 g
F P
s
P
p
.002 w
.64722 .53796 m .60139 .56494 L .59619 .5837 L p
1 g
F P
s
P
p
.002 w
.60139 .56494 m .64722 .53796 L .64647 .51791 L p
1 g
F P
s
P
p
.002 w
.47319 .60154 m .53177 .60925 L .5406 .594 L p
1 g
F P
s
P
p
.002 w
.59619 .5837 m .5406 .594 L .53177 .60925 L p
1 g
F P
s
P
p
.002 w
.32766 .5015 m .36221 .5502 L .37075 .53879 L p
1 g
F P
s
P
p
.002 w
.37075 .53879 m .33597 .4896 L .32766 .5015 L p
1 g
F P
s
P
p
.002 w
.31625 .37682 m .317 .43393 L .3297 .42178 L p
1 g
F P
s
P
p
.002 w
.3297 .42178 m .32919 .36549 L .31625 .37682 L p
1 g
F P
s
P
p
.002 w
.67716 .47866 m .64647 .51791 L .64722 .53796 L p
1 g
F P
s
P
p
.002 w
.64647 .51791 m .67716 .47866 L .6695 .4606 L p
1 g
F P
s
P
p
.002 w
.66545 .36136 m .64757 .32069 L .6336 .3242 L p
1 g
F P
s
P
p
.002 w
.60859 .29627 m .6336 .3242 L .64757 .32069 L p
1 g
F P
s
P
p
.002 w
.34763 .31336 m .32919 .36549 L .3461 .35624 L p
1 g
F P
s
P
p
.002 w
.3461 .35624 m .36406 .30626 L .34763 .31336 L p
1 g
F P
s
P
p
.002 w
.6695 .4606 m .6825 .41598 L .66882 .40356 L p
1 g
F P
s
P
p
.002 w
.66545 .36136 m .66882 .40356 L .6825 .41598 L p
1 g
F P
s
P
p
.002 w
.61705 .28655 m .57752 .26319 L .57625 .27713 L p
1 g
F P
s
P
p
.002 w
.57625 .27713 m .60859 .29627 L .61705 .28655 L p
1 g
F P
s
P
p
.002 w
.6825 .41598 m .6695 .4606 L .67716 .47866 L p
1 g
F P
s
P
p
.002 w
.52612 .24192 m .47706 .24751 L .49145 .25811 L p
1 g
F P
s
P
p
.002 w
.49145 .25811 m .53388 .25341 L .52612 .24192 L p
1 g
F P
s
P
p
.002 w
.64757 .32069 m .61705 .28655 L .60859 .29627 L p
1 g
F P
s
P
p
.002 w
.39931 .2659 m .36406 .30626 L .38345 .30263 L p
1 g
F P
s
P
p
.002 w
.38345 .30263 m .41652 .26513 L .39931 .2659 L p
1 g
F P
s
P
p
.002 w
.40898 .58833 m .46376 .61251 L .47319 .60154 L p
1 g
F P
s
P
p
.002 w
.53177 .60925 m .47319 .60154 L .46376 .61251 L p
1 g
F P
s
P
p
.002 w
.46275 .24145 m .41652 .26513 L .4353 .26869 L p
1 g
F P
s
P
p
.002 w
.4353 .26869 m .47706 .24751 L .46275 .24145 L p
1 g
F P
s
P
p
.002 w
.30874 .44645 m .32766 .5015 L .33597 .4896 L p
1 g
F P
s
P
p
.002 w
.33597 .4896 m .317 .43393 L .30874 .44645 L p
1 g
F P
s
P
p
.002 w
.6825 .41598 m .67877 .36719 L .66545 .36136 L p
1 g
F P
s
P
p
.002 w
.64757 .32069 m .66545 .36136 L .67877 .36719 L p
1 g
F P
s
P
p
.002 w
.57676 .25319 m .52612 .24192 L .53388 .25341 L p
1 g
F P
s
P
p
.002 w
.53388 .25341 m .57752 .26319 L .57676 .25319 L p
1 g
F P
s
P
p
.002 w
.53177 .60925 m .58822 .59902 L .59619 .5837 L p
1 g
F P
s
P
p
.002 w
.64405 .55584 m .59619 .5837 L .58822 .59902 L p
1 g
F P
s
P
p
.002 w
.59619 .5837 m .64405 .55584 L .64722 .53796 L p
1 g
F P
s
P
p
.002 w
.46376 .61251 m .52174 .62028 L .53177 .60925 L p
1 g
F P
s
P
p
.002 w
.58822 .59902 m .53177 .60925 L .52174 .62028 L p
1 g
F P
s
P
p
.002 w
.35704 .55887 m .40214 .59564 L .40898 .58833 L p
1 g
F P
s
P
p
.002 w
.40898 .58833 m .36221 .5502 L .35704 .55887 L p
1 g
F P
s
P
p
.002 w
.46376 .61251 m .40898 .58833 L .40214 .59564 L p
1 g
F P
s
P
p
.002 w
.68032 .49607 m .64722 .53796 L .64405 .55584 L p
1 g
F P
s
P
p
.002 w
.64722 .53796 m .68032 .49607 L .67716 .47866 L p
1 g
F P
s
P
p
.002 w
.32369 .51197 m .35704 .55887 L .36221 .5502 L p
1 g
F P
s
P
p
.002 w
.36221 .5502 m .32766 .5015 L .32369 .51197 L p
1 g
F P
s
P
p
.002 w
.33476 .32394 m .31625 .37682 L .32919 .36549 L p
1 g
F P
s
P
p
.002 w
.32919 .36549 m .34763 .31336 L .33476 .32394 L p
1 g
F P
s
P
p
.002 w
.30785 .39006 m .30874 .44645 L .317 .43393 L p
1 g
F P
s
P
p
.002 w
.317 .43393 m .31625 .37682 L .30785 .39006 L p
1 g
F P
s
P
p
.002 w
.67716 .47866 m .69178 .42925 L .6825 .41598 L p
1 g
F P
s
P
p
.002 w
.67877 .36719 m .6825 .41598 L .69178 .42925 L p
1 g
F P
s
P
p
.002 w
.69178 .42925 m .67716 .47866 L .68032 .49607 L p
1 g
F P
s
P
p
.002 w
.67877 .36719 m .65813 .31999 L .64757 .32069 L p
1 g
F P
s
P
p
.002 w
.61705 .28655 m .64757 .32069 L .65813 .31999 L p
1 g
F P
s
P
p
.002 w
.38421 .27123 m .34763 .31336 L .36406 .30626 L p
1 g
F P
s
P
p
.002 w
.36406 .30626 m .39931 .2659 L .38421 .27123 L p
1 g
F P
s
P
p
.002 w
.62269 .28031 m .57676 .25319 L .57752 .26319 L p
1 g
F P
s
P
p
.002 w
.57752 .26319 m .61705 .28655 L .62269 .28031 L p
1 g
F P
s
P
p
.002 w
.51733 .23512 m .46275 .24145 L .47706 .24751 L p
1 g
F P
s
P
p
.002 w
.47706 .24751 m .52612 .24192 L .51733 .23512 L p
1 g
F P
s
P
p
.002 w
.44889 .24034 m .39931 .2659 L .41652 .26513 L p
1 g
F P
s
P
p
.002 w
.41652 .26513 m .46275 .24145 L .44889 .24034 L p
1 g
F P
s
P
p
.002 w
.65813 .31999 m .62269 .28031 L .61705 .28655 L p
1 g
F P
s
P
p
.002 w
.40214 .59564 m .45494 .61899 L .46376 .61251 L p
1 g
F P
s
P
p
.002 w
.52174 .62028 m .46376 .61251 L .45494 .61899 L p
1 g
F P
s
P
p
.002 w
.3054 .45904 m .32369 .51197 L .32766 .5015 L p
1 g
F P
s
P
p
.002 w
.32766 .5015 m .30874 .44645 L .3054 .45904 L p
1 g
F P
s
P
p
.002 w
.69178 .42925 m .68776 .37498 L .67877 .36719 L p
1 g
F P
s
P
p
.002 w
.65813 .31999 m .67877 .36719 L .68776 .37498 L p
1 g
F P
s
P
p
.002 w
.52174 .62028 m .57755 .61033 L .58822 .59902 L p
1 g
F P
s
P
p
.002 w
.63683 .57096 m .58822 .59902 L .57755 .61033 L p
1 g
F P
s
P
p
.002 w
.58822 .59902 m .63683 .57096 L .64405 .55584 L p
1 g
F P
s
P
p
.002 w
.57384 .24766 m .51733 .23512 L .52612 .24192 L p
1 g
F P
s
P
p
.002 w
.52612 .24192 m .57676 .25319 L .57384 .24766 L p
1 g
F P
s
P
p
.002 w
.67866 .51234 m .64405 .55584 L .63683 .57096 L p
1 g
F P
s
P
p
.002 w
.64405 .55584 m .67866 .51234 L .68032 .49607 L p
1 g
F P
s
P
p
.002 w
.45494 .61899 m .51072 .62656 L .52174 .62028 L p
1 g
F P
s
P
p
.002 w
.57755 .61033 m .52174 .62028 L .51072 .62656 L p
1 g
F P
s
P
p
.002 w
.32603 .33791 m .30785 .39006 L .31625 .37682 L p
1 g
F P
s
P
p
.002 w
.31625 .37682 m .33476 .32394 L .32603 .33791 L p
1 g
F P
s
P
p
.002 w
.68032 .49607 m .69617 .44307 L .69178 .42925 L p
1 g
F P
s
P
p
.002 w
.68776 .37498 m .69178 .42925 L .69617 .44307 L p
1 g
F P
s
P
p
.002 w
.69617 .44307 m .68032 .49607 L .67866 .51234 L p
1 g
F P
s
P
p
.002 w
.30448 .40494 m .3054 .45904 L .30874 .44645 L p
1 g
F P
s
P
p
.002 w
.30874 .44645 m .30785 .39006 L .30448 .40494 L p
1 g
F P
s
P
p
.002 w
.35557 .56437 m .39771 .59872 L .40214 .59564 L p
1 g
F P
s
P
p
.002 w
.40214 .59564 m .35704 .55887 L .35557 .56437 L p
1 g
F P
s
P
p
.002 w
.45494 .61899 m .40214 .59564 L .39771 .59872 L p
1 g
F P
s
P
p
.002 w
.32442 .52062 m .35557 .56437 L .35704 .55887 L p
1 g
F P
s
P
p
.002 w
.35704 .55887 m .32369 .51197 L .32442 .52062 L p
1 g
F P
s
P
p
.002 w
.37177 .28123 m .33476 .32394 L .34763 .31336 L p
1 g
F P
s
P
p
.002 w
.34763 .31336 m .38421 .27123 L .37177 .28123 L p
1 g
F P
s
P
p
.002 w
.50767 .23349 m .44889 .24034 L .46275 .24145 L p
1 g
F P
s
P
p
.002 w
.46275 .24145 m .51733 .23512 L .50767 .23349 L p
1 g
F P
s
P
p
.002 w
.68776 .37498 m .66478 .32232 L .65813 .31999 L p
1 g
F P
s
P
p
.002 w
.62269 .28031 m .65813 .31999 L .66478 .32232 L p
1 g
F P
s
P
p
.002 w
.43591 .24453 m .38421 .27123 L .39931 .2659 L p
1 g
F P
s
P
p
.002 w
.39931 .2659 m .44889 .24034 L .43591 .24453 L p
1 g
F P
s
P
p
.002 w
.62518 .27796 m .57384 .24766 L .57676 .25319 L p
1 g
F P
s
P
p
.002 w
.57676 .25319 m .62269 .28031 L .62518 .27796 L p
1 g
F P
s
P
p
.002 w
.39771 .59872 m .44698 .62055 L .45494 .61899 L p
1 g
F P
s
P
p
.002 w
.51072 .62656 m .45494 .61899 L .44698 .62055 L p
1 g
F P
s
P
p
.002 w
.66478 .32232 m .62518 .27796 L .62269 .28031 L p
1 g
F P
s
P
p
.002 w
.30737 .47135 m .32442 .52062 L .32369 .51197 L p
1 g
F P
s
P
p
.002 w
.32369 .51197 m .3054 .45904 L .30737 .47135 L p
1 g
F P
s
P
p
.004 w
.38978 .70811 m
.42233 .62613 L
s
P
p
.002 w
.69617 .44307 m .69189 .38464 L .68776 .37498 L p
1 g
F P
s
P
p
.002 w
.66478 .32232 m .68776 .37498 L .69189 .38464 L p
1 g
F P
s
P
p
.002 w
.51072 .62656 m .56429 .61709 L .57755 .61033 L p
1 g
F P
s
P
p
.002 w
.57755 .61033 m .62551 .58275 L .63683 .57096 L p
1 g
F P
s
P
p
.002 w
.62551 .58275 m .57755 .61033 L .56429 .61709 L p
1 g
F P
s
P
p
.002 w
.63683 .57096 m .67194 .52696 L .67866 .51234 L p
1 g
F P
s
P
p
.002 w
.67194 .52696 m .63683 .57096 L .62551 .58275 L p
1 g
F P
s
P
p
.002 w
.56871 .24703 m .50767 .23349 L .51733 .23512 L p
1 g
F P
s
P
p
.002 w
.51733 .23512 m .57384 .24766 L .56871 .24703 L p
1 g
F P
s
P
p
.002 w
.44698 .62055 m .49894 .62763 L .51072 .62656 L p
1 g
F P
s
P
p
.002 w
.56429 .61709 m .51072 .62656 L .49894 .62763 L p
1 g
F P
s
P
p
.002 w
.32191 .35506 m .30448 .40494 L .30785 .39006 L p
1 g
F P
s
P
p
.002 w
.30785 .39006 m .32603 .33791 L .32191 .35506 L p
1 g
F P
s
P
p
.002 w
.67866 .51234 m .69524 .4571 L .69617 .44307 L p
1 g
F P
s
P
p
.002 w
.69524 .4571 m .67866 .51234 L .67194 .52696 L p
1 g
F P
s
P
p
.002 w
.69189 .38464 m .69617 .44307 L .69524 .4571 L p
1 g
F P
s
P
p
.002 w
.36251 .29588 m .32603 .33791 L .33476 .32394 L p
1 g
F P
s
P
p
.002 w
.33476 .32394 m .37177 .28123 L .36251 .29588 L p
1 g
F P
s
P
p
.002 w
.30655 .42114 m .30737 .47135 L .3054 .45904 L p
1 g
F P
s
P
p
.002 w
.3054 .45904 m .30448 .40494 L .30655 .42114 L p
1 g
F P
s
P
p
.002 w
.3581 .56636 m .39595 .59721 L .39771 .59872 L p
1 g
F P
s
P
p
.002 w
.39771 .59872 m .35557 .56437 L .3581 .56636 L p
1 g
F P
s
P
p
.002 w
.44698 .62055 m .39771 .59872 L .39595 .59721 L p
1 g
F P
s
P
p
.002 w
.49739 .23741 m .43591 .24453 L .44889 .24034 L p
1 g
F P
s
P
p
.002 w
.44889 .24034 m .50767 .23349 L .49739 .23741 L p
1 g
F P
s
P
p
.002 w
.33016 .5271 m .3581 .56636 L .35557 .56437 L p
1 g
F P
s
P
p
.002 w
.35557 .56437 m .32442 .52062 L .33016 .5271 L p
1 g
F P
s
P
p
.002 w
.42424 .25421 m .37177 .28123 L .38421 .27123 L p
1 g
F P
s
P
p
.002 w
.38421 .27123 m .43591 .24453 L .42424 .25421 L p
1 g
F P
s
P
p
.002 w
.69189 .38464 m .66708 .32779 L .66478 .32232 L p
1 g
F P
s
P
p
.002 w
.62518 .27796 m .66478 .32232 L .66708 .32779 L p
1 g
F P
s
P
p
.002 w
.62425 .27982 m .56871 .24703 L .57384 .24766 L p
1 g
F P
s
P
p
.002 w
.57384 .24766 m .62518 .27796 L .62425 .27982 L p
1 g
F P
s
P
p
.002 w
.39595 .59721 m .44017 .6168 L .44698 .62055 L p
1 g
F P
s
P
p
.004 w
.42815 .61147 m
.5 .43051 L
s
P
p
.004 w
.42743 .61327 m
.42796 .61193 L
s
P
p
.004 w
.42233 .62613 m
.42743 .61327 L
s
P
p
.002 w
.49894 .62763 m .44698 .62055 L .44017 .6168 L p
1 g
F P
s
P
p
.002 w
.66708 .32779 m .62425 .27982 L .62518 .27796 L p
1 g
F P
s
P
p
.002 w
.31493 .483 m .33016 .5271 L .32442 .52062 L p
1 g
F P
s
P
p
.002 w
.32442 .52062 m .30737 .47135 L .31493 .483 L p
1 g
F P
s
P
p
.002 w
.49894 .62763 m .54869 .61881 L .56429 .61709 L p
1 g
F P
s
P
p
.002 w
.6102 .59067 m .56429 .61709 L .54869 .61881 L p
1 g
F P
s
P
p
.002 w
.56429 .61709 m .6102 .59067 L .62551 .58275 L p
1 g
F P
s
P
p
.002 w
.66006 .53939 m .62551 .58275 L .6102 .59067 L p
1 g
F P
s
P
p
.002 w
.62551 .58275 m .66006 .53939 L .67194 .52696 L p
1 g
F P
s
P
p
.002 w
.69524 .4571 m .69074 .39602 L .69189 .38464 L p
1 g
F P
s
P
p
.002 w
.66708 .32779 m .69189 .38464 L .69074 .39602 L p
1 g
F P
s
P
p
.002 w
.3228 .37502 m .30655 .42114 L .30448 .40494 L p
1 g
F P
s
P
p
.002 w
.30448 .40494 m .32191 .35506 L .3228 .37502 L p
1 g
F P
s
P
p
.002 w
.56138 .25167 m .49739 .23741 L .50767 .23349 L p
1 g
F P
s
P
p
.002 w
.50767 .23349 m .56871 .24703 L .56138 .25167 L p
1 g
F P
s
P
p
.002 w
.68871 .47093 m .67194 .52696 L .66006 .53939 L p
1 g
F P
s
P
p
.002 w
.67194 .52696 m .68871 .47093 L .69524 .4571 L p
1 g
F P
s
P
p
.002 w
.54869 .61881 m .49894 .62763 L .4867 .62311 L p
1 g
F P
s
P
p
.002 w
.44017 .6168 m .4867 .62311 L .49894 .62763 L p
1 g
F P
s
P
p
.002 w
.35691 .31499 m .32191 .35506 L .32603 .33791 L p
1 g
F P
s
P
p
.002 w
.32603 .33791 m .36251 .29588 L .35691 .31499 L p
1 g
F P
s
P
p
.002 w
.69074 .39602 m .69524 .4571 L .68871 .47093 L p
1 g
F P
s
P
p
.002 w
.3143 .43822 m .31493 .483 L .30737 .47135 L p
1 g
F P
s
P
p
.002 w
.30737 .47135 m .30655 .42114 L .3143 .43822 L p
1 g
F P
s
P
p
.002 w
.41432 .2694 m .36251 .29588 L .37177 .28123 L p
1 g
F P
s
P
p
.002 w
.37177 .28123 m .42424 .25421 L .41432 .2694 L p
1 g
F P
s
P
p
.002 w
.48676 .2471 m .42424 .25421 L .43591 .24453 L p
1 g
F P
s
P
p
.002 w
.43591 .24453 m .49739 .23741 L .48676 .2471 L p
1 g
F P
s
P
p
.002 w
.36482 .56454 m .3971 .59085 L .39595 .59721 L p
1 g
F P
s
P
p
.002 w
.39595 .59721 m .3581 .56636 L .36482 .56454 L p
1 g
F P
s
P
p
.002 w
.44017 .6168 m .39595 .59721 L .3971 .59085 L p
1 g
F P
s
P
p
.002 w
.34104 .53107 m .36482 .56454 L .3581 .56636 L p
1 g
F P
s
P
p
.002 w
.3581 .56636 m .33016 .5271 L .34104 .53107 L p
1 g
F P
s
P
p
.002 w
.69074 .39602 m .66467 .33645 L .66708 .32779 L p
1 g
F P
s
P
p
.002 w
.62425 .27982 m .66708 .32779 L .66467 .33645 L p
1 g
F P
s
P
p
.002 w
.61968 .28612 m .56138 .25167 L .56871 .24703 L p
1 g
F P
s
P
p
.002 w
.56871 .24703 m .62425 .27982 L .61968 .28612 L p
1 g
F P
s
P
p
.002 w
.3971 .59085 m .4348 .60752 L .44017 .6168 L p
1 g
F P
s
P
p
.002 w
.4867 .62311 m .44017 .6168 L .4348 .60752 L p
1 g
F P
s
P
p
.002 w
.32818 .49358 m .34104 .53107 L .33016 .5271 L p
1 g
F P
s
P
p
.002 w
.33016 .5271 m .31493 .483 L .32818 .49358 L p
1 g
F P
s
P
p
.002 w
.66467 .33645 m .61968 .28612 L .62425 .27982 L p
1 g
F P
s
P
p
.002 w
.4867 .62311 m .53107 .61516 L .54869 .61881 L p
1 g
F P
s
P
p
.002 w
.59112 .59426 m .54869 .61881 L .53107 .61516 L p
1 g
F P
s
P
p
.002 w
.54869 .61881 m .59112 .59426 L .6102 .59067 L p
1 g
F P
s
P
p
.002 w
.64311 .54913 m .6102 .59067 L .59112 .59426 L p
1 g
F P
s
P
p
.002 w
.6102 .59067 m .64311 .54913 L .66006 .53939 L p
1 g
F P
s
P
p
.002 w
.68871 .47093 m .684 .40887 L .69074 .39602 L p
1 g
F P
s
P
p
.002 w
.66467 .33645 m .69074 .39602 L .684 .40887 L p
1 g
F P
s
P
p
.002 w
.32895 .39731 m .3143 .43822 L .30655 .42114 L p
1 g
F P
s
P
p
.002 w
.30655 .42114 m .3228 .37502 L .32895 .39731 L p
1 g
F P
s
P
p
.002 w
.67644 .48413 m .66006 .53939 L .64311 .54913 L p
1 g
F P
s
P
p
.002 w
.66006 .53939 m .67644 .48413 L .68871 .47093 L p
1 g
F P
s
P
p
.002 w
.35534 .33819 m .3228 .37502 L .32191 .35506 L p
1 g
F P
s
P
p
.002 w
.32191 .35506 m .35691 .31499 L .35534 .33819 L p
1 g
F P
s
P
p
.002 w
.55193 .26175 m .48676 .2471 L .49739 .23741 L p
1 g
F P
s
P
p
.002 w
.49739 .23741 m .56138 .25167 L .55193 .26175 L p
1 g
F P
s
P
p
.002 w
.53107 .61516 m .4867 .62311 L .47435 .61282 L p
1 g
F P
s
P
p
.002 w
.4348 .60752 m .47435 .61282 L .4867 .62311 L p
1 g
F P
s
P
p
.002 w
.684 .40887 m .68871 .47093 L .67644 .48413 L p
1 g
F P
s
P
p
.002 w
.40658 .28993 m .35691 .31499 L .36251 .29588 L p
1 g
F P
s
P
p
.002 w
.36251 .29588 m .41432 .2694 L .40658 .28993 L p
1 g
F P
s
P
p
.002 w
.32781 .45569 m .32818 .49358 L .31493 .483 L p
1 g
F P
s
P
p
.002 w
.31493 .483 m .3143 .43822 L .32781 .45569 L p
1 g
F P
s
P
p
.002 w
.47611 .26261 m .41432 .2694 L .42424 .25421 L p
1 g
F P
s
P
p
.002 w
.42424 .25421 m .48676 .2471 L .47611 .26261 L p
1 g
F P
s
P
p
.002 w
.37579 .5587 m .40131 .57952 L .3971 .59085 L p
1 g
F P
s
P
p
.002 w
.3971 .59085 m .36482 .56454 L .37579 .5587 L p
1 g
F P
s
P
p
.002 w
.4348 .60752 m .3971 .59085 L .40131 .57952 L p
1 g
F P
s
P
p
.002 w
.35704 .53224 m .37579 .5587 L .36482 .56454 L p
1 g
F P
s
P
p
.002 w
.36482 .56454 m .34104 .53107 L .35704 .53224 L p
1 g
F P
s
P
p
.002 w
.684 .40887 m .65733 .34825 L .66467 .33645 L p
1 g
F P
s
P
p
.002 w
.61968 .28612 m .66467 .33645 L .65733 .34825 L p
1 g
F P
s
P
p
.002 w
.61139 .29694 m .55193 .26175 L .56138 .25167 L p
1 g
F P
s
P
p
.002 w
.56138 .25167 m .61968 .28612 L .61139 .29694 L p
1 g
F P
s
P
p
.002 w
.40131 .57952 m .43112 .59266 L .4348 .60752 L p
1 g
F P
s
P
p
.002 w
.47435 .61282 m .4348 .60752 L .43112 .59266 L p
1 g
F P
s
P
p
.002 w
.34701 .50268 m .35704 .53224 L .34104 .53107 L p
1 g
F P
s
P
p
.002 w
.34104 .53107 m .32818 .49358 L .34701 .50268 L p
1 g
F P
s
P
p
.002 w
.65733 .34825 m .61139 .29694 L .61968 .28612 L p
1 g
F P
s
P
p
.002 w
.53107 .61516 m .5687 .59315 L .59112 .59426 L p
1 g
F P
s
P
p
.002 w
.62134 .55572 m .59112 .59426 L .5687 .59315 L p
1 g
F P
s
P
p
.002 w
.59112 .59426 m .62134 .55572 L .64311 .54913 L p
1 g
F P
s
P
p
.002 w
.47435 .61282 m .5119 .60594 L .53107 .61516 L p
1 g
F P
s
P
p
.002 w
.5687 .59315 m .53107 .61516 L .5119 .60594 L p
1 g
F P
s
P
p
.002 w
.65851 .49622 m .64311 .54913 L .62134 .55572 L p
1 g
F P
s
P
p
.002 w
.64311 .54913 m .65851 .49622 L .67644 .48413 L p
1 g
F P
s
P
p
.002 w
.34041 .42129 m .32781 .45569 L .3143 .43822 L p
1 g
F P
s
P
p
.002 w
.3143 .43822 m .32895 .39731 L .34041 .42129 L p
1 g
F P
s
P
p
.002 w
.35807 .36487 m .32895 .39731 L .3228 .37502 L p
1 g
F P
s
P
p
.002 w
.3228 .37502 m .35534 .33819 L .35807 .36487 L p
1 g
F P
s
P
p
.002 w
.67644 .48413 m .67157 .42286 L .684 .40887 L p
1 g
F P
s
P
p
.002 w
.65733 .34825 m .684 .40887 L .67157 .42286 L p
1 g
F P
s
P
p
.002 w
.67157 .42286 m .67644 .48413 L .65851 .49622 L p
1 g
F P
s
P
p
.002 w
.5119 .60594 m .47435 .61282 L .4623 .59673 L p
1 g
F P
s
P
p
.002 w
.43112 .59266 m .4623 .59673 L .47435 .61282 L p
1 g
F P
s
P
p
.002 w
.40141 .31534 m .35534 .33819 L .35691 .31499 L p
1 g
F P
s
P
p
.002 w
.35691 .31499 m .40658 .28993 L .40141 .31534 L p
1 g
F P
s
P
p
.002 w
.54056 .27729 m .47611 .26261 L .48676 .2471 L p
1 g
F P
s
P
p
.002 w
.48676 .2471 m .55193 .26175 L .54056 .27729 L p
1 g
F P
s
P
p
.002 w
.3469 .47297 m .34701 .50268 L .32818 .49358 L p
1 g
F P
s
P
p
.002 w
.32818 .49358 m .32781 .45569 L .3469 .47297 L p
1 g
F P
s
P
p
.002 w
.46579 .28372 m .40658 .28993 L .41432 .2694 L p
1 g
F P
s
P
p
.002 w
.41432 .2694 m .47611 .26261 L .46579 .28372 L p
1 g
F P
s
P
p
.002 w
.3909 .54881 m .40865 .56328 L .40131 .57952 L p
1 g
F P
s
P
p
.002 w
.40131 .57952 m .37579 .5587 L .3909 .54881 L p
1 g
F P
s
P
p
.002 w
.43112 .59266 m .40131 .57952 L .40865 .56328 L p
1 g
F P
s
P
p
.002 w
.37793 .53041 m .3909 .54881 L .37579 .5587 L p
1 g
F P
s
P
p
.002 w
.37579 .5587 m .35704 .53224 L .37793 .53041 L p
1 g
F P
s
P
p
.002 w
.67157 .42286 m .645 .36296 L .65733 .34825 L p
1 g
F P
s
P
p
.002 w
.61139 .29694 m .65733 .34825 L .645 .36296 L p
1 g
F P
s
P
p
.002 w
.59943 .31219 m .54056 .27729 L .55193 .26175 L p
1 g
F P
s
P
p
.002 w
.55193 .26175 m .61139 .29694 L .59943 .31219 L p
1 g
F P
s
P
p
.002 w
.5119 .60594 m .54351 .58717 L .5687 .59315 L p
1 g
F P
s
P
p
.002 w
.59525 .55877 m .5687 .59315 L .54351 .58717 L p
1 g
F P
s
P
p
.002 w
.5687 .59315 m .59525 .55877 L .62134 .55572 L p
1 g
F P
s
P
p
.002 w
.40865 .56328 m .42936 .57237 L .43112 .59266 L p
1 g
F P
s
P
p
.002 w
.4623 .59673 m .43112 .59266 L .42936 .57237 L p
1 g
F P
s
P
p
.002 w
.4623 .59673 m .49173 .59117 L .5119 .60594 L p
1 g
F P
s
P
p
.002 w
.54351 .58717 m .5119 .60594 L .49173 .59117 L p
1 g
F P
s
P
p
.002 w
.37108 .50992 m .37793 .53041 L .35704 .53224 L p
1 g
F P
s
P
p
.002 w
.35704 .53224 m .34701 .50268 L .37108 .50992 L p
1 g
F P
s
P
p
.002 w
.63523 .50673 m .62134 .55572 L .59525 .55877 L p
1 g
F P
s
P
p
.002 w
.62134 .55572 m .63523 .50673 L .65851 .49622 L p
1 g
F P
s
P
p
.002 w
.36517 .39424 m .34041 .42129 L .32895 .39731 L p
1 g
F P
s
P
p
.002 w
.32895 .39731 m .35807 .36487 L .36517 .39424 L p
1 g
F P
s
P
p
.002 w
.357 .44619 m .3469 .47297 L .32781 .45569 L p
1 g
F P
s
P
p
.002 w
.32781 .45569 m .34041 .42129 L .357 .44619 L p
1 g
F P
s
P
p
.002 w
.645 .36296 m .59943 .31219 L .61139 .29694 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.65851 .49622 m .65353 .43758 L .67157 .42286 L p
1 g
F P
s
P
p
.002 w
.645 .36296 m .67157 .42286 L .65353 .43758 L p
1 g
F P
s
P
p
.002 w
.39909 .34497 m .35807 .36487 L .35534 .33819 L p
1 g
F P
s
P
p
.002 w
.35534 .33819 m .40141 .31534 L .39909 .34497 L p
1 g
F P
s
P
p
.002 w
.65353 .43758 m .65851 .49622 L .63523 .50673 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.49173 .59117 m .4623 .59673 L .45097 .5751 L p
1 g
F P
s
P
p
.002 w
.42936 .57237 m .45097 .5751 L .4623 .59673 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.52756 .29802 m .46579 .28372 L .47611 .26261 L p
1 g
F P
s
P
p
.002 w
.47611 .26261 m .54056 .27729 L .52756 .29802 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.37117 .48944 m .37108 .50992 L .34701 .50268 L p
1 g
F P
s
P
p
.002 w
.34701 .50268 m .3469 .47297 L .37117 .48944 L p
1 g
F P
s
P
p
.002 w
.45621 .30996 m .40141 .31534 L .40658 .28993 L p
1 g
F P
s
P
p
.002 w
.40658 .28993 m .46579 .28372 L .45621 .30996 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49173 .59117 m .50753 .5816 L p
.54351 .58717 L 1 g
F P
s
P
p
.002 w
.50753 .5816 m .50871 .58089 L p
.50968 .58106 L 1 g
F P
s
P
p
.54351 .58717 m .50753 .5816 L .50968 .58106 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58074 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58074 L .5199 .57849 L 1 g
F
P
p
.002 w
.51095 .58074 m .51079 .57862 L p
.50043 .58069 L 1 g
F P
s
P
p
.002 w
.49173 .59117 m .48053 .58022 L p
.48908 .58042 L 1 g
F P
s
P
p
.002 w
.50871 .58089 m .50367 .58394 L p
.48908 .58042 L 1 g
F P
s
P
p
.002 w
.50367 .58394 m .49173 .59117 L p
.48908 .58042 L 1 g
F P
s
P
p
.002 w
.48908 .58042 m .48921 .57862 L p
.47781 .57768 L 1 g
F P
s
P
p
.49173 .59117 m .46225 .57288 L .46826 .57474 L 1 g
F
P
p
.002 w
.47801 .57775 m .48357 .58319 L p
.46826 .57474 L 1 g
F P
s
P
p
.002 w
.48357 .58319 m .49173 .59117 L p
.46826 .57474 L 1 g
F P
s
P
p
.002 w
.45097 .5751 m .46225 .57288 L p
.49173 .59117 L 1 g
F P
s
P
p
.002 w
.46826 .57474 m .46872 .57265 L p
.45884 .5687 L 1 g
F P
s
P
p
.002 w
.45097 .5751 m .44472 .55871 L p
.45081 .56303 L 1 g
F P
s
P
p
.002 w
.46421 .5725 m .45952 .57342 L p
.45081 .56303 L 1 g
F P
s
P
p
.002 w
.45952 .57342 m .45097 .5751 L p
.45081 .56303 L 1 g
F P
s
P
p
.002 w
.45081 .56303 m .45146 .56129 L p
.44374 .55458 L 1 g
F P
s
P
p
.45884 .5687 m .46421 .5725 L .46826 .57474 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.47781 .57768 m .47801 .57775 L .48908 .58042 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46813 .57536 L p
1 g
F P
s
P
p
.48921 .57862 m .46813 .57536 L .47772 .57768 L 1 g
F
P
p
.50043 .58069 m .50871 .58089 L .51095 .58074 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.50871 .58089 m .48908 .58042 L .47124 .57112 L 1 g
F
P
p
.002 w
.48053 .58022 m .47801 .57775 L p
.48908 .58042 L 1 g
F P
s
P
p
.002 w
.47801 .57775 m .47124 .57112 L p
.48908 .58042 L 1 g
F P
s
P
p
.002 w
.46813 .57536 m .4678 .57686 L p
.47772 .57768 L 1 g
F P
s
P
p
.002 w
.47124 .57112 m .47801 .57775 L p
.46826 .57474 L 1 g
F P
s
P
p
.002 w
.46225 .57288 m .46421 .5725 L p
.46826 .57474 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45017 .56475 L p
1 g
F P
s
P
p
.46872 .57265 m .45017 .56475 L .45338 .56652 L 1 g
F
P
p
.002 w
.46421 .5725 m .47124 .57112 L p
.46826 .57474 L 1 g
F P
s
P
p
.002 w
.45017 .56475 m .45002 .56518 L p
.45338 .56652 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43819 .54766 L p
1 g
F P
s
P
p
.45146 .56129 m .43819 .54766 L .43836 .54791 L 1 g
F
P
p
.002 w
.4297 .54708 m .43062 .53616 L p
.43819 .54766 L 1 g
F P
s
P
p
.002 w
.43851 .54815 m .43833 .54813 L p
.43819 .54766 L 1 g
F P
s
P
p
.002 w
.43833 .54813 m .4297 .54708 L p
.43819 .54766 L 1 g
F P
s
P
p
.002 w
.43819 .54766 m .43925 .54566 L p
.43517 .53758 L 1 g
F P
s
P
p
.45146 .56129 m .43836 .54791 L .439 .54875 L 1 g
F
P
p
.43836 .54791 m .43816 .54771 L .43851 .54815 L 1 g
F
P
p
.43836 .54791 m .43851 .54815 L .439 .54875 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52873 L p
1 g
F P
s
P
p
.002 w
.43062 .53616 m .43153 .52545 L p
.43251 .52873 L 1 g
F P
s
P
p
.43819 .54766 m .43208 .53837 L .43251 .52873 L 1 g
F
P
p
.43208 .53837 m .43062 .53616 L .43251 .52873 L 1 g
F
P
p
.002 w
.43251 .52873 m .43346 .52734 L p
.43309 .51686 L 1 g
F P
s
P
p
.002 w
.43308 .517 m .4322 .51748 L .43315 .51635 L p
1 g
F P
s
P
p
.43309 .51686 m .43309 .51686 L .43309 .51688 L 1 g
F
P
p
.43309 .51686 m .43309 .51688 L .43251 .52873 L 1 g
F
P
p
.43309 .51686 m .43309 .51693 L .43251 .52873 L 1 g
F
P
p
.43309 .51682 m .43308 .517 L .43251 .52873 L 1 g
F
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43118 .48348 m .43642 .48487 L p
.43301 .51121 L 1 g
F P
s
P
p
.002 w
.43207 .51317 m .43118 .48348 L p
.43301 .51121 L 1 g
F P
s
P
p
.002 w
.43386 .50944 m .43485 .50826 L p
.43838 .5 L 1 g
F P
s
P
p
.43838 .5 m .43711 .50266 L .43386 .50944 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43386 .50944 L p
1 g
F P
s
P
p
.43346 .52734 m .43386 .50944 L .43385 .50954 L 1 g
F
P
p
.002 w
.4334 .51386 m .4322 .51748 L p
.43642 .48487 L 1 g
F P
s
P
p
.43346 .52734 m .43385 .50945 L .43337 .51412 L 1 g
F
P
p
.002 w
.43315 .51635 m .4322 .51748 L .4334 .51386 L p
1 g
F P
s
P
p
.43346 .52734 m .43335 .51005 L .43307 .51619 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44247 .48647 m .44433 .4876 L p
.44247 .49148 L 1 g
F P
s
P
p
.44023 .49364 m .44247 .49148 L .43799 .50082 L 1 g
F
P
p
.44247 .48647 m .44247 .49148 L .44023 .49364 L 1 g
F
P
p
.002 w
.43642 .48487 m .44247 .48647 L .43711 .50266 L p
1 g
F P
s
P
p
.002 w
.44325 .49079 m .44239 .49162 L p
.43485 .50826 L 1 g
F P
s
P
p
.43485 .50826 m .44239 .49162 L .4384 .49997 L 1 g
F
P
p
.002 w
.43711 .50266 m .4334 .51386 L p
.43386 .50944 L 1 g
F P
s
P
p
.43642 .48487 m .43711 .50266 L .43386 .50944 L 1 g
F
P
p
.002 w
.44239 .49162 m .44166 .49233 L p
.4384 .49997 L 1 g
F P
s
P
p
.002 w
.44331 .49066 m .44339 .4905 L p
.44247 .49148 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44247 .49148 m .44339 .4905 L p
.45078 .48342 L 1 g
F P
s
P
p
.002 w
.45277 .49273 m .44565 .4884 L p
.45334 .48093 L 1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45334 .48093 m .46279 .47429 L .45277 .49273 L 1 g
F
P
p
.002 w
.47131 .47026 m .45277 .49273 L p
.46279 .47429 L 1 g
F P
s
P
p
.002 w
.4577 .4767 m .45826 .47608 L p
.46849 .47159 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47517 .46559 m .49856 .43709 L p
.49521 .4584 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49133 .48314 m .47698 .46755 L p
.47748 .4673 L 1 g
F P
s
P
p
.49422 .4647 m .49133 .48314 L .47748 .4673 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .4673 L p
1 g
F P
s
P
p
.45826 .47608 m .47748 .4673 L .47721 .46744 L 1 g
F
P
p
.45826 .47608 m .47747 .46732 L .47609 .46798 L 1 g
F
P
p
.002 w
.49133 .48314 m .46093 .50155 L p
.47379 .46908 L 1 g
F P
s
P
p
.47511 .46845 m .49133 .48314 L .47379 .46908 L 1 g
F
P
p
.002 w
.47684 .4674 m .47698 .46755 L p
.47432 .46773 L 1 g
F P
s
P
p
.002 w
.47698 .46755 m .49133 .48314 L p
.47511 .46845 L 1 g
F P
s
P
p
.45826 .47608 m .47609 .46798 L .46849 .47159 L 1 g
F
P
p
.47698 .46755 m .47511 .46845 L .47432 .46773 L 1 g
F
P
p
.47379 .46908 m .46093 .50155 L .47131 .47026 L 1 g
F
P
p
.47609 .46798 m .47744 .46736 L .47131 .47026 L 1 g
F
P
p
.47609 .46798 m .47131 .47026 L .46849 .47159 L 1 g
F
P
p
.002 w
.46093 .50155 m .45277 .49273 L .47131 .47026 L p
1 g
F P
s
P
p
.002 w
.47744 .46736 m .47718 .46778 L p
.46886 .47143 L 1 g
F P
s
P
p
.46849 .47159 m .47131 .47026 L .46886 .47143 L 1 g
F
P
p
.47131 .47026 m .47744 .46736 L .46886 .47143 L 1 g
F
P
p
.47432 .46773 m .47511 .46845 L .47379 .46908 L 1 g
F
P
p
.002 w
.47517 .46559 m .47684 .4674 L p
.47432 .46773 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50132 .5038 m .49133 .48314 L .51685 .46646 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .5225 .46726 L p
1 g
F P
s
P
p
.5 .4634 m .5225 .46726 L .51985 .46689 L 1 g
F
P
p
.52019 .46693 m .50132 .5038 L .51685 .46646 L 1 g
F
P
p
.5 .4634 m .51985 .46689 L .51159 .46563 L 1 g
F
P
p
.002 w
.53671 .49334 m .50132 .5038 L p
.52019 .46693 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.5225 .46726 m .53671 .49334 L .52019 .46693 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54219 .47657 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54187 .47642 m .54219 .47657 L .53671 .49334 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56584 .50908 L p
1 g
F P
s
P
p
.57083 .48097 m .57185 .52164 L .56584 .50908 L 1 g
F
P
p
.56401 .49079 m .56584 .50908 L .55991 .49669 L 1 g
F
P
p
.57083 .48097 m .56584 .50908 L .56401 .49079 L 1 g
F
P
p
.002 w
.56584 .50908 m .56515 .50826 L p
.56689 .51955 L 1 g
F P
s
P
p
.55661 .4905 m .56584 .50908 L .5606 .49814 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56737 .52855 L p
1 g
F P
s
P
p
.002 w
.57523 .52131 m .56806 .5486 L p
.56737 .52855 L 1 g
F P
s
P
p
.5679 .52691 m .56737 .52855 L .56733 .52734 L 1 g
F
P
p
.57523 .52131 m .56737 .52855 L .5679 .52691 L 1 g
F
P
p
.002 w
.56737 .52855 m .56654 .52734 L p
.56496 .53597 L 1 g
F P
s
P
p
.56515 .50826 m .56737 .52855 L .56722 .52428 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56142 .54692 L p
1 g
F P
s
P
p
.56723 .52896 m .56663 .53951 L .56338 .54086 L 1 g
F
P
p
.002 w
.56558 .55802 m .5547 .55646 L p
.56663 .53951 L 1 g
F P
s
P
p
.56654 .52734 m .56142 .54692 L .56496 .53597 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54906 .56269 L p
1 g
F P
s
P
p
.56558 .55802 m .54709 .56488 L .54906 .56269 L 1 g
F
P
p
.002 w
.5547 .55646 m .55784 .55691 L p
.54906 .56269 L 1 g
F P
s
P
p
.002 w
.55784 .55691 m .56558 .55802 L p
.54906 .56269 L 1 g
F P
s
P
p
.002 w
.54906 .56269 m .54854 .56129 L p
.54259 .56696 L 1 g
F P
s
P
p
.56075 .54566 m .54906 .56269 L .5527 .55867 L 1 g
F
P
p
.56075 .54566 m .54949 .56386 L .55513 .55585 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53162 .5742 L p
1 g
F P
s
P
p
.54854 .56129 m .53162 .5742 L .54259 .56696 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54906 .56269 m .51632 .57628 L .5547 .55646 L 1 g
F
P
p
.54709 .56488 m .54403 .56601 L .54906 .56269 L 1 g
F
P
p
.54403 .56601 m .51632 .57628 L .54906 .56269 L 1 g
F
P
p
.002 w
.56558 .55802 m .56208 .56265 L p
.51632 .57628 L 1 g
F P
s
P
p
.002 w
.56208 .56265 m .54351 .58717 L .52108 .57819 L p
1 g
F P
s
P
p
.002 w
.53162 .5742 m .53128 .57265 L p
.5199 .57849 L 1 g
F P
s
P
p
.5199 .57849 m .52108 .57819 L .53162 .5742 L 1 g
F
P
p
.002 w
.50871 .58089 m .51632 .57628 L .52108 .57819 L p
1 g
F P
s
P
p
.002 w
.52108 .57819 m .52516 .57982 L p
.51095 .58074 L 1 g
F P
s
P
p
.51095 .58074 m .50871 .58089 L .52108 .57819 L 1 g
F
P
p
.5199 .57849 m .51878 .57907 L .52108 .57819 L 1 g
F
P
p
.002 w
.52108 .57819 m .51632 .57628 L p
.56208 .56265 L 1 g
F P
s
P
p
.002 w
.52516 .57982 m .54351 .58717 L p
.50871 .58089 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53162 .5742 L p
1 g
F P
s
P
p
.51878 .57907 m .51111 .583 L .53162 .5742 L 1 g
F
P
p
.002 w
.53162 .5742 m .5322 .57686 L p
.54259 .56696 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54906 .56269 L p
1 g
F P
s
P
p
.54259 .56696 m .5322 .57686 L .54906 .56269 L 1 g
F
P
p
.002 w
.54906 .56269 m .54949 .56386 L p
.5527 .55867 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51632 .57628 m .53326 .55337 L .5547 .55646 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5547 .55646 m .53326 .55337 L p
.56663 .53951 L 1 g
F P
s
P
p
.002 w
.56142 .54692 m .56257 .5491 L p
.56496 .53597 L 1 g
F P
s
P
p
.56733 .52734 m .56723 .52896 L .53326 .55337 L 1 g
F
P
p
.56723 .52896 m .56338 .54086 L .53326 .55337 L 1 g
F
P
p
.002 w
.54949 .56386 m .54998 .56518 L p
.55513 .55585 L 1 g
F P
s
P
p
.002 w
.56806 .5486 m .56558 .55802 L p
.56733 .52734 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56737 .52855 L p
1 g
F P
s
P
p
.56496 .53597 m .56257 .5491 L .56737 .52855 L 1 g
F
P
p
.002 w
.56715 .52209 m .57523 .52131 L p
.56733 .52734 L 1 g
F P
s
P
p
.56515 .50826 m .56787 .52927 L .56689 .51955 L 1 g
F
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53326 .55337 m .54044 .52469 L .56715 .52209 L p
1 g
F P
s
P
p
.56733 .52734 m .53326 .55337 L .56715 .52209 L 1 g
F
P
p
.002 w
.57185 .52164 m .56715 .52209 L p
.56584 .50908 L 1 g
F P
s
P
p
.002 w
.56787 .52927 m .56854 .53025 L p
.56711 .52095 L 1 g
F P
s
P
p
.56689 .51955 m .56715 .52209 L .56711 .52095 L 1 g
F
P
p
.56715 .52209 m .56787 .52927 L .56711 .52095 L 1 g
F
P
p
.002 w
.56737 .52855 m .56787 .52927 L p
.56722 .52428 L 1 g
F P
s
P
p
.002 w
.55729 .49123 m .55661 .4905 L p
.5606 .49814 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55729 .49123 L p
1 g
F P
s
P
p
.56113 .49493 m .55991 .49669 L .55729 .49123 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55729 .49123 L p
1 g
F P
s
P
p
.5606 .49814 m .56713 .51061 L .55729 .49123 L 1 g
F
P
p
.54174 .47608 m .55729 .49123 L .55474 .48876 L 1 g
F
P
p
.55991 .49669 m .54044 .52469 L .55442 .48846 L 1 g
F
P
p
.55991 .49669 m .55442 .48846 L .55729 .49123 L 1 g
F
P
p
.54174 .47608 m .55474 .48876 L .54925 .48344 L 1 g
F
P
p
.55442 .48846 m .54044 .52469 L .55327 .48734 L 1 g
F
P
p
.55474 .48876 m .55759 .49155 L .55327 .48734 L 1 g
F
P
p
.55474 .48876 m .55327 .48734 L .54925 .48344 L 1 g
F
P
p
.002 w
.54044 .52469 m .53671 .49334 L .55327 .48734 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55327 .48734 m .55511 .48667 L p
.55442 .48846 L 1 g
F P
s
P
p
.55729 .49123 m .55442 .48846 L .55511 .48667 L 1 g
F
P
p
.002 w
.55327 .48734 m .53671 .49334 L p
.54219 .47657 L 1 g
F P
s
P
p
.002 w
.55759 .49155 m .55834 .49233 L p
.55118 .48532 L 1 g
F P
s
P
p
.54925 .48344 m .55327 .48734 L .55118 .48532 L 1 g
F
P
p
.55327 .48734 m .55759 .49155 L .55118 .48532 L 1 g
F
P
p
.002 w
.55729 .49123 m .55759 .49155 L p
.55474 .48876 L 1 g
F P
s
P
p
.002 w
.55511 .48667 m .57083 .48097 L p
.56113 .49493 L 1 g
F P
s
P
p
.56113 .49493 m .55729 .49123 L .55511 .48667 L 1 g
F
P
p
.55991 .49669 m .56584 .50908 L .54044 .52469 L 1 g
F
P
p
.002 w
.56715 .52209 m .54044 .52469 L p
.56584 .50908 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56584 .50908 L p
1 g
F P
s
P
p
.56689 .51955 m .56854 .53025 L .56584 .50908 L 1 g
F
P
p
.002 w
.56584 .50908 m .56713 .51061 L p
.5606 .49814 L 1 g
F P
s
P
p
.002 w
.57083 .48097 m .57523 .52131 L .57185 .52164 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54219 .47657 L p
1 g
F P
s
P
p
.002 w
.54219 .47657 m .54174 .47608 L p
.54925 .48344 L 1 g
F P
s
P
p
.54925 .48344 m .55834 .49233 L .54219 .47657 L 1 g
F
P
p
.55246 .44172 m .55994 .48492 L .54219 .47657 L 1 g
F
P
p
.54191 .4763 m .54219 .47657 L .54187 .47642 L 1 g
F
P
p
.55246 .44172 m .54219 .47657 L .54191 .4763 L 1 g
F
P
p
.002 w
.55994 .48492 m .55327 .48734 L p
.54219 .47657 L 1 g
F P
s
P
p
.52214 .46667 m .54219 .47657 L .53491 .47314 L 1 g
F
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52224 .46293 m .55246 .44172 L p
.54187 .47642 L 1 g
F P
s
P
p
.002 w
.53671 .49334 m .52484 .4684 L p
.54187 .47642 L 1 g
F P
s
P
p
.52214 .46667 m .53491 .47314 L .53194 .47175 L 1 g
F
P
p
.002 w
.52484 .4684 m .53671 .49334 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5225 .46726 L p
1 g
F P
s
P
p
.002 w
.5225 .46726 m .52214 .46667 L p
.5355 .47358 L 1 g
F P
s
P
p
.5355 .47358 m .54302 .47747 L .5225 .46726 L 1 g
F
P
p
.002 w
.52224 .46293 m .52443 .46754 L p
.5225 .46726 L 1 g
F P
s
P
p
.52052 .4663 m .5225 .46726 L .52019 .46693 L 1 g
F
P
p
.52224 .46293 m .5225 .46726 L .52052 .4663 L 1 g
F
P
p
.002 w
.52484 .4684 m .52224 .46293 L p
.54187 .47642 L 1 g
F P
s
P
p
.53194 .47175 m .54263 .47705 L .5355 .47358 L 1 g
F
P
p
.53491 .47314 m .54263 .47705 L .53194 .47175 L 1 g
F
P
p
.002 w
.54219 .47657 m .54263 .47705 L p
.53491 .47314 L 1 g
F P
s
P
p
.002 w
.55246 .44172 m .57083 .48097 L .55994 .48492 L p
1 g
F P
s
P
p
.002 w
.52443 .46754 m .52484 .4684 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.54263 .47705 m .54302 .47747 L p
.5355 .47358 L 1 g
F P
s
P
p
.51985 .46689 m .52256 .46736 L .51685 .46646 L 1 g
F
P
p
.51985 .46689 m .51685 .46646 L .51159 .46563 L 1 g
F
P
p
.002 w
.51685 .46646 m .52224 .46293 L p
.52019 .46693 L 1 g
F P
s
P
p
.002 w
.5225 .46726 m .52256 .46736 L p
.51985 .46689 L 1 g
F P
s
P
p
.002 w
.51685 .46646 m .49133 .48314 L p
.50242 .46418 L 1 g
F P
s
P
p
.002 w
.52256 .46736 m .52282 .46778 L p
.51159 .46563 L 1 g
F P
s
P
p
.49422 .4647 m .50242 .46418 L .49133 .48314 L 1 g
F
P
p
.002 w
.5 .4638 m .5 .4634 L p
.51159 .46563 L 1 g
F P
s
P
p
.002 w
.52016 .46066 m .52224 .46293 L p
.49422 .4647 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4638 L p
1 g
F P
s
P
p
.51159 .46563 m .52282 .46778 L .5 .4638 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.002 w
.49856 .43709 m .52016 .46066 L p
.5 .4638 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .48849 .46559 L 1 g
F
P
p
.4945 .46293 m .5 .4638 L .49422 .4647 L 1 g
F
P
p
.49856 .43709 m .5 .4638 L .4945 .46293 L 1 g
F
P
p
.002 w
.52224 .46293 m .51685 .46646 L p
.50242 .46418 L 1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .46442 L p
.48849 .46559 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47748 .4673 L p
.48274 .46663 L 1 g
F P
s
P
p
.48274 .46663 m .5 .46442 L .47747 .46732 L 1 g
F
P
p
.002 w
.47748 .4673 m .47786 .46667 L p
.48849 .46559 L 1 g
F P
s
P
p
.48849 .46559 m .5 .46442 L .47748 .4673 L 1 g
F
P
p
.49521 .4584 m .49422 .4647 L .47748 .4673 L 1 g
F
P
p
.002 w
.47698 .46755 m .47517 .46559 L p
.49521 .4584 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47747 .46732 L p
.47721 .46744 L 1 g
F P
s
P
p
.002 w
.47747 .46732 m .47744 .46736 L p
.47609 .46798 L 1 g
F P
s
P
p
.002 w
.47131 .47026 m .47517 .46559 L p
.47379 .46908 L 1 g
F P
s
P
p
.002 w
.47144 .46333 m .47517 .46559 L p
.46279 .47429 L 1 g
F P
s
P
p
.4577 .4767 m .46279 .47429 L .45334 .48093 L 1 g
F
P
p
.47144 .46333 m .46279 .47429 L .4577 .4767 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4577 .4767 L p
1 g
F P
s
P
p
.46849 .47159 m .47718 .46778 L .4577 .4767 L 1 g
F
P
p
.002 w
.47517 .46559 m .47131 .47026 L p
.46279 .47429 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44247 .49148 m .45277 .49273 L .43799 .50082 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45707 .47738 L p
1 g
F P
s
P
p
.44339 .4905 m .45707 .47738 L .45548 .47892 L 1 g
F
P
p
.45078 .48342 m .44565 .4884 L .44247 .49148 L 1 g
F
P
p
.002 w
.44433 .4876 m .44565 .4884 L p
.44247 .49148 L 1 g
F P
s
P
p
.002 w
.44565 .4884 m .45277 .49273 L p
.44247 .49148 L 1 g
F P
s
P
p
.002 w
.45707 .47738 m .45698 .47747 L p
.45548 .47892 L 1 g
F P
s
P
p
.002 w
.4547 .4532 m .47144 .46333 L p
.45334 .48093 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44223 .49173 L p
1 g
F P
s
P
p
.002 w
.44223 .49173 m .44247 .49148 L p
.44533 .48872 L 1 g
F P
s
P
p
.44533 .48872 m .45698 .47747 L .44223 .49173 L 1 g
F
P
p
.45078 .48342 m .45548 .47892 L .44565 .4884 L 1 g
F
P
p
.002 w
.44247 .48647 m .4547 .4532 L p
.45334 .48093 L 1 g
F P
s
P
p
.002 w
.44565 .4884 m .44247 .48647 L p
.45334 .48093 L 1 g
F P
s
P
p
.45548 .47892 m .45698 .47747 L .44247 .49148 L 1 g
F
P
p
.002 w
.4334 .51386 m .43711 .50266 L p
.43315 .51635 L 1 g
F P
s
P
p
.002 w
.43711 .50266 m .44247 .48647 L p
.43799 .50082 L 1 g
F P
s
P
p
.43799 .50082 m .43315 .51635 L .43711 .50266 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43385 .50945 L p
1 g
F P
s
P
p
.002 w
.43385 .50945 m .43386 .50944 L p
.43394 .50927 L 1 g
F P
s
P
p
.43394 .50927 m .44166 .49233 L .43385 .50945 L 1 g
F
P
p
.43838 .5 m .4384 .49997 L .43711 .50266 L 1 g
F
P
p
.002 w
.45277 .49273 m .43315 .51635 L p
.43799 .50082 L 1 g
F P
s
P
p
.4384 .49997 m .44166 .49233 L .43386 .50944 L 1 g
F
P
p
.002 w
.4322 .51748 m .43207 .51317 L p
.43301 .51121 L 1 g
F P
s
P
p
.002 w
.43386 .50944 m .43385 .50945 L p
.43385 .50954 L 1 g
F P
s
P
p
.002 w
.43385 .50945 m .43335 .51005 L p
.43337 .51412 L 1 g
F P
s
P
p
.43309 .51675 m .43306 .51712 L .43251 .52873 L 1 g
F
P
p
.002 w
.43305 .51734 m .4322 .51748 L .43308 .517 L p
1 g
F P
s
P
p
.43309 .51664 m .43304 .51739 L .43251 .52873 L 1 g
F
P
p
.002 w
.43303 .51761 m .4322 .51748 L .43305 .51734 L p
1 g
F P
s
P
p
.43308 .5165 m .433 .51804 L .43251 .52873 L 1 g
F
P
p
.002 w
.43301 .51786 m .4322 .51748 L .43303 .51761 L p
1 g
F P
s
P
p
.43308 .51634 m .4329 .52 L .43251 .52873 L 1 g
F
P
p
.43925 .54566 m .43251 .52873 L .43517 .53758 L 1 g
F
P
p
.43851 .54815 m .43819 .54766 L .43286 .52082 L 1 g
F
P
p
.43287 .52072 m .43286 .52082 L .4322 .51748 L 1 g
F
P
p
.43851 .54815 m .43286 .52082 L .43287 .52072 L 1 g
F
P
p
.002 w
.43335 .51005 m .43287 .51061 L p
.43307 .51619 L 1 g
F P
s
P
p
.002 w
.45277 .49273 m .46093 .50155 L .43308 .517 L p
1 g
F P
s
P
p
.002 w
.43315 .51635 m .45277 .49273 L p
.43308 .517 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.46093 .50155 m .46603 .51194 L .43305 .51734 L p
1 g
F P
s
P
p
.002 w
.43308 .517 m .46093 .50155 L p
.43305 .51734 L 1 g
F P
s
P
p
.43309 .51686 m .43309 .51682 L .43309 .51693 L 1 g
F
P
p
.43309 .51682 m .43309 .51675 L .43308 .517 L 1 g
F
P
p
.002 w
.46603 .51194 m .46754 .52274 L .43303 .51761 L p
1 g
F P
s
P
p
.002 w
.43305 .51734 m .46603 .51194 L p
.43303 .51761 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.46754 .52274 m .46531 .53276 L .43301 .51786 L p
1 g
F P
s
P
p
.002 w
.43303 .51761 m .46754 .52274 L p
.43301 .51786 L 1 g
F P
s
P
p
.43309 .51675 m .43309 .51664 L .43306 .51712 L 1 g
F
P
p
.43309 .51664 m .43308 .5165 L .43304 .51739 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.46531 .53276 m .45962 .54089 L .43299 .51816 L p
1 g
F P
s
P
p
.002 w
.43299 .51816 m .4322 .51748 L .43301 .51786 L p
1 g
F P
s
P
p
.002 w
.43301 .51786 m .46531 .53276 L p
.43299 .51816 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45962 .54089 m .45114 .5463 L .43297 .51865 L p
1 g
F P
s
P
p
.002 w
.43297 .51865 m .4322 .51748 L .43299 .51816 L p
1 g
F P
s
P
p
.002 w
.43299 .51816 m .45962 .54089 L p
.43297 .51865 L 1 g
F P
s
P
p
.43308 .5165 m .43308 .51634 L .433 .51804 L 1 g
F
P
p
.43308 .51634 m .43307 .51619 L .4329 .52 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45114 .5463 m .44079 .54842 L .4329 .52 L p
1 g
F P
s
P
p
.002 w
.4329 .52 m .4322 .51748 L .43297 .51865 L p
1 g
F P
s
P
p
.002 w
.43297 .51865 m .45114 .5463 L p
.4329 .52 L 1 g
F P
s
P
p
.002 w
.43153 .52545 m .4322 .51748 L p
.43819 .54766 L 1 g
F P
s
P
p
.002 w
.4322 .51748 m .44079 .54842 L .43851 .54815 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52873 L p
1 g
F P
s
P
p
.43307 .51619 m .43287 .51061 L .43251 .52873 L 1 g
F
P
p
.002 w
.43251 .52873 m .43146 .53025 L p
.43517 .53758 L 1 g
F P
s
P
p
.002 w
.4297 .54708 m .43851 .54815 L p
.45097 .5751 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43819 .54766 L p
1 g
F P
s
P
p
.43517 .53758 m .43146 .53025 L .43819 .54766 L 1 g
F
P
p
.002 w
.43819 .54766 m .43816 .54771 L p
.43836 .54791 L 1 g
F P
s
P
p
.002 w
.44264 .55327 m .45097 .5751 L p
.43851 .54815 L 1 g
F P
s
P
p
.002 w
.43816 .54771 m .43809 .54784 L p
.439 .54875 L 1 g
F P
s
P
p
.45146 .56129 m .43809 .54784 L .44374 .55458 L 1 g
F
P
p
.002 w
.43851 .54815 m .44079 .54842 L .44264 .55327 L p
1 g
F P
s
P
p
.46421 .5725 m .45081 .56303 L .44079 .54842 L 1 g
F
P
p
.002 w
.44472 .55871 m .44264 .55327 L p
.45081 .56303 L 1 g
F P
s
P
p
.002 w
.44264 .55327 m .44079 .54842 L p
.45081 .56303 L 1 g
F P
s
P
p
.002 w
.43809 .54784 m .43743 .5491 L p
.44374 .55458 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45081 .56303 L p
1 g
F P
s
P
p
.44374 .55458 m .43743 .5491 L .45081 .56303 L 1 g
F
P
p
.45884 .5687 m .45338 .56652 L .46421 .5725 L 1 g
F
P
p
.002 w
.47124 .57112 m .46421 .5725 L p
.44079 .54842 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46826 .57474 L p
1 g
F P
s
P
p
.45338 .56652 m .45002 .56518 L .46826 .57474 L 1 g
F
P
p
.47781 .57768 m .47772 .57768 L .47801 .57775 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58042 L p
1 g
F P
s
P
p
.47772 .57768 m .4678 .57686 L .48908 .58042 L 1 g
F
P
p
.50043 .58069 m .49501 .58177 L .50871 .58089 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51632 .57628 m .50871 .58089 L p
.47124 .57112 L 1 g
F P
s
P
p
.002 w
.51095 .58074 m .51111 .583 L p
.5199 .57849 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58074 L p
1 g
F P
s
P
p
.49501 .58177 m .48889 .583 L .51095 .58074 L 1 g
F
P
p
.002 w
.54351 .58717 m .56558 .55802 L .59525 .55877 L p
1 g
F P
s
P
p
.004 w
.47482 .46281 m
.5 .43051 L
s
P
p
.002 w
.40987 .53497 m .41902 .54243 L .40865 .56328 L p
1 g
F P
s
P
p
.002 w
.40865 .56328 m .3909 .54881 L .40987 .53497 L p
1 g
F P
s
P
p
.004 w
.39131 .56994 m
.40377 .55395 L
s
P
p
.002 w
.42936 .57237 m .40865 .56328 L .41902 .54243 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.40322 .52548 m .40987 .53497 L .3909 .54881 L p
1 g
F P
s
P
p
.002 w
.3909 .54881 m .37793 .53041 L .40322 .52548 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.65353 .43758 m .62783 .38024 L .645 .36296 L p
1 g
F P
s
P
p
.002 w
.59943 .31219 m .645 .36296 L .62783 .38024 L p
1 g
F P
s
P
p
.002 w
.37654 .42533 m .357 .44619 L .34041 .42129 L p
1 g
F P
s
P
p
.002 w
.34041 .42129 m .36517 .39424 L .37654 .42533 L p
1 g
F P
s
P
p
.002 w
.60719 .51523 m .59525 .55877 L .56558 .55802 L p
1 g
F P
s
P
p
.002 w
.59525 .55877 m .60719 .51523 L .63523 .50673 L p
1 g
F P
s
P
p
.002 w
.3783 .47113 m .37117 .48944 L .3469 .47297 L p
1 g
F P
s
P
p
.002 w
.3469 .47297 m .357 .44619 L .3783 .47113 L p
1 g
F P
s
P
p
.002 w
.58402 .33158 m .52756 .29802 L .54056 .27729 L p
1 g
F P
s
P
p
.002 w
.54056 .27729 m .59943 .31219 L .58402 .33158 L p
1 g
F P
s
P
p
.002 w
.41902 .54243 m .4297 .54708 L .42936 .57237 L p
1 g
F P
s
P
p
.002 w
.45097 .5751 m .42936 .57237 L .4297 .54708 L p
1 g
F P
s
P
p
.002 w
.39977 .51494 m .40322 .52548 L .37793 .53041 L p
1 g
F P
s
P
p
.002 w
.37793 .53041 m .37108 .50992 L .39977 .51494 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.39983 .37787 m .36517 .39424 L .35807 .36487 L p
1 g
F P
s
P
p
.002 w
.35807 .36487 m .39909 .34497 L .39983 .37787 L p
1 g
F P
s
P
p
.002 w
.63026 .45253 m .63523 .50673 L .60719 .51523 L p
1 g
F P
s
P
p
.002 w
.63523 .50673 m .63026 .45253 L .65353 .43758 L p
1 g
F P
s
P
p
.002 w
.62783 .38024 m .58402 .33158 L .59943 .31219 L p
1 g
F P
s
P
p
.002 w
.62783 .38024 m .65353 .43758 L .63026 .45253 L p
1 g
F P
s
P
p
.002 w
.44774 .34057 m .39909 .34497 L .40141 .31534 L p
1 g
F P
s
P
p
.002 w
.40141 .31534 m .45621 .30996 L .44774 .34057 L p
1 g
F P
s
P
p
.002 w
.39991 .50448 m .39977 .51494 L .37108 .50992 L p
1 g
F P
s
P
p
.002 w
.37108 .50992 m .37117 .48944 L .39991 .50448 L p
1 g
F P
s
P
p
.002 w
.51333 .32345 m .45621 .30996 L .46579 .28372 L p
1 g
F P
s
P
p
.002 w
.46579 .28372 m .52756 .29802 L .51333 .32345 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.47124 .57112 m .48802 .56071 L .51632 .57628 L p
1 g
F P
s
P
p
.002 w
.53326 .55337 m .51632 .57628 L .48802 .56071 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39187 .45702 m .3783 .47113 L .357 .44619 L p
1 g
F P
s
P
p
.002 w
.357 .44619 m .37654 .42533 L .39187 .45702 L p
1 g
F P
s
P
p
.002 w
.44079 .54842 m .45114 .5463 L .47124 .57112 L p
1 g
F P
s
P
p
.002 w
.48802 .56071 m .47124 .57112 L .45114 .5463 L p
1 g
F P
s
P
p
.002 w
.56558 .55802 m .57523 .52131 L .60719 .51523 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.40366 .4952 m .39991 .50448 L .37117 .48944 L p
1 g
F P
s
P
p
.002 w
.37117 .48944 m .3783 .47113 L .40366 .4952 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40367 .4129 m .37654 .42533 L .36517 .39424 L p
1 g
F P
s
P
p
.002 w
.36517 .39424 m .39983 .37787 L .40367 .4129 L p
1 g
F P
s
P
p
.002 w
.41902 .54243 m .40987 .53497 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.4297 .54708 m .41902 .54243 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.40987 .53497 m .40322 .52548 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.63026 .45253 m .60622 .39957 L .62783 .38024 L p
1 g
F P
s
P
p
.002 w
.58402 .33158 m .62783 .38024 L .60622 .39957 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.6024 .46719 m .60719 .51523 L .57523 .52131 L p
1 g
F P
s
P
p
.002 w
.60719 .51523 m .6024 .46719 L .63026 .45253 L p
1 g
F P
s
P
p
.002 w
.40322 .52548 m .39977 .51494 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.56557 .3546 m .51333 .32345 L .52756 .29802 L p
1 g
F P
s
P
p
.002 w
.52756 .29802 m .58402 .33158 L .56557 .3546 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.44074 .37453 m .39983 .37787 L .39909 .34497 L p
1 g
F P
s
P
p
.002 w
.39909 .34497 m .44774 .34057 L .44074 .37453 L p
1 g
F P
s
P
p
.002 w
.60622 .39957 m .63026 .45253 L .6024 .46719 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.39977 .51494 m .39991 .50448 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.45114 .5463 m .45962 .54089 L .48802 .56071 L p
1 g
F P
s
P
p
.002 w
.49942 .54486 m .48802 .56071 L .45962 .54089 L p
1 g
F P
s
P
p
.002 w
.48802 .56071 m .49942 .54486 L .53326 .55337 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60622 .39957 m .56557 .3546 L .58402 .33158 L p
1 g
F P
s
P
p
.002 w
.41066 .48813 m .40366 .4952 L .3783 .47113 L p
1 g
F P
s
P
p
.002 w
.3783 .47113 m .39187 .45702 L .41066 .48813 L p
1 g
F P
s
P
p
.002 w
.49836 .35279 m .44774 .34057 L .45621 .30996 L p
1 g
F P
s
P
p
.002 w
.45621 .30996 m .51333 .32345 L .49836 .35279 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.54044 .52469 m .53326 .55337 L .49942 .54486 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.39991 .50448 m .40366 .4952 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41054 .44875 m .39187 .45702 L .37654 .42533 L p
1 g
F P
s
P
p
.002 w
.37654 .42533 m .40367 .4129 L .41054 .44875 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57523 .52131 m .57083 .48097 L .6024 .46719 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45962 .54089 m .46531 .53276 L .49942 .54486 L p
1 g
F P
s
P
p
.002 w
.40366 .4952 m .41066 .48813 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.42017 .48406 m .43118 .48348 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.41066 .48813 m .42017 .48406 L .4322 .51748 L closepath p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.50408 .52518 m .49942 .54486 L .46531 .53276 L p
1 g
F P
s
P
p
.002 w
.49942 .54486 m .50408 .52518 L .54044 .52469 L p
1 g
F P
s
P
p
.002 w
.43552 .4106 m .40367 .4129 L .39983 .37787 L p
1 g
F P
s
P
p
.002 w
.39983 .37787 m .44074 .37453 L .43552 .4106 L p
1 g
F P
s
P
p
.002 w
.42017 .48406 m .41066 .48813 L .39187 .45702 L p
1 g
F P
s
P
p
.002 w
.39187 .45702 m .41054 .44875 L .42017 .48406 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.6024 .46719 m .5808 .42032 L .60622 .39957 L p
1 g
F P
s
P
p
.002 w
.56557 .3546 m .60622 .39957 L .5808 .42032 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.5808 .42032 m .6024 .46719 L .57083 .48097 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46531 .53276 m .46754 .52274 L .50408 .52518 L p
1 g
F P
s
P
p
.002 w
.54466 .3805 m .49836 .35279 L .51333 .32345 L p
1 g
F P
s
P
p
.002 w
.51333 .32345 m .56557 .3546 L .54466 .3805 L p
1 g
F P
s
P
p
.002 w
.4832 .38503 m .44074 .37453 L .44774 .34057 L p
1 g
F P
s
P
p
.002 w
.44774 .34057 m .49836 .35279 L .4832 .38503 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.53671 .49334 m .54044 .52469 L .50408 .52518 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5808 .42032 m .54466 .3805 L .56557 .3546 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43229 .44739 m .41054 .44875 L .40367 .4129 L p
1 g
F P
s
P
p
.002 w
.40367 .4129 m .43552 .4106 L .43229 .44739 L p
1 g
F P
s
P
p
.002 w
.46754 .52274 m .46603 .51194 L .50132 .5038 L p
1 g
F P
s
P
p
.002 w
.50132 .5038 m .50408 .52518 L .46754 .52274 L p
1 g
F P
s
P
p
.002 w
.43118 .48348 m .42017 .48406 L .41054 .44875 L p
1 g
F P
s
P
p
.002 w
.50408 .52518 m .50132 .5038 L .53671 .49334 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.41054 .44875 m .43229 .44739 L .43118 .48348 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.46603 .51194 m .46093 .50155 L .49133 .48314 L p
1 g
F P
s
P
p
.002 w
.49133 .48314 m .50132 .5038 L .46603 .51194 L p
1 g
F P
s
P
p
.002 w
.57083 .48097 m .55246 .44172 L .5808 .42032 L p
1 g
F P
s
P
p
.002 w
.44247 .48647 m .43118 .48348 L .43229 .44739 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46845 .41894 m .43552 .4106 L .44074 .37453 L p
1 g
F P
s
P
p
.002 w
.44074 .37453 m .4832 .38503 L .46845 .41894 L p
1 g
F P
s
P
p
.002 w
.54466 .3805 m .5808 .42032 L .55246 .44172 L p
1 g
F P
s
P
p
.002 w
.43229 .44739 m .4547 .4532 L .44247 .48647 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52204 .40835 m .4832 .38503 L .49836 .35279 L p
1 g
F P
s
P
p
.002 w
.49836 .35279 m .54466 .3805 L .52204 .40835 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.4547 .4532 m .43229 .44739 L .43552 .4106 L p
1 g
F P
s
P
p
.002 w
.43552 .4106 m .46845 .41894 L .4547 .4532 L p
1 g
F P
s
P
p
.002 w
.55246 .44172 m .52204 .40835 L .54466 .3805 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52204 .40835 m .55246 .44172 L .52224 .46293 L p
1 g
F P
s
P
p
.002 w
.47517 .46559 m .4547 .4532 L .46845 .41894 L p
1 g
F P
s
P
p
.002 w
.49856 .43709 m .46845 .41894 L .4832 .38503 L p
1 g
F P
s
P
p
.002 w
.4832 .38503 m .52204 .40835 L .49856 .43709 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.46845 .41894 m .49856 .43709 L .47517 .46559 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.52224 .46293 m .49856 .43709 L .52204 .40835 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.40377 .55395 m
.40965 .54641 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .38978 .70811 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39131 .56994 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0379845)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0379845)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47167 .43246 m .49006 .4524 L .50786 .43009 L p
1 g
F P
s
P
p
.002 w
.50786 .43009 m .49534 .41649 L .47167 .43246 L p
1 g
F P
s
P
p
.002 w
.52389 .43919 m .50786 .43009 L .49006 .4524 L p
1 g
F P
s
P
p
.002 w
.49534 .41649 m .50786 .43009 L .52549 .40776 L p
1 g
F P
s
P
p
.002 w
.50786 .43009 m .52389 .43919 L .53364 .41236 L p
1 g
F P
s
P
p
.002 w
.53364 .41236 m .52549 .40776 L .50786 .43009 L p
1 g
F P
s
P
p
.002 w
.4603 .408 m .47167 .43246 L .49534 .41649 L p
1 g
F P
s
P
p
.002 w
.49534 .41649 m .48764 .39981 L .4603 .408 L p
1 g
F P
s
P
p
.002 w
.48764 .39981 m .49534 .41649 L .51914 .40085 L p
1 g
F P
s
P
p
.002 w
.52549 .40776 m .51914 .40085 L .49534 .41649 L p
1 g
F P
s
P
p
.002 w
.44856 .44847 m .4724 .47431 L .49006 .4524 L p
1 g
F P
s
P
p
.002 w
.49006 .4524 m .47167 .43246 L .44856 .44847 L p
1 g
F P
s
P
p
.002 w
.51356 .4658 m .49006 .4524 L .4724 .47431 L p
1 g
F P
s
P
p
.002 w
.49006 .4524 m .51356 .4658 L .52389 .43919 L p
1 g
F P
s
P
p
.002 w
.54177 .44283 m .52389 .43919 L .51356 .4658 L p
1 g
F P
s
P
p
.002 w
.52389 .43919 m .54177 .44283 L .54272 .41418 L p
1 g
F P
s
P
p
.002 w
.54272 .41418 m .53364 .41236 L .52389 .43919 L p
1 g
F P
s
P
p
.002 w
.43374 .4168 m .44856 .44847 L .47167 .43246 L p
1 g
F P
s
P
p
.002 w
.47167 .43246 m .4603 .408 L .43374 .4168 L p
1 g
F P
s
P
p
.002 w
.45717 .38152 m .4603 .408 L .48764 .39981 L p
1 g
F P
s
P
p
.002 w
.48764 .39981 m .48559 .38178 L .45717 .38152 L p
1 g
F P
s
P
p
.002 w
.48559 .38178 m .48764 .39981 L .51525 .39237 L p
1 g
F P
s
P
p
.002 w
.51914 .40085 m .51525 .39237 L .48764 .39981 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .51914 .40085 L .52549 .40776 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .52549 .40776 L .53364 .41236 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .51525 .39237 L .51914 .40085 L closepath p
1 g
F P
s
P
p
.002 w
.53981 .47125 m .51356 .4658 L .50284 .49172 L p
1 g
F P
s
P
p
.002 w
.4724 .47431 m .50284 .49172 L .51356 .4658 L p
1 g
F P
s
P
p
.002 w
.51356 .4658 m .53981 .47125 L .54177 .44283 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .53364 .41236 L .54272 .41418 L closepath p
1 g
F P
s
P
p
.002 w
.51525 .39237 m .51425 .38322 L .48559 .38178 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .51425 .38322 L .51525 .39237 L closepath p
1 g
F P
s
P
p
.002 w
.55963 .44058 m .54177 .44283 L .53981 .47125 L p
1 g
F P
s
P
p
.002 w
.54177 .44283 m .55963 .44058 L .55177 .41299 L p
1 g
F P
s
P
p
.002 w
.55177 .41299 m .54272 .41418 L .54177 .44283 L p
1 g
F P
s
P
p
.002 w
.42952 .38246 m .43374 .4168 L .4603 .408 L p
1 g
F P
s
P
p
.002 w
.4603 .408 m .45717 .38152 L .42952 .38246 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .54272 .41418 L .55177 .41299 L closepath p
1 g
F P
s
P
p
.002 w
.48946 .3643 m .48559 .38178 L .51425 .38322 L p
1 g
F P
s
P
p
.002 w
.51425 .38322 m .51626 .37438 L .48946 .3643 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .51626 .37438 L .51425 .38322 L closepath p
1 g
F P
s
P
p
.002 w
.46271 .35576 m .45717 .38152 L .48559 .38178 L p
1 g
F P
s
P
p
.002 w
.48559 .38178 m .48946 .3643 L .46271 .35576 L p
1 g
F P
s
P
p
.002 w
.42644 .46423 m .45522 .49539 L .4724 .47431 L p
1 g
F P
s
P
p
.002 w
.4724 .47431 m .44856 .44847 L .42644 .46423 L p
1 g
F P
s
P
p
.002 w
.50284 .49172 m .4724 .47431 L .45522 .49539 L p
1 g
F P
s
P
p
.002 w
.40846 .42605 m .42644 .46423 L .44856 .44847 L p
1 g
F P
s
P
p
.002 w
.44856 .44847 m .43374 .4168 L .40846 .42605 L p
1 g
F P
s
P
p
.002 w
.5598 .40891 m .55177 .41299 L .55963 .44058 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .55177 .41299 L .5598 .40891 L closepath p
1 g
F P
s
P
p
.002 w
.50284 .49172 m .53685 .49891 L .53981 .47125 L p
1 g
F P
s
P
p
.002 w
.56609 .46809 m .53981 .47125 L .53685 .49891 L p
1 g
F P
s
P
p
.002 w
.53981 .47125 m .56609 .46809 L .55963 .44058 L p
1 g
F P
s
P
p
.002 w
.49889 .34923 m .48946 .3643 L .51626 .37438 L p
1 g
F P
s
P
p
.002 w
.51626 .37438 m .52109 .3668 L .49889 .34923 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .52109 .3668 L .51626 .37438 L closepath p
1 g
F P
s
P
p
.002 w
.57557 .43263 m .55963 .44058 L .56609 .46809 L p
1 g
F P
s
P
p
.002 w
.55963 .44058 m .57557 .43263 L .5598 .40891 L p
1 g
F P
s
P
p
.002 w
.53685 .49891 m .50284 .49172 L .49192 .51647 L p
1 g
F P
s
P
p
.002 w
.45522 .49539 m .49192 .51647 L .50284 .49172 L p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .5598 .40891 L .56595 .40237 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .56595 .40237 L .56954 .39406 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .56954 .39406 L .57015 .38487 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .57015 .38487 L .56771 .37582 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .56771 .37582 L .56248 .36791 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .56248 .36791 L .55502 .362 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .55502 .362 L .54616 .35875 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .54616 .35875 L .53689 .35852 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .53689 .35852 L .52822 .36131 L closepath p
1 g
F P
s
P
p
.002 w
.54264 .38581 m .52822 .36131 L .52109 .3668 L closepath p
1 g
F P
s
P
p
.002 w
.56595 .40237 m .5598 .40891 L .57557 .43263 L p
1 g
F P
s
P
p
.002 w
.43652 .34895 m .42952 .38246 L .45717 .38152 L p
1 g
F P
s
P
p
.002 w
.45717 .38152 m .46271 .35576 L .43652 .34895 L p
1 g
F P
s
P
p
.002 w
.47647 .33347 m .46271 .35576 L .48946 .3643 L p
1 g
F P
s
P
p
.002 w
.48946 .3643 m .49889 .34923 L .47647 .33347 L p
1 g
F P
s
P
p
.002 w
.51295 .33825 m .49889 .34923 L .52109 .3668 L p
1 g
F P
s
P
p
.002 w
.52109 .3668 m .52822 .36131 L .51295 .33825 L p
1 g
F P
s
P
p
.002 w
.40319 .3846 m .40846 .42605 L .43374 .4168 L p
1 g
F P
s
P
p
.002 w
.43374 .4168 m .42952 .38246 L .40319 .3846 L p
1 g
F P
s
P
p
.002 w
.57557 .43263 m .58784 .41976 L .56595 .40237 L p
1 g
F P
s
P
p
.002 w
.56954 .39406 m .56595 .40237 L .58784 .41976 L p
1 g
F P
s
P
p
.002 w
.53015 .33261 m .51295 .33825 L .52822 .36131 L p
1 g
F P
s
P
p
.002 w
.52822 .36131 m .53689 .35852 L .53015 .33261 L p
1 g
F P
s
P
p
.002 w
.56609 .46809 m .58964 .45653 L .57557 .43263 L p
1 g
F P
s
P
p
.002 w
.58784 .41976 m .57557 .43263 L .58964 .45653 L p
1 g
F P
s
P
p
.002 w
.53685 .49891 m .571 .495 L .56609 .46809 L p
1 g
F P
s
P
p
.002 w
.58964 .45653 m .56609 .46809 L .571 .495 L p
1 g
F P
s
P
p
.002 w
.49192 .51647 m .53295 .5253 L .53685 .49891 L p
1 g
F P
s
P
p
.002 w
.571 .495 m .53685 .49891 L .53295 .5253 L p
1 g
F P
s
P
p
.002 w
.58784 .41976 m .59507 .40331 L .56954 .39406 L p
1 g
F P
s
P
p
.002 w
.57015 .38487 m .56954 .39406 L .59507 .40331 L p
1 g
F P
s
P
p
.002 w
.40574 .47944 m .43884 .51524 L .45522 .49539 L p
1 g
F P
s
P
p
.002 w
.45522 .49539 m .42644 .46423 L .40574 .47944 L p
1 g
F P
s
P
p
.002 w
.49192 .51647 m .45522 .49539 L .43884 .51524 L p
1 g
F P
s
P
p
.002 w
.5486 .333 m .53015 .33261 L .53689 .35852 L p
1 g
F P
s
P
p
.002 w
.53689 .35852 m .54616 .35875 L .5486 .333 L p
1 g
F P
s
P
p
.002 w
.38496 .43559 m .40574 .47944 L .42644 .46423 L p
1 g
F P
s
P
p
.002 w
.42644 .46423 m .40846 .42605 L .38496 .43559 L p
1 g
F P
s
P
p
.002 w
.49712 .31712 m .47647 .33347 L .49889 .34923 L p
1 g
F P
s
P
p
.002 w
.49889 .34923 m .51295 .33825 L .49712 .31712 L p
1 g
F P
s
P
p
.002 w
.45424 .31983 m .43652 .34895 L .46271 .35576 L p
1 g
F P
s
P
p
.002 w
.46271 .35576 m .47647 .33347 L .45424 .31983 L p
1 g
F P
s
P
p
.002 w
.59507 .40331 m .59638 .38505 L .57015 .38487 L p
1 g
F P
s
P
p
.002 w
.56771 .37582 m .57015 .38487 L .59638 .38505 L p
1 g
F P
s
P
p
.002 w
.41142 .34405 m .40319 .3846 L .42952 .38246 L p
1 g
F P
s
P
p
.002 w
.42952 .38246 m .43652 .34895 L .41142 .34405 L p
1 g
F P
s
P
p
.002 w
.56627 .33943 m .5486 .333 L .54616 .35875 L p
1 g
F P
s
P
p
.002 w
.54616 .35875 m .55502 .362 L .56627 .33943 L p
1 g
F P
s
P
p
.002 w
.43884 .51524 m .48099 .53955 L .49192 .51647 L p
1 g
F P
s
P
p
.002 w
.53295 .5253 m .49192 .51647 L .48099 .53955 L p
1 g
F P
s
P
p
.002 w
.59638 .38505 m .59158 .36701 L .56771 .37582 L p
1 g
F P
s
P
p
.002 w
.56248 .36791 m .56771 .37582 L .59158 .36701 L p
1 g
F P
s
P
p
.002 w
.58116 .3512 m .56627 .33943 L .55502 .362 L p
1 g
F P
s
P
p
.002 w
.55502 .362 m .56248 .36791 L .58116 .3512 L p
1 g
F P
s
P
p
.002 w
.59158 .36701 m .58116 .3512 L .56248 .36791 L p
1 g
F P
s
P
p
.002 w
.58964 .45653 m .60788 .43766 L .58784 .41976 L p
1 g
F P
s
P
p
.002 w
.59507 .40331 m .58784 .41976 L .60788 .43766 L p
1 g
F P
s
P
p
.002 w
.3787 .38793 m .38496 .43559 L .40846 .42605 L p
1 g
F P
s
P
p
.002 w
.40846 .42605 m .40319 .3846 L .3787 .38793 L p
1 g
F P
s
P
p
.002 w
.52252 .30863 m .49712 .31712 L .51295 .33825 L p
1 g
F P
s
P
p
.002 w
.51295 .33825 m .53015 .33261 L .52252 .30863 L p
1 g
F P
s
P
p
.002 w
.571 .495 m .60171 .48016 L .58964 .45653 L p
1 g
F P
s
P
p
.002 w
.60788 .43766 m .58964 .45653 L .60171 .48016 L p
1 g
F P
s
P
p
.002 w
.53295 .5253 m .57423 .52077 L .571 .495 L p
1 g
F P
s
P
p
.002 w
.60171 .48016 m .571 .495 L .57423 .52077 L p
1 g
F P
s
P
p
.002 w
.60788 .43766 m .6187 .4134 L .59507 .40331 L p
1 g
F P
s
P
p
.002 w
.59638 .38505 m .59507 .40331 L .6187 .4134 L p
1 g
F P
s
P
p
.002 w
.48102 .29836 m .45424 .31983 L .47647 .33347 L p
1 g
F P
s
P
p
.002 w
.47647 .33347 m .49712 .31712 L .48102 .29836 L p
1 g
F P
s
P
p
.002 w
.48099 .53955 m .52815 .54986 L .53295 .5253 L p
1 g
F P
s
P
p
.002 w
.57423 .52077 m .53295 .5253 L .52815 .54986 L p
1 g
F P
s
P
p
.002 w
.54989 .3091 m .52252 .30863 L .53015 .33261 L p
1 g
F P
s
P
p
.002 w
.53015 .33261 m .5486 .333 L .54989 .3091 L p
1 g
F P
s
P
p
.002 w
.43265 .30868 m .41142 .34405 L .43652 .34895 L p
1 g
F P
s
P
p
.002 w
.43652 .34895 m .45424 .31983 L .43265 .30868 L p
1 g
F P
s
P
p
.002 w
.38691 .49378 m .4236 .53345 L .43884 .51524 L p
1 g
F P
s
P
p
.002 w
.43884 .51524 m .40574 .47944 L .38691 .49378 L p
1 g
F P
s
P
p
.002 w
.48099 .53955 m .43884 .51524 L .4236 .53345 L p
1 g
F P
s
P
p
.002 w
.36377 .44523 m .38691 .49378 L .40574 .47944 L p
1 g
F P
s
P
p
.002 w
.40574 .47944 m .38496 .43559 L .36377 .44523 L p
1 g
F P
s
P
p
.002 w
.6187 .4134 m .62078 .38637 L .59638 .38505 L p
1 g
F P
s
P
p
.002 w
.59158 .36701 m .59638 .38505 L .62078 .38637 L p
1 g
F P
s
P
p
.002 w
.38795 .34121 m .3787 .38793 L .40319 .3846 L p
1 g
F P
s
P
p
.002 w
.40319 .3846 m .41142 .34405 L .38795 .34121 L p
1 g
F P
s
P
p
.002 w
.60171 .48016 m .62562 .45574 L .60788 .43766 L p
1 g
F P
s
P
p
.002 w
.6187 .4134 m .60788 .43766 L .62562 .45574 L p
1 g
F P
s
P
p
.002 w
.57614 .31858 m .54989 .3091 L .5486 .333 L p
1 g
F P
s
P
p
.002 w
.5486 .333 m .56627 .33943 L .57614 .31858 L p
1 g
F P
s
P
p
.002 w
.52815 .54986 m .48099 .53955 L .47028 .56045 L p
1 g
F P
s
P
p
.002 w
.4236 .53345 m .47028 .56045 L .48099 .53955 L p
1 g
F P
s
P
p
.002 w
.62078 .38637 m .61373 .35957 L .59158 .36701 L p
1 g
F P
s
P
p
.002 w
.58116 .3512 m .59158 .36701 L .61373 .35957 L p
1 g
F P
s
P
p
.002 w
.59828 .33607 m .57614 .31858 L .56627 .33943 L p
1 g
F P
s
P
p
.002 w
.56627 .33943 m .58116 .3512 L .59828 .33607 L p
1 g
F P
s
P
p
.002 w
.57423 .52077 m .61149 .50305 L .60171 .48016 L p
1 g
F P
s
P
p
.002 w
.62562 .45574 m .60171 .48016 L .61149 .50305 L p
1 g
F P
s
P
p
.002 w
.51412 .28712 m .48102 .29836 L .49712 .31712 L p
1 g
F P
s
P
p
.002 w
.49712 .31712 m .52252 .30863 L .51412 .28712 L p
1 g
F P
s
P
p
.002 w
.61373 .35957 m .59828 .33607 L .58116 .3512 L p
1 g
F P
s
P
p
.002 w
.35665 .39243 m .36377 .44523 L .38496 .43559 L p
1 g
F P
s
P
p
.002 w
.38496 .43559 m .3787 .38793 L .35665 .39243 L p
1 g
F P
s
P
p
.002 w
.52815 .54986 m .57568 .54487 L .57423 .52077 L p
1 g
F P
s
P
p
.002 w
.61149 .50305 m .57423 .52077 L .57568 .54487 L p
1 g
F P
s
P
p
.002 w
.46497 .28247 m .43265 .30868 L .45424 .31983 L p
1 g
F P
s
P
p
.002 w
.45424 .31983 m .48102 .29836 L .46497 .28247 L p
1 g
F P
s
P
p
.002 w
.62562 .45574 m .63992 .42417 L .6187 .4134 L p
1 g
F P
s
P
p
.002 w
.62078 .38637 m .6187 .4134 L .63992 .42417 L p
1 g
F P
s
P
p
.002 w
.47028 .56045 m .52251 .57203 L .52815 .54986 L p
1 g
F P
s
P
p
.002 w
.57568 .54487 m .52815 .54986 L .52251 .57203 L p
1 g
F P
s
P
p
.002 w
.41219 .30033 m .38795 .34121 L .41142 .34405 L p
1 g
F P
s
P
p
.002 w
.41142 .34405 m .43265 .30868 L .41219 .30033 L p
1 g
F P
s
P
p
.002 w
.54994 .2876 m .51412 .28712 L .52252 .30863 L p
1 g
F P
s
P
p
.002 w
.52252 .30863 m .54989 .3091 L .54994 .2876 L p
1 g
F P
s
P
p
.002 w
.61149 .50305 m .64062 .47363 L .62562 .45574 L p
1 g
F P
s
P
p
.002 w
.63992 .42417 m .62562 .45574 L .64062 .47363 L p
1 g
F P
s
P
p
.002 w
.37041 .50693 m .40986 .54956 L .4236 .53345 L p
1 g
F P
s
P
p
.002 w
.4236 .53345 m .38691 .49378 L .37041 .50693 L p
1 g
F P
s
P
p
.002 w
.47028 .56045 m .4236 .53345 L .40986 .54956 L p
1 g
F P
s
P
p
.002 w
.36666 .34057 m .35665 .39243 L .3787 .38793 L p
1 g
F P
s
P
p
.002 w
.3787 .38793 m .38795 .34121 L .36666 .34057 L p
1 g
F P
s
P
p
.002 w
.63992 .42417 m .64278 .38884 L .62078 .38637 L p
1 g
F P
s
P
p
.002 w
.61373 .35957 m .62078 .38637 L .64278 .38884 L p
1 g
F P
s
P
p
.002 w
.34543 .45479 m .37041 .50693 L .38691 .49378 L p
1 g
F P
s
P
p
.002 w
.38691 .49378 m .36377 .44523 L .34543 .45479 L p
1 g
F P
s
P
p
.002 w
.58437 .29995 m .54994 .2876 L .54989 .3091 L p
1 g
F P
s
P
p
.002 w
.54989 .3091 m .57614 .31858 L .58437 .29995 L p
1 g
F P
s
P
p
.002 w
.57568 .54487 m .61869 .52469 L .61149 .50305 L p
1 g
F P
s
P
p
.002 w
.64062 .47363 m .61149 .50305 L .61869 .52469 L p
1 g
F P
s
P
p
.002 w
.40986 .54956 m .46001 .57865 L .47028 .56045 L p
1 g
F P
s
P
p
.002 w
.52251 .57203 m .47028 .56045 L .46001 .57865 L p
1 g
F P
s
P
p
.002 w
.50512 .26863 m .46497 .28247 L .48102 .29836 L p
1 g
F P
s
P
p
.002 w
.48102 .29836 m .51412 .28712 L .50512 .26863 L p
1 g
F P
s
P
p
.002 w
.64278 .38884 m .63364 .35371 L .61373 .35957 L p
1 g
F P
s
P
p
.002 w
.59828 .33607 m .61373 .35957 L .63364 .35371 L p
1 g
F P
s
P
p
.002 w
.61341 .32288 m .58437 .29995 L .57614 .31858 L p
1 g
F P
s
P
p
.002 w
.57614 .31858 m .59828 .33607 L .61341 .32288 L p
1 g
F P
s
P
p
.002 w
.63364 .35371 m .61341 .32288 L .59828 .33607 L p
1 g
F P
s
P
p
.002 w
.33759 .39806 m .34543 .45479 L .36377 .44523 L p
1 g
F P
s
P
p
.002 w
.36377 .44523 m .35665 .39243 L .33759 .39806 L p
1 g
F P
s
P
p
.002 w
.52251 .57203 m .57523 .56673 L .57568 .54487 L p
1 g
F P
s
P
p
.002 w
.61869 .52469 m .57568 .54487 L .57523 .56673 L p
1 g
F P
s
P
p
.002 w
.44933 .26991 m .41219 .30033 L .43265 .30868 L p
1 g
F P
s
P
p
.002 w
.43265 .30868 m .46497 .28247 L .44933 .26991 L p
1 g
F P
s
P
p
.002 w
.64062 .47363 m .65816 .43541 L .63992 .42417 L p
1 g
F P
s
P
p
.002 w
.64278 .38884 m .63992 .42417 L .65816 .43541 L p
1 g
F P
s
P
p
.002 w
.39335 .29508 m .36666 .34057 L .38795 .34121 L p
1 g
F P
s
P
p
.002 w
.38795 .34121 m .41219 .30033 L .39335 .29508 L p
1 g
F P
s
P
p
.002 w
.46001 .57865 m .51612 .59126 L .52251 .57203 L p
1 g
F P
s
P
p
.002 w
.57523 .56673 m .52251 .57203 L .51612 .59126 L p
1 g
F P
s
P
p
.002 w
.5487 .26908 m .50512 .26863 L .51412 .28712 L p
1 g
F P
s
P
p
.002 w
.51412 .28712 m .54994 .2876 L .5487 .26908 L p
1 g
F P
s
P
p
.002 w
.61869 .52469 m .65245 .49095 L .64062 .47363 L p
1 g
F P
s
P
p
.002 w
.65816 .43541 m .64062 .47363 L .65245 .49095 L p
1 g
F P
s
P
p
.002 w
.34814 .34226 m .33759 .39806 L .35665 .39243 L p
1 g
F P
s
P
p
.002 w
.35665 .39243 m .36666 .34057 L .34814 .34226 L p
1 g
F P
s
P
p
.002 w
.65816 .43541 m .6618 .39246 L .64278 .38884 L p
1 g
F P
s
P
p
.002 w
.63364 .35371 m .64278 .38884 L .6618 .39246 L p
1 g
F P
s
P
p
.002 w
.35669 .51855 m .39799 .56314 L .40986 .54956 L p
1 g
F P
s
P
p
.002 w
.40986 .54956 m .37041 .50693 L .35669 .51855 L p
1 g
F P
s
P
p
.002 w
.46001 .57865 m .40986 .54956 L .39799 .56314 L p
1 g
F P
s
P
p
.002 w
.33048 .46404 m .35669 .51855 L .37041 .50693 L p
1 g
F P
s
P
p
.002 w
.37041 .50693 m .34543 .45479 L .33048 .46404 L p
1 g
F P
s
P
p
.002 w
.5907 .28407 m .5487 .26908 L .54994 .2876 L p
1 g
F P
s
P
p
.002 w
.54994 .2876 m .58437 .29995 L .5907 .28407 L p
1 g
F P
s
P
p
.002 w
.57523 .56673 m .62304 .54457 L .61869 .52469 L p
1 g
F P
s
P
p
.002 w
.65245 .49095 m .61869 .52469 L .62304 .54457 L p
1 g
F P
s
P
p
.002 w
.49566 .25374 m .44933 .26991 L .46497 .28247 L p
1 g
F P
s
P
p
.002 w
.46497 .28247 m .50512 .26863 L .49566 .25374 L p
1 g
F P
s
P
p
.002 w
.39799 .56314 m .45042 .59364 L .46001 .57865 L p
1 g
F P
s
P
p
.002 w
.51612 .59126 m .46001 .57865 L .45042 .59364 L p
1 g
F P
s
P
p
.002 w
.6618 .39246 m .65077 .34965 L .63364 .35371 L p
1 g
F P
s
P
p
.002 w
.61341 .32288 m .63364 .35371 L .65077 .34965 L p
1 g
F P
s
P
p
.002 w
.62613 .31202 m .5907 .28407 L .58437 .29995 L p
1 g
F P
s
P
p
.002 w
.58437 .29995 m .61341 .32288 L .62613 .31202 L p
1 g
F P
s
P
p
.002 w
.51612 .59126 m .57281 .58577 L .57523 .56673 L p
1 g
F P
s
P
p
.002 w
.62304 .54457 m .57523 .56673 L .57281 .58577 L p
1 g
F P
s
P
p
.002 w
.65077 .34965 m .62613 .31202 L .61341 .32288 L p
1 g
F P
s
P
p
.002 w
.32212 .40473 m .33048 .46404 L .34543 .45479 L p
1 g
F P
s
P
p
.002 w
.34543 .45479 m .33759 .39806 L .32212 .40473 L p
1 g
F P
s
P
p
.002 w
.43447 .26113 m .39335 .29508 L .41219 .30033 L p
1 g
F P
s
P
p
.002 w
.41219 .30033 m .44933 .26991 L .43447 .26113 L p
1 g
F P
s
P
p
.002 w
.65245 .49095 m .6729 .4469 L .65816 .43541 L p
1 g
F P
s
P
p
.002 w
.6618 .39246 m .65816 .43541 L .6729 .4469 L p
1 g
F P
s
P
p
.002 w
.37665 .29324 m .34814 .34226 L .36666 .34057 L p
1 g
F P
s
P
p
.002 w
.36666 .34057 m .39335 .29508 L .37665 .29324 L p
1 g
F P
s
P
p
.002 w
.45042 .59364 m .50909 .60696 L .51612 .59126 L p
1 g
F P
s
P
p
.002 w
.57281 .58577 m .51612 .59126 L .50909 .60696 L p
1 g
F P
s
P
p
.002 w
.54613 .25413 m .49566 .25374 L .50512 .26863 L p
1 g
F P
s
P
p
.002 w
.50512 .26863 m .5487 .26908 L .54613 .25413 L p
1 g
F P
s
P
p
.002 w
.62304 .54457 m .66069 .50727 L .65245 .49095 L p
1 g
F P
s
P
p
.002 w
.6729 .4469 m .65245 .49095 L .66069 .50727 L p
1 g
F P
s
P
p
.002 w
.33297 .34637 m .32212 .40473 L .33759 .39806 L p
1 g
F P
s
P
p
.002 w
.33759 .39806 m .34814 .34226 L .33297 .34637 L p
1 g
F P
s
P
p
.002 w
.6729 .4469 m .67726 .39722 L .6618 .39246 L p
1 g
F P
s
P
p
.002 w
.65077 .34965 m .6618 .39246 L .67726 .39722 L p
1 g
F P
s
P
p
.002 w
.34624 .52829 m .38836 .57374 L .39799 .56314 L p
1 g
F P
s
P
p
.002 w
.39799 .56314 m .35669 .51855 L .34624 .52829 L p
1 g
F P
s
P
p
.002 w
.45042 .59364 m .39799 .56314 L .38836 .57374 L p
1 g
F P
s
P
p
.002 w
.57281 .58577 m .62432 .56214 L .62304 .54457 L p
1 g
F P
s
P
p
.002 w
.66069 .50727 m .62304 .54457 L .62432 .56214 L p
1 g
F P
s
P
p
.002 w
.31945 .47276 m .34624 .52829 L .35669 .51855 L p
1 g
F P
s
P
p
.002 w
.35669 .51855 m .33048 .46404 L .31945 .47276 L p
1 g
F P
s
P
p
.002 w
.48597 .24299 m .43447 .26113 L .44933 .26991 L p
1 g
F P
s
P
p
.002 w
.44933 .26991 m .49566 .25374 L .48597 .24299 L p
1 g
F P
s
P
p
.002 w
.59486 .27145 m .54613 .25413 L .5487 .26908 L p
1 g
F P
s
P
p
.002 w
.5487 .26908 m .5907 .28407 L .59486 .27145 L p
1 g
F P
s
P
p
.002 w
.50909 .60696 m .45042 .59364 L .44178 .60488 L p
1 g
F P
s
P
p
.002 w
.38836 .57374 m .44178 .60488 L .45042 .59364 L p
1 g
F P
s
P
p
.002 w
.67726 .39722 m .66456 .34757 L .65077 .34965 L p
1 g
F P
s
P
p
.002 w
.62613 .31202 m .65077 .34965 L .66456 .34757 L p
1 g
F P
s
P
p
.002 w
.50909 .60696 m .56839 .60139 L .57281 .58577 L p
1 g
F P
s
P
p
.002 w
.62432 .56214 m .57281 .58577 L .56839 .60139 L p
1 g
F P
s
P
p
.002 w
.636 .30388 m .59486 .27145 L .5907 .28407 L p
1 g
F P
s
P
p
.002 w
.5907 .28407 m .62613 .31202 L .636 .30388 L p
1 g
F P
s
P
p
.002 w
.4208 .25657 m .37665 .29324 L .39335 .29508 L p
1 g
F P
s
P
p
.002 w
.39335 .29508 m .43447 .26113 L .4208 .25657 L p
1 g
F P
s
P
p
.002 w
.31081 .41235 m .31945 .47276 L .33048 .46404 L p
1 g
F P
s
P
p
.002 w
.33048 .46404 m .32212 .40473 L .31081 .41235 L p
1 g
F P
s
P
p
.002 w
.66456 .34757 m .636 .30388 L .62613 .31202 L p
1 g
F P
s
P
p
.002 w
.66069 .50727 m .68359 .45838 L .6729 .4469 L p
1 g
F P
s
P
p
.002 w
.67726 .39722 m .6729 .4469 L .68359 .45838 L p
1 g
F P
s
P
p
.002 w
.36264 .29503 m .33297 .34637 L .34814 .34226 L p
1 g
F P
s
P
p
.002 w
.34814 .34226 m .37665 .29324 L .36264 .29503 L p
1 g
F P
s
P
p
.002 w
.44178 .60488 m .50154 .61856 L .50909 .60696 L p
1 g
F P
s
P
p
.002 w
.56839 .60139 m .50909 .60696 L .50154 .61856 L p
1 g
F P
s
P
p
.002 w
.54221 .24333 m .48597 .24299 L .49566 .25374 L p
1 g
F P
s
P
p
.002 w
.49566 .25374 m .54613 .25413 L .54221 .24333 L p
1 g
F P
s
P
p
.002 w
.62432 .56214 m .66495 .52216 L .66069 .50727 L p
1 g
F P
s
P
p
.002 w
.68359 .45838 m .66069 .50727 L .66495 .52216 L p
1 g
F P
s
P
p
.002 w
.32173 .35291 m .31081 .41235 L .32212 .40473 L p
1 g
F P
s
P
p
.002 w
.32212 .40473 m .33297 .34637 L .32173 .35291 L p
1 g
F P
s
P
p
.002 w
.68359 .45838 m .68857 .40306 L .67726 .39722 L p
1 g
F P
s
P
p
.002 w
.66456 .34757 m .67726 .39722 L .68857 .40306 L p
1 g
F P
s
P
p
.002 w
.56839 .60139 m .6223 .57685 L .62432 .56214 L p
1 g
F P
s
P
p
.002 w
.66495 .52216 m .62432 .56214 L .6223 .57685 L p
1 g
F P
s
P
p
.002 w
.3395 .53579 m .38133 .58093 L .38836 .57374 L p
1 g
F P
s
P
p
.002 w
.38836 .57374 m .34624 .52829 L .3395 .53579 L p
1 g
F P
s
P
p
.002 w
.44178 .60488 m .38836 .57374 L .38133 .58093 L p
1 g
F P
s
P
p
.002 w
.47626 .2369 m .4208 .25657 L .43447 .26113 L p
1 g
F P
s
P
p
.002 w
.43447 .26113 m .48597 .24299 L .47626 .2369 L p
1 g
F P
s
P
p
.002 w
.31285 .4807 m .3395 .53579 L .34624 .52829 L p
1 g
F P
s
P
p
.002 w
.34624 .52829 m .31945 .47276 L .31285 .4807 L p
1 g
F P
s
P
p
.002 w
.59663 .26262 m .54221 .24333 L .54613 .25413 L p
1 g
F P
s
P
p
.002 w
.54613 .25413 m .59486 .27145 L .59663 .26262 L p
1 g
F P
s
P
p
.002 w
.38133 .58093 m .43436 .61188 L .44178 .60488 L p
1 g
F P
s
P
p
.002 w
.50154 .61856 m .44178 .60488 L .43436 .61188 L p
1 g
F P
s
P
p
.002 w
.50154 .61856 m .56194 .61302 L .56839 .60139 L p
1 g
F P
s
P
p
.002 w
.6223 .57685 m .56839 .60139 L .56194 .61302 L p
1 g
F P
s
P
p
.002 w
.68857 .40306 m .67448 .34765 L .66456 .34757 L p
1 g
F P
s
P
p
.002 w
.636 .30388 m .66456 .34757 L .67448 .34765 L p
1 g
F P
s
P
p
.002 w
.40874 .25658 m .36264 .29503 L .37665 .29324 L p
1 g
F P
s
P
p
.002 w
.37665 .29324 m .4208 .25657 L .40874 .25658 L p
1 g
F P
s
P
p
.002 w
.64259 .29884 m .59663 .26262 L .59486 .27145 L p
1 g
F P
s
P
p
.002 w
.59486 .27145 m .636 .30388 L .64259 .29884 L p
1 g
F P
s
P
p
.002 w
.30421 .42079 m .31285 .4807 L .31945 .47276 L p
1 g
F P
s
P
p
.002 w
.31945 .47276 m .31081 .41235 L .30421 .42079 L p
1 g
F P
s
P
p
.002 w
.66495 .52216 m .68975 .46956 L .68359 .45838 L p
1 g
F P
s
P
p
.002 w
.68857 .40306 m .68359 .45838 L .68975 .46956 L p
1 g
F P
s
P
p
.002 w
.67448 .34765 m .64259 .29884 L .636 .30388 L p
1 g
F P
s
P
p
.002 w
.35184 .30062 m .32173 .35291 L .33297 .34637 L p
1 g
F P
s
P
p
.002 w
.33297 .34637 m .36264 .29503 L .35184 .30062 L p
1 g
F P
s
P
p
.002 w
.53698 .23721 m .47626 .2369 L .48597 .24299 L p
1 g
F P
s
P
p
.002 w
.48597 .24299 m .54221 .24333 L .53698 .23721 L p
1 g
F P
s
P
p
.002 w
.43436 .61188 m .49364 .62552 L .50154 .61856 L p
1 g
F P
s
P
p
.002 w
.56194 .61302 m .50154 .61856 L .49364 .62552 L p
1 g
F P
s
P
p
.002 w
.6223 .57685 m .66489 .53514 L .66495 .52216 L p
1 g
F P
s
P
p
.002 w
.68975 .46956 m .66495 .52216 L .66489 .53514 L p
1 g
F P
s
P
p
.002 w
.31496 .36188 m .30421 .42079 L .31081 .41235 L p
1 g
F P
s
P
p
.002 w
.31081 .41235 m .32173 .35291 L .31496 .36188 L p
1 g
F P
s
P
p
.002 w
.68975 .46956 m .6952 .40989 L .68857 .40306 L p
1 g
F P
s
P
p
.002 w
.67448 .34765 m .68857 .40306 L .6952 .40989 L p
1 g
F P
s
P
p
.002 w
.56194 .61302 m .61686 .58815 L .6223 .57685 L p
1 g
F P
s
P
p
.002 w
.66489 .53514 m .6223 .57685 L .61686 .58815 L p
1 g
F P
s
P
p
.002 w
.46679 .23594 m .40874 .25658 L .4208 .25657 L p
1 g
F P
s
P
p
.002 w
.4208 .25657 m .47626 .2369 L .46679 .23594 L p
1 g
F P
s
P
p
.002 w
.33687 .54073 m .37726 .5843 L .38133 .58093 L p
1 g
F P
s
P
p
.002 w
.38133 .58093 m .3395 .53579 L .33687 .54073 L p
1 g
F P
s
P
p
.002 w
.43436 .61188 m .38133 .58093 L .37726 .5843 L p
1 g
F P
s
P
p
.002 w
.59581 .25803 m .53698 .23721 L .54221 .24333 L p
1 g
F P
s
P
p
.002 w
.54221 .24333 m .59663 .26262 L .59581 .25803 L p
1 g
F P
s
P
p
.002 w
.31114 .48758 m .33687 .54073 L .3395 .53579 L p
1 g
F P
s
P
p
.002 w
.3395 .53579 m .31285 .4807 L .31114 .48758 L p
1 g
F P
s
P
p
.002 w
.49364 .62552 m .55352 .62011 L .56194 .61302 L p
1 g
F P
s
P
p
.002 w
.61686 .58815 m .56194 .61302 L .55352 .62011 L p
1 g
F P
s
P
p
.002 w
.49364 .62552 m .43436 .61188 L .42843 .61418 L p
1 g
F P
s
P
p
.002 w
.37726 .5843 m .42843 .61418 L .43436 .61188 L p
1 g
F P
s
P
p
.002 w
.39873 .26146 m .35184 .30062 L .36264 .29503 L p
1 g
F P
s
P
p
.002 w
.36264 .29503 m .40874 .25658 L .39873 .26146 L p
1 g
F P
s
P
p
.002 w
.6952 .40989 m .68001 .35001 L .67448 .34765 L p
1 g
F P
s
P
p
.002 w
.64259 .29884 m .67448 .34765 L .68001 .35001 L p
1 g
F P
s
P
p
.002 w
.64553 .29721 m .59581 .25803 L .59663 .26262 L p
1 g
F P
s
P
p
.002 w
.59663 .26262 m .64259 .29884 L .64553 .29721 L p
1 g
F P
s
P
p
.002 w
.66489 .53514 m .69091 .48012 L .68975 .46956 L p
1 g
F P
s
P
p
.002 w
.6952 .40989 m .68975 .46956 L .69091 .48012 L p
1 g
F P
s
P
p
.002 w
.30279 .42985 m .31114 .48758 L .31285 .4807 L p
1 g
F P
s
P
p
.002 w
.31285 .4807 m .30421 .42079 L .30279 .42985 L p
1 g
F P
s
P
p
.002 w
.68001 .35001 m .64553 .29721 L .64259 .29884 L p
1 g
F P
s
P
p
.002 w
.34475 .3101 m .31496 .36188 L .32173 .35291 L p
1 g
F P
s
P
p
.002 w
.32173 .35291 m .35184 .30062 L .34475 .3101 L p
1 g
F P
s
P
p
.002 w
.53047 .23624 m .46679 .23594 L .47626 .2369 L p
1 g
F P
s
P
p
.002 w
.47626 .2369 m .53698 .23721 L .53047 .23624 L p
1 g
F P
s
P
p
.002 w
.42843 .61418 m .48558 .62737 L .49364 .62552 L p
1 g
F P
s
P
p
.002 w
.55352 .62011 m .49364 .62552 L .48558 .62737 L p
1 g
F P
s
P
p
.002 w
.61686 .58815 m .66024 .54575 L .66489 .53514 L p
1 g
F P
s
P
p
.002 w
.69091 .48012 m .66489 .53514 L .66024 .54575 L p
1 g
F P
s
P
p
.004 w
.28991 .64281 m
.30439 .62819 L
s
P
p
.002 w
.31314 .37316 m .30279 .42985 L .30421 .42079 L p
1 g
F P
s
P
p
.002 w
.30421 .42079 m .31496 .36188 L .31314 .37316 L p
1 g
F P
s
P
p
.002 w
.55352 .62011 m .60793 .59552 L .61686 .58815 L p
1 g
F P
s
P
p
.002 w
.66024 .54575 m .61686 .58815 L .60793 .59552 L p
1 g
F P
s
P
p
.002 w
.69091 .48012 m .69666 .41759 L .6952 .40989 L p
1 g
F P
s
P
p
.002 w
.68001 .35001 m .6952 .40989 L .69666 .41759 L p
1 g
F P
s
P
p
.002 w
.45787 .24045 m .39873 .26146 L .40874 .25658 L p
1 g
F P
s
P
p
.002 w
.40874 .25658 m .46679 .23594 L .45787 .24045 L p
1 g
F P
s
P
p
.002 w
.33872 .54279 m .37645 .5835 L .37726 .5843 L p
1 g
F P
s
P
p
.002 w
.37726 .5843 m .33687 .54073 L .33872 .54279 L p
1 g
F P
s
P
p
.002 w
.42843 .61418 m .37726 .5843 L .37645 .5835 L p
1 g
F P
s
P
p
.002 w
.59224 .25812 m .53047 .23624 L .53698 .23721 L p
1 g
F P
s
P
p
.002 w
.53698 .23721 m .59581 .25803 L .59224 .25812 L p
1 g
F P
s
P
p
.002 w
.31469 .49316 m .33872 .54279 L .33687 .54073 L p
1 g
F P
s
P
p
.002 w
.33687 .54073 m .31114 .48758 L .31469 .49316 L p
1 g
F P
s
P
p
.002 w
.48558 .62737 m .54324 .62216 L .55352 .62011 L p
1 g
F P
s
P
p
.002 w
.60793 .59552 m .55352 .62011 L .54324 .62216 L p
1 g
F P
s
P
p
.002 w
.39119 .27137 m .34475 .3101 L .35184 .30062 L p
1 g
F P
s
P
p
.002 w
.35184 .30062 m .39873 .26146 L .39119 .27137 L p
1 g
F P
s
P
p
.002 w
.37645 .5835 m .42425 .61141 L .42843 .61418 L p
1 g
F P
s
P
p
.002 w
.48558 .62737 m .42843 .61418 L .42425 .61141 L p
1 g
F P
s
P
p
.002 w
.69666 .41759 m .68071 .35475 L .68001 .35001 L p
1 g
F P
s
P
p
.002 w
.64553 .29721 m .68001 .35001 L .68071 .35475 L p
1 g
F P
s
P
p
.002 w
.66024 .54575 m .68675 .48974 L .69091 .48012 L p
1 g
F P
s
P
p
.002 w
.69666 .41759 m .69091 .48012 L .68675 .48974 L p
1 g
F P
s
P
p
.002 w
.30693 .43932 m .31469 .49316 L .31114 .48758 L p
1 g
F P
s
P
p
.002 w
.31114 .48758 m .30279 .42985 L .30693 .43932 L p
1 g
F P
s
P
p
.002 w
.64449 .29929 m .59224 .25812 L .59581 .25803 L p
1 g
F P
s
P
p
.002 w
.59581 .25803 m .64553 .29721 L .64449 .29929 L p
1 g
F P
s
P
p
.002 w
.68071 .35475 m .64449 .29929 L .64553 .29721 L p
1 g
F P
s
P
p
.002 w
.34183 .32342 m .31314 .37316 L .31496 .36188 L p
1 g
F P
s
P
p
.002 w
.31496 .36188 m .34475 .3101 L .34183 .32342 L p
1 g
F P
s
P
p
.002 w
.52281 .24081 m .45787 .24045 L .46679 .23594 L p
1 g
F P
s
P
p
.002 w
.46679 .23594 m .53047 .23624 L .52281 .24081 L p
1 g
F P
s
P
p
.002 w
.42425 .61141 m .47759 .6237 L .48558 .62737 L p
1 g
F P
s
P
p
.002 w
.54324 .62216 m .48558 .62737 L .47759 .6237 L p
1 g
F P
s
P
p
.002 w
.60793 .59552 m .65086 .55354 L .66024 .54575 L p
1 g
F P
s
P
p
.002 w
.68675 .48974 m .66024 .54575 L .65086 .55354 L p
1 g
F P
s
P
p
.002 w
.31663 .38656 m .30693 .43932 L .30279 .42985 L p
1 g
F P
s
P
p
.002 w
.30279 .42985 m .31314 .37316 L .31663 .38656 L p
1 g
F P
s
P
p
.002 w
.54324 .62216 m .59555 .59848 L .60793 .59552 L p
1 g
F P
s
P
p
.002 w
.65086 .55354 m .60793 .59552 L .59555 .59848 L p
1 g
F P
s
P
p
.002 w
.68675 .48974 m .69256 .42599 L .69666 .41759 L p
1 g
F P
s
P
p
.002 w
.68071 .35475 m .69666 .41759 L .69256 .42599 L p
1 g
F P
s
P
p
.002 w
.44979 .25065 m .39119 .27137 L .39873 .26146 L p
1 g
F P
s
P
p
.002 w
.39873 .26146 m .45787 .24045 L .44979 .25065 L p
1 g
F P
s
P
p
.002 w
.58586 .26319 m .52281 .24081 L .53047 .23624 L p
1 g
F P
s
P
p
.002 w
.53047 .23624 m .59224 .25812 L .58586 .26319 L p
1 g
F P
s
P
p
.002 w
.34527 .54171 m .37916 .57827 L .37645 .5835 L p
1 g
F P
s
P
p
.002 w
.37645 .5835 m .33872 .54279 L .34527 .54171 L p
1 g
F P
s
P
p
.004 w
.3579 .57411 m
.36298 .56898 L
s
P
p
.004 w
.36688 .56503 m
.5 .43051 L
s
P
p
.004 w
.36298 .56898 m
.364 .56794 L
s
P
p
.004 w
.30439 .62819 m
.3579 .57411 L
s
P
p
.002 w
.42425 .61141 m .37645 .5835 L .37916 .57827 L p
1 g
F P
s
P
p
.002 w
.32374 .49717 m .34527 .54171 L .33872 .54279 L p
1 g
F P
s
P
p
.002 w
.33872 .54279 m .31469 .49316 L .32374 .49717 L p
1 g
F P
s
P
p
.002 w
.38652 .28631 m .34183 .32342 L .34475 .3101 L p
1 g
F P
s
P
p
.002 w
.34475 .3101 m .39119 .27137 L .38652 .28631 L p
1 g
F P
s
P
p
.002 w
.47759 .6237 m .53129 .61881 L .54324 .62216 L p
1 g
F P
s
P
p
.002 w
.59555 .59848 m .54324 .62216 L .53129 .61881 L p
1 g
F P
s
P
p
.002 w
.47759 .6237 m .42425 .61141 L .42207 .60331 L p
1 g
F P
s
P
p
.002 w
.37916 .57827 m .42207 .60331 L .42425 .61141 L p
1 g
F P
s
P
p
.002 w
.69256 .42599 m .67623 .36188 L .68071 .35475 L p
1 g
F P
s
P
p
.002 w
.64449 .29929 m .68071 .35475 L .67623 .36188 L p
1 g
F P
s
P
p
.002 w
.65086 .55354 m .67703 .49805 L .68675 .48974 L p
1 g
F P
s
P
p
.002 w
.69256 .42599 m .68675 .48974 L .67703 .49805 L p
1 g
F P
s
P
p
.002 w
.31685 .44893 m .32374 .49717 L .31469 .49316 L p
1 g
F P
s
P
p
.002 w
.31469 .49316 m .30693 .43932 L .31685 .44893 L p
1 g
F P
s
P
p
.002 w
.63921 .30525 m .58586 .26319 L .59224 .25812 L p
1 g
F P
s
P
p
.002 w
.59224 .25812 m .64449 .29929 L .63921 .30525 L p
1 g
F P
s
P
p
.002 w
.34341 .3404 m .31663 .38656 L .31314 .37316 L p
1 g
F P
s
P
p
.002 w
.31314 .37316 m .34183 .32342 L .34341 .3404 L p
1 g
F P
s
P
p
.002 w
.67623 .36188 m .63921 .30525 L .64449 .29929 L p
1 g
F P
s
P
p
.002 w
.51415 .25112 m .44979 .25065 L .45787 .24045 L p
1 g
F P
s
P
p
.002 w
.45787 .24045 m .52281 .24081 L .51415 .25112 L p
1 g
F P
s
P
p
.002 w
.59555 .59848 m .63673 .55809 L .65086 .55354 L p
1 g
F P
s
P
p
.002 w
.67703 .49805 m .65086 .55354 L .63673 .55809 L p
1 g
F P
s
P
p
.002 w
.42207 .60331 m .4699 .61428 L .47759 .6237 L p
1 g
F P
s
P
p
.002 w
.53129 .61881 m .47759 .6237 L .4699 .61428 L p
1 g
F P
s
P
p
.002 w
.32565 .40179 m .31685 .44893 L .30693 .43932 L p
1 g
F P
s
P
p
.002 w
.30693 .43932 m .31663 .38656 L .32565 .40179 L p
1 g
F P
s
P
p
.002 w
.53129 .61881 m .57989 .59669 L .59555 .59848 L p
1 g
F P
s
P
p
.002 w
.63673 .55809 m .59555 .59848 L .57989 .59669 L p
1 g
F P
s
P
p
.002 w
.44287 .26656 m .38652 .28631 L .39119 .27137 L p
1 g
F P
s
P
p
.002 w
.39119 .27137 m .44979 .25065 L .44287 .26656 L p
1 g
F P
s
P
p
.002 w
.67703 .49805 m .68268 .43488 L .69256 .42599 L p
1 g
F P
s
P
p
.002 w
.67623 .36188 m .69256 .42599 L .68268 .43488 L p
1 g
F P
s
P
p
.002 w
.57667 .2734 m .51415 .25112 L .52281 .24081 L p
1 g
F P
s
P
p
.002 w
.52281 .24081 m .58586 .26319 L .57667 .2734 L p
1 g
F P
s
P
p
.002 w
.38503 .30609 m .34341 .3404 L .34183 .32342 L p
1 g
F P
s
P
p
.002 w
.34183 .32342 m .38652 .28631 L .38503 .30609 L p
1 g
F P
s
P
p
.002 w
.35664 .53734 m .38551 .56849 L .37916 .57827 L p
1 g
F P
s
P
p
.002 w
.37916 .57827 m .34527 .54171 L .35664 .53734 L p
1 g
F P
s
P
p
.002 w
.42207 .60331 m .37916 .57827 L .38551 .56849 L p
1 g
F P
s
P
p
.002 w
.4699 .61428 m .51795 .60981 L .53129 .61881 L p
1 g
F P
s
P
p
.002 w
.57989 .59669 m .53129 .61881 L .51795 .60981 L p
1 g
F P
s
P
p
.002 w
.33835 .49939 m .35664 .53734 L .34527 .54171 L p
1 g
F P
s
P
p
.002 w
.34527 .54171 m .32374 .49717 L .33835 .49939 L p
1 g
F P
s
P
p
.002 w
.38551 .56849 m .42209 .5898 L .42207 .60331 L p
1 g
F P
s
P
p
.002 w
.4699 .61428 m .42207 .60331 L .42209 .5898 L p
1 g
F P
s
P
p
.002 w
.63673 .55809 m .66173 .50472 L .67703 .49805 L p
1 g
F P
s
P
p
.002 w
.68268 .43488 m .67703 .49805 L .66173 .50472 L p
1 g
F P
s
P
p
.002 w
.68268 .43488 m .66639 .37133 L .67623 .36188 L p
1 g
F P
s
P
p
.002 w
.63921 .30525 m .67623 .36188 L .66639 .37133 L p
1 g
F P
s
P
p
.002 w
.3497 .36069 m .32565 .40179 L .31663 .38656 L p
1 g
F P
s
P
p
.002 w
.31663 .38656 m .34341 .3404 L .3497 .36069 L p
1 g
F P
s
P
p
.002 w
.3326 .45837 m .33835 .49939 L .32374 .49717 L p
1 g
F P
s
P
p
.002 w
.32374 .49717 m .31685 .44893 L .3326 .45837 L p
1 g
F P
s
P
p
.002 w
.62961 .31516 m .57667 .2734 L .58586 .26319 L p
1 g
F P
s
P
p
.002 w
.58586 .26319 m .63921 .30525 L .62961 .31516 L p
1 g
F P
s
P
p
.002 w
.66639 .37133 m .62961 .31516 L .63921 .30525 L p
1 g
F P
s
P
p
.002 w
.57989 .59669 m .61802 .55905 L .63673 .55809 L p
1 g
F P
s
P
p
.002 w
.66173 .50472 m .63673 .55809 L .61802 .55905 L p
1 g
F P
s
P
p
.002 w
.50474 .26719 m .44287 .26656 L .44979 .25065 L p
1 g
F P
s
P
p
.002 w
.44979 .25065 m .51415 .25112 L .50474 .26719 L p
1 g
F P
s
P
p
.002 w
.42209 .5898 m .46279 .59906 L .4699 .61428 L p
1 g
F P
s
P
p
.002 w
.51795 .60981 m .4699 .61428 L .46279 .59906 L p
1 g
F P
s
P
p
.002 w
.51795 .60981 m .56128 .58991 L .57989 .59669 L p
1 g
F P
s
P
p
.002 w
.61802 .55905 m .57989 .59669 L .56128 .58991 L p
1 g
F P
s
P
p
.002 w
.34021 .41842 m .3326 .45837 L .31685 .44893 L p
1 g
F P
s
P
p
.002 w
.31685 .44893 m .32565 .40179 L .34021 .41842 L p
1 g
F P
s
P
p
.002 w
.43741 .28798 m .38503 .30609 L .38652 .28631 L p
1 g
F P
s
P
p
.002 w
.38652 .28631 m .44287 .26656 L .43741 .28798 L p
1 g
F P
s
P
p
.002 w
.66173 .50472 m .66698 .444 L .68268 .43488 L p
1 g
F P
s
P
p
.002 w
.66639 .37133 m .68268 .43488 L .66698 .444 L p
1 g
F P
s
P
p
.002 w
.38694 .33031 m .3497 .36069 L .34341 .3404 L p
1 g
F P
s
P
p
.002 w
.34341 .3404 m .38503 .30609 L .38694 .33031 L p
1 g
F P
s
P
p
.002 w
.46279 .59906 m .50356 .59513 L .51795 .60981 L p
1 g
F P
s
P
p
.002 w
.56128 .58991 m .51795 .60981 L .50356 .59513 L p
1 g
F P
s
P
p
.002 w
.56483 .28872 m .50474 .26719 L .51415 .25112 L p
1 g
F P
s
P
p
.002 w
.51415 .25112 m .57667 .2734 L .56483 .28872 L p
1 g
F P
s
P
p
.002 w
.37275 .52959 m .39554 .5542 L .38551 .56849 L p
1 g
F P
s
P
p
.002 w
.38551 .56849 m .35664 .53734 L .37275 .52959 L p
1 g
F P
s
P
p
.002 w
.42209 .5898 m .38551 .56849 L .39554 .5542 L p
1 g
F P
s
P
p
.002 w
.35837 .49963 m .37275 .52959 L .35664 .53734 L p
1 g
F P
s
P
p
.002 w
.35664 .53734 m .33835 .49939 L .35837 .49963 L p
1 g
F P
s
P
p
.002 w
.61802 .55905 m .64103 .50941 L .66173 .50472 L p
1 g
F P
s
P
p
.002 w
.66698 .444 m .66173 .50472 L .64103 .50941 L p
1 g
F P
s
P
p
.002 w
.39554 .5542 m .42443 .57099 L .42209 .5898 L p
1 g
F P
s
P
p
.002 w
.46279 .59906 m .42209 .5898 L .42443 .57099 L p
1 g
F P
s
P
p
.002 w
.36074 .38376 m .34021 .41842 L .32565 .40179 L p
1 g
F P
s
P
p
.002 w
.32565 .40179 m .3497 .36069 L .36074 .38376 L p
1 g
F P
s
P
p
.002 w
.66698 .444 m .65118 .38292 L .66639 .37133 L p
1 g
F P
s
P
p
.002 w
.62961 .31516 m .66639 .37133 L .65118 .38292 L p
1 g
F P
s
P
p
.002 w
.35394 .46732 m .35837 .49963 L .33835 .49939 L p
1 g
F P
s
P
p
.002 w
.33835 .49939 m .3326 .45837 L .35394 .46732 L p
1 g
F P
s
P
p
.002 w
.61574 .32892 m .56483 .28872 L .57667 .2734 L p
1 g
F P
s
P
p
.002 w
.57667 .2734 m .62961 .31516 L .61574 .32892 L p
1 g
F P
s
P
p
.002 w
.56128 .58991 m .59511 .5562 L .61802 .55905 L p
1 g
F P
s
P
p
.002 w
.64103 .50941 m .61802 .55905 L .59511 .5562 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.49484 .28877 m .43741 .28798 L .44287 .26656 L p
1 g
F P
s
P
p
.002 w
.44287 .26656 m .50474 .26719 L .49484 .28877 L p
1 g
F P
s
P
p
.002 w
.65118 .38292 m .61574 .32892 L .62961 .31516 L p
1 g
F P
s
P
p
.002 w
.42443 .57099 m .45653 .5782 L .46279 .59906 L p
1 g
F P
s
P
p
.002 w
.50356 .59513 m .46279 .59906 L .45653 .5782 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50356 .59513 m .54017 .57811 L .56128 .58991 L p
1 g
F P
s
P
p
.002 w
.59511 .5562 m .56128 .58991 L .54017 .57811 L p
1 g
F P
s
P
p
.002 w
.36008 .43597 m .35394 .46732 L .3326 .45837 L p
1 g
F P
s
P
p
.002 w
.3326 .45837 m .34021 .41842 L .36008 .43597 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.43368 .31443 m .38694 .33031 L .38503 .30609 L p
1 g
F P
s
P
p
.002 w
.38503 .30609 m .43741 .28798 L .43368 .31443 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.64103 .50941 m .64568 .45303 L .66698 .444 L p
1 g
F P
s
P
p
.002 w
.65118 .38292 m .66698 .444 L .64568 .45303 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.39237 .3583 m .36074 .38376 L .3497 .36069 L p
1 g
F P
s
P
p
.002 w
.3497 .36069 m .38694 .33031 L .39237 .3583 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45653 .5782 m .4738 .57647 L p
.50356 .59513 L 1 g
F P
s
P
p
.002 w
.49368 .58185 m .50356 .59513 L p
.47915 .57982 L 1 g
F P
s
P
p
.47915 .57982 m .4738 .57647 L .48906 .5806 L 1 g
F
P
p
.47915 .57982 m .48906 .5806 L .49368 .58185 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51089 .58001 L p
1 g
F P
s
P
p
.002 w
.54017 .57811 m .53911 .5786 L p
.52118 .57732 L 1 g
F P
s
P
p
.54017 .57811 m .52118 .57732 L .5223 .57703 L 1 g
F
P
p
.002 w
.53911 .5786 m .50356 .59513 L .49298 .5809 L p
1 g
F P
s
P
p
.53128 .57265 m .51089 .58001 L .52322 .57678 L 1 g
F
P
p
.002 w
.51089 .58001 m .51079 .57862 L p
.5015 .58048 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .5806 L p
1 g
F P
s
P
p
.002 w
.49298 .5809 m .49368 .58185 L p
.48906 .5806 L 1 g
F P
s
P
p
.002 w
.48906 .5806 m .48889 .583 L p
.49758 .58126 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .5806 L .49758 .58126 L 1 g
F
P
p
.002 w
.48906 .5806 m .48921 .57862 L p
.47851 .57774 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57454 L p
1 g
F P
s
P
p
.002 w
.45653 .5782 m .45488 .56985 L p
.46831 .57454 L 1 g
F P
s
P
p
.002 w
.4738 .57647 m .47164 .57668 L p
.46831 .57454 L 1 g
F P
s
P
p
.002 w
.47164 .57668 m .45653 .5782 L p
.46831 .57454 L 1 g
F P
s
P
p
.002 w
.46831 .57454 m .46872 .57265 L p
.45978 .56908 L 1 g
F P
s
P
p
.48921 .57862 m .46831 .57454 L .47712 .57763 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45082 .56301 L p
1 g
F P
s
P
p
.45653 .5782 m .42989 .54741 L .45082 .56301 L 1 g
F
P
p
.002 w
.454 .56537 m .45438 .56733 L p
.45082 .56301 L 1 g
F P
s
P
p
.002 w
.45438 .56733 m .45653 .5782 L p
.45082 .56301 L 1 g
F P
s
P
p
.002 w
.45082 .56301 m .45146 .56129 L p
.44424 .55501 L 1 g
F P
s
P
p
.46872 .57265 m .45082 .56301 L .45224 .56407 L 1 g
F
P
p
.46872 .57265 m .45072 .56327 L .45978 .56908 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4383 .54745 L p
1 g
F P
s
P
p
.002 w
.42916 .54725 m .43158 .53761 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.43978 .5496 m .43892 .54941 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.43892 .54941 m .42916 .54725 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.4383 .54745 m .43925 .54566 L p
.43533 .53791 L 1 g
F P
s
P
p
.45146 .56129 m .4383 .54745 L .43909 .5486 L 1 g
F
P
p
.45146 .56129 m .43819 .54767 L .44424 .55501 L 1 g
F
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43252 .52871 L p
1 g
F P
s
P
p
.42916 .54725 m .42848 .51475 L .43252 .52871 L 1 g
F
P
p
.002 w
.43321 .53111 m .43222 .53505 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.43222 .53505 m .42916 .54725 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.43252 .52871 m .43346 .52734 L p
.4331 .5169 L 1 g
F P
s
P
p
.002 w
.42589 .51326 m .43465 .50181 L p
.43386 .50943 L 1 g
F P
s
P
p
.002 w
.43305 .51738 m .4307 .51603 L p
.43386 .50943 L 1 g
F P
s
P
p
.002 w
.4307 .51603 m .42589 .51326 L p
.43386 .50943 L 1 g
F P
s
P
p
.002 w
.43386 .50943 m .43485 .50826 L p
.43837 .50004 L 1 g
F P
s
P
p
.4331 .5169 m .43305 .51738 L .43252 .52871 L 1 g
F
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43339 .51 L p
1 g
F P
s
P
p
.43346 .52734 m .43339 .51 L .43308 .51656 L 1 g
F
P
p
.43925 .54566 m .43252 .52871 L .43267 .52924 L 1 g
F
P
p
.43925 .54566 m .43248 .52877 L .43533 .53791 L 1 g
F
P
p
.002 w
.4362 .51921 m .43321 .53111 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.42848 .51475 m .43305 .51738 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.43305 .51738 m .4362 .51921 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.43339 .51 m .43287 .51061 L p
.43308 .51656 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44247 .49148 L p
1 g
F P
s
P
p
.002 w
.44233 .49176 m .42589 .51326 L p
.44015 .49372 L 1 g
F P
s
P
p
.44015 .49372 m .44379 .48873 L .44247 .49148 L 1 g
F
P
p
.44015 .49372 m .44247 .49148 L .44233 .49176 L 1 g
F
P
p
.002 w
.44247 .49148 m .44247 .49148 L p
.44246 .49149 L 1 g
F P
s
P
p
.43485 .50826 m .44247 .49148 L .44246 .49149 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44762 .52169 m .4362 .51921 L .44504 .489 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.46893 .51551 m .45893 .52042 L .44567 .48839 L p
1 g
F P
s
P
p
.002 w
.48086 .49713 m .47652 .50747 L .44596 .48811 L p
1 g
F P
s
P
p
.002 w
.47819 .47422 m .48144 .48563 L .44639 .48769 L p
1 g
F P
s
P
p
.002 w
.44247 .49148 m .44339 .4905 L p
.45101 .4832 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45766 .47673 m .45826 .47608 L p
.4689 .47141 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47143 .46416 m .49861 .43929 L p
.4842 .46393 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47819 .47422 m .47452 .46876 L p
.4775 .46727 L 1 g
F P
s
P
p
.48271 .46649 m .47819 .47422 L .4775 .46727 L 1 g
F
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.4891 .46553 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49861 .43929 m .51193 .4592 L .50212 .46357 L p
1 g
F P
s
P
p
.002 w
.48144 .48563 m .47819 .47422 L .50103 .46406 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47673 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.58849 .46953 m .58545 .51191 L .56662 .5105 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56605 .50933 L p
1 g
F P
s
P
p
.55661 .4905 m .56605 .50933 L .56537 .50791 L 1 g
F
P
p
.58849 .46953 m .56662 .5105 L .56605 .50933 L 1 g
F
P
p
.56451 .49593 m .56605 .50933 L .56129 .49947 L 1 g
F
P
p
.58849 .46953 m .56605 .50933 L .56451 .49593 L 1 g
F
P
p
.002 w
.56605 .50933 m .56515 .50826 L p
.56657 .51749 L 1 g
F P
s
P
p
.002 w
.56618 .51047 m .56662 .5105 L p
.56621 .51093 L 1 g
F P
s
P
p
.56657 .51749 m .56618 .51047 L .56605 .50933 L 1 g
F
P
p
.57107 .52031 m .56687 .52276 L .56662 .5105 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.56687 .52276 m .56621 .51093 L .56662 .5105 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56717 .52826 L p
1 g
F P
s
P
p
.58545 .51191 m .56835 .54935 L .56717 .52826 L 1 g
F
P
p
.56913 .52144 m .56717 .52826 L .56687 .52276 L 1 g
F
P
p
.58545 .51191 m .56717 .52826 L .56913 .52144 L 1 g
F
P
p
.002 w
.56717 .52826 m .56654 .52734 L p
.56495 .53603 L 1 g
F P
s
P
p
.56515 .50826 m .56717 .52826 L .56657 .51749 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54904 .56264 L p
1 g
F P
s
P
p
.5686 .54944 m .53773 .57634 L .54904 .56264 L 1 g
F
P
p
.56716 .54977 m .54904 .56264 L .55789 .55194 L 1 g
F
P
p
.5686 .54944 m .54904 .56264 L .56716 .54977 L 1 g
F
P
p
.002 w
.54904 .56264 m .54854 .56129 L p
.54149 .56801 L 1 g
F P
s
P
p
.56075 .54566 m .54904 .56264 L .55608 .55413 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57457 L p
1 g
F P
s
P
p
.54017 .57811 m .52648 .57728 L .5317 .57457 L 1 g
F
P
p
.002 w
.53379 .57348 m .53434 .57388 L p
.5317 .57457 L 1 g
F P
s
P
p
.002 w
.53434 .57388 m .54017 .57811 L p
.5317 .57457 L 1 g
F P
s
P
p
.002 w
.5317 .57457 m .53128 .57265 L p
.52322 .57678 L 1 g
F P
s
P
p
.54854 .56129 m .5317 .57457 L .53309 .57384 L 1 g
F
P
p
.54854 .56129 m .53177 .57491 L .54149 .56801 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.52648 .57728 m .48858 .57498 L .53379 .57348 L 1 g
F
P
p
.002 w
.49298 .5809 m .48858 .57498 L p
.52118 .57732 L 1 g
F P
s
P
p
.53911 .5786 m .51089 .58001 L .52118 .57732 L 1 g
F
P
p
.51089 .58001 m .49298 .5809 L .52118 .57732 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5317 .57457 L p
1 g
F P
s
P
p
.52322 .57678 m .51111 .583 L .5317 .57457 L 1 g
F
P
p
.002 w
.5317 .57457 m .53177 .57491 L p
.53309 .57384 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.48858 .57498 m .51722 .56146 L .53379 .57348 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56166 .54738 L p
1 g
F P
s
P
p
.56654 .52734 m .56166 .54738 L .56177 .54711 L 1 g
F
P
p
.5686 .54944 m .56004 .55144 L .56166 .54738 L 1 g
F
P
p
.002 w
.56182 .54699 m .56194 .54703 L p
.56166 .54738 L 1 g
F P
s
P
p
.002 w
.56194 .54703 m .5686 .54944 L p
.56166 .54738 L 1 g
F P
s
P
p
.002 w
.56166 .54738 m .56075 .54566 L p
.55673 .55334 L 1 g
F P
s
P
p
.56654 .52734 m .56177 .54711 L .56495 .53603 L 1 g
F
P
p
.56177 .54711 m .56169 .54743 L .56182 .54699 L 1 g
F
P
p
.56177 .54711 m .56182 .54699 L .56495 .53603 L 1 g
F
P
p
.002 w
.54998 .56518 m .55165 .56305 L p
.55673 .55334 L 1 g
F P
s
P
p
.56075 .54566 m .55608 .55413 L .55673 .55334 L 1 g
F
P
p
.55608 .55413 m .54998 .56518 L .55673 .55334 L 1 g
F
P
p
.56166 .54738 m .51722 .56146 L .56182 .54699 L 1 g
F
P
p
.56004 .55144 m .55789 .55194 L .56166 .54738 L 1 g
F
P
p
.55789 .55194 m .51722 .56146 L .56166 .54738 L 1 g
F
P
p
.002 w
.56169 .54743 m .56166 .54738 L p
.55165 .56305 L 1 g
F P
s
P
p
.55673 .55334 m .55165 .56305 L .56166 .54738 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.51722 .56146 m .5393 .53885 L .56182 .54699 L p
1 g
F P
s
P
p
.002 w
.56166 .54738 m .56169 .54743 L p
.56177 .54711 L 1 g
F P
s
P
p
.56717 .52826 m .56772 .53805 L .56435 .53814 L 1 g
F
P
p
.002 w
.56835 .54935 m .56194 .54703 L p
.56772 .53805 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56194 .54703 m .5393 .53885 L p
.56772 .53805 L 1 g
F P
s
P
p
.002 w
.56169 .54743 m .56257 .5491 L p
.56495 .53603 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56687 .52276 m .56717 .52826 L .5393 .53885 L 1 g
F
P
p
.56717 .52826 m .56435 .53814 L .5393 .53885 L 1 g
F
P
p
.002 w
.55165 .56305 m .56257 .5491 L .56169 .54743 L p
1 g
F P
s
P
p
.55789 .55194 m .54904 .56264 L .51722 .56146 L 1 g
F
P
p
.002 w
.53773 .57634 m .53379 .57348 L p
.54904 .56264 L 1 g
F P
s
P
p
.002 w
.53379 .57348 m .51722 .56146 L p
.54904 .56264 L 1 g
F P
s
P
p
.002 w
.53177 .57491 m .5322 .57686 L p
.54149 .56801 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54904 .56264 L p
1 g
F P
s
P
p
.54149 .56801 m .5322 .57686 L .54904 .56264 L 1 g
F
P
p
.002 w
.54904 .56264 m .54998 .56518 L p
.55608 .55413 L 1 g
F P
s
P
p
.002 w
.5686 .54944 m .54017 .57811 L .53773 .57634 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56717 .52826 L p
1 g
F P
s
P
p
.56495 .53603 m .56257 .5491 L .56717 .52826 L 1 g
F
P
p
.002 w
.56717 .52826 m .56854 .53025 L p
.56657 .51749 L 1 g
F P
s
P
p
.002 w
.58545 .51191 m .5686 .54944 L .56835 .54935 L p
1 g
F P
s
P
p
.56687 .52276 m .5393 .53885 L .56621 .51093 L 1 g
F
P
p
.55661 .4905 m .56537 .50791 L .56122 .49932 L 1 g
F
P
p
.56341 .49714 m .56129 .49947 L .55734 .49127 L 1 g
F
P
p
.002 w
.56662 .5105 m .58545 .51191 L p
.57107 .52031 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55734 .49127 L p
1 g
F P
s
P
p
.002 w
.55734 .49127 m .55661 .4905 L p
.56122 .49932 L 1 g
F P
s
P
p
.56122 .49932 m .56713 .51061 L .55734 .49127 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55225 .50943 m .55366 .48773 L p
.55734 .49127 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.56129 .49947 m .55225 .50943 L .55734 .49127 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55734 .49127 L p
1 g
F P
s
P
p
.002 w
.55225 .50943 m .51694 .50445 L p
.54737 .48162 L 1 g
F P
s
P
p
.54174 .47608 m .55734 .49127 L .55366 .48773 L 1 g
F
P
p
.002 w
.55366 .48773 m .55225 .50943 L p
.54737 .48162 L 1 g
F P
s
P
p
.55043 .48459 m .55366 .48773 L .5516 .48573 L 1 g
F
P
p
.54174 .47608 m .55366 .48773 L .55043 .48459 L 1 g
F
P
p
.002 w
.51694 .50445 m .51826 .48178 L .5436 .47796 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54737 .48162 m .51694 .50445 L .5436 .47796 L 1 g
F
P
p
.52699 .46935 m .54234 .47673 L .51826 .48178 L 1 g
F
P
p
.002 w
.54234 .47673 m .54174 .47608 L p
.55598 .49003 L 1 g
F P
s
P
p
.002 w
.54458 .47781 m .5436 .47796 L p
.54234 .47673 L 1 g
F P
s
P
p
.002 w
.5436 .47796 m .51826 .48178 L p
.54234 .47673 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54234 .47673 L p
1 g
F P
s
P
p
.55598 .49003 m .55834 .49233 L .54234 .47673 L 1 g
F
P
p
.002 w
.5436 .47796 m .5544 .47633 L p
.54737 .48162 L 1 g
F P
s
P
p
.002 w
.5544 .47633 m .55366 .48773 L p
.54737 .48162 L 1 g
F P
s
P
p
.5516 .48573 m .55366 .48773 L .55834 .49233 L 1 g
F
P
p
.002 w
.55734 .49127 m .55754 .49149 L p
.55366 .48773 L 1 g
F P
s
P
p
.002 w
.55754 .49149 m .55834 .49233 L p
.55366 .48773 L 1 g
F P
s
P
p
.002 w
.5544 .47633 m .58849 .46953 L p
.56341 .49714 L 1 g
F P
s
P
p
.002 w
.55366 .48773 m .5544 .47633 L p
.56341 .49714 L 1 g
F P
s
P
p
.56122 .49932 m .56612 .50942 L .56364 .50394 L 1 g
F
P
p
.56537 .50791 m .56612 .50942 L .56122 .49932 L 1 g
F
P
p
.56129 .49947 m .56605 .50933 L .55225 .50943 L 1 g
F
P
p
.002 w
.56662 .5105 m .56618 .51047 L p
.56605 .50933 L 1 g
F P
s
P
p
.002 w
.56618 .51047 m .55225 .50943 L p
.56605 .50933 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56612 .50942 L p
1 g
F P
s
P
p
.002 w
.56612 .50942 m .56605 .50933 L p
.56618 .5104 L 1 g
F P
s
P
p
.56618 .5104 m .56854 .53025 L .56612 .50942 L 1 g
F
P
p
.56657 .51749 m .56823 .52825 L .56618 .51047 L 1 g
F
P
p
.002 w
.5393 .53885 m .55225 .50943 L .56618 .51047 L p
1 g
F P
s
P
p
.56621 .51093 m .5393 .53885 L .56618 .51047 L 1 g
F
P
p
.56823 .52825 m .56854 .53025 L .56605 .50933 L 1 g
F
P
p
.002 w
.56605 .50933 m .56612 .50942 L p
.56537 .50791 L 1 g
F P
s
P
p
.002 w
.56612 .50942 m .56713 .51061 L p
.56364 .50394 L 1 g
F P
s
P
p
.002 w
.54234 .47673 m .54302 .47747 L p
.53167 .4716 L 1 g
F P
s
P
p
.52214 .46667 m .54234 .47673 L .53167 .4716 L 1 g
F
P
p
.002 w
.54531 .44328 m .5544 .47633 L .54458 .47781 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.51826 .48178 m .51385 .46606 L p
.52244 .46717 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.53167 .4716 L 1 g
F P
s
P
p
.52802 .46789 m .52699 .46935 L .52244 .46717 L 1 g
F
P
p
.52699 .46935 m .51826 .48178 L .52244 .46717 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46717 L p
1 g
F P
s
P
p
.53167 .4716 m .54302 .47747 L .52244 .46717 L 1 g
F
P
p
.54531 .44328 m .54458 .47781 L .52699 .46935 L 1 g
F
P
p
.002 w
.52244 .46717 m .52259 .46742 L p
.51778 .46656 L 1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .51778 .46656 L 1 g
F
P
p
.002 w
.51193 .4592 m .54531 .44328 L p
.52802 .46789 L 1 g
F P
s
P
p
.5 .4634 m .52259 .46742 L .51687 .46653 L 1 g
F
P
p
.002 w
.51385 .46606 m .51826 .48178 L p
.50552 .46476 L 1 g
F P
s
P
p
.51365 .46602 m .52271 .46761 L .51717 .4667 L 1 g
F
P
p
.5 .4634 m .51687 .46653 L .51365 .46602 L 1 g
F
P
p
.51687 .46653 m .52271 .46761 L .51365 .46602 L 1 g
F
P
p
.002 w
.51826 .48178 m .48144 .48563 L p
.50552 .46476 L 1 g
F P
s
P
p
.50552 .46476 m .48144 .48563 L .50103 .46406 L 1 g
F
P
p
.002 w
.50103 .46406 m .47819 .47422 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.51717 .4667 L 1 g
F P
s
P
p
.51717 .4667 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.49861 .43929 m .50212 .46357 L .5 .46389 L 1 g
F
P
p
.47786 .46667 m .5 .46389 L .4891 .46553 L 1 g
F
P
p
.48561 .46153 m .5 .46389 L .48271 .46649 L 1 g
F
P
p
.49861 .43929 m .5 .46389 L .48561 .46153 L 1 g
F
P
p
.002 w
.51193 .4592 m .51385 .46606 L p
.50552 .46476 L 1 g
F P
s
P
p
.002 w
.51385 .46606 m .51193 .4592 L p
.52802 .46789 L 1 g
F P
s
P
p
.002 w
.50103 .46406 m .51193 .4592 L p
.50552 .46476 L 1 g
F P
s
P
p
.002 w
.52259 .46742 m .52271 .46761 L p
.51687 .46653 L 1 g
F P
s
P
p
.002 w
.52271 .46761 m .52282 .46778 L p
.51717 .4667 L 1 g
F P
s
P
p
.48271 .46649 m .5 .46389 L .47819 .47422 L 1 g
F
P
p
.002 w
.50212 .46357 m .50103 .46406 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.4891 .46553 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46727 L p
1 g
F P
s
P
p
.4891 .46553 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.4842 .46393 m .48271 .46649 L .4775 .46727 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.45826 .47608 m .4775 .46727 L .47579 .46812 L 1 g
F
P
p
.45826 .47608 m .47743 .46738 L .4689 .47141 L 1 g
F
P
p
.002 w
.47452 .46876 m .47143 .46416 L p
.4842 .46393 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .47743 .46738 L p
.47579 .46812 L 1 g
F P
s
P
p
.002 w
.47452 .46876 m .47819 .47422 L p
.45842 .47637 L 1 g
F P
s
P
p
.002 w
.47743 .46738 m .47718 .46778 L p
.4689 .47141 L 1 g
F P
s
P
p
.002 w
.47819 .47422 m .44701 .48709 L p
.45842 .47637 L 1 g
F P
s
P
p
.002 w
.47143 .46416 m .47452 .46876 L p
.45842 .47637 L 1 g
F P
s
P
p
.002 w
.45907 .47537 m .47143 .46416 L p
.45842 .47637 L 1 g
F P
s
P
p
.45842 .47637 m .44701 .48709 L .45766 .47673 L 1 g
F
P
p
.45842 .47637 m .45766 .47673 L .45907 .47537 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45766 .47673 L p
1 g
F P
s
P
p
.4689 .47141 m .47718 .46778 L .45766 .47673 L 1 g
F
P
p
.45101 .4832 m .45112 .48309 L .45057 .48363 L 1 g
F
P
p
.45101 .4832 m .45057 .48363 L .44247 .49148 L 1 g
F
P
p
.45112 .48309 m .45013 .48406 L .44247 .49148 L 1 g
F
P
p
.45138 .48285 m .44971 .48447 L .44247 .49148 L 1 g
F
P
p
.4518 .48244 m .44923 .48494 L .44247 .49148 L 1 g
F
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4454 .48775 m .46192 .45659 L .47097 .4638 L p
1 g
F P
s
P
p
.002 w
.47097 .4638 m .47143 .46416 L .45907 .47537 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45766 .47673 L p
1 g
F P
s
P
p
.002 w
.45907 .47537 m .4454 .48775 L p
.47097 .4638 L 1 g
F P
s
P
p
.002 w
.45766 .47673 m .45704 .47741 L p
.45137 .48285 L 1 g
F P
s
P
p
.44339 .4905 m .45766 .47673 L .45137 .48285 L 1 g
F
P
p
.002 w
.45704 .47741 m .45698 .47747 L p
.45588 .47853 L 1 g
F P
s
P
p
.44339 .4905 m .45704 .47741 L .45588 .47853 L 1 g
F
P
p
.43485 .50826 m .44247 .49148 L .43837 .50004 L 1 g
F
P
p
.002 w
.44233 .49176 m .44278 .49118 L p
.43386 .50943 L 1 g
F P
s
P
p
.002 w
.44278 .49118 m .4454 .48775 L p
.44442 .4896 L 1 g
F P
s
P
p
.43386 .50943 m .44278 .49118 L .44442 .4896 L 1 g
F
P
p
.002 w
.44701 .48709 m .4454 .48775 L .45907 .47537 L p
1 g
F P
s
P
p
.002 w
.44639 .48769 m .4454 .48775 L .44701 .48709 L p
1 g
F P
s
P
p
.002 w
.44701 .48709 m .47819 .47422 L p
.44639 .48769 L 1 g
F P
s
P
p
.45112 .48309 m .45138 .48285 L .45013 .48406 L 1 g
F
P
p
.45138 .48285 m .4518 .48244 L .44971 .48447 L 1 g
F
P
p
.002 w
.48144 .48563 m .48086 .49713 L .44613 .48794 L p
1 g
F P
s
P
p
.002 w
.44613 .48794 m .4454 .48775 L .44639 .48769 L p
1 g
F P
s
P
p
.002 w
.44639 .48769 m .48144 .48563 L p
.44613 .48794 L 1 g
F P
s
P
p
.002 w
.44596 .48811 m .4454 .48775 L .44613 .48794 L p
1 g
F P
s
P
p
.002 w
.44613 .48794 m .48086 .49713 L p
.44596 .48811 L 1 g
F P
s
P
p
.4518 .48244 m .4524 .48187 L .44923 .48494 L 1 g
F
P
p
.4524 .48187 m .45319 .48111 L .44859 .48556 L 1 g
F
P
p
.4524 .48187 m .44859 .48556 L .44247 .49148 L 1 g
F
P
p
.002 w
.47652 .50747 m .46893 .51551 L .44582 .48824 L p
1 g
F P
s
P
p
.002 w
.44582 .48824 m .4454 .48775 L .44596 .48811 L p
1 g
F P
s
P
p
.002 w
.44596 .48811 m .47652 .50747 L p
.44582 .48824 L 1 g
F P
s
P
p
.002 w
.44567 .48839 m .4454 .48775 L .44582 .48824 L p
1 g
F P
s
P
p
.002 w
.44582 .48824 m .46893 .51551 L p
.44567 .48839 L 1 g
F P
s
P
p
.45319 .48111 m .45413 .48021 L .44773 .48639 L 1 g
F
P
p
.45319 .48111 m .44773 .48639 L .44247 .49148 L 1 g
F
P
p
.45413 .48021 m .45511 .47927 L .44659 .48749 L 1 g
F
P
p
.45413 .48021 m .44659 .48749 L .44247 .49148 L 1 g
F
P
p
.002 w
.45893 .52042 m .44762 .52169 L .44546 .4886 L p
1 g
F P
s
P
p
.002 w
.44546 .4886 m .4454 .48775 L .44567 .48839 L p
1 g
F P
s
P
p
.002 w
.44567 .48839 m .45893 .52042 L p
.44546 .4886 L 1 g
F P
s
P
p
.002 w
.44504 .489 m .4454 .48775 L .44546 .4886 L p
1 g
F P
s
P
p
.002 w
.44546 .4886 m .44762 .52169 L p
.44504 .489 L 1 g
F P
s
P
p
.45511 .47927 m .45588 .47853 L .44511 .48893 L 1 g
F
P
p
.45511 .47927 m .44511 .48893 L .44247 .49148 L 1 g
F
P
p
.45588 .47853 m .44278 .49118 L .44247 .49148 L 1 g
F
P
p
.002 w
.4362 .51921 m .43305 .51738 L p
.44477 .48925 L 1 g
F P
s
P
p
.002 w
.4454 .48775 m .44504 .489 L p
.44477 .48925 L 1 g
F P
s
P
p
.002 w
.44504 .489 m .4362 .51921 L p
.44477 .48925 L 1 g
F P
s
P
p
.43305 .51738 m .43386 .50943 L .44442 .4896 L 1 g
F
P
p
.43305 .51738 m .44442 .4896 L .44477 .48925 L 1 g
F
P
p
.002 w
.44379 .48873 m .4454 .48775 L .44278 .49118 L p
1 g
F P
s
P
p
.002 w
.44278 .49118 m .44233 .49176 L p
.44247 .49148 L 1 g
F P
s
P
p
.44247 .49148 m .44379 .48873 L .44278 .49118 L 1 g
F
P
p
.002 w
.43465 .50181 m .44233 .49176 L p
.43386 .50943 L 1 g
F P
s
P
p
.002 w
.44247 .49148 m .44166 .49233 L p
.43837 .50004 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44247 .49148 L p
1 g
F P
s
P
p
.002 w
.44247 .49148 m .44247 .49148 L p
.44256 .49139 L 1 g
F P
s
P
p
.44256 .49139 m .45698 .47747 L .44247 .49148 L 1 g
F
P
p
.45588 .47853 m .45619 .47823 L .44278 .49118 L 1 g
F
P
p
.44477 .48925 m .44442 .4896 L .4454 .48775 L 1 g
F
P
p
.45619 .47823 m .45698 .47747 L .44247 .49148 L 1 g
F
P
p
.002 w
.42589 .51326 m .41778 .50448 L .44379 .48873 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43386 .50943 L p
1 g
F P
s
P
p
.43837 .50004 m .44166 .49233 L .43386 .50943 L 1 g
F
P
p
.4331 .5169 m .43308 .51656 L .43305 .51738 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43252 .52871 L p
1 g
F P
s
P
p
.43308 .51656 m .43287 .51061 L .43252 .52871 L 1 g
F
P
p
.002 w
.43252 .52871 m .43248 .52877 L p
.43267 .52924 L 1 g
F P
s
P
p
.002 w
.42589 .51326 m .42848 .51475 L p
.42916 .54725 L 1 g
F P
s
P
p
.43978 .5496 m .4383 .54745 L .4362 .51921 L 1 g
F
P
p
.002 w
.43158 .53761 m .43321 .53111 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.43321 .53111 m .4362 .51921 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.43248 .52877 m .43146 .53025 L p
.43533 .53791 L 1 g
F P
s
P
p
.002 w
.42989 .54741 m .43978 .5496 L p
.45082 .56301 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.43533 .53791 m .43146 .53025 L .4383 .54745 L 1 g
F
P
p
.002 w
.4383 .54745 m .43819 .54767 L p
.43909 .5486 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45139 .55217 m .43978 .5496 L p
.4362 .51921 L 1 g
F P
s
P
p
.002 w
.45139 .55217 m .454 .56537 L p
.45082 .56301 L 1 g
F P
s
P
p
.002 w
.43978 .5496 m .45139 .55217 L p
.45082 .56301 L 1 g
F P
s
P
p
.002 w
.43819 .54767 m .43743 .5491 L p
.44424 .55501 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45082 .56301 L p
1 g
F P
s
P
p
.44424 .55501 m .43743 .5491 L .45082 .56301 L 1 g
F
P
p
.002 w
.45082 .56301 m .45072 .56327 L p
.45224 .56407 L 1 g
F P
s
P
p
.002 w
.42916 .54725 m .42989 .54741 L p
.45653 .5782 L 1 g
F P
s
P
p
.4738 .57647 m .46831 .57454 L .45139 .55217 L 1 g
F
P
p
.002 w
.45488 .56985 m .454 .56537 L p
.46831 .57454 L 1 g
F P
s
P
p
.002 w
.454 .56537 m .45139 .55217 L p
.46831 .57454 L 1 g
F P
s
P
p
.002 w
.45072 .56327 m .45002 .56518 L p
.45978 .56908 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46831 .57454 L p
1 g
F P
s
P
p
.45978 .56908 m .45002 .56518 L .46831 .57454 L 1 g
F
P
p
.002 w
.46831 .57454 m .4678 .57686 L p
.47712 .57763 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48858 .57498 m .4738 .57647 L p
.45139 .55217 L 1 g
F P
s
P
p
.002 w
.4738 .57647 m .48858 .57498 L .49298 .5809 L p
1 g
F P
s
P
p
.48906 .5806 m .4738 .57647 L .49298 .5809 L 1 g
F
P
p
.002 w
.51089 .58001 m .51111 .583 L p
.52322 .57678 L 1 g
F P
s
P
p
.5223 .57703 m .52118 .57732 L .48858 .57498 L 1 g
F
P
p
.002 w
.51106 .58231 m .51089 .58001 L p
.49758 .58126 L 1 g
F P
s
P
p
.5015 .58048 m .49758 .58126 L .51089 .58001 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58231 L p
1 g
F P
s
P
p
.49758 .58126 m .48889 .583 L .51106 .58231 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .5806 L p
1 g
F P
s
P
p
.47851 .57774 m .4678 .57686 L .48906 .5806 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.5506 .3089 m .49484 .28877 L .50474 .26719 L p
1 g
F P
s
P
p
.002 w
.50474 .26719 m .56483 .28872 L .5506 .3089 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.39331 .51856 m .40911 .53564 L .39554 .5542 L p
1 g
F P
s
P
p
.002 w
.39554 .5542 m .37275 .52959 L .39331 .51856 L p
1 g
F P
s
P
p
.002 w
.42443 .57099 m .39554 .5542 L .40911 .53564 L p
1 g
F P
s
P
p
.002 w
.59511 .5562 m .61537 .51188 L .64103 .50941 L p
1 g
F P
s
P
p
.002 w
.64568 .45303 m .64103 .50941 L .61537 .51188 L p
1 g
F P
s
P
p
.004 w
.46942 .46257 m
.5 .43051 L
s
P
p
.002 w
.38339 .49777 m .39331 .51856 L .37275 .52959 L p
1 g
F P
s
P
p
.002 w
.37275 .52959 m .35837 .49963 L .38339 .49777 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.37635 .40891 m .36008 .43597 L .34021 .41842 L p
1 g
F P
s
P
p
.002 w
.34021 .41842 m .36074 .38376 L .37635 .40891 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45653 .5782 m .42443 .57099 L .42916 .54725 L p
1 g
F P
s
P
p
.002 w
.40911 .53564 m .42916 .54725 L .42443 .57099 L p
1 g
F P
s
P
p
.002 w
.64568 .45303 m .63084 .39636 L .65118 .38292 L p
1 g
F P
s
P
p
.002 w
.61574 .32892 m .65118 .38292 L .63084 .39636 L p
1 g
F P
s
P
p
.002 w
.54017 .57811 m .5686 .54944 L .59511 .5562 L p
1 g
F P
s
P
p
.002 w
.61537 .51188 m .59511 .5562 L .5686 .54944 L p
1 g
F P
s
P
p
.002 w
.38042 .47541 m .38339 .49777 L .35837 .49963 L p
1 g
F P
s
P
p
.002 w
.35837 .49963 m .35394 .46732 L .38042 .47541 L p
1 g
F P
s
P
p
.002 w
.59786 .34626 m .5506 .3089 L .56483 .28872 L p
1 g
F P
s
P
p
.002 w
.56483 .28872 m .61574 .32892 L .59786 .34626 L p
1 g
F P
s
P
p
.002 w
.48481 .31536 m .43368 .31443 L .43741 .28798 L p
1 g
F P
s
P
p
.002 w
.43741 .28798 m .49484 .28877 L .48481 .31536 L p
1 g
F P
s
P
p
.002 w
.63084 .39636 m .59786 .34626 L .61574 .32892 L p
1 g
F P
s
P
p
.002 w
.43189 .34515 m .39237 .3583 L .38694 .33031 L p
1 g
F P
s
P
p
.002 w
.38694 .33031 m .43368 .31443 L .43189 .34515 L p
1 g
F P
s
P
p
.002 w
.38478 .45381 m .38042 .47541 L .35394 .46732 L p
1 g
F P
s
P
p
.002 w
.35394 .46732 m .36008 .43597 L .38478 .45381 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61537 .51188 m .61926 .46166 L .64568 .45303 L p
1 g
F P
s
P
p
.002 w
.63084 .39636 m .64568 .45303 L .61926 .46166 L p
1 g
F P
s
P
p
.002 w
.40124 .38918 m .37635 .40891 L .36074 .38376 L p
1 g
F P
s
P
p
.002 w
.36074 .38376 m .39237 .3583 L .40124 .38918 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.45139 .55217 m .47351 .54983 L .48858 .57498 L p
1 g
F P
s
P
p
.002 w
.51722 .56146 m .48858 .57498 L .47351 .54983 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.53439 .33342 m .48481 .31536 L .49484 .28877 L p
1 g
F P
s
P
p
.002 w
.49484 .28877 m .5506 .3089 L .53439 .33342 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.5686 .54944 m .58545 .51191 L .61537 .51188 L p
1 g
F P
s
P
p
.002 w
.61926 .46166 m .61537 .51188 L .58545 .51191 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.39612 .43528 m .38478 .45381 L .36008 .43597 L p
1 g
F P
s
P
p
.002 w
.36008 .43597 m .37635 .40891 L .39612 .43528 L p
1 g
F P
s
P
p
.002 w
.41778 .50448 m .42589 .51326 L .40911 .53564 L p
1 g
F P
s
P
p
.002 w
.40911 .53564 m .39331 .51856 L .41778 .50448 L p
1 g
F P
s
P
p
.002 w
.42916 .54725 m .40911 .53564 L .42589 .51326 L p
1 g
F P
s
P
p
.002 w
.41271 .49379 m .41778 .50448 L .39331 .51856 L p
1 g
F P
s
P
p
.002 w
.39331 .51856 m .38339 .49777 L .41271 .49379 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.61926 .46166 m .60586 .41126 L .63084 .39636 L p
1 g
F P
s
P
p
.002 w
.59786 .34626 m .63084 .39636 L .60586 .41126 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.41124 .48232 m .41271 .49379 L .38339 .49777 L p
1 g
F P
s
P
p
.002 w
.38339 .49777 m .38042 .47541 L .41124 .48232 L p
1 g
F P
s
P
p
.002 w
.475 .34616 m .43189 .34515 L .43368 .31443 L p
1 g
F P
s
P
p
.002 w
.43368 .31443 m .48481 .31536 L .475 .34616 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.47351 .54983 m .49318 .54037 L .51722 .56146 L p
1 g
F P
s
P
p
.002 w
.5393 .53885 m .51722 .56146 L .49318 .54037 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57644 .36671 m .53439 .33342 L .5506 .3089 L p
1 g
F P
s
P
p
.002 w
.5506 .3089 m .59786 .34626 L .57644 .36671 L p
1 g
F P
s
P
p
.002 w
.4362 .51921 m .44762 .52169 L .45139 .55217 L p
1 g
F P
s
P
p
.002 w
.47351 .54983 m .45139 .55217 L .44762 .52169 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43218 .37913 m .40124 .38918 L .39237 .3583 L p
1 g
F P
s
P
p
.002 w
.39237 .3583 m .43189 .34515 L .43218 .37913 L p
1 g
F P
s
P
p
.002 w
.60586 .41126 m .57644 .36671 L .59786 .34626 L p
1 g
F P
s
P
p
.002 w
.41355 .4713 m .41124 .48232 L .38042 .47541 L p
1 g
F P
s
P
p
.002 w
.38042 .47541 m .38478 .45381 L .41355 .4713 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41333 .42187 m .39612 .43528 L .37635 .40891 L p
1 g
F P
s
P
p
.002 w
.37635 .40891 m .40124 .38918 L .41333 .42187 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58545 .51191 m .58849 .46953 L .61926 .46166 L p
1 g
F P
s
P
p
.002 w
.60586 .41126 m .61926 .46166 L .58849 .46953 L p
1 g
F P
s
P
p
.002 w
.44762 .52169 m .45893 .52042 L .47351 .54983 L p
1 g
F P
s
P
p
.002 w
.49318 .54037 m .47351 .54983 L .45893 .52042 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.41942 .4619 m .41355 .4713 L .38478 .45381 L p
1 g
F P
s
P
p
.002 w
.38478 .45381 m .39612 .43528 L .41942 .4619 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.51674 .36152 m .475 .34616 L .48481 .31536 L p
1 g
F P
s
P
p
.002 w
.48481 .31536 m .53439 .33342 L .51674 .36152 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.49318 .54037 m .50823 .52471 L .5393 .53885 L p
1 g
F P
s
P
p
.002 w
.55225 .50943 m .5393 .53885 L .50823 .52471 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.41778 .50448 m .41271 .49379 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45893 .52042 m .46893 .51551 L .49318 .54037 L p
1 g
F P
s
P
p
.002 w
.50823 .52471 m .49318 .54037 L .46893 .51551 L p
1 g
F P
s
P
p
.002 w
.46581 .38012 m .43218 .37913 L .43189 .34515 L p
1 g
F P
s
P
p
.002 w
.43189 .34515 m .475 .34616 L .46581 .38012 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.41271 .49379 m .41124 .48232 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.58849 .46953 m .57702 .42709 L .60586 .41126 L p
1 g
F P
s
P
p
.002 w
.57644 .36671 m .60586 .41126 L .57702 .42709 L p
1 g
F P
s
P
p
.002 w
.43459 .41516 m .41333 .42187 L .40124 .38918 L p
1 g
F P
s
P
p
.002 w
.40124 .38918 m .43218 .37913 L .43459 .41516 L p
1 g
F P
s
P
p
.002 w
.42823 .45516 m .41942 .4619 L .39612 .43528 L p
1 g
F P
s
P
p
.002 w
.39612 .43528 m .41333 .42187 L .42823 .45516 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55215 .38959 m .51674 .36152 L .53439 .33342 L p
1 g
F P
s
P
p
.002 w
.53439 .33342 m .57644 .36671 L .55215 .38959 L p
1 g
F P
s
P
p
.002 w
.41124 .48232 m .41355 .4713 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57702 .42709 m .55215 .38959 L .57644 .36671 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57702 .42709 m .58849 .46953 L .5544 .47633 L p
1 g
F P
s
P
p
.002 w
.41355 .4713 m .41942 .4619 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50823 .52471 m .51694 .50445 L .55225 .50943 L p
1 g
F P
s
P
p
.002 w
.46893 .51551 m .47652 .50747 L .50823 .52471 L p
1 g
F P
s
P
p
.002 w
.51694 .50445 m .50823 .52471 L .47652 .50747 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.4983 .39221 m .46581 .38012 L .475 .34616 L p
1 g
F P
s
P
p
.002 w
.475 .34616 m .51674 .36152 L .4983 .39221 L p
1 g
F P
s
P
p
.002 w
.43905 .45184 m .42823 .45516 L .41333 .42187 L p
1 g
F P
s
P
p
.002 w
.41333 .42187 m .43459 .41516 L .43905 .45184 L p
1 g
F P
s
P
p
.002 w
.41942 .4619 m .42823 .45516 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.4576 .41597 m .43459 .41516 L .43218 .37913 L p
1 g
F P
s
P
p
.002 w
.43218 .37913 m .46581 .38012 L .4576 .41597 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47652 .50747 m .48086 .49713 L .51694 .50445 L p
1 g
F P
s
P
p
.002 w
.45071 .45232 m .46192 .45659 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.43905 .45184 m .45071 .45232 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.42823 .45516 m .43905 .45184 L .4454 .48775 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.5544 .47633 m .54531 .44328 L .57702 .42709 L p
1 g
F P
s
P
p
.002 w
.55215 .38959 m .57702 .42709 L .54531 .44328 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51826 .48178 m .51694 .50445 L .48086 .49713 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.52588 .4141 m .4983 .39221 L .51674 .36152 L p
1 g
F P
s
P
p
.002 w
.51674 .36152 m .55215 .38959 L .52588 .4141 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48086 .49713 m .48144 .48563 L .51826 .48178 L p
1 g
F P
s
P
p
.002 w
.45071 .45232 m .43905 .45184 L .43459 .41516 L p
1 g
F P
s
P
p
.002 w
.43459 .41516 m .4576 .41597 L .45071 .45232 L p
1 g
F P
s
P
p
.002 w
.54531 .44328 m .52588 .4141 L .55215 .38959 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.004 w
.44365 .48959 m
.4454 .48775 L
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.47978 .42432 m .4576 .41597 L .46581 .38012 L p
1 g
F P
s
P
p
.002 w
.46581 .38012 m .4983 .39221 L .47978 .42432 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.46192 .45659 m .45071 .45232 L .4576 .41597 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52588 .4141 m .54531 .44328 L .51193 .4592 L p
1 g
F P
s
P
p
.002 w
.47143 .46416 m .46192 .45659 L .47978 .42432 L p
1 g
F P
s
P
p
.002 w
.4576 .41597 m .47978 .42432 L .46192 .45659 L p
1 g
F P
s
P
p
.002 w
.47978 .42432 m .49861 .43929 L .47143 .46416 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.49861 .43929 m .47978 .42432 L .4983 .39221 L p
1 g
F P
s
P
p
.002 w
.4983 .39221 m .52588 .4141 L .49861 .43929 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51193 .4592 m .49861 .43929 L .52588 .4141 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.41193 .52285 m
.44365 .48959 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28991 .64281 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .41193 .52285 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0434109)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0434109)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47899 .4416 m .494 .45243 L .50679 .42691 L p
1 g
F P
s
P
p
.002 w
.50679 .42691 m .49919 .42142 L .47899 .4416 L p
1 g
F P
s
P
p
.002 w
.51573 .42968 m .50679 .42691 L .494 .45243 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .49919 .42142 L .50679 .42691 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .50679 .42691 L .51573 .42968 L closepath p
1 g
F P
s
P
p
.002 w
.46823 .42658 m .47899 .4416 L .49919 .42142 L p
1 g
F P
s
P
p
.002 w
.49919 .42142 m .49375 .41381 L .46823 .42658 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .49375 .41381 L .49919 .42142 L closepath p
1 g
F P
s
P
p
.002 w
.494 .45243 m .51164 .45793 L .51573 .42968 L p
1 g
F P
s
P
p
.002 w
.52505 .42944 m .51573 .42968 L .51164 .45793 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .51573 .42968 L .52505 .42944 L closepath p
1 g
F P
s
P
p
.002 w
.46286 .40897 m .46823 .42658 L .49375 .41381 L p
1 g
F P
s
P
p
.002 w
.49375 .41381 m .49106 .40489 L .46286 .40897 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .49106 .40489 L .49375 .41381 L closepath p
1 g
F P
s
P
p
.002 w
.4592 .46161 m .48128 .47755 L .494 .45243 L p
1 g
F P
s
P
p
.002 w
.494 .45243 m .47899 .4416 L .4592 .46161 L p
1 g
F P
s
P
p
.002 w
.51164 .45793 m .494 .45243 L .48128 .47755 L p
1 g
F P
s
P
p
.002 w
.44333 .43953 m .4592 .46161 L .47899 .4416 L p
1 g
F P
s
P
p
.002 w
.47899 .4416 m .46823 .42658 L .44333 .43953 L p
1 g
F P
s
P
p
.002 w
.51164 .45793 m .53007 .45751 L .52505 .42944 L p
1 g
F P
s
P
p
.002 w
.53376 .42621 m .52505 .42944 L .53007 .45751 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .52505 .42944 L .53376 .42621 L closepath p
1 g
F P
s
P
p
.002 w
.46348 .39063 m .46286 .40897 L .49106 .40489 L p
1 g
F P
s
P
p
.002 w
.49106 .40489 m .4914 .39561 L .46348 .39063 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .4914 .39561 L .49106 .40489 L closepath p
1 g
F P
s
P
p
.002 w
.48128 .47755 m .50725 .48568 L .51164 .45793 L p
1 g
F P
s
P
p
.002 w
.53007 .45751 m .51164 .45793 L .50725 .48568 L p
1 g
F P
s
P
p
.002 w
.43536 .41361 m .44333 .43953 L .46823 .42658 L p
1 g
F P
s
P
p
.002 w
.46823 .42658 m .46286 .40897 L .43536 .41361 L p
1 g
F P
s
P
p
.002 w
.53007 .45751 m .54731 .45117 L .53376 .42621 L p
1 g
F P
s
P
p
.002 w
.54091 .42033 m .53376 .42621 L .54731 .45117 L p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .53376 .42621 L .54091 .42033 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .54091 .42033 L .54572 .41242 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .54572 .41242 L .54767 .40334 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .54767 .40334 L .54653 .39406 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .54653 .39406 L .54241 .38562 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .54241 .38562 L .53576 .37892 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .53576 .37892 L .52731 .37471 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .52731 .37471 L .51799 .37344 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .51799 .37344 L .50881 .37526 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .50881 .37526 L .50078 .37994 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .50078 .37994 L .49476 .38699 L closepath p
1 g
F P
s
P
p
.002 w
.51944 .40143 m .49476 .38699 L .4914 .39561 L closepath p
1 g
F P
s
P
p
.002 w
.47007 .37352 m .46348 .39063 L .4914 .39561 L p
1 g
F P
s
P
p
.002 w
.4914 .39561 m .49476 .38699 L .47007 .37352 L p
1 g
F P
s
P
p
.002 w
.50725 .48568 m .53439 .48511 L .53007 .45751 L p
1 g
F P
s
P
p
.002 w
.54731 .45117 m .53007 .45751 L .53439 .48511 L p
1 g
F P
s
P
p
.002 w
.54731 .45117 m .56151 .43958 L .54091 .42033 L p
1 g
F P
s
P
p
.002 w
.54572 .41242 m .54091 .42033 L .56151 .43958 L p
1 g
F P
s
P
p
.002 w
.43618 .38656 m .43536 .41361 L .46286 .40897 L p
1 g
F P
s
P
p
.002 w
.46286 .40897 m .46348 .39063 L .43618 .38656 L p
1 g
F P
s
P
p
.002 w
.48194 .35951 m .47007 .37352 L .49476 .38699 L p
1 g
F P
s
P
p
.002 w
.49476 .38699 m .50078 .37994 L .48194 .35951 L p
1 g
F P
s
P
p
.002 w
.56151 .43958 m .57111 .42394 L .54572 .41242 L p
1 g
F P
s
P
p
.002 w
.54767 .40334 m .54572 .41242 L .57111 .42394 L p
1 g
F P
s
P
p
.002 w
.49785 .35015 m .48194 .35951 L .50078 .37994 L p
1 g
F P
s
P
p
.002 w
.50078 .37994 m .50881 .37526 L .49785 .35015 L p
1 g
F P
s
P
p
.002 w
.44019 .4811 m .46889 .50181 L .48128 .47755 L p
1 g
F P
s
P
p
.002 w
.48128 .47755 m .4592 .46161 L .44019 .4811 L p
1 g
F P
s
P
p
.002 w
.50725 .48568 m .48128 .47755 L .46889 .50181 L p
1 g
F P
s
P
p
.002 w
.41951 .45242 m .44019 .4811 L .4592 .46161 L p
1 g
F P
s
P
p
.002 w
.4592 .46161 m .44333 .43953 L .41951 .45242 L p
1 g
F P
s
P
p
.002 w
.53439 .48511 m .55983 .47586 L .54731 .45117 L p
1 g
F P
s
P
p
.002 w
.56151 .43958 m .54731 .45117 L .55983 .47586 L p
1 g
F P
s
P
p
.002 w
.44581 .36128 m .43618 .38656 L .46348 .39063 L p
1 g
F P
s
P
p
.002 w
.46348 .39063 m .47007 .37352 L .44581 .36128 L p
1 g
F P
s
P
p
.002 w
.57111 .42394 m .57503 .40593 L .54767 .40334 L p
1 g
F P
s
P
p
.002 w
.54653 .39406 m .54767 .40334 L .57503 .40593 L p
1 g
F P
s
P
p
.002 w
.46889 .50181 m .50263 .51241 L .50725 .48568 L p
1 g
F P
s
P
p
.002 w
.53439 .48511 m .50725 .48568 L .50263 .51241 L p
1 g
F P
s
P
p
.002 w
.51608 .3465 m .49785 .35015 L .50881 .37526 L p
1 g
F P
s
P
p
.002 w
.50881 .37526 m .51799 .37344 L .51608 .3465 L p
1 g
F P
s
P
p
.002 w
.40906 .41872 m .41951 .45242 L .44333 .43953 L p
1 g
F P
s
P
p
.002 w
.44333 .43953 m .43536 .41361 L .40906 .41872 L p
1 g
F P
s
P
p
.002 w
.57503 .40593 m .57281 .3875 L .54653 .39406 L p
1 g
F P
s
P
p
.002 w
.54241 .38562 m .54653 .39406 L .57281 .3875 L p
1 g
F P
s
P
p
.002 w
.53463 .34898 m .51608 .3465 L .51799 .37344 L p
1 g
F P
s
P
p
.002 w
.51799 .37344 m .52731 .37471 L .53463 .34898 L p
1 g
F P
s
P
p
.002 w
.57281 .3875 m .56465 .37069 L .54241 .38562 L p
1 g
F P
s
P
p
.002 w
.53576 .37892 m .54241 .38562 L .56465 .37069 L p
1 g
F P
s
P
p
.002 w
.55144 .35735 m .53463 .34898 L .52731 .37471 L p
1 g
F P
s
P
p
.002 w
.52731 .37471 m .53576 .37892 L .55144 .35735 L p
1 g
F P
s
P
p
.002 w
.55983 .47586 m .58083 .45883 L .56151 .43958 L p
1 g
F P
s
P
p
.002 w
.57111 .42394 m .56151 .43958 L .58083 .45883 L p
1 g
F P
s
P
p
.002 w
.56465 .37069 m .55144 .35735 L .53576 .37892 L p
1 g
F P
s
P
p
.002 w
.46328 .34053 m .44581 .36128 L .47007 .37352 L p
1 g
F P
s
P
p
.002 w
.47007 .37352 m .48194 .35951 L .46328 .34053 L p
1 g
F P
s
P
p
.002 w
.50263 .51241 m .53792 .51175 L .53439 .48511 L p
1 g
F P
s
P
p
.002 w
.55983 .47586 m .53439 .48511 L .53792 .51175 L p
1 g
F P
s
P
p
.002 w
.41003 .38352 m .40906 .41872 L .43536 .41361 L p
1 g
F P
s
P
p
.002 w
.43536 .41361 m .43618 .38656 L .41003 .38352 L p
1 g
F P
s
P
p
.002 w
.58083 .45883 m .5951 .43578 L .57111 .42394 L p
1 g
F P
s
P
p
.002 w
.57503 .40593 m .57111 .42394 L .5951 .43578 L p
1 g
F P
s
P
p
.002 w
.48677 .32661 m .46328 .34053 L .48194 .35951 L p
1 g
F P
s
P
p
.002 w
.48194 .35951 m .49785 .35015 L .48677 .32661 L p
1 g
F P
s
P
p
.002 w
.53792 .51175 m .57106 .4998 L .55983 .47586 L p
1 g
F P
s
P
p
.002 w
.58083 .45883 m .55983 .47586 L .57106 .4998 L p
1 g
F P
s
P
p
.002 w
.42245 .35054 m .41003 .38352 L .43618 .38656 L p
1 g
F P
s
P
p
.002 w
.43618 .38656 m .44581 .36128 L .42245 .35054 L p
1 g
F P
s
P
p
.002 w
.42231 .49967 m .45704 .52473 L .46889 .50181 L p
1 g
F P
s
P
p
.002 w
.46889 .50181 m .44019 .4811 L .42231 .49967 L p
1 g
F P
s
P
p
.002 w
.50263 .51241 m .46889 .50181 L .45704 .52473 L p
1 g
F P
s
P
p
.002 w
.39725 .46499 m .42231 .49967 L .44019 .4811 L p
1 g
F P
s
P
p
.002 w
.44019 .4811 m .41951 .45242 L .39725 .46499 L p
1 g
F P
s
P
p
.002 w
.5951 .43578 m .60099 .40917 L .57503 .40593 L p
1 g
F P
s
P
p
.002 w
.57281 .3875 m .57503 .40593 L .60099 .40917 L p
1 g
F P
s
P
p
.002 w
.51374 .32113 m .48677 .32661 L .49785 .35015 L p
1 g
F P
s
P
p
.002 w
.49785 .35015 m .51608 .3465 L .51374 .32113 L p
1 g
F P
s
P
p
.002 w
.45704 .52473 m .49786 .5376 L .50263 .51241 L p
1 g
F P
s
P
p
.002 w
.53792 .51175 m .50263 .51241 L .49786 .5376 L p
1 g
F P
s
P
p
.002 w
.38451 .42423 m .39725 .46499 L .41951 .45242 L p
1 g
F P
s
P
p
.002 w
.41951 .45242 m .40906 .41872 L .38451 .42423 L p
1 g
F P
s
P
p
.002 w
.60099 .40917 m .59777 .38188 L .57281 .3875 L p
1 g
F P
s
P
p
.002 w
.56465 .37069 m .57281 .3875 L .59777 .38188 L p
1 g
F P
s
P
p
.002 w
.54123 .32477 m .51374 .32113 L .51608 .3465 L p
1 g
F P
s
P
p
.002 w
.51608 .3465 m .53463 .34898 L .54123 .32477 L p
1 g
F P
s
P
p
.002 w
.57106 .4998 m .5985 .47771 L .58083 .45883 L p
1 g
F P
s
P
p
.002 w
.5951 .43578 m .58083 .45883 L .5985 .47771 L p
1 g
F P
s
P
p
.002 w
.44515 .32339 m .42245 .35054 L .44581 .36128 L p
1 g
F P
s
P
p
.002 w
.44581 .36128 m .46328 .34053 L .44515 .32339 L p
1 g
F P
s
P
p
.002 w
.59777 .38188 m .58573 .35695 L .56465 .37069 L p
1 g
F P
s
P
p
.002 w
.55144 .35735 m .56465 .37069 L .58573 .35695 L p
1 g
F P
s
P
p
.002 w
.56616 .33717 m .54123 .32477 L .53463 .34898 L p
1 g
F P
s
P
p
.002 w
.53463 .34898 m .55144 .35735 L .56616 .33717 L p
1 g
F P
s
P
p
.002 w
.58573 .35695 m .56616 .33717 L .55144 .35735 L p
1 g
F P
s
P
p
.002 w
.49786 .5376 m .54059 .53688 L .53792 .51175 L p
1 g
F P
s
P
p
.002 w
.57106 .4998 m .53792 .51175 L .54059 .53688 L p
1 g
F P
s
P
p
.002 w
.38556 .38158 m .38451 .42423 L .40906 .41872 L p
1 g
F P
s
P
p
.002 w
.40906 .41872 m .41003 .38352 L .38556 .38158 L p
1 g
F P
s
P
p
.002 w
.5985 .47771 m .6172 .44773 L .5951 .43578 L p
1 g
F P
s
P
p
.002 w
.60099 .40917 m .5951 .43578 L .6172 .44773 L p
1 g
F P
s
P
p
.002 w
.47576 .30513 m .44515 .32339 L .46328 .34053 L p
1 g
F P
s
P
p
.002 w
.46328 .34053 m .48677 .32661 L .47576 .30513 L p
1 g
F P
s
P
p
.002 w
.54059 .53688 m .58076 .52252 L .57106 .4998 L p
1 g
F P
s
P
p
.002 w
.5985 .47771 m .57106 .4998 L .58076 .52252 L p
1 g
F P
s
P
p
.002 w
.40049 .34155 m .38556 .38158 L .41003 .38352 L p
1 g
F P
s
P
p
.002 w
.41003 .38352 m .42245 .35054 L .40049 .34155 L p
1 g
F P
s
P
p
.002 w
.6172 .44773 m .625 .41301 L .60099 .40917 L p
1 g
F P
s
P
p
.002 w
.59777 .38188 m .60099 .40917 L .625 .41301 L p
1 g
F P
s
P
p
.002 w
.40596 .51695 m .446 .54583 L .45704 .52473 L p
1 g
F P
s
P
p
.002 w
.45704 .52473 m .42231 .49967 L .40596 .51695 L p
1 g
F P
s
P
p
.002 w
.49786 .5376 m .45704 .52473 L .446 .54583 L p
1 g
F P
s
P
p
.002 w
.37702 .47701 m .40596 .51695 L .42231 .49967 L p
1 g
F P
s
P
p
.002 w
.42231 .49967 m .39725 .46499 L .37702 .47701 L p
1 g
F P
s
P
p
.002 w
.511 .29789 m .47576 .30513 L .48677 .32661 L p
1 g
F P
s
P
p
.002 w
.48677 .32661 m .51374 .32113 L .511 .29789 L p
1 g
F P
s
P
p
.002 w
.446 .54583 m .49304 .5607 L .49786 .5376 L p
1 g
F P
s
P
p
.002 w
.54059 .53688 m .49786 .5376 L .49304 .5607 L p
1 g
F P
s
P
p
.002 w
.36224 .43003 m .37702 .47701 L .39725 .46499 L p
1 g
F P
s
P
p
.002 w
.39725 .46499 m .38451 .42423 L .36224 .43003 L p
1 g
F P
s
P
p
.002 w
.625 .41301 m .62088 .37734 L .59777 .38188 L p
1 g
F P
s
P
p
.002 w
.58573 .35695 m .59777 .38188 L .62088 .37734 L p
1 g
F P
s
P
p
.002 w
.58076 .52252 m .61411 .49585 L .5985 .47771 L p
1 g
F P
s
P
p
.002 w
.6172 .44773 m .5985 .47771 L .61411 .49585 L p
1 g
F P
s
P
p
.002 w
.54696 .30261 m .511 .29789 L .51374 .32113 L p
1 g
F P
s
P
p
.002 w
.51374 .32113 m .54123 .32477 L .54696 .30261 L p
1 g
F P
s
P
p
.002 w
.42793 .30852 m .40049 .34155 L .42245 .35054 L p
1 g
F P
s
P
p
.002 w
.42245 .35054 m .44515 .32339 L .42793 .30852 L p
1 g
F P
s
P
p
.002 w
.62088 .37734 m .60518 .34471 L .58573 .35695 L p
1 g
F P
s
P
p
.002 w
.56616 .33717 m .58573 .35695 L .60518 .34471 L p
1 g
F P
s
P
p
.002 w
.57959 .31882 m .54696 .30261 L .54123 .32477 L p
1 g
F P
s
P
p
.002 w
.54123 .32477 m .56616 .33717 L .57959 .31882 L p
1 g
F P
s
P
p
.002 w
.49304 .5607 m .5423 .55997 L .54059 .53688 L p
1 g
F P
s
P
p
.002 w
.58076 .52252 m .54059 .53688 L .5423 .55997 L p
1 g
F P
s
P
p
.002 w
.60518 .34471 m .57959 .31882 L .56616 .33717 L p
1 g
F P
s
P
p
.002 w
.36332 .38082 m .36224 .43003 L .38451 .42423 L p
1 g
F P
s
P
p
.002 w
.38451 .42423 m .38556 .38158 L .36332 .38082 L p
1 g
F P
s
P
p
.002 w
.61411 .49585 m .63691 .45954 L .6172 .44773 L p
1 g
F P
s
P
p
.002 w
.625 .41301 m .6172 .44773 L .63691 .45954 L p
1 g
F P
s
P
p
.002 w
.46506 .28623 m .42793 .30852 L .44515 .32339 L p
1 g
F P
s
P
p
.002 w
.44515 .32339 m .47576 .30513 L .46506 .28623 L p
1 g
F P
s
P
p
.002 w
.5423 .55997 m .58869 .54352 L .58076 .52252 L p
1 g
F P
s
P
p
.002 w
.61411 .49585 m .58076 .52252 L .58869 .54352 L p
1 g
F P
s
P
p
.002 w
.38043 .33456 m .36332 .38082 L .38556 .38158 L p
1 g
F P
s
P
p
.002 w
.38556 .38158 m .40049 .34155 L .38043 .33456 L p
1 g
F P
s
P
p
.002 w
.63691 .45954 m .6465 .4174 L .625 .41301 L p
1 g
F P
s
P
p
.002 w
.62088 .37734 m .625 .41301 L .6465 .4174 L p
1 g
F P
s
P
p
.002 w
.39152 .53253 m .436 .56461 L .446 .54583 L p
1 g
F P
s
P
p
.002 w
.446 .54583 m .40596 .51695 L .39152 .53253 L p
1 g
F P
s
P
p
.002 w
.49304 .5607 m .446 .54583 L .436 .56461 L p
1 g
F P
s
P
p
.002 w
.5079 .27734 m .46506 .28623 L .47576 .30513 L p
1 g
F P
s
P
p
.002 w
.47576 .30513 m .511 .29789 L .5079 .27734 L p
1 g
F P
s
P
p
.002 w
.35933 .48819 m .39152 .53253 L .40596 .51695 L p
1 g
F P
s
P
p
.002 w
.40596 .51695 m .37702 .47701 L .35933 .48819 L p
1 g
F P
s
P
p
.002 w
.436 .56461 m .48825 .58117 L .49304 .5607 L p
1 g
F P
s
P
p
.002 w
.5423 .55997 m .49304 .5607 L .48825 .58117 L p
1 g
F P
s
P
p
.002 w
.34281 .43602 m .35933 .48819 L .37702 .47701 L p
1 g
F P
s
P
p
.002 w
.37702 .47701 m .36224 .43003 L .34281 .43602 L p
1 g
F P
s
P
p
.002 w
.58869 .54352 m .62726 .51285 L .61411 .49585 L p
1 g
F P
s
P
p
.002 w
.63691 .45954 m .61411 .49585 L .62726 .51285 L p
1 g
F P
s
P
p
.002 w
.6465 .4174 m .64159 .37403 L .62088 .37734 L p
1 g
F P
s
P
p
.002 w
.60518 .34471 m .62088 .37734 L .64159 .37403 L p
1 g
F P
s
P
p
.002 w
.55167 .28303 m .5079 .27734 L .511 .29789 L p
1 g
F P
s
P
p
.002 w
.511 .29789 m .54696 .30261 L .55167 .28303 L p
1 g
F P
s
P
p
.002 w
.41203 .29631 m .38043 .33456 L .40049 .34155 L p
1 g
F P
s
P
p
.002 w
.40049 .34155 m .42793 .30852 L .41203 .29631 L p
1 g
F P
s
P
p
.002 w
.64159 .37403 m .62254 .33429 L .60518 .34471 L p
1 g
F P
s
P
p
.002 w
.57959 .31882 m .60518 .34471 L .62254 .33429 L p
1 g
F P
s
P
p
.002 w
.48825 .58117 m .54298 .58045 L .5423 .55997 L p
1 g
F P
s
P
p
.002 w
.58869 .54352 m .5423 .55997 L .54298 .58045 L p
1 g
F P
s
P
p
.002 w
.5914 .30275 m .55167 .28303 L .54696 .30261 L p
1 g
F P
s
P
p
.002 w
.54696 .30261 m .57959 .31882 L .5914 .30275 L p
1 g
F P
s
P
p
.002 w
.62254 .33429 m .5914 .30275 L .57959 .31882 L p
1 g
F P
s
P
p
.002 w
.34389 .38132 m .34281 .43602 L .36224 .43003 L p
1 g
F P
s
P
p
.002 w
.36224 .43003 m .36332 .38082 L .34389 .38132 L p
1 g
F P
s
P
p
.002 w
.62726 .51285 m .65372 .47097 L .63691 .45954 L p
1 g
F P
s
P
p
.002 w
.6465 .4174 m .63691 .45954 L .65372 .47097 L p
1 g
F P
s
P
p
.002 w
.45492 .27043 m .41203 .29631 L .42793 .30852 L p
1 g
F P
s
P
p
.002 w
.42793 .30852 m .46506 .28623 L .45492 .27043 L p
1 g
F P
s
P
p
.002 w
.54298 .58045 m .59458 .56228 L .58869 .54352 L p
1 g
F P
s
P
p
.002 w
.62726 .51285 m .58869 .54352 L .59458 .56228 L p
1 g
F P
s
P
p
.002 w
.36279 .32983 m .34389 .38132 L .36332 .38082 L p
1 g
F P
s
P
p
.002 w
.36332 .38082 m .38043 .33456 L .36279 .32983 L p
1 g
F P
s
P
p
.002 w
.65372 .47097 m .66493 .42227 L .6465 .4174 L p
1 g
F P
s
P
p
.002 w
.64159 .37403 m .6465 .4174 L .66493 .42227 L p
1 g
F P
s
P
p
.002 w
.50449 .26006 m .45492 .27043 L .46506 .28623 L p
1 g
F P
s
P
p
.002 w
.46506 .28623 m .5079 .27734 L .50449 .26006 L p
1 g
F P
s
P
p
.002 w
.37941 .546 m .42732 .58055 L .436 .56461 L p
1 g
F P
s
P
p
.002 w
.436 .56461 m .39152 .53253 L .37941 .546 L p
1 g
F P
s
P
p
.002 w
.48825 .58117 m .436 .56461 L .42732 .58055 L p
1 g
F P
s
P
p
.002 w
.34468 .49827 m .37941 .546 L .39152 .53253 L p
1 g
F P
s
P
p
.002 w
.39152 .53253 m .35933 .48819 L .34468 .49827 L p
1 g
F P
s
P
p
.002 w
.42732 .58055 m .4836 .59844 L .48825 .58117 L p
1 g
F P
s
P
p
.002 w
.54298 .58045 m .48825 .58117 L .4836 .59844 L p
1 g
F P
s
P
p
.002 w
.59458 .56228 m .63756 .52827 L .62726 .51285 L p
1 g
F P
s
P
p
.002 w
.65372 .47097 m .62726 .51285 L .63756 .52827 L p
1 g
F P
s
P
p
.002 w
.3268 .44208 m .34468 .49827 L .35933 .48819 L p
1 g
F P
s
P
p
.002 w
.35933 .48819 m .34281 .43602 L .3268 .44208 L p
1 g
F P
s
P
p
.002 w
.66493 .42227 m .65934 .37206 L .64159 .37403 L p
1 g
F P
s
P
p
.002 w
.62254 .33429 m .64159 .37403 L .65934 .37206 L p
1 g
F P
s
P
p
.002 w
.39786 .28717 m .36279 .32983 L .38043 .33456 L p
1 g
F P
s
P
p
.002 w
.38043 .33456 m .41203 .29631 L .39786 .28717 L p
1 g
F P
s
P
p
.002 w
.55521 .26659 m .50449 .26006 L .5079 .27734 L p
1 g
F P
s
P
p
.002 w
.5079 .27734 m .55167 .28303 L .55521 .26659 L p
1 g
F P
s
P
p
.002 w
.65934 .37206 m .63733 .32601 L .62254 .33429 L p
1 g
F P
s
P
p
.002 w
.5914 .30275 m .62254 .33429 L .63733 .32601 L p
1 g
F P
s
P
p
.002 w
.4836 .59844 m .54257 .59774 L .54298 .58045 L p
1 g
F P
s
P
p
.002 w
.59458 .56228 m .54298 .58045 L .54257 .59774 L p
1 g
F P
s
P
p
.002 w
.60125 .28944 m .55521 .26659 L .55167 .28303 L p
1 g
F P
s
P
p
.002 w
.55167 .28303 m .5914 .30275 L .60125 .28944 L p
1 g
F P
s
P
p
.002 w
.63733 .32601 m .60125 .28944 L .5914 .30275 L p
1 g
F P
s
P
p
.002 w
.32785 .38313 m .3268 .44208 L .34281 .43602 L p
1 g
F P
s
P
p
.002 w
.34281 .43602 m .34389 .38132 L .32785 .38313 L p
1 g
F P
s
P
p
.002 w
.63756 .52827 m .66711 .48175 L .65372 .47097 L p
1 g
F P
s
P
p
.002 w
.66493 .42227 m .65372 .47097 L .66711 .48175 L p
1 g
F P
s
P
p
.002 w
.44558 .25826 m .39786 .28717 L .41203 .29631 L p
1 g
F P
s
P
p
.002 w
.41203 .29631 m .45492 .27043 L .44558 .25826 L p
1 g
F P
s
P
p
.002 w
.54257 .59774 m .59821 .57826 L .59458 .56228 L p
1 g
F P
s
P
p
.002 w
.63756 .52827 m .59458 .56228 L .59821 .57826 L p
1 g
F P
s
P
p
.002 w
.34812 .32757 m .32785 .38313 L .34389 .38132 L p
1 g
F P
s
P
p
.002 w
.34389 .38132 m .36279 .32983 L .34812 .32757 L p
1 g
F P
s
P
p
.002 w
.66711 .48175 m .6797 .42754 L .66493 .42227 L p
1 g
F P
s
P
p
.002 w
.65934 .37206 m .66493 .42227 L .6797 .42754 L p
1 g
F P
s
P
p
.002 w
.50083 .24662 m .44558 .25826 L .45492 .27043 L p
1 g
F P
s
P
p
.002 w
.45492 .27043 m .50449 .26006 L .50083 .24662 L p
1 g
F P
s
P
p
.002 w
.37 .55694 m .42023 .59315 L .42732 .58055 L p
1 g
F P
s
P
p
.002 w
.42732 .58055 m .37941 .546 L .37 .55694 L p
1 g
F P
s
P
p
.002 w
.4836 .59844 m .42732 .58055 L .42023 .59315 L p
1 g
F P
s
P
p
.002 w
.33357 .50693 m .37 .55694 L .37941 .546 L p
1 g
F P
s
P
p
.002 w
.37941 .546 m .34468 .49827 L .33357 .50693 L p
1 g
F P
s
P
p
.002 w
.42023 .59315 m .4792 .61193 L .4836 .59844 L p
1 g
F P
s
P
p
.002 w
.54257 .59774 m .4836 .59844 L .4792 .61193 L p
1 g
F P
s
P
p
.002 w
.59821 .57826 m .64461 .5417 L .63756 .52827 L p
1 g
F P
s
P
p
.002 w
.66711 .48175 m .63756 .52827 L .64461 .5417 L p
1 g
F P
s
P
p
.002 w
.31476 .44807 m .33357 .50693 L .34468 .49827 L p
1 g
F P
s
P
p
.002 w
.34468 .49827 m .3268 .44208 L .31476 .44807 L p
1 g
F P
s
P
p
.002 w
.6797 .42754 m .67355 .37156 L .65934 .37206 L p
1 g
F P
s
P
p
.002 w
.63733 .32601 m .65934 .37206 L .67355 .37156 L p
1 g
F P
s
P
p
.002 w
.38587 .2815 m .34812 .32757 L .36279 .32983 L p
1 g
F P
s
P
p
.002 w
.36279 .32983 m .39786 .28717 L .38587 .2815 L p
1 g
F P
s
P
p
.002 w
.55741 .25387 m .50083 .24662 L .50449 .26006 L p
1 g
F P
s
P
p
.002 w
.50449 .26006 m .55521 .26659 L .55741 .25387 L p
1 g
F P
s
P
p
.002 w
.4792 .61193 m .54101 .61126 L .54257 .59774 L p
1 g
F P
s
P
p
.002 w
.59821 .57826 m .54257 .59774 L .54101 .61126 L p
1 g
F P
s
P
p
.002 w
.67355 .37156 m .64905 .32017 L .63733 .32601 L p
1 g
F P
s
P
p
.002 w
.60125 .28944 m .63733 .32601 L .64905 .32017 L p
1 g
F P
s
P
p
.002 w
.60881 .27935 m .55741 .25387 L .55521 .26659 L p
1 g
F P
s
P
p
.002 w
.55521 .26659 m .60125 .28944 L .60881 .27935 L p
1 g
F P
s
P
p
.002 w
.31578 .38627 m .31476 .44807 L .3268 .44208 L p
1 g
F P
s
P
p
.002 w
.3268 .44208 m .32785 .38313 L .31578 .38627 L p
1 g
F P
s
P
p
.002 w
.64905 .32017 m .60881 .27935 L .60125 .28944 L p
1 g
F P
s
P
p
.002 w
.64461 .5417 m .67658 .49158 L .66711 .48175 L p
1 g
F P
s
P
p
.002 w
.6797 .42754 m .66711 .48175 L .67658 .49158 L p
1 g
F P
s
P
p
.002 w
.43733 .25022 m .38587 .2815 L .39786 .28717 L p
1 g
F P
s
P
p
.002 w
.39786 .28717 m .44558 .25826 L .43733 .25022 L p
1 g
F P
s
P
p
.002 w
.54101 .61126 m .59936 .59093 L .59821 .57826 L p
1 g
F P
s
P
p
.002 w
.64461 .5417 m .59821 .57826 L .59936 .59093 L p
1 g
F P
s
P
p
.002 w
.33695 .32801 m .31578 .38627 L .32785 .38313 L p
1 g
F P
s
P
p
.002 w
.32785 .38313 m .34812 .32757 L .33695 .32801 L p
1 g
F P
s
P
p
.002 w
.67658 .49158 m .69025 .43309 L .6797 .42754 L p
1 g
F P
s
P
p
.002 w
.67355 .37156 m .6797 .42754 L .69025 .43309 L p
1 g
F P
s
P
p
.002 w
.497 .23759 m .43733 .25022 L .44558 .25826 L p
1 g
F P
s
P
p
.002 w
.44558 .25826 m .50083 .24662 L .497 .23759 L p
1 g
F P
s
P
p
.002 w
.36371 .56493 m .41499 .6019 L .42023 .59315 L p
1 g
F P
s
P
p
.002 w
.42023 .59315 m .37 .55694 L .36371 .56493 L p
1 g
F P
s
P
p
.002 w
.4792 .61193 m .42023 .59315 L .41499 .6019 L p
1 g
F P
s
P
p
.002 w
.3265 .51389 m .36371 .56493 L .37 .55694 L p
1 g
F P
s
P
p
.002 w
.37 .55694 m .33357 .50693 L .3265 .51389 L p
1 g
F P
s
P
p
.002 w
.59936 .59093 m .64806 .55267 L .64461 .5417 L p
1 g
F P
s
P
p
.002 w
.67658 .49158 m .64461 .5417 L .64806 .55267 L p
1 g
F P
s
P
p
.002 w
.41499 .6019 m .47519 .62109 L .4792 .61193 L p
1 g
F P
s
P
p
.002 w
.54101 .61126 m .4792 .61193 L .47519 .62109 L p
1 g
F P
s
P
p
.002 w
.30724 .45382 m .3265 .51389 L .33357 .50693 L p
1 g
F P
s
P
p
.002 w
.33357 .50693 m .31476 .44807 L .30724 .45382 L p
1 g
F P
s
P
p
.002 w
.69025 .43309 m .68367 .37263 L .67355 .37156 L p
1 g
F P
s
P
p
.002 w
.64905 .32017 m .67355 .37156 L .68367 .37263 L p
1 g
F P
s
P
p
.002 w
.37647 .27964 m .33695 .32801 L .34812 .32757 L p
1 g
F P
s
P
p
.002 w
.34812 .32757 m .38587 .2815 L .37647 .27964 L p
1 g
F P
s
P
p
.002 w
.55815 .24539 m .497 .23759 L .50083 .24662 L p
1 g
F P
s
P
p
.002 w
.50083 .24662 m .55741 .25387 L .55815 .24539 L p
1 g
F P
s
P
p
.002 w
.47519 .62109 m .53829 .62046 L .54101 .61126 L p
1 g
F P
s
P
p
.002 w
.59936 .59093 m .54101 .61126 L .53829 .62046 L p
1 g
F P
s
P
p
.002 w
.68367 .37263 m .65722 .31708 L .64905 .32017 L p
1 g
F P
s
P
p
.002 w
.60881 .27935 m .64905 .32017 L .65722 .31708 L p
1 g
F P
s
P
p
.002 w
.61372 .27294 m .55815 .24539 L .55741 .25387 L p
1 g
F P
s
P
p
.002 w
.55741 .25387 m .60881 .27935 L .61372 .27294 L p
1 g
F P
s
P
p
.002 w
.30823 .39076 m .30724 .45382 L .31476 .44807 L p
1 g
F P
s
P
p
.002 w
.31476 .44807 m .31578 .38627 L .30823 .39076 L p
1 g
F P
s
P
p
.002 w
.65722 .31708 m .61372 .27294 L .60881 .27935 L p
1 g
F P
s
P
p
.002 w
.64806 .55267 m .68164 .50015 L .67658 .49158 L p
1 g
F P
s
P
p
.002 w
.69025 .43309 m .67658 .49158 L .68164 .50015 L p
1 g
F P
s
P
p
.002 w
.43044 .24677 m .37647 .27964 L .38587 .2815 L p
1 g
F P
s
P
p
.002 w
.38587 .2815 m .43733 .25022 L .43044 .24677 L p
1 g
F P
s
P
p
.002 w
.53829 .62046 m .59785 .59976 L .59936 .59093 L p
1 g
F P
s
P
p
.002 w
.64806 .55267 m .59936 .59093 L .59785 .59976 L p
1 g
F P
s
P
p
.002 w
.32979 .33128 m .30823 .39076 L .31578 .38627 L p
1 g
F P
s
P
p
.002 w
.31578 .38627 m .33695 .32801 L .32979 .33128 L p
1 g
F P
s
P
p
.002 w
.68164 .50015 m .69603 .43881 L .69025 .43309 L p
1 g
F P
s
P
p
.002 w
.68367 .37263 m .69025 .43309 L .69603 .43881 L p
1 g
F P
s
P
p
.002 w
.49308 .23349 m .43044 .24677 L .43733 .25022 L p
1 g
F P
s
P
p
.002 w
.43733 .25022 m .497 .23759 L .49308 .23349 L p
1 g
F P
s
P
p
.002 w
.36089 .56958 m .41186 .60632 L .41499 .6019 L p
1 g
F P
s
P
p
.002 w
.41499 .6019 m .36371 .56493 L .36089 .56958 L p
1 g
F P
s
P
p
.002 w
.47519 .62109 m .41499 .6019 L .41186 .60632 L p
1 g
F P
s
P
p
.002 w
.32389 .51886 m .36089 .56958 L .36371 .56493 L p
1 g
F P
s
P
p
.002 w
.36371 .56493 m .3265 .51389 L .32389 .51886 L p
1 g
F P
s
P
p
.002 w
.59785 .59976 m .64758 .56075 L .64806 .55267 L p
1 g
F P
s
P
p
.002 w
.68164 .50015 m .64806 .55267 L .64758 .56075 L p
1 g
F P
s
P
p
.002 w
.41186 .60632 m .47169 .62541 L .47519 .62109 L p
1 g
F P
s
P
p
.002 w
.53829 .62046 m .47519 .62109 L .47169 .62541 L p
1 g
F P
s
P
p
.002 w
.30474 .45919 m .32389 .51886 L .3265 .51389 L p
1 g
F P
s
P
p
.002 w
.3265 .51389 m .30724 .45382 L .30474 .45919 L p
1 g
F P
s
P
p
.002 w
.69603 .43881 m .68916 .37534 L .68367 .37263 L p
1 g
F P
s
P
p
.002 w
.65722 .31708 m .68367 .37263 L .68916 .37534 L p
1 g
F P
s
P
p
.002 w
.37011 .28189 m .32979 .33128 L .33695 .32801 L p
1 g
F P
s
P
p
.002 w
.33695 .32801 m .37647 .27964 L .37011 .28189 L p
1 g
F P
s
P
p
.002 w
.55732 .24167 m .49308 .23349 L .497 .23759 L p
1 g
F P
s
P
p
.002 w
.497 .23759 m .55815 .24539 L .55732 .24167 L p
1 g
F P
s
P
p
.002 w
.47169 .62541 m .53438 .6248 L .53829 .62046 L p
1 g
F P
s
P
p
.002 w
.59785 .59976 m .53829 .62046 L .53438 .6248 L p
1 g
F P
s
P
p
.002 w
.68916 .37534 m .6614 .31699 L .65722 .31708 L p
1 g
F P
s
P
p
.002 w
.61372 .27294 m .65722 .31708 L .6614 .31699 L p
1 g
F P
s
P
p
.002 w
.61571 .27061 m .55732 .24167 L .55815 .24539 L p
1 g
F P
s
P
p
.002 w
.55815 .24539 m .61372 .27294 L .61571 .27061 L p
1 g
F P
s
P
p
.002 w
.3057 .39655 m .30474 .45919 L .30724 .45382 L p
1 g
F P
s
P
p
.002 w
.30724 .45382 m .30823 .39076 L .3057 .39655 L p
1 g
F P
s
P
p
.002 w
.6614 .31699 m .61571 .27061 L .61372 .27294 L p
1 g
F P
s
P
p
.002 w
.64758 .56075 m .68189 .50717 L .68164 .50015 L p
1 g
F P
s
P
p
.002 w
.69603 .43881 m .68164 .50015 L .68189 .50717 L p
1 g
F P
s
P
p
.002 w
.4252 .24833 m .37011 .28189 L .37647 .27964 L p
1 g
F P
s
P
p
.002 w
.37647 .27964 m .43044 .24677 L .4252 .24833 L p
1 g
F P
s
P
p
.002 w
.53438 .6248 m .59355 .60426 L .59785 .59976 L p
1 g
F P
s
P
p
.002 w
.64758 .56075 m .59785 .59976 L .59355 .60426 L p
1 g
F P
s
P
p
.004 w
.27177 .5275 m
.3029 .51427 L
s
P
p
.004 w
.23488 .54317 m
.27177 .5275 L
s
P
p
.002 w
.3271 .33748 m .3057 .39655 L .30823 .39076 L p
1 g
F P
s
P
p
.002 w
.30823 .39076 m .32979 .33128 L .3271 .33748 L p
1 g
F P
s
P
p
.002 w
.68189 .50717 m .6966 .44455 L .69603 .43881 L p
1 g
F P
s
P
p
.002 w
.68916 .37534 m .69603 .43881 L .6966 .44455 L p
1 g
F P
s
P
p
.002 w
.48918 .23476 m .4252 .24833 L .43044 .24677 L p
1 g
F P
s
P
p
.002 w
.43044 .24677 m .49308 .23349 L .48918 .23476 L p
1 g
F P
s
P
p
.002 w
.36184 .57053 m .41106 .606 L .41186 .60632 L p
1 g
F P
s
P
p
.002 w
.41186 .60632 m .36089 .56958 L .36184 .57053 L p
1 g
F P
s
P
p
.002 w
.47169 .62541 m .41186 .60632 L .41106 .606 L p
1 g
F P
s
P
p
.002 w
.32612 .52157 m .36184 .57053 L .36089 .56958 L p
1 g
F P
s
P
p
.002 w
.36089 .56958 m .32389 .51886 L .32612 .52157 L p
1 g
F P
s
P
p
.002 w
.59355 .60426 m .64294 .56553 L .64758 .56075 L p
1 g
F P
s
P
p
.002 w
.68189 .50717 m .64758 .56075 L .64294 .56553 L p
1 g
F P
s
P
p
.002 w
.41106 .606 m .46882 .62444 L .47169 .62541 L p
1 g
F P
s
P
p
.002 w
.53438 .6248 m .47169 .62541 L .46882 .62444 L p
1 g
F P
s
P
p
.002 w
.36715 .28846 m .3271 .33748 L .32979 .33128 L p
1 g
F P
s
P
p
.002 w
.32979 .33128 m .37011 .28189 L .36715 .28846 L p
1 g
F P
s
P
p
.002 w
.30765 .46397 m .32612 .52157 L .32389 .51886 L p
1 g
F P
s
P
p
.002 w
.32389 .51886 m .30474 .45919 L .30765 .46397 L p
1 g
F P
s
P
p
.002 w
.6966 .44455 m .68958 .37973 L .68916 .37534 L p
1 g
F P
s
P
p
.002 w
.6614 .31699 m .68916 .37534 L .68958 .37973 L p
1 g
F P
s
P
p
.002 w
.55483 .24313 m .48918 .23476 L .49308 .23349 L p
1 g
F P
s
P
p
.002 w
.49308 .23349 m .55732 .24167 L .55483 .24313 L p
1 g
F P
s
P
p
.002 w
.46882 .62444 m .52933 .62384 L .53438 .6248 L p
1 g
F P
s
P
p
.002 w
.59355 .60426 m .53438 .6248 L .52933 .62384 L p
1 g
F P
s
P
p
.002 w
.68958 .37973 m .66121 .32011 L .6614 .31699 L p
1 g
F P
s
P
p
.002 w
.61571 .27061 m .6614 .31699 L .66121 .32011 L p
1 g
F P
s
P
p
.002 w
.6145 .27271 m .55483 .24313 L .55732 .24167 L p
1 g
F P
s
P
p
.002 w
.55732 .24167 m .61571 .27061 L .6145 .27271 L p
1 g
F P
s
P
p
.002 w
.3086 .40356 m .30765 .46397 L .30474 .45919 L p
1 g
F P
s
P
p
.002 w
.30474 .45919 m .3057 .39655 L .3086 .40356 L p
1 g
F P
s
P
p
.002 w
.66121 .32011 m .6145 .27271 L .61571 .27061 L p
1 g
F P
s
P
p
.002 w
.64294 .56553 m .67699 .51232 L .68189 .50717 L p
1 g
F P
s
P
p
.002 w
.6966 .44455 m .68189 .50717 L .67699 .51232 L p
1 g
F P
s
P
p
.002 w
.42188 .25516 m .36715 .28846 L .37011 .28189 L p
1 g
F P
s
P
p
.002 w
.37011 .28189 m .4252 .24833 L .42188 .25516 L p
1 g
F P
s
P
p
.002 w
.52933 .62384 m .58641 .60401 L .59355 .60426 L p
1 g
F P
s
P
p
.002 w
.64294 .56553 m .59355 .60426 L .58641 .60401 L p
1 g
F P
s
P
p
.002 w
.32927 .34663 m .3086 .40356 L .3057 .39655 L p
1 g
F P
s
P
p
.002 w
.3057 .39655 m .3271 .33748 L .32927 .34663 L p
1 g
F P
s
P
p
.002 w
.67699 .51232 m .69157 .45014 L .6966 .44455 L p
1 g
F P
s
P
p
.002 w
.68958 .37973 m .6966 .44455 L .69157 .45014 L p
1 g
F P
s
P
p
.002 w
.48543 .24172 m .42188 .25516 L .4252 .24833 L p
1 g
F P
s
P
p
.002 w
.4252 .24833 m .48918 .23476 L .48543 .24172 L p
1 g
F P
s
P
p
.002 w
.3668 .5675 m .41278 .60064 L .41106 .606 L p
1 g
F P
s
P
p
.002 w
.41106 .606 m .36184 .57053 L .3668 .5675 L p
1 g
F P
s
P
p
.002 w
.46882 .62444 m .41106 .606 L .41278 .60064 L p
1 g
F P
s
P
p
.002 w
.33346 .52177 m .3668 .5675 L .36184 .57053 L p
1 g
F P
s
P
p
.002 w
.36184 .57053 m .32612 .52157 L .33346 .52177 L p
1 g
F P
s
P
p
.002 w
.58641 .60401 m .63399 .56664 L .64294 .56553 L p
1 g
F P
s
P
p
.002 w
.67699 .51232 m .64294 .56553 L .63399 .56664 L p
1 g
F P
s
P
p
.002 w
.41278 .60064 m .46673 .61785 L .46882 .62444 L p
1 g
F P
s
P
p
.002 w
.52933 .62384 m .46882 .62444 L .46673 .61785 L p
1 g
F P
s
P
p
.002 w
.36791 .29943 m .32927 .34663 L .3271 .33748 L p
1 g
F P
s
P
p
.002 w
.3271 .33748 m .36715 .28846 L .36791 .29943 L p
1 g
F P
s
P
p
.002 w
.31625 .468 m .33346 .52177 L .32612 .52157 L p
1 g
F P
s
P
p
.002 w
.32612 .52157 m .30765 .46397 L .31625 .468 L p
1 g
F P
s
P
p
.004 w
.3029 .51427 m
.3102 .51116 L
s
P
p
.002 w
.69157 .45014 m .68456 .38576 L .68958 .37973 L p
1 g
F P
s
P
p
.002 w
.66121 .32011 m .68958 .37973 L .68456 .38576 L p
1 g
F P
s
P
p
.002 w
.55064 .25006 m .48543 .24172 L .48918 .23476 L p
1 g
F P
s
P
p
.002 w
.48918 .23476 m .55483 .24313 L .55064 .25006 L p
1 g
F P
s
P
p
.002 w
.46673 .61785 m .52321 .61726 L .52933 .62384 L p
1 g
F P
s
P
p
.002 w
.58641 .60401 m .52933 .62384 L .52321 .61726 L p
1 g
F P
s
P
p
.002 w
.68456 .38576 m .65635 .32655 L .66121 .32011 L p
1 g
F P
s
P
p
.002 w
.6145 .27271 m .66121 .32011 L .65635 .32655 L p
1 g
F P
s
P
p
.002 w
.60993 .27946 m .55064 .25006 L .55483 .24313 L p
1 g
F P
s
P
p
.002 w
.55483 .24313 m .6145 .27271 L .60993 .27946 L p
1 g
F P
s
P
p
.002 w
.31719 .41165 m .31625 .468 L .30765 .46397 L p
1 g
F P
s
P
p
.002 w
.30765 .46397 m .3086 .40356 L .31719 .41165 L p
1 g
F P
s
P
p
.002 w
.63399 .56664 m .66676 .51533 L .67699 .51232 L p
1 g
F P
s
P
p
.002 w
.69157 .45014 m .67699 .51232 L .66676 .51533 L p
1 g
F P
s
P
p
.002 w
.65635 .32655 m .60993 .27946 L .6145 .27271 L p
1 g
F P
s
P
p
.002 w
.42068 .2674 m .36791 .29943 L .36715 .28846 L p
1 g
F P
s
P
p
.002 w
.36715 .28846 m .42188 .25516 L .42068 .2674 L p
1 g
F P
s
P
p
.002 w
.52321 .61726 m .57644 .59871 L .58641 .60401 L p
1 g
F P
s
P
p
.002 w
.63399 .56664 m .58641 .60401 L .57644 .59871 L p
1 g
F P
s
P
p
.002 w
.33653 .35862 m .31719 .41165 L .3086 .40356 L p
1 g
F P
s
P
p
.002 w
.3086 .40356 m .32927 .34663 L .33653 .35862 L p
1 g
F P
s
P
p
.002 w
.66676 .51533 m .68074 .45539 L .69157 .45014 L p
1 g
F P
s
P
p
.002 w
.68456 .38576 m .69157 .45014 L .68074 .45539 L p
1 g
F P
s
P
p
.002 w
.48194 .25452 m .42068 .2674 L .42188 .25516 L p
1 g
F P
s
P
p
.002 w
.42188 .25516 m .48543 .24172 L .48194 .25452 L p
1 g
F P
s
P
p
.002 w
.37587 .56034 m .41712 .59007 L .41278 .60064 L p
1 g
F P
s
P
p
.002 w
.41278 .60064 m .3668 .5675 L .37587 .56034 L p
1 g
F P
s
P
p
.002 w
.46673 .61785 m .41278 .60064 L .41712 .59007 L p
1 g
F P
s
P
p
.002 w
.34599 .5193 m .37587 .56034 L .3668 .5675 L p
1 g
F P
s
P
p
.002 w
.3668 .5675 m .33346 .52177 L .34599 .5193 L p
1 g
F P
s
P
p
.002 w
.57644 .59871 m .62075 .56381 L .63399 .56664 L p
1 g
F P
s
P
p
.002 w
.66676 .51533 m .63399 .56664 L .62075 .56381 L p
1 g
F P
s
P
p
.002 w
.41712 .59007 m .46552 .60548 L .46673 .61785 L p
1 g
F P
s
P
p
.002 w
.52321 .61726 m .46673 .61785 L .46552 .60548 L p
1 g
F P
s
P
p
.002 w
.37261 .31472 m .33653 .35862 L .32927 .34663 L p
1 g
F P
s
P
p
.002 w
.32927 .34663 m .36791 .29943 L .37261 .31472 L p
1 g
F P
s
P
p
.002 w
.33062 .47109 m .34599 .5193 L .33346 .52177 L p
1 g
F P
s
P
p
.004 w
.33943 .49874 m
.5 .43051 L
s
P
p
.002 w
.33346 .52177 m .31625 .468 L .33062 .47109 L p
1 g
F P
s
P
p
.004 w
.32944 .50299 m
.33074 .50244 L
s
P
p
.004 w
.3102 .51116 m
.32294 .50575 L
s
P
p
.004 w
.32294 .50575 m
.32944 .50299 L
s
P
p
.002 w
.68074 .45539 m .67391 .39337 L .68456 .38576 L p
1 g
F P
s
P
p
.002 w
.65635 .32655 m .68456 .38576 L .67391 .39337 L p
1 g
F P
s
P
p
.002 w
.54478 .26261 m .48194 .25452 L .48543 .24172 L p
1 g
F P
s
P
p
.002 w
.48543 .24172 m .55064 .25006 L .54478 .26261 L p
1 g
F P
s
P
p
.002 w
.46552 .60548 m .51616 .60491 L .52321 .61726 L p
1 g
F P
s
P
p
.002 w
.57644 .59871 m .52321 .61726 L .51616 .60491 L p
1 g
F P
s
P
p
.002 w
.67391 .39337 m .64667 .33633 L .65635 .32655 L p
1 g
F P
s
P
p
.002 w
.60993 .27946 m .65635 .32655 L .64667 .33633 L p
1 g
F P
s
P
p
.002 w
.33154 .42063 m .33062 .47109 L .31625 .468 L p
1 g
F P
s
P
p
.002 w
.31625 .468 m .31719 .41165 L .33154 .42063 L p
1 g
F P
s
P
p
.002 w
.60192 .29096 m .54478 .26261 L .55064 .25006 L p
1 g
F P
s
P
p
.002 w
.55064 .25006 m .60993 .27946 L .60192 .29096 L p
1 g
F P
s
P
p
.002 w
.62075 .56381 m .6512 .51596 L .66676 .51533 L p
1 g
F P
s
P
p
.002 w
.68074 .45539 m .66676 .51533 L .6512 .51596 L p
1 g
F P
s
P
p
.002 w
.64667 .33633 m .60192 .29096 L .60993 .27946 L p
1 g
F P
s
P
p
.002 w
.42181 .28499 m .37261 .31472 L .36791 .29943 L p
1 g
F P
s
P
p
.002 w
.36791 .29943 m .42068 .2674 L .42181 .28499 L p
1 g
F P
s
P
p
.002 w
.51616 .60491 m .56381 .58822 L .57644 .59871 L p
1 g
F P
s
P
p
.002 w
.62075 .56381 m .57644 .59871 L .56381 .58822 L p
1 g
F P
s
P
p
.002 w
.34896 .37323 m .33154 .42063 L .31719 .41165 L p
1 g
F P
s
P
p
.002 w
.31719 .41165 m .33653 .35862 L .34896 .37323 L p
1 g
F P
s
P
p
.002 w
.6512 .51596 m .6641 .46012 L .68074 .45539 L p
1 g
F P
s
P
p
.002 w
.67391 .39337 m .68074 .45539 L .6641 .46012 L p
1 g
F P
s
P
p
.002 w
.47886 .2731 m .42181 .28499 L .42068 .2674 L p
1 g
F P
s
P
p
.002 w
.42068 .2674 m .48194 .25452 L .47886 .2731 L p
1 g
F P
s
P
p
.002 w
.56381 .58822 m .60339 .55691 L .62075 .56381 L p
1 g
F P
s
P
p
.002 w
.6512 .51596 m .62075 .56381 L .60339 .55691 L p
1 g
F P
s
P
p
.002 w
.38901 .54901 m .42411 .57432 L .41712 .59007 L p
1 g
F P
s
P
p
.002 w
.41712 .59007 m .37587 .56034 L .38901 .54901 L p
1 g
F P
s
P
p
.002 w
.46552 .60548 m .41712 .59007 L .42411 .57432 L p
1 g
F P
s
P
p
.002 w
.36362 .51408 m .38901 .54901 L .37587 .56034 L p
1 g
F P
s
P
p
.002 w
.37587 .56034 m .34599 .5193 L .36362 .51408 L p
1 g
F P
s
P
p
.002 w
.38131 .33406 m .34896 .37323 L .33653 .35862 L p
1 g
F P
s
P
p
.002 w
.33653 .35862 m .37261 .31472 L .38131 .33406 L p
1 g
F P
s
P
p
.002 w
.42411 .57432 m .46529 .5874 L .46552 .60548 L p
1 g
F P
s
P
p
.002 w
.51616 .60491 m .46552 .60548 L .46529 .5874 L p
1 g
F P
s
P
p
.002 w
.6641 .46012 m .65764 .40238 L .67391 .39337 L p
1 g
F P
s
P
p
.002 w
.64667 .33633 m .67391 .39337 L .65764 .40238 L p
1 g
F P
s
P
p
.002 w
.35062 .47309 m .36362 .51408 L .34599 .5193 L p
1 g
F P
s
P
p
.002 w
.34599 .5193 m .33062 .47109 L .35062 .47309 L p
1 g
F P
s
P
p
.002 w
.53735 .2807 m .47886 .2731 L .48194 .25452 L p
1 g
F P
s
P
p
.002 w
.48194 .25452 m .54478 .26261 L .53735 .2807 L p
1 g
F P
s
P
p
.002 w
.46529 .5874 m .50834 .58685 L .51616 .60491 L p
1 g
F P
s
P
p
.002 w
.56381 .58822 m .51616 .60491 L .50834 .58685 L p
1 g
F P
s
P
p
.002 w
.65764 .40238 m .63222 .34932 L .64667 .33633 L p
1 g
F P
s
P
p
.002 w
.60192 .29096 m .64667 .33633 L .63222 .34932 L p
1 g
F P
s
P
p
.002 w
.35151 .43024 m .35062 .47309 L .33062 .47109 L p
1 g
F P
s
P
p
.002 w
.33062 .47109 m .33154 .42063 L .35151 .43024 L p
1 g
F P
s
P
p
.002 w
.59053 .30711 m .53735 .2807 L .54478 .26261 L p
1 g
F P
s
P
p
.002 w
.54478 .26261 m .60192 .29096 L .59053 .30711 L p
1 g
F P
s
P
p
.002 w
.60339 .55691 m .6305 .51405 L .6512 .51596 L p
1 g
F P
s
P
p
.002 w
.6641 .46012 m .6512 .51596 L .6305 .51405 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.63222 .34932 m .59053 .30711 L .60192 .29096 L p
1 g
F P
s
P
p
.002 w
.42534 .30762 m .38131 .33406 L .37261 .31472 L p
1 g
F P
s
P
p
.002 w
.37261 .31472 m .42181 .28499 L .42534 .30762 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50834 .58685 m .54878 .57258 L .56381 .58822 L p
1 g
F P
s
P
p
.002 w
.60339 .55691 m .56381 .58822 L .54878 .57258 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.36641 .39008 m .35151 .43024 L .33154 .42063 L p
1 g
F P
s
P
p
.002 w
.33154 .42063 m .34896 .37323 L .36641 .39008 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.6305 .51405 m .6419 .46413 L .6641 .46012 L p
1 g
F P
s
P
p
.002 w
.65764 .40238 m .6641 .46012 L .6419 .46413 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.47631 .29712 m .42534 .30762 L .42181 .28499 L p
1 g
F P
s
P
p
.002 w
.42181 .28499 m .47886 .2731 L .47631 .29712 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54878 .57258 m .58228 .54592 L .60339 .55691 L p
1 g
F P
s
P
p
.002 w
.6305 .51405 m .60339 .55691 L .58228 .54592 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.406 .53368 m .43365 .55362 L .42411 .57432 L p
1 g
F P
s
P
p
.002 w
.42411 .57432 m .38901 .54901 L .406 .53368 L p
1 g
F P
s
P
p
.002 w
.46529 .5874 m .42411 .57432 L .43365 .55362 L p
1 g
F P
s
P
p
.002 w
.38603 .50614 m .406 .53368 L .38901 .54901 L p
1 g
F P
s
P
p
.002 w
.38901 .54901 m .36362 .51408 L .38603 .50614 L p
1 g
F P
s
P
p
.002 w
.39393 .35699 m .36641 .39008 L .34896 .37323 L p
1 g
F P
s
P
p
.002 w
.34896 .37323 m .38131 .33406 L .39393 .35699 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46529 .5874 m .44069 .55585 L .45088 .56286 L 1 g
F
P
p
.002 w
.46579 .57313 m .46557 .57933 L p
.45088 .56286 L 1 g
F P
s
P
p
.002 w
.46557 .57933 m .46529 .5874 L p
.45088 .56286 L 1 g
F P
s
P
p
.002 w
.45088 .56286 m .45146 .56129 L p
.44419 .55497 L 1 g
F P
s
P
p
.002 w
.43365 .55362 m .43731 .54589 L p
.43838 .5473 L 1 g
F P
s
P
p
.002 w
.44616 .55758 m .44148 .5561 L p
.43838 .5473 L 1 g
F P
s
P
p
.002 w
.44148 .5561 m .43365 .55362 L p
.43838 .5473 L 1 g
F P
s
P
p
.002 w
.43838 .5473 m .43925 .54566 L p
.43558 .53841 L 1 g
F P
s
P
p
.002 w
.43764 .5452 m .43365 .55362 L p
.43211 .54144 L 1 g
F P
s
P
p
.43211 .54144 m .42896 .51653 L .43261 .52858 L 1 g
F
P
p
.43211 .54144 m .43261 .52858 L .43764 .5452 L 1 g
F
P
p
.002 w
.43261 .52858 m .43346 .52734 L p
.43312 .51767 L 1 g
F P
s
P
p
.002 w
.42641 .51469 m .43408 .5074 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43296 .51941 m .43011 .51735 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43011 .51735 m .42641 .51469 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43389 .5094 m .43485 .50826 L p
.4383 .50019 L 1 g
F P
s
P
p
.002 w
.43548 .50606 m .42641 .51469 L p
.44006 .4938 L 1 g
F P
s
P
p
.44006 .4938 m .44502 .48622 L .44251 .49144 L 1 g
F
P
p
.44006 .4938 m .44251 .49144 L .43548 .50606 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43312 .51767 m .43296 .51941 L .43261 .52858 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43558 .53841 m .43764 .5452 L .43838 .5473 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43206 .52938 L p
1 g
F P
s
P
p
.43925 .54566 m .43206 .52938 L .43447 .5362 L 1 g
F
P
p
.44419 .55497 m .44616 .55758 L .45088 .56286 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.46872 .57265 m .46008 .5692 L .46579 .57313 L 1 g
F
P
p
.002 w
.49203 .58706 m .46529 .5874 L .46577 .57379 L p
1 g
F P
s
P
p
.002 w
.46577 .57379 m .46579 .57313 L p
.46832 .57447 L 1 g
F P
s
P
p
.49203 .58706 m .46577 .57379 L .46832 .57447 L 1 g
F
P
p
.002 w
.4891 .58004 m .48921 .57862 L p
.4814 .57798 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50834 .58685 m .49203 .58706 L p
.48387 .57977 L 1 g
F P
s
P
p
.50834 .58685 m .48387 .57977 L .48752 .57996 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46832 .57447 L p
1 g
F P
s
P
p
.48921 .57862 m .46832 .57447 L .4814 .57798 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58004 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58004 L .5006 .58066 L 1 g
F
P
p
.49655 .58044 m .48208 .57816 L .46611 .5639 L 1 g
F
P
p
.50237 .5836 m .4891 .58004 L .49655 .58044 L 1 g
F
P
p
.4891 .58004 m .48208 .57816 L .49655 .58044 L 1 g
F
P
p
.50834 .58685 m .48208 .57816 L .50237 .5836 L 1 g
F
P
p
.51079 .57862 m .5006 .58066 L .50625 .58096 L 1 g
F
P
p
.002 w
.53088 .5789 m .50834 .58685 L .50659 .58191 L p
1 g
F P
s
P
p
.002 w
.50659 .58191 m .50625 .58096 L p
.51094 .58057 L 1 g
F P
s
P
p
.53088 .5789 m .50659 .58191 L .51094 .58057 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58057 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58057 L .52335 .57672 L 1 g
F
P
p
.002 w
.51094 .58057 m .51079 .57862 L p
.50625 .58096 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53161 .57416 m .53128 .57265 L p
.52335 .57672 L 1 g
F P
s
P
p
.002 w
.50625 .58096 m .5 .5634 L p
.52532 .57611 L 1 g
F P
s
P
p
.53088 .5789 m .51094 .58057 L .52532 .57611 L 1 g
F
P
p
.51094 .58057 m .50625 .58096 L .52532 .57611 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54878 .57258 m .53088 .5789 L p
.52693 .57691 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53161 .57416 L p
1 g
F P
s
P
p
.54854 .56129 m .53161 .57416 L .54058 .56888 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.5378 .57052 m .52693 .57691 L .5 .5634 L 1 g
F
P
p
.54878 .57258 m .52693 .57691 L .5378 .57052 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.54854 .56129 m .54058 .56888 L .54402 .56685 L 1 g
F
P
p
.58228 .54592 m .54754 .56493 L .56857 .5476 L 1 g
F
P
p
.54754 .56493 m .54402 .56685 L .54912 .56285 L 1 g
F
P
p
.54754 .56493 m .54912 .56285 L .56857 .5476 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54912 .56285 L p
1 g
F P
s
P
p
.002 w
.58228 .54592 m .54878 .57258 L .54402 .56685 L p
1 g
F P
s
P
p
.56075 .54566 m .54912 .56285 L .55688 .55268 L 1 g
F
P
p
.002 w
.54912 .56285 m .54854 .56129 L p
.54402 .56685 L 1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56136 .54681 m .56075 .54566 L p
.55688 .55268 L 1 g
F P
s
P
p
.002 w
.54402 .56685 m .53177 .55209 L p
.55995 .54865 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56136 .54681 L p
1 g
F P
s
P
p
.56857 .5476 m .55802 .55588 L .56071 .54856 L 1 g
F
P
p
.56654 .52734 m .56136 .54681 L .56458 .53806 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56654 .52734 m .56458 .53806 L .56548 .53563 L 1 g
F
P
p
.60514 .50953 m .5677 .53417 L .56794 .52653 L 1 g
F
P
p
.5677 .53417 m .56548 .53563 L .56738 .52857 L 1 g
F
P
p
.5677 .53417 m .56738 .52857 L .56794 .52653 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56738 .52857 L p
1 g
F P
s
P
p
.56515 .50826 m .56738 .52857 L .56687 .51944 L 1 g
F
P
p
.002 w
.56738 .52857 m .56654 .52734 L p
.56548 .53563 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56548 .53563 m .55801 .53106 L p
.56794 .52653 L 1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.57582 .50245 m .60514 .50953 L p
.56729 .52682 L 1 g
F P
s
P
p
.56515 .50826 m .56687 .51944 L .56674 .51704 L 1 g
F
P
p
.002 w
.57582 .50245 m .56842 .51433 L p
.56562 .50481 L 1 g
F P
s
P
p
.002 w
.56842 .51433 m .56674 .51704 L p
.56603 .50931 L 1 g
F P
s
P
p
.56842 .51433 m .56603 .50931 L .56562 .50481 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56603 .50931 L p
1 g
F P
s
P
p
.55661 .4905 m .56603 .50931 L .56188 .50057 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55801 .53106 m .53135 .51273 L p
.56406 .50517 L 1 g
F P
s
P
p
.56562 .50481 m .56496 .50706 L .56406 .50517 L 1 g
F
P
p
.56496 .50706 m .55801 .53106 L .56406 .50517 L 1 g
F
P
p
.002 w
.56603 .50931 m .56515 .50826 L p
.56674 .51704 L 1 g
F P
s
P
p
.002 w
.56674 .51704 m .55801 .53106 L p
.56562 .50481 L 1 g
F P
s
P
p
.55661 .4905 m .56188 .50057 L .56065 .498 L 1 g
F
P
p
.58314 .46927 m .56222 .496 L .55485 .4862 L 1 g
F
P
p
.56222 .496 m .56065 .498 L .55735 .49128 L 1 g
F
P
p
.56222 .496 m .55735 .49128 L .55485 .4862 L 1 g
F
P
p
.002 w
.55735 .49128 m .55661 .4905 L p
.56065 .498 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55735 .49128 L p
1 g
F P
s
P
p
.002 w
.55757 .49152 m .55735 .49128 L p
.56065 .498 L 1 g
F P
s
P
p
.54174 .47608 m .55735 .49128 L .55044 .4846 L 1 g
F
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56065 .498 m .54352 .49297 L p
.55315 .48722 L 1 g
F P
s
P
p
.55485 .4862 m .55735 .49128 L .55315 .48722 L 1 g
F
P
p
.55735 .49128 m .56065 .498 L .55315 .48722 L 1 g
F
P
p
.002 w
.58314 .46927 m .57582 .50245 L .56065 .498 L p
1 g
F P
s
P
p
.002 w
.53135 .51273 m .54352 .49297 L .56065 .498 L p
1 g
F P
s
P
p
.002 w
.56065 .498 m .57582 .50245 L p
.56406 .50517 L 1 g
F P
s
P
p
.56406 .50517 m .53135 .51273 L .56065 .498 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55757 .49152 L p
1 g
F P
s
P
p
.56188 .50057 m .56713 .51061 L .55757 .49152 L 1 g
F
P
p
.54174 .47608 m .55044 .4846 L .54622 .48051 L 1 g
F
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54622 .48051 m .54352 .49297 L p
.53906 .47519 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54238 .47678 L p
1 g
F P
s
P
p
.52214 .46667 m .54238 .47678 L .53275 .47216 L 1 g
F
P
p
.54238 .47678 m .53906 .47519 L .53851 .47302 L 1 g
F
P
p
.54622 .48051 m .53906 .47519 L .54238 .47678 L 1 g
F
P
p
.002 w
.54352 .49297 m .50942 .48141 L p
.53603 .47373 L 1 g
F P
s
P
p
.53851 .47302 m .53906 .47519 L .53603 .47373 L 1 g
F
P
p
.53906 .47519 m .54352 .49297 L .53603 .47373 L 1 g
F
P
p
.52214 .46667 m .53275 .47216 L .52812 .46994 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52812 .46994 m .51188 .46978 L p
.51676 .46644 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .51374 .46604 L 1 g
F
P
p
.51847 .46527 m .52246 .4672 L .51676 .46644 L 1 g
F
P
p
.52246 .4672 m .52812 .46994 L .51676 .46644 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.51035 .45788 m .54555 .44672 L p
.51676 .46644 L 1 g
F P
s
P
p
.002 w
.51188 .46978 m .51136 .46572 L p
.51676 .46644 L 1 g
F P
s
P
p
.5 .4634 m .51374 .46604 L .51136 .46572 L 1 g
F
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51136 .46572 m .51188 .46978 L p
.49729 .4643 L 1 g
F P
s
P
p
.51136 .46572 m .49729 .4643 L .5 .46389 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.49729 .4643 m .51188 .46978 L .47837 .46716 L 1 g
F
P
p
.002 w
.5 .46389 m .5 .46442 L p
.48939 .4655 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .48939 .4655 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44237 .49159 L p
1 g
F P
s
P
p
.002 w
.44251 .49144 m .44339 .4905 L p
.45097 .48324 L 1 g
F P
s
P
p
.4462 .48787 m .45766 .47673 L .47396 .46902 L 1 g
F
P
p
.45097 .48324 m .45572 .47868 L .4462 .48787 L 1 g
F
P
p
.45097 .48324 m .4462 .48787 L .44251 .49144 L 1 g
F
P
p
.002 w
.47396 .46902 m .44962 .49261 L .4462 .48787 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45766 .47673 L p
1 g
F P
s
P
p
.002 w
.45766 .47673 m .45698 .47747 L p
.45097 .48324 L 1 g
F P
s
P
p
.44339 .4905 m .45766 .47673 L .45097 .48324 L 1 g
F
P
p
.002 w
.44313 .48361 m .44257 .48283 L p
.45867 .47575 L 1 g
F P
s
P
p
.002 w
.45942 .49968 m .44962 .49261 L .47396 .46902 L p
1 g
F P
s
P
p
.002 w
.48291 .50306 m .47093 .50329 L .47477 .46864 L p
1 g
F P
s
P
p
.002 w
.50326 .49151 m .4941 .49899 L .47502 .46852 L p
1 g
F P
s
P
p
.002 w
.51188 .46978 m .50942 .48141 L .4753 .46838 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .4673 L p
1 g
F P
s
P
p
.47786 .46667 m .48939 .4655 L .47837 .46716 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5076 .4523 m .51035 .45788 L .47837 .46716 L p
1 g
F P
s
P
p
.002 w
.47837 .46716 m .47689 .46759 L p
.47748 .4673 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47786 .46667 L p
.47837 .46716 L 1 g
F P
s
P
p
.5076 .4523 m .47837 .46716 L .47748 .4673 L 1 g
F
P
p
.002 w
.47748 .4673 m .47748 .4673 L p
.47837 .46716 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47748 .4673 L p
.47738 .46735 L 1 g
F P
s
P
p
.45826 .47608 m .47748 .4673 L .47738 .46735 L 1 g
F
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47482 .46819 m .505 .44702 L .5076 .4523 L p
1 g
F P
s
P
p
.45826 .47608 m .47748 .4673 L .4773 .46739 L 1 g
F
P
p
.45826 .47608 m .47747 .46731 L .47722 .46743 L 1 g
F
P
p
.45826 .47608 m .47746 .46732 L .47715 .46748 L 1 g
F
P
p
.002 w
.47689 .46759 m .47482 .46819 L p
.5076 .4523 L 1 g
F P
s
P
p
.45826 .47608 m .47746 .46734 L .4771 .46751 L 1 g
F
P
p
.45826 .47608 m .47745 .46735 L .47708 .46753 L 1 g
F
P
p
.45826 .47608 m .47744 .46737 L .47711 .46752 L 1 g
F
P
p
.45826 .47608 m .47743 .46738 L .47721 .46748 L 1 g
F
P
p
.002 w
.47561 .46823 m .51188 .46978 L p
.4753 .46838 L 1 g
F P
s
P
p
.002 w
.50942 .48141 m .50326 .49151 L .47514 .46846 L p
1 g
F P
s
P
p
.002 w
.4753 .46838 m .50942 .48141 L p
.47514 .46846 L 1 g
F P
s
P
p
.002 w
.47514 .46846 m .50326 .49151 L p
.47502 .46852 L 1 g
F P
s
P
p
.002 w
.4941 .49899 m .48291 .50306 L .47491 .46857 L p
1 g
F P
s
P
p
.002 w
.47502 .46852 m .4941 .49899 L p
.47491 .46857 L 1 g
F P
s
P
p
.002 w
.47491 .46857 m .48291 .50306 L p
.47477 .46864 L 1 g
F P
s
P
p
.002 w
.47093 .50329 m .45942 .49968 L .47455 .46875 L p
1 g
F P
s
P
p
.002 w
.47477 .46864 m .47093 .50329 L p
.47455 .46875 L 1 g
F P
s
P
p
.002 w
.47455 .46875 m .45942 .49968 L p
.47396 .46902 L 1 g
F P
s
P
p
.002 w
.51188 .46978 m .47561 .46823 L p
.47837 .46716 L 1 g
F P
s
P
p
.45826 .47608 m .47743 .46738 L .46898 .47138 L 1 g
F
P
p
.002 w
.4753 .46838 m .47482 .46819 L .47561 .46823 L p
1 g
F P
s
P
p
.002 w
.47748 .4673 m .47747 .46731 L p
.4773 .46739 L 1 g
F P
s
P
p
.002 w
.47747 .46731 m .47746 .46732 L p
.47722 .46743 L 1 g
F P
s
P
p
.002 w
.47514 .46846 m .47482 .46819 L .4753 .46838 L p
1 g
F P
s
P
p
.002 w
.47502 .46852 m .47482 .46819 L .47514 .46846 L p
1 g
F P
s
P
p
.002 w
.47746 .46732 m .47746 .46734 L p
.47715 .46748 L 1 g
F P
s
P
p
.002 w
.47746 .46734 m .47745 .46735 L p
.4771 .46751 L 1 g
F P
s
P
p
.002 w
.47491 .46857 m .47482 .46819 L .47502 .46852 L p
1 g
F P
s
P
p
.002 w
.47477 .46864 m .47482 .46819 L .47491 .46857 L p
1 g
F P
s
P
p
.002 w
.47745 .46735 m .47744 .46737 L p
.47708 .46753 L 1 g
F P
s
P
p
.002 w
.47744 .46737 m .47743 .46738 L p
.47711 .46752 L 1 g
F P
s
P
p
.002 w
.47455 .46875 m .47482 .46819 L .47477 .46864 L p
1 g
F P
s
P
p
.002 w
.47396 .46902 m .47482 .46819 L .47455 .46875 L p
1 g
F P
s
P
p
.002 w
.47743 .46738 m .47743 .46738 L p
.47721 .46748 L 1 g
F P
s
P
p
.002 w
.47689 .46759 m .47837 .46716 L p
.47561 .46823 L 1 g
F P
s
P
p
.002 w
.47743 .46738 m .47718 .46778 L p
.46898 .47138 L 1 g
F P
s
P
p
.002 w
.45766 .47673 m .45826 .47608 L p
.46898 .47138 L 1 g
F P
s
P
p
.45766 .47673 m .45867 .47575 L .47396 .46902 L 1 g
F
P
p
.44313 .48361 m .45867 .47575 L .45766 .47673 L 1 g
F
P
p
.002 w
.4462 .48787 m .44313 .48361 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.44257 .48283 m .47482 .46819 L .47396 .46902 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .45766 .47673 L p
.47145 .4703 L 1 g
F P
s
P
p
.46898 .47138 m .47145 .4703 L .45766 .47673 L 1 g
F
P
p
.002 w
.47718 .46778 m .45795 .47701 L p
.47145 .4703 L 1 g
F P
s
P
p
.002 w
.45795 .47701 m .45698 .47747 L p
.47145 .4703 L 1 g
F P
s
P
p
.002 w
.47561 .46823 m .47482 .46819 L .47689 .46759 L p
1 g
F P
s
P
p
.002 w
.47837 .46716 m .49334 .46282 L p
.49729 .4643 L 1 g
F P
s
P
p
.5 .46389 m .49729 .4643 L .49334 .46282 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47748 .4673 L p
1 g
F P
s
P
p
.48939 .4655 m .5 .46442 L .47748 .4673 L 1 g
F
P
p
.002 w
.5 .46421 m .5 .46389 L p
.51136 .46572 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.51136 .46572 L 1 g
F P
s
P
p
.002 w
.49334 .46282 m .51035 .45788 L .51136 .46572 L p
1 g
F P
s
P
p
.002 w
.51136 .46572 m .51035 .45788 L p
.51676 .46644 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46421 L p
1 g
F P
s
P
p
.51374 .46604 m .52282 .46778 L .5 .46421 L 1 g
F
P
p
.002 w
.52246 .4672 m .52282 .46778 L p
.51374 .46604 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52246 .4672 L p
.52812 .46994 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.52812 .46994 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.54555 .44672 m .54846 .47014 L .52812 .46994 L p
1 g
F P
s
P
p
.54555 .44672 m .52812 .46994 L .51847 .46527 L 1 g
F
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.50942 .48141 m .51188 .46978 L .54846 .47014 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46724 L p
1 g
F P
s
P
p
.53275 .47216 m .54302 .47747 L .52249 .46724 L 1 g
F
P
p
.002 w
.54238 .47678 m .54302 .47747 L p
.53275 .47216 L 1 g
F P
s
P
p
.002 w
.54255 .47696 m .54238 .47678 L p
.54622 .48051 L 1 g
F P
s
P
p
.002 w
.54238 .47678 m .54174 .47608 L p
.54622 .48051 L 1 g
F P
s
P
p
.002 w
.54846 .47014 m .54622 .48051 L p
.53851 .47302 L 1 g
F P
s
P
p
.002 w
.54352 .49297 m .54846 .47014 L .58314 .46927 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54255 .47696 L p
1 g
F P
s
P
p
.55044 .4846 m .55834 .49233 L .54255 .47696 L 1 g
F
P
p
.002 w
.55735 .49128 m .55834 .49233 L p
.55044 .4846 L 1 g
F P
s
P
p
.002 w
.56603 .50931 m .56713 .51061 L p
.56188 .50057 L 1 g
F P
s
P
p
.002 w
.56633 .50966 m .56603 .50931 L p
.56674 .51704 L 1 g
F P
s
P
p
.002 w
.55801 .53106 m .56674 .51704 L p
.56729 .52682 L 1 g
F P
s
P
p
.002 w
.56674 .51704 m .57582 .50245 L p
.56729 .52682 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56633 .50966 L p
1 g
F P
s
P
p
.56687 .51944 m .56854 .53025 L .56633 .50966 L 1 g
F
P
p
.002 w
.56738 .52857 m .56854 .53025 L p
.56687 .51944 L 1 g
F P
s
P
p
.002 w
.56784 .52923 m .56738 .52857 L p
.56548 .53563 L 1 g
F P
s
P
p
.002 w
.60514 .50953 m .58228 .54592 L .56548 .53563 L p
1 g
F P
s
P
p
.002 w
.53177 .55209 m .55801 .53106 L .56548 .53563 L p
1 g
F P
s
P
p
.002 w
.56548 .53563 m .58228 .54592 L p
.56071 .54856 L 1 g
F P
s
P
p
.56071 .54856 m .53177 .55209 L .56548 .53563 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56784 .52923 L p
1 g
F P
s
P
p
.56458 .53806 m .56257 .5491 L .56784 .52923 L 1 g
F
P
p
.002 w
.56136 .54681 m .56257 .5491 L p
.56458 .53806 L 1 g
F P
s
P
p
.56071 .54856 m .54912 .56285 L .55995 .54865 L 1 g
F
P
p
.55802 .55588 m .54912 .56285 L .56071 .54856 L 1 g
F
P
p
.54912 .56285 m .54402 .56685 L .55995 .54865 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56136 .54681 L p
1 g
F P
s
P
p
.55688 .55268 m .54998 .56518 L .56136 .54681 L 1 g
F
P
p
.002 w
.54912 .56285 m .54998 .56518 L p
.55688 .55268 L 1 g
F P
s
P
p
.002 w
.54942 .56367 m .54912 .56285 L p
.54402 .56685 L 1 g
F P
s
P
p
.002 w
.5 .5634 m .53177 .55209 L .54402 .56685 L p
1 g
F P
s
P
p
.002 w
.54402 .56685 m .54878 .57258 L p
.5378 .57052 L 1 g
F P
s
P
p
.5378 .57052 m .5 .5634 L .54402 .56685 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54942 .56367 L p
1 g
F P
s
P
p
.54058 .56888 m .5322 .57686 L .54942 .56367 L 1 g
F
P
p
.002 w
.53161 .57416 m .5322 .57686 L p
.54058 .56888 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53161 .57416 L p
1 g
F P
s
P
p
.52335 .57672 m .51111 .583 L .53161 .57416 L 1 g
F
P
p
.002 w
.51094 .58057 m .51111 .583 L p
.52335 .57672 L 1 g
F P
s
P
p
.002 w
.51098 .58121 m .51094 .58057 L p
.50625 .58096 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46611 .5639 m .5 .5634 L .50834 .58685 L p
1 g
F P
s
P
p
.002 w
.4891 .58004 m .48889 .583 L p
.5006 .58066 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58121 L p
1 g
F P
s
P
p
.5006 .58066 m .48889 .583 L .51098 .58121 L 1 g
F
P
p
.48752 .57996 m .48387 .57977 L .48208 .57816 L 1 g
F
P
p
.002 w
.46832 .57447 m .46872 .57265 L p
.46579 .57313 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.46579 .57313 m .46611 .5639 L p
.49203 .58706 L 1 g
F P
s
P
p
.002 w
.46832 .57447 m .4678 .57686 L p
.4814 .57798 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58004 L p
1 g
F P
s
P
p
.4814 .57798 m .4678 .57686 L .4891 .58004 L 1 g
F
P
p
.002 w
.46825 .57482 m .46832 .57447 L p
.46579 .57313 L 1 g
F P
s
P
p
.002 w
.46611 .5639 m .46579 .57313 L p
.45088 .56286 L 1 g
F P
s
P
p
.002 w
.44069 .55585 m .44616 .55758 L p
.45088 .56286 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43786 .54828 L p
1 g
F P
s
P
p
.45146 .56129 m .43786 .54828 L .44261 .5536 L 1 g
F
P
p
.002 w
.44616 .55758 m .46611 .5639 L p
.45088 .56286 L 1 g
F P
s
P
p
.002 w
.43786 .54828 m .43743 .5491 L p
.44261 .5536 L 1 g
F P
s
P
p
.44616 .55758 m .43838 .5473 L .44554 .52849 L 1 g
F
P
p
.002 w
.43731 .54589 m .43764 .5452 L p
.43838 .5473 L 1 g
F P
s
P
p
.002 w
.43764 .5452 m .44554 .52849 L p
.43838 .5473 L 1 g
F P
s
P
p
.002 w
.43206 .52938 m .43146 .53025 L p
.43447 .5362 L 1 g
F P
s
P
p
.002 w
.44554 .52849 m .43764 .5452 L p
.43261 .52858 L 1 g
F P
s
P
p
.002 w
.42896 .51653 m .43296 .51941 L p
.43261 .52858 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43332 .51008 L p
1 g
F P
s
P
p
.43346 .52734 m .43332 .51008 L .43308 .51639 L 1 g
F
P
p
.002 w
.43296 .51941 m .44554 .52849 L p
.43261 .52858 L 1 g
F P
s
P
p
.002 w
.43332 .51008 m .43287 .51061 L p
.43308 .51639 L 1 g
F P
s
P
p
.43296 .51941 m .43389 .5094 L .44962 .49261 L 1 g
F
P
p
.002 w
.43408 .5074 m .43548 .50606 L p
.43389 .5094 L 1 g
F P
s
P
p
.43485 .50826 m .44237 .49159 L .43855 .49962 L 1 g
F
P
p
.4383 .50019 m .43548 .50606 L .43389 .5094 L 1 g
F
P
p
.002 w
.43548 .50606 m .44962 .49261 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.44237 .49159 m .44166 .49233 L p
.43855 .49962 L 1 g
F P
s
P
p
.002 w
.44502 .48622 m .44962 .49261 L .43548 .50606 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44251 .49144 L p
1 g
F P
s
P
p
.45572 .47868 m .45698 .47747 L .44251 .49144 L 1 g
F
P
p
.4383 .50019 m .43855 .49962 L .43548 .50606 L 1 g
F
P
p
.002 w
.44257 .48283 m .44502 .48622 L p
.42641 .51469 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43389 .5094 L p
1 g
F P
s
P
p
.43855 .49962 m .44166 .49233 L .43389 .5094 L 1 g
F
P
p
.43312 .51767 m .43308 .51639 L .43296 .51941 L 1 g
F
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44554 .52849 m .43296 .51941 L p
.44962 .49261 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43261 .52858 L p
1 g
F P
s
P
p
.43308 .51639 m .43287 .51061 L .43261 .52858 L 1 g
F
P
p
.43558 .53841 m .43447 .5362 L .43764 .5452 L 1 g
F
P
p
.002 w
.42641 .51469 m .42896 .51653 L p
.43365 .55362 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43838 .5473 L p
1 g
F P
s
P
p
.43447 .5362 m .43146 .53025 L .43838 .5473 L 1 g
F
P
p
.44419 .55497 m .44261 .5536 L .44616 .55758 L 1 g
F
P
p
.002 w
.46611 .5639 m .44616 .55758 L p
.44554 .52849 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45088 .56286 L p
1 g
F P
s
P
p
.44261 .5536 m .43743 .5491 L .45088 .56286 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46825 .57482 L p
1 g
F P
s
P
p
.46008 .5692 m .45002 .56518 L .46825 .57482 L 1 g
F
P
p
.002 w
.43365 .55362 m .44069 .55585 L p
.46529 .5874 L 1 g
F P
s
P
p
.002 w
.6419 .46413 m .63601 .41258 L .65764 .40238 L p
1 g
F P
s
P
p
.002 w
.63222 .34932 m .65764 .40238 L .63601 .41258 L p
1 g
F P
s
P
p
.002 w
.37587 .47385 m .38603 .50614 L .36362 .51408 L p
1 g
F P
s
P
p
.002 w
.36362 .51408 m .35062 .47309 L .37587 .47385 L p
1 g
F P
s
P
p
.002 w
.52852 .30398 m .47631 .29712 L .47886 .2731 L p
1 g
F P
s
P
p
.002 w
.47886 .2731 m .53735 .2807 L .52852 .30398 L p
1 g
F P
s
P
p
.002 w
.37667 .44017 m .37587 .47385 L .35062 .47309 L p
1 g
F P
s
P
p
.002 w
.35062 .47309 m .35151 .43024 L .37667 .44017 L p
1 g
F P
s
P
p
.002 w
.63601 .41258 m .61323 .36523 L .63222 .34932 L p
1 g
F P
s
P
p
.002 w
.59053 .30711 m .63222 .34932 L .61323 .36523 L p
1 g
F P
s
P
p
.002 w
.58228 .54592 m .60514 .50953 L .6305 .51405 L p
1 g
F P
s
P
p
.002 w
.6419 .46413 m .6305 .51405 L .60514 .50953 L p
1 g
F P
s
P
p
.002 w
.57599 .32757 m .52852 .30398 L .53735 .2807 L p
1 g
F P
s
P
p
.002 w
.53735 .2807 m .59053 .30711 L .57599 .32757 L p
1 g
F P
s
P
p
.002 w
.61323 .36523 m .57599 .32757 L .59053 .30711 L p
1 g
F P
s
P
p
.002 w
.43127 .33473 m .39393 .35699 L .38131 .33406 L p
1 g
F P
s
P
p
.002 w
.38131 .33406 m .42534 .30762 L .43127 .33473 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.38848 .40868 m .37667 .44017 L .35151 .43024 L p
1 g
F P
s
P
p
.002 w
.35151 .43024 m .36641 .39008 L .38848 .40868 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.60514 .50953 m .61465 .46723 L .6419 .46413 L p
1 g
F P
s
P
p
.002 w
.63601 .41258 m .6419 .46413 L .61465 .46723 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.47441 .32596 m .43127 .33473 L .42534 .30762 L p
1 g
F P
s
P
p
.002 w
.42534 .30762 m .47631 .29712 L .47441 .32596 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.43365 .55362 m .406 .53368 L .42641 .51469 L p
1 g
F P
s
P
p
.002 w
.41016 .38282 m .38848 .40868 L .36641 .39008 L p
1 g
F P
s
P
p
.002 w
.36641 .39008 m .39393 .35699 L .41016 .38282 L p
1 g
F P
s
P
p
.002 w
.41263 .49562 m .42641 .51469 L .406 .53368 L p
1 g
F P
s
P
p
.002 w
.406 .53368 m .38603 .50614 L .41263 .49562 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44554 .52849 m .468 .53557 L .46611 .5639 L p
1 g
F P
s
P
p
.002 w
.5 .5634 m .46611 .5639 L .468 .53557 L p
1 g
F P
s
P
p
.002 w
.61465 .46723 m .60954 .42363 L .63601 .41258 L p
1 g
F P
s
P
p
.002 w
.61323 .36523 m .63601 .41258 L .60954 .42363 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40566 .4733 m .41263 .49562 L .38603 .50614 L p
1 g
F P
s
P
p
.002 w
.38603 .50614 m .37587 .47385 L .40566 .4733 L p
1 g
F P
s
P
p
.002 w
.51855 .33184 m .47441 .32596 L .47631 .29712 L p
1 g
F P
s
P
p
.002 w
.47631 .29712 m .52852 .30398 L .51855 .33184 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.468 .53557 m .49142 .53518 L .5 .5634 L p
1 g
F P
s
P
p
.002 w
.53177 .55209 m .5 .5634 L .49142 .53518 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.61465 .46723 m .60514 .50953 L .57582 .50245 L p
1 g
F P
s
P
p
.002 w
.40629 .45006 m .40566 .4733 L .37587 .47385 L p
1 g
F P
s
P
p
.002 w
.37587 .47385 m .37667 .44017 L .40629 .45006 L p
1 g
F P
s
P
p
.002 w
.60954 .42363 m .59019 .38363 L .61323 .36523 L p
1 g
F P
s
P
p
.002 w
.57599 .32757 m .61323 .36523 L .59019 .38363 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.55868 .35181 m .51855 .33184 L .52852 .30398 L p
1 g
F P
s
P
p
.002 w
.52852 .30398 m .57599 .32757 L .55868 .35181 L p
1 g
F P
s
P
p
.002 w
.43948 .36549 m .41016 .38282 L .39393 .35699 L p
1 g
F P
s
P
p
.002 w
.39393 .35699 m .43127 .33473 L .43948 .36549 L p
1 g
F P
s
P
p
.002 w
.59019 .38363 m .55868 .35181 L .57599 .32757 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.49142 .53518 m .51332 .5273 L .53177 .55209 L p
1 g
F P
s
P
p
.002 w
.55801 .53106 m .53177 .55209 L .51332 .5273 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41452 .42839 m .40629 .45006 L .37667 .44017 L p
1 g
F P
s
P
p
.002 w
.37667 .44017 m .38848 .40868 L .41452 .42839 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57582 .50245 m .58314 .46927 L .61465 .46723 L p
1 g
F P
s
P
p
.002 w
.60954 .42363 m .61465 .46723 L .58314 .46927 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47327 .35873 m .43948 .36549 L .43127 .33473 L p
1 g
F P
s
P
p
.002 w
.43127 .33473 m .47441 .32596 L .47327 .35873 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.51332 .5273 m .53135 .51273 L .55801 .53106 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42953 .41066 m .41452 .42839 L .38848 .40868 L p
1 g
F P
s
P
p
.002 w
.38848 .40868 m .41016 .38282 L .42953 .41066 L p
1 g
F P
s
P
p
.002 w
.44962 .49261 m .45942 .49968 L .44554 .52849 L p
1 g
F P
s
P
p
.002 w
.468 .53557 m .44554 .52849 L .45942 .49968 L p
1 g
F P
s
P
p
.002 w
.42641 .51469 m .41263 .49562 L .44257 .48283 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45942 .49968 m .47093 .50329 L .468 .53557 L p
1 g
F P
s
P
p
.002 w
.49142 .53518 m .468 .53557 L .47093 .50329 L p
1 g
F P
s
P
p
.002 w
.58314 .46927 m .57903 .43515 L .60954 .42363 L p
1 g
F P
s
P
p
.002 w
.59019 .38363 m .60954 .42363 L .57903 .43515 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.43904 .4714 m .44257 .48283 L .41263 .49562 L p
1 g
F P
s
P
p
.002 w
.41263 .49562 m .40566 .4733 L .43904 .4714 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.50779 .3634 m .47327 .35873 L .47441 .32596 L p
1 g
F P
s
P
p
.002 w
.47441 .32596 m .51855 .33184 L .50779 .3634 L p
1 g
F P
s
P
p
.002 w
.47093 .50329 m .48291 .50306 L .49142 .53518 L p
1 g
F P
s
P
p
.002 w
.51332 .5273 m .49142 .53518 L .48291 .50306 L p
1 g
F P
s
P
p
.002 w
.43941 .45952 m .43904 .4714 L .40566 .4733 L p
1 g
F P
s
P
p
.002 w
.40566 .4733 m .40629 .45006 L .43941 .45952 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.44973 .39884 m .42953 .41066 L .41016 .38282 L p
1 g
F P
s
P
p
.002 w
.41016 .38282 m .43948 .36549 L .44973 .39884 L p
1 g
F P
s
P
p
.002 w
.57903 .43515 m .56382 .40389 L .59019 .38363 L p
1 g
F P
s
P
p
.002 w
.55868 .35181 m .59019 .38363 L .56382 .40389 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.53916 .37904 m .50779 .3634 L .51855 .33184 L p
1 g
F P
s
P
p
.002 w
.51855 .33184 m .55868 .35181 L .53916 .37904 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.56382 .40389 m .53916 .37904 L .55868 .35181 L p
1 g
F P
s
P
p
.002 w
.48291 .50306 m .4941 .49899 L .51332 .5273 L p
1 g
F P
s
P
p
.002 w
.53135 .51273 m .51332 .5273 L .4941 .49899 L p
1 g
F P
s
P
p
.002 w
.44367 .44849 m .43941 .45952 L .40629 .45006 L p
1 g
F P
s
P
p
.002 w
.40629 .45006 m .41452 .42839 L .44367 .44849 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57903 .43515 m .58314 .46927 L .54846 .47014 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47294 .39428 m .44973 .39884 L .43948 .36549 L p
1 g
F P
s
P
p
.002 w
.43948 .36549 m .47327 .35873 L .47294 .39428 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.4941 .49899 m .50326 .49151 L .53135 .51273 L p
1 g
F P
s
P
p
.002 w
.54352 .49297 m .53135 .51273 L .50326 .49151 L p
1 g
F P
s
P
p
.002 w
.45135 .43949 m .44367 .44849 L .41452 .42839 L p
1 g
F P
s
P
p
.002 w
.41452 .42839 m .42953 .41066 L .45135 .43949 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54846 .47014 m .54555 .44672 L .57903 .43515 L p
1 g
F P
s
P
p
.002 w
.56382 .40389 m .57903 .43515 L .54555 .44672 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.44257 .48283 m .43904 .4714 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.49662 .39753 m .47294 .39428 L .47327 .35873 L p
1 g
F P
s
P
p
.002 w
.47327 .35873 m .50779 .3634 L .49662 .39753 L p
1 g
F P
s
P
p
.002 w
.50326 .49151 m .50942 .48141 L .54352 .49297 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.43904 .4714 m .43941 .45952 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.46166 .43352 m .45135 .43949 L .42953 .41066 L p
1 g
F P
s
P
p
.002 w
.42953 .41066 m .44973 .39884 L .46166 .43352 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54555 .44672 m .53506 .4253 L .56382 .40389 L p
1 g
F P
s
P
p
.002 w
.53916 .37904 m .56382 .40389 L .53506 .4253 L p
1 g
F P
s
P
p
.002 w
.51813 .40827 m .49662 .39753 L .50779 .3634 L p
1 g
F P
s
P
p
.002 w
.50779 .3634 m .53916 .37904 L .51813 .40827 L p
1 g
F P
s
P
p
.002 w
.43941 .45952 m .44367 .44849 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.53506 .4253 m .51813 .40827 L .53916 .37904 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.47346 .43125 m .46166 .43352 L .44973 .39884 L p
1 g
F P
s
P
p
.002 w
.44973 .39884 m .47294 .39428 L .47346 .43125 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.44367 .44849 m .45135 .43949 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45135 .43949 m .46166 .43352 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.53506 .4253 m .54555 .44672 L .51035 .45788 L p
1 g
F P
s
P
p
.002 w
.4964 .43838 m .505 .44702 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.48548 .43292 m .4964 .43838 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.004 w
.49516 .43776 m
.5 .43051 L
s
P
p
.002 w
.47346 .43125 m .48548 .43292 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.46166 .43352 m .47346 .43125 L .47482 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.48548 .43292 m .47346 .43125 L .47294 .39428 L p
1 g
F P
s
P
p
.002 w
.47294 .39428 m .49662 .39753 L .48548 .43292 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51035 .45788 m .505 .44702 L .53506 .4253 L p
1 g
F P
s
P
p
.002 w
.51813 .40827 m .53506 .4253 L .505 .44702 L p
1 g
F P
s
P
p
.002 w
.4964 .43838 m .48548 .43292 L .49662 .39753 L p
1 g
F P
s
P
p
.002 w
.49662 .39753 m .51813 .40827 L .4964 .43838 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.505 .44702 m .4964 .43838 L .51813 .40827 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.45921 .49155 m
.47482 .46819 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .23488 .54317 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .45921 .49155 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0488372)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0488372)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4957 .46083 m .51365 .45629 L .50229 .43015 L p
1 g
F P
s
P
p
.002 w
.50229 .43015 m .49321 .43244 L .4957 .46083 L p
1 g
F P
s
P
p
.002 w
.51015 .42506 m .50229 .43015 L .51365 .45629 L p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .49321 .43244 L .50229 .43015 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .50229 .43015 L .51015 .42506 L closepath p
1 g
F P
s
P
p
.002 w
.47726 .45939 m .4957 .46083 L .49321 .43244 L p
1 g
F P
s
P
p
.002 w
.49321 .43244 m .48388 .4317 L .47726 .45939 L p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .48388 .4317 L .49321 .43244 L closepath p
1 g
F P
s
P
p
.002 w
.51365 .45629 m .5292 .44625 L .51015 .42506 L p
1 g
F P
s
P
p
.002 w
.51595 .41773 m .51015 .42506 L .5292 .44625 L p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .51015 .42506 L .51595 .41773 L closepath p
1 g
F P
s
P
p
.002 w
.4603 .45211 m .47726 .45939 L .48388 .4317 L p
1 g
F P
s
P
p
.002 w
.48388 .4317 m .47531 .428 L .4603 .45211 L p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .47531 .428 L .48388 .4317 L closepath p
1 g
F P
s
P
p
.002 w
.5292 .44625 m .54068 .43177 L .51595 .41773 L p
1 g
F P
s
P
p
.002 w
.51905 .40894 m .51595 .41773 L .54068 .43177 L p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .51595 .41773 L .51905 .40894 L closepath p
1 g
F P
s
P
p
.002 w
.44664 .43975 m .4603 .45211 L .47531 .428 L p
1 g
F P
s
P
p
.002 w
.47531 .428 m .46842 .42174 L .44664 .43975 L p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .46842 .42174 L .47531 .428 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .46397 .41357 L .46842 .42174 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .51905 .40894 L .51912 .39963 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .51912 .39963 L .51614 .39082 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .51614 .39082 L .51042 .38346 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .51042 .38346 L .50259 .37835 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .50259 .37835 L .49348 .37606 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .49348 .37606 L .48409 .37684 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .48409 .37684 L .47545 .38061 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .47545 .38061 L .4685 .38695 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .4685 .38695 L .464 .39518 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .464 .39518 L .46244 .40439 L closepath p
1 g
F P
s
P
p
.002 w
.49088 .40402 m .46244 .40439 L .46397 .41357 L closepath p
1 g
F P
s
P
p
.002 w
.54068 .43177 m .54686 .4144 L .51905 .40894 L p
1 g
F P
s
P
p
.002 w
.51912 .39963 m .51905 .40894 L .54686 .4144 L p
1 g
F P
s
P
p
.002 w
.49832 .48867 m .52475 .48197 L .51365 .45629 L p
1 g
F P
s
P
p
.002 w
.51365 .45629 m .4957 .46083 L .49832 .48867 L p
1 g
F P
s
P
p
.002 w
.5292 .44625 m .51365 .45629 L .52475 .48197 L p
1 g
F P
s
P
p
.002 w
.47115 .48659 m .49832 .48867 L .4957 .46083 L p
1 g
F P
s
P
p
.002 w
.4957 .46083 m .47726 .45939 L .47115 .48659 L p
1 g
F P
s
P
p
.002 w
.43777 .4236 m .44664 .43975 L .46842 .42174 L p
1 g
F P
s
P
p
.002 w
.46842 .42174 m .46397 .41357 L .43777 .4236 L p
1 g
F P
s
P
p
.002 w
.52475 .48197 m .54767 .4672 L .5292 .44625 L p
1 g
F P
s
P
p
.002 w
.54068 .43177 m .5292 .44625 L .54767 .4672 L p
1 g
F P
s
P
p
.002 w
.54686 .4144 m .54706 .39597 L .51912 .39963 L p
1 g
F P
s
P
p
.002 w
.51614 .39082 m .51912 .39963 L .54706 .39597 L p
1 g
F P
s
P
p
.002 w
.44613 .47591 m .47115 .48659 L .47726 .45939 L p
1 g
F P
s
P
p
.002 w
.47726 .45939 m .4603 .45211 L .44613 .47591 L p
1 g
F P
s
P
p
.002 w
.43468 .4054 m .43777 .4236 L .46397 .41357 L p
1 g
F P
s
P
p
.002 w
.46397 .41357 m .46244 .40439 L .43468 .4054 L p
1 g
F P
s
P
p
.002 w
.54767 .4672 m .56462 .44589 L .54068 .43177 L p
1 g
F P
s
P
p
.002 w
.54686 .4144 m .54068 .43177 L .56462 .44589 L p
1 g
F P
s
P
p
.002 w
.54706 .39597 m .5412 .37849 L .51614 .39082 L p
1 g
F P
s
P
p
.002 w
.51042 .38346 m .51614 .39082 L .5412 .37849 L p
1 g
F P
s
P
p
.002 w
.42593 .45772 m .44613 .47591 L .4603 .45211 L p
1 g
F P
s
P
p
.002 w
.4603 .45211 m .44664 .43975 L .42593 .45772 L p
1 g
F P
s
P
p
.002 w
.43773 .38712 m .43468 .4054 L .46244 .40439 L p
1 g
F P
s
P
p
.002 w
.46244 .40439 m .464 .39518 L .43773 .38712 L p
1 g
F P
s
P
p
.002 w
.5412 .37849 m .5299 .36385 L .51042 .38346 L p
1 g
F P
s
P
p
.002 w
.50259 .37835 m .51042 .38346 L .5299 .36385 L p
1 g
F P
s
P
p
.002 w
.56462 .44589 m .5738 .4203 L .54686 .4144 L p
1 g
F P
s
P
p
.002 w
.54706 .39597 m .54686 .4144 L .5738 .4203 L p
1 g
F P
s
P
p
.002 w
.44664 .37076 m .43773 .38712 L .464 .39518 L p
1 g
F P
s
P
p
.002 w
.464 .39518 m .4685 .38695 L .44664 .37076 L p
1 g
F P
s
P
p
.002 w
.5299 .36385 m .51436 .35367 L .50259 .37835 L p
1 g
F P
s
P
p
.002 w
.49348 .37606 m .50259 .37835 L .51436 .35367 L p
1 g
F P
s
P
p
.002 w
.46043 .35813 m .44664 .37076 L .4685 .38695 L p
1 g
F P
s
P
p
.002 w
.4685 .38695 m .47545 .38061 L .46043 .35813 L p
1 g
F P
s
P
p
.002 w
.41277 .43392 m .42593 .45772 L .44664 .43975 L p
1 g
F P
s
P
p
.002 w
.44664 .43975 m .43777 .4236 L .41277 .43392 L p
1 g
F P
s
P
p
.002 w
.51436 .35367 m .49627 .34909 L .49348 .37606 L p
1 g
F P
s
P
p
.002 w
.48409 .37684 m .49348 .37606 L .49627 .34909 L p
1 g
F P
s
P
p
.002 w
.4776 .35063 m .46043 .35813 L .47545 .38061 L p
1 g
F P
s
P
p
.002 w
.47545 .38061 m .48409 .37684 L .4776 .35063 L p
1 g
F P
s
P
p
.002 w
.49627 .34909 m .4776 .35063 L .48409 .37684 L p
1 g
F P
s
P
p
.002 w
.50101 .51545 m .53539 .50672 L .52475 .48197 L p
1 g
F P
s
P
p
.002 w
.52475 .48197 m .49832 .48867 L .50101 .51545 L p
1 g
F P
s
P
p
.002 w
.54767 .4672 m .52475 .48197 L .53539 .50672 L p
1 g
F P
s
P
p
.002 w
.46566 .51278 m .50101 .51545 L .49832 .48867 L p
1 g
F P
s
P
p
.002 w
.49832 .48867 m .47115 .48659 L .46566 .51278 L p
1 g
F P
s
P
p
.002 w
.5738 .4203 m .57416 .39312 L .54706 .39597 L p
1 g
F P
s
P
p
.002 w
.5412 .37849 m .54706 .39597 L .57416 .39312 L p
1 g
F P
s
P
p
.002 w
.53539 .50672 m .56521 .48753 L .54767 .4672 L p
1 g
F P
s
P
p
.002 w
.56462 .44589 m .54767 .4672 L .56521 .48753 L p
1 g
F P
s
P
p
.002 w
.40812 .40704 m .41277 .43392 L .43777 .4236 L p
1 g
F P
s
P
p
.002 w
.43777 .4236 m .43468 .4054 L .40812 .40704 L p
1 g
F P
s
P
p
.002 w
.43307 .49894 m .46566 .51278 L .47115 .48659 L p
1 g
F P
s
P
p
.002 w
.47115 .48659 m .44613 .47591 L .43307 .49894 L p
1 g
F P
s
P
p
.002 w
.57416 .39312 m .56558 .36727 L .5412 .37849 L p
1 g
F P
s
P
p
.002 w
.5299 .36385 m .5412 .37849 L .56558 .36727 L p
1 g
F P
s
P
p
.002 w
.56521 .48753 m .58732 .45984 L .56462 .44589 L p
1 g
F P
s
P
p
.002 w
.5738 .4203 m .56462 .44589 L .58732 .45984 L p
1 g
F P
s
P
p
.002 w
.41257 .37999 m .40812 .40704 L .43468 .4054 L p
1 g
F P
s
P
p
.002 w
.43468 .4054 m .43773 .38712 L .41257 .37999 L p
1 g
F P
s
P
p
.002 w
.4067 .47532 m .43307 .49894 L .44613 .47591 L p
1 g
F P
s
P
p
.002 w
.44613 .47591 m .42593 .45772 L .4067 .47532 L p
1 g
F P
s
P
p
.002 w
.56558 .36727 m .54894 .34559 L .5299 .36385 L p
1 g
F P
s
P
p
.002 w
.51436 .35367 m .5299 .36385 L .54894 .34559 L p
1 g
F P
s
P
p
.002 w
.58732 .45984 m .59934 .42655 L .5738 .4203 L p
1 g
F P
s
P
p
.002 w
.57416 .39312 m .5738 .4203 L .59934 .42655 L p
1 g
F P
s
P
p
.002 w
.4257 .35576 m .41257 .37999 L .43773 .38712 L p
1 g
F P
s
P
p
.002 w
.43773 .38712 m .44664 .37076 L .4257 .35576 L p
1 g
F P
s
P
p
.002 w
.54894 .34559 m .52598 .33048 L .51436 .35367 L p
1 g
F P
s
P
p
.002 w
.49627 .34909 m .51436 .35367 L .52598 .33048 L p
1 g
F P
s
P
p
.002 w
.38946 .44435 m .4067 .47532 L .42593 .45772 L p
1 g
F P
s
P
p
.002 w
.42593 .45772 m .41277 .43392 L .38946 .44435 L p
1 g
F P
s
P
p
.002 w
.44611 .33703 m .4257 .35576 L .44664 .37076 L p
1 g
F P
s
P
p
.002 w
.44664 .37076 m .46043 .35813 L .44611 .33703 L p
1 g
F P
s
P
p
.002 w
.52598 .33048 m .4992 .32365 L .49627 .34909 L p
1 g
F P
s
P
p
.002 w
.4776 .35063 m .49627 .34909 L .4992 .32365 L p
1 g
F P
s
P
p
.002 w
.47155 .32591 m .44611 .33703 L .46043 .35813 L p
1 g
F P
s
P
p
.002 w
.46043 .35813 m .4776 .35063 L .47155 .32591 L p
1 g
F P
s
P
p
.002 w
.4992 .32365 m .47155 .32591 L .4776 .35063 L p
1 g
F P
s
P
p
.002 w
.59934 .42655 m .5999 .39114 L .57416 .39312 L p
1 g
F P
s
P
p
.002 w
.56558 .36727 m .57416 .39312 L .5999 .39114 L p
1 g
F P
s
P
p
.002 w
.50373 .54063 m .54536 .53006 L .53539 .50672 L p
1 g
F P
s
P
p
.002 w
.53539 .50672 m .50101 .51545 L .50373 .54063 L p
1 g
F P
s
P
p
.002 w
.56521 .48753 m .53539 .50672 L .54536 .53006 L p
1 g
F P
s
P
p
.002 w
.46092 .53745 m .50373 .54063 L .50101 .51545 L p
1 g
F P
s
P
p
.002 w
.50101 .51545 m .46566 .51278 L .46092 .53745 L p
1 g
F P
s
P
p
.002 w
.54536 .53006 m .58148 .50684 L .56521 .48753 L p
1 g
F P
s
P
p
.002 w
.58732 .45984 m .56521 .48753 L .58148 .50684 L p
1 g
F P
s
P
p
.002 w
.3833 .4093 m .38946 .44435 L .41277 .43392 L p
1 g
F P
s
P
p
.002 w
.41277 .43392 m .40812 .40704 L .3833 .4093 L p
1 g
F P
s
P
p
.002 w
.4214 .52075 m .46092 .53745 L .46566 .51278 L p
1 g
F P
s
P
p
.002 w
.46566 .51278 m .43307 .49894 L .4214 .52075 L p
1 g
F P
s
P
p
.002 w
.5999 .39114 m .58882 .35741 L .56558 .36727 L p
1 g
F P
s
P
p
.002 w
.54894 .34559 m .56558 .36727 L .58882 .35741 L p
1 g
F P
s
P
p
.002 w
.58148 .50684 m .60831 .47335 L .58732 .45984 L p
1 g
F P
s
P
p
.002 w
.59934 .42655 m .58732 .45984 L .60831 .47335 L p
1 g
F P
s
P
p
.002 w
.38904 .37397 m .3833 .4093 L .40812 .40704 L p
1 g
F P
s
P
p
.002 w
.40812 .40704 m .41257 .37999 L .38904 .37397 L p
1 g
F P
s
P
p
.002 w
.38938 .49219 m .4214 .52075 L .43307 .49894 L p
1 g
F P
s
P
p
.002 w
.43307 .49894 m .4067 .47532 L .38938 .49219 L p
1 g
F P
s
P
p
.002 w
.58882 .35741 m .56716 .32905 L .54894 .34559 L p
1 g
F P
s
P
p
.002 w
.52598 .33048 m .54894 .34559 L .56716 .32905 L p
1 g
F P
s
P
p
.002 w
.60831 .47335 m .62296 .43303 L .59934 .42655 L p
1 g
F P
s
P
p
.002 w
.5999 .39114 m .59934 .42655 L .62296 .43303 L p
1 g
F P
s
P
p
.002 w
.40614 .34227 m .38904 .37397 L .41257 .37999 L p
1 g
F P
s
P
p
.002 w
.41257 .37999 m .4257 .35576 L .40614 .34227 L p
1 g
F P
s
P
p
.002 w
.56716 .32905 m .53722 .30925 L .52598 .33048 L p
1 g
F P
s
P
p
.002 w
.4992 .32365 m .52598 .33048 L .53722 .30925 L p
1 g
F P
s
P
p
.002 w
.36836 .45468 m .38938 .49219 L .4067 .47532 L p
1 g
F P
s
P
p
.002 w
.4067 .47532 m .38946 .44435 L .36836 .45468 L p
1 g
F P
s
P
p
.002 w
.4328 .31776 m .40614 .34227 L .4257 .35576 L p
1 g
F P
s
P
p
.002 w
.4257 .35576 m .44611 .33703 L .4328 .31776 L p
1 g
F P
s
P
p
.002 w
.53722 .30925 m .50222 .30028 L .4992 .32365 L p
1 g
F P
s
P
p
.002 w
.47155 .32591 m .4992 .32365 L .50222 .30028 L p
1 g
F P
s
P
p
.002 w
.62296 .43303 m .62374 .39009 L .5999 .39114 L p
1 g
F P
s
P
p
.002 w
.58882 .35741 m .5999 .39114 L .62374 .39009 L p
1 g
F P
s
P
p
.002 w
.46607 .30321 m .4328 .31776 L .44611 .33703 L p
1 g
F P
s
P
p
.002 w
.44611 .33703 m .47155 .32591 L .46607 .30321 L p
1 g
F P
s
P
p
.002 w
.50222 .30028 m .46607 .30321 L .47155 .32591 L p
1 g
F P
s
P
p
.002 w
.50642 .56368 m .55443 .55147 L .54536 .53006 L p
1 g
F P
s
P
p
.002 w
.54536 .53006 m .50373 .54063 L .50642 .56368 L p
1 g
F P
s
P
p
.002 w
.58148 .50684 m .54536 .53006 L .55443 .55147 L p
1 g
F P
s
P
p
.002 w
.45704 .56005 m .50642 .56368 L .50373 .54063 L p
1 g
F P
s
P
p
.002 w
.50373 .54063 m .46092 .53745 L .45704 .56005 L p
1 g
F P
s
P
p
.002 w
.36078 .41215 m .36836 .45468 L .38946 .44435 L p
1 g
F P
s
P
p
.002 w
.38946 .44435 m .3833 .4093 L .36078 .41215 L p
1 g
F P
s
P
p
.002 w
.55443 .55147 m .59611 .52471 L .58148 .50684 L p
1 g
F P
s
P
p
.002 w
.60831 .47335 m .58148 .50684 L .59611 .52471 L p
1 g
F P
s
P
p
.002 w
.41141 .54087 m .45704 .56005 L .46092 .53745 L p
1 g
F P
s
P
p
.002 w
.46092 .53745 m .4214 .52075 L .41141 .54087 L p
1 g
F P
s
P
p
.002 w
.62374 .39009 m .6104 .34913 L .58882 .35741 L p
1 g
F P
s
P
p
.002 w
.56716 .32905 m .58882 .35741 L .6104 .34913 L p
1 g
F P
s
P
p
.002 w
.59611 .52471 m .62711 .48612 L .60831 .47335 L p
1 g
F P
s
P
p
.002 w
.62296 .43303 m .60831 .47335 L .62711 .48612 L p
1 g
F P
s
P
p
.002 w
.36766 .36921 m .36078 .41215 L .3833 .4093 L p
1 g
F P
s
P
p
.002 w
.3833 .4093 m .38904 .37397 L .36766 .36921 L p
1 g
F P
s
P
p
.002 w
.37437 .50798 m .41141 .54087 L .4214 .52075 L p
1 g
F P
s
P
p
.002 w
.4214 .52075 m .38938 .49219 L .37437 .50798 L p
1 g
F P
s
P
p
.002 w
.6104 .34913 m .58418 .31463 L .56716 .32905 L p
1 g
F P
s
P
p
.002 w
.53722 .30925 m .56716 .32905 L .58418 .31463 L p
1 g
F P
s
P
p
.002 w
.62711 .48612 m .64411 .43962 L .62296 .43303 L p
1 g
F P
s
P
p
.002 w
.62374 .39009 m .62296 .43303 L .64411 .43962 L p
1 g
F P
s
P
p
.002 w
.3884 .33063 m .36766 .36921 L .38904 .37397 L p
1 g
F P
s
P
p
.002 w
.38904 .37397 m .40614 .34227 L .3884 .33063 L p
1 g
F P
s
P
p
.002 w
.35 .4647 m .37437 .50798 L .38938 .49219 L p
1 g
F P
s
P
p
.002 w
.38938 .49219 m .36836 .45468 L .35 .4647 L p
1 g
F P
s
P
p
.002 w
.58418 .31463 m .54782 .2905 L .53722 .30925 L p
1 g
F P
s
P
p
.002 w
.50222 .30028 m .53722 .30925 L .54782 .2905 L p
1 g
F P
s
P
p
.002 w
.4208 .30078 m .3884 .33063 L .40614 .34227 L p
1 g
F P
s
P
p
.002 w
.40614 .34227 m .4328 .31776 L .4208 .30078 L p
1 g
F P
s
P
p
.002 w
.64411 .43962 m .64512 .39005 L .62374 .39009 L p
1 g
F P
s
P
p
.002 w
.6104 .34913 m .62374 .39009 L .64512 .39005 L p
1 g
F P
s
P
p
.002 w
.54782 .2905 m .50528 .27953 L .50222 .30028 L p
1 g
F P
s
P
p
.002 w
.46607 .30321 m .50222 .30028 L .50528 .27953 L p
1 g
F P
s
P
p
.002 w
.46128 .28308 m .4208 .30078 L .4328 .31776 L p
1 g
F P
s
P
p
.002 w
.4328 .31776 m .46607 .30321 L .46128 .28308 L p
1 g
F P
s
P
p
.002 w
.50528 .27953 m .46128 .28308 L .46607 .30321 L p
1 g
F P
s
P
p
.002 w
.50903 .58402 m .56239 .57044 L .55443 .55147 L p
1 g
F P
s
P
p
.002 w
.55443 .55147 m .50642 .56368 L .50903 .58402 L p
1 g
F P
s
P
p
.002 w
.59611 .52471 m .55443 .55147 L .56239 .57044 L p
1 g
F P
s
P
p
.002 w
.45413 .58004 m .50903 .58402 L .50642 .56368 L p
1 g
F P
s
P
p
.002 w
.50642 .56368 m .45704 .56005 L .45413 .58004 L p
1 g
F P
s
P
p
.002 w
.34113 .41556 m .35 .4647 L .36836 .45468 L p
1 g
F P
s
P
p
.002 w
.36836 .45468 m .36078 .41215 L .34113 .41556 L p
1 g
F P
s
P
p
.002 w
.56239 .57044 m .60873 .54073 L .59611 .52471 L p
1 g
F P
s
P
p
.002 w
.62711 .48612 m .59611 .52471 L .60873 .54073 L p
1 g
F P
s
P
p
.002 w
.40337 .55878 m .45413 .58004 L .45704 .56005 L p
1 g
F P
s
P
p
.002 w
.45704 .56005 m .41141 .54087 L .40337 .55878 L p
1 g
F P
s
P
p
.002 w
.64512 .39005 m .62981 .34268 L .6104 .34913 L p
1 g
F P
s
P
p
.002 w
.58418 .31463 m .6104 .34913 L .62981 .34268 L p
1 g
F P
s
P
p
.002 w
.60873 .54073 m .64324 .49786 L .62711 .48612 L p
1 g
F P
s
P
p
.002 w
.64411 .43962 m .62711 .48612 L .64324 .49786 L p
1 g
F P
s
P
p
.002 w
.34899 .36588 m .34113 .41556 L .36078 .41215 L p
1 g
F P
s
P
p
.002 w
.36078 .41215 m .36766 .36921 L .34899 .36588 L p
1 g
F P
s
P
p
.002 w
.36211 .52228 m .40337 .55878 L .41141 .54087 L p
1 g
F P
s
P
p
.002 w
.41141 .54087 m .37437 .50798 L .36211 .52228 L p
1 g
F P
s
P
p
.002 w
.62981 .34268 m .59958 .30273 L .58418 .31463 L p
1 g
F P
s
P
p
.002 w
.54782 .2905 m .58418 .31463 L .59958 .30273 L p
1 g
F P
s
P
p
.002 w
.64324 .49786 m .66223 .44619 L .64411 .43962 L p
1 g
F P
s
P
p
.002 w
.64512 .39005 m .64411 .43962 L .66223 .44619 L p
1 g
F P
s
P
p
.002 w
.37294 .32119 m .34899 .36588 L .36766 .36921 L p
1 g
F P
s
P
p
.002 w
.36766 .36921 m .3884 .33063 L .37294 .32119 L p
1 g
F P
s
P
p
.002 w
.3349 .47417 m .36211 .52228 L .37437 .50798 L p
1 g
F P
s
P
p
.002 w
.37437 .50798 m .35 .4647 L .3349 .47417 L p
1 g
F P
s
P
p
.002 w
.59958 .30273 m .55755 .27473 L .54782 .2905 L p
1 g
F P
s
P
p
.002 w
.50528 .27953 m .54782 .2905 L .55755 .27473 L p
1 g
F P
s
P
p
.002 w
.41044 .28659 m .37294 .32119 L .3884 .33063 L p
1 g
F P
s
P
p
.002 w
.3884 .33063 m .4208 .30078 L .41044 .28659 L p
1 g
F P
s
P
p
.002 w
.66223 .44619 m .66346 .39105 L .64512 .39005 L p
1 g
F P
s
P
p
.002 w
.62981 .34268 m .64512 .39005 L .66346 .39105 L p
1 g
F P
s
P
p
.002 w
.55755 .27473 m .5083 .26199 L .50528 .27953 L p
1 g
F P
s
P
p
.002 w
.46128 .28308 m .50528 .27953 L .5083 .26199 L p
1 g
F P
s
P
p
.002 w
.45734 .26607 m .41044 .28659 L .4208 .30078 L p
1 g
F P
s
P
p
.002 w
.4208 .30078 m .46128 .28308 L .45734 .26607 L p
1 g
F P
s
P
p
.002 w
.5083 .26199 m .45734 .26607 L .46128 .28308 L p
1 g
F P
s
P
p
.002 w
.51149 .60109 m .569 .58644 L .56239 .57044 L p
1 g
F P
s
P
p
.002 w
.56239 .57044 m .50903 .58402 L .51149 .60109 L p
1 g
F P
s
P
p
.002 w
.60873 .54073 m .56239 .57044 L .569 .58644 L p
1 g
F P
s
P
p
.002 w
.45232 .59684 m .51149 .60109 L .50903 .58402 L p
1 g
F P
s
P
p
.002 w
.50903 .58402 m .45413 .58004 L .45232 .59684 L p
1 g
F P
s
P
p
.002 w
.32493 .41948 m .3349 .47417 L .35 .4647 L p
1 g
F P
s
P
p
.002 w
.35 .4647 m .34113 .41556 L .32493 .41948 L p
1 g
F P
s
P
p
.002 w
.569 .58644 m .61896 .55443 L .60873 .54073 L p
1 g
F P
s
P
p
.002 w
.64324 .49786 m .60873 .54073 L .61896 .55443 L p
1 g
F P
s
P
p
.002 w
.39757 .57399 m .45232 .59684 L .45413 .58004 L p
1 g
F P
s
P
p
.002 w
.45413 .58004 m .40337 .55878 L .39757 .57399 L p
1 g
F P
s
P
p
.002 w
.66346 .39105 m .64652 .33829 L .62981 .34268 L p
1 g
F P
s
P
p
.002 w
.59958 .30273 m .62981 .34268 L .64652 .33829 L p
1 g
F P
s
P
p
.002 w
.61896 .55443 m .65622 .50827 L .64324 .49786 L p
1 g
F P
s
P
p
.002 w
.66223 .44619 m .64324 .49786 L .65622 .50827 L p
1 g
F P
s
P
p
.002 w
.33361 .36411 m .32493 .41948 L .34113 .41556 L p
1 g
F P
s
P
p
.002 w
.34113 .41556 m .34899 .36588 L .33361 .36411 L p
1 g
F P
s
P
p
.002 w
.35302 .53469 m .39757 .57399 L .40337 .55878 L p
1 g
F P
s
P
p
.002 w
.40337 .55878 m .36211 .52228 L .35302 .53469 L p
1 g
F P
s
P
p
.002 w
.64652 .33829 m .61292 .29374 L .59958 .30273 L p
1 g
F P
s
P
p
.002 w
.55755 .27473 m .59958 .30273 L .61292 .29374 L p
1 g
F P
s
P
p
.002 w
.65622 .50827 m .67676 .45259 L .66223 .44619 L p
1 g
F P
s
P
p
.002 w
.66346 .39105 m .66223 .44619 L .67676 .45259 L p
1 g
F P
s
P
p
.002 w
.36025 .31427 m .33361 .36411 L .34899 .36588 L p
1 g
F P
s
P
p
.002 w
.34899 .36588 m .37294 .32119 L .36025 .31427 L p
1 g
F P
s
P
p
.002 w
.32359 .48285 m .35302 .53469 L .36211 .52228 L p
1 g
F P
s
P
p
.002 w
.36211 .52228 m .3349 .47417 L .32359 .48285 L p
1 g
F P
s
P
p
.002 w
.61292 .29374 m .56612 .26248 L .55755 .27473 L p
1 g
F P
s
P
p
.002 w
.5083 .26199 m .55755 .27473 L .56612 .26248 L p
1 g
F P
s
P
p
.002 w
.40205 .27565 m .36025 .31427 L .37294 .32119 L p
1 g
F P
s
P
p
.002 w
.37294 .32119 m .41044 .28659 L .40205 .27565 L p
1 g
F P
s
P
p
.002 w
.67676 .45259 m .67818 .39312 L .66346 .39105 L p
1 g
F P
s
P
p
.002 w
.64652 .33829 m .66346 .39105 L .67818 .39312 L p
1 g
F P
s
P
p
.002 w
.56612 .26248 m .51122 .24822 L .5083 .26199 L p
1 g
F P
s
P
p
.002 w
.45734 .26607 m .5083 .26199 L .51122 .24822 L p
1 g
F P
s
P
p
.002 w
.45436 .25276 m .40205 .27565 L .41044 .28659 L p
1 g
F P
s
P
p
.002 w
.41044 .28659 m .45734 .26607 L .45436 .25276 L p
1 g
F P
s
P
p
.002 w
.51122 .24822 m .45436 .25276 L .45734 .26607 L p
1 g
F P
s
P
p
.002 w
.51375 .6143 m .57405 .59894 L .569 .58644 L p
1 g
F P
s
P
p
.002 w
.569 .58644 m .51149 .60109 L .51375 .6143 L p
1 g
F P
s
P
p
.002 w
.61896 .55443 m .569 .58644 L .57405 .59894 L p
1 g
F P
s
P
p
.002 w
.31275 .42385 m .32359 .48285 L .3349 .47417 L p
1 g
F P
s
P
p
.002 w
.3349 .47417 m .32493 .41948 L .31275 .42385 L p
1 g
F P
s
P
p
.002 w
.4517 .60988 m .51375 .6143 L .51149 .60109 L p
1 g
F P
s
P
p
.002 w
.51149 .60109 m .45232 .59684 L .4517 .60988 L p
1 g
F P
s
P
p
.002 w
.57405 .59894 m .62645 .56539 L .61896 .55443 L p
1 g
F P
s
P
p
.002 w
.65622 .50827 m .61896 .55443 L .62645 .56539 L p
1 g
F P
s
P
p
.002 w
.39426 .58597 m .4517 .60988 L .45232 .59684 L p
1 g
F P
s
P
p
.002 w
.45232 .59684 m .39757 .57399 L .39426 .58597 L p
1 g
F P
s
P
p
.002 w
.67818 .39312 m .65999 .33618 L .64652 .33829 L p
1 g
F P
s
P
p
.002 w
.61292 .29374 m .64652 .33829 L .65999 .33618 L p
1 g
F P
s
P
p
.002 w
.62645 .56539 m .66554 .51701 L .65622 .50827 L p
1 g
F P
s
P
p
.002 w
.67676 .45259 m .65622 .50827 L .66554 .51701 L p
1 g
F P
s
P
p
.002 w
.32205 .36406 m .31275 .42385 L .32493 .41948 L p
1 g
F P
s
P
p
.002 w
.32493 .41948 m .33361 .36411 L .32205 .36406 L p
1 g
F P
s
P
p
.002 w
.34751 .54481 m .39426 .58597 L .39757 .57399 L p
1 g
F P
s
P
p
.002 w
.39757 .57399 m .35302 .53469 L .34751 .54481 L p
1 g
F P
s
P
p
.002 w
.65999 .33618 m .62378 .28805 L .61292 .29374 L p
1 g
F P
s
P
p
.002 w
.56612 .26248 m .61292 .29374 L .62378 .28805 L p
1 g
F P
s
P
p
.002 w
.66554 .51701 m .68715 .45865 L .67676 .45259 L p
1 g
F P
s
P
p
.002 w
.67818 .39312 m .67676 .45259 L .68715 .45865 L p
1 g
F P
s
P
p
.002 w
.35079 .31019 m .32205 .36406 L .33361 .36411 L p
1 g
F P
s
P
p
.002 w
.33361 .36411 m .36025 .31427 L .35079 .31019 L p
1 g
F P
s
P
p
.002 w
.31658 .49047 m .34751 .54481 L .35302 .53469 L p
1 g
F P
s
P
p
.002 w
.35302 .53469 m .32359 .48285 L .31658 .49047 L p
1 g
F P
s
P
p
.002 w
.62378 .28805 m .57327 .25424 L .56612 .26248 L p
1 g
F P
s
P
p
.002 w
.51122 .24822 m .56612 .26248 L .57327 .25424 L p
1 g
F P
s
P
p
.002 w
.39596 .26844 m .35079 .31019 L .36025 .31427 L p
1 g
F P
s
P
p
.002 w
.36025 .31427 m .40205 .27565 L .39596 .26844 L p
1 g
F P
s
P
p
.002 w
.68715 .45865 m .68871 .39629 L .67818 .39312 L p
1 g
F P
s
P
p
.002 w
.65999 .33618 m .67818 .39312 L .68871 .39629 L p
1 g
F P
s
P
p
.002 w
.57327 .25424 m .51395 .2388 L .51122 .24822 L p
1 g
F P
s
P
p
.002 w
.45436 .25276 m .51122 .24822 L .51395 .2388 L p
1 g
F P
s
P
p
.002 w
.4525 .24369 m .39596 .26844 L .40205 .27565 L p
1 g
F P
s
P
p
.002 w
.40205 .27565 m .45436 .25276 L .4525 .24369 L p
1 g
F P
s
P
p
.002 w
.51395 .2388 m .4525 .24369 L .45436 .25276 L p
1 g
F P
s
P
p
.002 w
.51573 .6231 m .5773 .6074 L .57405 .59894 L p
1 g
F P
s
P
p
.002 w
.57405 .59894 m .51375 .6143 L .51573 .6231 L p
1 g
F P
s
P
p
.002 w
.62645 .56539 m .57405 .59894 L .5773 .6074 L p
1 g
F P
s
P
p
.002 w
.30516 .42858 m .31658 .49047 L .32359 .48285 L p
1 g
F P
s
P
p
.002 w
.32359 .48285 m .31275 .42385 L .30516 .42858 L p
1 g
F P
s
P
p
.002 w
.45236 .61861 m .51573 .6231 L .51375 .6143 L p
1 g
F P
s
P
p
.002 w
.51375 .6143 m .4517 .60988 L .45236 .61861 L p
1 g
F P
s
P
p
.002 w
.5773 .6074 m .63082 .57316 L .62645 .56539 L p
1 g
F P
s
P
p
.002 w
.66554 .51701 m .62645 .56539 L .63082 .57316 L p
1 g
F P
s
P
p
.002 w
.68871 .39629 m .66968 .33654 L .65999 .33618 L p
1 g
F P
s
P
p
.002 w
.62378 .28805 m .65999 .33618 L .66968 .33654 L p
1 g
F P
s
P
p
.002 w
.3937 .59423 m .45236 .61861 L .4517 .60988 L p
1 g
F P
s
P
p
.002 w
.4517 .60988 m .39426 .58597 L .3937 .59423 L p
1 g
F P
s
P
p
.002 w
.63082 .57316 m .67077 .52378 L .66554 .51701 L p
1 g
F P
s
P
p
.002 w
.68715 .45865 m .66554 .51701 L .67077 .52378 L p
1 g
F P
s
P
p
.002 w
.31488 .36582 m .30516 .42858 L .31275 .42385 L p
1 g
F P
s
P
p
.002 w
.31275 .42385 m .32205 .36406 L .31488 .36582 L p
1 g
F P
s
P
p
.002 w
.34594 .55224 m .3937 .59423 L .39426 .58597 L p
1 g
F P
s
P
p
.002 w
.39426 .58597 m .34751 .54481 L .34594 .55224 L p
1 g
F P
s
P
p
.002 w
.66968 .33654 m .63172 .286 L .62378 .28805 L p
1 g
F P
s
P
p
.002 w
.57327 .25424 m .62378 .28805 L .63172 .286 L p
1 g
F P
s
P
p
.002 w
.67077 .52378 m .69286 .4642 L .68715 .45865 L p
1 g
F P
s
P
p
.002 w
.68871 .39629 m .68715 .45865 L .69286 .4642 L p
1 g
F P
s
P
p
.002 w
.34503 .30924 m .31488 .36582 L .32205 .36406 L p
1 g
F P
s
P
p
.002 w
.32205 .36406 m .35079 .31019 L .34503 .30924 L p
1 g
F P
s
P
p
.002 w
.31433 .49677 m .34594 .55224 L .34751 .54481 L p
1 g
F P
s
P
p
.002 w
.34751 .54481 m .31658 .49047 L .31433 .49677 L p
1 g
F P
s
P
p
.002 w
.63172 .286 m .57872 .25048 L .57327 .25424 L p
1 g
F P
s
P
p
.002 w
.51395 .2388 m .57327 .25424 L .57872 .25048 L p
1 g
F P
s
P
p
.002 w
.39246 .26537 m .34503 .30924 L .35079 .31019 L p
1 g
F P
s
P
p
.002 w
.35079 .31019 m .39596 .26844 L .39246 .26537 L p
1 g
F P
s
P
p
.002 w
.69286 .4642 m .6945 .40053 L .68871 .39629 L p
1 g
F P
s
P
p
.002 w
.66968 .33654 m .68871 .39629 L .6945 .40053 L p
1 g
F P
s
P
p
.002 w
.57872 .25048 m .51642 .23424 L .51395 .2388 L p
1 g
F P
s
P
p
.002 w
.4525 .24369 m .51395 .2388 L .51642 .23424 L p
1 g
F P
s
P
p
.002 w
.45187 .23937 m .39246 .26537 L .39596 .26844 L p
1 g
F P
s
P
p
.002 w
.39596 .26844 m .4525 .24369 L .45187 .23937 L p
1 g
F P
s
P
p
.002 w
.51642 .23424 m .45187 .23937 L .4525 .24369 L p
1 g
F P
s
P
p
.002 w
.30264 .43357 m .31433 .49677 L .31658 .49047 L p
1 g
F P
s
P
p
.002 w
.31658 .49047 m .30516 .42858 L .30264 .43357 L p
1 g
F P
s
P
p
.002 w
.51736 .62696 m .57857 .61136 L .5773 .6074 L p
1 g
F P
s
P
p
.002 w
.5773 .6074 m .51573 .6231 L .51736 .62696 L p
1 g
F P
s
P
p
.002 w
.63082 .57316 m .5773 .6074 L .57857 .61136 L p
1 g
F P
s
P
p
.002 w
.45437 .62251 m .51736 .62696 L .51573 .6231 L p
1 g
F P
s
P
p
.002 w
.51573 .6231 m .45236 .61861 L .45437 .62251 L p
1 g
F P
s
P
p
.002 w
.57857 .61136 m .63177 .57733 L .63082 .57316 L p
1 g
F P
s
P
p
.002 w
.67077 .52378 m .63082 .57316 L .63177 .57733 L p
1 g
F P
s
P
p
.002 w
.6945 .40053 m .67509 .33951 L .66968 .33654 L p
1 g
F P
s
P
p
.002 w
.63172 .286 m .66968 .33654 L .67509 .33951 L p
1 g
F P
s
P
p
.002 w
.39607 .5983 m .45437 .62251 L .45236 .61861 L p
1 g
F P
s
P
p
.002 w
.45236 .61861 m .3937 .59423 L .39607 .5983 L p
1 g
F P
s
P
p
.002 w
.63177 .57733 m .67149 .52825 L .67077 .52378 L p
1 g
F P
s
P
p
.002 w
.69286 .4642 m .67077 .52378 L .67149 .52825 L p
1 g
F P
s
P
p
.002 w
.31256 .36946 m .30264 .43357 L .30516 .42858 L p
1 g
F P
s
P
p
.002 w
.30516 .42858 m .31488 .36582 L .31256 .36946 L p
1 g
F P
s
P
p
.002 w
.3486 .55658 m .39607 .5983 L .3937 .59423 L p
1 g
F P
s
P
p
.002 w
.3937 .59423 m .34594 .55224 L .3486 .55658 L p
1 g
F P
s
P
p
.002 w
.67509 .33951 m .63635 .28788 L .63172 .286 L p
1 g
F P
s
P
p
.002 w
.57872 .25048 m .63172 .286 L .63635 .28788 L p
1 g
F P
s
P
p
.004 w
.28649 .42993 m
.29572 .42995 L
s
P
p
.004 w
.24125 .4298 m
.28649 .42993 L
s
P
p
.002 w
.67149 .52825 m .69345 .46905 L .69286 .4642 L p
1 g
F P
s
P
p
.002 w
.6945 .40053 m .69286 .4642 L .69345 .46905 L p
1 g
F P
s
P
p
.002 w
.34337 .31165 m .31256 .36946 L .31488 .36582 L p
1 g
F P
s
P
p
.002 w
.31488 .36582 m .34503 .30924 L .34337 .31165 L p
1 g
F P
s
P
p
.002 w
.31721 .50148 m .3486 .55658 L .34594 .55224 L p
1 g
F P
s
P
p
.002 w
.34594 .55224 m .31433 .49677 L .31721 .50148 L p
1 g
F P
s
P
p
.002 w
.63635 .28788 m .5822 .25159 L .57872 .25048 L p
1 g
F P
s
P
p
.002 w
.51642 .23424 m .57872 .25048 L .5822 .25159 L p
1 g
F P
s
P
p
.002 w
.39184 .26682 m .34337 .31165 L .34503 .30924 L p
1 g
F P
s
P
p
.002 w
.34503 .30924 m .39246 .26537 L .39184 .26682 L p
1 g
F P
s
P
p
.002 w
.69345 .46905 m .69508 .4058 L .6945 .40053 L p
1 g
F P
s
P
p
.002 w
.67509 .33951 m .6945 .40053 L .69508 .4058 L p
1 g
F P
s
P
p
.002 w
.5822 .25159 m .51854 .235 L .51642 .23424 L p
1 g
F P
s
P
p
.002 w
.45187 .23937 m .51642 .23424 L .51854 .235 L p
1 g
F P
s
P
p
.002 w
.45256 .24024 m .39184 .26682 L .39246 .26537 L p
1 g
F P
s
P
p
.002 w
.39246 .26537 m .45187 .23937 L .45256 .24024 L p
1 g
F P
s
P
p
.002 w
.51854 .235 m .45256 .24024 L .45187 .23937 L p
1 g
F P
s
P
p
.002 w
.30561 .43869 m .31721 .50148 L .31433 .49677 L p
1 g
F P
s
P
p
.002 w
.31433 .49677 m .30264 .43357 L .30561 .43869 L p
1 g
F P
s
P
p
.002 w
.51857 .62546 m .57767 .61039 L .57857 .61136 L p
1 g
F P
s
P
p
.002 w
.57857 .61136 m .51736 .62696 L .51857 .62546 L p
1 g
F P
s
P
p
.002 w
.63177 .57733 m .57857 .61136 L .57767 .61039 L p
1 g
F P
s
P
p
.002 w
.45776 .62115 m .51857 .62546 L .51736 .62696 L p
1 g
F P
s
P
p
.002 w
.51736 .62696 m .45437 .62251 L .45776 .62115 L p
1 g
F P
s
P
p
.002 w
.57767 .61039 m .62904 .57753 L .63177 .57733 L p
1 g
F P
s
P
p
.002 w
.67149 .52825 m .63177 .57733 L .62904 .57753 L p
1 g
F P
s
P
p
.002 w
.69508 .4058 m .6758 .34518 L .67509 .33951 L p
1 g
F P
s
P
p
.002 w
.63635 .28788 m .67509 .33951 L .6758 .34518 L p
1 g
F P
s
P
p
.002 w
.4015 .59777 m .45776 .62115 L .45437 .62251 L p
1 g
F P
s
P
p
.002 w
.45437 .62251 m .39607 .5983 L .4015 .59777 L p
1 g
F P
s
P
p
.002 w
.62904 .57753 m .66738 .53015 L .67149 .52825 L p
1 g
F P
s
P
p
.002 w
.69345 .46905 m .67149 .52825 L .66738 .53015 L p
1 g
F P
s
P
p
.002 w
.31548 .37501 m .30561 .43869 L .30264 .43357 L p
1 g
F P
s
P
p
.002 w
.30264 .43357 m .31256 .36946 L .31548 .37501 L p
1 g
F P
s
P
p
.002 w
.35572 .55751 m .4015 .59777 L .39607 .5983 L p
1 g
F P
s
P
p
.002 w
.39607 .5983 m .3486 .55658 L .35572 .55751 L p
1 g
F P
s
P
p
.002 w
.6758 .34518 m .63729 .29391 L .63635 .28788 L p
1 g
F P
s
P
p
.002 w
.5822 .25159 m .63635 .28788 L .63729 .29391 L p
1 g
F P
s
P
p
.002 w
.66738 .53015 m .68856 .47302 L .69345 .46905 L p
1 g
F P
s
P
p
.002 w
.69508 .4058 m .69345 .46905 L .68856 .47302 L p
1 g
F P
s
P
p
.002 w
.34612 .31758 m .31548 .37501 L .31256 .36946 L p
1 g
F P
s
P
p
.002 w
.31256 .36946 m .34337 .31165 L .34612 .31758 L p
1 g
F P
s
P
p
.002 w
.32547 .50435 m .35572 .55751 L .3486 .55658 L p
1 g
F P
s
P
p
.002 w
.3486 .55658 m .31721 .50148 L .32547 .50435 L p
1 g
F P
s
P
p
.002 w
.63729 .29391 m .58348 .25787 L .5822 .25159 L p
1 g
F P
s
P
p
.002 w
.51854 .235 m .5822 .25159 L .58348 .25787 L p
1 g
F P
s
P
p
.002 w
.68856 .47302 m .69009 .412 L .69508 .4058 L p
1 g
F P
s
P
p
.002 w
.6758 .34518 m .69508 .4058 L .69009 .412 L p
1 g
F P
s
P
p
.002 w
.3943 .27304 m .34612 .31758 L .34337 .31165 L p
1 g
F P
s
P
p
.002 w
.34337 .31165 m .39184 .26682 L .3943 .27304 L p
1 g
F P
s
P
p
.002 w
.58348 .25787 m .52022 .24141 L .51854 .235 L p
1 g
F P
s
P
p
.002 w
.45256 .24024 m .51854 .235 L .52022 .24141 L p
1 g
F P
s
P
p
.002 w
.45465 .24663 m .3943 .27304 L .39184 .26682 L p
1 g
F P
s
P
p
.002 w
.39184 .26682 m .45256 .24024 L .45465 .24663 L p
1 g
F P
s
P
p
.002 w
.52022 .24141 m .45465 .24663 L .45256 .24024 L p
1 g
F P
s
P
p
.002 w
.31434 .4438 m .32547 .50435 L .31721 .50148 L p
1 g
F P
s
P
p
.002 w
.31721 .50148 m .30561 .43869 L .31434 .4438 L p
1 g
F P
s
P
p
.002 w
.5193 .61826 m .5745 .6042 L .57767 .61039 L p
1 g
F P
s
P
p
.002 w
.57767 .61039 m .51857 .62546 L .5193 .61826 L p
1 g
F P
s
P
p
.002 w
.62904 .57753 m .57767 .61039 L .5745 .6042 L p
1 g
F P
s
P
p
.002 w
.46252 .61423 m .5193 .61826 L .51857 .62546 L p
1 g
F P
s
P
p
.002 w
.51857 .62546 m .45776 .62115 L .46252 .61423 L p
1 g
F P
s
P
p
.002 w
.5745 .6042 m .62247 .5735 L .62904 .57753 L p
1 g
F P
s
P
p
.002 w
.66738 .53015 m .62904 .57753 L .62247 .5735 L p
1 g
F P
s
P
p
.002 w
.69009 .412 m .67146 .35357 L .6758 .34518 L p
1 g
F P
s
P
p
.002 w
.63729 .29391 m .6758 .34518 L .67146 .35357 L p
1 g
F P
s
P
p
.002 w
.41002 .59237 m .46252 .61423 L .45776 .62115 L p
1 g
F P
s
P
p
.002 w
.45776 .62115 m .4015 .59777 L .41002 .59237 L p
1 g
F P
s
P
p
.002 w
.62247 .5735 m .65824 .52925 L .66738 .53015 L p
1 g
F P
s
P
p
.002 w
.68856 .47302 m .66738 .53015 L .65824 .52925 L p
1 g
F P
s
P
p
.002 w
.32392 .38241 m .31434 .4438 L .30561 .43869 L p
1 g
F P
s
P
p
.002 w
.30561 .43869 m .31548 .37501 L .32392 .38241 L p
1 g
F P
s
P
p
.002 w
.36735 .55477 m .41002 .59237 L .4015 .59777 L p
1 g
F P
s
P
p
.002 w
.4015 .59777 m .35572 .55751 L .36735 .55477 L p
1 g
F P
s
P
p
.002 w
.67146 .35357 m .63429 .30417 L .63729 .29391 L p
1 g
F P
s
P
p
.002 w
.58348 .25787 m .63729 .29391 L .63429 .30417 L p
1 g
F P
s
P
p
.002 w
.65824 .52925 m .67796 .47593 L .68856 .47302 L p
1 g
F P
s
P
p
.002 w
.69009 .412 m .68856 .47302 L .67796 .47593 L p
1 g
F P
s
P
p
.002 w
.35349 .32707 m .32392 .38241 L .31548 .37501 L p
1 g
F P
s
P
p
.002 w
.31548 .37501 m .34612 .31758 L .35349 .32707 L p
1 g
F P
s
P
p
.002 w
.33921 .50517 m .36735 .55477 L .35572 .55751 L p
1 g
F P
s
P
p
.002 w
.35572 .55751 m .32547 .50435 L .33921 .50517 L p
1 g
F P
s
P
p
.002 w
.63429 .30417 m .58238 .26947 L .58348 .25787 L p
1 g
F P
s
P
p
.002 w
.52022 .24141 m .58348 .25787 L .58238 .26947 L p
1 g
F P
s
P
p
.002 w
.67796 .47593 m .67933 .41902 L .69009 .412 L p
1 g
F P
s
P
p
.002 w
.67146 .35357 m .69009 .412 L .67933 .41902 L p
1 g
F P
s
P
p
.002 w
.39998 .28416 m .35349 .32707 L .34612 .31758 L p
1 g
F P
s
P
p
.002 w
.34612 .31758 m .3943 .27304 L .39998 .28416 L p
1 g
F P
s
P
p
.002 w
.58238 .26947 m .52138 .25364 L .52022 .24141 L p
1 g
F P
s
P
p
.002 w
.45465 .24663 m .52022 .24141 L .52138 .25364 L p
1 g
F P
s
P
p
.002 w
.45816 .2587 m .39998 .28416 L .3943 .27304 L p
1 g
F P
s
P
p
.002 w
.3943 .27304 m .45465 .24663 L .45816 .2587 L p
1 g
F P
s
P
p
.002 w
.32892 .44873 m .33921 .50517 L .32547 .50435 L p
1 g
F P
s
P
p
.002 w
.32547 .50435 m .31434 .4438 L .32892 .44873 L p
1 g
F P
s
P
p
.002 w
.52138 .25364 m .45816 .2587 L .45465 .24663 L p
1 g
F P
s
P
p
.002 w
.5195 .60524 m .56901 .59263 L .5745 .6042 L p
1 g
F P
s
P
p
.002 w
.5745 .6042 m .5193 .61826 L .5195 .60524 L p
1 g
F P
s
P
p
.002 w
.62247 .5735 m .5745 .6042 L .56901 .59263 L p
1 g
F P
s
P
p
.002 w
.46859 .6016 m .5195 .60524 L .5193 .61826 L p
1 g
F P
s
P
p
.002 w
.5193 .61826 m .46252 .61423 L .46859 .6016 L p
1 g
F P
s
P
p
.002 w
.56901 .59263 m .61201 .56509 L .62247 .5735 L p
1 g
F P
s
P
p
.002 w
.65824 .52925 m .62247 .5735 L .61201 .56509 L p
1 g
F P
s
P
p
.002 w
.67933 .41902 m .66189 .36457 L .67146 .35357 L p
1 g
F P
s
P
p
.002 w
.63429 .30417 m .67146 .35357 L .66189 .36457 L p
1 g
F P
s
P
p
.002 w
.42156 .58196 m .46859 .6016 L .46252 .61423 L p
1 g
F P
s
P
p
.002 w
.46252 .61423 m .41002 .59237 L .42156 .58196 L p
1 g
F P
s
P
p
.002 w
.61201 .56509 m .64404 .5254 L .65824 .52925 L p
1 g
F P
s
P
p
.002 w
.67796 .47593 m .65824 .52925 L .64404 .5254 L p
1 g
F P
s
P
p
.002 w
.33792 .39155 m .32892 .44873 L .31434 .4438 L p
1 g
F P
s
P
p
.002 w
.31434 .4438 m .32392 .38241 L .33792 .39155 L p
1 g
F P
s
P
p
.004 w
.29572 .42995 m
.317 .43001 L
s
P
p
.002 w
.3834 .54823 m .42156 .58196 L .41002 .59237 L p
1 g
F P
s
P
p
.002 w
.41002 .59237 m .36735 .55477 L .3834 .54823 L p
1 g
F P
s
P
p
.002 w
.66189 .36457 m .62718 .31859 L .63429 .30417 L p
1 g
F P
s
P
p
.002 w
.58238 .26947 m .63429 .30417 L .62718 .31859 L p
1 g
F P
s
P
p
.002 w
.64404 .5254 m .66165 .4776 L .67796 .47593 L p
1 g
F P
s
P
p
.002 w
.67933 .41902 m .67796 .47593 L .66165 .4776 L p
1 g
F P
s
P
p
.002 w
.36554 .34003 m .33792 .39155 L .32392 .38241 L p
1 g
F P
s
P
p
.002 w
.32392 .38241 m .35349 .32707 L .36554 .34003 L p
1 g
F P
s
P
p
.002 w
.3583 .50379 m .3834 .54823 L .36735 .55477 L p
1 g
F P
s
P
p
.002 w
.36735 .55477 m .33921 .50517 L .3583 .50379 L p
1 g
F P
s
P
p
.002 w
.62718 .31859 m .57878 .28634 L .58238 .26947 L p
1 g
F P
s
P
p
.002 w
.52138 .25364 m .58238 .26947 L .57878 .28634 L p
1 g
F P
s
P
p
.002 w
.66165 .4776 m .6628 .42665 L .67933 .41902 L p
1 g
F P
s
P
p
.002 w
.66189 .36457 m .67933 .41902 L .6628 .42665 L p
1 g
F P
s
P
p
.002 w
.40887 .30009 m .36554 .34003 L .35349 .32707 L p
1 g
F P
s
P
p
.002 w
.35349 .32707 m .39998 .28416 L .40887 .30009 L p
1 g
F P
s
P
p
.002 w
.57878 .28634 m .52195 .27165 L .52138 .25364 L p
1 g
F P
s
P
p
.002 w
.45816 .2587 m .52138 .25364 L .52195 .27165 L p
1 g
F P
s
P
p
.002 w
.34919 .4533 m .3583 .50379 L .33921 .50517 L p
1 g
F P
s
P
p
.002 w
.33921 .50517 m .32892 .44873 L .34919 .4533 L p
1 g
F P
s
P
p
.002 w
.46306 .27639 m .40887 .30009 L .39998 .28416 L p
1 g
F P
s
P
p
.002 w
.39998 .28416 m .45816 .2587 L .46306 .27639 L p
1 g
F P
s
P
p
.002 w
.52195 .27165 m .46306 .27639 L .45816 .2587 L p
1 g
F P
s
P
p
.002 w
.51911 .58647 m .56122 .57575 L .56901 .59263 L p
1 g
F P
s
P
p
.002 w
.56901 .59263 m .5195 .60524 L .51911 .58647 L p
1 g
F P
s
P
p
.002 w
.61201 .56509 m .56901 .59263 L .56122 .57575 L p
1 g
F P
s
P
p
.002 w
.47583 .58333 m .51911 .58647 L .5195 .60524 L p
1 g
F P
s
P
p
.002 w
.5195 .60524 m .46859 .6016 L .47583 .58333 L p
1 g
F P
s
P
p
.002 w
.56122 .57575 m .59779 .55231 L .61201 .56509 L p
1 g
F P
s
P
p
.002 w
.64404 .5254 m .61201 .56509 L .59779 .55231 L p
1 g
F P
s
P
p
.002 w
.6628 .42665 m .64709 .37798 L .66189 .36457 L p
1 g
F P
s
P
p
.002 w
.62718 .31859 m .66189 .36457 L .64709 .37798 L p
1 g
F P
s
P
p
.002 w
.4359 .56659 m .47583 .58333 L .46859 .6016 L p
1 g
F P
s
P
p
.002 w
.46859 .6016 m .42156 .58196 L .4359 .56659 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.59779 .55231 m .62497 .51854 L .64404 .5254 L p
1 g
F P
s
P
p
.002 w
.66165 .4776 m .64404 .5254 L .62497 .51854 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.35735 .4022 m .34919 .4533 L .32892 .44873 L p
1 g
F P
s
P
p
.004 w
.35289 .43011 m
.5 .43051 L
s
P
p
.002 w
.32892 .44873 m .33792 .39155 L .35735 .4022 L p
1 g
F P
s
P
p
.004 w
.33605 .43006 m
.33734 .43007 L
s
P
p
.004 w
.32963 .43005 m
.33605 .43006 L
s
P
p
.004 w
.317 .43001 m
.32963 .43005 L
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.40355 .53789 m .4359 .56659 L .42156 .58196 L p
1 g
F P
s
P
p
.002 w
.42156 .58196 m .3834 .54823 L .40355 .53789 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.64709 .37798 m .61598 .33693 L .62718 .31859 L p
1 g
F P
s
P
p
.002 w
.57878 .28634 m .62718 .31859 L .61598 .33693 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.62497 .51854 m .63986 .47792 L .66165 .4776 L p
1 g
F P
s
P
p
.002 w
.6628 .42665 m .66165 .4776 L .63986 .47792 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.3821 .3562 m .35735 .4022 L .33792 .39155 L p
1 g
F P
s
P
p
.002 w
.33792 .39155 m .36554 .34003 L .3821 .3562 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.38236 .50014 m .40355 .53789 L .3834 .54823 L p
1 g
F P
s
P
p
.002 w
.3834 .54823 m .3583 .50379 L .38236 .50014 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.61598 .33693 m .57267 .30818 L .57878 .28634 L p
1 g
F P
s
P
p
.002 w
.52195 .27165 m .57878 .28634 L .57267 .30818 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.63986 .47792 m .64073 .43468 L .6628 .42665 L p
1 g
F P
s
P
p
.002 w
.64709 .37798 m .6628 .42665 L .64073 .43468 L p
1 g
F P
s
P
p
.002 w
.42084 .32056 m .3821 .3562 L .36554 .34003 L p
1 g
F P
s
P
p
.002 w
.36554 .34003 m .40887 .30009 L .42084 .32056 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.57267 .30818 m .52187 .29513 L .52195 .27165 L p
1 g
F P
s
P
p
.002 w
.46306 .27639 m .52195 .27165 L .52187 .29513 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.37476 .45732 m .38236 .50014 L .3583 .50379 L p
1 g
F P
s
P
p
.002 w
.3583 .50379 m .34919 .4533 L .37476 .45732 L p
1 g
F P
s
P
p
.002 w
.46927 .2994 m .42084 .32056 L .40887 .30009 L p
1 g
F P
s
P
p
.002 w
.40887 .30009 m .46306 .27639 L .46927 .2994 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.52187 .29513 m .46927 .2994 L .46306 .27639 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53158 .57405 L p
1 g
F P
s
P
p
.002 w
.55399 .55978 m .56122 .57575 L p
.54257 .56992 L 1 g
F P
s
P
p
.54257 .56992 m .53955 .56898 L .54913 .56288 L 1 g
F
P
p
.54257 .56992 m .54913 .56288 L .55399 .55978 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54913 .56288 L p
1 g
F P
s
P
p
.56075 .54566 m .54913 .56288 L .55334 .55835 L 1 g
F
P
p
.59779 .55231 m .55334 .55835 L .55687 .55367 L 1 g
F
P
p
.55486 .55633 m .55334 .55835 L .55434 .55728 L 1 g
F
P
p
.56075 .54566 m .55334 .55835 L .55486 .55633 L 1 g
F
P
p
.002 w
.59779 .55231 m .56122 .57575 L .55334 .55835 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.51814 .56229 m .5513 .55385 L .55334 .55835 L p
1 g
F P
s
P
p
.002 w
.55334 .55835 m .55399 .55978 L p
.55187 .55993 L 1 g
F P
s
P
p
.55187 .55993 m .51814 .56229 L .55334 .55835 L 1 g
F
P
p
.002 w
.58008 .53537 m .59779 .55231 L p
.55687 .55367 L 1 g
F P
s
P
p
.002 w
.56164 .54734 m .56075 .54566 L p
.55486 .55633 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56164 .54734 L p
1 g
F P
s
P
p
.002 w
.56171 .54717 m .56183 .54709 L p
.56164 .54734 L 1 g
F P
s
P
p
.002 w
.56183 .54709 m .58008 .53537 L p
.55687 .55367 L 1 g
F P
s
P
p
.002 w
.58008 .53537 m .56171 .54717 L p
.56615 .53267 L 1 g
F P
s
P
p
.56654 .52734 m .56164 .54734 L .56171 .54717 L 1 g
F
P
p
.56471 .53736 m .56171 .54717 L .56402 .54115 L 1 g
F
P
p
.56654 .52734 m .56171 .54717 L .56471 .53736 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5674 .52859 L p
1 g
F P
s
P
p
.002 w
.56712 .52243 m .56877 .52408 L p
.5672 .52427 L 1 g
F P
s
P
p
.002 w
.56877 .52408 m .58008 .53537 L p
.56615 .53267 L 1 g
F P
s
P
p
.56515 .50826 m .5674 .52859 L .56712 .52243 L 1 g
F
P
p
.60144 .50877 m .56712 .52243 L .56648 .5137 L 1 g
F
P
p
.56692 .51973 m .56712 .52243 L .56703 .52043 L 1 g
F
P
p
.56515 .50826 m .56712 .52243 L .56692 .51973 L 1 g
F
P
p
.002 w
.60144 .50877 m .58008 .53537 L .56712 .52243 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.56615 .53267 m .5395 .52749 L .5672 .52427 L 1 g
F
P
p
.5674 .52859 m .5672 .52427 L .56877 .52408 L 1 g
F
P
p
.56615 .53267 m .5672 .52427 L .5674 .52859 L 1 g
F
P
p
.002 w
.57411 .4963 m .60144 .50877 L p
.56648 .5137 L 1 g
F P
s
P
p
.002 w
.56616 .50947 m .56515 .50826 L p
.56692 .51973 L 1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56616 .50947 L p
1 g
F P
s
P
p
.002 w
.56522 .50741 m .56595 .5065 L p
.56616 .50947 L 1 g
F P
s
P
p
.002 w
.56595 .5065 m .57411 .4963 L p
.56727 .51188 L 1 g
F P
s
P
p
.56648 .5137 m .56616 .50947 L .56727 .51188 L 1 g
F
P
p
.56616 .50947 m .56595 .5065 L .56727 .51188 L 1 g
F
P
p
.002 w
.55739 .49133 m .55661 .4905 L p
.56212 .50103 L 1 g
F P
s
P
p
.002 w
.57411 .4963 m .56522 .50741 L p
.55875 .49411 L 1 g
F P
s
P
p
.55661 .4905 m .56616 .50947 L .56522 .50741 L 1 g
F
P
p
.56212 .50103 m .56522 .50741 L .56359 .50386 L 1 g
F
P
p
.55661 .4905 m .56522 .50741 L .56212 .50103 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.55343 .4875 m .53636 .49094 L .55067 .48483 L 1 g
F
P
p
.002 w
.55534 .48711 m .57411 .4963 L p
.55875 .49411 L 1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55095 .4851 L 1 g
F
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55875 .49411 m .53636 .49094 L .55343 .4875 L 1 g
F
P
p
.55739 .49133 m .55343 .4875 L .55534 .48711 L 1 g
F
P
p
.55875 .49411 m .55343 .4875 L .55739 .49133 L 1 g
F
P
p
.002 w
.53636 .49094 m .54387 .48151 L .55067 .48483 L p
1 g
F P
s
P
p
.002 w
.55828 .49228 m .55739 .49133 L p
.56359 .50386 L 1 g
F P
s
P
p
.56212 .50103 m .56359 .50386 L .55739 .49133 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55828 .49228 L p
1 g
F P
s
P
p
.56359 .50386 m .56713 .51061 L .55828 .49228 L 1 g
F
P
p
.54174 .47608 m .55095 .4851 L .55067 .48483 L 1 g
F
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.58208 .47421 m .57411 .4963 L .55067 .48483 L p
1 g
F P
s
P
p
.002 w
.55067 .48483 m .54387 .48151 L p
.54668 .48097 L 1 g
F P
s
P
p
.54174 .47608 m .55067 .48483 L .54474 .47909 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54474 .47909 m .54387 .48151 L p
.53894 .47516 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47685 L p
1 g
F P
s
P
p
.52214 .46667 m .54244 .47685 L .53304 .47231 L 1 g
F
P
p
.54244 .47685 m .53894 .47516 L .53344 .46808 L 1 g
F
P
p
.54474 .47909 m .53894 .47516 L .54244 .47685 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46721 L p
1 g
F P
s
P
p
.002 w
.54387 .48151 m .51417 .46611 L p
.52175 .46712 L 1 g
F P
s
P
p
.5 .4634 m .52247 .46721 L .51417 .46611 L 1 g
F
P
p
.002 w
.51417 .46611 m .54387 .48151 L p
.51281 .46593 L 1 g
F P
s
P
p
.51399 .46609 m .51417 .46611 L .51399 .46609 L 1 g
F
P
p
.5 .4634 m .51417 .46611 L .51399 .46609 L 1 g
F
P
p
.002 w
.54387 .48151 m .53636 .49094 L .51281 .46593 L p
1 g
F P
s
P
p
.53894 .47516 m .54387 .48151 L .52175 .46712 L 1 g
F
P
p
.52247 .46721 m .52175 .46712 L .52025 .46614 L 1 g
F
P
p
.53894 .47516 m .52175 .46712 L .52247 .46721 L 1 g
F
P
p
.002 w
.52619 .49749 m .51445 .50047 L .51191 .46581 L p
1 g
F P
s
P
p
.5 .4634 m .51399 .46609 L .51329 .466 L 1 g
F
P
p
.51277 .46592 m .51329 .466 L .51281 .46593 L 1 g
F
P
p
.5 .4634 m .51329 .466 L .51277 .46592 L 1 g
F
P
p
.002 w
.53636 .49094 m .52619 .49749 L .51226 .46585 L p
1 g
F P
s
P
p
.5 .4634 m .51281 .46593 L .51191 .46581 L 1 g
F
P
p
.002 w
.51445 .50047 m .50241 .49955 L .51161 .46576 L p
1 g
F P
s
P
p
.002 w
.51191 .46581 m .51445 .50047 L p
.51161 .46576 L 1 g
F P
s
P
p
.002 w
.50241 .49955 m .49134 .49483 L .5113 .46571 L p
1 g
F P
s
P
p
.002 w
.51161 .46576 m .50241 .49955 L p
.5113 .46571 L 1 g
F P
s
P
p
.5 .4634 m .51191 .46581 L .51146 .46574 L 1 g
F
P
p
.002 w
.49134 .49483 m .48246 .4868 L .51086 .46565 L p
1 g
F P
s
P
p
.002 w
.5113 .46571 m .49134 .49483 L p
.51086 .46565 L 1 g
F P
s
P
p
.002 w
.48246 .4868 m .47671 .47632 L .51 .46551 L p
1 g
F P
s
P
p
.002 w
.51086 .46565 m .48246 .4868 L p
.51 .46551 L 1 g
F P
s
P
p
.5 .4634 m .51146 .46574 L .51053 .46559 L 1 g
F
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47671 .47632 m .47538 .46834 L p
.50589 .46485 L 1 g
F P
s
P
p
.47538 .46834 m .47748 .46729 L .50589 .46485 L 1 g
F
P
p
.002 w
.47748 .46729 m .47786 .46667 L p
.48942 .46549 L 1 g
F P
s
P
p
.002 w
.49451 .46473 m .50589 .46485 L p
.47748 .46729 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47474 .46452 m .47678 .45267 L .50623 .46295 L p
1 g
F P
s
P
p
.002 w
.50589 .46485 m .49451 .46473 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .4639 L p
.50589 .46485 L 1 g
F P
s
P
p
.002 w
.51 .46551 m .47671 .47632 L p
.50589 .46485 L 1 g
F P
s
P
p
.50589 .46485 m .51053 .46559 L .51 .46551 L 1 g
F
P
p
.50589 .46485 m .51 .46551 L .5 .46396 L 1 g
F
P
p
.5 .4634 m .51053 .46559 L .50589 .46485 L 1 g
F
P
p
.002 w
.5 .4639 m .5 .46389 L p
.50589 .46485 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.50589 .46485 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .49984 .46392 L 1 g
F
P
p
.47786 .46667 m .5 .4639 L .48942 .46549 L 1 g
F
P
p
.002 w
.49451 .46473 m .47474 .46452 L p
.497 .46341 L 1 g
F P
s
P
p
.497 .46341 m .50623 .46295 L .5 .46389 L 1 g
F
P
p
.497 .46341 m .5 .46389 L .49451 .46473 L 1 g
F
P
p
.002 w
.50623 .46295 m .51185 .46491 L .50589 .46485 L p
1 g
F P
s
P
p
.5 .46389 m .50623 .46295 L .50589 .46485 L 1 g
F
P
p
.002 w
.5 .46389 m .5 .4639 L p
.49984 .46392 L 1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .46442 L p
.48942 .46549 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .46729 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47671 .47632 m .45017 .48401 L p
.45623 .47812 L 1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.47538 .46834 m .47671 .47632 L p
.45623 .47812 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45769 .4767 L p
1 g
F P
s
P
p
.44339 .4905 m .45769 .4767 L .45083 .48338 L 1 g
F
P
p
.45432 .47829 m .45769 .4767 L .45623 .47812 L 1 g
F
P
p
.45769 .4767 m .47538 .46834 L .45623 .47812 L 1 g
F
P
p
.002 w
.45769 .4767 m .45698 .47747 L p
.45083 .48338 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43297 .52026 m .42731 .52392 L p
.42871 .52045 L 1 g
F P
s
P
p
.42871 .52045 m .43431 .50662 L .43406 .5092 L 1 g
F
P
p
.42871 .52045 m .43406 .5092 L .43297 .52026 L 1 g
F
P
p
.002 w
.43406 .5092 m .43485 .50826 L p
.43794 .50103 L 1 g
F P
s
P
p
.002 w
.43243 .5285 m .42731 .52392 L .43297 .52026 L p
1 g
F P
s
P
p
.002 w
.43243 .52884 m .43346 .52734 L p
.43247 .52533 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43243 .52884 L p
1 g
F P
s
P
p
.002 w
.42731 .52392 m .43226 .52834 L p
.4322 .54822 L 1 g
F P
s
P
p
.4322 .54822 m .43226 .52834 L .43243 .52884 L 1 g
F
P
p
.43925 .54566 m .43243 .52884 L .43592 .53906 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43859 .5469 L p
1 g
F P
s
P
p
.45146 .56129 m .43859 .5469 L .44437 .55513 L 1 g
F
P
p
.4322 .54822 m .43232 .53799 L .43859 .5469 L 1 g
F
P
p
.4322 .54822 m .43859 .5469 L .43885 .54767 L 1 g
F
P
p
.002 w
.43859 .5469 m .43925 .54566 L p
.43592 .53906 L 1 g
F P
s
P
p
.43232 .53799 m .43243 .5285 L .43912 .54765 L 1 g
F
P
p
.4359 .56659 m .4322 .54822 L .43912 .54765 L 1 g
F
P
p
.45146 .56129 m .44437 .55513 L .44488 .55585 L 1 g
F
P
p
.002 w
.46536 .57894 m .4359 .56659 L .44337 .55766 L p
1 g
F P
s
P
p
.002 w
.44337 .55766 m .44488 .55585 L p
.45094 .56269 L 1 g
F P
s
P
p
.46536 .57894 m .44337 .55766 L .45094 .56269 L 1 g
F
P
p
.002 w
.46837 .57425 m .46872 .57265 L p
.46179 .56988 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47583 .58333 m .46536 .57894 L p
.46269 .57212 L 1 g
F P
s
P
p
.47583 .58333 m .46269 .57212 L .47065 .5751 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46837 .57425 L p
1 g
F P
s
P
p
.48921 .57862 m .46837 .57425 L .47443 .57651 L 1 g
F
P
p
.002 w
.47778 .57777 m .47583 .58333 L p
.47065 .5751 L 1 g
F P
s
P
p
.48921 .57862 m .46807 .57561 L .47716 .57763 L 1 g
F
P
p
.002 w
.51582 .58623 m .47583 .58333 L .47691 .58024 L p
1 g
F P
s
P
p
.002 w
.47691 .58024 m .47778 .57777 L p
.48909 .58028 L 1 g
F P
s
P
p
.51582 .58623 m .47691 .58024 L .48909 .58028 L 1 g
F
P
p
.002 w
.51092 .58036 m .51079 .57862 L p
.50224 .58033 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58036 L p
1 g
F P
s
P
p
.002 w
.51911 .58647 m .51582 .58623 L p
.50921 .58073 L 1 g
F P
s
P
p
.51911 .58647 m .50921 .58073 L .50935 .5807 L 1 g
F
P
p
.53128 .57265 m .51092 .58036 L .5188 .57866 L 1 g
F
P
p
.56122 .57575 m .5188 .57866 L .54281 .57 L 1 g
F
P
p
.52136 .57774 m .5188 .57866 L .5201 .57838 L 1 g
F
P
p
.53128 .57265 m .5188 .57866 L .52136 .57774 L 1 g
F
P
p
.002 w
.56122 .57575 m .51911 .58647 L .5188 .57866 L p
1 g
F P
s
P
p
.54854 .56129 m .53158 .57405 L .54234 .5672 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.51911 .58647 m .50876 .58035 L .51109 .58036 L 1 g
F
P
p
.51582 .58623 m .5 .58271 L .50921 .58073 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58028 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .58028 L .50224 .58033 L 1 g
F
P
p
.002 w
.48406 .55978 m .51814 .56229 L .51911 .58647 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53198 .57583 L p
1 g
F P
s
P
p
.002 w
.53198 .57583 m .53128 .57265 L p
.5201 .57838 L 1 g
F P
s
P
p
.5201 .57838 m .51111 .583 L .53198 .57583 L 1 g
F
P
p
.48921 .57862 m .47748 .57766 L .47778 .57777 L 1 g
F
P
p
.002 w
.48896 .58195 m .48909 .58028 L p
.47778 .57777 L 1 g
F P
s
P
p
.002 w
.48909 .58028 m .48921 .57862 L p
.47778 .57777 L 1 g
F P
s
P
p
.002 w
.47778 .57777 m .48406 .55978 L p
.50921 .58073 L 1 g
F P
s
P
p
.5 .58271 m .47778 .57777 L .50921 .58073 L 1 g
F
P
p
.54281 .57 m .53158 .57405 L .53955 .56898 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54913 .56288 L p
1 g
F P
s
P
p
.002 w
.54913 .56288 m .54854 .56129 L p
.54234 .5672 L 1 g
F P
s
P
p
.54234 .5672 m .5322 .57686 L .54913 .56288 L 1 g
F
P
p
.002 w
.5188 .57866 m .51814 .56229 L p
.53955 .56898 L 1 g
F P
s
P
p
.53158 .57405 m .5188 .57866 L .53955 .56898 L 1 g
F
P
p
.51109 .58036 m .50876 .58035 L .48406 .55978 L 1 g
F
P
p
.002 w
.51092 .58036 m .51111 .583 L p
.5201 .57838 L 1 g
F P
s
P
p
.50935 .5807 m .50921 .58073 L .50876 .58035 L 1 g
F
P
p
.002 w
.48909 .58028 m .48889 .583 L p
.50224 .58033 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58036 L p
1 g
F P
s
P
p
.50224 .58033 m .48889 .583 L .51092 .58036 L 1 g
F
P
p
.002 w
.45267 .54655 m .48406 .55978 L .47778 .57777 L p
1 g
F P
s
P
p
.47065 .5751 m .45267 .54655 L .47778 .57777 L 1 g
F
P
p
.002 w
.46837 .57425 m .46807 .57561 L p
.47443 .57651 L 1 g
F P
s
P
p
.002 w
.46807 .57561 m .4678 .57686 L p
.47716 .57763 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45094 .56269 L p
1 g
F P
s
P
p
.46872 .57265 m .45094 .56269 L .46179 .56988 L 1 g
F
P
p
.002 w
.45094 .56269 m .45146 .56129 L p
.44488 .55585 L 1 g
F P
s
P
p
.002 w
.44488 .55585 m .45267 .54655 L p
.46536 .57894 L 1 g
F P
s
P
p
.002 w
.45094 .56269 m .45002 .56518 L p
.46179 .56988 L 1 g
F P
s
P
p
.47065 .5751 m .46837 .57425 L .45267 .54655 L 1 g
F
P
p
.46837 .57425 m .46269 .57212 L .46182 .5699 L 1 g
F
P
p
.46837 .57425 m .46182 .5699 L .45267 .54655 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48896 .58195 L p
1 g
F P
s
P
p
.47748 .57766 m .4678 .57686 L .48896 .58195 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46837 .57425 L p
1 g
F P
s
P
p
.46179 .56988 m .45002 .56518 L .46837 .57425 L 1 g
F
P
p
.002 w
.45051 .56386 m .45094 .56269 L p
.44488 .55585 L 1 g
F P
s
P
p
.002 w
.45267 .54655 m .44488 .55585 L p
.43912 .54765 L 1 g
F P
s
P
p
.002 w
.44488 .55585 m .4359 .56659 L p
.43912 .54765 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45051 .56386 L p
1 g
F P
s
P
p
.44437 .55513 m .43743 .5491 L .45051 .56386 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43859 .5469 L p
1 g
F P
s
P
p
.43592 .53906 m .43146 .53025 L .43859 .5469 L 1 g
F
P
p
.43885 .54767 m .43859 .5469 L .43912 .54765 L 1 g
F
P
p
.002 w
.43243 .5285 m .45267 .54655 L p
.43912 .54765 L 1 g
F P
s
P
p
.002 w
.43859 .5469 m .43743 .5491 L p
.44437 .55513 L 1 g
F P
s
P
p
.002 w
.43243 .52884 m .43146 .53025 L p
.43592 .53906 L 1 g
F P
s
P
p
.002 w
.43226 .52834 m .43243 .5285 L p
.43243 .52884 L 1 g
F P
s
P
p
.002 w
.45267 .54655 m .43243 .5285 L p
.45392 .50671 L 1 g
F P
s
P
p
.43346 .52734 m .43315 .51844 L .43297 .52026 L 1 g
F
P
p
.43346 .52734 m .43297 .52026 L .43262 .52563 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43297 .52026 m .45392 .50671 L p
.43243 .5285 L 1 g
F P
s
P
p
.43262 .52563 m .43297 .52026 L .43247 .52533 L 1 g
F
P
p
.002 w
.43207 .52936 m .43243 .52884 L p
.43247 .52533 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44249 .49145 L p
1 g
F P
s
P
p
.43485 .50826 m .44249 .49145 L .43794 .50103 L 1 g
F
P
p
.002 w
.45392 .50671 m .43297 .52026 L p
.43728 .50242 L 1 g
F P
s
P
p
.43728 .50242 m .43915 .49467 L .44046 .49574 L 1 g
F
P
p
.43728 .50242 m .44046 .49574 L .45392 .50671 L 1 g
F
P
p
.002 w
.44444 .48958 m .45392 .50671 L p
.43915 .49467 L 1 g
F P
s
P
p
.002 w
.44249 .49145 m .44166 .49233 L p
.43794 .50103 L 1 g
F P
s
P
p
.43431 .50662 m .43915 .49467 L .43297 .52026 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43406 .5092 L p
1 g
F P
s
P
p
.43794 .50103 m .44166 .49233 L .43406 .5092 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43207 .52936 L p
1 g
F P
s
P
p
.43315 .51844 m .43287 .51061 L .43207 .52936 L 1 g
F
P
p
.44339 .4905 m .45083 .48338 L .45017 .48401 L 1 g
F
P
p
.002 w
.45392 .50671 m .44444 .48958 L p
.47671 .47632 L 1 g
F P
s
P
p
.002 w
.45017 .48401 m .47671 .47632 L p
.44444 .48958 L 1 g
F P
s
P
p
.002 w
.44222 .49174 m .44235 .49161 L p
.45017 .48401 L 1 g
F P
s
P
p
.002 w
.44235 .49161 m .44339 .4905 L p
.45017 .48401 L 1 g
F P
s
P
p
.002 w
.44444 .48958 m .44258 .48621 L .45017 .48401 L p
1 g
F P
s
P
p
.002 w
.44258 .48621 m .44444 .48958 L p
.43915 .49467 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44222 .49174 L p
.45338 .48096 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .4555 .47891 L p
.45338 .48096 L 1 g
F P
s
P
p
.002 w
.4555 .47891 m .44166 .49233 L p
.45338 .48096 L 1 g
F P
s
P
p
.45083 .48338 m .45698 .47747 L .44222 .49174 L 1 g
F
P
p
.44258 .48621 m .45432 .47829 L .45623 .47812 L 1 g
F
P
p
.002 w
.45017 .48401 m .44258 .48621 L p
.45623 .47812 L 1 g
F P
s
P
p
.45826 .47608 m .47748 .46729 L .47134 .47034 L 1 g
F
P
p
.002 w
.45698 .47747 m .45826 .47608 L p
.47134 .47034 L 1 g
F P
s
P
p
.002 w
.47474 .46452 m .47538 .46834 L p
.45432 .47829 L 1 g
F P
s
P
p
.47134 .47034 m .47538 .46834 L .47718 .46778 L 1 g
F
P
p
.002 w
.47748 .46729 m .47744 .46736 L p
.47538 .46834 L 1 g
F P
s
P
p
.002 w
.47744 .46736 m .47718 .46778 L p
.47538 .46834 L 1 g
F P
s
P
p
.002 w
.47474 .46452 m .4829 .4646 L p
.47748 .46729 L 1 g
F P
s
P
p
.002 w
.47538 .46834 m .47526 .46763 L p
.47748 .46729 L 1 g
F P
s
P
p
.002 w
.47526 .46763 m .47474 .46452 L p
.47748 .46729 L 1 g
F P
s
P
p
.002 w
.4829 .4646 m .49451 .46473 L p
.47748 .46729 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47748 .46729 L p
1 g
F P
s
P
p
.48942 .46549 m .5 .46442 L .47748 .46729 L 1 g
F
P
p
.002 w
.47718 .46778 m .45706 .47744 L p
.47134 .47034 L 1 g
F P
s
P
p
.002 w
.45706 .47744 m .45698 .47747 L p
.47134 .47034 L 1 g
F P
s
P
p
.002 w
.50589 .46485 m .51185 .46491 L .51 .46551 L p
1 g
F P
s
P
p
.002 w
.51 .46551 m .51185 .46491 L .51086 .46565 L p
1 g
F P
s
P
p
.002 w
.5 .46406 m .5 .46396 L p
.51086 .46565 L 1 g
F P
s
P
p
.51086 .46565 m .51146 .46574 L .5113 .46572 L 1 g
F
P
p
.51086 .46565 m .5113 .46572 L .5 .46406 L 1 g
F
P
p
.002 w
.51086 .46565 m .51185 .46491 L .5113 .46571 L p
1 g
F P
s
P
p
.002 w
.5113 .46571 m .51185 .46491 L .51161 .46576 L p
1 g
F P
s
P
p
.002 w
.5 .46412 m .5 .46406 L p
.51161 .46576 L 1 g
F P
s
P
p
.51161 .46576 m .51191 .46581 L .51176 .46578 L 1 g
F
P
p
.51161 .46576 m .51176 .46578 L .5 .46412 L 1 g
F
P
p
.002 w
.51161 .46576 m .51185 .46491 L .51191 .46581 L p
1 g
F P
s
P
p
.002 w
.51226 .46585 m .51185 .46491 L .51281 .46593 L p
1 g
F P
s
P
p
.002 w
.51281 .46593 m .53636 .49094 L p
.51226 .46585 L 1 g
F P
s
P
p
.002 w
.51191 .46581 m .51185 .46491 L .51226 .46585 L p
1 g
F P
s
P
p
.002 w
.51226 .46585 m .52619 .49749 L p
.51191 .46581 L 1 g
F P
s
P
p
.002 w
.5 .46423 m .5 .46412 L p
.51281 .46593 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46423 L p
1 g
F P
s
P
p
.51399 .46609 m .52282 .46778 L .5 .46423 L 1 g
F
P
p
.002 w
.51281 .46593 m .51185 .46491 L .51417 .46611 L p
1 g
F P
s
P
p
.002 w
.52247 .46721 m .52282 .46778 L p
.51399 .46609 L 1 g
F P
s
P
p
.002 w
.51185 .46491 m .52025 .46614 L p
.52175 .46712 L 1 g
F P
s
P
p
.002 w
.51417 .46611 m .51185 .46491 L p
.52175 .46712 L 1 g
F P
s
P
p
.002 w
.52247 .46721 m .52214 .46667 L p
.53304 .47231 L 1 g
F P
s
P
p
.002 w
.52025 .46614 m .53344 .46808 L p
.53894 .47516 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52247 .46721 L p
1 g
F P
s
P
p
.53304 .47231 m .54302 .47747 L .52247 .46721 L 1 g
F
P
p
.002 w
.54244 .47685 m .54302 .47747 L p
.53304 .47231 L 1 g
F P
s
P
p
.002 w
.54255 .47696 m .54244 .47685 L p
.54474 .47909 L 1 g
F P
s
P
p
.002 w
.54244 .47685 m .54174 .47608 L p
.54474 .47909 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53344 .46808 m .54792 .4702 L .54474 .47909 L p
1 g
F P
s
P
p
.58208 .47421 m .55067 .48483 L .54668 .48097 L 1 g
F
P
p
.002 w
.54792 .4702 m .58208 .47421 L p
.54668 .48097 L 1 g
F P
s
P
p
.002 w
.54387 .48151 m .54474 .47909 L p
.54668 .48097 L 1 g
F P
s
P
p
.002 w
.54474 .47909 m .54792 .4702 L p
.54668 .48097 L 1 g
F P
s
P
p
.55067 .48483 m .55834 .49233 L .54261 .47703 L 1 g
F
P
p
.55095 .4851 m .55097 .48512 L .55067 .48483 L 1 g
F
P
p
.55097 .48512 m .55834 .49233 L .55067 .48483 L 1 g
F
P
p
.002 w
.54261 .47703 m .54255 .47696 L p
.55067 .48483 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54261 .47703 L p
1 g
F P
s
P
p
.002 w
.55739 .49133 m .55834 .49233 L p
.55095 .4851 L 1 g
F P
s
P
p
.002 w
.55067 .48483 m .55534 .48711 L p
.55343 .4875 L 1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55938 .5147 m .53636 .49094 L p
.55875 .49411 L 1 g
F P
s
P
p
.002 w
.56522 .50741 m .55938 .5147 L p
.55875 .49411 L 1 g
F P
s
P
p
.002 w
.56616 .50947 m .56713 .51061 L p
.56359 .50386 L 1 g
F P
s
P
p
.002 w
.55938 .5147 m .56522 .50741 L p
.56648 .5137 L 1 g
F P
s
P
p
.56648 .5137 m .56522 .50741 L .56616 .50947 L 1 g
F
P
p
.002 w
.56655 .50993 m .56616 .50947 L p
.56703 .52043 L 1 g
F P
s
P
p
.56692 .51973 m .56703 .52043 L .56616 .50947 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56655 .50993 L p
1 g
F P
s
P
p
.56703 .52043 m .56854 .53025 L .56655 .50993 L 1 g
F
P
p
.002 w
.56712 .52243 m .55938 .5147 L p
.56648 .5137 L 1 g
F P
s
P
p
.002 w
.5674 .52859 m .56854 .53025 L p
.56703 .52043 L 1 g
F P
s
P
p
.002 w
.5395 .52749 m .55938 .5147 L .56712 .52243 L p
1 g
F P
s
P
p
.5672 .52427 m .5395 .52749 L .56712 .52243 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5513 .55385 m .5395 .52749 L p
.56615 .53267 L 1 g
F P
s
P
p
.002 w
.56171 .54717 m .5513 .55385 L p
.56615 .53267 L 1 g
F P
s
P
p
.56402 .54115 m .56171 .54717 L .56257 .5491 L 1 g
F
P
p
.002 w
.56164 .54734 m .56165 .54736 L p
.56171 .54717 L 1 g
F P
s
P
p
.002 w
.56165 .54736 m .56257 .5491 L p
.56171 .54717 L 1 g
F P
s
P
p
.002 w
.5513 .55385 m .56171 .54717 L p
.55687 .55367 L 1 g
F P
s
P
p
.55687 .55367 m .56171 .54717 L .56164 .54734 L 1 g
F
P
p
.002 w
.56235 .54868 m .56164 .54734 L p
.55434 .55728 L 1 g
F P
s
P
p
.55486 .55633 m .55434 .55728 L .56164 .54734 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56235 .54868 L p
1 g
F P
s
P
p
.53955 .56898 m .51814 .56229 L .55399 .55978 L 1 g
F
P
p
.55434 .55728 m .54998 .56518 L .56235 .54868 L 1 g
F
P
p
.002 w
.55334 .55835 m .5513 .55385 L p
.55687 .55367 L 1 g
F P
s
P
p
.002 w
.54913 .56288 m .54998 .56518 L p
.55434 .55728 L 1 g
F P
s
P
p
.002 w
.53158 .57405 m .5322 .57686 L p
.54234 .5672 L 1 g
F P
s
P
p
.002 w
.62497 .51854 m .59779 .55231 L .58008 .53537 L p
1 g
F P
s
P
p
.002 w
.64073 .43468 m .62731 .39344 L .64709 .37798 L p
1 g
F P
s
P
p
.002 w
.61598 .33693 m .64709 .37798 L .62731 .39344 L p
1 g
F P
s
P
p
.002 w
.58008 .53537 m .60144 .50877 L .62497 .51854 L p
1 g
F P
s
P
p
.002 w
.63986 .47792 m .62497 .51854 L .60144 .50877 L p
1 g
F P
s
P
p
.002 w
.38177 .41406 m .37476 .45732 L .34919 .4533 L p
1 g
F P
s
P
p
.002 w
.34919 .4533 m .35735 .4022 L .38177 .41406 L p
1 g
F P
s
P
p
.002 w
.4359 .56659 m .40355 .53789 L .42731 .52392 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62731 .39344 m .60085 .35873 L .61598 .33693 L p
1 g
F P
s
P
p
.002 w
.57267 .30818 m .61598 .33693 L .60085 .35873 L p
1 g
F P
s
P
p
.002 w
.60144 .50877 m .61308 .4768 L .63986 .47792 L p
1 g
F P
s
P
p
.002 w
.64073 .43468 m .63986 .47792 L .61308 .4768 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4028 .37517 m .38177 .41406 L .35735 .4022 L p
1 g
F P
s
P
p
.002 w
.35735 .4022 m .3821 .3562 L .4028 .37517 L p
1 g
F P
s
P
p
.002 w
.41075 .49424 m .42731 .52392 L .40355 .53789 L p
1 g
F P
s
P
p
.002 w
.40355 .53789 m .38236 .50014 L .41075 .49424 L p
1 g
F P
s
P
p
.002 w
.60085 .35873 m .56412 .33448 L .57267 .30818 L p
1 g
F P
s
P
p
.002 w
.52187 .29513 m .57267 .30818 L .56412 .33448 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.61308 .4768 m .61366 .44282 L .64073 .43468 L p
1 g
F P
s
P
p
.002 w
.62731 .39344 m .64073 .43468 L .61366 .44282 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.43563 .34504 m .4028 .37517 L .3821 .3562 L p
1 g
F P
s
P
p
.002 w
.3821 .3562 m .42084 .32056 L .43563 .34504 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.56412 .33448 m .52111 .3235 L .52187 .29513 L p
1 g
F P
s
P
p
.002 w
.46927 .2994 m .52187 .29513 L .52111 .3235 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.4049 .46063 m .41075 .49424 L .38236 .50014 L p
1 g
F P
s
P
p
.002 w
.38236 .50014 m .37476 .45732 L .4049 .46063 L p
1 g
F P
s
P
p
.002 w
.4766 .32714 m .43563 .34504 L .42084 .32056 L p
1 g
F P
s
P
p
.002 w
.42084 .32056 m .46927 .2994 L .4766 .32714 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.52111 .3235 m .4766 .32714 L .46927 .2994 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51657 .53331 m .5395 .52749 L .5513 .55385 L p
1 g
F P
s
P
p
.002 w
.5513 .55385 m .51814 .56229 L .51657 .53331 L p
1 g
F P
s
P
p
.002 w
.49303 .53155 m .51657 .53331 L .51814 .56229 L p
1 g
F P
s
P
p
.002 w
.51814 .56229 m .48406 .55978 L .49303 .53155 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.61366 .44282 m .60303 .41049 L .62731 .39344 L p
1 g
F P
s
P
p
.002 w
.60085 .35873 m .62731 .39344 L .60303 .41049 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.47137 .52237 m .49303 .53155 L .48406 .55978 L p
1 g
F P
s
P
p
.002 w
.48406 .55978 m .45267 .54655 L .47137 .52237 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.61308 .4768 m .60144 .50877 L .57411 .4963 L p
1 g
F P
s
P
p
.002 w
.41049 .42674 m .4049 .46063 L .37476 .45732 L p
1 g
F P
s
P
p
.002 w
.37476 .45732 m .38177 .41406 L .41049 .42674 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.45392 .50671 m .47137 .52237 L .45267 .54655 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.60303 .41049 m .5822 .38334 L .60085 .35873 L p
1 g
F P
s
P
p
.002 w
.56412 .33448 m .60085 .35873 L .5822 .38334 L p
1 g
F P
s
P
p
.002 w
.57411 .4963 m .58208 .47421 L .61308 .4768 L p
1 g
F P
s
P
p
.002 w
.61366 .44282 m .61308 .4768 L .58208 .47421 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.42704 .39631 m .41049 .42674 L .38177 .41406 L p
1 g
F P
s
P
p
.002 w
.38177 .41406 m .4028 .37517 L .42704 .39631 L p
1 g
F P
s
P
p
.002 w
.42731 .52392 m .41075 .49424 L .44258 .48621 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5822 .38334 m .55338 .36442 L .56412 .33448 L p
1 g
F P
s
P
p
.002 w
.52111 .3235 m .56412 .33448 L .55338 .36442 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.58208 .47421 m .58241 .45078 L .61366 .44282 L p
1 g
F P
s
P
p
.002 w
.60303 .41049 m .61366 .44282 L .58241 .45078 L p
1 g
F P
s
P
p
.002 w
.45277 .37277 m .42704 .39631 L .4028 .37517 L p
1 g
F P
s
P
p
.002 w
.4028 .37517 m .43563 .34504 L .45277 .37277 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43863 .46307 m .44258 .48621 L .41075 .49424 L p
1 g
F P
s
P
p
.002 w
.41075 .49424 m .4049 .46063 L .43863 .46307 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.55338 .36442 m .51968 .35589 L .52111 .3235 L p
1 g
F P
s
P
p
.002 w
.4766 .32714 m .52111 .3235 L .51968 .35589 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.48484 .35877 m .45277 .37277 L .43563 .34504 L p
1 g
F P
s
P
p
.002 w
.43563 .34504 m .4766 .32714 L .48484 .35877 L p
1 g
F P
s
P
p
.002 w
.51968 .35589 m .48484 .35877 L .4766 .32714 L p
1 g
F P
s
P
p
.002 w
.58241 .45078 m .57501 .42854 L .60303 .41049 L p
1 g
F P
s
P
p
.002 w
.5822 .38334 m .60303 .41049 L .57501 .42854 L p
1 g
F P
s
P
p
.002 w
.51445 .50047 m .52619 .49749 L .5395 .52749 L p
1 g
F P
s
P
p
.002 w
.5395 .52749 m .51657 .53331 L .51445 .50047 L p
1 g
F P
s
P
p
.002 w
.55938 .5147 m .5395 .52749 L .52619 .49749 L p
1 g
F P
s
P
p
.002 w
.50241 .49955 m .51445 .50047 L .51657 .53331 L p
1 g
F P
s
P
p
.002 w
.51657 .53331 m .49303 .53155 L .50241 .49955 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.52619 .49749 m .53636 .49094 L .55938 .5147 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.49134 .49483 m .50241 .49955 L .49303 .53155 L p
1 g
F P
s
P
p
.002 w
.49303 .53155 m .47137 .52237 L .49134 .49483 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44256 .43978 m .43863 .46307 L .4049 .46063 L p
1 g
F P
s
P
p
.002 w
.4049 .46063 m .41049 .42674 L .44256 .43978 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48246 .4868 m .49134 .49483 L .47137 .52237 L p
1 g
F P
s
P
p
.002 w
.47137 .52237 m .45392 .50671 L .48246 .4868 L p
1 g
F P
s
P
p
.002 w
.57501 .42854 m .56061 .40992 L .5822 .38334 L p
1 g
F P
s
P
p
.002 w
.55338 .36442 m .5822 .38334 L .56061 .40992 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.58241 .45078 m .58208 .47421 L .54792 .4702 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.45398 .4189 m .44256 .43978 L .41049 .42674 L p
1 g
F P
s
P
p
.002 w
.41049 .42674 m .42704 .39631 L .45398 .4189 L p
1 g
F P
s
P
p
.002 w
.47671 .47632 m .48246 .4868 L .45392 .50671 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56061 .40992 m .54076 .39697 L .55338 .36442 L p
1 g
F P
s
P
p
.002 w
.51968 .35589 m .55338 .36442 L .54076 .39697 L p
1 g
F P
s
P
p
.002 w
.54792 .4702 m .54804 .45825 L .58241 .45078 L p
1 g
F P
s
P
p
.002 w
.57501 .42854 m .58241 .45078 L .54804 .45825 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47167 .40276 m .45398 .4189 L .42704 .39631 L p
1 g
F P
s
P
p
.002 w
.42704 .39631 m .45277 .37277 L .47167 .40276 L p
1 g
F P
s
P
p
.002 w
.44258 .48621 m .43863 .46307 L .47474 .46452 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.54076 .39697 m .51761 .39116 L .51968 .35589 L p
1 g
F P
s
P
p
.002 w
.48484 .35877 m .51968 .35589 L .51761 .39116 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54804 .45825 m .54422 .44692 L .57501 .42854 L p
1 g
F P
s
P
p
.002 w
.56061 .40992 m .57501 .42854 L .54422 .44692 L p
1 g
F P
s
P
p
.002 w
.49369 .39316 m .47167 .40276 L .45277 .37277 L p
1 g
F P
s
P
p
.002 w
.45277 .37277 m .48484 .35877 L .49369 .39316 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51761 .39116 m .49369 .39316 L .48484 .35877 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.47678 .45267 m .47474 .46452 L .43863 .46307 L p
1 g
F P
s
P
p
.002 w
.43863 .46307 m .44256 .43978 L .47678 .45267 L p
1 g
F P
s
P
p
.002 w
.54422 .44692 m .53686 .43746 L .56061 .40992 L p
1 g
F P
s
P
p
.002 w
.54076 .39697 m .56061 .40992 L .53686 .43746 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54804 .45825 m .54792 .4702 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.48262 .44207 m .47678 .45267 L .44256 .43978 L p
1 g
F P
s
P
p
.002 w
.44256 .43978 m .45398 .4189 L .48262 .44207 L p
1 g
F P
s
P
p
.002 w
.54422 .44692 m .54804 .45825 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53686 .43746 m .52674 .43091 L .54076 .39697 L p
1 g
F P
s
P
p
.002 w
.51761 .39116 m .54076 .39697 L .52674 .43091 L p
1 g
F P
s
P
p
.002 w
.49162 .43388 m .48262 .44207 L .45398 .4189 L p
1 g
F P
s
P
p
.002 w
.45398 .4189 m .47167 .40276 L .49162 .43388 L p
1 g
F P
s
P
p
.002 w
.53686 .43746 m .54422 .44692 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52674 .43091 m .51496 .42798 L .51761 .39116 L p
1 g
F P
s
P
p
.002 w
.49369 .39316 m .51761 .39116 L .51496 .42798 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.50281 .42901 m .49162 .43388 L .47167 .40276 L p
1 g
F P
s
P
p
.002 w
.47167 .40276 m .49369 .39316 L .50281 .42901 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51496 .42798 m .50281 .42901 L .49369 .39316 L p
1 g
F P
s
P
p
.002 w
.52674 .43091 m .53686 .43746 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.51496 .42798 m .52674 .43091 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.50281 .42901 m .51496 .42798 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.49162 .43388 m .50281 .42901 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.48262 .44207 m .49162 .43388 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.47678 .45267 m .48262 .44207 L .51185 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.51185 .46491 m
.5192 .48627 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .24125 .4298 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .5192 .48627 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0542636)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0542636)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49044 .47423 m .5146 .46196 L .49784 .43897 L p
1 g
F P
s
P
p
.002 w
.49784 .43897 m .48138 .44729 L .49044 .47423 L p
1 g
F P
s
P
p
.002 w
.51092 .42592 m .49784 .43897 L .5146 .46196 L p
1 g
F P
s
P
p
.002 w
.48138 .44729 m .49784 .43897 L .48114 .41581 L p
1 g
F P
s
P
p
.002 w
.49784 .43897 m .51092 .42592 L .48778 .40919 L p
1 g
F P
s
P
p
.002 w
.48778 .40919 m .48114 .41581 L .49784 .43897 L p
1 g
F P
s
P
p
.002 w
.5146 .46196 m .53383 .44279 L .51092 .42592 L p
1 g
F P
s
P
p
.002 w
.51927 .40949 m .51092 .42592 L .53383 .44279 L p
1 g
F P
s
P
p
.002 w
.51092 .42592 m .51927 .40949 L .492 .40085 L p
1 g
F P
s
P
p
.002 w
.492 .40085 m .48778 .40919 L .51092 .42592 L p
1 g
F P
s
P
p
.002 w
.48114 .41581 m .47279 .42002 L .48138 .44729 L p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .47279 .42002 L .48114 .41581 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .48114 .41581 L .48778 .40919 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .48778 .40919 L .492 .40085 L closepath p
1 g
F P
s
P
p
.002 w
.46382 .47827 m .49044 .47423 L .48138 .44729 L p
1 g
F P
s
P
p
.002 w
.48138 .44729 m .46327 .44999 L .46382 .47827 L p
1 g
F P
s
P
p
.002 w
.46327 .44999 m .48138 .44729 L .47279 .42002 L p
1 g
F P
s
P
p
.002 w
.53383 .44279 m .54614 .41867 L .51927 .40949 L p
1 g
F P
s
P
p
.002 w
.52197 .39142 m .51927 .40949 L .54614 .41867 L p
1 g
F P
s
P
p
.002 w
.51927 .40949 m .52197 .39142 L .49333 .39168 L p
1 g
F P
s
P
p
.002 w
.49333 .39168 m .492 .40085 L .51927 .40949 L p
1 g
F P
s
P
p
.002 w
.47279 .42002 m .4636 .42135 L .46327 .44999 L p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .4636 .42135 L .47279 .42002 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .492 .40085 L .49333 .39168 L closepath p
1 g
F P
s
P
p
.002 w
.4998 .50032 m .53114 .48436 L .5146 .46196 L p
1 g
F P
s
P
p
.002 w
.5146 .46196 m .49044 .47423 L .4998 .50032 L p
1 g
F P
s
P
p
.002 w
.53383 .44279 m .5146 .46196 L .53114 .48436 L p
1 g
F P
s
P
p
.002 w
.53114 .48436 m .5561 .45948 L .53383 .44279 L p
1 g
F P
s
P
p
.002 w
.54614 .41867 m .53383 .44279 L .5561 .45948 L p
1 g
F P
s
P
p
.002 w
.44541 .44673 m .46327 .44999 L .4636 .42135 L p
1 g
F P
s
P
p
.002 w
.4636 .42135 m .45457 .41966 L .44541 .44673 L p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .45457 .41966 L .4636 .42135 L closepath p
1 g
F P
s
P
p
.002 w
.49164 .38267 m .49333 .39168 L .52197 .39142 L p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .49333 .39168 L .49164 .38267 L closepath p
1 g
F P
s
P
p
.002 w
.43752 .47361 m .46382 .47827 L .46327 .44999 L p
1 g
F P
s
P
p
.002 w
.46327 .44999 m .44541 .44673 L .43752 .47361 L p
1 g
F P
s
P
p
.002 w
.46526 .50569 m .4998 .50032 L .49044 .47423 L p
1 g
F P
s
P
p
.002 w
.49044 .47423 m .46382 .47827 L .46526 .50569 L p
1 g
F P
s
P
p
.002 w
.54614 .41867 m .55021 .39211 L .52197 .39142 L p
1 g
F P
s
P
p
.002 w
.5187 .3736 m .52197 .39142 L .55021 .39211 L p
1 g
F P
s
P
p
.002 w
.52197 .39142 m .5187 .3736 L .49164 .38267 L p
1 g
F P
s
P
p
.002 w
.42973 .43783 m .44541 .44673 L .45457 .41966 L p
1 g
F P
s
P
p
.002 w
.45457 .41966 m .44667 .41512 L .42973 .43783 L p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .44667 .41512 L .45457 .41966 L closepath p
1 g
F P
s
P
p
.002 w
.5561 .45948 m .57213 .42822 L .54614 .41867 L p
1 g
F P
s
P
p
.002 w
.55021 .39211 m .54614 .41867 L .57213 .42822 L p
1 g
F P
s
P
p
.002 w
.48707 .37479 m .49164 .38267 L .5187 .3736 L p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .49164 .38267 L .48707 .37479 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .43721 .39035 L .43748 .39963 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .43748 .39963 L .44075 .40819 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .44075 .40819 L .44667 .41512 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .48707 .37479 L .48012 .36889 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .48012 .36889 L .47153 .36562 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .47153 .36562 L .46223 .36537 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .46223 .36537 L .45324 .36816 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .45324 .36816 L .44555 .3737 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .44555 .3737 L .44 .38138 L closepath p
1 g
F P
s
P
p
.002 w
.46482 .39289 m .44 .38138 L .43721 .39035 L closepath p
1 g
F P
s
P
p
.002 w
.41792 .42417 m .42973 .43783 L .44667 .41512 L p
1 g
F P
s
P
p
.002 w
.44667 .41512 m .44075 .40819 L .41792 .42417 L p
1 g
F P
s
P
p
.002 w
.41433 .4606 m .43752 .47361 L .44541 .44673 L p
1 g
F P
s
P
p
.002 w
.44541 .44673 m .42973 .43783 L .41433 .4606 L p
1 g
F P
s
P
p
.002 w
.5187 .3736 m .50976 .35794 L .48707 .37479 L p
1 g
F P
s
P
p
.002 w
.48012 .36889 m .48707 .37479 L .50976 .35794 L p
1 g
F P
s
P
p
.002 w
.55021 .39211 m .54553 .36584 L .5187 .3736 L p
1 g
F P
s
P
p
.002 w
.50976 .35794 m .5187 .3736 L .54553 .36584 L p
1 g
F P
s
P
p
.002 w
.43105 .49978 m .46526 .50569 L .46382 .47827 L p
1 g
F P
s
P
p
.002 w
.46382 .47827 m .43752 .47361 L .43105 .49978 L p
1 g
F P
s
P
p
.002 w
.50932 .52509 m .54714 .50575 L .53114 .48436 L p
1 g
F P
s
P
p
.002 w
.53114 .48436 m .4998 .50032 L .50932 .52509 L p
1 g
F P
s
P
p
.002 w
.5561 .45948 m .53114 .48436 L .54714 .50575 L p
1 g
F P
s
P
p
.002 w
.54714 .50575 m .57729 .4757 L .5561 .45948 L p
1 g
F P
s
P
p
.002 w
.57213 .42822 m .5561 .45948 L .57729 .4757 L p
1 g
F P
s
P
p
.002 w
.57213 .42822 m .57753 .39374 L .55021 .39211 L p
1 g
F P
s
P
p
.002 w
.54553 .36584 m .55021 .39211 L .57753 .39374 L p
1 g
F P
s
P
p
.002 w
.41133 .40721 m .41792 .42417 L .44075 .40819 L p
1 g
F P
s
P
p
.002 w
.44075 .40819 m .43748 .39963 L .41133 .40721 L p
1 g
F P
s
P
p
.002 w
.50976 .35794 m .49605 .34617 L .48012 .36889 L p
1 g
F P
s
P
p
.002 w
.47153 .36562 m .48012 .36889 L .49605 .34617 L p
1 g
F P
s
P
p
.002 w
.41074 .38877 m .41133 .40721 L .43748 .39963 L p
1 g
F P
s
P
p
.002 w
.43748 .39963 m .43721 .39035 L .41074 .38877 L p
1 g
F P
s
P
p
.002 w
.46759 .53171 m .50932 .52509 L .4998 .50032 L p
1 g
F P
s
P
p
.002 w
.4998 .50032 m .46526 .50569 L .46759 .53171 L p
1 g
F P
s
P
p
.002 w
.39679 .44054 m .41433 .4606 L .42973 .43783 L p
1 g
F P
s
P
p
.002 w
.42973 .43783 m .41792 .42417 L .39679 .44054 L p
1 g
F P
s
P
p
.002 w
.49605 .34617 m .47903 .33961 L .47153 .36562 L p
1 g
F P
s
P
p
.002 w
.46223 .36537 m .47153 .36562 L .47903 .33961 L p
1 g
F P
s
P
p
.002 w
.57729 .4757 m .59674 .43797 L .57213 .42822 L p
1 g
F P
s
P
p
.002 w
.57753 .39374 m .57213 .42822 L .59674 .43797 L p
1 g
F P
s
P
p
.002 w
.54553 .36584 m .53247 .34269 L .50976 .35794 L p
1 g
F P
s
P
p
.002 w
.49605 .34617 m .50976 .35794 L .53247 .34269 L p
1 g
F P
s
P
p
.002 w
.41624 .37089 m .41074 .38877 L .43721 .39035 L p
1 g
F P
s
P
p
.002 w
.43721 .39035 m .44 .38138 L .41624 .37089 L p
1 g
F P
s
P
p
.002 w
.47903 .33961 m .46053 .33903 L .46223 .36537 L p
1 g
F P
s
P
p
.002 w
.45324 .36816 m .46223 .36537 L .46053 .33903 L p
1 g
F P
s
P
p
.002 w
.40079 .48301 m .43105 .49978 L .43752 .47361 L p
1 g
F P
s
P
p
.002 w
.43752 .47361 m .41433 .4606 L .40079 .48301 L p
1 g
F P
s
P
p
.002 w
.42728 .35558 m .41624 .37089 L .44 .38138 L p
1 g
F P
s
P
p
.002 w
.44 .38138 m .44555 .3737 L .42728 .35558 L p
1 g
F P
s
P
p
.002 w
.46053 .33903 m .44262 .34455 L .45324 .36816 L p
1 g
F P
s
P
p
.002 w
.44555 .3737 m .45324 .36816 L .44262 .34455 L p
1 g
F P
s
P
p
.002 w
.44262 .34455 m .42728 .35558 L .44555 .3737 L p
1 g
F P
s
P
p
.002 w
.57753 .39374 m .5716 .35957 L .54553 .36584 L p
1 g
F P
s
P
p
.002 w
.53247 .34269 m .54553 .36584 L .5716 .35957 L p
1 g
F P
s
P
p
.002 w
.38692 .4155 m .39679 .44054 L .41792 .42417 L p
1 g
F P
s
P
p
.002 w
.41792 .42417 m .41133 .40721 L .38692 .4155 L p
1 g
F P
s
P
p
.002 w
.42618 .52473 m .46759 .53171 L .46526 .50569 L p
1 g
F P
s
P
p
.002 w
.46526 .50569 m .43105 .49978 L .42618 .52473 L p
1 g
F P
s
P
p
.002 w
.53247 .34269 m .51232 .32519 L .49605 .34617 L p
1 g
F P
s
P
p
.002 w
.47903 .33961 m .49605 .34617 L .51232 .32519 L p
1 g
F P
s
P
p
.002 w
.59674 .43797 m .60341 .39631 L .57753 .39374 L p
1 g
F P
s
P
p
.002 w
.5716 .35957 m .57753 .39374 L .60341 .39631 L p
1 g
F P
s
P
p
.002 w
.51879 .54802 m .56229 .52569 L .54714 .50575 L p
1 g
F P
s
P
p
.002 w
.54714 .50575 m .50932 .52509 L .51879 .54802 L p
1 g
F P
s
P
p
.002 w
.57729 .4757 m .54714 .50575 L .56229 .52569 L p
1 g
F P
s
P
p
.002 w
.56229 .52569 m .597 .49113 L .57729 .4757 L p
1 g
F P
s
P
p
.002 w
.59674 .43797 m .57729 .4757 L .597 .49113 L p
1 g
F P
s
P
p
.002 w
.3778 .45699 m .40079 .48301 L .41433 .4606 L p
1 g
F P
s
P
p
.002 w
.41433 .4606 m .39679 .44054 L .3778 .45699 L p
1 g
F P
s
P
p
.002 w
.38593 .38819 m .38692 .4155 L .41133 .40721 L p
1 g
F P
s
P
p
.002 w
.41133 .40721 m .41074 .38877 L .38593 .38819 L p
1 g
F P
s
P
p
.002 w
.51232 .32519 m .48718 .31536 L .47903 .33961 L p
1 g
F P
s
P
p
.002 w
.46053 .33903 m .47903 .33961 L .48718 .31536 L p
1 g
F P
s
P
p
.002 w
.5716 .35957 m .55477 .32934 L .53247 .34269 L p
1 g
F P
s
P
p
.002 w
.51232 .32519 m .53247 .34269 L .55477 .32934 L p
1 g
F P
s
P
p
.002 w
.47077 .55577 m .51879 .54802 L .50932 .52509 L p
1 g
F P
s
P
p
.002 w
.50932 .52509 m .46759 .53171 L .47077 .55577 L p
1 g
F P
s
P
p
.002 w
.597 .49113 m .61945 .44774 L .59674 .43797 L p
1 g
F P
s
P
p
.002 w
.60341 .39631 m .59674 .43797 L .61945 .44774 L p
1 g
F P
s
P
p
.002 w
.38944 .50461 m .42618 .52473 L .43105 .49978 L p
1 g
F P
s
P
p
.002 w
.43105 .49978 m .40079 .48301 L .38944 .50461 L p
1 g
F P
s
P
p
.002 w
.39404 .36166 m .38593 .38819 L .41074 .38877 L p
1 g
F P
s
P
p
.002 w
.41074 .38877 m .41624 .37089 L .39404 .36166 L p
1 g
F P
s
P
p
.002 w
.48718 .31536 m .45978 .31441 L .46053 .33903 L p
1 g
F P
s
P
p
.002 w
.44262 .34455 m .46053 .33903 L .45978 .31441 L p
1 g
F P
s
P
p
.002 w
.60341 .39631 m .59642 .35494 L .5716 .35957 L p
1 g
F P
s
P
p
.002 w
.55477 .32934 m .5716 .35957 L .59642 .35494 L p
1 g
F P
s
P
p
.002 w
.4104 .33891 m .39404 .36166 L .41624 .37089 L p
1 g
F P
s
P
p
.002 w
.41624 .37089 m .42728 .35558 L .4104 .33891 L p
1 g
F P
s
P
p
.002 w
.45978 .31441 m .43318 .32254 L .44262 .34455 L p
1 g
F P
s
P
p
.002 w
.42728 .35558 m .44262 .34455 L .43318 .32254 L p
1 g
F P
s
P
p
.002 w
.36477 .42436 m .3778 .45699 L .39679 .44054 L p
1 g
F P
s
P
p
.002 w
.39679 .44054 m .38692 .4155 L .36477 .42436 L p
1 g
F P
s
P
p
.002 w
.43318 .32254 m .4104 .33891 L .42728 .35558 L p
1 g
F P
s
P
p
.002 w
.55477 .32934 m .52862 .3064 L .51232 .32519 L p
1 g
F P
s
P
p
.002 w
.48718 .31536 m .51232 .32519 L .52862 .3064 L p
1 g
F P
s
P
p
.002 w
.42304 .54792 m .47077 .55577 L .46759 .53171 L p
1 g
F P
s
P
p
.002 w
.46759 .53171 m .42618 .52473 L .42304 .54792 L p
1 g
F P
s
P
p
.002 w
.61945 .44774 m .62728 .39979 L .60341 .39631 L p
1 g
F P
s
P
p
.002 w
.59642 .35494 m .60341 .39631 L .62728 .39979 L p
1 g
F P
s
P
p
.002 w
.36142 .47319 m .38944 .50461 L .40079 .48301 L p
1 g
F P
s
P
p
.002 w
.40079 .48301 m .3778 .45699 L .36142 .47319 L p
1 g
F P
s
P
p
.002 w
.52804 .56859 m .57627 .54376 L .56229 .52569 L p
1 g
F P
s
P
p
.002 w
.56229 .52569 m .51879 .54802 L .52804 .56859 L p
1 g
F P
s
P
p
.002 w
.597 .49113 m .56229 .52569 L .57627 .54376 L p
1 g
F P
s
P
p
.002 w
.36335 .38867 m .36477 .42436 L .38692 .4155 L p
1 g
F P
s
P
p
.002 w
.38692 .4155 m .38593 .38819 L .36335 .38867 L p
1 g
F P
s
P
p
.002 w
.57627 .54376 m .61477 .50542 L .597 .49113 L p
1 g
F P
s
P
p
.002 w
.61945 .44774 m .597 .49113 L .61477 .50542 L p
1 g
F P
s
P
p
.002 w
.59642 .35494 m .5762 .31823 L .55477 .32934 L p
1 g
F P
s
P
p
.002 w
.52862 .3064 m .55477 .32934 L .5762 .31823 L p
1 g
F P
s
P
p
.002 w
.52862 .3064 m .49586 .29343 L .48718 .31536 L p
1 g
F P
s
P
p
.002 w
.45978 .31441 m .48718 .31536 L .49586 .29343 L p
1 g
F P
s
P
p
.002 w
.47479 .57733 m .52804 .56859 L .51879 .54802 L p
1 g
F P
s
P
p
.002 w
.51879 .54802 m .47077 .55577 L .47479 .57733 L p
1 g
F P
s
P
p
.002 w
.38058 .52491 m .42304 .54792 L .42618 .52473 L p
1 g
F P
s
P
p
.002 w
.42618 .52473 m .38944 .50461 L .38058 .52491 L p
1 g
F P
s
P
p
.002 w
.61477 .50542 m .63975 .45733 L .61945 .44774 L p
1 g
F P
s
P
p
.002 w
.62728 .39979 m .61945 .44774 L .63975 .45733 L p
1 g
F P
s
P
p
.002 w
.37389 .3539 m .36335 .38867 L .38593 .38819 L p
1 g
F P
s
P
p
.002 w
.38593 .38819 m .39404 .36166 L .37389 .3539 L p
1 g
F P
s
P
p
.002 w
.62728 .39979 m .61942 .3521 L .59642 .35494 L p
1 g
F P
s
P
p
.002 w
.5762 .31823 m .59642 .35494 L .61942 .3521 L p
1 g
F P
s
P
p
.002 w
.49586 .29343 m .46002 .29207 L .45978 .31441 L p
1 g
F P
s
P
p
.002 w
.43318 .32254 m .45978 .31441 L .46002 .29207 L p
1 g
F P
s
P
p
.002 w
.34544 .43364 m .36142 .47319 L .3778 .45699 L p
1 g
F P
s
P
p
.002 w
.3778 .45699 m .36477 .42436 L .34544 .43364 L p
1 g
F P
s
P
p
.002 w
.3953 .32408 m .37389 .3539 L .39404 .36166 L p
1 g
F P
s
P
p
.002 w
.39404 .36166 m .4104 .33891 L .3953 .32408 L p
1 g
F P
s
P
p
.002 w
.46002 .29207 m .42517 .30265 L .43318 .32254 L p
1 g
F P
s
P
p
.002 w
.4104 .33891 m .43318 .32254 L .42517 .30265 L p
1 g
F P
s
P
p
.002 w
.5762 .31823 m .54463 .29026 L .52862 .3064 L p
1 g
F P
s
P
p
.002 w
.49586 .29343 m .52862 .3064 L .54463 .29026 L p
1 g
F P
s
P
p
.002 w
.42517 .30265 m .3953 .32408 L .4104 .33891 L p
1 g
F P
s
P
p
.002 w
.42178 .5688 m .47479 .57733 L .47077 .55577 L p
1 g
F P
s
P
p
.002 w
.47077 .55577 m .42304 .54792 L .42178 .5688 L p
1 g
F P
s
P
p
.002 w
.63975 .45733 m .64859 .40415 L .62728 .39979 L p
1 g
F P
s
P
p
.002 w
.61942 .3521 m .62728 .39979 L .64859 .40415 L p
1 g
F P
s
P
p
.002 w
.3481 .48878 m .38058 .52491 L .38944 .50461 L p
1 g
F P
s
P
p
.002 w
.38944 .50461 m .36142 .47319 L .3481 .48878 L p
1 g
F P
s
P
p
.002 w
.34358 .39023 m .34544 .43364 L .36477 .42436 L p
1 g
F P
s
P
p
.002 w
.36477 .42436 m .36335 .38867 L .34358 .39023 L p
1 g
F P
s
P
p
.002 w
.61942 .3521 m .5963 .30967 L .5762 .31823 L p
1 g
F P
s
P
p
.002 w
.54463 .29026 m .5762 .31823 L .5963 .30967 L p
1 g
F P
s
P
p
.002 w
.53687 .58626 m .58872 .55948 L .57627 .54376 L p
1 g
F P
s
P
p
.002 w
.57627 .54376 m .52804 .56859 L .53687 .58626 L p
1 g
F P
s
P
p
.002 w
.61477 .50542 m .57627 .54376 L .58872 .55948 L p
1 g
F P
s
P
p
.002 w
.58872 .55948 m .63015 .51824 L .61477 .50542 L p
1 g
F P
s
P
p
.002 w
.63975 .45733 m .61477 .50542 L .63015 .51824 L p
1 g
F P
s
P
p
.002 w
.54463 .29026 m .50489 .27435 L .49586 .29343 L p
1 g
F P
s
P
p
.002 w
.46002 .29207 m .49586 .29343 L .50489 .27435 L p
1 g
F P
s
P
p
.002 w
.37454 .54342 m .42178 .5688 L .42304 .54792 L p
1 g
F P
s
P
p
.002 w
.42304 .54792 m .38058 .52491 L .37454 .54342 L p
1 g
F P
s
P
p
.002 w
.47958 .59579 m .53687 .58626 L .52804 .56859 L p
1 g
F P
s
P
p
.002 w
.52804 .56859 m .47479 .57733 L .47958 .59579 L p
1 g
F P
s
P
p
.002 w
.63015 .51824 m .65711 .46653 L .63975 .45733 L p
1 g
F P
s
P
p
.002 w
.64859 .40415 m .63975 .45733 L .65711 .46653 L p
1 g
F P
s
P
p
.002 w
.64859 .40415 m .64005 .35119 L .61942 .3521 L p
1 g
F P
s
P
p
.002 w
.5963 .30967 m .61942 .3521 L .64005 .35119 L p
1 g
F P
s
P
p
.002 w
.35633 .34787 m .34358 .39023 L .36335 .38867 L p
1 g
F P
s
P
p
.002 w
.36335 .38867 m .37389 .3539 L .35633 .34787 L p
1 g
F P
s
P
p
.002 w
.50489 .27435 m .4613 .27257 L .46002 .29207 L p
1 g
F P
s
P
p
.002 w
.42517 .30265 m .46002 .29207 L .4613 .27257 L p
1 g
F P
s
P
p
.002 w
.32947 .44314 m .3481 .48878 L .36142 .47319 L p
1 g
F P
s
P
p
.002 w
.36142 .47319 m .34544 .43364 L .32947 .44314 L p
1 g
F P
s
P
p
.002 w
.5963 .30967 m .55998 .27724 L .54463 .29026 L p
1 g
F P
s
P
p
.002 w
.50489 .27435 m .54463 .29026 L .55998 .27724 L p
1 g
F P
s
P
p
.002 w
.3824 .3115 m .35633 .34787 L .37389 .3539 L p
1 g
F P
s
P
p
.002 w
.37389 .3539 m .3953 .32408 L .3824 .3115 L p
1 g
F P
s
P
p
.002 w
.4613 .27257 m .41882 .2854 L .42517 .30265 L p
1 g
F P
s
P
p
.002 w
.3953 .32408 m .42517 .30265 L .41882 .2854 L p
1 g
F P
s
P
p
.002 w
.42252 .58678 m .47958 .59579 L .47479 .57733 L p
1 g
F P
s
P
p
.002 w
.47479 .57733 m .42178 .5688 L .42252 .58678 L p
1 g
F P
s
P
p
.002 w
.41882 .2854 m .3824 .3115 L .3953 .32408 L p
1 g
F P
s
P
p
.002 w
.65711 .46653 m .66676 .40934 L .64859 .40415 L p
1 g
F P
s
P
p
.002 w
.64005 .35119 m .64859 .40415 L .66676 .40934 L p
1 g
F P
s
P
p
.002 w
.33829 .50339 m .37454 .54342 L .38058 .52491 L p
1 g
F P
s
P
p
.002 w
.38058 .52491 m .3481 .48878 L .33829 .50339 L p
1 g
F P
s
P
p
.002 w
.64005 .35119 m .61455 .30397 L .5963 .30967 L p
1 g
F P
s
P
p
.002 w
.55998 .27724 m .5963 .30967 L .61455 .30397 L p
1 g
F P
s
P
p
.002 w
.32719 .3929 m .32947 .44314 L .34544 .43364 L p
1 g
F P
s
P
p
.002 w
.34544 .43364 m .34358 .39023 L .32719 .3929 L p
1 g
F P
s
P
p
.002 w
.55998 .27724 m .5141 .25869 L .50489 .27435 L p
1 g
F P
s
P
p
.002 w
.4613 .27257 m .50489 .27435 L .5141 .25869 L p
1 g
F P
s
P
p
.002 w
.54504 .6005 m .59931 .57241 L .58872 .55948 L p
1 g
F P
s
P
p
.002 w
.58872 .55948 m .53687 .58626 L .54504 .6005 L p
1 g
F P
s
P
p
.002 w
.63015 .51824 m .58872 .55948 L .59931 .57241 L p
1 g
F P
s
P
p
.002 w
.59931 .57241 m .64269 .52923 L .63015 .51824 L p
1 g
F P
s
P
p
.002 w
.65711 .46653 m .63015 .51824 L .64269 .52923 L p
1 g
F P
s
P
p
.002 w
.37158 .55962 m .42252 .58678 L .42178 .5688 L p
1 g
F P
s
P
p
.002 w
.42178 .5688 m .37454 .54342 L .37158 .55962 L p
1 g
F P
s
P
p
.002 w
.48509 .61059 m .54504 .6005 L .53687 .58626 L p
1 g
F P
s
P
p
.002 w
.53687 .58626 m .47958 .59579 L .48509 .61059 L p
1 g
F P
s
P
p
.002 w
.66676 .40934 m .65774 .35231 L .64005 .35119 L p
1 g
F P
s
P
p
.002 w
.61455 .30397 m .64005 .35119 L .65774 .35231 L p
1 g
F P
s
P
p
.002 w
.64269 .52923 m .67098 .47512 L .65711 .46653 L p
1 g
F P
s
P
p
.002 w
.66676 .40934 m .65711 .46653 L .67098 .47512 L p
1 g
F P
s
P
p
.002 w
.34189 .34378 m .32719 .3929 L .34358 .39023 L p
1 g
F P
s
P
p
.002 w
.34358 .39023 m .35633 .34787 L .34189 .34378 L p
1 g
F P
s
P
p
.002 w
.5141 .25869 m .46364 .25651 L .4613 .27257 L p
1 g
F P
s
P
p
.002 w
.41882 .2854 m .4613 .27257 L .46364 .25651 L p
1 g
F P
s
P
p
.002 w
.31741 .45266 m .33829 .50339 L .3481 .48878 L p
1 g
F P
s
P
p
.002 w
.3481 .48878 m .32947 .44314 L .31741 .45266 L p
1 g
F P
s
P
p
.002 w
.61455 .30397 m .57429 .26777 L .55998 .27724 L p
1 g
F P
s
P
p
.002 w
.5141 .25869 m .55998 .27724 L .57429 .26777 L p
1 g
F P
s
P
p
.002 w
.37212 .30157 m .34189 .34378 L .35633 .34787 L p
1 g
F P
s
P
p
.002 w
.35633 .34787 m .3824 .3115 L .37212 .30157 L p
1 g
F P
s
P
p
.002 w
.46364 .25651 m .41437 .27131 L .41882 .2854 L p
1 g
F P
s
P
p
.002 w
.3824 .3115 m .41882 .2854 L .41437 .27131 L p
1 g
F P
s
P
p
.002 w
.42534 .60129 m .48509 .61059 L .47958 .59579 L p
1 g
F P
s
P
p
.002 w
.47958 .59579 m .42252 .58678 L .42534 .60129 L p
1 g
F P
s
P
p
.002 w
.41437 .27131 m .37212 .30157 L .3824 .3115 L p
1 g
F P
s
P
p
.002 w
.67098 .47512 m .6812 .41527 L .66676 .40934 L p
1 g
F P
s
P
p
.002 w
.65774 .35231 m .66676 .40934 L .6812 .41527 L p
1 g
F P
s
P
p
.002 w
.33242 .51662 m .37158 .55962 L .37454 .54342 L p
1 g
F P
s
P
p
.002 w
.37454 .54342 m .33829 .50339 L .33242 .51662 L p
1 g
F P
s
P
p
.002 w
.65774 .35231 m .63044 .3014 L .61455 .30397 L p
1 g
F P
s
P
p
.002 w
.57429 .26777 m .61455 .30397 L .63044 .3014 L p
1 g
F P
s
P
p
.002 w
.31476 .39668 m .31741 .45266 L .32947 .44314 L p
1 g
F P
s
P
p
.002 w
.32947 .44314 m .32719 .3929 L .31476 .39668 L p
1 g
F P
s
P
p
.002 w
.57429 .26777 m .52328 .24698 L .5141 .25869 L p
1 g
F P
s
P
p
.002 w
.46364 .25651 m .5141 .25869 L .52328 .24698 L p
1 g
F P
s
P
p
.002 w
.55234 .61077 m .60767 .58208 L .59931 .57241 L p
1 g
F P
s
P
p
.002 w
.59931 .57241 m .54504 .6005 L .55234 .61077 L p
1 g
F P
s
P
p
.002 w
.64269 .52923 m .59931 .57241 L .60767 .58208 L p
1 g
F P
s
P
p
.002 w
.60767 .58208 m .65194 .53803 L .64269 .52923 L p
1 g
F P
s
P
p
.002 w
.67098 .47512 m .64269 .52923 L .65194 .53803 L p
1 g
F P
s
P
p
.002 w
.37195 .57299 m .42534 .60129 L .42252 .58678 L p
1 g
F P
s
P
p
.002 w
.42252 .58678 m .37158 .55962 L .37195 .57299 L p
1 g
F P
s
P
p
.002 w
.49122 .62114 m .55234 .61077 L .54504 .6005 L p
1 g
F P
s
P
p
.002 w
.54504 .6005 m .48509 .61059 L .49122 .62114 L p
1 g
F P
s
P
p
.002 w
.6812 .41527 m .6719 .35556 L .65774 .35231 L p
1 g
F P
s
P
p
.002 w
.63044 .3014 m .65774 .35231 L .6719 .35556 L p
1 g
F P
s
P
p
.002 w
.65194 .53803 m .68084 .48287 L .67098 .47512 L p
1 g
F P
s
P
p
.002 w
.6812 .41527 m .67098 .47512 L .68084 .48287 L p
1 g
F P
s
P
p
.002 w
.33111 .34185 m .31476 .39668 L .32719 .3929 L p
1 g
F P
s
P
p
.002 w
.32719 .3929 m .34189 .34378 L .33111 .34185 L p
1 g
F P
s
P
p
.002 w
.3098 .46197 m .33242 .51662 L .33829 .50339 L p
1 g
F P
s
P
p
.002 w
.33829 .50339 m .31741 .45266 L .3098 .46197 L p
1 g
F P
s
P
p
.002 w
.52328 .24698 m .46704 .24446 L .46364 .25651 L p
1 g
F P
s
P
p
.002 w
.41437 .27131 m .46364 .25651 L .46704 .24446 L p
1 g
F P
s
P
p
.002 w
.63044 .3014 m .58718 .26229 L .57429 .26777 L p
1 g
F P
s
P
p
.002 w
.52328 .24698 m .57429 .26777 L .58718 .26229 L p
1 g
F P
s
P
p
.002 w
.36484 .29471 m .33111 .34185 L .34189 .34378 L p
1 g
F P
s
P
p
.002 w
.34189 .34378 m .37212 .30157 L .36484 .29471 L p
1 g
F P
s
P
p
.002 w
.4303 .61176 m .49122 .62114 L .48509 .61059 L p
1 g
F P
s
P
p
.002 w
.48509 .61059 m .42534 .60129 L .4303 .61176 L p
1 g
F P
s
P
p
.002 w
.46704 .24446 m .41204 .26093 L .41437 .27131 L p
1 g
F P
s
P
p
.002 w
.37212 .30157 m .41437 .27131 L .41204 .26093 L p
1 g
F P
s
P
p
.002 w
.41204 .26093 m .36484 .29471 L .37212 .30157 L p
1 g
F P
s
P
p
.002 w
.68084 .48287 m .69135 .42185 L .6812 .41527 L p
1 g
F P
s
P
p
.002 w
.6719 .35556 m .6812 .41527 L .69135 .42185 L p
1 g
F P
s
P
p
.002 w
.33087 .52804 m .37195 .57299 L .37158 .55962 L p
1 g
F P
s
P
p
.002 w
.37158 .55962 m .33242 .51662 L .33087 .52804 L p
1 g
F P
s
P
p
.002 w
.6719 .35556 m .64345 .3022 L .63044 .3014 L p
1 g
F P
s
P
p
.002 w
.58718 .26229 m .63044 .3014 L .64345 .3022 L p
1 g
F P
s
P
p
.002 w
.30686 .40154 m .3098 .46197 L .31741 .45266 L p
1 g
F P
s
P
p
.002 w
.31741 .45266 m .31476 .39668 L .30686 .40154 L p
1 g
F P
s
P
p
.002 w
.58718 .26229 m .5322 .23977 L .52328 .24698 L p
1 g
F P
s
P
p
.002 w
.46704 .24446 m .52328 .24698 L .5322 .23977 L p
1 g
F P
s
P
p
.002 w
.55852 .61657 m .61347 .58804 L .60767 .58208 L p
1 g
F P
s
P
p
.002 w
.60767 .58208 m .55234 .61077 L .55852 .61657 L p
1 g
F P
s
P
p
.002 w
.65194 .53803 m .60767 .58208 L .61347 .58804 L p
1 g
F P
s
P
p
.002 w
.61347 .58804 m .65745 .54428 L .65194 .53803 L p
1 g
F P
s
P
p
.002 w
.68084 .48287 m .65194 .53803 L .65745 .54428 L p
1 g
F P
s
P
p
.002 w
.37586 .583 m .4303 .61176 L .42534 .60129 L p
1 g
F P
s
P
p
.002 w
.42534 .60129 m .37195 .57299 L .37586 .583 L p
1 g
F P
s
P
p
.002 w
.69135 .42185 m .68197 .36098 L .6719 .35556 L p
1 g
F P
s
P
p
.002 w
.64345 .3022 m .6719 .35556 L .68197 .36098 L p
1 g
F P
s
P
p
.002 w
.49784 .62692 m .55852 .61657 L .55234 .61077 L p
1 g
F P
s
P
p
.002 w
.55234 .61077 m .49122 .62114 L .49784 .62692 L p
1 g
F P
s
P
p
.002 w
.65745 .54428 m .68619 .48951 L .68084 .48287 L p
1 g
F P
s
P
p
.002 w
.69135 .42185 m .68084 .48287 L .68619 .48951 L p
1 g
F P
s
P
p
.002 w
.3245 .34227 m .30686 .40154 L .31476 .39668 L p
1 g
F P
s
P
p
.002 w
.31476 .39668 m .33111 .34185 L .3245 .34227 L p
1 g
F P
s
P
p
.002 w
.30711 .4708 m .33087 .52804 L .33242 .51662 L p
1 g
F P
s
P
p
.002 w
.33242 .51662 m .3098 .46197 L .30711 .4708 L p
1 g
F P
s
P
p
.002 w
.5322 .23977 m .47148 .23698 L .46704 .24446 L p
1 g
F P
s
P
p
.002 w
.41204 .26093 m .46704 .24446 L .47148 .23698 L p
1 g
F P
s
P
p
.002 w
.64345 .3022 m .59821 .26117 L .58718 .26229 L p
1 g
F P
s
P
p
.002 w
.5322 .23977 m .58718 .26229 L .59821 .26117 L p
1 g
F P
s
P
p
.002 w
.36096 .29128 m .3245 .34227 L .33111 .34185 L p
1 g
F P
s
P
p
.002 w
.33111 .34185 m .36484 .29471 L .36096 .29128 L p
1 g
F P
s
P
p
.002 w
.4374 .61766 m .49784 .62692 L .49122 .62114 L p
1 g
F P
s
P
p
.002 w
.49122 .62114 m .4303 .61176 L .4374 .61766 L p
1 g
F P
s
P
p
.002 w
.47148 .23698 m .41202 .25475 L .41204 .26093 L p
1 g
F P
s
P
p
.002 w
.36484 .29471 m .41204 .26093 L .41202 .25475 L p
1 g
F P
s
P
p
.002 w
.68619 .48951 m .69667 .42895 L .69135 .42185 L p
1 g
F P
s
P
p
.002 w
.68197 .36098 m .69135 .42185 L .69667 .42895 L p
1 g
F P
s
P
p
.002 w
.33396 .53722 m .37586 .583 L .37195 .57299 L p
1 g
F P
s
P
p
.002 w
.37195 .57299 m .33087 .52804 L .33396 .53722 L p
1 g
F P
s
P
p
.002 w
.41202 .25475 m .36096 .29128 L .36484 .29471 L p
1 g
F P
s
P
p
.002 w
.68197 .36098 m .65304 .30657 L .64345 .3022 L p
1 g
F P
s
P
p
.002 w
.59821 .26117 m .64345 .3022 L .65304 .30657 L p
1 g
F P
s
P
p
.002 w
.304 .40741 m .30711 .4708 L .3098 .46197 L p
1 g
F P
s
P
p
.002 w
.3098 .46197 m .30686 .40154 L .304 .40741 L p
1 g
F P
s
P
p
.002 w
.59821 .26117 m .54062 .23752 L .5322 .23977 L p
1 g
F P
s
P
p
.002 w
.47148 .23698 m .5322 .23977 L .54062 .23752 L p
1 g
F P
s
P
p
.002 w
.56334 .61745 m .61638 .58991 L .61347 .58804 L p
1 g
F P
s
P
p
.002 w
.61347 .58804 m .55852 .61657 L .56334 .61745 L p
1 g
F P
s
P
p
.002 w
.65745 .54428 m .61347 .58804 L .61638 .58991 L p
1 g
F P
s
P
p
.002 w
.38341 .58916 m .4374 .61766 L .4303 .61176 L p
1 g
F P
s
P
p
.002 w
.4303 .61176 m .37586 .583 L .38341 .58916 L p
1 g
F P
s
P
p
.002 w
.61638 .58991 m .65884 .54766 L .65745 .54428 L p
1 g
F P
s
P
p
.002 w
.68619 .48951 m .65745 .54428 L .65884 .54766 L p
1 g
F P
s
P
p
.002 w
.69667 .42895 m .68741 .36856 L .68197 .36098 L p
1 g
F P
s
P
p
.002 w
.65304 .30657 m .68197 .36098 L .68741 .36856 L p
1 g
F P
s
P
p
.002 w
.50482 .62744 m .56334 .61745 L .55852 .61657 L p
1 g
F P
s
P
p
.002 w
.55852 .61657 m .49784 .62692 L .50482 .62744 L p
1 g
F P
s
P
p
.002 w
.30972 .47887 m .33396 .53722 L .33087 .52804 L p
1 g
F P
s
P
p
.002 w
.33087 .52804 m .30711 .4708 L .30972 .47887 L p
1 g
F P
s
P
p
.002 w
.3225 .34518 m .304 .40741 L .30686 .40154 L p
1 g
F P
s
P
p
.002 w
.30686 .40154 m .3245 .34227 L .3225 .34518 L p
1 g
F P
s
P
p
.002 w
.65884 .54766 m .68659 .4948 L .68619 .48951 L p
1 g
F P
s
P
p
.002 w
.69667 .42895 m .68619 .48951 L .68659 .4948 L p
1 g
F P
s
P
p
.002 w
.54062 .23752 m .47691 .23456 L .47148 .23698 L p
1 g
F P
s
P
p
.002 w
.41202 .25475 m .47148 .23698 L .47691 .23456 L p
1 g
F P
s
P
p
.004 w
.31311 .33121 m
.31817 .3339 L
s
P
p
.002 w
.65304 .30657 m .60697 .26473 L .59821 .26117 L p
1 g
F P
s
P
p
.002 w
.54062 .23752 m .59821 .26117 L .60697 .26473 L p
1 g
F P
s
P
p
.002 w
.44657 .61852 m .50482 .62744 L .49784 .62692 L p
1 g
F P
s
P
p
.002 w
.49784 .62692 m .4374 .61766 L .44657 .61852 L p
1 g
F P
s
P
p
.002 w
.36082 .29161 m .3225 .34518 L .3245 .34227 L p
1 g
F P
s
P
p
.002 w
.3245 .34227 m .36096 .29128 L .36082 .29161 L p
1 g
F P
s
P
p
.002 w
.47691 .23456 m .41446 .25322 L .41202 .25475 L p
1 g
F P
s
P
p
.002 w
.36096 .29128 m .41202 .25475 L .41446 .25322 L p
1 g
F P
s
P
p
.002 w
.34189 .54378 m .38341 .58916 L .37586 .583 L p
1 g
F P
s
P
p
.002 w
.37586 .583 m .33396 .53722 L .34189 .54378 L p
1 g
F P
s
P
p
.002 w
.68659 .4948 m .69671 .43639 L .69667 .42895 L p
1 g
F P
s
P
p
.002 w
.68741 .36856 m .69667 .42895 L .69671 .43639 L p
1 g
F P
s
P
p
.002 w
.41446 .25322 m .36082 .29161 L .36096 .29128 L p
1 g
F P
s
P
p
.002 w
.68741 .36856 m .65875 .31461 L .65304 .30657 L p
1 g
F P
s
P
p
.002 w
.60697 .26473 m .65304 .30657 L .65875 .31461 L p
1 g
F P
s
P
p
.002 w
.30657 .4142 m .30972 .47887 L .30711 .4708 L p
1 g
F P
s
P
p
.002 w
.30711 .4708 m .304 .40741 L .30657 .4142 L p
1 g
F P
s
P
p
.002 w
.60697 .26473 m .54825 .24061 L .54062 .23752 L p
1 g
F P
s
P
p
.002 w
.47691 .23456 m .54062 .23752 L .54825 .24061 L p
1 g
F P
s
P
p
.002 w
.39461 .59105 m .44657 .61852 L .4374 .61766 L p
1 g
F P
s
P
p
.002 w
.4374 .61766 m .38341 .58916 L .39461 .59105 L p
1 g
F P
s
P
p
.002 w
.56658 .61306 m .61613 .58734 L .61638 .58991 L p
1 g
F P
s
P
p
.002 w
.61638 .58991 m .56334 .61745 L .56658 .61306 L p
1 g
F P
s
P
p
.002 w
.65884 .54766 m .61638 .58991 L .61613 .58734 L p
1 g
F P
s
P
p
.002 w
.61613 .58734 m .6558 .54787 L .65884 .54766 L p
1 g
F P
s
P
p
.002 w
.68659 .4948 m .65884 .54766 L .6558 .54787 L p
1 g
F P
s
P
p
.002 w
.69671 .43639 m .68778 .37821 L .68741 .36856 L p
1 g
F P
s
P
p
.002 w
.65875 .31461 m .68741 .36856 L .68778 .37821 L p
1 g
F P
s
P
p
.002 w
.51196 .62237 m .56658 .61306 L .56334 .61745 L p
1 g
F P
s
P
p
.002 w
.56334 .61745 m .50482 .62744 L .51196 .62237 L p
1 g
F P
s
P
p
.002 w
.31792 .48591 m .34189 .54378 L .33396 .53722 L p
1 g
F P
s
P
p
.002 w
.33396 .53722 m .30972 .47887 L .31792 .48591 L p
1 g
F P
s
P
p
.002 w
.3255 .35066 m .30657 .4142 L .304 .40741 L p
1 g
F P
s
P
p
.002 w
.304 .40741 m .3225 .34518 L .3255 .35066 L p
1 g
F P
s
P
p
.002 w
.6558 .54787 m .68171 .49849 L .68659 .4948 L p
1 g
F P
s
P
p
.002 w
.69671 .43639 m .68659 .4948 L .68171 .49849 L p
1 g
F P
s
P
p
.002 w
.54825 .24061 m .48323 .23762 L .47691 .23456 L p
1 g
F P
s
P
p
.002 w
.41446 .25322 m .47691 .23456 L .48323 .23762 L p
1 g
F P
s
P
p
.002 w
.65875 .31461 m .61306 .27315 L .60697 .26473 L p
1 g
F P
s
P
p
.002 w
.54825 .24061 m .60697 .26473 L .61306 .27315 L p
1 g
F P
s
P
p
.002 w
.45767 .61399 m .51196 .62237 L .50482 .62744 L p
1 g
F P
s
P
p
.002 w
.50482 .62744 m .44657 .61852 L .45767 .61399 L p
1 g
F P
s
P
p
.002 w
.36466 .29593 m .3255 .35066 L .3225 .34518 L p
1 g
F P
s
P
p
.002 w
.3225 .34518 m .36082 .29161 L .36466 .29593 L p
1 g
F P
s
P
p
.002 w
.35473 .54732 m .39461 .59105 L .38341 .58916 L p
1 g
F P
s
P
p
.002 w
.38341 .58916 m .34189 .54378 L .35473 .54732 L p
1 g
F P
s
P
p
.002 w
.48323 .23762 m .41947 .2567 L .41446 .25322 L p
1 g
F P
s
P
p
.002 w
.36082 .29161 m .41446 .25322 L .41947 .2567 L p
1 g
F P
s
P
p
.002 w
.68171 .49849 m .69112 .44399 L .69671 .43639 L p
1 g
F P
s
P
p
.002 w
.68778 .37821 m .69671 .43639 L .69112 .44399 L p
1 g
F P
s
P
p
.002 w
.41947 .2567 m .36466 .29593 L .36082 .29161 L p
1 g
F P
s
P
p
.002 w
.68778 .37821 m .66015 .32631 L .65875 .31461 L p
1 g
F P
s
P
p
.002 w
.61306 .27315 m .65875 .31461 L .66015 .32631 L p
1 g
F P
s
P
p
.002 w
.31487 .42175 m .31792 .48591 L .30972 .47887 L p
1 g
F P
s
P
p
.002 w
.30972 .47887 m .30657 .4142 L .31487 .42175 L p
1 g
F P
s
P
p
.002 w
.61306 .27315 m .55482 .2493 L .54825 .24061 L p
1 g
F P
s
P
p
.002 w
.48323 .23762 m .54825 .24061 L .55482 .2493 L p
1 g
F P
s
P
p
.002 w
.40935 .58833 m .45767 .61399 L .44657 .61852 L p
1 g
F P
s
P
p
.002 w
.44657 .61852 m .39461 .59105 L .40935 .58833 L p
1 g
F P
s
P
p
.002 w
.56803 .60319 m .6125 .58013 L .61613 .58734 L p
1 g
F P
s
P
p
.002 w
.61613 .58734 m .56658 .61306 L .56803 .60319 L p
1 g
F P
s
P
p
.002 w
.6558 .54787 m .61613 .58734 L .6125 .58013 L p
1 g
F P
s
P
p
.002 w
.6125 .58013 m .64812 .54469 L .6558 .54787 L p
1 g
F P
s
P
p
.002 w
.68171 .49849 m .6558 .54787 L .64812 .54469 L p
1 g
F P
s
P
p
.002 w
.69112 .44399 m .68273 .38979 L .68778 .37821 L p
1 g
F P
s
P
p
.002 w
.66015 .32631 m .68778 .37821 L .68273 .38979 L p
1 g
F P
s
P
p
.002 w
.33179 .49161 m .35473 .54732 L .34189 .54378 L p
1 g
F P
s
P
p
.002 w
.34189 .54378 m .31792 .48591 L .33179 .49161 L p
1 g
F P
s
P
p
.002 w
.51905 .61148 m .56803 .60319 L .56658 .61306 L p
1 g
F P
s
P
p
.002 w
.56658 .61306 m .51196 .62237 L .51905 .61148 L p
1 g
F P
s
P
p
.002 w
.33372 .35871 m .31487 .42175 L .30657 .4142 L p
1 g
F P
s
P
p
.002 w
.30657 .4142 m .3255 .35066 L .33372 .35871 L p
1 g
F P
s
P
p
.002 w
.64812 .54469 m .67134 .50037 L .68171 .49849 L p
1 g
F P
s
P
p
.002 w
.69112 .44399 m .68171 .49849 L .67134 .50037 L p
1 g
F P
s
P
p
.002 w
.66015 .32631 m .61613 .2865 L .61306 .27315 L p
1 g
F P
s
P
p
.002 w
.55482 .2493 m .61306 .27315 L .61613 .2865 L p
1 g
F P
s
P
p
.002 w
.55482 .2493 m .49032 .24641 L .48323 .23762 L p
1 g
F P
s
P
p
.002 w
.41947 .2567 m .48323 .23762 L .49032 .24641 L p
1 g
F P
s
P
p
.002 w
.47047 .60388 m .51905 .61148 L .51196 .62237 L p
1 g
F P
s
P
p
.002 w
.51196 .62237 m .45767 .61399 L .47047 .60388 L p
1 g
F P
s
P
p
.002 w
.37237 .54756 m .40935 .58833 L .39461 .59105 L p
1 g
F P
s
P
p
.002 w
.39461 .59105 m .35473 .54732 L .37237 .54756 L p
1 g
F P
s
P
p
.002 w
.37263 .30439 m .33372 .35871 L .3255 .35066 L p
1 g
F P
s
P
p
.002 w
.3255 .35066 m .36466 .29593 L .37263 .30439 L p
1 g
F P
s
P
p
.004 w
.31817 .3339 m
.32757 .33889 L
s
P
p
.002 w
.67134 .50037 m .67971 .45152 L .69112 .44399 L p
1 g
F P
s
P
p
.002 w
.68273 .38979 m .69112 .44399 L .67971 .45152 L p
1 g
F P
s
P
p
.002 w
.49032 .24641 m .42704 .26541 L .41947 .2567 L p
1 g
F P
s
P
p
.002 w
.36466 .29593 m .41947 .2567 L .42704 .26541 L p
1 g
F P
s
P
p
.002 w
.68273 .38979 m .65691 .34153 L .66015 .32631 L p
1 g
F P
s
P
p
.002 w
.61613 .2865 m .66015 .32631 L .65691 .34153 L p
1 g
F P
s
P
p
.002 w
.42704 .26541 m .37263 .30439 L .36466 .29593 L p
1 g
F P
s
P
p
.002 w
.32899 .42987 m .33179 .49161 L .31792 .48591 L p
1 g
F P
s
P
p
.002 w
.31792 .48591 m .31487 .42175 L .32899 .42987 L p
1 g
F P
s
P
p
.002 w
.61613 .2865 m .56005 .26367 L .55482 .2493 L p
1 g
F P
s
P
p
.002 w
.49032 .24641 m .55482 .2493 L .56005 .26367 L p
1 g
F P
s
P
p
.002 w
.42736 .58081 m .47047 .60388 L .45767 .61399 L p
1 g
F P
s
P
p
.002 w
.45767 .61399 m .40935 .58833 L .42736 .58081 L p
1 g
F P
s
P
p
.002 w
.67971 .45152 m .67209 .40303 L .68273 .38979 L p
1 g
F P
s
P
p
.002 w
.65691 .34153 m .68273 .38979 L .67209 .40303 L p
1 g
F P
s
P
p
.002 w
.56752 .58781 m .60541 .5682 L .6125 .58013 L p
1 g
F P
s
P
p
.002 w
.6125 .58013 m .56803 .60319 L .56752 .58781 L p
1 g
F P
s
P
p
.002 w
.64812 .54469 m .6125 .58013 L .60541 .5682 L p
1 g
F P
s
P
p
.002 w
.60541 .5682 m .63574 .53801 L .64812 .54469 L p
1 g
F P
s
P
p
.002 w
.67134 .50037 m .64812 .54469 L .63574 .53801 L p
1 g
F P
s
P
p
.002 w
.35121 .4957 m .37237 .54756 L .35473 .54732 L p
1 g
F P
s
P
p
.002 w
.35473 .54732 m .33179 .49161 L .35121 .4957 L p
1 g
F P
s
P
p
.002 w
.52586 .59477 m .56752 .58781 L .56803 .60319 L p
1 g
F P
s
P
p
.002 w
.56803 .60319 m .51905 .61148 L .52586 .59477 L p
1 g
F P
s
P
p
.002 w
.34723 .36922 m .32899 .42987 L .31487 .42175 L p
1 g
F P
s
P
p
.002 w
.31487 .42175 m .33372 .35871 L .34723 .36922 L p
1 g
F P
s
P
p
.002 w
.63574 .53801 m .65547 .50026 L .67134 .50037 L p
1 g
F P
s
P
p
.002 w
.67971 .45152 m .67134 .50037 L .65547 .50026 L p
1 g
F P
s
P
p
.002 w
.65691 .34153 m .61588 .30463 L .61613 .2865 L p
1 g
F P
s
P
p
.002 w
.56005 .26367 m .61613 .2865 L .61588 .30463 L p
1 g
F P
s
P
p
.002 w
.56005 .26367 m .49798 .26102 L .49032 .24641 L p
1 g
F P
s
P
p
.002 w
.42704 .26541 m .49032 .24641 L .49798 .26102 L p
1 g
F P
s
P
p
.002 w
.39449 .5443 m .42736 .58081 L .40935 .58833 L p
1 g
F P
s
P
p
.002 w
.40935 .58833 m .37237 .54756 L .39449 .5443 L p
1 g
F P
s
P
p
.002 w
.48463 .5882 m .52586 .59477 L .51905 .61148 L p
1 g
F P
s
P
p
.002 w
.51905 .61148 m .47047 .60388 L .48463 .5882 L p
1 g
F P
s
P
p
.002 w
.38472 .31694 m .34723 .36922 L .33372 .35871 L p
1 g
F P
s
P
p
.002 w
.33372 .35871 m .37263 .30439 L .38472 .31694 L p
1 g
F P
s
P
p
.002 w
.65547 .50026 m .6625 .45872 L .67971 .45152 L p
1 g
F P
s
P
p
.002 w
.67209 .40303 m .67971 .45152 L .6625 .45872 L p
1 g
F P
s
P
p
.002 w
.49798 .26102 m .43709 .2794 L .42704 .26541 L p
1 g
F P
s
P
p
.002 w
.37263 .30439 m .42704 .26541 L .43709 .2794 L p
1 g
F P
s
P
p
.002 w
.67209 .40303 m .64889 .35999 L .65691 .34153 L p
1 g
F P
s
P
p
.002 w
.61588 .30463 m .65691 .34153 L .64889 .35999 L p
1 g
F P
s
P
p
.002 w
.43709 .2794 m .38472 .31694 L .37263 .30439 L p
1 g
F P
s
P
p
.002 w
.34878 .43832 m .35121 .4957 L .33179 .49161 L p
1 g
F P
s
P
p
.002 w
.33179 .49161 m .32899 .42987 L .34878 .43832 L p
1 g
F P
s
P
p
.002 w
.61588 .30463 m .56369 .28358 L .56005 .26367 L p
1 g
F P
s
P
p
.002 w
.49798 .26102 m .56005 .26367 L .56369 .28358 L p
1 g
F P
s
P
p
.002 w
.44818 .5685 m .48463 .5882 L .47047 .60388 L p
1 g
F P
s
P
p
.002 w
.47047 .60388 m .42736 .58081 L .44818 .5685 L p
1 g
F P
s
P
p
.002 w
.6625 .45872 m .65591 .41758 L .67209 .40303 L p
1 g
F P
s
P
p
.002 w
.64889 .35999 m .67209 .40303 L .65591 .41758 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.56497 .5671 m .59487 .55167 L .60541 .5682 L p
1 g
F P
s
P
p
.002 w
.60541 .5682 m .56752 .58781 L .56497 .5671 L p
1 g
F P
s
P
p
.002 w
.63574 .53801 m .60541 .5682 L .59487 .55167 L p
1 g
F P
s
P
p
.002 w
.3758 .49797 m .39449 .5443 L .37237 .54756 L p
1 g
F P
s
P
p
.002 w
.37237 .54756 m .35121 .4957 L .3758 .49797 L p
1 g
F P
s
P
p
.002 w
.59487 .55167 m .6188 .52784 L .63574 .53801 L p
1 g
F P
s
P
p
.002 w
.65547 .50026 m .63574 .53801 L .6188 .52784 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53178 .57494 L p
1 g
F P
s
P
p
.002 w
.56497 .5671 m .56752 .58781 L p
.53423 .57341 L 1 g
F P
s
P
p
.002 w
.53698 .57171 m .56497 .5671 L p
.53423 .57341 L 1 g
F P
s
P
p
.54854 .56129 m .53178 .57494 L .53698 .57171 L 1 g
F
P
p
.002 w
.56497 .5671 m .54267 .57077 L p
.55463 .55882 L 1 g
F P
s
P
p
.002 w
.54267 .57077 m .53698 .57171 L p
.54912 .56285 L 1 g
F P
s
P
p
.54267 .57077 m .54912 .56285 L .55463 .55882 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54912 .56285 L p
1 g
F P
s
P
p
.56075 .54566 m .54912 .56285 L .55579 .55464 L 1 g
F
P
p
.54854 .56129 m .53698 .57171 L .53968 .56973 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56752 .58781 m .52586 .59477 L .53137 .57519 L p
1 g
F P
s
P
p
.002 w
.53137 .57519 m .5314 .57508 L p
.53178 .57494 L 1 g
F P
s
P
p
.56752 .58781 m .53137 .57519 L .53423 .57341 L 1 g
F
P
p
.002 w
.5314 .57508 m .52586 .59477 L p
.51169 .57983 L 1 g
F P
s
P
p
.002 w
.53178 .57494 m .53128 .57265 L p
.52225 .57728 L 1 g
F P
s
P
p
.52586 .59477 m .48625 .58595 L .5109 .58002 L 1 g
F
P
p
.51184 .57998 m .5109 .58002 L .51169 .57983 L 1 g
F
P
p
.52586 .59477 m .5109 .58002 L .51184 .57998 L 1 g
F
P
p
.002 w
.5109 .58002 m .51079 .57862 L p
.50228 .58032 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58067 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58067 L .48967 .58073 L 1 g
F
P
p
.48463 .5882 m .48162 .57998 L .48906 .58067 L 1 g
F
P
p
.002 w
.48999 .58076 m .48987 .58093 L p
.48906 .58067 L 1 g
F P
s
P
p
.002 w
.48987 .58093 m .48463 .5882 L p
.48906 .58067 L 1 g
F P
s
P
p
.002 w
.48906 .58067 m .48921 .57862 L p
.48136 .57822 L 1 g
F P
s
P
p
.51079 .57862 m .48967 .58073 L .50228 .58032 L 1 g
F
P
p
.48967 .58073 m .48905 .58079 L .48999 .58076 L 1 g
F
P
p
.48967 .58073 m .48999 .58076 L .50228 .58032 L 1 g
F
P
p
.48162 .57998 m .48092 .57808 L .48906 .58067 L 1 g
F
P
p
.48921 .57862 m .48032 .57789 L .48136 .57822 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48463 .5882 m .44818 .5685 L .44898 .56791 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46841 .5741 L p
1 g
F P
s
P
p
.48921 .57862 m .46841 .5741 L .48032 .57789 L 1 g
F
P
p
.002 w
.44898 .56791 m .45305 .56492 L p
.46841 .5741 L 1 g
F P
s
P
p
.48463 .5882 m .44898 .56791 L .48092 .57808 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.44818 .5685 m .44844 .56126 L .45078 .56312 L 1 g
F
P
p
.002 w
.45305 .56492 m .45245 .56537 L p
.45078 .56312 L 1 g
F P
s
P
p
.002 w
.45245 .56537 m .44818 .5685 L p
.45078 .56312 L 1 g
F P
s
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44569 .55628 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56312 L p
1 g
F P
s
P
p
.002 w
.45078 .56312 m .45002 .56518 L p
.45676 .56787 L 1 g
F P
s
P
p
.46872 .57265 m .45078 .56312 L .45676 .56787 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .5468 L p
1 g
F P
s
P
p
.45146 .56129 m .43864 .5468 L .44569 .55628 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44818 .5685 m .44504 .56498 L p
.44968 .52716 L 1 g
F P
s
P
p
.002 w
.44504 .56498 m .42052 .53747 L .43372 .5328 L p
1 g
F P
s
P
p
.002 w
.43864 .5468 m .43925 .54566 L p
.43594 .53911 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43265 .52852 L p
1 g
F P
s
P
p
.42052 .53747 m .42951 .51594 L .43265 .52852 L 1 g
F
P
p
.002 w
.43372 .5328 m .43229 .53331 L p
.43265 .52852 L 1 g
F P
s
P
p
.002 w
.43229 .53331 m .42052 .53747 L p
.43265 .52852 L 1 g
F P
s
P
p
.002 w
.43265 .52852 m .43346 .52734 L p
.43323 .52079 L 1 g
F P
s
P
p
.43925 .54566 m .43265 .52852 L .43466 .53659 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43411 .50914 L p
1 g
F P
s
P
p
.43346 .52734 m .43411 .50914 L .43323 .52079 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.43649 .50398 m .43768 .49639 L .43696 .50295 L 1 g
F
P
p
.42951 .51594 m .4345 .50401 L .43265 .52852 L 1 g
F
P
p
.002 w
.43411 .50914 m .43485 .50826 L p
.43898 .4986 L 1 g
F P
s
P
p
.002 w
.43874 .49911 m .43768 .49639 L .44018 .49611 L p
1 g
F P
s
P
p
.43898 .4986 m .43913 .49826 L .43874 .49911 L 1 g
F
P
p
.43898 .4986 m .43874 .49911 L .43411 .50914 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.4345 .50401 m .43768 .49639 L .43649 .50398 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44255 .49139 L p
1 g
F P
s
P
p
.002 w
.44018 .49611 m .43768 .49639 L p
.44157 .49335 L 1 g
F P
s
P
p
.43485 .50826 m .44255 .49139 L .44034 .49579 L 1 g
F
P
p
.002 w
.43768 .49639 m .4367 .46261 L .45524 .4661 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.44157 .49335 m .44255 .49139 L .47051 .47067 L 1 g
F
P
p
.44157 .49335 m .47051 .47067 L .47074 .47057 L 1 g
F
P
p
.002 w
.47288 .49247 m .47235 .46981 L p
.50901 .47483 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46725 L p
1 g
F P
s
P
p
.45826 .47608 m .47751 .46725 L .47672 .46764 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47786 .46667 L p
.48877 .46556 L 1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51269 .46341 m .51985 .45358 L .53521 .4689 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56622 .50953 L p
1 g
F P
s
P
p
.58107 .53086 m .57361 .52567 L .56622 .50953 L 1 g
F
P
p
.002 w
.56559 .50815 m .56619 .50903 L p
.56622 .50953 L 1 g
F P
s
P
p
.002 w
.56619 .50903 m .58107 .53086 L p
.56622 .50953 L 1 g
F P
s
P
p
.002 w
.56622 .50953 m .56515 .50826 L p
.56684 .51923 L 1 g
F P
s
P
p
.55661 .4905 m .56622 .50953 L .56559 .50815 L 1 g
F
P
p
.59765 .51435 m .56559 .50815 L .56481 .50647 L 1 g
F
P
p
.55661 .4905 m .56559 .50815 L .56464 .50609 L 1 g
F
P
p
.55661 .4905 m .56464 .50609 L .56281 .50235 L 1 g
F
P
p
.002 w
.56858 .50216 m .56464 .50609 L p
.55741 .49135 L 1 g
F P
s
P
p
.002 w
.57288 .49788 m .59765 .51435 L p
.56481 .50647 L 1 g
F P
s
P
p
.002 w
.56437 .50636 m .56464 .50609 L p
.56481 .50647 L 1 g
F P
s
P
p
.002 w
.56464 .50609 m .57288 .49788 L p
.56481 .50647 L 1 g
F P
s
P
p
.002 w
.59765 .51435 m .58107 .53086 L .56559 .50815 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55827 .49226 L p
1 g
F P
s
P
p
.002 w
.55827 .49226 m .55661 .4905 L p
.56374 .50414 L 1 g
F P
s
P
p
.56374 .50414 m .56713 .51061 L .55827 .49226 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49135 L p
1 g
F P
s
P
p
.54174 .47608 m .55741 .49135 L .55088 .48503 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54528 .47895 m .55439 .4852 L p
.5572 .49114 L 1 g
F P
s
P
p
.002 w
.56437 .50636 m .54671 .48099 L p
.5572 .49114 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56437 .50636 m .55372 .51181 L .54551 .47983 L p
1 g
F P
s
P
p
.54174 .47608 m .55088 .48503 L .54671 .48099 L 1 g
F
P
p
.002 w
.54551 .47983 m .54528 .47895 L .54671 .48099 L p
1 g
F P
s
P
p
.002 w
.54671 .48099 m .56437 .50636 L p
.54551 .47983 L 1 g
F P
s
P
p
.002 w
.55372 .51181 m .54206 .51365 L .54523 .47956 L p
1 g
F P
s
P
p
.002 w
.54523 .47956 m .54528 .47895 L .54551 .47983 L p
1 g
F P
s
P
p
.002 w
.54551 .47983 m .55372 .51181 L p
.54523 .47956 L 1 g
F P
s
P
p
.002 w
.54206 .51365 m .53064 .51167 L .54508 .47941 L p
1 g
F P
s
P
p
.002 w
.54508 .47941 m .54528 .47895 L .54523 .47956 L p
1 g
F P
s
P
p
.002 w
.54523 .47956 m .54206 .51365 L p
.54508 .47941 L 1 g
F P
s
P
p
.002 w
.53064 .51167 m .52068 .50605 L .54496 .4793 L p
1 g
F P
s
P
p
.002 w
.54496 .4793 m .54528 .47895 L .54508 .47941 L p
1 g
F P
s
P
p
.002 w
.54508 .47941 m .53064 .51167 L p
.54496 .4793 L 1 g
F P
s
P
p
.002 w
.52068 .50605 m .51326 .49738 L .54485 .4792 L p
1 g
F P
s
P
p
.002 w
.54485 .4792 m .54528 .47895 L .54496 .4793 L p
1 g
F P
s
P
p
.002 w
.54496 .4793 m .52068 .50605 L p
.54485 .4792 L 1 g
F P
s
P
p
.54496 .4793 m .54515 .47948 L .54497 .47931 L 1 g
F
P
p
.54515 .47948 m .54523 .47956 L .54517 .4795 L 1 g
F
P
p
.54515 .47948 m .54517 .4795 L .54497 .47931 L 1 g
F
P
p
.54523 .47956 m .54534 .47967 L .54526 .47959 L 1 g
F
P
p
.54523 .47956 m .54526 .47959 L .54497 .47931 L 1 g
F
P
p
.54534 .47967 m .54551 .47983 L .5454 .47972 L 1 g
F
P
p
.54534 .47967 m .5454 .47972 L .54497 .47931 L 1 g
F
P
p
.54551 .47983 m .54671 .48099 L .54583 .48014 L 1 g
F
P
p
.54551 .47983 m .54583 .48014 L .54497 .47931 L 1 g
F
P
p
.002 w
.51326 .49738 m .50922 .48659 L .54472 .47907 L p
1 g
F P
s
P
p
.002 w
.54472 .47907 m .54528 .47895 L .54485 .4792 L p
1 g
F P
s
P
p
.002 w
.54485 .4792 m .51326 .49738 L p
.54472 .47907 L 1 g
F P
s
P
p
.54174 .47608 m .54671 .48099 L .54508 .47942 L 1 g
F
P
p
.54494 .47928 m .54508 .47942 L .54496 .4793 L 1 g
F
P
p
.54174 .47608 m .54508 .47942 L .54494 .47928 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54394 .47831 m .51999 .46689 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47685 L p
1 g
F P
s
P
p
.52214 .46667 m .54244 .47685 L .53308 .47234 L 1 g
F
P
p
.52247 .46722 m .54244 .47685 L .54394 .47831 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52247 .46722 L p
1 g
F P
s
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.53308 .47234 L 1 g
F P
s
P
p
.53308 .47234 m .54302 .47747 L .52247 .46722 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.5 .4634 m .52247 .46722 L .51999 .46689 L 1 g
F
P
p
.002 w
.51999 .46689 m .54394 .47831 L p
.51192 .46581 L 1 g
F P
s
P
p
.002 w
.54394 .47831 m .54528 .47895 L p
.54413 .47849 L 1 g
F P
s
P
p
.51192 .46581 m .54394 .47831 L .54413 .47849 L 1 g
F
P
p
.002 w
.50901 .47483 m .51192 .46581 L p
.54413 .47849 L 1 g
F P
s
P
p
.002 w
.54528 .47895 m .54451 .47886 L p
.54413 .47849 L 1 g
F P
s
P
p
.002 w
.54451 .47886 m .50901 .47483 L p
.54413 .47849 L 1 g
F P
s
P
p
.002 w
.50922 .48659 m .50901 .47483 L .54451 .47886 L p
1 g
F P
s
P
p
.002 w
.54451 .47886 m .54528 .47895 L .54472 .47907 L p
1 g
F P
s
P
p
.002 w
.54472 .47907 m .50922 .48659 L p
.54451 .47886 L 1 g
F P
s
P
p
.002 w
.54244 .47685 m .54174 .47608 L p
.54495 .47929 L 1 g
F P
s
P
p
.54495 .47929 m .54496 .4793 L .54461 .47896 L 1 g
F
P
p
.54495 .47929 m .54461 .47896 L .54244 .47685 L 1 g
F
P
p
.54496 .4793 m .54497 .47931 L .54394 .47831 L 1 g
F
P
p
.54496 .4793 m .54394 .47831 L .54244 .47685 L 1 g
F
P
p
.002 w
.54258 .47699 m .54245 .47685 L p
.54497 .47931 L 1 g
F P
s
P
p
.002 w
.54245 .47685 m .54244 .47685 L p
.54394 .47831 L 1 g
F P
s
P
p
.54394 .47831 m .54497 .47931 L .54245 .47685 L 1 g
F
P
p
.5164 .46641 m .51999 .46689 L .51651 .46643 L 1 g
F
P
p
.5 .4634 m .51999 .46689 L .5164 .46641 L 1 g
F
P
p
.5 .4634 m .52268 .46756 L .51595 .46647 L 1 g
F
P
p
.47379 .4691 m .47751 .46725 L .5034 .46442 L 1 g
F
P
p
.47379 .4691 m .5034 .46442 L .50451 .46461 L 1 g
F
P
p
.002 w
.5 .46387 m .5 .4634 L p
.51595 .46647 L 1 g
F P
s
P
p
.002 w
.51047 .4623 m .51269 .46341 L p
.47751 .46725 L 1 g
F P
s
P
p
.002 w
.51269 .46341 m .50901 .47483 L .47313 .46943 L p
1 g
F P
s
P
p
.47379 .4691 m .51269 .46341 L .47313 .46943 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.51595 .46647 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46387 L p
1 g
F P
s
P
p
.002 w
.49903 .45655 m .51047 .4623 L p
.5 .46387 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46387 L .48877 .46556 L 1 g
F
P
p
.47751 .46725 m .48817 .46195 L .5 .46387 L 1 g
F
P
p
.48817 .46195 m .49903 .45655 L .5 .46387 L 1 g
F
P
p
.002 w
.51192 .46581 m .51269 .46341 L .51999 .46689 L p
1 g
F P
s
P
p
.002 w
.51999 .46689 m .51269 .46341 L p
.5165 .46434 L 1 g
F P
s
P
p
.5165 .46434 m .53521 .4689 L .52247 .46722 L 1 g
F
P
p
.5165 .46434 m .52247 .46722 L .51999 .46689 L 1 g
F
P
p
.52247 .46722 m .53414 .46876 L .54244 .47685 L 1 g
F
P
p
.002 w
.54244 .47685 m .54302 .47747 L p
.53308 .47234 L 1 g
F P
s
P
p
.002 w
.53521 .4689 m .54528 .47895 L .54394 .47831 L p
1 g
F P
s
P
p
.53414 .46876 m .53521 .4689 L .54394 .47831 L 1 g
F
P
p
.002 w
.54671 .48099 m .54528 .47895 L p
.5572 .49114 L 1 g
F P
s
P
p
.002 w
.56464 .50609 m .56437 .50636 L p
.55439 .4852 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54258 .47699 L p
1 g
F P
s
P
p
.55088 .48503 m .55834 .49233 L .54258 .47699 L 1 g
F
P
p
.002 w
.55741 .49135 m .55834 .49233 L p
.55088 .48503 L 1 g
F P
s
P
p
.002 w
.55439 .4852 m .57288 .49788 L .56858 .50216 L p
1 g
F P
s
P
p
.56858 .50216 m .55741 .49135 L .55439 .4852 L 1 g
F
P
p
.56281 .50235 m .56464 .50609 L .56374 .50414 L 1 g
F
P
p
.56374 .50414 m .56559 .50815 L .56381 .50428 L 1 g
F
P
p
.002 w
.56559 .50815 m .56437 .50636 L p
.56481 .50647 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56745 .52866 L p
1 g
F P
s
P
p
.56515 .50826 m .56745 .52866 L .56684 .51923 L 1 g
F
P
p
.56622 .50953 m .55372 .51181 L .56559 .50815 L 1 g
F
P
p
.57361 .52567 m .56696 .52103 L .56622 .50953 L 1 g
F
P
p
.56696 .52103 m .55372 .51181 L .56622 .50953 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .54739 L p
1 g
F P
s
P
p
.56654 .52734 m .56167 .54739 L .56319 .54312 L 1 g
F
P
p
.002 w
.59487 .55167 m .56497 .5671 L .56149 .54789 L p
1 g
F P
s
P
p
.56654 .52734 m .56319 .54312 L .56415 .54041 L 1 g
F
P
p
.002 w
.56149 .54789 m .56145 .54769 L p
.56167 .54739 L 1 g
F P
s
P
p
.59487 .55167 m .56149 .54789 L .56343 .54243 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53213 .57251 m .53761 .54519 L p
.55328 .55774 L 1 g
F P
s
P
p
.55463 .55882 m .5502 .56152 L .55328 .55774 L 1 g
F
P
p
.002 w
.54951 .56391 m .54854 .56129 L p
.5388 .57057 L 1 g
F P
s
P
p
.5502 .56152 m .53213 .57251 L .55328 .55774 L 1 g
F
P
p
.002 w
.53698 .57171 m .53213 .57251 L p
.55463 .55882 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56075 .54566 L p
.55579 .55464 L 1 g
F P
s
P
p
.55579 .55464 m .56145 .54769 L .56167 .54739 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.53761 .54519 m .56034 .54152 L .56145 .54769 L p
1 g
F P
s
P
p
.002 w
.56145 .54769 m .56497 .5671 L p
.55328 .55774 L 1 g
F P
s
P
p
.55328 .55774 m .53761 .54519 L .56145 .54769 L 1 g
F
P
p
.55579 .55464 m .55349 .55882 L .56145 .54769 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56168 .54741 L p
1 g
F P
s
P
p
.002 w
.56168 .54741 m .56167 .54739 L p
.56155 .54758 L 1 g
F P
s
P
p
.56155 .54758 m .54998 .56518 L .56168 .54741 L 1 g
F
P
p
.55349 .55882 m .54998 .56518 L .56167 .54739 L 1 g
F
P
p
.56343 .54243 m .56167 .54739 L .56034 .54152 L 1 g
F
P
p
.002 w
.56145 .54769 m .56034 .54152 L p
.56167 .54739 L 1 g
F P
s
P
p
.002 w
.58107 .53086 m .59487 .55167 L p
.56343 .54243 L 1 g
F P
s
P
p
.002 w
.56452 .53937 m .58107 .53086 L p
.56343 .54243 L 1 g
F P
s
P
p
.56415 .54041 m .56211 .54822 L .56398 .54135 L 1 g
F
P
p
.56319 .54312 m .56211 .54822 L .56415 .54041 L 1 g
F
P
p
.002 w
.56167 .54739 m .56211 .54822 L p
.56319 .54312 L 1 g
F P
s
P
p
.002 w
.58107 .53086 m .56452 .53937 L p
.56912 .52254 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56034 .54152 m .56452 .53937 L p
.56343 .54243 L 1 g
F P
s
P
p
.002 w
.56034 .54152 m .55372 .51181 L p
.56912 .52254 L 1 g
F P
s
P
p
.002 w
.56452 .53937 m .56034 .54152 L p
.56912 .52254 L 1 g
F P
s
P
p
.002 w
.56211 .54822 m .56257 .5491 L p
.56398 .54135 L 1 g
F P
s
P
p
.002 w
.56745 .52866 m .56854 .53025 L p
.56684 .51923 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56622 .50953 L p
1 g
F P
s
P
p
.56684 .51923 m .56854 .53025 L .56622 .50953 L 1 g
F
P
p
.002 w
.56622 .50953 m .56713 .51061 L p
.56381 .50428 L 1 g
F P
s
P
p
.002 w
.55372 .51181 m .56437 .50636 L .56559 .50815 L p
1 g
F P
s
P
p
.002 w
.52247 .46722 m .52268 .46756 L p
.51651 .46643 L 1 g
F P
s
P
p
.002 w
.52268 .46756 m .52282 .46778 L p
.51595 .46647 L 1 g
F P
s
P
p
.50451 .46461 m .5034 .46442 L .51269 .46341 L 1 g
F
P
p
.002 w
.5 .46387 m .5 .46442 L p
.48877 .46556 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47751 .46725 L p
1 g
F P
s
P
p
.48877 .46556 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.002 w
.47951 .44675 m .49903 .45655 L p
.47626 .46744 L 1 g
F P
s
P
p
.002 w
.47234 .46931 m .47277 .46797 L p
.47626 .46744 L 1 g
F P
s
P
p
.002 w
.47277 .46797 m .47951 .44675 L p
.47626 .46744 L 1 g
F P
s
P
p
.45826 .47608 m .47672 .46764 L .47428 .46886 L 1 g
F
P
p
.002 w
.47313 .46943 m .50901 .47483 L p
.47235 .46981 L 1 g
F P
s
P
p
.45826 .47608 m .47738 .46746 L .46929 .47124 L 1 g
F
P
p
.47234 .46931 m .49903 .45655 L .47379 .4691 L 1 g
F
P
p
.47428 .46886 m .47748 .4673 L .47448 .46877 L 1 g
F
P
p
.47672 .46764 m .47748 .4673 L .47428 .46886 L 1 g
F
P
p
.002 w
.47751 .46725 m .47748 .4673 L p
.47672 .46764 L 1 g
F P
s
P
p
.002 w
.47313 .46943 m .47234 .46931 L p
.47379 .4691 L 1 g
F P
s
P
p
.002 w
.47235 .46981 m .47234 .46931 L .47313 .46943 L p
1 g
F P
s
P
p
.002 w
.47748 .4673 m .47738 .46746 L p
.47448 .46877 L 1 g
F P
s
P
p
.002 w
.45775 .47664 m .45826 .47608 L p
.46929 .47124 L 1 g
F P
s
P
p
.002 w
.46644 .4682 m .47234 .46931 L p
.44255 .49139 L 1 g
F P
s
P
p
.43768 .49639 m .45524 .4661 L .44157 .49335 L 1 g
F
P
p
.43485 .50826 m .44205 .49192 L .43913 .49826 L 1 g
F
P
p
.002 w
.47234 .46931 m .47288 .49247 L .44018 .49611 L p
1 g
F P
s
P
p
.44157 .49335 m .47234 .46931 L .44018 .49611 L 1 g
F
P
p
.002 w
.47738 .46746 m .47718 .46778 L p
.46929 .47124 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45524 .4661 m .46644 .4682 L p
.45775 .47664 L 1 g
F P
s
P
p
.002 w
.44255 .49139 m .44339 .4905 L p
.44944 .4847 L 1 g
F P
s
P
p
.44255 .49139 m .44757 .4814 L .45775 .47664 L 1 g
F
P
p
.44757 .4814 m .45524 .4661 L .45775 .47664 L 1 g
F
P
p
.47074 .47057 m .47051 .47067 L .47234 .46931 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45775 .47664 L p
1 g
F P
s
P
p
.46929 .47124 m .47718 .46778 L .45775 .47664 L 1 g
F
P
p
.002 w
.44205 .49192 m .44166 .49233 L p
.43925 .49797 L 1 g
F P
s
P
p
.43937 .49773 m .44205 .49192 L .43925 .49797 L 1 g
F
P
p
.002 w
.44255 .49139 m .44205 .49192 L p
.44034 .49579 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44255 .49139 L p
1 g
F P
s
P
p
.44944 .4847 m .45698 .47747 L .44255 .49139 L 1 g
F
P
p
.43913 .49826 m .43937 .49773 L .43925 .49797 L 1 g
F
P
p
.43411 .50914 m .43649 .50398 L .43265 .52852 L 1 g
F
P
p
.4345 .50401 m .43649 .50398 L .43411 .50914 L 1 g
F
P
p
.002 w
.44968 .52716 m .43874 .49911 L p
.47288 .49247 L 1 g
F P
s
P
p
.002 w
.44018 .49611 m .47288 .49247 L p
.43874 .49911 L 1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43768 .49639 m .44968 .52716 L .43372 .5328 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43411 .50914 L p
1 g
F P
s
P
p
.43913 .49826 m .44166 .49233 L .43411 .50914 L 1 g
F
P
p
.43265 .52852 m .43649 .50398 L .43372 .5328 L 1 g
F
P
p
.43649 .50398 m .43696 .50295 L .43372 .5328 L 1 g
F
P
p
.002 w
.43411 .50914 m .43287 .51061 L p
.43323 .52079 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43265 .52852 L p
1 g
F P
s
P
p
.43323 .52079 m .43287 .51061 L .43265 .52852 L 1 g
F
P
p
.002 w
.43265 .52852 m .43146 .53025 L p
.43466 .53659 L 1 g
F P
s
P
p
.002 w
.43372 .5328 m .44968 .52716 L p
.44504 .56498 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43864 .5468 L p
1 g
F P
s
P
p
.43594 .53911 m .43146 .53025 L .43864 .5468 L 1 g
F
P
p
.002 w
.43864 .5468 m .43743 .5491 L p
.44569 .55628 L 1 g
F P
s
P
p
.45078 .56312 m .44968 .52716 L .45305 .56492 L 1 g
F
P
p
.44844 .56126 m .44848 .56003 L .45078 .56312 L 1 g
F
P
p
.44848 .56003 m .44968 .52716 L .45078 .56312 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.44569 .55628 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.002 w
.44968 .52716 m .4712 .5516 L .45305 .56492 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46784 .57668 L p
1 g
F P
s
P
p
.002 w
.46784 .57668 m .46841 .5741 L p
.45863 .56935 L 1 g
F P
s
P
p
.45863 .56935 m .45002 .56518 L .46784 .57668 L 1 g
F
P
p
.002 w
.46841 .5741 m .46872 .57265 L p
.46046 .56935 L 1 g
F P
s
P
p
.46046 .56935 m .45002 .56518 L .46841 .5741 L 1 g
F
P
p
.48092 .57808 m .46841 .5741 L .4712 .5516 L 1 g
F
P
p
.002 w
.45305 .56492 m .4712 .5516 L p
.46841 .5741 L 1 g
F P
s
P
p
.002 w
.46841 .5741 m .4678 .57686 L p
.48032 .57789 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .47057 .57767 L p
.48136 .57822 L 1 g
F P
s
P
p
.48032 .57789 m .4678 .57686 L .48136 .57822 L 1 g
F
P
p
.48906 .58067 m .4712 .5516 L .48999 .58076 L 1 g
F
P
p
.48092 .57808 m .4712 .5516 L .48906 .58067 L 1 g
F
P
p
.002 w
.48905 .58079 m .48906 .58067 L p
.47057 .57767 L 1 g
F P
s
P
p
.48136 .57822 m .47057 .57767 L .48906 .58067 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.4712 .5516 m .49973 .56721 L .48999 .58076 L p
1 g
F P
s
P
p
.002 w
.48906 .58067 m .48905 .58079 L p
.48967 .58073 L 1 g
F P
s
P
p
.5109 .58002 m .5 .58264 L .49996 .5804 L 1 g
F
P
p
.002 w
.48625 .58595 m .48987 .58093 L p
.5 .58264 L 1 g
F P
s
P
p
.002 w
.48987 .58093 m .49973 .56721 L p
.5 .58264 L 1 g
F P
s
P
p
.002 w
.48905 .58079 m .48889 .583 L p
.50228 .58032 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.51169 .57983 m .5109 .58002 L .49973 .56721 L 1 g
F
P
p
.5109 .58002 m .49996 .5804 L .49973 .56721 L 1 g
F
P
p
.002 w
.47057 .57767 m .48889 .583 L .48905 .58079 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58002 L p
1 g
F P
s
P
p
.50228 .58032 m .48889 .583 L .5109 .58002 L 1 g
F
P
p
.52225 .57728 m .51315 .58195 L .5314 .57508 L 1 g
F
P
p
.52225 .57728 m .5314 .57508 L .53178 .57494 L 1 g
F
P
p
.002 w
.52586 .59477 m .48463 .5882 L .48625 .58595 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49973 .56721 m .53213 .57251 L .5314 .57508 L p
1 g
F P
s
P
p
.51169 .57983 m .49973 .56721 L .5314 .57508 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53179 .57499 L p
1 g
F P
s
P
p
.002 w
.53179 .57499 m .53178 .57494 L p
.53144 .57507 L 1 g
F P
s
P
p
.53144 .57507 m .51111 .583 L .53179 .57499 L 1 g
F
P
p
.51315 .58195 m .51111 .583 L .53178 .57494 L 1 g
F
P
p
.53423 .57341 m .53178 .57494 L .53213 .57251 L 1 g
F
P
p
.002 w
.5314 .57508 m .53213 .57251 L p
.53178 .57494 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54951 .56391 L p
1 g
F P
s
P
p
.5388 .57057 m .5322 .57686 L .54951 .56391 L 1 g
F
P
p
.002 w
.54912 .56285 m .54998 .56518 L p
.55579 .55464 L 1 g
F P
s
P
p
.53968 .56973 m .53698 .57171 L .5388 .57057 L 1 g
F
P
p
.002 w
.53178 .57494 m .5322 .57686 L p
.5388 .57057 L 1 g
F P
s
P
p
.002 w
.53213 .57251 m .53698 .57171 L p
.53423 .57341 L 1 g
F P
s
P
p
.002 w
.64889 .35999 m .61214 .3272 L .61588 .30463 L p
1 g
F P
s
P
p
.002 w
.56369 .28358 m .61588 .30463 L .61214 .3272 L p
1 g
F P
s
P
p
.002 w
.36586 .38198 m .34878 .43832 L .32899 .42987 L p
1 g
F P
s
P
p
.002 w
.32899 .42987 m .34723 .36922 L .36586 .38198 L p
1 g
F P
s
P
p
.002 w
.6188 .52784 m .63432 .49805 L .65547 .50026 L p
1 g
F P
s
P
p
.002 w
.6625 .45872 m .65547 .50026 L .63432 .49805 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.56369 .28358 m .50598 .28128 L .49798 .26102 L p
1 g
F P
s
P
p
.002 w
.43709 .2794 m .49798 .26102 L .50598 .28128 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.42052 .53747 m .44818 .5685 L .42736 .58081 L p
1 g
F P
s
P
p
.002 w
.42736 .58081 m .39449 .5443 L .42052 .53747 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.63432 .49805 m .63976 .46531 L .6625 .45872 L p
1 g
F P
s
P
p
.002 w
.65591 .41758 m .6625 .45872 L .63976 .46531 L p
1 g
F P
s
P
p
.002 w
.65591 .41758 m .63609 .38121 L .64889 .35999 L p
1 g
F P
s
P
p
.002 w
.61214 .3272 m .64889 .35999 L .63609 .38121 L p
1 g
F P
s
P
p
.002 w
.40076 .33341 m .36586 .38198 L .34723 .36922 L p
1 g
F P
s
P
p
.002 w
.34723 .36922 m .38472 .31694 L .40076 .33341 L p
1 g
F P
s
P
p
.004 w
.32757 .33889 m
.35359 .35272 L
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50598 .28128 m .44942 .29848 L .43709 .2794 L p
1 g
F P
s
P
p
.002 w
.38472 .31694 m .43709 .2794 L .44942 .29848 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.37383 .4468 m .3758 .49797 L .35121 .4957 L p
1 g
F P
s
P
p
.002 w
.35121 .4957 m .34878 .43832 L .37383 .4468 L p
1 g
F P
s
P
p
.002 w
.44942 .29848 m .40076 .33341 L .38472 .31694 L p
1 g
F P
s
P
p
.002 w
.61214 .3272 m .56551 .30862 L .56369 .28358 L p
1 g
F P
s
P
p
.002 w
.50598 .28128 m .56369 .28358 L .56551 .30862 L p
1 g
F P
s
P
p
.002 w
.63976 .46531 m .63445 .43301 L .65591 .41758 L p
1 g
F P
s
P
p
.002 w
.63609 .38121 m .65591 .41758 L .63445 .43301 L p
1 g
F P
s
P
p
.002 w
.40493 .49823 m .42052 .53747 L .39449 .5443 L p
1 g
F P
s
P
p
.002 w
.39449 .5443 m .3758 .49797 L .40493 .49823 L p
1 g
F P
s
P
p
.002 w
.6188 .52784 m .59487 .55167 L .58107 .53086 L p
1 g
F P
s
P
p
.002 w
.58107 .53086 m .59765 .51435 L .6188 .52784 L p
1 g
F P
s
P
p
.002 w
.63432 .49805 m .6188 .52784 L .59765 .51435 L p
1 g
F P
s
P
p
.002 w
.63609 .38121 m .60486 .35363 L .61214 .3272 L p
1 g
F P
s
P
p
.002 w
.56551 .30862 m .61214 .3272 L .60486 .35363 L p
1 g
F P
s
P
p
.002 w
.38919 .39663 m .37383 .4468 L .34878 .43832 L p
1 g
F P
s
P
p
.002 w
.34878 .43832 m .36586 .38198 L .38919 .39663 L p
1 g
F P
s
P
p
.002 w
.59765 .51435 m .60836 .4937 L .63432 .49805 L p
1 g
F P
s
P
p
.002 w
.63976 .46531 m .63432 .49805 L .60836 .4937 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.56551 .30862 m .51407 .30677 L .50598 .28128 L p
1 g
F P
s
P
p
.002 w
.44942 .29848 m .50598 .28128 L .51407 .30677 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51526 .54143 m .53761 .54519 L .53213 .57251 L p
1 g
F P
s
P
p
.002 w
.53213 .57251 m .49973 .56721 L .51526 .54143 L p
1 g
F P
s
P
p
.002 w
.63445 .43301 m .61874 .40455 L .63609 .38121 L p
1 g
F P
s
P
p
.002 w
.60486 .35363 m .63609 .38121 L .61874 .40455 L p
1 g
F P
s
P
p
.002 w
.60836 .4937 m .61205 .47105 L .63976 .46531 L p
1 g
F P
s
P
p
.002 w
.63445 .43301 m .63976 .46531 L .61205 .47105 L p
1 g
F P
s
P
p
.002 w
.42034 .35337 m .38919 .39663 L .36586 .38198 L p
1 g
F P
s
P
p
.004 w
.40221 .37855 m
.5 .43051 L
s
P
p
.002 w
.36586 .38198 m .40076 .33341 L .42034 .35337 L p
1 g
F P
s
P
p
.004 w
.36923 .36103 m
.37847 .36594 L
s
P
p
.004 w
.37847 .36594 m
.38316 .36843 L
s
P
p
.004 w
.35359 .35272 m
.36923 .36103 L
s
P
p
.004 w
.38316 .36843 m
.3841 .36893 L
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.51407 .30677 m .46369 .32221 L .44942 .29848 L p
1 g
F P
s
P
p
.002 w
.40076 .33341 m .44942 .29848 L .46369 .32221 L p
1 g
F P
s
P
p
.002 w
.40347 .45501 m .40493 .49823 L .3758 .49797 L p
1 g
F P
s
P
p
.002 w
.3758 .49797 m .37383 .4468 L .40347 .45501 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46369 .32221 m .42034 .35337 L .40076 .33341 L p
1 g
F P
s
P
p
.002 w
.60486 .35363 m .56538 .33814 L .56551 .30862 L p
1 g
F P
s
P
p
.002 w
.51407 .30677 m .56551 .30862 L .56538 .33814 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49567 .53056 m .51526 .54143 L .49973 .56721 L p
1 g
F P
s
P
p
.002 w
.49973 .56721 m .4712 .5516 L .49567 .53056 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.61205 .47105 m .60827 .44877 L .63445 .43301 L p
1 g
F P
s
P
p
.002 w
.61874 .40455 m .63445 .43301 L .60827 .44877 L p
1 g
F P
s
P
p
.002 w
.42052 .53747 m .40493 .49823 L .43768 .49639 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61874 .40455 m .59416 .38311 L .60486 .35363 L p
1 g
F P
s
P
p
.002 w
.56538 .33814 m .60486 .35363 L .59416 .38311 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60836 .4937 m .59765 .51435 L .57288 .49788 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.41656 .4127 m .40347 .45501 L .37383 .4468 L p
1 g
F P
s
P
p
.002 w
.37383 .4468 m .38919 .39663 L .41656 .4127 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.54206 .51365 m .55372 .51181 L .56034 .54152 L p
1 g
F P
s
P
p
.002 w
.56034 .54152 m .53761 .54519 L .54206 .51365 L p
1 g
F P
s
P
p
.002 w
.57288 .49788 m .57835 .48727 L .60836 .4937 L p
1 g
F P
s
P
p
.002 w
.61205 .47105 m .60836 .4937 L .57835 .48727 L p
1 g
F P
s
P
p
.002 w
.56538 .33814 m .52193 .33675 L .51407 .30677 L p
1 g
F P
s
P
p
.002 w
.46369 .32221 m .51407 .30677 L .52193 .33675 L p
1 g
F P
s
P
p
.002 w
.48098 .51365 m .49567 .53056 L .4712 .5516 L p
1 g
F P
s
P
p
.002 w
.4712 .5516 m .44968 .52716 L .48098 .51365 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.60827 .44877 m .59733 .42924 L .61874 .40455 L p
1 g
F P
s
P
p
.002 w
.59416 .38311 m .61874 .40455 L .59733 .42924 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53064 .51167 m .54206 .51365 L .53761 .54519 L p
1 g
F P
s
P
p
.002 w
.53761 .54519 m .51526 .54143 L .53064 .51167 L p
1 g
F P
s
P
p
.002 w
.57835 .48727 m .58019 .47566 L .61205 .47105 L p
1 g
F P
s
P
p
.002 w
.60827 .44877 m .61205 .47105 L .58019 .47566 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.4367 .46261 m .43768 .49639 L .40493 .49823 L p
1 g
F P
s
P
p
.002 w
.40493 .49823 m .40347 .45501 L .4367 .46261 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44289 .37623 m .41656 .4127 L .38919 .39663 L p
1 g
F P
s
P
p
.002 w
.38919 .39663 m .42034 .35337 L .44289 .37623 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52193 .33675 m .47945 .34991 L .46369 .32221 L p
1 g
F P
s
P
p
.002 w
.42034 .35337 m .46369 .32221 L .47945 .34991 L p
1 g
F P
s
P
p
.002 w
.59416 .38311 m .56321 .37117 L .56538 .33814 L p
1 g
F P
s
P
p
.002 w
.52193 .33675 m .56538 .33814 L .56321 .37117 L p
1 g
F P
s
P
p
.002 w
.52068 .50605 m .53064 .51167 L .51526 .54143 L p
1 g
F P
s
P
p
.002 w
.51526 .54143 m .49567 .53056 L .52068 .50605 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.47945 .34991 m .44289 .37623 L .42034 .35337 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58019 .47566 m .57819 .46428 L .60827 .44877 L p
1 g
F P
s
P
p
.002 w
.59733 .42924 m .60827 .44877 L .57819 .46428 L p
1 g
F P
s
P
p
.002 w
.47288 .49247 m .48098 .51365 L .44968 .52716 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59733 .42924 m .58033 .41461 L .59416 .38311 L p
1 g
F P
s
P
p
.002 w
.56321 .37117 m .59416 .38311 L .58033 .41461 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.51326 .49738 m .52068 .50605 L .49567 .53056 L p
1 g
F P
s
P
p
.002 w
.49567 .53056 m .48098 .51365 L .51326 .49738 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44704 .42962 m .4367 .46261 L .40347 .45501 L p
1 g
F P
s
P
p
.002 w
.40347 .45501 m .41656 .4127 L .44704 .42962 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57835 .48727 m .57288 .49788 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.57819 .46428 m .57254 .45436 L .59733 .42924 L p
1 g
F P
s
P
p
.002 w
.58033 .41461 m .59733 .42924 L .57254 .45436 L p
1 g
F P
s
P
p
.002 w
.58019 .47566 m .57835 .48727 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.56321 .37117 m .52926 .37026 L .52193 .33675 L p
1 g
F P
s
P
p
.002 w
.47945 .34991 m .52193 .33675 L .52926 .37026 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57819 .46428 m .58019 .47566 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.58033 .41461 m .55903 .40656 L .56321 .37117 L p
1 g
F P
s
P
p
.002 w
.52926 .37026 m .56321 .37117 L .55903 .40656 L p
1 g
F P
s
P
p
.002 w
.46763 .40119 m .44704 .42962 L .41656 .4127 L p
1 g
F P
s
P
p
.002 w
.41656 .4127 m .44289 .37623 L .46763 .40119 L p
1 g
F P
s
P
p
.002 w
.50922 .48659 m .51326 .49738 L .48098 .51365 L p
1 g
F P
s
P
p
.002 w
.48098 .51365 m .47288 .49247 L .50922 .48659 L p
1 g
F P
s
P
p
.002 w
.57254 .45436 m .57819 .46428 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52926 .37026 m .49613 .38063 L .47945 .34991 L p
1 g
F P
s
P
p
.002 w
.44289 .37623 m .47945 .34991 L .49613 .38063 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57254 .45436 m .56383 .44698 L .58033 .41461 L p
1 g
F P
s
P
p
.002 w
.55903 .40656 m .58033 .41461 L .56383 .44698 L p
1 g
F P
s
P
p
.002 w
.49613 .38063 m .46763 .40119 L .44289 .37623 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56383 .44698 m .57254 .45436 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.47951 .44675 m .47234 .46931 L .4367 .46261 L p
1 g
F P
s
P
p
.002 w
.4367 .46261 m .44704 .42962 L .47951 .44675 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50901 .47483 m .50922 .48659 L .47288 .49247 L p
1 g
F P
s
P
p
.002 w
.55903 .40656 m .53577 .40605 L .52926 .37026 L p
1 g
F P
s
P
p
.002 w
.49613 .38063 m .52926 .37026 L .53577 .40605 L p
1 g
F P
s
P
p
.002 w
.55298 .44296 m .56383 .44698 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.54118 .44276 m .55298 .44296 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.52971 .44644 m .54118 .44276 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.002 w
.51985 .45358 m .52971 .44644 L .54528 .47895 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52087 .45284 L
s
P
p
.002 w
.56383 .44698 m .55298 .44296 L .55903 .40656 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.53577 .40605 m .55903 .40656 L .55298 .44296 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.004 w
.54528 .47895 m
.54674 .48051 L
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.55298 .44296 m .54118 .44276 L .53577 .40605 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49362 .42732 m .47951 .44675 L .44704 .42962 L p
1 g
F P
s
P
p
.002 w
.44704 .42962 m .46763 .40119 L .49362 .42732 L p
1 g
F P
s
P
p
.002 w
.53577 .40605 m .51311 .41323 L .49613 .38063 L p
1 g
F P
s
P
p
.002 w
.46763 .40119 m .49613 .38063 L .51311 .41323 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51311 .41323 m .49362 .42732 L .46763 .40119 L p
1 g
F P
s
P
p
.002 w
.51311 .41323 m .53577 .40605 L .54118 .44276 L p
1 g
F P
s
P
p
.002 w
.54118 .44276 m .52971 .44644 L .51311 .41323 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51985 .45358 m .51269 .46341 L .47951 .44675 L p
1 g
F P
s
P
p
.002 w
.52971 .44644 m .51985 .45358 L .49362 .42732 L p
1 g
F P
s
P
p
.002 w
.49362 .42732 m .51311 .41323 L .52971 .44644 L p
1 g
F P
s
P
p
.002 w
.47951 .44675 m .49362 .42732 L .51985 .45358 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.54674 .48051 m
.57318 .50879 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .31311 .33121 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57318 .50879 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0596899)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0596899)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50223 .46985 m .52997 .44842 L .50955 .4286 L p
1 g
F P
s
P
p
.002 w
.50955 .4286 m .4881 .44516 L .50223 .46985 L p
1 g
F P
s
P
p
.002 w
.52517 .4066 m .50955 .4286 L .52997 .44842 L p
1 g
F P
s
P
p
.002 w
.4881 .44516 m .50955 .4286 L .48892 .40886 L p
1 g
F P
s
P
p
.002 w
.50955 .4286 m .52517 .4066 L .49955 .39381 L p
1 g
F P
s
P
p
.002 w
.49955 .39381 m .48892 .40886 L .50955 .4286 L p
1 g
F P
s
P
p
.002 w
.46976 .48217 m .50223 .46985 L .4881 .44516 L p
1 g
F P
s
P
p
.002 w
.4881 .44516 m .46297 .4546 L .46976 .48217 L p
1 g
F P
s
P
p
.002 w
.46297 .4546 m .4881 .44516 L .47427 .42015 L p
1 g
F P
s
P
p
.002 w
.48892 .40886 m .47427 .42015 L .4881 .44516 L p
1 g
F P
s
P
p
.002 w
.47427 .42015 m .48892 .40886 L .46846 .38954 L p
1 g
F P
s
P
p
.002 w
.48892 .40886 m .49955 .39381 L .47385 .38187 L p
1 g
F P
s
P
p
.002 w
.47385 .38187 m .46846 .38954 L .48892 .40886 L p
1 g
F P
s
P
p
.002 w
.47427 .42015 m .4571 .42654 L .46297 .4546 L p
1 g
F P
s
P
p
.002 w
.4571 .42654 m .47427 .42015 L .461 .39528 L p
1 g
F P
s
P
p
.002 w
.46846 .38954 m .461 .39528 L .47427 .42015 L p
1 g
F P
s
P
p
.002 w
.52997 .44842 m .55024 .42 L .52517 .4066 L p
1 g
F P
s
P
p
.002 w
.53334 .38136 m .52517 .4066 L .55024 .42 L p
1 g
F P
s
P
p
.002 w
.52517 .4066 m .53334 .38136 L .50504 .37657 L p
1 g
F P
s
P
p
.002 w
.50504 .37657 m .49955 .39381 L .52517 .4066 L p
1 g
F P
s
P
p
.002 w
.51642 .49377 m .54981 .46795 L .52997 .44842 L p
1 g
F P
s
P
p
.002 w
.52997 .44842 m .50223 .46985 L .51642 .49377 L p
1 g
F P
s
P
p
.002 w
.55024 .42 m .52997 .44842 L .54981 .46795 L p
1 g
F P
s
P
p
.002 w
.49955 .39381 m .50504 .37657 L .4766 .37309 L p
1 g
F P
s
P
p
.002 w
.4766 .37309 m .47385 .38187 L .49955 .39381 L p
1 g
F P
s
P
p
.002 w
.47735 .50875 m .51642 .49377 L .50223 .46985 L p
1 g
F P
s
P
p
.002 w
.50223 .46985 m .46976 .48217 L .47735 .50875 L p
1 g
F P
s
P
p
.002 w
.43669 .4559 m .46297 .4546 L .4571 .42654 L p
1 g
F P
s
P
p
.002 w
.4571 .42654 m .43918 .42732 L .43669 .4559 L p
1 g
F P
s
P
p
.002 w
.43918 .42732 m .4571 .42654 L .45226 .3985 L p
1 g
F P
s
P
p
.002 w
.461 .39528 m .45226 .3985 L .4571 .42654 L p
1 g
F P
s
P
p
.002 w
.43572 .48405 m .46976 .48217 L .46297 .4546 L p
1 g
F P
s
P
p
.002 w
.46297 .4546 m .43669 .4559 L .43572 .48405 L p
1 g
F P
s
P
p
.002 w
.54981 .46795 m .5743 .43378 L .55024 .42 L p
1 g
F P
s
P
p
.002 w
.56098 .38737 m .55024 .42 L .5743 .43378 L p
1 g
F P
s
P
p
.002 w
.55024 .42 m .56098 .38737 L .53334 .38136 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .461 .39528 L .46846 .38954 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .46846 .38954 L .47385 .38187 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .45226 .3985 L .461 .39528 L closepath p
1 g
F P
s
P
p
.002 w
.50476 .35891 m .50504 .37657 L .53334 .38136 L p
1 g
F P
s
P
p
.002 w
.50504 .37657 m .50476 .35891 L .47639 .36414 L p
1 g
F P
s
P
p
.002 w
.47639 .36414 m .4766 .37309 L .50504 .37657 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .47385 .38187 L .4766 .37309 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .3985 m .44316 .39884 L .43918 .42732 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .44316 .39884 L .45226 .3985 L closepath p
1 g
F P
s
P
p
.002 w
.53312 .35541 m .53334 .38136 L .56098 .38737 L p
1 g
F P
s
P
p
.002 w
.53334 .38136 m .53312 .35541 L .50476 .35891 L p
1 g
F P
s
P
p
.002 w
.43632 .51124 m .47735 .50875 L .46976 .48217 L p
1 g
F P
s
P
p
.002 w
.46976 .48217 m .43572 .48405 L .43632 .51124 L p
1 g
F P
s
P
p
.002 w
.41194 .44879 m .43669 .4559 L .43918 .42732 L p
1 g
F P
s
P
p
.002 w
.43918 .42732 m .42239 .42235 L .41194 .44879 L p
1 g
F P
s
P
p
.002 w
.42239 .42235 m .43918 .42732 L .44316 .39884 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .4766 .37309 L .47639 .36414 L closepath p
1 g
F P
s
P
p
.002 w
.53041 .51648 m .56871 .48683 L .54981 .46795 L p
1 g
F P
s
P
p
.002 w
.54981 .46795 m .51642 .49377 L .53041 .51648 L p
1 g
F P
s
P
p
.002 w
.5743 .43378 m .54981 .46795 L .56871 .48683 L p
1 g
F P
s
P
p
.002 w
.44316 .39884 m .43467 .39626 L .42239 .42235 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .43467 .39626 L .44316 .39884 L closepath p
1 g
F P
s
P
p
.002 w
.48561 .53381 m .53041 .51648 L .51642 .49377 L p
1 g
F P
s
P
p
.002 w
.51642 .49377 m .47735 .50875 L .48561 .53381 L p
1 g
F P
s
P
p
.002 w
.40355 .47508 m .43572 .48405 L .43669 .4559 L p
1 g
F P
s
P
p
.002 w
.43669 .4559 m .41194 .44879 L .40355 .47508 L p
1 g
F P
s
P
p
.002 w
.47324 .35595 m .47639 .36414 L .50476 .35891 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .47639 .36414 L .47324 .35595 L closepath p
1 g
F P
s
P
p
.002 w
.49868 .34269 m .50476 .35891 L .53312 .35541 L p
1 g
F P
s
P
p
.002 w
.50476 .35891 m .49868 .34269 L .47324 .35595 L p
1 g
F P
s
P
p
.002 w
.40852 .41208 m .42239 .42235 L .43467 .39626 L p
1 g
F P
s
P
p
.002 w
.43467 .39626 m .4277 .391 L .40852 .41208 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .4277 .391 L .43467 .39626 L closepath p
1 g
F P
s
P
p
.002 w
.56871 .48683 m .5969 .44767 L .5743 .43378 L p
1 g
F P
s
P
p
.002 w
.58744 .3945 m .5743 .43378 L .5969 .44767 L p
1 g
F P
s
P
p
.002 w
.5743 .43378 m .58744 .3945 L .56098 .38737 L p
1 g
F P
s
P
p
.002 w
.56093 .35373 m .56098 .38737 L .58744 .3945 L p
1 g
F P
s
P
p
.002 w
.56098 .38737 m .56093 .35373 L .53312 .35541 L p
1 g
F P
s
P
p
.002 w
.39139 .43385 m .41194 .44879 L .42239 .42235 L p
1 g
F P
s
P
p
.002 w
.42239 .42235 m .40852 .41208 L .39139 .43385 L p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .4265 .35731 L .42237 .36579 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .42237 .36579 L .42118 .3749 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .42118 .3749 L .42303 .38362 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .42303 .38362 L .4277 .391 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .47324 .35595 L .46746 .34944 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .46746 .34944 L .45965 .34531 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .45965 .34531 L .45066 .34404 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .45066 .34404 L .44148 .34579 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .44148 .34579 L .43311 .35038 L closepath p
1 g
F P
s
P
p
.002 w
.44854 .37099 m .43311 .35038 L .4265 .35731 L closepath p
1 g
F P
s
P
p
.002 w
.46746 .34944 m .47324 .35595 L .49868 .34269 L p
1 g
F P
s
P
p
.002 w
.43852 .53693 m .48561 .53381 L .47735 .50875 L p
1 g
F P
s
P
p
.002 w
.47735 .50875 m .43632 .51124 L .43852 .53693 L p
1 g
F P
s
P
p
.002 w
.52438 .33147 m .53312 .35541 L .56093 .35373 L p
1 g
F P
s
P
p
.002 w
.53312 .35541 m .52438 .33147 L .49868 .34269 L p
1 g
F P
s
P
p
.002 w
.39913 .39754 m .40852 .41208 L .4277 .391 L p
1 g
F P
s
P
p
.002 w
.4277 .391 m .42303 .38362 L .39913 .39754 L p
1 g
F P
s
P
p
.002 w
.39743 .5007 m .43632 .51124 L .43572 .48405 L p
1 g
F P
s
P
p
.002 w
.43572 .48405 m .40355 .47508 L .39743 .5007 L p
1 g
F P
s
P
p
.002 w
.49868 .34269 m .48735 .32968 L .46746 .34944 L p
1 g
F P
s
P
p
.002 w
.45965 .34531 m .46746 .34944 L .48735 .32968 L p
1 g
F P
s
P
p
.002 w
.48735 .32968 m .49868 .34269 L .52438 .33147 L p
1 g
F P
s
P
p
.002 w
.54393 .53752 m .58628 .50469 L .56871 .48683 L p
1 g
F P
s
P
p
.002 w
.56871 .48683 m .53041 .51648 L .54393 .53752 L p
1 g
F P
s
P
p
.002 w
.5969 .44767 m .56871 .48683 L .58628 .50469 L p
1 g
F P
s
P
p
.002 w
.37668 .4559 m .40355 .47508 L .41194 .44879 L p
1 g
F P
s
P
p
.002 w
.41194 .44879 m .39139 .43385 L .37668 .4559 L p
1 g
F P
s
P
p
.002 w
.39532 .38025 m .39913 .39754 L .42303 .38362 L p
1 g
F P
s
P
p
.002 w
.42303 .38362 m .42118 .3749 L .39532 .38025 L p
1 g
F P
s
P
p
.002 w
.49442 .55683 m .54393 .53752 L .53041 .51648 L p
1 g
F P
s
P
p
.002 w
.53041 .51648 m .48561 .53381 L .49442 .55683 L p
1 g
F P
s
P
p
.002 w
.37735 .41251 m .39139 .43385 L .40852 .41208 L p
1 g
F P
s
P
p
.002 w
.40852 .41208 m .39913 .39754 L .37735 .41251 L p
1 g
F P
s
P
p
.002 w
.48735 .32968 m .47192 .32136 L .45965 .34531 L p
1 g
F P
s
P
p
.002 w
.45066 .34404 m .45965 .34531 L .47192 .32136 L p
1 g
F P
s
P
p
.002 w
.5969 .44767 m .61218 .40266 L .58744 .3945 L p
1 g
F P
s
P
p
.002 w
.58766 .35392 m .58744 .3945 L .61218 .40266 L p
1 g
F P
s
P
p
.002 w
.58744 .3945 m .58766 .35392 L .56093 .35373 L p
1 g
F P
s
P
p
.002 w
.39761 .3621 m .39532 .38025 L .42118 .3749 L p
1 g
F P
s
P
p
.002 w
.42118 .3749 m .42237 .36579 L .39761 .3621 L p
1 g
F P
s
P
p
.002 w
.54984 .32255 m .56093 .35373 L .58766 .35392 L p
1 g
F P
s
P
p
.002 w
.56093 .35373 m .54984 .32255 L .52438 .33147 L p
1 g
F P
s
P
p
.002 w
.58628 .50469 m .61756 .46143 L .5969 .44767 L p
1 g
F P
s
P
p
.002 w
.61218 .40266 m .5969 .44767 L .61756 .46143 L p
1 g
F P
s
P
p
.002 w
.47192 .32136 m .45406 .31873 L .45066 .34404 L p
1 g
F P
s
P
p
.002 w
.44148 .34579 m .45066 .34404 L .45406 .31873 L p
1 g
F P
s
P
p
.002 w
.4058 .34514 m .39761 .3621 L .42237 .36579 L p
1 g
F P
s
P
p
.002 w
.42237 .36579 m .4265 .35731 L .4058 .34514 L p
1 g
F P
s
P
p
.002 w
.52438 .33147 m .50784 .31215 L .48735 .32968 L p
1 g
F P
s
P
p
.002 w
.47192 .32136 m .48735 .32968 L .50784 .31215 L p
1 g
F P
s
P
p
.002 w
.50784 .31215 m .52438 .33147 L .54984 .32255 L p
1 g
F P
s
P
p
.002 w
.39375 .52512 m .43852 .53693 L .43632 .51124 L p
1 g
F P
s
P
p
.002 w
.43632 .51124 m .39743 .5007 L .39375 .52512 L p
1 g
F P
s
P
p
.002 w
.45406 .31873 m .43572 .32215 L .44148 .34579 L p
1 g
F P
s
P
p
.002 w
.43311 .35038 m .44148 .34579 L .43572 .32215 L p
1 g
F P
s
P
p
.002 w
.419 .33129 m .4058 .34514 L .4265 .35731 L p
1 g
F P
s
P
p
.002 w
.4265 .35731 m .43311 .35038 L .419 .33129 L p
1 g
F P
s
P
p
.002 w
.44233 .56053 m .49442 .55683 L .48561 .53381 L p
1 g
F P
s
P
p
.002 w
.48561 .53381 m .43852 .53693 L .44233 .56053 L p
1 g
F P
s
P
p
.002 w
.43572 .32215 m .419 .33129 L .43311 .35038 L p
1 g
F P
s
P
p
.002 w
.37154 .38697 m .37735 .41251 L .39913 .39754 L p
1 g
F P
s
P
p
.002 w
.39913 .39754 m .39532 .38025 L .37154 .38697 L p
1 g
F P
s
P
p
.002 w
.36477 .47779 m .39743 .5007 L .40355 .47508 L p
1 g
F P
s
P
p
.002 w
.40355 .47508 m .37668 .4559 L .36477 .47779 L p
1 g
F P
s
P
p
.002 w
.35818 .42826 m .37668 .4559 L .39139 .43385 L p
1 g
F P
s
P
p
.002 w
.39139 .43385 m .37735 .41251 L .35818 .42826 L p
1 g
F P
s
P
p
.002 w
.50784 .31215 m .48514 .29968 L .47192 .32136 L p
1 g
F P
s
P
p
.002 w
.45406 .31873 m .47192 .32136 L .48514 .29968 L p
1 g
F P
s
P
p
.002 w
.55668 .5564 m .60213 .52114 L .58628 .50469 L p
1 g
F P
s
P
p
.002 w
.58628 .50469 m .54393 .53752 L .55668 .5564 L p
1 g
F P
s
P
p
.002 w
.61756 .46143 m .58628 .50469 L .60213 .52114 L p
1 g
F P
s
P
p
.002 w
.61756 .46143 m .63467 .41169 L .61218 .40266 L p
1 g
F P
s
P
p
.002 w
.61274 .35605 m .61218 .40266 L .63467 .41169 L p
1 g
F P
s
P
p
.002 w
.61218 .40266 m .61274 .35605 L .58766 .35392 L p
1 g
F P
s
P
p
.002 w
.5036 .57726 m .55668 .5564 L .54393 .53752 L p
1 g
F P
s
P
p
.002 w
.54393 .53752 m .49442 .55683 L .5036 .57726 L p
1 g
F P
s
P
p
.002 w
.37479 .36004 m .37154 .38697 L .39532 .38025 L p
1 g
F P
s
P
p
.002 w
.39532 .38025 m .39761 .3621 L .37479 .36004 L p
1 g
F P
s
P
p
.002 w
.57456 .31616 m .58766 .35392 L .61274 .35605 L p
1 g
F P
s
P
p
.002 w
.58766 .35392 m .57456 .31616 L .54984 .32255 L p
1 g
F P
s
P
p
.002 w
.54984 .32255 m .52854 .29723 L .50784 .31215 L p
1 g
F P
s
P
p
.002 w
.48514 .29968 m .50784 .31215 L .52854 .29723 L p
1 g
F P
s
P
p
.002 w
.52854 .29723 m .54984 .32255 L .57456 .31616 L p
1 g
F P
s
P
p
.002 w
.48514 .29968 m .45869 .29562 L .45406 .31873 L p
1 g
F P
s
P
p
.002 w
.43572 .32215 m .45406 .31873 L .45869 .29562 L p
1 g
F P
s
P
p
.002 w
.60213 .52114 m .63579 .47477 L .61756 .46143 L p
1 g
F P
s
P
p
.002 w
.63467 .41169 m .61756 .46143 L .63579 .47477 L p
1 g
F P
s
P
p
.002 w
.39269 .54778 m .44233 .56053 L .43852 .53693 L p
1 g
F P
s
P
p
.002 w
.43852 .53693 m .39375 .52512 L .39269 .54778 L p
1 g
F P
s
P
p
.002 w
.38689 .33479 m .37479 .36004 L .39761 .3621 L p
1 g
F P
s
P
p
.002 w
.39761 .3621 m .4058 .34514 L .38689 .33479 L p
1 g
F P
s
P
p
.002 w
.35038 .39499 m .35818 .42826 L .37735 .41251 L p
1 g
F P
s
P
p
.002 w
.37735 .41251 m .37154 .38697 L .35038 .39499 L p
1 g
F P
s
P
p
.002 w
.35601 .49904 m .39375 .52512 L .39743 .5007 L p
1 g
F P
s
P
p
.002 w
.39743 .5007 m .36477 .47779 L .35601 .49904 L p
1 g
F P
s
P
p
.002 w
.34214 .4445 m .36477 .47779 L .37668 .4559 L p
1 g
F P
s
P
p
.002 w
.37668 .4559 m .35818 .42826 L .34214 .4445 L p
1 g
F P
s
P
p
.002 w
.45869 .29562 m .43144 .3006 L .43572 .32215 L p
1 g
F P
s
P
p
.002 w
.419 .33129 m .43572 .32215 L .43144 .3006 L p
1 g
F P
s
P
p
.002 w
.44772 .58149 m .5036 .57726 L .49442 .55683 L p
1 g
F P
s
P
p
.002 w
.49442 .55683 m .44233 .56053 L .44772 .58149 L p
1 g
F P
s
P
p
.002 w
.40653 .31417 m .38689 .33479 L .4058 .34514 L p
1 g
F P
s
P
p
.002 w
.4058 .34514 m .419 .33129 L .40653 .31417 L p
1 g
F P
s
P
p
.002 w
.43144 .3006 m .40653 .31417 L .419 .33129 L p
1 g
F P
s
P
p
.002 w
.52854 .29723 m .49907 .28077 L .48514 .29968 L p
1 g
F P
s
P
p
.002 w
.45869 .29562 m .48514 .29968 L .49907 .28077 L p
1 g
F P
s
P
p
.002 w
.63467 .41169 m .63559 .36012 L .61274 .35605 L p
1 g
F P
s
P
p
.002 w
.59799 .31253 m .61274 .35605 L .63559 .36012 L p
1 g
F P
s
P
p
.002 w
.61274 .35605 m .59799 .31253 L .57456 .31616 L p
1 g
F P
s
P
p
.002 w
.35449 .35972 m .35038 .39499 L .37154 .38697 L p
1 g
F P
s
P
p
.002 w
.37154 .38697 m .37479 .36004 L .35449 .35972 L p
1 g
F P
s
P
p
.002 w
.63579 .47477 m .65436 .42146 L .63467 .41169 L p
1 g
F P
s
P
p
.002 w
.63559 .36012 m .63467 .41169 L .65436 .42146 L p
1 g
F P
s
P
p
.002 w
.57456 .31616 m .54903 .28535 L .52854 .29723 L p
1 g
F P
s
P
p
.002 w
.49907 .28077 m .52854 .29723 L .54903 .28535 L p
1 g
F P
s
P
p
.002 w
.54903 .28535 m .57456 .31616 L .59799 .31253 L p
1 g
F P
s
P
p
.002 w
.56838 .57264 m .61586 .53578 L .60213 .52114 L p
1 g
F P
s
P
p
.002 w
.60213 .52114 m .55668 .5564 L .56838 .57264 L p
1 g
F P
s
P
p
.002 w
.63579 .47477 m .60213 .52114 L .61586 .53578 L p
1 g
F P
s
P
p
.002 w
.51298 .59457 m .56838 .57264 L .55668 .5564 L p
1 g
F P
s
P
p
.002 w
.55668 .5564 m .5036 .57726 L .51298 .59457 L p
1 g
F P
s
P
p
.002 w
.49907 .28077 m .46451 .27528 L .45869 .29562 L p
1 g
F P
s
P
p
.002 w
.43144 .3006 m .45869 .29562 L .46451 .27528 L p
1 g
F P
s
P
p
.002 w
.33245 .40417 m .34214 .4445 L .35818 .42826 L p
1 g
F P
s
P
p
.002 w
.35818 .42826 m .35038 .39499 L .33245 .40417 L p
1 g
F P
s
P
p
.002 w
.3944 .56809 m .44772 .58149 L .44233 .56053 L p
1 g
F P
s
P
p
.002 w
.44233 .56053 m .39269 .54778 L .3944 .56809 L p
1 g
F P
s
P
p
.002 w
.35073 .51916 m .39269 .54778 L .39375 .52512 L p
1 g
F P
s
P
p
.002 w
.39375 .52512 m .35601 .49904 L .35073 .51916 L p
1 g
F P
s
P
p
.002 w
.61586 .53578 m .6511 .48739 L .63579 .47477 L p
1 g
F P
s
P
p
.002 w
.65436 .42146 m .63579 .47477 L .6511 .48739 L p
1 g
F P
s
P
p
.002 w
.3297 .46087 m .35601 .49904 L .36477 .47779 L p
1 g
F P
s
P
p
.002 w
.36477 .47779 m .34214 .4445 L .3297 .46087 L p
1 g
F P
s
P
p
.002 w
.37029 .32656 m .35449 .35972 L .37479 .36004 L p
1 g
F P
s
P
p
.002 w
.37479 .36004 m .38689 .33479 L .37029 .32656 L p
1 g
F P
s
P
p
.002 w
.45465 .5992 m .51298 .59457 L .5036 .57726 L p
1 g
F P
s
P
p
.002 w
.5036 .57726 m .44772 .58149 L .45465 .5992 L p
1 g
F P
s
P
p
.002 w
.46451 .27528 m .42878 .28171 L .43144 .3006 L p
1 g
F P
s
P
p
.002 w
.40653 .31417 m .43144 .3006 L .42878 .28171 L p
1 g
F P
s
P
p
.002 w
.39606 .29948 m .37029 .32656 L .38689 .33479 L p
1 g
F P
s
P
p
.002 w
.38689 .33479 m .40653 .31417 L .39606 .29948 L p
1 g
F P
s
P
p
.002 w
.42878 .28171 m .39606 .29948 L .40653 .31417 L p
1 g
F P
s
P
p
.002 w
.54903 .28535 m .51343 .26516 L .49907 .28077 L p
1 g
F P
s
P
p
.002 w
.46451 .27528 m .49907 .28077 L .51343 .26516 L p
1 g
F P
s
P
p
.002 w
.65436 .42146 m .65562 .36613 L .63559 .36012 L p
1 g
F P
s
P
p
.002 w
.61957 .31184 m .63559 .36012 L .65562 .36613 L p
1 g
F P
s
P
p
.002 w
.63559 .36012 m .61957 .31184 L .59799 .31253 L p
1 g
F P
s
P
p
.002 w
.59799 .31253 m .56886 .27686 L .54903 .28535 L p
1 g
F P
s
P
p
.002 w
.51343 .26516 m .54903 .28535 L .56886 .27686 L p
1 g
F P
s
P
p
.002 w
.56886 .27686 m .59799 .31253 L .61957 .31184 L p
1 g
F P
s
P
p
.002 w
.33728 .36125 m .33245 .40417 L .35038 .39499 L p
1 g
F P
s
P
p
.002 w
.35038 .39499 m .35449 .35972 L .33728 .36125 L p
1 g
F P
s
P
p
.002 w
.6511 .48739 m .67068 .43178 L .65436 .42146 L p
1 g
F P
s
P
p
.002 w
.65562 .36613 m .65436 .42146 L .67068 .43178 L p
1 g
F P
s
P
p
.002 w
.57871 .58576 m .62706 .54821 L .61586 .53578 L p
1 g
F P
s
P
p
.002 w
.61586 .53578 m .56838 .57264 L .57871 .58576 L p
1 g
F P
s
P
p
.002 w
.6511 .48739 m .61586 .53578 L .62706 .54821 L p
1 g
F P
s
P
p
.002 w
.52235 .60819 m .57871 .58576 L .56838 .57264 L p
1 g
F P
s
P
p
.002 w
.56838 .57264 m .51298 .59457 L .52235 .60819 L p
1 g
F P
s
P
p
.002 w
.31829 .41437 m .3297 .46087 L .34214 .4445 L p
1 g
F P
s
P
p
.002 w
.34214 .4445 m .33245 .40417 L .31829 .41437 L p
1 g
F P
s
P
p
.002 w
.34921 .53762 m .3944 .56809 L .39269 .54778 L p
1 g
F P
s
P
p
.002 w
.39269 .54778 m .35073 .51916 L .34921 .53762 L p
1 g
F P
s
P
p
.002 w
.51343 .26516 m .47146 .25831 L .46451 .27528 L p
1 g
F P
s
P
p
.002 w
.42878 .28171 m .46451 .27528 L .47146 .25831 L p
1 g
F P
s
P
p
.002 w
.32134 .477 m .35073 .51916 L .35601 .49904 L p
1 g
F P
s
P
p
.002 w
.35601 .49904 m .3297 .46087 L .32134 .477 L p
1 g
F P
s
P
p
.002 w
.39896 .58546 m .45465 .5992 L .44772 .58149 L p
1 g
F P
s
P
p
.002 w
.44772 .58149 m .3944 .56809 L .39896 .58546 L p
1 g
F P
s
P
p
.002 w
.62706 .54821 m .66301 .49898 L .6511 .48739 L p
1 g
F P
s
P
p
.002 w
.67068 .43178 m .6511 .48739 L .66301 .49898 L p
1 g
F P
s
P
p
.002 w
.35647 .32077 m .33728 .36125 L .35449 .35972 L p
1 g
F P
s
P
p
.002 w
.35449 .35972 m .37029 .32656 L .35647 .32077 L p
1 g
F P
s
P
p
.002 w
.46304 .61308 m .52235 .60819 L .51298 .59457 L p
1 g
F P
s
P
p
.002 w
.51298 .59457 m .45465 .5992 L .46304 .61308 L p
1 g
F P
s
P
p
.002 w
.47146 .25831 m .42789 .26602 L .42878 .28171 L p
1 g
F P
s
P
p
.002 w
.39606 .29948 m .42878 .28171 L .42789 .26602 L p
1 g
F P
s
P
p
.002 w
.56886 .27686 m .52792 .25336 L .51343 .26516 L p
1 g
F P
s
P
p
.002 w
.47146 .25831 m .51343 .26516 L .52792 .25336 L p
1 g
F P
s
P
p
.002 w
.38793 .28768 m .35647 .32077 L .37029 .32656 L p
1 g
F P
s
P
p
.002 w
.37029 .32656 m .39606 .29948 L .38793 .28768 L p
1 g
F P
s
P
p
.002 w
.42789 .26602 m .38793 .28768 L .39606 .29948 L p
1 g
F P
s
P
p
.002 w
.61957 .31184 m .58752 .27214 L .56886 .27686 L p
1 g
F P
s
P
p
.002 w
.52792 .25336 m .56886 .27686 L .58752 .27214 L p
1 g
F P
s
P
p
.002 w
.67068 .43178 m .67225 .37404 L .65562 .36613 L p
1 g
F P
s
P
p
.002 w
.63872 .31425 m .65562 .36613 L .67225 .37404 L p
1 g
F P
s
P
p
.002 w
.65562 .36613 m .63872 .31425 L .61957 .31184 L p
1 g
F P
s
P
p
.002 w
.58752 .27214 m .61957 .31184 L .63872 .31425 L p
1 g
F P
s
P
p
.002 w
.32375 .36468 m .31829 .41437 L .33245 .40417 L p
1 g
F P
s
P
p
.002 w
.33245 .40417 m .33728 .36125 L .32375 .36468 L p
1 g
F P
s
P
p
.002 w
.66301 .49898 m .68308 .44244 L .67068 .43178 L p
1 g
F P
s
P
p
.002 w
.67225 .37404 m .67068 .43178 L .68308 .44244 L p
1 g
F P
s
P
p
.002 w
.30849 .4254 m .32134 .477 L .3297 .46087 L p
1 g
F P
s
P
p
.002 w
.3297 .46087 m .31829 .41437 L .30849 .4254 L p
1 g
F P
s
P
p
.002 w
.58736 .59527 m .63532 .55799 L .62706 .54821 L p
1 g
F P
s
P
p
.002 w
.62706 .54821 m .57871 .58576 L .58736 .59527 L p
1 g
F P
s
P
p
.002 w
.66301 .49898 m .62706 .54821 L .63532 .55799 L p
1 g
F P
s
P
p
.002 w
.35171 .55388 m .39896 .58546 L .3944 .56809 L p
1 g
F P
s
P
p
.002 w
.3944 .56809 m .34921 .53762 L .35171 .55388 L p
1 g
F P
s
P
p
.002 w
.31748 .49248 m .34921 .53762 L .35073 .51916 L p
1 g
F P
s
P
p
.002 w
.35073 .51916 m .32134 .477 L .31748 .49248 L p
1 g
F P
s
P
p
.002 w
.53149 .61759 m .58736 .59527 L .57871 .58576 L p
1 g
F P
s
P
p
.002 w
.57871 .58576 m .52235 .60819 L .53149 .61759 L p
1 g
F P
s
P
p
.002 w
.52792 .25336 m .47942 .24527 L .47146 .25831 L p
1 g
F P
s
P
p
.002 w
.42789 .26602 m .47146 .25831 L .47942 .24527 L p
1 g
F P
s
P
p
.002 w
.40641 .59931 m .46304 .61308 L .45465 .5992 L p
1 g
F P
s
P
p
.002 w
.45465 .5992 m .39896 .58546 L .40641 .59931 L p
1 g
F P
s
P
p
.002 w
.63532 .55799 m .67104 .50919 L .66301 .49898 L p
1 g
F P
s
P
p
.002 w
.68308 .44244 m .66301 .49898 L .67104 .50919 L p
1 g
F P
s
P
p
.002 w
.34595 .31768 m .32375 .36468 L .33728 .36125 L p
1 g
F P
s
P
p
.002 w
.33728 .36125 m .35647 .32077 L .34595 .31768 L p
1 g
F P
s
P
p
.002 w
.47275 .62255 m .53149 .61759 L .52235 .60819 L p
1 g
F P
s
P
p
.002 w
.52235 .60819 m .46304 .61308 L .47275 .62255 L p
1 g
F P
s
P
p
.002 w
.58752 .27214 m .5422 .24586 L .52792 .25336 L p
1 g
F P
s
P
p
.002 w
.47942 .24527 m .52792 .25336 L .5422 .24586 L p
1 g
F P
s
P
p
.002 w
.47942 .24527 m .42889 .25412 L .42789 .26602 L p
1 g
F P
s
P
p
.002 w
.38793 .28768 m .42789 .26602 L .42889 .25412 L p
1 g
F P
s
P
p
.002 w
.38248 .27923 m .34595 .31768 L .35647 .32077 L p
1 g
F P
s
P
p
.002 w
.35647 .32077 m .38793 .28768 L .38248 .27923 L p
1 g
F P
s
P
p
.002 w
.63872 .31425 m .60452 .27148 L .58752 .27214 L p
1 g
F P
s
P
p
.002 w
.5422 .24586 m .58752 .27214 L .60452 .27148 L p
1 g
F P
s
P
p
.002 w
.67225 .37404 m .65485 .31986 L .63872 .31425 L p
1 g
F P
s
P
p
.002 w
.60452 .27148 m .63872 .31425 L .65485 .31986 L p
1 g
F P
s
P
p
.002 w
.68308 .44244 m .68487 .38376 L .67225 .37404 L p
1 g
F P
s
P
p
.002 w
.65485 .31986 m .67225 .37404 L .68487 .38376 L p
1 g
F P
s
P
p
.002 w
.42889 .25412 m .38248 .27923 L .38793 .28768 L p
1 g
F P
s
P
p
.002 w
.31446 .37004 m .30849 .4254 L .31829 .41437 L p
1 g
F P
s
P
p
.002 w
.31829 .41437 m .32375 .36468 L .31446 .37004 L p
1 g
F P
s
P
p
.002 w
.67104 .50919 m .69104 .4532 L .68308 .44244 L p
1 g
F P
s
P
p
.002 w
.68487 .38376 m .68308 .44244 L .69104 .4532 L p
1 g
F P
s
P
p
.002 w
.30354 .43701 m .31748 .49248 L .32134 .477 L p
1 g
F P
s
P
p
.002 w
.32134 .477 m .30849 .4254 L .30354 .43701 L p
1 g
F P
s
P
p
.002 w
.31849 .50687 m .35171 .55388 L .34921 .53762 L p
1 g
F P
s
P
p
.002 w
.34921 .53762 m .31748 .49248 L .31849 .50687 L p
1 g
F P
s
P
p
.002 w
.35839 .56737 m .40641 .59931 L .39896 .58546 L p
1 g
F P
s
P
p
.002 w
.39896 .58546 m .35171 .55388 L .35839 .56737 L p
1 g
F P
s
P
p
.002 w
.594 .6007 m .64027 .56473 L .63532 .55799 L p
1 g
F P
s
P
p
.002 w
.63532 .55799 m .58736 .59527 L .594 .6007 L p
1 g
F P
s
P
p
.002 w
.67104 .50919 m .63532 .55799 L .64027 .56473 L p
1 g
F P
s
P
p
.002 w
.41674 .60905 m .47275 .62255 L .46304 .61308 L p
1 g
F P
s
P
p
.002 w
.46304 .61308 m .40641 .59931 L .41674 .60905 L p
1 g
F P
s
P
p
.002 w
.5422 .24586 m .48826 .23673 L .47942 .24527 L p
1 g
F P
s
P
p
.002 w
.42889 .25412 m .47942 .24527 L .48826 .23673 L p
1 g
F P
s
P
p
.002 w
.54015 .62227 m .594 .6007 L .58736 .59527 L p
1 g
F P
s
P
p
.002 w
.58736 .59527 m .53149 .61759 L .54015 .62227 L p
1 g
F P
s
P
p
.002 w
.33919 .31756 m .31446 .37004 L .32375 .36468 L p
1 g
F P
s
P
p
.002 w
.32375 .36468 m .34595 .31768 L .33919 .31756 L p
1 g
F P
s
P
p
.002 w
.64027 .56473 m .67474 .51768 L .67104 .50919 L p
1 g
F P
s
P
p
.002 w
.69104 .4532 m .67104 .50919 L .67474 .51768 L p
1 g
F P
s
P
p
.002 w
.60452 .27148 m .55589 .24311 L .5422 .24586 L p
1 g
F P
s
P
p
.002 w
.48826 .23673 m .5422 .24586 L .55589 .24311 L p
1 g
F P
s
P
p
.002 w
.48362 .62711 m .54015 .62227 L .53149 .61759 L p
1 g
F P
s
P
p
.002 w
.53149 .61759 m .47275 .62255 L .48362 .62711 L p
1 g
F P
s
P
p
.002 w
.48826 .23673 m .43189 .24654 L .42889 .25412 L p
1 g
F P
s
P
p
.002 w
.38248 .27923 m .42889 .25412 L .43189 .24654 L p
1 g
F P
s
P
p
.002 w
.65485 .31986 m .61932 .27515 L .60452 .27148 L p
1 g
F P
s
P
p
.002 w
.55589 .24311 m .60452 .27148 L .61932 .27515 L p
1 g
F P
s
P
p
.002 w
.68487 .38376 m .66737 .32871 L .65485 .31986 L p
1 g
F P
s
P
p
.002 w
.61932 .27515 m .65485 .31986 L .66737 .32871 L p
1 g
F P
s
P
p
.002 w
.69104 .4532 m .69293 .39515 L .68487 .38376 L p
1 g
F P
s
P
p
.002 w
.66737 .32871 m .68487 .38376 L .69293 .39515 L p
1 g
F P
s
P
p
.002 w
.38001 .27458 m .33919 .31756 L .34595 .31768 L p
1 g
F P
s
P
p
.002 w
.34595 .31768 m .38248 .27923 L .38001 .27458 L p
1 g
F P
s
P
p
.002 w
.43189 .24654 m .38001 .27458 L .38248 .27923 L p
1 g
F P
s
P
p
.002 w
.30993 .37731 m .30354 .43701 L .30849 .4254 L p
1 g
F P
s
P
p
.002 w
.30849 .4254 m .31446 .37004 L .30993 .37731 L p
1 g
F P
s
P
p
.002 w
.67474 .51768 m .69407 .46378 L .69104 .4532 L p
1 g
F P
s
P
p
.002 w
.69293 .39515 m .69104 .4532 L .69407 .46378 L p
1 g
F P
s
P
p
.002 w
.30388 .44892 m .31849 .50687 L .31748 .49248 L p
1 g
F P
s
P
p
.002 w
.31748 .49248 m .30354 .43701 L .30388 .44892 L p
1 g
F P
s
P
p
.002 w
.32464 .51969 m .35839 .56737 L .35171 .55388 L p
1 g
F P
s
P
p
.002 w
.35171 .55388 m .31849 .50687 L .32464 .51969 L p
1 g
F P
s
P
p
.002 w
.36931 .57756 m .41674 .60905 L .40641 .59931 L p
1 g
F P
s
P
p
.002 w
.40641 .59931 m .35839 .56737 L .36931 .57756 L p
1 g
F P
s
P
p
.002 w
.42983 .61418 m .48362 .62711 L .47275 .62255 L p
1 g
F P
s
P
p
.002 w
.47275 .62255 m .41674 .60905 L .42983 .61418 L p
1 g
F P
s
P
p
.002 w
.55589 .24311 m .4978 .2332 L .48826 .23673 L p
1 g
F P
s
P
p
.002 w
.43189 .24654 m .48826 .23673 L .4978 .2332 L p
1 g
F P
s
P
p
.002 w
.59832 .60166 m .64154 .56805 L .64027 .56473 L p
1 g
F P
s
P
p
.002 w
.64027 .56473 m .594 .6007 L .59832 .60166 L p
1 g
F P
s
P
p
.002 w
.67474 .51768 m .64027 .56473 L .64154 .56805 L p
1 g
F P
s
P
p
.002 w
.54806 .6218 m .59832 .60166 L .594 .6007 L p
1 g
F P
s
P
p
.002 w
.594 .6007 m .54015 .62227 L .54806 .6218 L p
1 g
F P
s
P
p
.002 w
.33665 .32059 m .30993 .37731 L .31446 .37004 L p
1 g
F P
s
P
p
.002 w
.31446 .37004 m .33919 .31756 L .33665 .32059 L p
1 g
F P
s
P
p
.002 w
.64154 .56805 m .67375 .52412 L .67474 .51768 L p
1 g
F P
s
P
p
.002 w
.69407 .46378 m .67474 .51768 L .67375 .52412 L p
1 g
F P
s
P
p
.002 w
.61932 .27515 m .56859 .24545 L .55589 .24311 L p
1 g
F P
s
P
p
.002 w
.4978 .2332 m .55589 .24311 L .56859 .24545 L p
1 g
F P
s
P
p
.002 w
.66737 .32871 m .63138 .28328 L .61932 .27515 L p
1 g
F P
s
P
p
.002 w
.56859 .24545 m .61932 .27515 L .63138 .28328 L p
1 g
F P
s
P
p
.002 w
.69293 .39515 m .67572 .34074 L .66737 .32871 L p
1 g
F P
s
P
p
.002 w
.63138 .28328 m .66737 .32871 L .67572 .34074 L p
1 g
F P
s
P
p
.002 w
.49541 .62632 m .54806 .6218 L .54015 .62227 L p
1 g
F P
s
P
p
.002 w
.54015 .62227 m .48362 .62711 L .49541 .62632 L p
1 g
F P
s
P
p
.002 w
.69407 .46378 m .69594 .40798 L .69293 .39515 L p
1 g
F P
s
P
p
.002 w
.67572 .34074 m .69293 .39515 L .69594 .40798 L p
1 g
F P
s
P
p
.002 w
.4978 .2332 m .43692 .24376 L .43189 .24654 L p
1 g
F P
s
P
p
.002 w
.38001 .27458 m .43189 .24654 L .43692 .24376 L p
1 g
F P
s
P
p
.002 w
.43692 .24376 m .38081 .2741 L .38001 .27458 L p
1 g
F P
s
P
p
.002 w
.38081 .2741 m .33665 .32059 L .33919 .31756 L p
1 g
F P
s
P
p
.002 w
.33919 .31756 m .38001 .27458 L .38081 .2741 L p
1 g
F P
s
P
p
.002 w
.31059 .3864 m .30388 .44892 L .30354 .43701 L p
1 g
F P
s
P
p
.002 w
.30354 .43701 m .30993 .37731 L .31059 .3864 L p
1 g
F P
s
P
p
.002 w
.67375 .52412 m .69178 .47387 L .69407 .46378 L p
1 g
F P
s
P
p
.002 w
.69594 .40798 m .69407 .46378 L .69178 .47387 L p
1 g
F P
s
P
p
.002 w
.30984 .46079 m .32464 .51969 L .31849 .50687 L p
1 g
F P
s
P
p
.002 w
.31849 .50687 m .30388 .44892 L .30984 .46079 L p
1 g
F P
s
P
p
.002 w
.33604 .53047 m .36931 .57756 L .35839 .56737 L p
1 g
F P
s
P
p
.002 w
.35839 .56737 m .32464 .51969 L .33604 .53047 L p
1 g
F P
s
P
p
.002 w
.38439 .58395 m .42983 .61418 L .41674 .60905 L p
1 g
F P
s
P
p
.002 w
.41674 .60905 m .36931 .57756 L .38439 .58395 L p
1 g
F P
s
P
p
.002 w
.44544 .61425 m .49541 .62632 L .48362 .62711 L p
1 g
F P
s
P
p
.002 w
.48362 .62711 m .42983 .61418 L .44544 .61425 L p
1 g
F P
s
P
p
.002 w
.56859 .24545 m .5078 .23508 L .4978 .2332 L p
1 g
F P
s
P
p
.002 w
.43692 .24376 m .4978 .2332 L .5078 .23508 L p
1 g
F P
s
P
p
.002 w
.60005 .59781 m .63887 .56762 L .64154 .56805 L p
1 g
F P
s
P
p
.002 w
.64154 .56805 m .59832 .60166 L .60005 .59781 L p
1 g
F P
s
P
p
.002 w
.67375 .52412 m .64154 .56805 L .63887 .56762 L p
1 g
F P
s
P
p
.002 w
.55495 .61587 m .60005 .59781 L .59832 .60166 L p
1 g
F P
s
P
p
.002 w
.59832 .60166 m .54806 .6218 L .55495 .61587 L p
1 g
F P
s
P
p
.002 w
.33867 .32691 m .31059 .3864 L .30993 .37731 L p
1 g
F P
s
P
p
.002 w
.30993 .37731 m .33665 .32059 L .33867 .32691 L p
1 g
F P
s
P
p
.002 w
.63887 .56762 m .66778 .52818 L .67375 .52412 L p
1 g
F P
s
P
p
.002 w
.69178 .47387 m .67375 .52412 L .66778 .52818 L p
1 g
F P
s
P
p
.002 w
.63138 .28328 m .57985 .25314 L .56859 .24545 L p
1 g
F P
s
P
p
.002 w
.5078 .23508 m .56859 .24545 L .57985 .25314 L p
1 g
F P
s
P
p
.002 w
.69594 .40798 m .67942 .3558 L .67572 .34074 L p
1 g
F P
s
P
p
.002 w
.64019 .29593 m .67572 .34074 L .67942 .3558 L p
1 g
F P
s
P
p
.002 w
.67572 .34074 m .64019 .29593 L .63138 .28328 L p
1 g
F P
s
P
p
.002 w
.57985 .25314 m .63138 .28328 L .64019 .29593 L p
1 g
F P
s
P
p
.002 w
.50781 .61986 m .55495 .61587 L .54806 .6218 L p
1 g
F P
s
P
p
.002 w
.54806 .6218 m .49541 .62632 L .50781 .61986 L p
1 g
F P
s
P
p
.002 w
.69178 .47387 m .69349 .42197 L .69594 .40798 L p
1 g
F P
s
P
p
.002 w
.67942 .3558 m .69594 .40798 L .69349 .42197 L p
1 g
F P
s
P
p
.002 w
.5078 .23508 m .44397 .2462 L .43692 .24376 L p
1 g
F P
s
P
p
.002 w
.38081 .2741 m .43692 .24376 L .44397 .2462 L p
1 g
F P
s
P
p
.002 w
.31678 .39716 m .30984 .46079 L .30388 .44892 L p
1 g
F P
s
P
p
.002 w
.30388 .44892 m .31059 .3864 L .31678 .39716 L p
1 g
F P
s
P
p
.002 w
.38507 .27808 m .33867 .32691 L .33665 .32059 L p
1 g
F P
s
P
p
.002 w
.33665 .32059 m .38081 .2741 L .38507 .27808 L p
1 g
F P
s
P
p
.002 w
.35267 .53876 m .38439 .58395 L .36931 .57756 L p
1 g
F P
s
P
p
.002 w
.36931 .57756 m .33604 .53047 L .35267 .53876 L p
1 g
F P
s
P
p
.002 w
.32157 .47226 m .33604 .53047 L .32464 .51969 L p
1 g
F P
s
P
p
.002 w
.32464 .51969 m .30984 .46079 L .32157 .47226 L p
1 g
F P
s
P
p
.002 w
.44397 .2462 m .38507 .27808 L .38081 .2741 L p
1 g
F P
s
P
p
.002 w
.66778 .52818 m .6839 .48314 L .69178 .47387 L p
1 g
F P
s
P
p
.002 w
.69349 .42197 m .69178 .47387 L .6839 .48314 L p
1 g
F P
s
P
p
.002 w
.40341 .58611 m .44544 .61425 L .42983 .61418 L p
1 g
F P
s
P
p
.002 w
.42983 .61418 m .38439 .58395 L .40341 .58611 L p
1 g
F P
s
P
p
.002 w
.46325 .60897 m .50781 .61986 L .49541 .62632 L p
1 g
F P
s
P
p
.002 w
.49541 .62632 m .44544 .61425 L .46325 .60897 L p
1 g
F P
s
P
p
.002 w
.57985 .25314 m .518 .24269 L .5078 .23508 L p
1 g
F P
s
P
p
.002 w
.44397 .2462 m .5078 .23508 L .518 .24269 L p
1 g
F P
s
P
p
.002 w
.59896 .58895 m .63207 .56321 L .63887 .56762 L p
1 g
F P
s
P
p
.002 w
.63887 .56762 m .60005 .59781 L .59896 .58895 L p
1 g
F P
s
P
p
.002 w
.66778 .52818 m .63887 .56762 L .63207 .56321 L p
1 g
F P
s
P
p
.002 w
.56053 .60429 m .59896 .58895 L .60005 .59781 L p
1 g
F P
s
P
p
.002 w
.60005 .59781 m .55495 .61587 L .56053 .60429 L p
1 g
F P
s
P
p
.002 w
.64019 .29593 m .58926 .26627 L .57985 .25314 L p
1 g
F P
s
P
p
.002 w
.518 .24269 m .57985 .25314 L .58926 .26627 L p
1 g
F P
s
P
p
.002 w
.34549 .33652 m .31678 .39716 L .31059 .3864 L p
1 g
F P
s
P
p
.002 w
.31059 .3864 m .33867 .32691 L .34549 .33652 L p
1 g
F P
s
P
p
.002 w
.69349 .42197 m .67806 .37361 L .67942 .3558 L p
1 g
F P
s
P
p
.002 w
.64529 .31295 m .67942 .3558 L .67806 .37361 L p
1 g
F P
s
P
p
.002 w
.67942 .3558 m .64529 .31295 L .64019 .29593 L p
1 g
F P
s
P
p
.002 w
.58926 .26627 m .64019 .29593 L .64529 .31295 L p
1 g
F P
s
P
p
.002 w
.63207 .56321 m .65668 .52958 L .66778 .52818 L p
1 g
F P
s
P
p
.002 w
.6839 .48314 m .66778 .52818 L .65668 .52958 L p
1 g
F P
s
P
p
.002 w
.6839 .48314 m .68534 .43677 L .69349 .42197 L p
1 g
F P
s
P
p
.002 w
.67806 .37361 m .69349 .42197 L .68534 .43677 L p
1 g
F P
s
P
p
.002 w
.52048 .60758 m .56053 .60429 L .55495 .61587 L p
1 g
F P
s
P
p
.002 w
.55495 .61587 m .50781 .61986 L .52048 .60758 L p
1 g
F P
s
P
p
.002 w
.518 .24269 m .45296 .25412 L .44397 .2462 L p
1 g
F P
s
P
p
.002 w
.38507 .27808 m .44397 .2462 L .45296 .25412 L p
1 g
F P
s
P
p
.002 w
.32862 .40933 m .32157 .47226 L .30984 .46079 L p
1 g
F P
s
P
p
.002 w
.30984 .46079 m .31678 .39716 L .32862 .40933 L p
1 g
F P
s
P
p
.002 w
.37425 .54413 m .40341 .58611 L .38439 .58395 L p
1 g
F P
s
P
p
.002 w
.38439 .58395 m .35267 .53876 L .37425 .54413 L p
1 g
F P
s
P
p
.002 w
.33904 .48293 m .35267 .53876 L .33604 .53047 L p
1 g
F P
s
P
p
.002 w
.33604 .53047 m .32157 .47226 L .33904 .48293 L p
1 g
F P
s
P
p
.002 w
.39287 .28669 m .34549 .33652 L .33867 .32691 L p
1 g
F P
s
P
p
.002 w
.33867 .32691 m .38507 .27808 L .39287 .28669 L p
1 g
F P
s
P
p
.002 w
.42596 .58374 m .46325 .60897 L .44544 .61425 L p
1 g
F P
s
P
p
.002 w
.44544 .61425 m .40341 .58611 L .42596 .58374 L p
1 g
F P
s
P
p
.002 w
.65668 .52958 m .67032 .49125 L .6839 .48314 L p
1 g
F P
s
P
p
.002 w
.68534 .43677 m .6839 .48314 L .67032 .49125 L p
1 g
F P
s
P
p
.002 w
.45296 .25412 m .39287 .28669 L .38507 .27808 L p
1 g
F P
s
P
p
.002 w
.48279 .5982 m .52048 .60758 L .50781 .61986 L p
1 g
F P
s
P
p
.002 w
.50781 .61986 m .46325 .60897 L .48279 .5982 L p
1 g
F P
s
P
p
.002 w
.58926 .26627 m .52808 .25611 L .518 .24269 L p
1 g
F P
s
P
p
.002 w
.45296 .25412 m .518 .24269 L .52808 .25611 L p
1 g
F P
s
P
p
.002 w
.5949 .57504 m .62108 .5547 L .63207 .56321 L p
1 g
F P
s
P
p
.002 w
.63207 .56321 m .59896 .58895 L .5949 .57504 L p
1 g
F P
s
P
p
.002 w
.65668 .52958 m .63207 .56321 L .62108 .5547 L p
1 g
F P
s
P
p
.002 w
.68534 .43677 m .67142 .39374 L .67806 .37361 L p
1 g
F P
s
P
p
.002 w
.6463 .33407 m .67806 .37361 L .67142 .39374 L p
1 g
F P
s
P
p
.002 w
.67806 .37361 m .6463 .33407 L .64529 .31295 L p
1 g
F P
s
P
p
.002 w
.64529 .31295 m .59639 .28474 L .58926 .26627 L p
1 g
F P
s
P
p
.002 w
.52808 .25611 m .58926 .26627 L .59639 .28474 L p
1 g
F P
s
P
p
.002 w
.59639 .28474 m .64529 .31295 L .6463 .33407 L p
1 g
F P
s
P
p
.002 w
.56454 .5871 m .5949 .57504 L .59896 .58895 L p
1 g
F P
s
P
p
.002 w
.59896 .58895 m .56053 .60429 L .56454 .5871 L p
1 g
F P
s
P
p
.002 w
.35719 .34932 m .32862 .40933 L .31678 .39716 L p
1 g
F P
s
P
p
.002 w
.31678 .39716 m .34549 .33652 L .35719 .34932 L p
1 g
F P
s
P
p
.002 w
.67032 .49125 m .6714 .45193 L .68534 .43677 L p
1 g
F P
s
P
p
.002 w
.67142 .39374 m .68534 .43677 L .6714 .45193 L p
1 g
F P
s
P
p
.002 w
.62108 .5547 m .64049 .5281 L .65668 .52958 L p
1 g
F P
s
P
p
.002 w
.67032 .49125 m .65668 .52958 L .64049 .5281 L p
1 g
F P
s
P
p
.002 w
.53299 .58958 m .56454 .5871 L .56053 .60429 L p
1 g
F P
s
P
p
.002 w
.56053 .60429 m .52048 .60758 L .53299 .58958 L p
1 g
F P
s
P
p
.002 w
.34605 .42259 m .33904 .48293 L .32157 .47226 L p
1 g
F P
s
P
p
.002 w
.32157 .47226 m .32862 .40933 L .34605 .42259 L p
1 g
F P
s
P
p
.002 w
.40031 .54627 m .42596 .58374 L .40341 .58611 L p
1 g
F P
s
P
p
.002 w
.40341 .58611 m .37425 .54413 L .40031 .54627 L p
1 g
F P
s
P
p
.002 w
.36194 .49237 m .37425 .54413 L .35267 .53876 L p
1 g
F P
s
P
p
.002 w
.35267 .53876 m .33904 .48293 L .36194 .49237 L p
1 g
F P
s
P
p
.002 w
.52808 .25611 m .46371 .26759 L .45296 .25412 L p
1 g
F P
s
P
p
.002 w
.39287 .28669 m .45296 .25412 L .46371 .26759 L p
1 g
F P
s
P
p
.002 w
.45145 .57669 m .48279 .5982 L .46325 .60897 L p
1 g
F P
s
P
p
.002 w
.46325 .60897 m .42596 .58374 L .45145 .57669 L p
1 g
F P
s
P
p
.002 w
.40418 .29995 m .35719 .34932 L .34549 .33652 L p
1 g
F P
s
P
p
.002 w
.34549 .33652 m .39287 .28669 L .40418 .29995 L p
1 g
F P
s
P
p
.002 w
.64049 .5281 m .65116 .49786 L .67032 .49125 L p
1 g
F P
s
P
p
.002 w
.6714 .45193 m .67032 .49125 L .65116 .49786 L p
1 g
F P
s
P
p
.002 w
.46371 .26759 m .40418 .29995 L .39287 .28669 L p
1 g
F P
s
P
p
.002 w
.50347 .58204 m .53299 .58958 L .52048 .60758 L p
1 g
F P
s
P
p
.002 w
.52048 .60758 m .48279 .5982 L .50347 .58204 L p
1 g
F P
s
P
p
.002 w
.59639 .28474 m .53769 .27525 L .52808 .25611 L p
1 g
F P
s
P
p
.002 w
.46371 .26759 m .52808 .25611 L .53769 .27525 L p
1 g
F P
s
P
p
.002 w
.6714 .45193 m .65943 .41564 L .67142 .39374 L p
1 g
F P
s
P
p
.002 w
.64296 .35876 m .67142 .39374 L .65943 .41564 L p
1 g
F P
s
P
p
.002 w
.67142 .39374 m .64296 .35876 L .6463 .33407 L p
1 g
F P
s
P
p
.002 w
.60089 .30821 m .6463 .33407 L .64296 .35876 L p
1 g
F P
s
P
p
.002 w
.6463 .33407 m .60089 .30821 L .59639 .28474 L p
1 g
F P
s
P
p
.002 w
.53769 .27525 m .59639 .28474 L .60089 .30821 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.58783 .55625 m .60602 .54212 L .62108 .5547 L p
1 g
F P
s
P
p
.002 w
.62108 .5547 m .5949 .57504 L .58783 .55625 L p
1 g
F P
s
P
p
.002 w
.64049 .5281 m .62108 .5547 L .60602 .54212 L p
1 g
F P
s
P
p
.002 w
.56675 .56456 m .58783 .55625 L .5949 .57504 L p
1 g
F P
s
P
p
.002 w
.5949 .57504 m .56454 .5871 L .56675 .56456 L p
1 g
F P
s
P
p
.002 w
.65116 .49786 m .65186 .46697 L .6714 .45193 L p
1 g
F P
s
P
p
.002 w
.65943 .41564 m .6714 .45193 L .65186 .46697 L p
1 g
F P
s
P
p
.002 w
.37364 .36505 m .34605 .42259 L .32862 .40933 L p
1 g
F P
s
P
p
.002 w
.32862 .40933 m .35719 .34932 L .37364 .36505 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.60602 .54212 m .61947 .52364 L .64049 .5281 L p
1 g
F P
s
P
p
.002 w
.65116 .49786 m .64049 .5281 L .61947 .52364 L p
1 g
F P
s
P
p
.002 w
.43011 .54493 m .45145 .57669 L .42596 .58374 L p
1 g
F P
s
P
p
.002 w
.42596 .58374 m .40031 .54627 L .43011 .54493 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.38972 .50021 m .40031 .54627 L .37425 .54413 L p
1 g
F P
s
P
p
.002 w
.37425 .54413 m .36194 .49237 L .38972 .50021 L p
1 g
F P
s
P
p
.002 w
.56675 .56456 m .56454 .5871 L p
.54521 .56649 L 1 g
F P
s
P
p
.002 w
.54579 .56611 m .56675 .56456 L p
.54521 .56649 L 1 g
F P
s
P
p
.54854 .56129 m .5397 .56971 L .54664 .56545 L 1 g
F
P
p
.002 w
.5493 .56335 m .54854 .56129 L p
.54664 .56545 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.53299 .58958 m .52899 .57587 L .53165 .57434 L 1 g
F
P
p
.002 w
.54453 .56694 m .54246 .57101 L p
.53165 .57434 L 1 g
F P
s
P
p
.002 w
.54246 .57101 m .53299 .58958 L p
.53165 .57434 L 1 g
F P
s
P
p
.002 w
.53165 .57434 m .53128 .57265 L p
.52244 .57718 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53165 .57434 L p
1 g
F P
s
P
p
.002 w
.53165 .57434 m .5322 .57686 L p
.5397 .56971 L 1 g
F P
s
P
p
.54854 .56129 m .53165 .57434 L .5397 .56971 L 1 g
F
P
p
.002 w
.56675 .56456 m .54728 .566 L p
.56209 .55327 L 1 g
F P
s
P
p
.002 w
.54728 .566 m .54579 .56611 L p
.5493 .56335 L 1 g
F P
s
P
p
.54728 .566 m .5493 .56335 L .56209 .55327 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5493 .56335 L p
1 g
F P
s
P
p
.56075 .54566 m .5493 .56335 L .55542 .55532 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56159 .54723 m .56075 .54566 L p
.55542 .55532 L 1 g
F P
s
P
p
.002 w
.54492 .56618 m .55579 .53798 L p
.5603 .54892 L 1 g
F P
s
P
p
.56209 .55327 m .55013 .56226 L .5603 .54892 L 1 g
F
P
p
.55013 .56226 m .54492 .56618 L .5603 .54892 L 1 g
F
P
p
.5397 .56971 m .54453 .56694 L .54579 .56611 L 1 g
F
P
p
.54664 .56545 m .54579 .56611 L .54944 .56372 L 1 g
F
P
p
.5397 .56971 m .54579 .56611 L .54664 .56545 L 1 g
F
P
p
.002 w
.54579 .56611 m .54492 .56618 L p
.56209 .55327 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56699 .53722 m .56675 .56456 L p
.56065 .54977 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56159 .54723 L p
1 g
F P
s
P
p
.56654 .52734 m .56159 .54723 L .5642 .54017 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56524 .53734 m .56699 .53722 L p
.56065 .54977 L 1 g
F P
s
P
p
.002 w
.57784 .53298 m .56699 .53722 L .56668 .53199 L p
1 g
F P
s
P
p
.002 w
.57055 .51738 m .57784 .53298 L p
.56776 .53208 L 1 g
F P
s
P
p
.56776 .53208 m .56668 .53199 L .56753 .52878 L 1 g
F
P
p
.56776 .53208 m .56753 .52878 L .57055 .51738 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56753 .52878 L p
1 g
F P
s
P
p
.56515 .50826 m .56753 .52878 L .56691 .51969 L 1 g
F
P
p
.002 w
.56753 .52878 m .56654 .52734 L p
.56359 .54348 L 1 g
F P
s
P
p
.002 w
.56668 .53199 m .56699 .53722 L .56524 .53734 L p
1 g
F P
s
P
p
.56359 .54348 m .56348 .54411 L .56668 .53199 L 1 g
F
P
p
.56359 .54348 m .56668 .53199 L .56753 .52878 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56622 .50953 m .56515 .50826 L p
.56691 .51969 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56622 .50953 L p
1 g
F P
s
P
p
.002 w
.56516 .50588 m .56611 .5079 L p
.56614 .50937 L 1 g
F P
s
P
p
.002 w
.56525 .50743 m .56516 .50588 L p
.56614 .50937 L 1 g
F P
s
P
p
.002 w
.56611 .5079 m .57055 .51738 L p
.56753 .52878 L 1 g
F P
s
P
p
.55661 .4905 m .56622 .50953 L .56525 .50743 L 1 g
F
P
p
.55661 .4905 m .56525 .50743 L .56485 .50655 L 1 g
F
P
p
.55661 .4905 m .56485 .50655 L .56467 .50618 L 1 g
F
P
p
.002 w
.56464 .5061 m .56516 .50588 L .56471 .50625 L p
1 g
F P
s
P
p
.56463 .50608 m .56467 .50618 L .56464 .5061 L 1 g
F
P
p
.55661 .4905 m .56467 .50618 L .56463 .50608 L 1 g
F
P
p
.55661 .4905 m .56464 .5061 L .56459 .50599 L 1 g
F
P
p
.55661 .4905 m .5646 .50603 L .56425 .5053 L 1 g
F
P
p
.55661 .4905 m .56425 .5053 L .564 .50478 L 1 g
F
P
p
.55661 .4905 m .56402 .50482 L .56281 .50236 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.56335 .50347 m .56516 .50588 L .56425 .5053 L p
1 g
F P
s
P
p
.002 w
.55561 .47328 m .56516 .50588 L .56335 .50347 L p
1 g
F P
s
P
p
.002 w
.55008 .4764 m .55561 .47328 L p
.56118 .495 L 1 g
F P
s
P
p
.55741 .49135 m .56118 .495 L .56335 .50347 L 1 g
F
P
p
.55008 .4764 m .56118 .495 L .55741 .49135 L 1 g
F
P
p
.002 w
.55743 .49138 m .55661 .4905 L p
.55669 .49065 L 1 g
F P
s
P
p
.002 w
.56456 .50594 m .56516 .50588 L .56464 .5061 L p
1 g
F P
s
P
p
.002 w
.56446 .50572 m .56516 .50588 L .56456 .50594 L p
1 g
F P
s
P
p
.002 w
.56425 .5053 m .56516 .50588 L .56446 .50572 L p
1 g
F P
s
P
p
.002 w
.56471 .50625 m .56516 .50588 L .56479 .50643 L p
1 g
F P
s
P
p
.002 w
.56479 .50643 m .56516 .50588 L .56492 .50671 L p
1 g
F P
s
P
p
.002 w
.56492 .50671 m .56516 .50588 L .56525 .50743 L p
1 g
F P
s
P
p
.56753 .52878 m .56668 .53199 L .56614 .50937 L 1 g
F
P
p
.56622 .50953 m .56614 .50937 L .56611 .5079 L 1 g
F
P
p
.56753 .52878 m .56614 .50937 L .56622 .50953 L 1 g
F
P
p
.55669 .49065 m .56377 .5042 L .55743 .49138 L 1 g
F
P
p
.56377 .5042 m .56713 .51061 L .56251 .50145 L 1 g
F
P
p
.56377 .5042 m .56251 .50145 L .55743 .49138 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55743 .49138 L p
1 g
F P
s
P
p
.002 w
.56335 .50347 m .54584 .48016 L p
.55741 .49135 L 1 g
F P
s
P
p
.55089 .48504 m .55743 .49138 L .55096 .48511 L 1 g
F
P
p
.54174 .47608 m .55715 .4911 L .55089 .48504 L 1 g
F
P
p
.55715 .4911 m .55743 .49138 L .55089 .48504 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49135 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54512 .4792 m .55008 .4764 L p
.55741 .49135 L 1 g
F P
s
P
p
.54174 .47608 m .55741 .49135 L .55715 .4911 L 1 g
F
P
p
.002 w
.53672 .48791 m .54499 .47933 L p
.56335 .50347 L 1 g
F P
s
P
p
.002 w
.54584 .48016 m .56335 .50347 L p
.54499 .47933 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .55748 .4915 L p
.54174 .47608 L 1 g
F P
s
P
p
.002 w
.53672 .48791 m .50672 .46789 L p
.54474 .47908 L 1 g
F P
s
P
p
.002 w
.54499 .47933 m .53672 .48791 L p
.54474 .47908 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54174 .47608 L p
.55748 .4915 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.52337 .4506 m .54512 .4792 L p
.54474 .47908 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47684 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.52152 .46705 m .54244 .47684 L .54474 .47908 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .51302 .4659 L 1 g
F
P
p
.51219 .46221 m .52244 .46717 L .52152 .46705 L 1 g
F
P
p
.52244 .46717 m .54244 .47684 L .52152 .46705 L 1 g
F
P
p
.002 w
.50672 .46789 m .50914 .46538 L p
.54474 .47908 L 1 g
F P
s
P
p
.5 .4634 m .51302 .4659 L .50914 .46538 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.52337 .4506 m .50914 .46538 L p
.47634 .44658 L 1 g
F P
s
P
p
.002 w
.50914 .46538 m .50672 .46789 L .50139 .46415 L p
1 g
F P
s
P
p
.5 .4634 m .50914 .46538 L .50617 .46491 L 1 g
F
P
p
.002 w
.5 .46392 m .5 .4634 L p
.50682 .46507 L 1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50139 .46415 m .47634 .44658 L p
.50914 .46538 L 1 g
F P
s
P
p
.50617 .46491 m .50914 .46538 L .50682 .46507 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.50139 .46415 m .50672 .46789 L p
.49405 .46477 L 1 g
F P
s
P
p
.5 .46392 m .50139 .46415 L .49405 .46477 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.47443 .46866 m .49405 .46477 L .50672 .46789 L 1 g
F
P
p
.47759 .46711 m .49405 .46477 L .47443 .46866 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46711 L p
1 g
F P
s
P
p
.46232 .4746 m .47443 .46866 L .50672 .46789 L 1 g
F
P
p
.002 w
.47759 .46711 m .47718 .46778 L p
.46811 .47176 L 1 g
F P
s
P
p
.45826 .47608 m .47759 .46711 L .46811 .47176 L 1 g
F
P
p
.002 w
.46097 .4773 m .46232 .4746 L p
.50672 .46789 L 1 g
F P
s
P
p
.45826 .47608 m .46811 .47176 L .46232 .4746 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47634 .44658 m .46232 .4746 L p
.42718 .46441 L 1 g
F P
s
P
p
.002 w
.46232 .4746 m .46097 .4773 L .45856 .47639 L p
1 g
F P
s
P
p
.45826 .47608 m .46232 .4746 L .46002 .47569 L 1 g
F
P
p
.002 w
.45757 .47684 m .45826 .47608 L p
.46015 .47566 L 1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45757 .47684 L p
1 g
F P
s
P
p
.44339 .4905 m .45757 .47684 L .45648 .47789 L 1 g
F
P
p
.44515 .48885 m .45434 .47996 L .46097 .4773 L 1 g
F
P
p
.002 w
.45856 .47639 m .46097 .4773 L p
.45434 .47996 L 1 g
F P
s
P
p
.449 .48513 m .45753 .47687 L .45277 .48151 L 1 g
F
P
p
.44339 .4905 m .45648 .47789 L .449 .48513 L 1 g
F
P
p
.45648 .47789 m .45753 .47687 L .449 .48513 L 1 g
F
P
p
.4234 .49236 m .45757 .47684 L .45434 .47996 L 1 g
F
P
p
.45757 .47684 m .45856 .47639 L .45434 .47996 L 1 g
F
P
p
.002 w
.42154 .50608 m .4234 .49236 L p
.45434 .47996 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.44284 .49109 m .44134 .49413 L .42678 .50663 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44284 .49109 L p
1 g
F P
s
P
p
.002 w
.43481 .50747 m .42678 .50663 L p
.44134 .49413 L 1 g
F P
s
P
p
.002 w
.44284 .49109 m .44166 .49233 L p
.43778 .50142 L 1 g
F P
s
P
p
.43485 .50826 m .44284 .49109 L .43778 .50142 L 1 g
F
P
p
.43485 .50826 m .43778 .50142 L .43481 .50747 L 1 g
F
P
p
.002 w
.42605 .52655 m .42154 .50608 L .43409 .50739 L p
1 g
F P
s
P
p
.002 w
.43409 .50739 m .43481 .50747 L p
.43397 .50931 L 1 g
F P
s
P
p
.42605 .52655 m .43409 .50739 L .43397 .50931 L 1 g
F
P
p
.002 w
.43277 .52834 m .43346 .52734 L p
.43324 .52092 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43011 .54493 m .42605 .52655 L p
.43143 .52355 L 1 g
F P
s
P
p
.43011 .54493 m .43143 .52355 L .43541 .53781 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43277 .52834 L p
1 g
F P
s
P
p
.43925 .54566 m .43277 .52834 L .43539 .53773 L 1 g
F
P
p
.002 w
.43711 .54388 m .43011 .54493 L p
.43541 .53781 L 1 g
F P
s
P
p
.43925 .54566 m .43163 .53 L .4327 .53271 L 1 g
F
P
p
.002 w
.44806 .57165 m .43011 .54493 L .43586 .54407 L p
1 g
F P
s
P
p
.002 w
.43586 .54407 m .43711 .54388 L p
.43843 .54721 L 1 g
F P
s
P
p
.44806 .57165 m .43586 .54407 L .43843 .54721 L 1 g
F
P
p
.002 w
.45097 .56261 m .45146 .56129 L p
.4461 .55664 L 1 g
F P
s
P
p
.43925 .54566 m .43558 .5384 L .43711 .54388 L 1 g
F
P
p
.002 w
.43817 .54769 m .43843 .54721 L p
.43711 .54388 L 1 g
F P
s
P
p
.002 w
.43843 .54721 m .43925 .54566 L p
.43711 .54388 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.44806 .57165 m .44191 .55604 L .45193 .5633 L 1 g
F
P
p
.002 w
.45145 .57669 m .44806 .57165 L p
.45193 .5633 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45097 .56261 L p
1 g
F P
s
P
p
.46872 .57265 m .45097 .56261 L .46006 .56919 L 1 g
F
P
p
.4549 .56546 m .45193 .5633 L .4627 .54005 L 1 g
F
P
p
.45145 .57669 m .45193 .5633 L .4549 .56546 L 1 g
F
P
p
.46872 .57265 m .46006 .56919 L .46343 .57163 L 1 g
F
P
p
.48279 .5982 m .46458 .5732 L .48088 .58106 L 1 g
F
P
p
.46458 .5732 m .46343 .57163 L .46836 .5743 L 1 g
F
P
p
.46458 .5732 m .46836 .5743 L .48088 .58106 L 1 g
F
P
p
.002 w
.46836 .5743 m .46872 .57265 L p
.46343 .57163 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46836 .5743 L p
1 g
F P
s
P
p
.48921 .57862 m .46836 .5743 L .48104 .57795 L 1 g
F
P
p
.002 w
.46343 .57163 m .47911 .56501 L p
.48052 .5778 L 1 g
F P
s
P
p
.48088 .58106 m .46836 .5743 L .48052 .5778 L 1 g
F
P
p
.46836 .5743 m .46343 .57163 L .48052 .5778 L 1 g
F
P
p
.002 w
.48909 .58027 m .48921 .57862 L p
.48104 .57795 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50347 .58204 m .48279 .5982 L p
.48072 .57958 L 1 g
F P
s
P
p
.51079 .57862 m .49863 .58105 L .50251 .58137 L 1 g
F
P
p
.51079 .57862 m .50251 .58137 L .50349 .58136 L 1 g
F
P
p
.002 w
.51095 .58073 m .51079 .57862 L p
.50349 .58136 L 1 g
F P
s
P
p
.002 w
.50415 .58136 m .50347 .58204 L p
.50356 .58136 L 1 g
F P
s
P
p
.50349 .58136 m .5033 .58144 L .50415 .58136 L 1 g
F
P
p
.50349 .58136 m .50415 .58136 L .51095 .58073 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50251 .58137 m .50347 .58204 L p
.48072 .57958 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.47911 .56501 m .50798 .54896 L p
.50356 .58136 L 1 g
F P
s
P
p
.002 w
.50347 .58204 m .50251 .58137 L p
.50356 .58136 L 1 g
F P
s
P
p
.002 w
.50251 .58137 m .47911 .56501 L p
.50356 .58136 L 1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.50798 .54896 m .5246 .56083 L .50415 .58136 L p
1 g
F P
s
P
p
.50356 .58136 m .50798 .54896 L .50415 .58136 L 1 g
F
P
p
.50349 .58136 m .50251 .58137 L .5033 .58144 L 1 g
F
P
p
.002 w
.53299 .58958 m .50347 .58204 L .50415 .58136 L p
1 g
F P
s
P
p
.53299 .58958 m .50663 .58206 L .5299 .57899 L 1 g
F
P
p
.50663 .58206 m .50415 .58136 L .51095 .58073 L 1 g
F
P
p
.50663 .58206 m .51095 .58073 L .5299 .57899 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58073 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58073 L .52244 .57718 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.50415 .58136 m .5246 .56083 L p
.5299 .57899 L 1 g
F P
s
P
p
.002 w
.51095 .58073 m .51111 .583 L p
.52244 .57718 L 1 g
F P
s
P
p
.002 w
.51104 .58207 m .51095 .58073 L p
.5033 .58144 L 1 g
F P
s
P
p
.002 w
.47911 .56501 m .50251 .58137 L p
.48072 .57958 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51104 .58207 L p
1 g
F P
s
P
p
.49863 .58105 m .48889 .583 L .51104 .58207 L 1 g
F
P
p
.002 w
.46836 .5743 m .4678 .57686 L p
.48104 .57795 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58027 L p
1 g
F P
s
P
p
.48104 .57795 m .4678 .57686 L .48909 .58027 L 1 g
F
P
p
.002 w
.46819 .57508 m .46836 .5743 L p
.46343 .57163 L 1 g
F P
s
P
p
.002 w
.48279 .5982 m .45145 .57669 L .46343 .57163 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.4627 .54005 m .47911 .56501 L .45145 .57669 L p
1 g
F P
s
P
p
.002 w
.45097 .56261 m .45002 .56518 L p
.46006 .56919 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46819 .57508 L p
1 g
F P
s
P
p
.46006 .56919 m .45002 .56518 L .46819 .57508 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43843 .54721 L p
1 g
F P
s
P
p
.44191 .55604 m .43843 .54721 L .45097 .56261 L 1 g
F
P
p
.002 w
.43843 .54721 m .43743 .5491 L p
.4461 .55664 L 1 g
F P
s
P
p
.45146 .56129 m .43843 .54721 L .4461 .55664 L 1 g
F
P
p
.45097 .56261 m .43711 .54388 L .45193 .5633 L 1 g
F
P
p
.43843 .54721 m .43711 .54388 L .45097 .56261 L 1 g
F
P
p
.002 w
.43711 .54388 m .4627 .54005 L p
.45193 .5633 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45097 .56261 L p
1 g
F P
s
P
p
.4461 .55664 m .43743 .5491 L .45097 .56261 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45632 .50971 m .4627 .54005 L .43711 .54388 L p
1 g
F P
s
P
p
.43541 .53781 m .45632 .50971 L .43711 .54388 L 1 g
F
P
p
.002 w
.43277 .52834 m .43163 .53 L p
.43539 .53773 L 1 g
F P
s
P
p
.002 w
.43163 .53 m .43146 .53025 L p
.4327 .53271 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43397 .50931 L p
1 g
F P
s
P
p
.43346 .52734 m .43397 .50931 L .43324 .52092 L 1 g
F
P
p
.002 w
.43397 .50931 m .43485 .50826 L p
.43481 .50747 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43481 .50747 m .45632 .50971 L p
.42605 .52655 L 1 g
F P
s
P
p
.002 w
.43397 .50931 m .43287 .51061 L p
.43324 .52092 L 1 g
F P
s
P
p
.43541 .53781 m .43277 .52834 L .45632 .50971 L 1 g
F
P
p
.43277 .52834 m .43143 .52355 L .43313 .52261 L 1 g
F
P
p
.43277 .52834 m .43313 .52261 L .45632 .50971 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43817 .54769 L p
1 g
F P
s
P
p
.43558 .5384 m .43146 .53025 L .43817 .54769 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43277 .52834 L p
1 g
F P
s
P
p
.43324 .52092 m .43287 .51061 L .43277 .52834 L 1 g
F
P
p
.002 w
.43383 .50948 m .43397 .50931 L p
.43481 .50747 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.46097 .4773 m .45632 .50971 L .43481 .50747 L p
1 g
F P
s
P
p
.44134 .49413 m .46097 .4773 L .43481 .50747 L 1 g
F
P
p
.44515 .48885 m .46097 .4773 L .44134 .49413 L 1 g
F
P
p
.44515 .48885 m .44134 .49413 L .44284 .49109 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43383 .50948 L p
1 g
F P
s
P
p
.43778 .50142 m .44166 .49233 L .43383 .50948 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44284 .49109 L p
1 g
F P
s
P
p
.002 w
.44284 .49109 m .44339 .4905 L p
.449 .48513 L 1 g
F P
s
P
p
.449 .48513 m .45698 .47747 L .44284 .49109 L 1 g
F
P
p
.002 w
.42678 .50663 m .42154 .50608 L p
.44515 .48885 L 1 g
F P
s
P
p
.42154 .50608 m .45434 .47996 L .44515 .48885 L 1 g
F
P
p
.002 w
.45757 .47684 m .45753 .47687 L p
.45648 .47789 L 1 g
F P
s
P
p
.002 w
.45753 .47687 m .45698 .47747 L p
.45277 .48151 L 1 g
F P
s
P
p
.002 w
.45856 .47639 m .45818 .47624 L p
.46232 .4746 L 1 g
F P
s
P
p
.002 w
.45818 .47624 m .42718 .46441 L p
.46043 .47405 L 1 g
F P
s
P
p
.46043 .47405 m .46232 .4746 L .45818 .47624 L 1 g
F
P
p
.46002 .47569 m .46232 .4746 L .46015 .47566 L 1 g
F
P
p
.002 w
.45741 .477 m .45757 .47684 L p
.46015 .47566 L 1 g
F P
s
P
p
.002 w
.4234 .49236 m .42718 .46441 L .45856 .47639 L p
1 g
F P
s
P
p
.002 w
.46232 .4746 m .46518 .46888 L p
.47443 .46866 L 1 g
F P
s
P
p
.46518 .46888 m .47759 .46711 L .47443 .46866 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45741 .477 L p
1 g
F P
s
P
p
.46811 .47176 m .47718 .46778 L .45741 .477 L 1 g
F
P
p
.002 w
.5 .46392 m .5 .46442 L p
.48774 .46566 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46392 L .48774 .46566 L 1 g
F
P
p
.002 w
.47759 .46711 m .47786 .46667 L p
.48774 .46566 L 1 g
F P
s
P
p
.002 w
.46518 .46888 m .47018 .45888 L p
.49405 .46477 L 1 g
F P
s
P
p
.47018 .45888 m .5 .46392 L .49405 .46477 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46711 L p
1 g
F P
s
P
p
.48774 .46566 m .5 .46442 L .47759 .46711 L 1 g
F
P
p
.002 w
.5 .46415 m .5 .46392 L p
.50682 .46507 L 1 g
F P
s
P
p
.002 w
.47018 .45888 m .47634 .44658 L .50139 .46415 L p
1 g
F P
s
P
p
.002 w
.50914 .46538 m .51219 .46221 L p
.52152 .46705 L 1 g
F P
s
P
p
.50914 .46538 m .52152 .46705 L .54474 .47908 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46415 L p
1 g
F P
s
P
p
.51302 .4659 m .52282 .46778 L .5 .46415 L 1 g
F
P
p
.002 w
.52244 .46717 m .52282 .46778 L p
.51302 .4659 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54302 .47747 L p
.53259 .47208 L 1 g
F P
s
P
p
.52214 .46667 m .54244 .47684 L .53259 .47208 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.51219 .46221 m .51957 .45455 L p
.54244 .47684 L 1 g
F P
s
P
p
.002 w
.51957 .45455 m .52337 .4506 L p
.54474 .47908 L 1 g
F P
s
P
p
.002 w
.58721 .52571 m .57784 .53298 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.59412 .51618 m .58721 .52571 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.59782 .5054 m .59412 .51618 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.59791 .49448 m .59782 .5054 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.59435 .48461 m .59791 .49448 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.58749 .47685 m .59435 .48461 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.57803 .47207 m .58749 .47685 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.56701 .47082 m .57803 .47207 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.55561 .47328 m .56701 .47082 L .56516 .50588 L closepath p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55748 .4915 L p
.56007 .49417 L 1 g
F P
s
P
p
.002 w
.55748 .4915 m .55834 .49233 L .55838 .49238 L p
1 g
F P
s
P
p
.002 w
.55838 .49238 m .56007 .49417 L p
.55748 .4915 L 1 g
F P
s
P
p
.002 w
.55748 .4915 m .54302 .47747 L .54244 .47684 L p
1 g
F P
s
P
p
.002 w
.54512 .4792 m .54499 .47933 L p
.54474 .47908 L 1 g
F P
s
P
p
.002 w
.54584 .48016 m .54512 .4792 L p
.55741 .49135 L 1 g
F P
s
P
p
.002 w
.55741 .49135 m .55743 .49138 L p
.55715 .4911 L 1 g
F P
s
P
p
.002 w
.55743 .49138 m .55834 .49233 L p
.55096 .48511 L 1 g
F P
s
P
p
.002 w
.54499 .47933 m .54512 .4792 L .54584 .48016 L p
1 g
F P
s
P
p
.002 w
.56425 .5053 m .53672 .48791 L p
.56335 .50347 L 1 g
F P
s
P
p
.564 .50478 m .56425 .5053 L .56402 .50482 L 1 g
F
P
p
.56281 .50236 m .56402 .50482 L .56292 .50258 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53152 .52019 m .52954 .50961 L .56456 .50594 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.56464 .5061 m .53152 .52019 L p
.56456 .50594 L 1 g
F P
s
P
p
.002 w
.52954 .50961 m .53132 .49844 L .56446 .50572 L p
1 g
F P
s
P
p
.002 w
.56456 .50594 m .52954 .50961 L p
.56446 .50572 L 1 g
F P
s
P
p
.56459 .50599 m .56464 .5061 L .5646 .50603 L 1 g
F
P
p
.56292 .50258 m .5646 .50603 L .56354 .50375 L 1 g
F
P
p
.002 w
.53132 .49844 m .53672 .48791 L .56425 .5053 L p
1 g
F P
s
P
p
.002 w
.56446 .50572 m .53132 .49844 L p
.56425 .5053 L 1 g
F P
s
P
p
.002 w
.53703 .52902 m .53152 .52019 L .56464 .5061 L p
1 g
F P
s
P
p
.002 w
.56471 .50625 m .53703 .52902 L p
.56464 .5061 L 1 g
F P
s
P
p
.56354 .50375 m .56471 .50625 L .56372 .50411 L 1 g
F
P
p
.56471 .50625 m .56485 .50655 L .56479 .50643 L 1 g
F
P
p
.56471 .50625 m .56479 .50643 L .56372 .50411 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54543 .53516 m .53703 .52902 L .56471 .50625 L p
1 g
F P
s
P
p
.002 w
.56479 .50643 m .54543 .53516 L p
.56471 .50625 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55579 .53798 m .54543 .53516 L .56479 .50643 L p
1 g
F P
s
P
p
.002 w
.56492 .50671 m .55579 .53798 L p
.56479 .50643 L 1 g
F P
s
P
p
.56372 .50411 m .56492 .50671 L .56377 .5042 L 1 g
F
P
p
.56492 .50671 m .56525 .50743 L .56504 .50696 L 1 g
F
P
p
.56492 .50671 m .56504 .50696 L .56377 .5042 L 1 g
F
P
p
.002 w
.55579 .53798 m .56492 .50671 L p
.56668 .53199 L 1 g
F P
s
P
p
.002 w
.56525 .50743 m .56668 .53199 L p
.56492 .50671 L 1 g
F P
s
P
p
.002 w
.56622 .50953 m .56713 .51061 L p
.56377 .5042 L 1 g
F P
s
P
p
.002 w
.56668 .53199 m .56525 .50743 L p
.56614 .50937 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56622 .50953 L p
1 g
F P
s
P
p
.56691 .51969 m .56854 .53025 L .56622 .50953 L 1 g
F
P
p
.002 w
.56524 .53734 m .55579 .53798 L p
.56668 .53199 L 1 g
F P
s
P
p
.002 w
.56753 .52878 m .56854 .53025 L p
.56691 .51969 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56753 .52878 L p
1 g
F P
s
P
p
.56348 .54411 m .56257 .5491 L .56753 .52878 L 1 g
F
P
p
.002 w
.55579 .53798 m .56524 .53734 L p
.56065 .54977 L 1 g
F P
s
P
p
.002 w
.56159 .54723 m .56257 .5491 L p
.5642 .54017 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56159 .54723 L p
1 g
F P
s
P
p
.55542 .55532 m .54998 .56518 L .56159 .54723 L 1 g
F
P
p
.002 w
.5493 .56335 m .54998 .56518 L p
.55542 .55532 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.52899 .57587 m .5246 .56083 L .54453 .56694 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53165 .57434 L p
1 g
F P
s
P
p
.52244 .57718 m .51111 .583 L .53165 .57434 L 1 g
F
P
p
.002 w
.54944 .56372 m .5493 .56335 L p
.54664 .56545 L 1 g
F P
s
P
p
.5397 .56971 m .53839 .57096 L .54453 .56694 L 1 g
F
P
p
.002 w
.5246 .56083 m .54492 .56618 L .54453 .56694 L p
1 g
F P
s
P
p
.002 w
.56454 .5871 m .53299 .58958 L .54492 .56618 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54944 .56372 L p
1 g
F P
s
P
p
.53839 .57096 m .5322 .57686 L .54944 .56372 L 1 g
F
P
p
.002 w
.54492 .56618 m .54579 .56611 L p
.54521 .56649 L 1 g
F P
s
P
p
.002 w
.36873 .43652 m .36194 .49237 L .33904 .48293 L p
1 g
F P
s
P
p
.002 w
.33904 .48293 m .34605 .42259 L .36873 .43652 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.53769 .27525 m .47594 .28649 L .46371 .26759 L p
1 g
F P
s
P
p
.002 w
.40418 .29995 m .46371 .26759 L .47594 .28649 L p
1 g
F P
s
P
p
.002 w
.61947 .52364 m .62679 .50266 L .65116 .49786 L p
1 g
F P
s
P
p
.002 w
.65186 .46697 m .65116 .49786 L .62679 .50266 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51689 .45004 L
s
P
p
.002 w
.41882 .31765 m .37364 .36505 L .35719 .34932 L p
1 g
F P
s
P
p
.002 w
.35719 .34932 m .40418 .29995 L .41882 .31765 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.47594 .28649 m .41882 .31765 L .40418 .29995 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.65186 .46697 m .64227 .43863 L .65943 .41564 L p
1 g
F P
s
P
p
.002 w
.6352 .38635 m .65943 .41564 L .64227 .43863 L p
1 g
F P
s
P
p
.002 w
.65943 .41564 m .6352 .38635 L .64296 .35876 L p
1 g
F P
s
P
p
.002 w
.60246 .3361 m .64296 .35876 L .6352 .38635 L p
1 g
F P
s
P
p
.002 w
.64296 .35876 m .60246 .3361 L .60089 .30821 L p
1 g
F P
s
P
p
.002 w
.60089 .30821 m .54648 .29974 L .53769 .27525 L p
1 g
F P
s
P
p
.002 w
.47594 .28649 m .53769 .27525 L .54648 .29974 L p
1 g
F P
s
P
p
.002 w
.54648 .29974 m .60089 .30821 L .60246 .3361 L p
1 g
F P
s
P
p
.002 w
.62679 .50266 m .62713 .48134 L .65186 .46697 L p
1 g
F P
s
P
p
.002 w
.64227 .43863 m .65186 .46697 L .62713 .48134 L p
1 g
F P
s
P
p
.002 w
.39448 .38328 m .36873 .43652 L .34605 .42259 L p
1 g
F P
s
P
p
.002 w
.34605 .42259 m .37364 .36505 L .39448 .38328 L p
1 g
F P
s
P
p
.002 w
.57784 .53298 m .58721 .52571 L .60602 .54212 L p
1 g
F P
s
P
p
.002 w
.60602 .54212 m .58783 .55625 L .57784 .53298 L p
1 g
F P
s
P
p
.002 w
.61947 .52364 m .60602 .54212 L .58721 .52571 L p
1 g
F P
s
P
p
.002 w
.56699 .53722 m .57784 .53298 L .58783 .55625 L p
1 g
F P
s
P
p
.002 w
.58783 .55625 m .56675 .56456 L .56699 .53722 L p
1 g
F P
s
P
p
.002 w
.42154 .50608 m .43011 .54493 L .40031 .54627 L p
1 g
F P
s
P
p
.002 w
.40031 .54627 m .38972 .50021 L .42154 .50608 L p
1 g
F P
s
P
p
.002 w
.58721 .52571 m .59412 .51618 L .61947 .52364 L p
1 g
F P
s
P
p
.002 w
.62679 .50266 m .61947 .52364 L .59412 .51618 L p
1 g
F P
s
P
p
.002 w
.39607 .45064 m .38972 .50021 L .36194 .49237 L p
1 g
F P
s
P
p
.002 w
.36194 .49237 m .36873 .43652 L .39607 .45064 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.54648 .29974 m .4893 .31039 L .47594 .28649 L p
1 g
F P
s
P
p
.002 w
.41882 .31765 m .47594 .28649 L .4893 .31039 L p
1 g
F P
s
P
p
.004 w
.43513 .27663 m
.44025 .28876 L
s
P
p
.002 w
.59412 .51618 m .59782 .5054 L .62679 .50266 L p
1 g
F P
s
P
p
.002 w
.62713 .48134 m .62679 .50266 L .59782 .5054 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.54543 .53516 m .55579 .53798 L .54492 .56618 L p
1 g
F P
s
P
p
.002 w
.54492 .56618 m .5246 .56083 L .54543 .53516 L p
1 g
F P
s
P
p
.002 w
.62713 .48134 m .62035 .4619 L .64227 .43863 L p
1 g
F P
s
P
p
.002 w
.62312 .41594 m .64227 .43863 L .62035 .4619 L p
1 g
F P
s
P
p
.002 w
.64227 .43863 m .62312 .41594 L .6352 .38635 L p
1 g
F P
s
P
p
.002 w
.4364 .33938 m .39448 .38328 L .37364 .36505 L p
1 g
F P
s
P
p
.002 w
.37364 .36505 m .41882 .31765 L .4364 .33938 L p
1 g
F P
s
P
p
.002 w
.60093 .36757 m .6352 .38635 L .62312 .41594 L p
1 g
F P
s
P
p
.002 w
.6352 .38635 m .60093 .36757 L .60246 .3361 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.55408 .32891 m .60246 .3361 L .60093 .36757 L p
1 g
F P
s
P
p
.002 w
.60246 .3361 m .55408 .32891 L .54648 .29974 L p
1 g
F P
s
P
p
.002 w
.4893 .31039 m .4364 .33938 L .41882 .31765 L p
1 g
F P
s
P
p
.002 w
.4893 .31039 m .54648 .29974 L .55408 .32891 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59782 .5054 m .59791 .49448 L .62713 .48134 L p
1 g
F P
s
P
p
.002 w
.62035 .4619 m .62713 .48134 L .59791 .49448 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49693 .53172 m .50798 .54896 L .47911 .56501 L p
1 g
F P
s
P
p
.002 w
.47911 .56501 m .4627 .54005 L .49693 .53172 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.53703 .52902 m .54543 .53516 L .5246 .56083 L p
1 g
F P
s
P
p
.002 w
.5246 .56083 m .50798 .54896 L .53703 .52902 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.41913 .40344 m .39607 .45064 L .36873 .43652 L p
1 g
F P
s
P
p
.002 w
.36873 .43652 m .39448 .38328 L .41913 .40344 L p
1 g
F P
s
P
p
.002 w
.42718 .46441 m .42154 .50608 L .38972 .50021 L p
1 g
F P
s
P
p
.002 w
.38972 .50021 m .39607 .45064 L .42718 .46441 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59791 .49448 m .59435 .48461 L .62035 .4619 L p
1 g
F P
s
P
p
.002 w
.60704 .44648 m .62035 .4619 L .59435 .48461 L p
1 g
F P
s
P
p
.002 w
.62035 .4619 m .60704 .44648 L .62312 .41594 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59625 .40157 m .62312 .41594 L .60704 .44648 L p
1 g
F P
s
P
p
.002 w
.62312 .41594 m .59625 .40157 L .60093 .36757 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55408 .32891 m .50334 .33863 L .4893 .31039 L p
1 g
F P
s
P
p
.002 w
.4364 .33938 m .4893 .31039 L .50334 .33863 L p
1 g
F P
s
P
p
.004 w
.45976 .33506 m
.46009 .33584 L
s
P
p
.004 w
.46146 .3391 m
.5 .43051 L
s
P
p
.004 w
.4549 .32352 m
.45976 .33506 L
s
P
p
.004 w
.44025 .28876 m
.4549 .32352 L
s
P
p
.002 w
.56017 .36185 m .60093 .36757 L .59625 .40157 L p
1 g
F P
s
P
p
.002 w
.60093 .36757 m .56017 .36185 L .55408 .32891 L p
1 g
F P
s
P
p
.002 w
.53152 .52019 m .53703 .52902 L .50798 .54896 L p
1 g
F P
s
P
p
.002 w
.50798 .54896 m .49693 .53172 L .53152 .52019 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.49279 .51091 m .49693 .53172 L .4627 .54005 L p
1 g
F P
s
P
p
.002 w
.4627 .54005 m .45632 .50971 L .49279 .51091 L p
1 g
F P
s
P
p
.002 w
.45641 .36448 m .41913 .40344 L .39448 .38328 L p
1 g
F P
s
P
p
.002 w
.39448 .38328 m .4364 .33938 L .45641 .36448 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.50334 .33863 m .55408 .32891 L .56017 .36185 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.50334 .33863 m .45641 .36448 L .4364 .33938 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.59435 .48461 m .58749 .47685 L .60704 .44648 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.58853 .43684 m .60704 .44648 L .58749 .47685 L p
1 g
F P
s
P
p
.002 w
.60704 .44648 m .58853 .43684 L .59625 .40157 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44676 .42481 m .42718 .46441 L .39607 .45064 L p
1 g
F P
s
P
p
.002 w
.39607 .45064 m .41913 .40344 L .44676 .42481 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.52954 .50961 m .53152 .52019 L .49693 .53172 L p
1 g
F P
s
P
p
.002 w
.49693 .53172 m .49279 .51091 L .52954 .50961 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.56446 .39739 m .59625 .40157 L .58853 .43684 L p
1 g
F P
s
P
p
.002 w
.59625 .40157 m .56446 .39739 L .56017 .36185 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.58749 .47685 m .57803 .47207 L .58853 .43684 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.56017 .36185 m .51753 .37026 L .50334 .33863 L p
1 g
F P
s
P
p
.002 w
.45641 .36448 m .50334 .33863 L .51753 .37026 L p
1 g
F P
s
P
p
.002 w
.51753 .37026 m .56017 .36185 L .56446 .39739 L p
1 g
F P
s
P
p
.002 w
.49614 .4888 m .49279 .51091 L .45632 .50971 L p
1 g
F P
s
P
p
.002 w
.45632 .50971 m .46097 .4773 L .49614 .4888 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56677 .43419 m .58853 .43684 L .57803 .47207 L p
1 g
F P
s
P
p
.002 w
.58853 .43684 m .56677 .43419 L .56446 .39739 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.57803 .47207 m .56701 .47082 L .56677 .43419 L p
1 g
F P
s
P
p
.002 w
.47813 .39209 m .44676 .42481 L .41913 .40344 L p
1 g
F P
s
P
p
.002 w
.41913 .40344 m .45641 .36448 L .47813 .39209 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.53132 .49844 m .52954 .50961 L .49279 .51091 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49279 .51091 m .49614 .4888 L .53132 .49844 L p
1 g
F P
s
P
p
.002 w
.42718 .46441 m .44676 .42481 L .47634 .44658 L p
1 g
F P
s
P
p
.002 w
.51753 .37026 m .47813 .39209 L .45641 .36448 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56701 .47082 m .55561 .47328 L .54419 .43893 L p
1 g
F P
s
P
p
.002 w
.54419 .43893 m .56677 .43419 L .56701 .47082 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.004 w
.56769 .5088 m
.56829 .5095 L
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.53672 .48791 m .53132 .49844 L .49614 .4888 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.53133 .40413 m .56446 .39739 L .56677 .43419 L p
1 g
F P
s
P
p
.002 w
.56446 .39739 m .53133 .40413 L .51753 .37026 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55561 .47328 m .54512 .4792 L .52337 .4506 L p
1 g
F P
s
P
p
.002 w
.52337 .4506 m .54419 .43893 L .55561 .47328 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49614 .4888 m .50672 .46789 L .53672 .48791 L p
1 g
F P
s
P
p
.002 w
.56677 .43419 m .54419 .43893 L .53133 .40413 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.47813 .39209 m .51753 .37026 L .53133 .40413 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.50672 .46789 m .49614 .4888 L .46097 .4773 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.004 w
.56963 .51104 m
.57023 .51174 L
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.004 w
.57158 .5133 m
.57176 .5135 L
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50075 .42118 m .47634 .44658 L .44676 .42481 L p
1 g
F P
s
P
p
.002 w
.44676 .42481 m .47813 .39209 L .50075 .42118 L p
1 g
F P
s
P
p
.002 w
.54419 .43893 m .52337 .4506 L .50075 .42118 L p
1 g
F P
s
P
p
.002 w
.50075 .42118 m .53133 .40413 L .54419 .43893 L p
1 g
F P
s
P
p
.002 w
.53133 .40413 m .50075 .42118 L .47813 .39209 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.004 w
.57176 .5135 m
.57219 .514 L
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47634 .44658 m .50075 .42118 L .52337 .4506 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.004 w
.57354 .51557 m
.57415 .51628 L
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.004 w
.57552 .51786 m
.57614 .51857 L
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.004 w
.57751 .52016 m
.57813 .52088 L
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.004 w
.57952 .52248 m
.58014 .5232 L
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.58154 .52482 m
.58217 .52554 L
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.004 w
.58357 .52717 m
.58421 .5279 L
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.58626 .53028 m
.60472 .55162 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .43513 .27663 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60472 .55162 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0651163)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0651163)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49428 .47479 m .531 .45438 L .51416 .43151 L p
1 g
F P
s
P
p
.002 w
.51416 .43151 m .48358 .44848 L .49428 .47479 L p
1 g
F P
s
P
p
.002 w
.53889 .40714 m .51416 .43151 L .531 .45438 L p
1 g
F P
s
P
p
.002 w
.48358 .44848 m .51416 .43151 L .49702 .40865 L p
1 g
F P
s
P
p
.002 w
.51416 .43151 m .53889 .40714 L .51613 .38971 L p
1 g
F P
s
P
p
.002 w
.51613 .38971 m .49702 .40865 L .51416 .43151 L p
1 g
F P
s
P
p
.002 w
.49702 .40865 m .4733 .42179 L .48358 .44848 L p
1 g
F P
s
P
p
.002 w
.4733 .42179 m .49702 .40865 L .47988 .38623 L p
1 g
F P
s
P
p
.002 w
.49702 .40865 m .51613 .38971 L .49291 .37323 L p
1 g
F P
s
P
p
.002 w
.49291 .37323 m .47988 .38623 L .49702 .40865 L p
1 g
F P
s
P
p
.002 w
.45403 .48448 m .49428 .47479 L .48358 .44848 L p
1 g
F P
s
P
p
.002 w
.48358 .44848 m .45005 .4564 L .45403 .48448 L p
1 g
F P
s
P
p
.002 w
.45005 .4564 m .48358 .44848 L .4733 .42179 L p
1 g
F P
s
P
p
.002 w
.4733 .42179 m .4473 .42783 L .45005 .4564 L p
1 g
F P
s
P
p
.002 w
.4473 .42783 m .4733 .42179 L .46363 .39521 L p
1 g
F P
s
P
p
.002 w
.47988 .38623 m .46363 .39521 L .4733 .42179 L p
1 g
F P
s
P
p
.002 w
.50521 .50025 m .54722 .47687 L .531 .45438 L p
1 g
F P
s
P
p
.002 w
.531 .45438 m .49428 .47479 L .50521 .50025 L p
1 g
F P
s
P
p
.002 w
.56079 .4252 m .531 .45438 L .54722 .47687 L p
1 g
F P
s
P
p
.002 w
.531 .45438 m .56079 .4252 L .53889 .40714 L p
1 g
F P
s
P
p
.002 w
.52869 .3668 m .51613 .38971 L .53889 .40714 L p
1 g
F P
s
P
p
.002 w
.51613 .38971 m .52869 .3668 L .5014 .35751 L p
1 g
F P
s
P
p
.002 w
.5014 .35751 m .49291 .37323 L .51613 .38971 L p
1 g
F P
s
P
p
.002 w
.45918 .51154 m .50521 .50025 L .49428 .47479 L p
1 g
F P
s
P
p
.002 w
.49428 .47479 m .45403 .48448 L .45918 .51154 L p
1 g
F P
s
P
p
.002 w
.55531 .37765 m .53889 .40714 L .56079 .4252 L p
1 g
F P
s
P
p
.002 w
.53889 .40714 m .55531 .37765 L .52869 .3668 L p
1 g
F P
s
P
p
.002 w
.46363 .39521 m .47988 .38623 L .46304 .36465 L p
1 g
F P
s
P
p
.002 w
.47988 .38623 m .49291 .37323 L .46967 .358 L p
1 g
F P
s
P
p
.002 w
.46967 .358 m .46304 .36465 L .47988 .38623 L p
1 g
F P
s
P
p
.002 w
.46363 .39521 m .44582 .39927 L .4473 .42783 L p
1 g
F P
s
P
p
.002 w
.44582 .39927 m .46363 .39521 L .45475 .36923 L p
1 g
F P
s
P
p
.002 w
.46304 .36465 m .45475 .36923 L .46363 .39521 L p
1 g
F P
s
P
p
.002 w
.4168 .45439 m .45005 .4564 L .4473 .42783 L p
1 g
F P
s
P
p
.002 w
.4473 .42783 m .42159 .42607 L .4168 .45439 L p
1 g
F P
s
P
p
.002 w
.42159 .42607 m .4473 .42783 L .44582 .39927 L p
1 g
F P
s
P
p
.002 w
.41402 .48236 m .45403 .48448 L .45005 .4564 L p
1 g
F P
s
P
p
.002 w
.45005 .4564 m .4168 .45439 L .41402 .48236 L p
1 g
F P
s
P
p
.002 w
.49291 .37323 m .5014 .35751 L .47394 .34997 L p
1 g
F P
s
P
p
.002 w
.47394 .34997 m .46967 .358 L .49291 .37323 L p
1 g
F P
s
P
p
.002 w
.54722 .47687 m .58142 .44357 L .56079 .4252 L p
1 g
F P
s
P
p
.002 w
.58076 .38987 m .56079 .4252 L .58142 .44357 L p
1 g
F P
s
P
p
.002 w
.56079 .4252 m .58076 .38987 L .55531 .37765 L p
1 g
F P
s
P
p
.002 w
.44582 .39927 m .42827 .39793 L .42159 .42607 L p
1 g
F P
s
P
p
.002 w
.42827 .39793 m .44582 .39927 L .44566 .37126 L p
1 g
F P
s
P
p
.002 w
.45475 .36923 m .44566 .37126 L .44582 .39927 L p
1 g
F P
s
P
p
.002 w
.51618 .52438 m .56253 .49855 L .54722 .47687 L p
1 g
F P
s
P
p
.002 w
.54722 .47687 m .50521 .50025 L .51618 .52438 L p
1 g
F P
s
P
p
.002 w
.58142 .44357 m .54722 .47687 L .56253 .49855 L p
1 g
F P
s
P
p
.002 w
.53332 .34217 m .52869 .3668 L .55531 .37765 L p
1 g
F P
s
P
p
.002 w
.52869 .3668 m .53332 .34217 L .50439 .34069 L p
1 g
F P
s
P
p
.002 w
.50439 .34069 m .5014 .35751 L .52869 .3668 L p
1 g
F P
s
P
p
.002 w
.46542 .53703 m .51618 .52438 L .50521 .50025 L p
1 g
F P
s
P
p
.002 w
.50521 .50025 m .45918 .51154 L .46542 .53703 L p
1 g
F P
s
P
p
.002 w
.41334 .50944 m .45918 .51154 L .45403 .48448 L p
1 g
F P
s
P
p
.002 w
.45403 .48448 m .41402 .48236 L .41334 .50944 L p
1 g
F P
s
P
p
.002 w
.5014 .35751 m .50439 .34069 L .47538 .34141 L p
1 g
F P
s
P
p
.002 w
.47538 .34141 m .47394 .34997 L .5014 .35751 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .45475 .36923 L .46304 .36465 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .46304 .36465 L .46967 .358 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .44566 .37126 L .45475 .36923 L closepath p
1 g
F P
s
P
p
.002 w
.5616 .34584 m .55531 .37765 L .58076 .38987 L p
1 g
F P
s
P
p
.002 w
.55531 .37765 m .5616 .34584 L .53332 .34217 L p
1 g
F P
s
P
p
.002 w
.38716 .44237 m .4168 .45439 L .42159 .42607 L p
1 g
F P
s
P
p
.002 w
.42159 .42607 m .39879 .41654 L .38716 .44237 L p
1 g
F P
s
P
p
.002 w
.39879 .41654 m .42159 .42607 L .42827 .39793 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .46967 .358 L .47394 .34997 L closepath p
1 g
F P
s
P
p
.002 w
.42827 .39793 m .41281 .39128 L .39879 .41654 L p
1 g
F P
s
P
p
.002 w
.41281 .39128 m .42827 .39793 L .43674 .37051 L p
1 g
F P
s
P
p
.002 w
.44566 .37126 m .43674 .37051 L .42827 .39793 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .43674 .37051 L .44566 .37126 L closepath p
1 g
F P
s
P
p
.002 w
.56253 .49855 m .60037 .4619 L .58142 .44357 L p
1 g
F P
s
P
p
.002 w
.60454 .40325 m .58142 .44357 L .60037 .4619 L p
1 g
F P
s
P
p
.002 w
.58142 .44357 m .60454 .40325 L .58076 .38987 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .47394 .34997 L .47538 .34141 L closepath p
1 g
F P
s
P
p
.002 w
.37818 .46825 m .41402 .48236 L .4168 .45439 L p
1 g
F P
s
P
p
.002 w
.4168 .45439 m .38716 .44237 L .37818 .46825 L p
1 g
F P
s
P
p
.002 w
.43674 .37051 m .42893 .36705 L .41281 .39128 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .42893 .36705 L .43674 .37051 L closepath p
1 g
F P
s
P
p
.002 w
.50148 .32449 m .50439 .34069 L .53332 .34217 L p
1 g
F P
s
P
p
.002 w
.50439 .34069 m .50148 .32449 L .47381 .33322 L p
1 g
F P
s
P
p
.002 w
.47381 .33322 m .47538 .34141 L .50439 .34069 L p
1 g
F P
s
P
p
.002 w
.58869 .35166 m .58076 .38987 L .60454 .40325 L p
1 g
F P
s
P
p
.002 w
.58076 .38987 m .58869 .35166 L .5616 .34584 L p
1 g
F P
s
P
p
.002 w
.41481 .53506 m .46542 .53703 L .45918 .51154 L p
1 g
F P
s
P
p
.002 w
.45918 .51154 m .41334 .50944 L .41481 .53506 L p
1 g
F P
s
P
p
.002 w
.52697 .54667 m .57659 .51899 L .56253 .49855 L p
1 g
F P
s
P
p
.002 w
.56253 .49855 m .51618 .52438 L .52697 .54667 L p
1 g
F P
s
P
p
.002 w
.60037 .4619 m .56253 .49855 L .57659 .51899 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .47538 .34141 L .47381 .33322 L closepath p
1 g
F P
s
P
p
.002 w
.52933 .31833 m .53332 .34217 L .5616 .34584 L p
1 g
F P
s
P
p
.002 w
.53332 .34217 m .52933 .31833 L .50148 .32449 L p
1 g
F P
s
P
p
.002 w
.47267 .56042 m .52697 .54667 L .51618 .52438 L p
1 g
F P
s
P
p
.002 w
.51618 .52438 m .46542 .53703 L .47267 .56042 L p
1 g
F P
s
P
p
.002 w
.4011 .3799 m .41281 .39128 L .42893 .36705 L p
1 g
F P
s
P
p
.002 w
.42893 .36705 m .42307 .36122 L .4011 .3799 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .42307 .36122 L .42893 .36705 L closepath p
1 g
F P
s
P
p
.002 w
.38137 .40004 m .39879 .41654 L .41281 .39128 L p
1 g
F P
s
P
p
.002 w
.41281 .39128 m .4011 .3799 L .38137 .40004 L p
1 g
F P
s
P
p
.002 w
.37212 .49366 m .41334 .50944 L .41402 .48236 L p
1 g
F P
s
P
p
.002 w
.41402 .48236 m .37818 .46825 L .37212 .49366 L p
1 g
F P
s
P
p
.002 w
.46937 .3263 m .47381 .33322 L .50148 .32449 L p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .47381 .33322 L .46937 .3263 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .41983 .35362 L .42307 .36122 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .43567 .32305 L .42795 .32889 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .42795 .32889 L .42238 .33651 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .42238 .33651 L .41958 .34508 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .41958 .34508 L .41983 .35362 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .46937 .3263 L .46251 .32141 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .46251 .32141 L .45397 .3191 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .45397 .3191 L .44468 .31967 L closepath p
1 g
F P
s
P
p
.002 w
.44683 .34433 m .44468 .31967 L .43567 .32305 L closepath p
1 g
F P
s
P
p
.002 w
.36432 .42123 m .38716 .44237 L .39879 .41654 L p
1 g
F P
s
P
p
.002 w
.39879 .41654 m .38137 .40004 L .36432 .42123 L p
1 g
F P
s
P
p
.002 w
.39449 .36495 m .4011 .3799 L .42307 .36122 L p
1 g
F P
s
P
p
.002 w
.42307 .36122 m .41983 .35362 L .39449 .36495 L p
1 g
F P
s
P
p
.002 w
.5568 .31489 m .5616 .34584 L .58869 .35166 L p
1 g
F P
s
P
p
.002 w
.5616 .34584 m .5568 .31489 L .52933 .31833 L p
1 g
F P
s
P
p
.002 w
.57659 .51899 m .61721 .47984 L .60037 .4619 L p
1 g
F P
s
P
p
.002 w
.62614 .41756 m .60037 .4619 L .61721 .47984 L p
1 g
F P
s
P
p
.002 w
.60037 .4619 m .62614 .41756 L .60454 .40325 L p
1 g
F P
s
P
p
.002 w
.49287 .31069 m .50148 .32449 L .52933 .31833 L p
1 g
F P
s
P
p
.002 w
.50148 .32449 m .49287 .31069 L .46937 .3263 L p
1 g
F P
s
P
p
.002 w
.61402 .35955 m .60454 .40325 L .62614 .41756 L p
1 g
F P
s
P
p
.002 w
.60454 .40325 m .61402 .35955 L .58869 .35166 L p
1 g
F P
s
P
p
.002 w
.46251 .32141 m .46937 .3263 L .49287 .31069 L p
1 g
F P
s
P
p
.002 w
.39383 .34798 m .39449 .36495 L .41983 .35362 L p
1 g
F P
s
P
p
.002 w
.41983 .35362 m .41958 .34508 L .39383 .34798 L p
1 g
F P
s
P
p
.002 w
.37138 .37811 m .38137 .40004 L .4011 .3799 L p
1 g
F P
s
P
p
.002 w
.4011 .3799 m .39449 .36495 L .37138 .37811 L p
1 g
F P
s
P
p
.002 w
.41849 .55865 m .47267 .56042 L .46542 .53703 L p
1 g
F P
s
P
p
.002 w
.46542 .53703 m .41481 .53506 L .41849 .55865 L p
1 g
F P
s
P
p
.002 w
.35038 .44309 m .37818 .46825 L .38716 .44237 L p
1 g
F P
s
P
p
.002 w
.38716 .44237 m .36432 .42123 L .35038 .44309 L p
1 g
F P
s
P
p
.002 w
.49287 .31069 m .47938 .30084 L .46251 .32141 L p
1 g
F P
s
P
p
.002 w
.45397 .3191 m .46251 .32141 L .47938 .30084 L p
1 g
F P
s
P
p
.002 w
.51691 .29786 m .52933 .31833 L .5568 .31489 L p
1 g
F P
s
P
p
.002 w
.52933 .31833 m .51691 .29786 L .49287 .31069 L p
1 g
F P
s
P
p
.002 w
.53736 .56662 m .58909 .53773 L .57659 .51899 L p
1 g
F P
s
P
p
.002 w
.57659 .51899 m .52697 .54667 L .53736 .56662 L p
1 g
F P
s
P
p
.002 w
.61721 .47984 m .57659 .51899 L .58909 .53773 L p
1 g
F P
s
P
p
.002 w
.36918 .51806 m .41481 .53506 L .41334 .50944 L p
1 g
F P
s
P
p
.002 w
.41334 .50944 m .37212 .49366 L .36918 .51806 L p
1 g
F P
s
P
p
.002 w
.3993 .33088 m .39383 .34798 L .41958 .34508 L p
1 g
F P
s
P
p
.002 w
.41958 .34508 m .42238 .33651 L .3993 .33088 L p
1 g
F P
s
P
p
.002 w
.58332 .31431 m .58869 .35166 L .61402 .35955 L p
1 g
F P
s
P
p
.002 w
.58869 .35166 m .58332 .31431 L .5568 .31489 L p
1 g
F P
s
P
p
.002 w
.48081 .58114 m .53736 .56662 L .52697 .54667 L p
1 g
F P
s
P
p
.002 w
.52697 .54667 m .47267 .56042 L .48081 .58114 L p
1 g
F P
s
P
p
.002 w
.47938 .30084 m .49287 .31069 L .51691 .29786 L p
1 g
F P
s
P
p
.002 w
.47938 .30084 m .46242 .29612 L .45397 .3191 L p
1 g
F P
s
P
p
.002 w
.44468 .31967 m .45397 .3191 L .46242 .29612 L p
1 g
F P
s
P
p
.002 w
.41037 .31559 m .3993 .33088 L .42238 .33651 L p
1 g
F P
s
P
p
.002 w
.42238 .33651 m .42795 .32889 L .41037 .31559 L p
1 g
F P
s
P
p
.002 w
.35104 .3929 m .36432 .42123 L .38137 .40004 L p
1 g
F P
s
P
p
.002 w
.38137 .40004 m .37138 .37811 L .35104 .3929 L p
1 g
F P
s
P
p
.002 w
.46242 .29612 m .44386 .29716 L .44468 .31967 L p
1 g
F P
s
P
p
.002 w
.43567 .32305 m .44468 .31967 L .44386 .29716 L p
1 g
F P
s
P
p
.002 w
.37017 .35305 m .37138 .37811 L .39449 .36495 L p
1 g
F P
s
P
p
.002 w
.39449 .36495 m .39383 .34798 L .37017 .35305 L p
1 g
F P
s
P
p
.002 w
.42582 .3039 m .41037 .31559 L .42795 .32889 L p
1 g
F P
s
P
p
.002 w
.42795 .32889 m .43567 .32305 L .42582 .3039 L p
1 g
F P
s
P
p
.002 w
.44386 .29716 m .42582 .3039 L .43567 .32305 L p
1 g
F P
s
P
p
.002 w
.61721 .47984 m .64506 .43253 L .62614 .41756 L p
1 g
F P
s
P
p
.002 w
.63701 .36942 m .62614 .41756 L .64506 .43253 L p
1 g
F P
s
P
p
.002 w
.62614 .41756 m .63701 .36942 L .61402 .35955 L p
1 g
F P
s
P
p
.002 w
.58909 .53773 m .63154 .49702 L .61721 .47984 L p
1 g
F P
s
P
p
.002 w
.64506 .43253 m .61721 .47984 L .63154 .49702 L p
1 g
F P
s
P
p
.002 w
.33995 .46515 m .37212 .49366 L .37818 .46825 L p
1 g
F P
s
P
p
.002 w
.37818 .46825 m .35038 .44309 L .33995 .46515 L p
1 g
F P
s
P
p
.002 w
.54098 .28813 m .5568 .31489 L .58332 .31431 L p
1 g
F P
s
P
p
.002 w
.5568 .31489 m .54098 .28813 L .51691 .29786 L p
1 g
F P
s
P
p
.002 w
.51691 .29786 m .49714 .28311 L .47938 .30084 L p
1 g
F P
s
P
p
.002 w
.46242 .29612 m .47938 .30084 L .49714 .28311 L p
1 g
F P
s
P
p
.002 w
.42438 .57961 m .48081 .58114 L .47267 .56042 L p
1 g
F P
s
P
p
.002 w
.47267 .56042 m .41849 .55865 L .42438 .57961 L p
1 g
F P
s
P
p
.002 w
.49714 .28311 m .51691 .29786 L .54098 .28813 L p
1 g
F P
s
P
p
.002 w
.6083 .31669 m .61402 .35955 L .63701 .36942 L p
1 g
F P
s
P
p
.002 w
.61402 .35955 m .6083 .31669 L .58332 .31431 L p
1 g
F P
s
P
p
.002 w
.37813 .32764 m .37017 .35305 L .39383 .34798 L p
1 g
F P
s
P
p
.002 w
.39383 .34798 m .3993 .33088 L .37813 .32764 L p
1 g
F P
s
P
p
.002 w
.36955 .54085 m .41849 .55865 L .41481 .53506 L p
1 g
F P
s
P
p
.002 w
.41481 .53506 m .36918 .51806 L .36955 .54085 L p
1 g
F P
s
P
p
.002 w
.33401 .40905 m .35038 .44309 L .36432 .42123 L p
1 g
F P
s
P
p
.002 w
.36432 .42123 m .35104 .3929 L .33401 .40905 L p
1 g
F P
s
P
p
.002 w
.34919 .36027 m .35104 .3929 L .37138 .37811 L p
1 g
F P
s
P
p
.002 w
.37138 .37811 m .37017 .35305 L .34919 .36027 L p
1 g
F P
s
P
p
.002 w
.54712 .58371 m .59971 .55432 L .58909 .53773 L p
1 g
F P
s
P
p
.002 w
.58909 .53773 m .53736 .56662 L .54712 .58371 L p
1 g
F P
s
P
p
.002 w
.63154 .49702 m .58909 .53773 L .59971 .55432 L p
1 g
F P
s
P
p
.002 w
.49714 .28311 m .47207 .27594 L .46242 .29612 L p
1 g
F P
s
P
p
.002 w
.44386 .29716 m .46242 .29612 L .47207 .27594 L p
1 g
F P
s
P
p
.002 w
.48971 .59863 m .54712 .58371 L .53736 .56662 L p
1 g
F P
s
P
p
.002 w
.53736 .56662 m .48081 .58114 L .48971 .59863 L p
1 g
F P
s
P
p
.002 w
.39453 .30483 m .37813 .32764 L .3993 .33088 L p
1 g
F P
s
P
p
.002 w
.3993 .33088 m .41037 .31559 L .39453 .30483 L p
1 g
F P
s
P
p
.002 w
.33341 .48692 m .36918 .51806 L .37212 .49366 L p
1 g
F P
s
P
p
.002 w
.37212 .49366 m .33995 .46515 L .33341 .48692 L p
1 g
F P
s
P
p
.002 w
.56458 .28183 m .58332 .31431 L .6083 .31669 L p
1 g
F P
s
P
p
.002 w
.58332 .31431 m .56458 .28183 L .54098 .28813 L p
1 g
F P
s
P
p
.002 w
.47207 .27594 m .44446 .27737 L .44386 .29716 L p
1 g
F P
s
P
p
.002 w
.42582 .3039 m .44386 .29716 L .44446 .27737 L p
1 g
F P
s
P
p
.002 w
.63154 .49702 m .6608 .44787 L .64506 .43253 L p
1 g
F P
s
P
p
.002 w
.65708 .38113 m .64506 .43253 L .6608 .44787 L p
1 g
F P
s
P
p
.002 w
.64506 .43253 m .65708 .38113 L .63701 .36942 L p
1 g
F P
s
P
p
.002 w
.41755 .28738 m .39453 .30483 L .41037 .31559 L p
1 g
F P
s
P
p
.002 w
.41037 .31559 m .42582 .3039 L .41755 .28738 L p
1 g
F P
s
P
p
.002 w
.44446 .27737 m .41755 .28738 L .42582 .3039 L p
1 g
F P
s
P
p
.002 w
.59971 .55432 m .64294 .51303 L .63154 .49702 L p
1 g
F P
s
P
p
.002 w
.6608 .44787 m .63154 .49702 L .64294 .51303 L p
1 g
F P
s
P
p
.002 w
.54098 .28813 m .51544 .2687 L .49714 .28311 L p
1 g
F P
s
P
p
.002 w
.47207 .27594 m .49714 .28311 L .51544 .2687 L p
1 g
F P
s
P
p
.002 w
.51544 .2687 m .54098 .28813 L .56458 .28183 L p
1 g
F P
s
P
p
.002 w
.63114 .32207 m .63701 .36942 L .65708 .38113 L p
1 g
F P
s
P
p
.002 w
.63701 .36942 m .63114 .32207 L .6083 .31669 L p
1 g
F P
s
P
p
.002 w
.32082 .42625 m .33995 .46515 L .35038 .44309 L p
1 g
F P
s
P
p
.002 w
.35038 .44309 m .33401 .40905 L .32082 .42625 L p
1 g
F P
s
P
p
.002 w
.35943 .32697 m .34919 .36027 L .37017 .35305 L p
1 g
F P
s
P
p
.002 w
.37017 .35305 m .37813 .32764 L .35943 .32697 L p
1 g
F P
s
P
p
.002 w
.43245 .59734 m .48971 .59863 L .48081 .58114 L p
1 g
F P
s
P
p
.002 w
.48081 .58114 m .42438 .57961 L .43245 .59734 L p
1 g
F P
s
P
p
.002 w
.37337 .56145 m .42438 .57961 L .41849 .55865 L p
1 g
F P
s
P
p
.002 w
.41849 .55865 m .36955 .54085 L .37337 .56145 L p
1 g
F P
s
P
p
.002 w
.33149 .36955 m .33401 .40905 L .35104 .3929 L p
1 g
F P
s
P
p
.002 w
.35104 .3929 m .34919 .36027 L .33149 .36955 L p
1 g
F P
s
P
p
.002 w
.51544 .2687 m .48274 .25914 L .47207 .27594 L p
1 g
F P
s
P
p
.002 w
.44446 .27737 m .47207 .27594 L .48274 .25914 L p
1 g
F P
s
P
p
.002 w
.58716 .27923 m .6083 .31669 L .63114 .32207 L p
1 g
F P
s
P
p
.002 w
.6083 .31669 m .58716 .27923 L .56458 .28183 L p
1 g
F P
s
P
p
.002 w
.33108 .50788 m .36955 .54085 L .36918 .51806 L p
1 g
F P
s
P
p
.002 w
.36918 .51806 m .33341 .48692 L .33108 .50788 L p
1 g
F P
s
P
p
.002 w
.55601 .59742 m .6081 .56827 L .59971 .55432 L p
1 g
F P
s
P
p
.002 w
.59971 .55432 m .54712 .58371 L .55601 .59742 L p
1 g
F P
s
P
p
.002 w
.64294 .51303 m .59971 .55432 L .6081 .56827 L p
1 g
F P
s
P
p
.002 w
.38088 .29697 m .35943 .32697 L .37813 .32764 L p
1 g
F P
s
P
p
.002 w
.37813 .32764 m .39453 .30483 L .38088 .29697 L p
1 g
F P
s
P
p
.002 w
.49919 .61231 m .55601 .59742 L .54712 .58371 L p
1 g
F P
s
P
p
.002 w
.54712 .58371 m .48971 .59863 L .49919 .61231 L p
1 g
F P
s
P
p
.002 w
.64294 .51303 m .67284 .46325 L .6608 .44787 L p
1 g
F P
s
P
p
.002 w
.67364 .39447 m .6608 .44787 L .67284 .46325 L p
1 g
F P
s
P
p
.002 w
.6608 .44787 m .67364 .39447 L .65708 .38113 L p
1 g
F P
s
P
p
.002 w
.53389 .25809 m .56458 .28183 L .58716 .27923 L p
1 g
F P
s
P
p
.002 w
.56458 .28183 m .53389 .25809 L .51544 .2687 L p
1 g
F P
s
P
p
.002 w
.48274 .25914 m .51544 .2687 L .53389 .25809 L p
1 g
F P
s
P
p
.002 w
.48274 .25914 m .44654 .26089 L .44446 .27737 L p
1 g
F P
s
P
p
.002 w
.41755 .28738 m .44446 .27737 L .44654 .26089 L p
1 g
F P
s
P
p
.002 w
.31198 .44412 m .33341 .48692 L .33995 .46515 L p
1 g
F P
s
P
p
.002 w
.33995 .46515 m .32082 .42625 L .31198 .44412 L p
1 g
F P
s
P
p
.002 w
.41114 .274 m .38088 .29697 L .39453 .30483 L p
1 g
F P
s
P
p
.002 w
.39453 .30483 m .41755 .28738 L .41114 .274 L p
1 g
F P
s
P
p
.002 w
.65121 .33047 m .65708 .38113 L .67364 .39447 L p
1 g
F P
s
P
p
.002 w
.65708 .38113 m .65121 .33047 L .63114 .32207 L p
1 g
F P
s
P
p
.002 w
.6081 .56827 m .65099 .52744 L .64294 .51303 L p
1 g
F P
s
P
p
.002 w
.67284 .46325 m .64294 .51303 L .65099 .52744 L p
1 g
F P
s
P
p
.002 w
.44654 .26089 m .41114 .274 L .41755 .28738 L p
1 g
F P
s
P
p
.002 w
.34377 .32902 m .33149 .36955 L .34919 .36027 L p
1 g
F P
s
P
p
.002 w
.34919 .36027 m .35943 .32697 L .34377 .32902 L p
1 g
F P
s
P
p
.002 w
.38071 .57924 m .43245 .59734 L .42438 .57961 L p
1 g
F P
s
P
p
.002 w
.42438 .57961 m .37337 .56145 L .38071 .57924 L p
1 g
F P
s
P
p
.002 w
.31767 .3808 m .32082 .42625 L .33401 .40905 L p
1 g
F P
s
P
p
.002 w
.33401 .40905 m .33149 .36955 L .31767 .3808 L p
1 g
F P
s
P
p
.002 w
.44261 .61125 m .49919 .61231 L .48971 .59863 L p
1 g
F P
s
P
p
.002 w
.48971 .59863 m .43245 .59734 L .44261 .61125 L p
1 g
F P
s
P
p
.002 w
.60814 .28055 m .63114 .32207 L .65121 .33047 L p
1 g
F P
s
P
p
.002 w
.63114 .32207 m .60814 .28055 L .58716 .27923 L p
1 g
F P
s
P
p
.002 w
.33322 .52747 m .37337 .56145 L .36955 .54085 L p
1 g
F P
s
P
p
.002 w
.36955 .54085 m .33108 .50788 L .33322 .52747 L p
1 g
F P
s
P
p
.002 w
.53389 .25809 m .49425 .24627 L .48274 .25914 L p
1 g
F P
s
P
p
.002 w
.44654 .26089 m .48274 .25914 L .49425 .24627 L p
1 g
F P
s
P
p
.002 w
.36988 .29237 m .34377 .32902 L .35943 .32697 L p
1 g
F P
s
P
p
.002 w
.35943 .32697 m .38088 .29697 L .36988 .29237 L p
1 g
F P
s
P
p
.002 w
.55206 .25169 m .58716 .27923 L .60814 .28055 L p
1 g
F P
s
P
p
.002 w
.58716 .27923 m .55206 .25169 L .53389 .25809 L p
1 g
F P
s
P
p
.002 w
.56375 .60721 m .61395 .5791 L .6081 .56827 L p
1 g
F P
s
P
p
.002 w
.6081 .56827 m .55601 .59742 L .56375 .60721 L p
1 g
F P
s
P
p
.002 w
.65099 .52744 m .6081 .56827 L .61395 .5791 L p
1 g
F P
s
P
p
.002 w
.49425 .24627 m .53389 .25809 L .55206 .25169 L p
1 g
F P
s
P
p
.002 w
.30793 .46226 m .33108 .50788 L .33341 .48692 L p
1 g
F P
s
P
p
.002 w
.33341 .48692 m .31198 .44412 L .30793 .46226 L p
1 g
F P
s
P
p
.002 w
.65099 .52744 m .68073 .47832 L .67284 .46325 L p
1 g
F P
s
P
p
.002 w
.68615 .40923 m .67284 .46325 L .68073 .47832 L p
1 g
F P
s
P
p
.002 w
.67284 .46325 m .68615 .40923 L .67364 .39447 L p
1 g
F P
s
P
p
.002 w
.50907 .62165 m .56375 .60721 L .55601 .59742 L p
1 g
F P
s
P
p
.002 w
.55601 .59742 m .49919 .61231 L .50907 .62165 L p
1 g
F P
s
P
p
.002 w
.6679 .34183 m .67364 .39447 L .68615 .40923 L p
1 g
F P
s
P
p
.002 w
.67364 .39447 m .6679 .34183 L .65121 .33047 L p
1 g
F P
s
P
p
.002 w
.49425 .24627 m .45012 .24829 L .44654 .26089 L p
1 g
F P
s
P
p
.002 w
.41114 .274 m .44654 .26089 L .45012 .24829 L p
1 g
F P
s
P
p
.002 w
.40685 .26427 m .36988 .29237 L .38088 .29697 L p
1 g
F P
s
P
p
.002 w
.38088 .29697 m .41114 .274 L .40685 .26427 L p
1 g
F P
s
P
p
.002 w
.33173 .3339 m .31767 .3808 L .33149 .36955 L p
1 g
F P
s
P
p
.002 w
.33149 .36955 m .34377 .32902 L .33173 .3339 L p
1 g
F P
s
P
p
.002 w
.30829 .39382 m .31198 .44412 L .32082 .42625 L p
1 g
F P
s
P
p
.002 w
.32082 .42625 m .31767 .3808 L .30829 .39382 L p
1 g
F P
s
P
p
.002 w
.61395 .5791 m .65532 .53982 L .65099 .52744 L p
1 g
F P
s
P
p
.002 w
.68073 .47832 m .65099 .52744 L .65532 .53982 L p
1 g
F P
s
P
p
.002 w
.45012 .24829 m .40685 .26427 L .41114 .274 L p
1 g
F P
s
P
p
.002 w
.39158 .59361 m .44261 .61125 L .43245 .59734 L p
1 g
F P
s
P
p
.002 w
.43245 .59734 m .38071 .57924 L .39158 .59361 L p
1 g
F P
s
P
p
.002 w
.62691 .28595 m .65121 .33047 L .6679 .34183 L p
1 g
F P
s
P
p
.002 w
.65121 .33047 m .62691 .28595 L .60814 .28055 L p
1 g
F P
s
P
p
.002 w
.45473 .62077 m .50907 .62165 L .49919 .61231 L p
1 g
F P
s
P
p
.002 w
.49919 .61231 m .44261 .61125 L .45473 .62077 L p
1 g
F P
s
P
p
.002 w
.34003 .54508 m .38071 .57924 L .37337 .56145 L p
1 g
F P
s
P
p
.002 w
.37337 .56145 m .33322 .52747 L .34003 .54508 L p
1 g
F P
s
P
p
.002 w
.55206 .25169 m .50636 .23788 L .49425 .24627 L p
1 g
F P
s
P
p
.002 w
.45012 .24829 m .49425 .24627 L .50636 .23788 L p
1 g
F P
s
P
p
.002 w
.56947 .2499 m .60814 .28055 L .62691 .28595 L p
1 g
F P
s
P
p
.002 w
.60814 .28055 m .56947 .2499 L .55206 .25169 L p
1 g
F P
s
P
p
.002 w
.30905 .48019 m .33322 .52747 L .33108 .50788 L p
1 g
F P
s
P
p
.002 w
.33108 .50788 m .30793 .46226 L .30905 .48019 L p
1 g
F P
s
P
p
.002 w
.50636 .23788 m .55206 .25169 L .56947 .2499 L p
1 g
F P
s
P
p
.002 w
.36196 .29135 m .33173 .3339 L .34377 .32902 L p
1 g
F P
s
P
p
.002 w
.34377 .32902 m .36988 .29237 L .36196 .29135 L p
1 g
F P
s
P
p
.002 w
.65532 .53982 m .68402 .49267 L .68073 .47832 L p
1 g
F P
s
P
p
.002 w
.69406 .42509 m .68073 .47832 L .68402 .49267 L p
1 g
F P
s
P
p
.002 w
.68073 .47832 m .69406 .42509 L .68615 .40923 L p
1 g
F P
s
P
p
.002 w
.57008 .61261 m .61695 .58636 L .61395 .5791 L p
1 g
F P
s
P
p
.002 w
.61395 .5791 m .56375 .60721 L .57008 .61261 L p
1 g
F P
s
P
p
.002 w
.65532 .53982 m .61395 .5791 L .61695 .58636 L p
1 g
F P
s
P
p
.002 w
.68059 .356 m .68615 .40923 L .69406 .42509 L p
1 g
F P
s
P
p
.002 w
.68615 .40923 m .68059 .356 L .6679 .34183 L p
1 g
F P
s
P
p
.002 w
.51911 .62612 m .57008 .61261 L .56375 .60721 L p
1 g
F P
s
P
p
.002 w
.56375 .60721 m .50907 .62165 L .51911 .62612 L p
1 g
F P
s
P
p
.002 w
.30386 .40836 m .30793 .46226 L .31198 .44412 L p
1 g
F P
s
P
p
.002 w
.31198 .44412 m .30829 .39382 L .30386 .40836 L p
1 g
F P
s
P
p
.002 w
.50636 .23788 m .45522 .24013 L .45012 .24829 L p
1 g
F P
s
P
p
.002 w
.40685 .26427 m .45012 .24829 L .45522 .24013 L p
1 g
F P
s
P
p
.002 w
.32383 .34166 m .30829 .39382 L .31767 .3808 L p
1 g
F P
s
P
p
.002 w
.31767 .3808 m .33173 .3339 L .32383 .34166 L p
1 g
F P
s
P
p
.002 w
.40587 .60399 m .45473 .62077 L .44261 .61125 L p
1 g
F P
s
P
p
.002 w
.44261 .61125 m .39158 .59361 L .40587 .60399 L p
1 g
F P
s
P
p
.002 w
.40493 .25868 m .36196 .29135 L .36988 .29237 L p
1 g
F P
s
P
p
.002 w
.36988 .29237 m .40685 .26427 L .40493 .25868 L p
1 g
F P
s
P
p
.002 w
.64288 .29551 m .6679 .34183 L .68059 .356 L p
1 g
F P
s
P
p
.002 w
.6679 .34183 m .64288 .29551 L .62691 .28595 L p
1 g
F P
s
P
p
.002 w
.61695 .58636 m .65558 .54974 L .65532 .53982 L p
1 g
F P
s
P
p
.002 w
.68402 .49267 m .65532 .53982 L .65558 .54974 L p
1 g
F P
s
P
p
.002 w
.45522 .24013 m .40493 .25868 L .40685 .26427 L p
1 g
F P
s
P
p
.002 w
.35156 .56014 m .39158 .59361 L .38071 .57924 L p
1 g
F P
s
P
p
.002 w
.38071 .57924 m .34003 .54508 L .35156 .56014 L p
1 g
F P
s
P
p
.002 w
.46859 .62537 m .51911 .62612 L .50907 .62165 L p
1 g
F P
s
P
p
.002 w
.50907 .62165 m .45473 .62077 L .46859 .62537 L p
1 g
F P
s
P
p
.002 w
.58563 .25301 m .62691 .28595 L .64288 .29551 L p
1 g
F P
s
P
p
.002 w
.62691 .28595 m .58563 .25301 L .56947 .2499 L p
1 g
F P
s
P
p
.002 w
.56947 .2499 m .51878 .23445 L .50636 .23788 L p
1 g
F P
s
P
p
.002 w
.45522 .24013 m .50636 .23788 L .51878 .23445 L p
1 g
F P
s
P
p
.002 w
.31558 .49738 m .34003 .54508 L .33322 .52747 L p
1 g
F P
s
P
p
.002 w
.33322 .52747 m .30905 .48019 L .31558 .49738 L p
1 g
F P
s
P
p
.002 w
.51878 .23445 m .56947 .2499 L .58563 .25301 L p
1 g
F P
s
P
p
.002 w
.35755 .29417 m .32383 .34166 L .33173 .3339 L p
1 g
F P
s
P
p
.002 w
.33173 .3339 m .36196 .29135 L .35755 .29417 L p
1 g
F P
s
P
p
.002 w
.68402 .49267 m .69691 .4417 L .69406 .42509 L p
1 g
F P
s
P
p
.002 w
.68874 .37274 m .69406 .42509 L .69691 .4417 L p
1 g
F P
s
P
p
.002 w
.69406 .42509 m .68874 .37274 L .68059 .356 L p
1 g
F P
s
P
p
.002 w
.65558 .54974 m .68235 .50588 L .68402 .49267 L p
1 g
F P
s
P
p
.002 w
.69691 .4417 m .68402 .49267 L .68235 .50588 L p
1 g
F P
s
P
p
.002 w
.3048 .42411 m .30905 .48019 L .30793 .46226 L p
1 g
F P
s
P
p
.002 w
.30793 .46226 m .30386 .40836 L .3048 .42411 L p
1 g
F P
s
P
p
.002 w
.57474 .61319 m .61684 .58961 L .61695 .58636 L p
1 g
F P
s
P
p
.002 w
.61695 .58636 m .57008 .61261 L .57474 .61319 L p
1 g
F P
s
P
p
.002 w
.65558 .54974 m .61695 .58636 L .61684 .58961 L p
1 g
F P
s
P
p
.002 w
.52903 .62532 m .57474 .61319 L .57008 .61261 L p
1 g
F P
s
P
p
.002 w
.57008 .61261 m .51911 .62612 L .52903 .62532 L p
1 g
F P
s
P
p
.002 w
.32058 .35225 m .30386 .40836 L .30829 .39382 L p
1 g
F P
s
P
p
.002 w
.30829 .39382 m .32383 .34166 L .32058 .35225 L p
1 g
F P
s
P
p
.002 w
.68059 .356 m .65544 .3092 L .64288 .29551 L p
1 g
F P
s
P
p
.002 w
.65544 .3092 m .68059 .356 L .68874 .37274 L p
1 g
F P
s
P
p
.002 w
.42336 .60983 m .46859 .62537 L .45473 .62077 L p
1 g
F P
s
P
p
.002 w
.45473 .62077 m .40587 .60399 L .42336 .60983 L p
1 g
F P
s
P
p
.002 w
.51878 .23445 m .46178 .23693 L .45522 .24013 L p
1 g
F P
s
P
p
.002 w
.40493 .25868 m .45522 .24013 L .46178 .23693 L p
1 g
F P
s
P
p
.002 w
.36772 .57204 m .40587 .60399 L .39158 .59361 L p
1 g
F P
s
P
p
.002 w
.39158 .59361 m .35156 .56014 L .36772 .57204 L p
1 g
F P
s
P
p
.002 w
.61684 .58961 m .65151 .55675 L .65558 .54974 L p
1 g
F P
s
P
p
.002 w
.68235 .50588 m .65558 .54974 L .65151 .55675 L p
1 g
F P
s
P
p
.002 w
.40559 .25765 m .35755 .29417 L .36196 .29135 L p
1 g
F P
s
P
p
.002 w
.36196 .29135 m .40493 .25868 L .40559 .25765 L p
1 g
F P
s
P
p
.002 w
.46178 .23693 m .40559 .25765 L .40493 .25868 L p
1 g
F P
s
P
p
.002 w
.48389 .62463 m .52903 .62532 L .51911 .62612 L p
1 g
F P
s
P
p
.002 w
.51911 .62612 m .46859 .62537 L .48389 .62463 L p
1 g
F P
s
P
p
.002 w
.64288 .29551 m .60001 .26123 L .58563 .25301 L p
1 g
F P
s
P
p
.002 w
.60001 .26123 m .64288 .29551 L .65544 .3092 L p
1 g
F P
s
P
p
.002 w
.32764 .51328 m .35156 .56014 L .34003 .54508 L p
1 g
F P
s
P
p
.002 w
.34003 .54508 m .31558 .49738 L .32764 .51328 L p
1 g
F P
s
P
p
.002 w
.58563 .25301 m .53118 .23638 L .51878 .23445 L p
1 g
F P
s
P
p
.002 w
.46178 .23693 m .51878 .23445 L .53118 .23638 L p
1 g
F P
s
P
p
.002 w
.53118 .23638 m .58563 .25301 L .60001 .26123 L p
1 g
F P
s
P
p
.002 w
.68235 .50588 m .69433 .45863 L .69691 .4417 L p
1 g
F P
s
P
p
.002 w
.69691 .4417 m .69186 .39173 L .68874 .37274 L p
1 g
F P
s
P
p
.002 w
.69186 .39173 m .69691 .4417 L .69433 .45863 L p
1 g
F P
s
P
p
.002 w
.35701 .30101 m .32058 .35225 L .32383 .34166 L p
1 g
F P
s
P
p
.002 w
.32383 .34166 m .35755 .29417 L .35701 .30101 L p
1 g
F P
s
P
p
.002 w
.65151 .55675 m .67547 .5175 L .68235 .50588 L p
1 g
F P
s
P
p
.002 w
.69433 .45863 m .68235 .50588 L .67547 .5175 L p
1 g
F P
s
P
p
.002 w
.31141 .44065 m .31558 .49738 L .30905 .48019 L p
1 g
F P
s
P
p
.002 w
.30905 .48019 m .3048 .42411 L .31141 .44065 L p
1 g
F P
s
P
p
.002 w
.66405 .32683 m .68874 .37274 L .69186 .39173 L p
1 g
F P
s
P
p
.002 w
.68874 .37274 m .66405 .32683 L .65544 .3092 L p
1 g
F P
s
P
p
.002 w
.32236 .36554 m .3048 .42411 L .30386 .40836 L p
1 g
F P
s
P
p
.002 w
.30386 .40836 m .32058 .35225 L .32236 .36554 L p
1 g
F P
s
P
p
.002 w
.57748 .6086 m .6134 .58848 L .61684 .58961 L p
1 g
F P
s
P
p
.002 w
.61684 .58961 m .57474 .61319 L .57748 .6086 L p
1 g
F P
s
P
p
.002 w
.65151 .55675 m .61684 .58961 L .6134 .58848 L p
1 g
F P
s
P
p
.002 w
.53855 .61891 m .57748 .6086 L .57474 .61319 L p
1 g
F P
s
P
p
.002 w
.57474 .61319 m .52903 .62532 L .53855 .61891 L p
1 g
F P
s
P
p
.002 w
.44369 .61072 m .48389 .62463 L .46859 .62537 L p
1 g
F P
s
P
p
.002 w
.46859 .62537 m .42336 .60983 L .44369 .61072 L p
1 g
F P
s
P
p
.002 w
.38828 .58026 m .42336 .60983 L .40587 .60399 L p
1 g
F P
s
P
p
.002 w
.40587 .60399 m .36772 .57204 L .38828 .58026 L p
1 g
F P
s
P
p
.002 w
.53118 .23638 m .46971 .23909 L .46178 .23693 L p
1 g
F P
s
P
p
.002 w
.40559 .25765 m .46178 .23693 L .46971 .23909 L p
1 g
F P
s
P
p
.002 w
.6134 .58848 m .64295 .56046 L .65151 .55675 L p
1 g
F P
s
P
p
.002 w
.67547 .5175 m .65151 .55675 L .64295 .56046 L p
1 g
F P
s
P
p
.002 w
.40897 .26151 m .35701 .30101 L .35755 .29417 L p
1 g
F P
s
P
p
.002 w
.35755 .29417 m .40559 .25765 L .40897 .26151 L p
1 g
F P
s
P
p
.002 w
.61208 .27461 m .65544 .3092 L .66405 .32683 L p
1 g
F P
s
P
p
.002 w
.65544 .3092 m .61208 .27461 L .60001 .26123 L p
1 g
F P
s
P
p
.002 w
.34514 .52733 m .36772 .57204 L .35156 .56014 L p
1 g
F P
s
P
p
.002 w
.35156 .56014 m .32764 .51328 L .34514 .52733 L p
1 g
F P
s
P
p
.002 w
.46971 .23909 m .40897 .26151 L .40559 .25765 L p
1 g
F P
s
P
p
.002 w
.50024 .61825 m .53855 .61891 L .52903 .62532 L p
1 g
F P
s
P
p
.002 w
.52903 .62532 m .48389 .62463 L .50024 .61825 L p
1 g
F P
s
P
p
.002 w
.5432 .24396 m .60001 .26123 L .61208 .27461 L p
1 g
F P
s
P
p
.002 w
.60001 .26123 m .5432 .24396 L .53118 .23638 L p
1 g
F P
s
P
p
.002 w
.46971 .23909 m .53118 .23638 L .5432 .24396 L p
1 g
F P
s
P
p
.002 w
.67547 .5175 m .68608 .4754 L .69433 .45863 L p
1 g
F P
s
P
p
.002 w
.68958 .41251 m .69433 .45863 L .68608 .4754 L p
1 g
F P
s
P
p
.002 w
.69433 .45863 m .68958 .41251 L .69186 .39173 L p
1 g
F P
s
P
p
.002 w
.32379 .45749 m .32764 .51328 L .31558 .49738 L p
1 g
F P
s
P
p
.002 w
.31558 .49738 m .31141 .44065 L .32379 .45749 L p
1 g
F P
s
P
p
.002 w
.64295 .56046 m .66326 .52708 L .67547 .5175 L p
1 g
F P
s
P
p
.002 w
.68608 .4754 m .67547 .5175 L .66326 .52708 L p
1 g
F P
s
P
p
.002 w
.36061 .31191 m .32236 .36554 L .32058 .35225 L p
1 g
F P
s
P
p
.002 w
.32058 .35225 m .35701 .30101 L .36061 .31191 L p
1 g
F P
s
P
p
.002 w
.66821 .34807 m .69186 .39173 L .68958 .41251 L p
1 g
F P
s
P
p
.002 w
.69186 .39173 m .66821 .34807 L .66405 .32683 L p
1 g
F P
s
P
p
.002 w
.32943 .38126 m .31141 .44065 L .3048 .42411 L p
1 g
F P
s
P
p
.002 w
.3048 .42411 m .32236 .36554 L .32943 .38126 L p
1 g
F P
s
P
p
.002 w
.41278 .58435 m .44369 .61072 L .42336 .60983 L p
1 g
F P
s
P
p
.002 w
.42336 .60983 m .38828 .58026 L .41278 .58435 L p
1 g
F P
s
P
p
.002 w
.46637 .60636 m .50024 .61825 L .48389 .62463 L p
1 g
F P
s
P
p
.002 w
.48389 .62463 m .44369 .61072 L .46637 .60636 L p
1 g
F P
s
P
p
.002 w
.5781 .59864 m .60652 .58273 L .6134 .58848 L p
1 g
F P
s
P
p
.002 w
.6134 .58848 m .57748 .6086 L .5781 .59864 L p
1 g
F P
s
P
p
.002 w
.64295 .56046 m .6134 .58848 L .60652 .58273 L p
1 g
F P
s
P
p
.002 w
.54733 .60674 m .5781 .59864 L .57748 .6086 L p
1 g
F P
s
P
p
.002 w
.57748 .6086 m .53855 .61891 L .54733 .60674 L p
1 g
F P
s
P
p
.002 w
.62133 .29301 m .66405 .32683 L .66821 .34807 L p
1 g
F P
s
P
p
.002 w
.66405 .32683 m .62133 .29301 L .61208 .27461 L p
1 g
F P
s
P
p
.002 w
.5432 .24396 m .47886 .2469 L .46971 .23909 L p
1 g
F P
s
P
p
.002 w
.40897 .26151 m .46971 .23909 L .47886 .2469 L p
1 g
F P
s
P
p
.002 w
.36778 .53896 m .38828 .58026 L .36772 .57204 L p
1 g
F P
s
P
p
.002 w
.36772 .57204 m .34514 .52733 L .36778 .53896 L p
1 g
F P
s
P
p
.002 w
.60652 .58273 m .62987 .56055 L .64295 .56046 L p
1 g
F P
s
P
p
.002 w
.66326 .52708 m .64295 .56046 L .62987 .56055 L p
1 g
F P
s
P
p
.002 w
.41516 .27049 m .36061 .31191 L .35701 .30101 L p
1 g
F P
s
P
p
.002 w
.35701 .30101 m .40897 .26151 L .41516 .27049 L p
1 g
F P
s
P
p
.002 w
.5172 .60612 m .54733 .60674 L .53855 .61891 L p
1 g
F P
s
P
p
.002 w
.53855 .61891 m .50024 .61825 L .5172 .60612 L p
1 g
F P
s
P
p
.002 w
.55443 .25728 m .61208 .27461 L .62133 .29301 L p
1 g
F P
s
P
p
.002 w
.61208 .27461 m .55443 .25728 L .5432 .24396 L p
1 g
F P
s
P
p
.002 w
.47886 .2469 m .41516 .27049 L .40897 .26151 L p
1 g
F P
s
P
p
.002 w
.47886 .2469 m .5432 .24396 L .55443 .25728 L p
1 g
F P
s
P
p
.002 w
.66326 .52708 m .67212 .49145 L .68608 .4754 L p
1 g
F P
s
P
p
.002 w
.68169 .43452 m .68608 .4754 L .67212 .49145 L p
1 g
F P
s
P
p
.002 w
.68608 .4754 m .68169 .43452 L .68958 .41251 L p
1 g
F P
s
P
p
.002 w
.34183 .47411 m .34514 .52733 L .32764 .51328 L p
1 g
F P
s
P
p
.002 w
.32764 .51328 m .32379 .45749 L .34183 .47411 L p
1 g
F P
s
P
p
.002 w
.66757 .37244 m .68958 .41251 L .68169 .43452 L p
1 g
F P
s
P
p
.002 w
.68958 .41251 m .66757 .37244 L .66821 .34807 L p
1 g
F P
s
P
p
.002 w
.62987 .56055 m .6458 .53421 L .66326 .52708 L p
1 g
F P
s
P
p
.002 w
.67212 .49145 m .66326 .52708 L .6458 .53421 L p
1 g
F P
s
P
p
.002 w
.3685 .32677 m .32943 .38126 L .32236 .36554 L p
1 g
F P
s
P
p
.002 w
.32236 .36554 m .36061 .31191 L .3685 .32677 L p
1 g
F P
s
P
p
.002 w
.34185 .39904 m .32379 .45749 L .31141 .44065 L p
1 g
F P
s
P
p
.002 w
.31141 .44065 m .32943 .38126 L .34185 .39904 L p
1 g
F P
s
P
p
.002 w
.44059 .58398 m .46637 .60636 L .44369 .61072 L p
1 g
F P
s
P
p
.002 w
.44369 .61072 m .41278 .58435 L .44059 .58398 L p
1 g
F P
s
P
p
.002 w
.49076 .59664 m .5172 .60612 L .50024 .61825 L p
1 g
F P
s
P
p
.002 w
.50024 .61825 m .46637 .60636 L .49076 .59664 L p
1 g
F P
s
P
p
.002 w
.6273 .31611 m .66821 .34807 L .66757 .37244 L p
1 g
F P
s
P
p
.002 w
.66821 .34807 m .6273 .31611 L .62133 .29301 L p
1 g
F P
s
P
p
.002 w
.39502 .54767 m .41278 .58435 L .38828 .58026 L p
1 g
F P
s
P
p
.002 w
.38828 .58026 m .36778 .53896 L .39502 .54767 L p
1 g
F P
s
P
p
.002 w
.57643 .5833 m .59621 .57223 L .60652 .58273 L p
1 g
F P
s
P
p
.002 w
.60652 .58273 m .5781 .59864 L .57643 .5833 L p
1 g
F P
s
P
p
.002 w
.62987 .56055 m .60652 .58273 L .59621 .57223 L p
1 g
F P
s
P
p
.002 w
.55505 .58887 m .57643 .5833 L .5781 .59864 L p
1 g
F P
s
P
p
.002 w
.5781 .59864 m .54733 .60674 L .55505 .58887 L p
1 g
F P
s
P
p
.002 w
.55443 .25728 m .48901 .26047 L .47886 .2469 L p
1 g
F P
s
P
p
.002 w
.41516 .27049 m .47886 .2469 L .48901 .26047 L p
1 g
F P
s
P
p
.002 w
.59621 .57223 m .61241 .55679 L .62987 .56055 L p
1 g
F P
s
P
p
.002 w
.6458 .53421 m .62987 .56055 L .61241 .55679 L p
1 g
F P
s
P
p
.002 w
.56446 .27624 m .62133 .29301 L .6273 .31611 L p
1 g
F P
s
P
p
.002 w
.62133 .29301 m .56446 .27624 L .55443 .25728 L p
1 g
F P
s
P
p
.002 w
.42413 .28459 m .3685 .32677 L .36061 .31191 L p
1 g
F P
s
P
p
.002 w
.36061 .31191 m .41516 .27049 L .42413 .28459 L p
1 g
F P
s
P
p
.002 w
.36518 .48989 m .36778 .53896 L .34514 .52733 L p
1 g
F P
s
P
p
.002 w
.34514 .52733 m .34183 .47411 L .36518 .48989 L p
1 g
F P
s
P
p
.002 w
.6458 .53421 m .65259 .50624 L .67212 .49145 L p
1 g
F P
s
P
p
.002 w
.66817 .45709 m .67212 .49145 L .65259 .50624 L p
1 g
F P
s
P
p
.002 w
.67212 .49145 m .66817 .45709 L .68169 .43452 L p
1 g
F P
s
P
p
.002 w
.53421 .58834 m .55505 .58887 L .54733 .60674 L p
1 g
F P
s
P
p
.002 w
.54733 .60674 m .5172 .60612 L .53421 .58834 L p
1 g
F P
s
P
p
.002 w
.66192 .39926 m .68169 .43452 L .66817 .45709 L p
1 g
F P
s
P
p
.002 w
.68169 .43452 m .66192 .39926 L .66757 .37244 L p
1 g
F P
s
P
p
.002 w
.48901 .26047 m .55443 .25728 L .56446 .27624 L p
1 g
F P
s
P
p
.002 w
.48901 .26047 m .42413 .28459 L .41516 .27049 L p
1 g
F P
s
P
p
.002 w
.47087 .57898 m .49076 .59664 L .46637 .60636 L p
1 g
F P
s
P
p
.002 w
.46637 .60636 m .44059 .58398 L .47087 .57898 L p
1 g
F P
s
P
p
.002 w
.61241 .55679 m .62338 .5385 L .6458 .53421 L p
1 g
F P
s
P
p
.002 w
.65259 .50624 m .6458 .53421 L .62338 .5385 L p
1 g
F P
s
P
p
.002 w
.35946 .41834 m .34183 .47411 L .32379 .45749 L p
1 g
F P
s
P
p
.002 w
.32379 .45749 m .34185 .39904 L .35946 .41834 L p
1 g
F P
s
P
p
.002 w
.38065 .34532 m .34185 .39904 L .32943 .38126 L p
1 g
F P
s
P
p
.002 w
.32943 .38126 m .3685 .32677 L .38065 .34532 L p
1 g
F P
s
P
p
.002 w
.62963 .34333 m .66757 .37244 L .66192 .39926 L p
1 g
F P
s
P
p
.002 w
.66757 .37244 m .62963 .34333 L .6273 .31611 L p
1 g
F P
s
P
p
.002 w
.42608 .55303 m .44059 .58398 L .41278 .58435 L p
1 g
F P
s
P
p
.002 w
.41278 .58435 m .39502 .54767 L .42608 .55303 L p
1 g
F P
s
P
p
.002 w
.51608 .58166 m .53421 .58834 L .5172 .60612 L p
1 g
F P
s
P
p
.002 w
.5172 .60612 m .49076 .59664 L .51608 .58166 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.57239 .56277 m .5826 .55706 L .59621 .57223 L p
1 g
F P
s
P
p
.002 w
.59621 .57223 m .57643 .5833 L .57239 .56277 L p
1 g
F P
s
P
p
.004 w
.59341 .58194 m
.60538 .60133 L
s
P
p
.002 w
.61241 .55679 m .59621 .57223 L .5826 .55706 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.57288 .30047 m .6273 .31611 L .62963 .34333 L p
1 g
F P
s
P
p
.002 w
.6273 .31611 m .57288 .30047 L .56446 .27624 L p
1 g
F P
s
P
p
.002 w
.39321 .50424 m .39502 .54767 L .36778 .53896 L p
1 g
F P
s
P
p
.002 w
.36778 .53896 m .36518 .48989 L .39321 .50424 L p
1 g
F P
s
P
p
.002 w
.56137 .56561 m .57239 .56277 L .57643 .5833 L p
1 g
F P
s
P
p
.002 w
.57643 .5833 m .55505 .58887 L .56137 .56561 L p
1 g
F P
s
P
p
.002 w
.56446 .27624 m .49986 .27965 L .48901 .26047 L p
1 g
F P
s
P
p
.002 w
.42413 .28459 m .48901 .26047 L .49986 .27965 L p
1 g
F P
s
P
p
.002 w
.62338 .5385 m .62791 .51919 L .65259 .50624 L p
1 g
F P
s
P
p
.002 w
.64926 .47947 m .65259 .50624 L .62791 .51919 L p
1 g
F P
s
P
p
.002 w
.65259 .50624 m .64926 .47947 L .66817 .45709 L p
1 g
F P
s
P
p
.002 w
.65126 .4277 m .66817 .45709 L .64926 .47947 L p
1 g
F P
s
P
p
.002 w
.66817 .45709 m .65126 .4277 L .66192 .39926 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.5826 .55706 m .59094 .54909 L .61241 .55679 L p
1 g
F P
s
P
p
.002 w
.62338 .5385 m .61241 .55679 L .59094 .54909 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.55069 .56527 m .56137 .56561 L .55505 .58887 L p
1 g
F P
s
P
p
.002 w
.55505 .58887 m .53421 .58834 L .55069 .56527 L p
1 g
F P
s
P
p
.002 w
.43573 .30363 m .38065 .34532 L .3685 .32677 L p
1 g
F P
s
P
p
.002 w
.3685 .32677 m .42413 .28459 L .43573 .30363 L p
1 g
F P
s
P
p
.002 w
.49986 .27965 m .56446 .27624 L .57288 .30047 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51608 .58166 m .49076 .59664 L p
.49648 .5835 L 1 g
F P
s
P
p
.49648 .5835 m .49776 .58056 L .50901 .58123 L 1 g
F
P
p
.49648 .5835 m .50901 .58123 L .51608 .58166 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58088 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58088 L .51453 .58024 L 1 g
F
P
p
.53128 .57265 m .51453 .58024 L .51647 .57963 L 1 g
F
P
p
.002 w
.52013 .57849 m .51608 .58166 L p
.51782 .57921 L 1 g
F P
s
P
p
.002 w
.51608 .58166 m .51453 .58024 L p
.51782 .57921 L 1 g
F P
s
P
p
.51956 .57866 m .51559 .58004 L .51946 .57872 L 1 g
F
P
p
.53128 .57265 m .51647 .57963 L .51956 .57866 L 1 g
F
P
p
.51647 .57963 m .51559 .58004 L .51956 .57866 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.50263 .56938 m .53473 .55541 L p
.51782 .57921 L 1 g
F P
s
P
p
.002 w
.51453 .58024 m .50263 .56938 L p
.51782 .57921 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53421 .58834 m .51608 .58166 L .52013 .57849 L p
1 g
F P
s
P
p
.53421 .58834 m .52249 .58014 L .53864 .57213 L 1 g
F
P
p
.52249 .58014 m .52013 .57849 L .53169 .57452 L 1 g
F
P
p
.52249 .58014 m .53169 .57452 L .53864 .57213 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57452 L p
1 g
F P
s
P
p
.54854 .56129 m .53169 .57452 L .54 .56943 L 1 g
F
P
p
.002 w
.51535 .58099 m .51608 .58166 L p
.49776 .58056 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53169 .57452 L p
1 g
F P
s
P
p
.002 w
.53169 .57452 m .53128 .57265 L p
.51946 .57872 L 1 g
F P
s
P
p
.002 w
.51096 .58088 m .51079 .57862 L p
.50071 .58064 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58036 L p
1 g
F P
s
P
p
.002 w
.49076 .59664 m .47195 .57994 L p
.48908 .58036 L 1 g
F P
s
P
p
.49705 .58219 m .48908 .58036 L .49776 .58056 L 1 g
F
P
p
.49076 .59664 m .48908 .58036 L .49705 .58219 L 1 g
F
P
p
.002 w
.48908 .58036 m .48921 .57862 L p
.47727 .57764 L 1 g
F P
s
P
p
.51079 .57862 m .48908 .58036 L .50071 .58064 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.49776 .58056 m .48732 .57995 L .50263 .56938 L 1 g
F
P
p
.002 w
.47087 .57898 m .47616 .57738 L p
.48732 .57995 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46824 .57483 L p
1 g
F P
s
P
p
.45137 .5677 m .46824 .57483 L .47087 .57898 L 1 g
F
P
p
.002 w
.46918 .57523 m .46935 .57562 L p
.46824 .57483 L 1 g
F P
s
P
p
.002 w
.46935 .57562 m .47087 .57898 L p
.46824 .57483 L 1 g
F P
s
P
p
.002 w
.46824 .57483 m .46872 .57265 L p
.46045 .56934 L 1 g
F P
s
P
p
.48921 .57862 m .46824 .57483 L .46918 .57523 L 1 g
F
P
p
.48921 .57862 m .46918 .57523 L .472 .5761 L 1 g
F
P
p
.002 w
.47087 .57898 m .46918 .57523 L p
.47321 .57648 L 1 g
F P
s
P
p
.002 w
.47616 .57738 m .47087 .57898 L p
.47321 .57648 L 1 g
F P
s
P
p
.48921 .57862 m .46809 .57553 L .47727 .57764 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45994 .55476 m .49542 .5527 L p
.47321 .57648 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45095 .56266 L p
1 g
F P
s
P
p
.46872 .57265 m .45095 .56266 L .46045 .56934 L 1 g
F
P
p
.002 w
.45994 .55476 m .46918 .57523 L p
.46824 .57483 L 1 g
F P
s
P
p
.45137 .5677 m .45351 .56446 L .46824 .57483 L 1 g
F
P
p
.45351 .56446 m .45994 .55476 L .46824 .57483 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44059 .58398 m .42608 .55303 L .44337 .55391 L p
1 g
F P
s
P
p
.002 w
.45095 .56266 m .45146 .56129 L p
.4446 .55533 L 1 g
F P
s
P
p
.44059 .58398 m .44337 .55391 L .45308 .56512 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43857 .54693 L p
1 g
F P
s
P
p
.42608 .55303 m .43687 .54445 L .43857 .54693 L 1 g
F
P
p
.002 w
.44337 .55391 m .44074 .55378 L p
.43857 .54693 L 1 g
F P
s
P
p
.002 w
.44074 .55378 m .42608 .55303 L p
.43857 .54693 L 1 g
F P
s
P
p
.002 w
.43857 .54693 m .43925 .54566 L p
.43637 .53997 L 1 g
F P
s
P
p
.45146 .56129 m .43857 .54693 L .44397 .55478 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43857 .54693 m .45953 .52643 L .44337 .55391 L 1 g
F
P
p
.43687 .54445 m .4376 .54387 L .43857 .54693 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43272 .52842 L p
1 g
F P
s
P
p
.43925 .54566 m .43272 .52842 L .43637 .53997 L 1 g
F
P
p
.4376 .54387 m .45953 .52643 L .43857 .54693 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42608 .55303 m .42503 .51659 L .43308 .51889 L p
1 g
F P
s
P
p
.002 w
.43272 .52842 m .43346 .52734 L p
.43314 .51826 L 1 g
F P
s
P
p
.002 w
.43308 .51889 m .42503 .51659 L p
.4337 .51284 L 1 g
F P
s
P
p
.43314 .51826 m .43312 .51769 L .43308 .51889 L 1 g
F
P
p
.43314 .51826 m .43308 .51889 L .43272 .52842 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43408 .50918 L p
1 g
F P
s
P
p
.002 w
.42503 .51659 m .43681 .48264 L p
.43408 .50918 L 1 g
F P
s
P
p
.43195 .5136 m .43408 .50918 L .4337 .51284 L 1 g
F
P
p
.42503 .51659 m .43408 .50918 L .43195 .5136 L 1 g
F
P
p
.002 w
.43408 .50918 m .43485 .50826 L p
.43748 .50211 L 1 g
F P
s
P
p
.43346 .52734 m .43408 .50918 L .43314 .51826 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.4337 .51284 m .43422 .50888 L .47005 .49714 L 1 g
F
P
p
.43422 .50888 m .43564 .49805 L .44273 .4912 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44273 .4912 L p
1 g
F P
s
P
p
.002 w
.44273 .4912 m .44339 .4905 L p
.45024 .48393 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.45783 .47655 m .49055 .47034 L .44911 .48504 L 1 g
F
P
p
.002 w
.45783 .47655 m .45826 .47608 L p
.46507 .47309 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46711 L p
1 g
F P
s
P
p
.45826 .47608 m .47759 .46711 L .46507 .47309 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.43817 .47872 m .44369 .47142 L p
.49055 .47034 L 1 g
F P
s
P
p
.002 w
.47759 .46711 m .47786 .46667 L p
.49014 .46542 L 1 g
F P
s
P
p
.002 w
.49896 .46407 m .49055 .47034 L .48626 .46601 L p
1 g
F P
s
P
p
.49014 .46542 m .49414 .46501 L .48626 .46601 L 1 g
F
P
p
.49014 .46542 m .48626 .46601 L .47759 .46711 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4639 L p
1 g
F P
s
P
p
.002 w
.49055 .47034 m .49896 .46407 L p
.53603 .48108 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46714 L p
1 g
F P
s
P
p
.5 .4639 m .5175 .46643 L .53603 .48108 L 1 g
F
P
p
.5 .4634 m .52242 .46714 L .51045 .46541 L 1 g
F
P
p
.002 w
.53063 .47117 m .53603 .48108 L p
.5175 .46643 L 1 g
F P
s
P
p
.51182 .46194 m .52242 .46714 L .5175 .46643 L 1 g
F
P
p
.52242 .46714 m .53063 .47117 L .5175 .46643 L 1 g
F
P
p
.49896 .46407 m .5 .4639 L .53603 .48108 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4639 L p
1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .4634 L p
.51045 .46541 L 1 g
F P
s
P
p
.51045 .46541 m .52282 .46778 L .5 .4639 L 1 g
F
P
p
.002 w
.52242 .46714 m .52282 .46778 L p
.51045 .46541 L 1 g
F P
s
P
p
.5 .4639 m .51182 .46194 L .5175 .46643 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54241 .47681 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56622 .50953 L p
1 g
F P
s
P
p
.002 w
.57428 .50529 m .57069 .51927 L p
.56622 .50953 L 1 g
F P
s
P
p
.002 w
.56472 .50627 m .56599 .50614 L p
.56622 .50953 L 1 g
F P
s
P
p
.002 w
.56599 .50614 m .57428 .50529 L p
.56622 .50953 L 1 g
F P
s
P
p
.002 w
.56622 .50953 m .56515 .50826 L p
.56691 .51965 L 1 g
F P
s
P
p
.55661 .4905 m .56622 .50953 L .56472 .50627 L 1 g
F
P
p
.002 w
.56229 .50128 m .55805 .47241 L p
.56472 .50627 L 1 g
F P
s
P
p
.56283 .5024 m .56472 .50627 L .56374 .50414 L 1 g
F
P
p
.55661 .4905 m .56472 .50627 L .56283 .5024 L 1 g
F
P
p
.002 w
.57428 .50529 m .56472 .50627 L p
.55805 .47241 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55739 .49133 m .55661 .4905 L p
.56291 .50255 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.002 w
.5614 .49521 m .56229 .50128 L p
.55739 .49133 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55739 .49133 L p
1 g
F P
s
P
p
.56291 .50255 m .56713 .51061 L .55739 .49133 L 1 g
F
P
p
.54174 .47608 m .55739 .49133 L .55022 .48439 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53603 .48108 m .54369 .47806 L p
.56304 .50644 L 1 g
F P
s
P
p
.002 w
.53603 .48108 m .53063 .47117 L p
.54241 .47681 L 1 g
F P
s
P
p
.54174 .47608 m .55022 .48439 L .54369 .47806 L 1 g
F
P
p
.002 w
.54241 .47681 m .54174 .47608 L p
.54369 .47806 L 1 g
F P
s
P
p
.002 w
.54442 .47778 m .54369 .47806 L p
.54241 .47681 L 1 g
F P
s
P
p
.002 w
.54369 .47806 m .53603 .48108 L p
.54241 .47681 L 1 g
F P
s
P
p
.002 w
.54247 .47688 m .54241 .47681 L p
.54369 .47806 L 1 g
F P
s
P
p
.002 w
.54369 .47806 m .5497 .4757 L p
.55582 .48981 L 1 g
F P
s
P
p
.54369 .47806 m .55582 .48981 L .56304 .50644 L 1 g
F
P
p
.002 w
.56229 .50128 m .56304 .50644 L p
.5497 .4757 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54247 .47688 L p
1 g
F P
s
P
p
.55022 .48439 m .55834 .49233 L .54247 .47688 L 1 g
F
P
p
.002 w
.55739 .49133 m .55834 .49233 L p
.55022 .48439 L 1 g
F P
s
P
p
.002 w
.5497 .4757 m .55805 .47241 L .5614 .49521 L p
1 g
F P
s
P
p
.5497 .4757 m .5614 .49521 L .55739 .49133 L 1 g
F
P
p
.002 w
.56472 .50627 m .56304 .50644 L .56229 .50128 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56753 .52878 L p
1 g
F P
s
P
p
.002 w
.57069 .51927 m .56768 .53101 L p
.56757 .52945 L 1 g
F P
s
P
p
.56515 .50826 m .56753 .52878 L .56691 .51965 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .54731 L p
1 g
F P
s
P
p
.002 w
.56137 .56561 m .555 .5654 L p
.56271 .54586 L 1 g
F P
s
P
p
.002 w
.56601 .53752 m .56517 .5426 L p
.56271 .54586 L 1 g
F P
s
P
p
.002 w
.56517 .5426 m .56137 .56561 L p
.56271 .54586 L 1 g
F P
s
P
p
.002 w
.56162 .54731 m .56075 .54566 L p
.55501 .55607 L 1 g
F P
s
P
p
.002 w
.55069 .56527 m .54863 .56448 L p
.54937 .56351 L 1 g
F P
s
P
p
.002 w
.5578 .55239 m .55341 .56034 L p
.54937 .56351 L 1 g
F P
s
P
p
.002 w
.55341 .56034 m .55069 .56527 L p
.54937 .56351 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52013 .57849 m .54148 .56175 L p
.53925 .56989 L 1 g
F P
s
P
p
.53864 .57213 m .53169 .57452 L .53925 .56989 L 1 g
F
P
p
.53169 .57452 m .52013 .57849 L .53925 .56989 L 1 g
F
P
p
.54854 .56129 m .54 .56943 L .54047 .56914 L 1 g
F
P
p
.002 w
.55069 .56527 m .53421 .58834 L p
.53925 .56989 L 1 g
F P
s
P
p
.002 w
.5483 .56435 m .54863 .56448 L p
.53925 .56989 L 1 g
F P
s
P
p
.002 w
.54863 .56448 m .55069 .56527 L p
.54607 .56713 L 1 g
F P
s
P
p
.53925 .56989 m .54863 .56448 L .54607 .56713 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54942 .56366 L p
1 g
F P
s
P
p
.002 w
.54942 .56366 m .54998 .56518 L p
.55267 .5603 L 1 g
F P
s
P
p
.56075 .54566 m .54942 .56366 L .55267 .5603 L 1 g
F
P
p
.002 w
.54937 .56351 m .54854 .56129 L p
.53323 .57619 L 1 g
F P
s
P
p
.002 w
.54148 .56175 m .5483 .56435 L p
.53925 .56989 L 1 g
F P
s
P
p
.55501 .55607 m .5578 .55239 L .56162 .54731 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54863 .56448 m .54148 .56175 L p
.5578 .55239 L 1 g
F P
s
P
p
.002 w
.53323 .57619 m .54998 .56518 L .54942 .56366 L p
1 g
F P
s
P
p
.002 w
.54942 .56366 m .54937 .56351 L p
.5483 .56435 L 1 g
F P
s
P
p
.5483 .56435 m .53323 .57619 L .54942 .56366 L 1 g
F
P
p
.002 w
.5322 .57686 m .53323 .57619 L p
.54047 .56914 L 1 g
F P
s
P
p
.54 .56943 m .5322 .57686 L .54047 .56914 L 1 g
F
P
p
.55501 .55607 m .55496 .55615 L .5578 .55239 L 1 g
F
P
p
.56654 .52734 m .56162 .54731 L .56362 .54185 L 1 g
F
P
p
.002 w
.56474 .53877 m .56601 .53752 L .56364 .54181 L p
1 g
F P
s
P
p
.002 w
.56364 .54181 m .56601 .53752 L p
.555 .5654 L 1 g
F P
s
P
p
.56416 .54037 m .56228 .54855 L .56353 .54384 L 1 g
F
P
p
.56654 .52734 m .56362 .54185 L .56416 .54037 L 1 g
F
P
p
.56362 .54185 m .56228 .54855 L .56416 .54037 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.5659 .5349 m .56757 .52945 L .56601 .53752 L 1 g
F
P
p
.002 w
.56768 .53101 m .56601 .53752 L p
.56757 .52945 L 1 g
F P
s
P
p
.57029 .51839 m .57069 .51927 L .5659 .5349 L 1 g
F
P
p
.002 w
.56601 .53752 m .5658 .5353 L p
.5659 .5349 L 1 g
F P
s
P
p
.002 w
.5826 .55706 m .57239 .56277 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.59094 .54909 m .5826 .55706 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.57239 .56277 m .56137 .56561 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.59652 .53966 m .59094 .54909 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.59875 .52977 m .59652 .53966 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.59734 .52046 m .59875 .52977 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.56498 .53811 m .56601 .53752 L .56474 .53877 L p
1 g
F P
s
P
p
.002 w
.56753 .52878 m .56654 .52734 L p
.56411 .54064 L 1 g
F P
s
P
p
.002 w
.5651 .53776 m .56601 .53752 L .56498 .53811 L p
1 g
F P
s
P
p
.56411 .54064 m .56514 .53763 L .56753 .52878 L 1 g
F
P
p
.002 w
.56518 .53751 m .56601 .53752 L .5651 .53776 L p
1 g
F P
s
P
p
.56514 .53763 m .56518 .53751 L .56521 .53741 L 1 g
F
P
p
.56514 .53763 m .56521 .53741 L .56753 .52878 L 1 g
F
P
p
.56518 .53751 m .56528 .53717 L .56753 .52878 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.53137 .53708 m .53521 .52707 L .56525 .53726 L p
1 g
F P
s
P
p
.002 w
.56525 .53726 m .56601 .53752 L .56518 .53751 L p
1 g
F P
s
P
p
.002 w
.56518 .53751 m .53137 .53708 L p
.56525 .53726 L 1 g
F P
s
P
p
.56522 .53739 m .56547 .5365 L .56753 .52878 L 1 g
F
P
p
.002 w
.5658 .5353 m .56601 .53752 L .56547 .5365 L p
1 g
F P
s
P
p
.56547 .5365 m .56559 .53608 L .5658 .5353 L 1 g
F
P
p
.56547 .5365 m .5658 .5353 L .56753 .52878 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55198 .51084 m .56304 .50644 L .5658 .5353 L p
1 g
F P
s
P
p
.002 w
.56547 .5365 m .55198 .51084 L p
.5658 .5353 L 1 g
F P
s
P
p
.002 w
.53521 .52707 m .54234 .51798 L .56534 .53696 L p
1 g
F P
s
P
p
.002 w
.56534 .53696 m .56601 .53752 L .56525 .53726 L p
1 g
F P
s
P
p
.002 w
.56525 .53726 m .53521 .52707 L p
.56534 .53696 L 1 g
F P
s
P
p
.56518 .53751 m .56522 .53739 L .56528 .53717 L 1 g
F
P
p
.002 w
.56547 .5365 m .56601 .53752 L .56534 .53696 L p
1 g
F P
s
P
p
.56522 .53739 m .56531 .53714 L .56559 .53608 L 1 g
F
P
p
.002 w
.54234 .51798 m .55198 .51084 L .56547 .5365 L p
1 g
F P
s
P
p
.002 w
.56534 .53696 m .54234 .51798 L p
.56547 .5365 L 1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.53122 .54688 m .53137 .53708 L .56518 .53751 L p
1 g
F P
s
P
p
.002 w
.5651 .53776 m .53122 .54688 L p
.56518 .53751 L 1 g
F P
s
P
p
.5651 .53776 m .56353 .54384 L .56531 .53714 L 1 g
F
P
p
.56411 .54064 m .56405 .54096 L .5651 .53776 L 1 g
F
P
p
.56405 .54096 m .56353 .54384 L .5651 .53776 L 1 g
F
P
p
.002 w
.53473 .55541 m .53122 .54688 L .5651 .53776 L p
1 g
F P
s
P
p
.002 w
.56498 .53811 m .53473 .55541 L p
.5651 .53776 L 1 g
F P
s
P
p
.002 w
.54148 .56175 m .53473 .55541 L .56498 .53811 L p
1 g
F P
s
P
p
.002 w
.56474 .53877 m .54148 .56175 L p
.56498 .53811 L 1 g
F P
s
P
p
.002 w
.59241 .51274 m .59734 .52046 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.58444 .50748 m .59241 .51274 L .56601 .53752 L closepath p
1 g
F P
s
P
p
.002 w
.57428 .50529 m .58444 .50748 L .5679 .53443 L p
1 g
F P
s
P
p
.002 w
.5679 .53443 m .56601 .53752 L .56768 .53101 L p
1 g
F P
s
P
p
.002 w
.56768 .53101 m .57428 .50529 L p
.5679 .53443 L 1 g
F P
s
P
p
.56472 .50627 m .56622 .50953 L .5659 .5349 L 1 g
F
P
p
.56622 .50953 m .57029 .51839 L .56753 .52878 L 1 g
F
P
p
.56622 .50953 m .56753 .52878 L .5659 .5349 L 1 g
F
P
p
.002 w
.56753 .52878 m .56754 .52879 L p
.56691 .51965 L 1 g
F P
s
P
p
.002 w
.56754 .52879 m .56854 .53025 L p
.56697 .52004 L 1 g
F P
s
P
p
.56691 .51965 m .56754 .52879 L .56697 .52004 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56803 .52951 L p
1 g
F P
s
P
p
.002 w
.56803 .52951 m .56753 .52878 L p
.56586 .53563 L 1 g
F P
s
P
p
.56586 .53563 m .56257 .5491 L .56803 .52951 L 1 g
F
P
p
.56353 .54384 m .56257 .5491 L .56753 .52878 L 1 g
F
P
p
.002 w
.56304 .50644 m .56472 .50627 L p
.5659 .5349 L 1 g
F P
s
P
p
.002 w
.5658 .5353 m .56304 .50644 L p
.5659 .5349 L 1 g
F P
s
P
p
.002 w
.54148 .56175 m .56474 .53877 L p
.5578 .55239 L 1 g
F P
s
P
p
.002 w
.56364 .54181 m .5578 .55239 L p
.56474 .53877 L 1 g
F P
s
P
p
.002 w
.555 .5654 m .55069 .56527 L .56364 .54181 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56162 .54731 L p
1 g
F P
s
P
p
.55496 .55615 m .54998 .56518 L .56162 .54731 L 1 g
F
P
p
.002 w
.56162 .54731 m .56228 .54855 L p
.56362 .54185 L 1 g
F P
s
P
p
.002 w
.56228 .54855 m .56257 .5491 L p
.56353 .54384 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56622 .50953 L p
1 g
F P
s
P
p
.56691 .51965 m .56854 .53025 L .56622 .50953 L 1 g
F
P
p
.002 w
.56622 .50953 m .56713 .51061 L p
.56374 .50414 L 1 g
F P
s
P
p
.002 w
.54241 .47681 m .54264 .47706 L p
.53761 .47451 L 1 g
F P
s
P
p
.52214 .46667 m .54241 .47681 L .53761 .47451 L 1 g
F
P
p
.002 w
.55805 .47241 m .54442 .47778 L p
.51873 .44933 L 1 g
F P
s
P
p
.52214 .46667 m .54264 .47706 L .53443 .47303 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53063 .47117 m .51873 .44933 L p
.54442 .47778 L 1 g
F P
s
P
p
.002 w
.52445 .45983 m .53063 .47117 L p
.51182 .46194 L 1 g
F P
s
P
p
.002 w
.54264 .47706 m .54302 .47747 L p
.53443 .47303 L 1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .46442 L p
.49199 .46523 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4639 L .49199 .46523 L 1 g
F
P
p
.002 w
.49896 .46407 m .51873 .44933 L .52445 .45983 L p
1 g
F P
s
P
p
.002 w
.51873 .44933 m .49896 .46407 L p
.4644 .444 L 1 g
F P
s
P
p
.002 w
.48626 .46601 m .4644 .444 L p
.49896 .46407 L 1 g
F P
s
P
p
.002 w
.44369 .47142 m .4644 .444 L .48626 .46601 L p
1 g
F P
s
P
p
.002 w
.48626 .46601 m .49055 .47034 L p
.44369 .47142 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46711 L p
1 g
F P
s
P
p
.49414 .46501 m .5 .46442 L .47759 .46711 L 1 g
F
P
p
.002 w
.47759 .46711 m .47718 .46778 L p
.46507 .47309 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.43485 .50826 m .44273 .4912 L .43748 .50211 L 1 g
F
P
p
.43422 .50888 m .44273 .4912 L .47005 .49714 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45734 .47708 L p
1 g
F P
s
P
p
.44339 .4905 m .45734 .47708 L .45125 .48297 L 1 g
F
P
p
.45024 .48393 m .44911 .48504 L .44273 .4912 L 1 g
F
P
p
.002 w
.44644 .4835 m .44911 .48504 L p
.44273 .4912 L 1 g
F P
s
P
p
.002 w
.44911 .48504 m .47005 .49714 L p
.44273 .4912 L 1 g
F P
s
P
p
.002 w
.45734 .47708 m .45698 .47747 L p
.45125 .48297 L 1 g
F P
s
P
p
.43817 .47872 m .45902 .47539 L .45783 .47655 L 1 g
F
P
p
.002 w
.44911 .48504 m .44501 .48267 L p
.45783 .47655 L 1 g
F P
s
P
p
.002 w
.44501 .48267 m .43817 .47872 L p
.45783 .47655 L 1 g
F P
s
P
p
.45902 .47539 m .46089 .47509 L .45783 .47655 L 1 g
F
P
p
.46089 .47509 m .49055 .47034 L .45783 .47655 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45783 .47655 L p
1 g
F P
s
P
p
.46507 .47309 m .47718 .46778 L .45783 .47655 L 1 g
F
P
p
.45024 .48393 m .45125 .48297 L .44911 .48504 L 1 g
F
P
p
.002 w
.49055 .47034 m .47005 .49714 L .44911 .48504 L p
1 g
F P
s
P
p
.002 w
.44273 .4912 m .44166 .49233 L p
.43748 .50211 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44273 .4912 L p
1 g
F P
s
P
p
.45125 .48297 m .45698 .47747 L .44273 .4912 L 1 g
F
P
p
.002 w
.43817 .47872 m .44644 .4835 L p
.44273 .4912 L 1 g
F P
s
P
p
.43564 .49805 m .43817 .47872 L .44273 .4912 L 1 g
F
P
p
.002 w
.43681 .48264 m .43817 .47872 L p
.4337 .51284 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43408 .50918 L p
1 g
F P
s
P
p
.43748 .50211 m .44166 .49233 L .43408 .50918 L 1 g
F
P
p
.002 w
.43408 .50918 m .43287 .51061 L p
.43314 .51826 L 1 g
F P
s
P
p
.002 w
.47005 .49714 m .45953 .52643 L .43308 .51889 L p
1 g
F P
s
P
p
.4337 .51284 m .47005 .49714 L .43308 .51889 L 1 g
F
P
p
.002 w
.43308 .51889 m .45953 .52643 L p
.43198 .54834 L 1 g
F P
s
P
p
.42608 .55303 m .43308 .51889 L .43198 .54834 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43272 .52842 L p
1 g
F P
s
P
p
.43312 .51769 m .43287 .51061 L .43272 .52842 L 1 g
F
P
p
.002 w
.43272 .52842 m .43146 .53025 L p
.43637 .53997 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43857 .54693 L p
1 g
F P
s
P
p
.43637 .53997 m .43146 .53025 L .43857 .54693 L 1 g
F
P
p
.002 w
.43857 .54693 m .43743 .5491 L p
.44397 .55478 L 1 g
F P
s
P
p
.002 w
.45953 .52643 m .45994 .55476 L .44337 .55391 L p
1 g
F P
s
P
p
.002 w
.44337 .55391 m .45994 .55476 L p
.45308 .56512 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45095 .56266 L p
1 g
F P
s
P
p
.4446 .55533 m .43743 .5491 L .45095 .56266 L 1 g
F
P
p
.002 w
.45095 .56266 m .45002 .56518 L p
.46045 .56934 L 1 g
F P
s
P
p
.002 w
.46918 .57523 m .45994 .55476 L p
.47321 .57648 L 1 g
F P
s
P
p
.47084 .57593 m .46918 .57523 L .46809 .57553 L 1 g
F
P
p
.002 w
.46824 .57483 m .46822 .57494 L p
.46918 .57523 L 1 g
F P
s
P
p
.002 w
.46822 .57494 m .46809 .57553 L p
.46918 .57523 L 1 g
F P
s
P
p
.472 .5761 m .46918 .57523 L .47084 .57593 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.49542 .5527 m .50263 .56938 L .47616 .57738 L p
1 g
F P
s
P
p
.47321 .57648 m .49542 .5527 L .47616 .57738 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46824 .57483 L p
1 g
F P
s
P
p
.46045 .56934 m .45002 .56518 L .46824 .57483 L 1 g
F
P
p
.002 w
.47087 .57898 m .44059 .58398 L p
.45137 .5677 L 1 g
F P
s
P
p
.002 w
.47616 .57738 m .50263 .56938 L p
.48732 .57995 L 1 g
F P
s
P
p
.002 w
.46809 .57553 m .4678 .57686 L p
.47727 .57764 L 1 g
F P
s
P
p
.002 w
.47195 .57994 m .47087 .57898 L p
.49776 .58056 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58036 L p
1 g
F P
s
P
p
.47727 .57764 m .4678 .57686 L .48908 .58036 L 1 g
F
P
p
.002 w
.48908 .58036 m .48889 .583 L p
.50071 .58064 L 1 g
F P
s
P
p
.002 w
.50263 .56938 m .51453 .58024 L p
.49776 .58056 L 1 g
F P
s
P
p
.002 w
.51453 .58024 m .51535 .58099 L p
.51096 .58088 L 1 g
F P
s
P
p
.49776 .58056 m .51453 .58024 L .51096 .58088 L 1 g
F
P
p
.51946 .57872 m .51756 .57969 L .53169 .57452 L 1 g
F
P
p
.51756 .57969 m .51111 .583 L .52038 .57918 L 1 g
F
P
p
.51756 .57969 m .52038 .57918 L .53169 .57452 L 1 g
F
P
p
.002 w
.53169 .57452 m .5322 .57686 L p
.54 .56943 L 1 g
F P
s
P
p
.002 w
.53473 .55541 m .54148 .56175 L .52013 .57849 L p
1 g
F P
s
P
p
.51782 .57921 m .53473 .55541 L .52013 .57849 L 1 g
F
P
p
.51647 .57963 m .51453 .58024 L .51559 .58004 L 1 g
F
P
p
.51946 .57872 m .51559 .58004 L .51756 .57969 L 1 g
F
P
p
.002 w
.51096 .58088 m .51111 .583 L p
.51756 .57969 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58088 L p
1 g
F P
s
P
p
.50071 .58064 m .48889 .583 L .51096 .58088 L 1 g
F
P
p
.004 w
.5 .43051 m
.51115 .44859 L
s
P
p
.004 w
.53037 .47974 m
.55031 .51207 L
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.6281 .37389 m .66192 .39926 L .65126 .4277 L p
1 g
F P
s
P
p
.002 w
.66192 .39926 m .6281 .37389 L .62963 .34333 L p
1 g
F P
s
P
p
.002 w
.49986 .27965 m .43573 .30363 L .42413 .28459 L p
1 g
F P
s
P
p
.002 w
.38188 .43855 m .36518 .48989 L .34183 .47411 L p
1 g
F P
s
P
p
.002 w
.34183 .47411 m .35946 .41834 L .38188 .43855 L p
1 g
F P
s
P
p
.002 w
.59094 .54909 m .59652 .53966 L .62338 .5385 L p
1 g
F P
s
P
p
.002 w
.62791 .51919 m .62338 .5385 L .59652 .53966 L p
1 g
F P
s
P
p
.002 w
.39685 .36707 m .35946 .41834 L .34185 .39904 L p
1 g
F P
s
P
p
.002 w
.34185 .39904 m .38065 .34532 L .39685 .36707 L p
1 g
F P
s
P
p
.002 w
.42503 .51659 m .42608 .55303 L .39502 .54767 L p
1 g
F P
s
P
p
.002 w
.39502 .54767 m .39321 .50424 L .42503 .51659 L p
1 g
F P
s
P
p
.002 w
.62791 .51919 m .62541 .50086 L .64926 .47947 L p
1 g
F P
s
P
p
.002 w
.63579 .45679 m .64926 .47947 L .62541 .50086 L p
1 g
F P
s
P
p
.002 w
.64926 .47947 m .63579 .45679 L .65126 .4277 L p
1 g
F P
s
P
p
.002 w
.5793 .32934 m .62963 .34333 L .6281 .37389 L p
1 g
F P
s
P
p
.002 w
.62963 .34333 m .5793 .32934 L .57288 .30047 L p
1 g
F P
s
P
p
.002 w
.59652 .53966 m .59875 .52977 L .62791 .51919 L p
1 g
F P
s
P
p
.002 w
.62541 .50086 m .62791 .51919 L .59875 .52977 L p
1 g
F P
s
P
p
.002 w
.62261 .4068 m .65126 .4277 L .63579 .45679 L p
1 g
F P
s
P
p
.002 w
.65126 .4277 m .62261 .4068 L .6281 .37389 L p
1 g
F P
s
P
p
.002 w
.57288 .30047 m .51107 .30407 L .49986 .27965 L p
1 g
F P
s
P
p
.002 w
.43573 .30363 m .49986 .27965 L .51107 .30407 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51107 .30407 m .57288 .30047 L .5793 .32934 L p
1 g
F P
s
P
p
.002 w
.40841 .45894 m .39321 .50424 L .36518 .48989 L p
1 g
F P
s
P
p
.002 w
.36518 .48989 m .38188 .43855 L .40841 .45894 L p
1 g
F P
s
P
p
.002 w
.44968 .32718 m .39685 .36707 L .38065 .34532 L p
1 g
F P
s
P
p
.002 w
.38065 .34532 m .43573 .30363 L .44968 .32718 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59875 .52977 m .59734 .52046 L .62541 .50086 L p
1 g
F P
s
P
p
.002 w
.61595 .48549 m .62541 .50086 L .59734 .52046 L p
1 g
F P
s
P
p
.002 w
.62541 .50086 m .61595 .48549 L .63579 .45679 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.51107 .30407 m .44968 .32718 L .43573 .30363 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41666 .39135 m .38188 .43855 L .35946 .41834 L p
1 g
F P
s
P
p
.002 w
.35946 .41834 m .39685 .36707 L .41666 .39135 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58343 .36198 m .6281 .37389 L .62261 .4068 L p
1 g
F P
s
P
p
.002 w
.6281 .37389 m .58343 .36198 L .5793 .32934 L p
1 g
F P
s
P
p
.002 w
.53122 .54688 m .53473 .55541 L .50263 .56938 L p
1 g
F P
s
P
p
.002 w
.50263 .56938 m .49542 .5527 L .53122 .54688 L p
1 g
F P
s
P
p
.002 w
.61328 .44088 m .63579 .45679 L .61595 .48549 L p
1 g
F P
s
P
p
.002 w
.63579 .45679 m .61328 .44088 L .62261 .4068 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.59734 .52046 m .59241 .51274 L .61595 .48549 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.49543 .53334 m .49542 .5527 L .45994 .55476 L p
1 g
F P
s
P
p
.002 w
.45994 .55476 m .45953 .52643 L .49543 .53334 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43817 .47872 m .42503 .51659 L .39321 .50424 L p
1 g
F P
s
P
p
.002 w
.39321 .50424 m .40841 .45894 L .43817 .47872 L p
1 g
F P
s
P
p
.002 w
.52223 .33303 m .5793 .32934 L .58343 .36198 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.54359 .34313 L
s
P
p
.002 w
.5793 .32934 m .52223 .33303 L .51107 .30407 L p
1 g
F P
s
P
p
.004 w
.55479 .32068 m
.57321 .28375 L
s
P
p
.002 w
.6004 .47486 m .61595 .48549 L .59241 .51274 L p
1 g
F P
s
P
p
.002 w
.61595 .48549 m .6004 .47486 L .61328 .44088 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.44968 .32718 m .51107 .30407 L .52223 .33303 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58503 .39723 m .62261 .4068 L .61328 .44088 L p
1 g
F P
s
P
p
.002 w
.62261 .4068 m .58503 .39723 L .58343 .36198 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59241 .51274 m .58444 .50748 L .6004 .47486 L p
1 g
F P
s
P
p
.002 w
.53137 .53708 m .53122 .54688 L .49542 .5527 L p
1 g
F P
s
P
p
.002 w
.49542 .5527 m .49543 .53334 L .53137 .53708 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46554 .35455 m .41666 .39135 L .39685 .36707 L p
1 g
F P
s
P
p
.002 w
.39685 .36707 m .44968 .32718 L .46554 .35455 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.43945 .41732 m .40841 .45894 L .38188 .43855 L p
1 g
F P
s
P
p
.002 w
.38188 .43855 m .41666 .39135 L .43945 .41732 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.52223 .33303 m .46554 .35455 L .44968 .32718 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.58444 .50748 m .57428 .50529 L .58037 .47029 L p
1 g
F P
s
P
p
.002 w
.58037 .47029 m .6004 .47486 L .58444 .50748 L p
1 g
F P
s
P
p
.002 w
.584 .4338 m .61328 .44088 L .6004 .47486 L p
1 g
F P
s
P
p
.002 w
.61328 .44088 m .584 .4338 L .58503 .39723 L p
1 g
F P
s
P
p
.002 w
.53521 .52707 m .53137 .53708 L .49543 .53334 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.6004 .47486 m .58037 .47029 L .584 .4338 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53291 .3656 m .58343 .36198 L .58503 .39723 L p
1 g
F P
s
P
p
.002 w
.58343 .36198 m .53291 .3656 L .52223 .33303 L p
1 g
F P
s
P
p
.004 w
.54539 .33952 m
.55479 .32068 L
s
P
p
.004 w
.54502 .34026 m
.54539 .33952 L
s
P
p
.002 w
.55805 .47241 m .58037 .47029 L .57428 .50529 L p
1 g
F P
s
P
p
.002 w
.50282 .51346 m .49543 .53334 L .45953 .52643 L p
1 g
F P
s
P
p
.002 w
.45953 .52643 m .47005 .49714 L .50282 .51346 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49543 .53334 m .50282 .51346 L .53521 .52707 L p
1 g
F P
s
P
p
.002 w
.54234 .51798 m .53521 .52707 L .50282 .51346 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46554 .35455 m .52223 .33303 L .53291 .3656 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56304 .50644 m .55198 .51084 L .53603 .48108 L p
1 g
F P
s
P
p
.002 w
.55198 .51084 m .54234 .51798 L .51687 .49532 L p
1 g
F P
s
P
p
.002 w
.50282 .51346 m .51687 .49532 L .54234 .51798 L p
1 g
F P
s
P
p
.002 w
.4644 .444 m .43817 .47872 L .40841 .45894 L p
1 g
F P
s
P
p
.002 w
.40841 .45894 m .43945 .41732 L .4644 .444 L p
1 g
F P
s
P
p
.002 w
.51687 .49532 m .53603 .48108 L .55198 .51084 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.48278 .3848 m .43945 .41732 L .41666 .39135 L p
1 g
F P
s
P
p
.002 w
.41666 .39135 m .46554 .35455 L .48278 .3848 L p
1 g
F P
s
P
p
.002 w
.5427 .40059 m .58503 .39723 L .584 .4338 L p
1 g
F P
s
P
p
.002 w
.58503 .39723 m .5427 .40059 L .53291 .3656 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.58037 .47029 m .55805 .47241 L .55119 .43666 L p
1 g
F P
s
P
p
.002 w
.55119 .43666 m .584 .4338 L .58037 .47029 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.584 .4338 m .55119 .43666 L .5427 .40059 L p
1 g
F P
s
P
p
.002 w
.53291 .3656 m .48278 .3848 L .46554 .35455 L p
1 g
F P
s
P
p
.002 w
.51687 .49532 m .50282 .51346 L .47005 .49714 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.47005 .49714 m .49055 .47034 L .51687 .49532 L p
1 g
F P
s
P
p
.002 w
.48278 .3848 m .53291 .3656 L .5427 .40059 L p
1 g
F P
s
P
p
.002 w
.51873 .44933 m .55119 .43666 L .55805 .47241 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.53603 .48108 m .51687 .49532 L .49055 .47034 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.50074 .41681 m .4644 .444 L .43945 .41732 L p
1 g
F P
s
P
p
.002 w
.43945 .41732 m .48278 .3848 L .50074 .41681 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50074 .41681 m .5427 .40059 L .55119 .43666 L p
1 g
F P
s
P
p
.002 w
.5427 .40059 m .50074 .41681 L .48278 .3848 L p
1 g
F P
s
P
p
.002 w
.55119 .43666 m .51873 .44933 L .50074 .41681 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.4644 .444 m .50074 .41681 L .51873 .44933 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.58821 .57351 m
.59341 .58194 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .57321 .28375 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60538 .60133 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0705426)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0705426)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48326 .45499 m .52299 .44155 L .5106 .4158 L p
1 g
F P
s
P
p
.002 w
.5106 .4158 m .47745 .427 L .48326 .45499 L p
1 g
F P
s
P
p
.002 w
.5395 .39689 m .5106 .4158 L .52299 .44155 L p
1 g
F P
s
P
p
.002 w
.47745 .427 m .5106 .4158 L .49793 .39036 L p
1 g
F P
s
P
p
.002 w
.5106 .4158 m .5395 .39689 L .52031 .37559 L p
1 g
F P
s
P
p
.002 w
.52031 .37559 m .49793 .39036 L .5106 .4158 L p
1 g
F P
s
P
p
.002 w
.44215 .4581 m .48326 .45499 L .47745 .427 L p
1 g
F P
s
P
p
.002 w
.47745 .427 m .44316 .42944 L .44215 .4581 L p
1 g
F P
s
P
p
.002 w
.44316 .42944 m .47745 .427 L .47218 .39905 L p
1 g
F P
s
P
p
.002 w
.49793 .39036 m .47218 .39905 L .47745 .427 L p
1 g
F P
s
P
p
.002 w
.4895 .48252 m .53488 .46715 L .52299 .44155 L p
1 g
F P
s
P
p
.002 w
.52299 .44155 m .48326 .45499 L .4895 .48252 L p
1 g
F P
s
P
p
.002 w
.55773 .41901 m .52299 .44155 L .53488 .46715 L p
1 g
F P
s
P
p
.002 w
.52299 .44155 m .55773 .41901 L .5395 .39689 L p
1 g
F P
s
P
p
.002 w
.44254 .48627 m .4895 .48252 L .48326 .45499 L p
1 g
F P
s
P
p
.002 w
.48326 .45499 m .44215 .4581 L .44254 .48627 L p
1 g
F P
s
P
p
.002 w
.47218 .39905 m .49793 .39036 L .48521 .36568 L p
1 g
F P
s
P
p
.002 w
.49793 .39036 m .52031 .37559 L .50052 .3555 L p
1 g
F P
s
P
p
.002 w
.50052 .3555 m .48521 .36568 L .49793 .39036 L p
1 g
F P
s
P
p
.002 w
.47218 .39905 m .44555 .40083 L .44316 .42944 L p
1 g
F P
s
P
p
.002 w
.44555 .40083 m .47218 .39905 L .46754 .37164 L p
1 g
F P
s
P
p
.002 w
.48521 .36568 m .46754 .37164 L .47218 .39905 L p
1 g
F P
s
P
p
.002 w
.49607 .50907 m .54604 .49213 L .53488 .46715 L p
1 g
F P
s
P
p
.002 w
.53488 .46715 m .4895 .48252 L .49607 .50907 L p
1 g
F P
s
P
p
.002 w
.57466 .44154 m .53488 .46715 L .54604 .49213 L p
1 g
F P
s
P
p
.002 w
.53488 .46715 m .57466 .44154 L .55773 .41901 L p
1 g
F P
s
P
p
.002 w
.56133 .37196 m .5395 .39689 L .55773 .41901 L p
1 g
F P
s
P
p
.002 w
.5395 .39689 m .56133 .37196 L .53708 .35613 L p
1 g
F P
s
P
p
.002 w
.53708 .35613 m .52031 .37559 L .5395 .39689 L p
1 g
F P
s
P
p
.002 w
.44436 .51342 m .49607 .50907 L .4895 .48252 L p
1 g
F P
s
P
p
.002 w
.4895 .48252 m .44254 .48627 L .44436 .51342 L p
1 g
F P
s
P
p
.002 w
.40344 .45038 m .44215 .4581 L .44316 .42944 L p
1 g
F P
s
P
p
.002 w
.44316 .42944 m .41097 .42274 L .40344 .45038 L p
1 g
F P
s
P
p
.002 w
.41097 .42274 m .44316 .42944 L .44555 .40083 L p
1 g
F P
s
P
p
.002 w
.52031 .37559 m .53708 .35613 L .51189 .34209 L p
1 g
F P
s
P
p
.002 w
.51189 .34209 m .50052 .3555 L .52031 .37559 L p
1 g
F P
s
P
p
.002 w
.58418 .3893 m .55773 .41901 L .57466 .44154 L p
1 g
F P
s
P
p
.002 w
.55773 .41901 m .58418 .3893 L .56133 .37196 L p
1 g
F P
s
P
p
.002 w
.44555 .40083 m .42065 .39542 L .41097 .42274 L p
1 g
F P
s
P
p
.002 w
.42065 .39542 m .44555 .40083 L .44929 .37278 L p
1 g
F P
s
P
p
.002 w
.46754 .37164 m .44929 .37278 L .44555 .40083 L p
1 g
F P
s
P
p
.002 w
.39821 .47782 m .44254 .48627 L .44215 .4581 L p
1 g
F P
s
P
p
.002 w
.44215 .4581 m .40344 .45038 L .39821 .47782 L p
1 g
F P
s
P
p
.002 w
.46754 .37164 m .48521 .36568 L .47267 .34224 L p
1 g
F P
s
P
p
.002 w
.48521 .36568 m .50052 .3555 L .48047 .33701 L p
1 g
F P
s
P
p
.002 w
.48047 .33701 m .47267 .34224 L .48521 .36568 L p
1 g
F P
s
P
p
.002 w
.44929 .37278 m .46754 .37164 L .46363 .34528 L p
1 g
F P
s
P
p
.002 w
.47267 .34224 m .46363 .34528 L .46754 .37164 L p
1 g
F P
s
P
p
.002 w
.50052 .3555 m .51189 .34209 L .48621 .33013 L p
1 g
F P
s
P
p
.002 w
.48621 .33013 m .48047 .33701 L .50052 .3555 L p
1 g
F P
s
P
p
.002 w
.54604 .49213 m .58996 .46408 L .57466 .44154 L p
1 g
F P
s
P
p
.002 w
.60516 .40781 m .57466 .44154 L .58996 .46408 L p
1 g
F P
s
P
p
.002 w
.57466 .44154 m .60516 .40781 L .58418 .3893 L p
1 g
F P
s
P
p
.002 w
.44929 .37278 m .43229 .36893 L .42065 .39542 L p
1 g
F P
s
P
p
.002 w
.43229 .36893 m .44929 .37278 L .45431 .34582 L p
1 g
F P
s
P
p
.002 w
.46363 .34528 m .45431 .34582 L .44929 .37278 L p
1 g
F P
s
P
p
.002 w
.50284 .53413 m .55625 .51601 L .54604 .49213 L p
1 g
F P
s
P
p
.002 w
.54604 .49213 m .49607 .50907 L .50284 .53413 L p
1 g
F P
s
P
p
.002 w
.58996 .46408 m .54604 .49213 L .55625 .51601 L p
1 g
F P
s
P
p
.002 w
.44759 .539 m .50284 .53413 L .49607 .50907 L p
1 g
F P
s
P
p
.002 w
.49607 .50907 m .44436 .51342 L .44759 .539 L p
1 g
F P
s
P
p
.002 w
.39545 .5045 m .44436 .51342 L .44254 .48627 L p
1 g
F P
s
P
p
.002 w
.44254 .48627 m .39821 .47782 L .39545 .5045 L p
1 g
F P
s
P
p
.002 w
.54645 .33384 m .53708 .35613 L .56133 .37196 L p
1 g
F P
s
P
p
.002 w
.53708 .35613 m .54645 .33384 L .5181 .3268 L p
1 g
F P
s
P
p
.002 w
.5181 .3268 m .51189 .34209 L .53708 .35613 L p
1 g
F P
s
P
p
.002 w
.57378 .3433 m .56133 .37196 L .58418 .3893 L p
1 g
F P
s
P
p
.002 w
.56133 .37196 m .57378 .3433 L .54645 .33384 L p
1 g
F P
s
P
p
.002 w
.38412 .40729 m .41097 .42274 L .42065 .39542 L p
1 g
F P
s
P
p
.002 w
.42065 .39542 m .40003 .38321 L .38412 .40729 L p
1 g
F P
s
P
p
.002 w
.40003 .38321 m .42065 .39542 L .43229 .36893 L p
1 g
F P
s
P
p
.002 w
.51189 .34209 m .5181 .3268 L .48928 .32233 L p
1 g
F P
s
P
p
.002 w
.48928 .32233 m .48621 .33013 L .51189 .34209 L p
1 g
F P
s
P
p
.002 w
.37094 .43221 m .40344 .45038 L .41097 .42274 L p
1 g
F P
s
P
p
.002 w
.41097 .42274 m .38412 .40729 L .37094 .43221 L p
1 g
F P
s
P
p
.002 w
.43229 .36893 m .41832 .36043 L .40003 .38321 L p
1 g
F P
s
P
p
.002 w
.41832 .36043 m .43229 .36893 L .44567 .3438 L p
1 g
F P
s
P
p
.002 w
.45431 .34582 m .44567 .3438 L .43229 .36893 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .46363 .34528 L .47267 .34224 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .47267 .34224 L .48047 .33701 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .45431 .34582 L .46363 .34528 L closepath p
1 g
F P
s
P
p
.002 w
.59954 .35502 m .58418 .3893 L .60516 .40781 L p
1 g
F P
s
P
p
.002 w
.58418 .3893 m .59954 .35502 L .57378 .3433 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .48047 .33701 L .48621 .33013 L closepath p
1 g
F P
s
P
p
.002 w
.55625 .51601 m .60331 .48619 L .58996 .46408 L p
1 g
F P
s
P
p
.002 w
.62384 .42718 m .58996 .46408 L .60331 .48619 L p
1 g
F P
s
P
p
.002 w
.58996 .46408 m .62384 .42718 L .60516 .40781 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .44567 .3438 L .45431 .34582 L closepath p
1 g
F P
s
P
p
.002 w
.36081 .45747 m .39821 .47782 L .40344 .45038 L p
1 g
F P
s
P
p
.002 w
.40344 .45038 m .37094 .43221 L .36081 .45747 L p
1 g
F P
s
P
p
.002 w
.39527 .52987 m .44759 .539 L .44436 .51342 L p
1 g
F P
s
P
p
.002 w
.44436 .51342 m .39545 .5045 L .39527 .52987 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .48621 .33013 L .48928 .32233 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3438 m .43863 .33939 L .41832 .36043 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .43863 .33939 L .44567 .3438 L closepath p
1 g
F P
s
P
p
.002 w
.50969 .55717 m .5653 .53829 L .55625 .51601 L p
1 g
F P
s
P
p
.002 w
.55625 .51601 m .50284 .53413 L .50969 .55717 L p
1 g
F P
s
P
p
.002 w
.60331 .48619 m .55625 .51601 L .5653 .53829 L p
1 g
F P
s
P
p
.002 w
.45221 .56246 m .50969 .55717 L .50284 .53413 L p
1 g
F P
s
P
p
.002 w
.50284 .53413 m .44759 .539 L .45221 .56246 L p
1 g
F P
s
P
p
.002 w
.51839 .31119 m .5181 .3268 L .54645 .33384 L p
1 g
F P
s
P
p
.002 w
.5181 .3268 m .51839 .31119 L .48931 .31441 L p
1 g
F P
s
P
p
.002 w
.48931 .31441 m .48928 .32233 L .5181 .3268 L p
1 g
F P
s
P
p
.002 w
.54723 .31093 m .54645 .33384 L .57378 .3433 L p
1 g
F P
s
P
p
.002 w
.54645 .33384 m .54723 .31093 L .51839 .31119 L p
1 g
F P
s
P
p
.002 w
.62317 .36882 m .60516 .40781 L .62384 .42718 L p
1 g
F P
s
P
p
.002 w
.60516 .40781 m .62317 .36882 L .59954 .35502 L p
1 g
F P
s
P
p
.002 w
.38596 .36527 m .40003 .38321 L .41832 .36043 L p
1 g
F P
s
P
p
.002 w
.41832 .36043 m .40892 .34807 L .38596 .36527 L p
1 g
F P
s
P
p
.002 w
.40892 .34807 m .41832 .36043 L .43863 .33939 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .48928 .32233 L .48931 .31441 L closepath p
1 g
F P
s
P
p
.002 w
.43863 .33939 m .43396 .33305 L .40892 .34807 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .43396 .33305 L .43863 .33939 L closepath p
1 g
F P
s
P
p
.002 w
.36557 .38434 m .38412 .40729 L .40003 .38321 L p
1 g
F P
s
P
p
.002 w
.40003 .38321 m .38596 .36527 L .36557 .38434 L p
1 g
F P
s
P
p
.002 w
.35403 .48254 m .39545 .5045 L .39821 .47782 L p
1 g
F P
s
P
p
.002 w
.39821 .47782 m .36081 .45747 L .35403 .48254 L p
1 g
F P
s
P
p
.002 w
.57521 .31367 m .57378 .3433 L .59954 .35502 L p
1 g
F P
s
P
p
.002 w
.57378 .3433 m .57521 .31367 L .54723 .31093 L p
1 g
F P
s
P
p
.002 w
.48627 .30724 m .48931 .31441 L .51839 .31119 L p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .48931 .31441 L .48627 .30724 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .44491 .30344 L .43796 .30977 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .43796 .30977 L .43357 .31739 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .43357 .31739 L .4322 .32545 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .4322 .32545 L .43396 .33305 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .46319 .29729 L .45364 .29911 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .45364 .29911 L .44491 .30344 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .48627 .30724 L .48045 .30161 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .48045 .30161 L .47247 .29816 L closepath p
1 g
F P
s
P
p
.002 w
.46055 .32051 m .47247 .29816 L .46319 .29729 L closepath p
1 g
F P
s
P
p
.002 w
.5653 .53829 m .61437 .50742 L .60331 .48619 L p
1 g
F P
s
P
p
.002 w
.63978 .44702 m .60331 .48619 L .61437 .50742 L p
1 g
F P
s
P
p
.002 w
.60331 .48619 m .63978 .44702 L .62384 .42718 L p
1 g
F P
s
P
p
.002 w
.40521 .33308 m .40892 .34807 L .43396 .33305 L p
1 g
F P
s
P
p
.002 w
.43396 .33305 m .4322 .32545 L .40521 .33308 L p
1 g
F P
s
P
p
.002 w
.34825 .40492 m .37094 .43221 L .38412 .40729 L p
1 g
F P
s
P
p
.002 w
.38412 .40729 m .36557 .38434 L .34825 .40492 L p
1 g
F P
s
P
p
.002 w
.39777 .55333 m .45221 .56246 L .44759 .539 L p
1 g
F P
s
P
p
.002 w
.44759 .539 m .39527 .52987 L .39777 .55333 L p
1 g
F P
s
P
p
.002 w
.51261 .29693 m .51839 .31119 L .54723 .31093 L p
1 g
F P
s
P
p
.002 w
.51839 .31119 m .51261 .29693 L .48627 .30724 L p
1 g
F P
s
P
p
.002 w
.38018 .34331 m .38596 .36527 L .40892 .34807 L p
1 g
F P
s
P
p
.002 w
.40892 .34807 m .40521 .33308 L .38018 .34331 L p
1 g
F P
s
P
p
.002 w
.64412 .38445 m .62384 .42718 L .63978 .44702 L p
1 g
F P
s
P
p
.002 w
.62384 .42718 m .64412 .38445 L .62317 .36882 L p
1 g
F P
s
P
p
.002 w
.48045 .30161 m .48627 .30724 L .51261 .29693 L p
1 g
F P
s
P
p
.002 w
.60175 .31942 m .59954 .35502 L .62317 .36882 L p
1 g
F P
s
P
p
.002 w
.59954 .35502 m .60175 .31942 L .57521 .31367 L p
1 g
F P
s
P
p
.002 w
.40774 .31707 m .40521 .33308 L .4322 .32545 L p
1 g
F P
s
P
p
.002 w
.4322 .32545 m .43357 .31739 L .40774 .31707 L p
1 g
F P
s
P
p
.002 w
.5165 .57766 m .57294 .55847 L .5653 .53829 L p
1 g
F P
s
P
p
.002 w
.5653 .53829 m .50969 .55717 L .5165 .57766 L p
1 g
F P
s
P
p
.002 w
.61437 .50742 m .5653 .53829 L .57294 .55847 L p
1 g
F P
s
P
p
.002 w
.45819 .58321 m .5165 .57766 L .50969 .55717 L p
1 g
F P
s
P
p
.002 w
.50969 .55717 m .45221 .56246 L .45819 .58321 L p
1 g
F P
s
P
p
.002 w
.35085 .50689 m .39527 .52987 L .39545 .5045 L p
1 g
F P
s
P
p
.002 w
.39545 .5045 m .35403 .48254 L .35085 .50689 L p
1 g
F P
s
P
p
.002 w
.53903 .28983 m .54723 .31093 L .57521 .31367 L p
1 g
F P
s
P
p
.002 w
.54723 .31093 m .53903 .28983 L .51261 .29693 L p
1 g
F P
s
P
p
.002 w
.33447 .4266 m .36081 .45747 L .37094 .43221 L p
1 g
F P
s
P
p
.002 w
.37094 .43221 m .34825 .40492 L .33447 .4266 L p
1 g
F P
s
P
p
.002 w
.51261 .29693 m .50122 .28562 L .48045 .30161 L p
1 g
F P
s
P
p
.002 w
.47247 .29816 m .48045 .30161 L .50122 .28562 L p
1 g
F P
s
P
p
.002 w
.41637 .30182 m .40774 .31707 L .43357 .31739 L p
1 g
F P
s
P
p
.002 w
.43357 .31739 m .43796 .30977 L .41637 .30182 L p
1 g
F P
s
P
p
.002 w
.3577 .35599 m .36557 .38434 L .38596 .36527 L p
1 g
F P
s
P
p
.002 w
.38596 .36527 m .38018 .34331 L .3577 .35599 L p
1 g
F P
s
P
p
.002 w
.50122 .28562 m .51261 .29693 L .53903 .28983 L p
1 g
F P
s
P
p
.002 w
.50122 .28562 m .48538 .27861 L .47247 .29816 L p
1 g
F P
s
P
p
.002 w
.46319 .29729 m .47247 .29816 L .48538 .27861 L p
1 g
F P
s
P
p
.002 w
.4302 .2891 m .41637 .30182 L .43796 .30977 L p
1 g
F P
s
P
p
.002 w
.43796 .30977 m .44491 .30344 L .4302 .2891 L p
1 g
F P
s
P
p
.002 w
.38365 .31965 m .38018 .34331 L .40521 .33308 L p
1 g
F P
s
P
p
.002 w
.40521 .33308 m .40774 .31707 L .38365 .31965 L p
1 g
F P
s
P
p
.002 w
.62622 .32815 m .62317 .36882 L .64412 .38445 L p
1 g
F P
s
P
p
.002 w
.62317 .36882 m .62622 .32815 L .60175 .31942 L p
1 g
F P
s
P
p
.002 w
.57294 .55847 m .62283 .52729 L .61437 .50742 L p
1 g
F P
s
P
p
.002 w
.65255 .46694 m .61437 .50742 L .62283 .52729 L p
1 g
F P
s
P
p
.002 w
.61437 .50742 m .65255 .46694 L .63978 .44702 L p
1 g
F P
s
P
p
.002 w
.45364 .29911 m .46319 .29729 L .46684 .27678 L p
1 g
F P
s
P
p
.002 w
.48538 .27861 m .46684 .27678 L .46319 .29729 L p
1 g
F P
s
P
p
.002 w
.4477 .28041 m .4302 .2891 L .44491 .30344 L p
1 g
F P
s
P
p
.002 w
.44491 .30344 m .45364 .29911 L .4477 .28041 L p
1 g
F P
s
P
p
.002 w
.56497 .2862 m .57521 .31367 L .60175 .31942 L p
1 g
F P
s
P
p
.002 w
.57521 .31367 m .56497 .2862 L .53903 .28983 L p
1 g
F P
s
P
p
.002 w
.46684 .27678 m .4477 .28041 L .45364 .29911 L p
1 g
F P
s
P
p
.002 w
.403 .5743 m .45819 .58321 L .45221 .56246 L p
1 g
F P
s
P
p
.002 w
.45221 .56246 m .39777 .55333 L .403 .5743 L p
1 g
F P
s
P
p
.002 w
.66186 .40164 m .63978 .44702 L .65255 .46694 L p
1 g
F P
s
P
p
.002 w
.63978 .44702 m .66186 .40164 L .64412 .38445 L p
1 g
F P
s
P
p
.002 w
.32466 .44894 m .35403 .48254 L .36081 .45747 L p
1 g
F P
s
P
p
.002 w
.36081 .45747 m .33447 .4266 L .32466 .44894 L p
1 g
F P
s
P
p
.002 w
.33835 .37092 m .34825 .40492 L .36557 .38434 L p
1 g
F P
s
P
p
.002 w
.36557 .38434 m .3577 .35599 L .33835 .37092 L p
1 g
F P
s
P
p
.002 w
.35149 .5299 m .39777 .55333 L .39527 .52987 L p
1 g
F P
s
P
p
.002 w
.39527 .52987 m .35085 .50689 L .35149 .5299 L p
1 g
F P
s
P
p
.002 w
.53903 .28983 m .52243 .27296 L .50122 .28562 L p
1 g
F P
s
P
p
.002 w
.48538 .27861 m .50122 .28562 L .52243 .27296 L p
1 g
F P
s
P
p
.002 w
.52243 .27296 m .53903 .28983 L .56497 .2862 L p
1 g
F P
s
P
p
.002 w
.39627 .29696 m .38365 .31965 L .40774 .31707 L p
1 g
F P
s
P
p
.002 w
.40774 .31707 m .41637 .30182 L .39627 .29696 L p
1 g
F P
s
P
p
.002 w
.5231 .59502 m .57896 .57602 L .57294 .55847 L p
1 g
F P
s
P
p
.002 w
.57294 .55847 m .5165 .57766 L .5231 .59502 L p
1 g
F P
s
P
p
.002 w
.62283 .52729 m .57294 .55847 L .57896 .57602 L p
1 g
F P
s
P
p
.002 w
.46546 .60068 m .5231 .59502 L .5165 .57766 L p
1 g
F P
s
P
p
.002 w
.5165 .57766 m .45819 .58321 L .46546 .60068 L p
1 g
F P
s
P
p
.002 w
.3619 .32519 m .3577 .35599 L .38018 .34331 L p
1 g
F P
s
P
p
.002 w
.38018 .34331 m .38365 .31965 L .3619 .32519 L p
1 g
F P
s
P
p
.002 w
.58986 .28621 m .60175 .31942 L .62622 .32815 L p
1 g
F P
s
P
p
.002 w
.60175 .31942 m .58986 .28621 L .56497 .2862 L p
1 g
F P
s
P
p
.002 w
.64801 .33976 m .64412 .38445 L .66186 .40164 L p
1 g
F P
s
P
p
.002 w
.64412 .38445 m .64801 .33976 L .62622 .32815 L p
1 g
F P
s
P
p
.002 w
.52243 .27296 m .49906 .2624 L .48538 .27861 L p
1 g
F P
s
P
p
.002 w
.46684 .27678 m .48538 .27861 L .49906 .2624 L p
1 g
F P
s
P
p
.002 w
.41681 .27794 m .39627 .29696 L .41637 .30182 L p
1 g
F P
s
P
p
.002 w
.41637 .30182 m .4302 .2891 L .41681 .27794 L p
1 g
F P
s
P
p
.002 w
.32272 .38785 m .33447 .4266 L .34825 .40492 L p
1 g
F P
s
P
p
.002 w
.34825 .40492 m .33835 .37092 L .32272 .38785 L p
1 g
F P
s
P
p
.002 w
.31922 .47142 m .35085 .50689 L .35403 .48254 L p
1 g
F P
s
P
p
.002 w
.35403 .48254 m .32466 .44894 L .31922 .47142 L p
1 g
F P
s
P
p
.002 w
.57896 .57602 m .62837 .5453 L .62283 .52729 L p
1 g
F P
s
P
p
.002 w
.66174 .48649 m .62283 .52729 L .62837 .5453 L p
1 g
F P
s
P
p
.002 w
.62283 .52729 m .66174 .48649 L .65255 .46694 L p
1 g
F P
s
P
p
.002 w
.67587 .42005 m .65255 .46694 L .66174 .48649 L p
1 g
F P
s
P
p
.002 w
.65255 .46694 m .67587 .42005 L .66186 .40164 L p
1 g
F P
s
P
p
.002 w
.4477 .28041 m .46684 .27678 L .47148 .25957 L p
1 g
F P
s
P
p
.002 w
.49906 .2624 m .47148 .25957 L .46684 .27678 L p
1 g
F P
s
P
p
.002 w
.44292 .26494 m .41681 .27794 L .4302 .2891 L p
1 g
F P
s
P
p
.002 w
.4302 .2891 m .4477 .28041 L .44292 .26494 L p
1 g
F P
s
P
p
.002 w
.54365 .26405 m .56497 .2862 L .58986 .28621 L p
1 g
F P
s
P
p
.002 w
.56497 .2862 m .54365 .26405 L .52243 .27296 L p
1 g
F P
s
P
p
.002 w
.41098 .59215 m .46546 .60068 L .45819 .58321 L p
1 g
F P
s
P
p
.002 w
.45819 .58321 m .403 .5743 L .41098 .59215 L p
1 g
F P
s
P
p
.002 w
.47148 .25957 m .44292 .26494 L .4477 .28041 L p
1 g
F P
s
P
p
.002 w
.49906 .2624 m .52243 .27296 L .54365 .26405 L p
1 g
F P
s
P
p
.002 w
.3561 .55099 m .403 .5743 L .39777 .55333 L p
1 g
F P
s
P
p
.002 w
.39777 .55333 m .35149 .5299 L .3561 .55099 L p
1 g
F P
s
P
p
.002 w
.34312 .3337 m .33835 .37092 L .3577 .35599 L p
1 g
F P
s
P
p
.002 w
.3577 .35599 m .3619 .32519 L .34312 .3337 L p
1 g
F P
s
P
p
.002 w
.37822 .29545 m .3619 .32519 L .38365 .31965 L p
1 g
F P
s
P
p
.002 w
.38365 .31965 m .39627 .29696 L .37822 .29545 L p
1 g
F P
s
P
p
.002 w
.61305 .29002 m .62622 .32815 L .64801 .33976 L p
1 g
F P
s
P
p
.002 w
.62622 .32815 m .61305 .29002 L .58986 .28621 L p
1 g
F P
s
P
p
.002 w
.6665 .35408 m .66186 .40164 L .67587 .42005 L p
1 g
F P
s
P
p
.002 w
.66186 .40164 m .6665 .35408 L .64801 .33976 L p
1 g
F P
s
P
p
.002 w
.52933 .6087 m .58312 .5904 L .57896 .57602 L p
1 g
F P
s
P
p
.002 w
.57896 .57602 m .5231 .59502 L .52933 .6087 L p
1 g
F P
s
P
p
.002 w
.62837 .5453 m .57896 .57602 L .58312 .5904 L p
1 g
F P
s
P
p
.002 w
.31136 .40643 m .32466 .44894 L .33447 .4266 L p
1 g
F P
s
P
p
.002 w
.33447 .4266 m .32272 .38785 L .31136 .40643 L p
1 g
F P
s
P
p
.002 w
.47391 .61427 m .52933 .6087 L .5231 .59502 L p
1 g
F P
s
P
p
.002 w
.5231 .59502 m .46546 .60068 L .47391 .61427 L p
1 g
F P
s
P
p
.002 w
.31847 .4935 m .35149 .5299 L .35085 .50689 L p
1 g
F P
s
P
p
.002 w
.35085 .50689 m .31922 .47142 L .31847 .4935 L p
1 g
F P
s
P
p
.002 w
.54365 .26405 m .51323 .25007 L .49906 .2624 L p
1 g
F P
s
P
p
.002 w
.47148 .25957 m .49906 .2624 L .51323 .25007 L p
1 g
F P
s
P
p
.002 w
.4051 .27041 m .37822 .29545 L .39627 .29696 L p
1 g
F P
s
P
p
.002 w
.39627 .29696 m .41681 .27794 L .4051 .27041 L p
1 g
F P
s
P
p
.002 w
.56437 .25926 m .58986 .28621 L .61305 .29002 L p
1 g
F P
s
P
p
.002 w
.58986 .28621 m .56437 .25926 L .54365 .26405 L p
1 g
F P
s
P
p
.002 w
.62837 .5453 m .66696 .50522 L .66174 .48649 L p
1 g
F P
s
P
p
.002 w
.68564 .4393 m .66174 .48649 L .66696 .50522 L p
1 g
F P
s
P
p
.002 w
.66174 .48649 m .68564 .4393 L .67587 .42005 L p
1 g
F P
s
P
p
.002 w
.51323 .25007 m .54365 .26405 L .56437 .25926 L p
1 g
F P
s
P
p
.002 w
.58312 .5904 m .63073 .56094 L .62837 .5453 L p
1 g
F P
s
P
p
.002 w
.66696 .50522 m .62837 .5453 L .63073 .56094 L p
1 g
F P
s
P
p
.002 w
.32791 .3451 m .32272 .38785 L .33835 .37092 L p
1 g
F P
s
P
p
.002 w
.33835 .37092 m .34312 .3337 L .32791 .3451 L p
1 g
F P
s
P
p
.002 w
.51323 .25007 m .47706 .24624 L .47148 .25957 L p
1 g
F P
s
P
p
.002 w
.44292 .26494 m .47148 .25957 L .47706 .24624 L p
1 g
F P
s
P
p
.002 w
.36477 .56951 m .41098 .59215 L .403 .5743 L p
1 g
F P
s
P
p
.002 w
.403 .5743 m .3561 .55099 L .36477 .56951 L p
1 g
F P
s
P
p
.002 w
.63393 .29769 m .64801 .33976 L .6665 .35408 L p
1 g
F P
s
P
p
.002 w
.64801 .33976 m .63393 .29769 L .61305 .29002 L p
1 g
F P
s
P
p
.002 w
.42163 .60629 m .47391 .61427 L .46546 .60068 L p
1 g
F P
s
P
p
.002 w
.46546 .60068 m .41098 .59215 L .42163 .60629 L p
1 g
F P
s
P
p
.002 w
.36276 .29751 m .34312 .3337 L .3619 .32519 L p
1 g
F P
s
P
p
.002 w
.3619 .32519 m .37822 .29545 L .36276 .29751 L p
1 g
F P
s
P
p
.002 w
.43946 .25328 m .4051 .27041 L .41681 .27794 L p
1 g
F P
s
P
p
.002 w
.41681 .27794 m .44292 .26494 L .43946 .25328 L p
1 g
F P
s
P
p
.002 w
.47706 .24624 m .43946 .25328 L .44292 .26494 L p
1 g
F P
s
P
p
.002 w
.68108 .37089 m .67587 .42005 L .68564 .4393 L p
1 g
F P
s
P
p
.002 w
.67587 .42005 m .68108 .37089 L .6665 .35408 L p
1 g
F P
s
P
p
.002 w
.30475 .42629 m .31922 .47142 L .32466 .44894 L p
1 g
F P
s
P
p
.002 w
.32466 .44894 m .31136 .40643 L .30475 .42629 L p
1 g
F P
s
P
p
.002 w
.32267 .51456 m .3561 .55099 L .35149 .5299 L p
1 g
F P
s
P
p
.002 w
.35149 .5299 m .31847 .4935 L .32267 .51456 L p
1 g
F P
s
P
p
.002 w
.53504 .61816 m .58523 .60108 L .58312 .5904 L p
1 g
F P
s
P
p
.002 w
.58312 .5904 m .52933 .6087 L .53504 .61816 L p
1 g
F P
s
P
p
.002 w
.63073 .56094 m .58312 .5904 L .58523 .60108 L p
1 g
F P
s
P
p
.002 w
.58405 .25891 m .61305 .29002 L .63393 .29769 L p
1 g
F P
s
P
p
.002 w
.61305 .29002 m .58405 .25891 L .56437 .25926 L p
1 g
F P
s
P
p
.002 w
.4834 .62343 m .53504 .61816 L .52933 .6087 L p
1 g
F P
s
P
p
.002 w
.52933 .6087 m .47391 .61427 L .4834 .62343 L p
1 g
F P
s
P
p
.002 w
.56437 .25926 m .52756 .24212 L .51323 .25007 L p
1 g
F P
s
P
p
.002 w
.47706 .24624 m .51323 .25007 L .52756 .24212 L p
1 g
F P
s
P
p
.002 w
.39549 .2669 m .36276 .29751 L .37822 .29545 L p
1 g
F P
s
P
p
.002 w
.37822 .29545 m .4051 .27041 L .39549 .2669 L p
1 g
F P
s
P
p
.002 w
.31686 .35925 m .31136 .40643 L .32272 .38785 L p
1 g
F P
s
P
p
.002 w
.32272 .38785 m .32791 .3451 L .31686 .35925 L p
1 g
F P
s
P
p
.002 w
.63073 .56094 m .66789 .52261 L .66696 .50522 L p
1 g
F P
s
P
p
.002 w
.69072 .45896 m .66696 .50522 L .66789 .52261 L p
1 g
F P
s
P
p
.002 w
.66696 .50522 m .69072 .45896 L .68564 .4393 L p
1 g
F P
s
P
p
.002 w
.52756 .24212 m .56437 .25926 L .58405 .25891 L p
1 g
F P
s
P
p
.002 w
.65186 .3092 m .6665 .35408 L .68108 .37089 L p
1 g
F P
s
P
p
.002 w
.6665 .35408 m .65186 .3092 L .63393 .29769 L p
1 g
F P
s
P
p
.002 w
.35045 .30329 m .32791 .3451 L .34312 .3337 L p
1 g
F P
s
P
p
.002 w
.34312 .3337 m .36276 .29751 L .35045 .30329 L p
1 g
F P
s
P
p
.002 w
.37746 .58484 m .42163 .60629 L .41098 .59215 L p
1 g
F P
s
P
p
.002 w
.41098 .59215 m .36477 .56951 L .37746 .58484 L p
1 g
F P
s
P
p
.002 w
.58523 .60108 m .62964 .57367 L .63073 .56094 L p
1 g
F P
s
P
p
.002 w
.66789 .52261 m .63073 .56094 L .62964 .57367 L p
1 g
F P
s
P
p
.002 w
.30333 .44694 m .31847 .4935 L .31922 .47142 L p
1 g
F P
s
P
p
.002 w
.31922 .47142 m .30475 .42629 L .30333 .44694 L p
1 g
F P
s
P
p
.002 w
.43484 .61613 m .4834 .62343 L .47391 .61427 L p
1 g
F P
s
P
p
.002 w
.47391 .61427 m .42163 .60629 L .43484 .61613 L p
1 g
F P
s
P
p
.002 w
.43946 .25328 m .47706 .24624 L .48348 .23735 L p
1 g
F P
s
P
p
.002 w
.52756 .24212 m .48348 .23735 L .47706 .24624 L p
1 g
F P
s
P
p
.002 w
.6912 .38986 m .68564 .4393 L .69072 .45896 L p
1 g
F P
s
P
p
.002 w
.68564 .4393 m .6912 .38986 L .68108 .37089 L p
1 g
F P
s
P
p
.002 w
.4375 .24593 m .39549 .2669 L .4051 .27041 L p
1 g
F P
s
P
p
.002 w
.4051 .27041 m .43946 .25328 L .4375 .24593 L p
1 g
F P
s
P
p
.002 w
.48348 .23735 m .4375 .24593 L .43946 .25328 L p
1 g
F P
s
P
p
.002 w
.33195 .534 m .36477 .56951 L .3561 .55099 L p
1 g
F P
s
P
p
.002 w
.3561 .55099 m .32267 .51456 L .33195 .534 L p
1 g
F P
s
P
p
.002 w
.60214 .26323 m .63393 .29769 L .65186 .3092 L p
1 g
F P
s
P
p
.002 w
.63393 .29769 m .60214 .26323 L .58405 .25891 L p
1 g
F P
s
P
p
.002 w
.31052 .37593 m .30475 .42629 L .31136 .40643 L p
1 g
F P
s
P
p
.002 w
.31136 .40643 m .31686 .35925 L .31052 .37593 L p
1 g
F P
s
P
p
.002 w
.58405 .25891 m .5417 .23901 L .52756 .24212 L p
1 g
F P
s
P
p
.002 w
.48348 .23735 m .52756 .24212 L .5417 .23901 L p
1 g
F P
s
P
p
.002 w
.66619 .32446 m .68108 .37089 L .6912 .38986 L p
1 g
F P
s
P
p
.002 w
.68108 .37089 m .66619 .32446 L .65186 .3092 L p
1 g
F P
s
P
p
.002 w
.54003 .62288 m .58509 .60754 L .58523 .60108 L p
1 g
F P
s
P
p
.002 w
.58523 .60108 m .53504 .61816 L .54003 .62288 L p
1 g
F P
s
P
p
.002 w
.62964 .57367 m .58523 .60108 L .58509 .60754 L p
1 g
F P
s
P
p
.002 w
.49374 .62764 m .54003 .62288 L .53504 .61816 L p
1 g
F P
s
P
p
.002 w
.53504 .61816 m .4834 .62343 L .49374 .62764 L p
1 g
F P
s
P
p
.002 w
.5417 .23901 m .58405 .25891 L .60214 .26323 L p
1 g
F P
s
P
p
.002 w
.38836 .26778 m .35045 .30329 L .36276 .29751 L p
1 g
F P
s
P
p
.002 w
.36276 .29751 m .39549 .2669 L .38836 .26778 L p
1 g
F P
s
P
p
.002 w
.62964 .57367 m .66425 .53815 L .66789 .52261 L p
1 g
F P
s
P
p
.002 w
.69075 .47852 m .66789 .52261 L .66425 .53815 L p
1 g
F P
s
P
p
.002 w
.66789 .52261 m .69075 .47852 L .69072 .45896 L p
1 g
F P
s
P
p
.002 w
.34181 .31286 m .31686 .35925 L .32791 .3451 L p
1 g
F P
s
P
p
.002 w
.32791 .3451 m .35045 .30329 L .34181 .31286 L p
1 g
F P
s
P
p
.002 w
.3074 .46783 m .32267 .51456 L .31847 .4935 L p
1 g
F P
s
P
p
.002 w
.31847 .4935 m .30333 .44694 L .3074 .46783 L p
1 g
F P
s
P
p
.002 w
.39403 .59639 m .43484 .61613 L .42163 .60629 L p
1 g
F P
s
P
p
.002 w
.42163 .60629 m .37746 .58484 L .39403 .59639 L p
1 g
F P
s
P
p
.002 w
.69636 .41059 m .69072 .45896 L .69075 .47852 L p
1 g
F P
s
P
p
.002 w
.69072 .45896 m .69636 .41059 L .6912 .38986 L p
1 g
F P
s
P
p
.002 w
.58509 .60754 m .62494 .58299 L .62964 .57367 L p
1 g
F P
s
P
p
.002 w
.66425 .53815 m .62964 .57367 L .62494 .58299 L p
1 g
F P
s
P
p
.002 w
.45039 .62116 m .49374 .62764 L .4834 .62343 L p
1 g
F P
s
P
p
.002 w
.4834 .62343 m .43484 .61613 L .45039 .62116 L p
1 g
F P
s
P
p
.002 w
.4375 .24593 m .48348 .23735 L .49063 .23343 L p
1 g
F P
s
P
p
.002 w
.5417 .23901 m .49063 .23343 L .48348 .23735 L p
1 g
F P
s
P
p
.002 w
.34628 .55115 m .37746 .58484 L .36477 .56951 L p
1 g
F P
s
P
p
.002 w
.36477 .56951 m .33195 .534 L .34628 .55115 L p
1 g
F P
s
P
p
.002 w
.43719 .24339 m .38836 .26778 L .39549 .2669 L p
1 g
F P
s
P
p
.002 w
.39549 .2669 m .4375 .24593 L .43719 .24339 L p
1 g
F P
s
P
p
.002 w
.61805 .27236 m .65186 .3092 L .66619 .32446 L p
1 g
F P
s
P
p
.002 w
.65186 .3092 m .61805 .27236 L .60214 .26323 L p
1 g
F P
s
P
p
.002 w
.49063 .23343 m .43719 .24339 L .4375 .24593 L p
1 g
F P
s
P
p
.002 w
.30933 .39477 m .30333 .44694 L .30475 .42629 L p
1 g
F P
s
P
p
.002 w
.30475 .42629 m .31052 .37593 L .30933 .39477 L p
1 g
F P
s
P
p
.002 w
.6912 .38986 m .67636 .3432 L .66619 .32446 L p
1 g
F P
s
P
p
.002 w
.67636 .3432 m .6912 .38986 L .69636 .41059 L p
1 g
F P
s
P
p
.002 w
.60214 .26323 m .55524 .24111 L .5417 .23901 L p
1 g
F P
s
P
p
.002 w
.49063 .23343 m .5417 .23901 L .55524 .24111 L p
1 g
F P
s
P
p
.002 w
.55524 .24111 m .60214 .26323 L .61805 .27236 L p
1 g
F P
s
P
p
.002 w
.31711 .48836 m .33195 .534 L .32267 .51456 L p
1 g
F P
s
P
p
.002 w
.32267 .51456 m .3074 .46783 L .31711 .48836 L p
1 g
F P
s
P
p
.002 w
.38407 .27329 m .34181 .31286 L .35045 .30329 L p
1 g
F P
s
P
p
.002 w
.35045 .30329 m .38836 .26778 L .38407 .27329 L p
1 g
F P
s
P
p
.002 w
.62494 .58299 m .65588 .55128 L .66425 .53815 L p
1 g
F P
s
P
p
.002 w
.66425 .53815 m .68544 .49743 L .69075 .47852 L p
1 g
F P
s
P
p
.002 w
.68544 .49743 m .66425 .53815 L .65588 .55128 L p
1 g
F P
s
P
p
.002 w
.54411 .62242 m .58256 .60933 L .58509 .60754 L p
1 g
F P
s
P
p
.002 w
.58509 .60754 m .54003 .62288 L .54411 .62242 L p
1 g
F P
s
P
p
.002 w
.62494 .58299 m .58509 .60754 L .58256 .60933 L p
1 g
F P
s
P
p
.002 w
.50469 .62647 m .54411 .62242 L .54003 .62288 L p
1 g
F P
s
P
p
.002 w
.54003 .62288 m .49374 .62764 L .50469 .62647 L p
1 g
F P
s
P
p
.002 w
.33733 .32618 m .31052 .37593 L .31686 .35925 L p
1 g
F P
s
P
p
.002 w
.31686 .35925 m .34181 .31286 L .33733 .32618 L p
1 g
F P
s
P
p
.002 w
.69075 .47852 m .69616 .43258 L .69636 .41059 L p
1 g
F P
s
P
p
.002 w
.69616 .43258 m .69075 .47852 L .68544 .49743 L p
1 g
F P
s
P
p
.002 w
.4142 .60361 m .45039 .62116 L .43484 .61613 L p
1 g
F P
s
P
p
.002 w
.43484 .61613 m .39403 .59639 L .4142 .60361 L p
1 g
F P
s
P
p
.002 w
.36549 .56539 m .39403 .59639 L .37746 .58484 L p
1 g
F P
s
P
p
.002 w
.37746 .58484 m .34628 .55115 L .36549 .56539 L p
1 g
F P
s
P
p
.002 w
.58256 .60933 m .61652 .58841 L .62494 .58299 L p
1 g
F P
s
P
p
.002 w
.65588 .55128 m .62494 .58299 L .61652 .58841 L p
1 g
F P
s
P
p
.002 w
.66619 .32446 m .6312 .28631 L .61805 .27236 L p
1 g
F P
s
P
p
.002 w
.6312 .28631 m .66619 .32446 L .67636 .3432 L p
1 g
F P
s
P
p
.002 w
.46794 .62095 m .50469 .62647 L .49374 .62764 L p
1 g
F P
s
P
p
.002 w
.49374 .62764 m .45039 .62116 L .46794 .62095 L p
1 g
F P
s
P
p
.002 w
.43719 .24339 m .49063 .23343 L .49836 .2349 L p
1 g
F P
s
P
p
.002 w
.55524 .24111 m .49836 .2349 L .49063 .23343 L p
1 g
F P
s
P
p
.002 w
.43865 .24604 m .38407 .27329 L .38836 .26778 L p
1 g
F P
s
P
p
.002 w
.38836 .26778 m .43719 .24339 L .43865 .24604 L p
1 g
F P
s
P
p
.002 w
.31361 .41533 m .3074 .46783 L .30333 .44694 L p
1 g
F P
s
P
p
.002 w
.30333 .44694 m .30933 .39477 L .31361 .41533 L p
1 g
F P
s
P
p
.002 w
.68183 .36506 m .69636 .41059 L .69616 .43258 L p
1 g
F P
s
P
p
.002 w
.69636 .41059 m .68183 .36506 L .67636 .3432 L p
1 g
F P
s
P
p
.002 w
.49836 .2349 m .43865 .24604 L .43719 .24339 L p
1 g
F P
s
P
p
.002 w
.33245 .50786 m .34628 .55115 L .33195 .534 L p
1 g
F P
s
P
p
.002 w
.33195 .534 m .31711 .48836 L .33245 .50786 L p
1 g
F P
s
P
p
.002 w
.56776 .24868 m .61805 .27236 L .6312 .28631 L p
1 g
F P
s
P
p
.002 w
.61805 .27236 m .56776 .24868 L .55524 .24111 L p
1 g
F P
s
P
p
.002 w
.49836 .2349 m .55524 .24111 L .56776 .24868 L p
1 g
F P
s
P
p
.002 w
.61652 .58841 m .64275 .56149 L .65588 .55128 L p
1 g
F P
s
P
p
.002 w
.67468 .51511 m .65588 .55128 L .64275 .56149 L p
1 g
F P
s
P
p
.002 w
.65588 .55128 m .67468 .51511 L .68544 .49743 L p
1 g
F P
s
P
p
.002 w
.33739 .34306 m .30933 .39477 L .31052 .37593 L p
1 g
F P
s
P
p
.002 w
.31052 .37593 m .33733 .32618 L .33739 .34306 L p
1 g
F P
s
P
p
.002 w
.69035 .45523 m .68544 .49743 L .67468 .51511 L p
1 g
F P
s
P
p
.002 w
.68544 .49743 m .69035 .45523 L .69616 .43258 L p
1 g
F P
s
P
p
.002 w
.38295 .28358 m .33733 .32618 L .34181 .31286 L p
1 g
F P
s
P
p
.002 w
.34181 .31286 m .38407 .27329 L .38295 .28358 L p
1 g
F P
s
P
p
.002 w
.43752 .60606 m .46794 .62095 L .45039 .62116 L p
1 g
F P
s
P
p
.002 w
.45039 .62116 m .4142 .60361 L .43752 .60606 L p
1 g
F P
s
P
p
.002 w
.54712 .61644 m .57756 .60608 L .58256 .60933 L p
1 g
F P
s
P
p
.002 w
.58256 .60933 m .54411 .62242 L .54712 .61644 L p
1 g
F P
s
P
p
.004 w
.56786 .61973 m
.57642 .6436 L
s
P
p
.002 w
.61652 .58841 m .58256 .60933 L .57756 .60608 L p
1 g
F P
s
P
p
.002 w
.51596 .61962 m .54712 .61644 L .54411 .62242 L p
1 g
F P
s
P
p
.002 w
.54411 .62242 m .50469 .62647 L .51596 .61962 L p
1 g
F P
s
P
p
.002 w
.3892 .57613 m .4142 .60361 L .39403 .59639 L p
1 g
F P
s
P
p
.002 w
.39403 .59639 m .36549 .56539 L .3892 .57613 L p
1 g
F P
s
P
p
.002 w
.64104 .30491 m .67636 .3432 L .68183 .36506 L p
1 g
F P
s
P
p
.002 w
.67636 .3432 m .64104 .30491 L .6312 .28631 L p
1 g
F P
s
P
p
.002 w
.57756 .60608 m .60439 .58952 L .61652 .58841 L p
1 g
F P
s
P
p
.002 w
.64275 .56149 m .61652 .58841 L .60439 .58952 L p
1 g
F P
s
P
p
.002 w
.32351 .43702 m .31711 .48836 L .3074 .46783 L p
1 g
F P
s
P
p
.002 w
.3074 .46783 m .31361 .41533 L .32351 .43702 L p
1 g
F P
s
P
p
.002 w
.68222 .38951 m .69616 .43258 L .69035 .45523 L p
1 g
F P
s
P
p
.002 w
.69616 .43258 m .68222 .38951 L .68183 .36506 L p
1 g
F P
s
P
p
.002 w
.48708 .6152 m .51596 .61962 L .50469 .62647 L p
1 g
F P
s
P
p
.002 w
.50469 .62647 m .46794 .62095 L .48708 .6152 L p
1 g
F P
s
P
p
.002 w
.56776 .24868 m .50647 .24208 L .49836 .2349 L p
1 g
F P
s
P
p
.002 w
.43865 .24604 m .49836 .2349 L .50647 .24208 L p
1 g
F P
s
P
p
.002 w
.35316 .52564 m .36549 .56539 L .34628 .55115 L p
1 g
F P
s
P
p
.002 w
.34628 .55115 m .33245 .50786 L .35316 .52564 L p
1 g
F P
s
P
p
.002 w
.44195 .25417 m .38295 .28358 L .38407 .27329 L p
1 g
F P
s
P
p
.002 w
.38407 .27329 m .43865 .24604 L .44195 .25417 L p
1 g
F P
s
P
p
.002 w
.57881 .26182 m .6312 .28631 L .64104 .30491 L p
1 g
F P
s
P
p
.002 w
.6312 .28631 m .57881 .26182 L .56776 .24868 L p
1 g
F P
s
P
p
.002 w
.50647 .24208 m .44195 .25417 L .43865 .24604 L p
1 g
F P
s
P
p
.002 w
.64275 .56149 m .65851 .53095 L .67468 .51511 L p
1 g
F P
s
P
p
.002 w
.67882 .47785 m .67468 .51511 L .65851 .53095 L p
1 g
F P
s
P
p
.002 w
.67468 .51511 m .67882 .47785 L .69035 .45523 L p
1 g
F P
s
P
p
.002 w
.50647 .24208 m .56776 .24868 L .57881 .26182 L p
1 g
F P
s
P
p
.002 w
.34227 .36315 m .31361 .41533 L .30933 .39477 L p
1 g
F P
s
P
p
.002 w
.30933 .39477 m .33739 .34306 L .34227 .36315 L p
1 g
F P
s
P
p
.002 w
.60439 .58952 m .62499 .56829 L .64275 .56149 L p
1 g
F P
s
P
p
.002 w
.65851 .53095 m .64275 .56149 L .62499 .56829 L p
1 g
F P
s
P
p
.002 w
.38522 .29863 m .33739 .34306 L .33733 .32618 L p
1 g
F P
s
P
p
.002 w
.33733 .32618 m .38295 .28358 L .38522 .29863 L p
1 g
F P
s
P
p
.002 w
.64708 .32782 m .68183 .36506 L .68222 .38951 L p
1 g
F P
s
P
p
.002 w
.68183 .36506 m .64708 .32782 L .64104 .30491 L p
1 g
F P
s
P
p
.002 w
.41681 .58287 m .43752 .60606 L .4142 .60361 L p
1 g
F P
s
P
p
.002 w
.4142 .60361 m .3892 .57613 L .41681 .58287 L p
1 g
F P
s
P
p
.002 w
.4634 .60342 m .48708 .6152 L .46794 .62095 L p
1 g
F P
s
P
p
.002 w
.46794 .62095 m .43752 .60606 L .4634 .60342 L p
1 g
F P
s
P
p
.002 w
.67728 .41589 m .69035 .45523 L .67882 .47785 L p
1 g
F P
s
P
p
.002 w
.69035 .45523 m .67728 .41589 L .68222 .38951 L p
1 g
F P
s
P
p
.002 w
.54887 .60478 m .57007 .59756 L .57756 .60608 L p
1 g
F P
s
P
p
.002 w
.57756 .60608 m .54712 .61644 L .54887 .60478 L p
1 g
F P
s
P
p
.002 w
.60439 .58952 m .57756 .60608 L .57007 .59756 L p
1 g
F P
s
P
p
.002 w
.33897 .45918 m .33245 .50786 L .31711 .48836 L p
1 g
F P
s
P
p
.002 w
.31711 .48836 m .32351 .43702 L .33897 .45918 L p
1 g
F P
s
P
p
.002 w
.52721 .60695 m .54887 .60478 L .54712 .61644 L p
1 g
F P
s
P
p
.002 w
.54712 .61644 m .51596 .61962 L .52721 .60695 L p
1 g
F P
s
P
p
.002 w
.37878 .54104 m .3892 .57613 L .36549 .56539 L p
1 g
F P
s
P
p
.002 w
.36549 .56539 m .35316 .52564 L .37878 .54104 L p
1 g
F P
s
P
p
.002 w
.57007 .59756 m .58872 .58602 L .60439 .58952 L p
1 g
F P
s
P
p
.002 w
.62499 .56829 m .60439 .58952 L .58872 .58602 L p
1 g
F P
s
P
p
.002 w
.50726 .6038 m .52721 .60695 L .51596 .61962 L p
1 g
F P
s
P
p
.002 w
.51596 .61962 m .48708 .6152 L .50726 .6038 L p
1 g
F P
s
P
p
.002 w
.58795 .28041 m .64104 .30491 L .64708 .32782 L p
1 g
F P
s
P
p
.002 w
.64104 .30491 m .58795 .28041 L .57881 .26182 L p
1 g
F P
s
P
p
.002 w
.57881 .26182 m .51472 .2551 L .50647 .24208 L p
1 g
F P
s
P
p
.002 w
.44195 .25417 m .50647 .24208 L .51472 .2551 L p
1 g
F P
s
P
p
.002 w
.44711 .26784 m .38522 .29863 L .38295 .28358 L p
1 g
F P
s
P
p
.002 w
.38295 .28358 m .44195 .25417 L .44711 .26784 L p
1 g
F P
s
P
p
.002 w
.62499 .56829 m .63717 .54435 L .65851 .53095 L p
1 g
F P
s
P
p
.002 w
.66172 .49973 m .65851 .53095 L .63717 .54435 L p
1 g
F P
s
P
p
.002 w
.65851 .53095 m .66172 .49973 L .67882 .47785 L p
1 g
F P
s
P
p
.002 w
.35204 .38594 m .32351 .43702 L .31361 .41533 L p
1 g
F P
s
P
p
.002 w
.31361 .41533 m .34227 .36315 L .35204 .38594 L p
1 g
F P
s
P
p
.002 w
.64893 .35447 m .68222 .38951 L .67728 .41589 L p
1 g
F P
s
P
p
.002 w
.68222 .38951 m .64893 .35447 L .64708 .32782 L p
1 g
F P
s
P
p
.002 w
.44756 .58523 m .4634 .60342 L .43752 .60606 L p
1 g
F P
s
P
p
.002 w
.43752 .60606 m .41681 .58287 L .44756 .58523 L p
1 g
F P
s
P
p
.002 w
.51472 .2551 m .57881 .26182 L .58795 .28041 L p
1 g
F P
s
P
p
.002 w
.58872 .58602 m .60292 .57127 L .62499 .56829 L p
1 g
F P
s
P
p
.002 w
.63717 .54435 m .62499 .56829 L .60292 .57127 L p
1 g
F P
s
P
p
.002 w
.51472 .2551 m .44711 .26784 L .44195 .25417 L p
1 g
F P
s
P
p
.002 w
.49108 .59557 m .50726 .6038 L .48708 .6152 L p
1 g
F P
s
P
p
.002 w
.48708 .6152 m .4634 .60342 L .49108 .59557 L p
1 g
F P
s
P
p
.002 w
.66694 .44338 m .67882 .47785 L .66172 .49973 L p
1 g
F P
s
P
p
.002 w
.67882 .47785 m .66694 .44338 L .67728 .41589 L p
1 g
F P
s
P
p
.002 w
.39103 .31821 m .34227 .36315 L .33739 .34306 L p
1 g
F P
s
P
p
.002 w
.33739 .34306 m .38522 .29863 L .39103 .31821 L p
1 g
F P
s
P
p
.002 w
.35969 .48105 m .35316 .52564 L .33245 .50786 L p
1 g
F P
s
P
p
.002 w
.33245 .50786 m .33897 .45918 L .35969 .48105 L p
1 g
F P
s
P
p
.002 w
.40856 .55344 m .41681 .58287 L .3892 .57613 L p
1 g
F P
s
P
p
.002 w
.3892 .57613 m .37878 .54104 L .40856 .55344 L p
1 g
F P
s
P
p
.002 w
.54925 .58745 m .5602 .58373 L .57007 .59756 L p
1 g
F P
s
P
p
.002 w
.57007 .59756 m .54887 .60478 L .54925 .58745 L p
1 g
F P
s
P
p
.002 w
.58872 .58602 m .57007 .59756 L .5602 .58373 L p
1 g
F P
s
P
p
.002 w
.53807 .58854 m .54925 .58745 L .54887 .60478 L p
1 g
F P
s
P
p
.002 w
.54887 .60478 m .52721 .60695 L .53807 .58854 L p
1 g
F P
s
P
p
.002 w
.59476 .30413 m .64708 .32782 L .64893 .35447 L p
1 g
F P
s
P
p
.002 w
.64708 .32782 m .59476 .30413 L .58795 .28041 L p
1 g
F P
s
P
p
.002 w
.5602 .58373 m .5698 .57775 L .58872 .58602 L p
1 g
F P
s
P
p
.002 w
.60292 .57127 m .58872 .58602 L .5698 .57775 L p
1 g
F P
s
P
p
.002 w
.52785 .58687 m .53807 .58854 L .52721 .60695 L p
1 g
F P
s
P
p
.002 w
.52721 .60695 m .50726 .6038 L .52785 .58687 L p
1 g
F P
s
P
p
.002 w
.60292 .57127 m .61115 .55475 L .63717 .54435 L p
1 g
F P
s
P
p
.002 w
.63938 .52007 m .63717 .54435 L .61115 .55475 L p
1 g
F P
s
P
p
.002 w
.63717 .54435 m .63938 .52007 L .66172 .49973 L p
1 g
F P
s
P
p
.002 w
.64636 .38411 m .67728 .41589 L .66694 .44338 L p
1 g
F P
s
P
p
.002 w
.67728 .41589 m .64636 .38411 L .64893 .35447 L p
1 g
F P
s
P
p
.004 w
.67275 .35565 m
.68718 .3494 L
s
P
p
.002 w
.48045 .58298 m .49108 .59557 L .4634 .60342 L p
1 g
F P
s
P
p
.002 w
.4634 .60342 m .44756 .58523 L .48045 .58298 L p
1 g
F P
s
P
p
.002 w
.3666 .41075 m .33897 .45918 L .32351 .43702 L p
1 g
F P
s
P
p
.002 w
.32351 .43702 m .35204 .38594 L .3666 .41075 L p
1 g
F P
s
P
p
.002 w
.58795 .28041 m .52284 .27386 L .51472 .2551 L p
1 g
F P
s
P
p
.002 w
.44711 .26784 m .51472 .2551 L .52284 .27386 L p
1 g
F P
s
P
p
.002 w
.65137 .47109 m .66172 .49973 L .63938 .52007 L p
1 g
F P
s
P
p
.002 w
.66172 .49973 m .65137 .47109 L .66694 .44338 L p
1 g
F P
s
P
p
.002 w
.38511 .50183 m .37878 .54104 L .35316 .52564 L p
1 g
F P
s
P
p
.002 w
.35316 .52564 m .35969 .48105 L .38511 .50183 L p
1 g
F P
s
P
p
.002 w
.45406 .28695 m .39103 .31821 L .38522 .29863 L p
1 g
F P
s
P
p
.002 w
.38522 .29863 m .44711 .26784 L .45406 .28695 L p
1 g
F P
s
P
p
.002 w
.5698 .57775 m .57705 .57014 L .60292 .57127 L p
1 g
F P
s
P
p
.002 w
.61115 .55475 m .60292 .57127 L .57705 .57014 L p
1 g
F P
s
P
p
.002 w
.52284 .27386 m .58795 .28041 L .59476 .30413 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.44158 .56231 m .44756 .58523 L .41681 .58287 L p
1 g
F P
s
P
p
.002 w
.41681 .58287 m .40856 .55344 L .44158 .56231 L p
1 g
F P
s
P
p
.002 w
.51965 .58258 m .52785 .58687 L .50726 .6038 L p
1 g
F P
s
P
p
.002 w
.50726 .6038 m .49108 .59557 L .51965 .58258 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.40035 .34186 m .35204 .38594 L .34227 .36315 L p
1 g
F P
s
P
p
.002 w
.34227 .36315 m .39103 .31821 L .40035 .34186 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.52284 .27386 m .45406 .28695 L .44711 .26784 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53761 .5354 L
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.6393 .41579 m .66694 .44338 L .65137 .47109 L p
1 g
F P
s
P
p
.002 w
.66694 .44338 m .6393 .41579 L .64636 .38411 L p
1 g
F P
s
P
p
.002 w
.59889 .33238 m .64893 .35447 L .64636 .38411 L p
1 g
F P
s
P
p
.002 w
.64893 .35447 m .59889 .33238 L .59476 .30413 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.57705 .57014 m .58116 .56167 L .61115 .55475 L p
1 g
F P
s
P
p
.002 w
.61242 .53814 m .61115 .55475 L .58116 .56167 L p
1 g
F P
s
P
p
.002 w
.61115 .55475 m .61242 .53814 L .63938 .52007 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.63098 .49803 m .63938 .52007 L .61242 .53814 L p
1 g
F P
s
P
p
.002 w
.63938 .52007 m .63098 .49803 L .65137 .47109 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51965 .58258 m .49108 .59557 L p
.50802 .58141 L 1 g
F P
s
P
p
.50802 .58141 m .50873 .58082 L .50997 .58102 L 1 g
F
P
p
.50802 .58141 m .50997 .58102 L .51965 .58258 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58082 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58082 L .5172 .57956 L 1 g
F
P
p
.002 w
.53309 .57417 m .51965 .58258 L .51937 .58223 L p
1 g
F P
s
P
p
.002 w
.51937 .58223 m .5172 .57956 L p
.53171 .57463 L 1 g
F P
s
P
p
.51937 .58223 m .53171 .57463 L .53309 .57417 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57463 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57463 L .53969 .56973 L 1 g
F
P
p
.53128 .57265 m .5172 .57956 L .51903 .57894 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51095 .58082 m .51079 .57862 L p
.49977 .58082 L 1 g
F P
s
P
p
.002 w
.51438 .57609 m .5172 .57956 L p
.50873 .58082 L 1 g
F P
s
P
p
.002 w
.5172 .57956 m .51822 .58082 L p
.51095 .58082 L 1 g
F P
s
P
p
.50873 .58082 m .5172 .57956 L .51095 .58082 L 1 g
F
P
p
.002 w
.51822 .58082 m .51965 .58258 L p
.50873 .58082 L 1 g
F P
s
P
p
.002 w
.52785 .58687 m .51965 .58258 L .53309 .57417 L p
1 g
F P
s
P
p
.002 w
.53309 .57417 m .54814 .56475 L .54249 .57091 L p
1 g
F P
s
P
p
.002 w
.54249 .57091 m .52785 .58687 L p
.53309 .57417 L 1 g
F P
s
P
p
.002 w
.53213 .57654 m .53171 .57464 L p
.51822 .57935 L 1 g
F P
s
P
p
.002 w
.53171 .57464 m .53128 .57265 L p
.5184 .57926 L 1 g
F P
s
P
p
.5184 .57926 m .51822 .57935 L .53171 .57464 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53213 .57654 L p
1 g
F P
s
P
p
.51822 .57935 m .51111 .583 L .53213 .57654 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54814 .56475 m .53309 .57417 L p
.53235 .57424 L 1 g
F P
s
P
p
.54854 .56129 m .53969 .56973 L .54736 .56501 L 1 g
F
P
p
.54854 .56129 m .54736 .56501 L .54771 .56479 L 1 g
F
P
p
.54854 .56129 m .54771 .56479 L .54779 .56474 L 1 g
F
P
p
.54854 .56129 m .54779 .56474 L .54785 .5647 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51265 .56809 m .51471 .55942 L .54785 .5647 L p
1 g
F P
s
P
p
.002 w
.54785 .5647 m .54814 .56475 L .54771 .56479 L p
1 g
F P
s
P
p
.002 w
.54771 .56479 m .51265 .56809 L p
.54785 .5647 L 1 g
F P
s
P
p
.54779 .56474 m .54771 .56479 L .54779 .56474 L 1 g
F
P
p
.54785 .5647 m .54779 .56474 L .54785 .5647 L 1 g
F
P
p
.54854 .56129 m .54785 .5647 L .5479 .56467 L 1 g
F
P
p
.002 w
.54937 .56352 m .54854 .56129 L p
.54825 .56441 L 1 g
F P
s
P
p
.002 w
.54912 .56372 m .54814 .56475 L .54835 .56433 L p
1 g
F P
s
P
p
.54825 .56441 m .54825 .56442 L .54912 .56372 L 1 g
F
P
p
.54825 .56441 m .54912 .56372 L .54937 .56352 L 1 g
F
P
p
.002 w
.57179 .54003 m .57518 .54295 L p
.54937 .56352 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54937 .56352 L p
1 g
F P
s
P
p
.002 w
.54912 .56372 m .5496 .56322 L p
.54937 .56352 L 1 g
F P
s
P
p
.002 w
.5496 .56322 m .57179 .54003 L p
.54937 .56352 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54937 .56352 L p
.54938 .56351 L 1 g
F P
s
P
p
.56075 .54566 m .54937 .56352 L .54938 .56351 L 1 g
F
P
p
.002 w
.56809 .53874 m .57179 .54003 L .55965 .55272 L p
1 g
F P
s
P
p
.002 w
.55965 .55272 m .5496 .56322 L p
.56162 .54731 L 1 g
F P
s
P
p
.56809 .53874 m .55965 .55272 L .56162 .54731 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .54731 L p
1 g
F P
s
P
p
.56654 .52734 m .56162 .54731 L .56417 .5403 L 1 g
F
P
p
.56075 .54566 m .54938 .56351 L .55503 .55604 L 1 g
F
P
p
.54938 .56351 m .54937 .56352 L .5496 .56322 L 1 g
F
P
p
.54938 .56351 m .5496 .56322 L .55503 .55604 L 1 g
F
P
p
.002 w
.57518 .54295 m .57844 .54574 L p
.54931 .56361 L 1 g
F P
s
P
p
.54937 .56352 m .54931 .56361 L .54912 .56372 L 1 g
F
P
p
.57518 .54295 m .54931 .56361 L .54937 .56352 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.57844 .54574 m .54871 .56439 L p
.54931 .56361 L 1 g
F P
s
P
p
.002 w
.57705 .57014 m .5698 .57775 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.58116 .56167 m .57705 .57014 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.58166 .55323 m .58116 .56167 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.57844 .54574 m .58166 .55323 L .54854 .56461 L p
1 g
F P
s
P
p
.002 w
.54854 .56461 m .54814 .56475 L .54871 .56439 L p
1 g
F P
s
P
p
.002 w
.54871 .56439 m .57844 .54574 L p
.54854 .56461 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56174 .54753 L p
1 g
F P
s
P
p
.002 w
.56174 .54753 m .56165 .54736 L p
.56039 .54927 L 1 g
F P
s
P
p
.56039 .54927 m .54998 .56518 L .56174 .54753 L 1 g
F
P
p
.002 w
.56165 .54736 m .56075 .54566 L p
.55495 .55617 L 1 g
F P
s
P
p
.55495 .55617 m .54998 .56518 L .56165 .54736 L 1 g
F
P
p
.002 w
.54814 .56475 m .54912 .56372 L p
.54931 .56361 L 1 g
F P
s
P
p
.002 w
.54871 .56439 m .54814 .56475 L p
.54931 .56361 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56654 .52734 m .56417 .5403 L .56512 .5377 L 1 g
F
P
p
.002 w
.57179 .54003 m .56813 .53875 L p
.57503 .50498 L 1 g
F P
s
P
p
.002 w
.56813 .53875 m .56512 .5377 L p
.56756 .52963 L 1 g
F P
s
P
p
.57503 .50498 m .56813 .53875 L .56756 .52963 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56751 .52875 L p
1 g
F P
s
P
p
.56515 .50826 m .56751 .52875 L .56725 .52457 L 1 g
F
P
p
.002 w
.56576 .50454 m .57503 .50498 L .56998 .51771 L p
1 g
F P
s
P
p
.002 w
.56998 .51771 m .56725 .52457 L p
.56612 .50942 L 1 g
F P
s
P
p
.56576 .50454 m .56998 .51771 L .56612 .50942 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56612 .50942 L p
1 g
F P
s
P
p
.55661 .4905 m .56612 .50942 L .56381 .50445 L 1 g
F
P
p
.002 w
.55302 .48245 m .55304 .46873 L p
.56087 .49469 L 1 g
F P
s
P
p
.56087 .49469 m .56381 .50445 L .55736 .4913 L 1 g
F
P
p
.56087 .49469 m .55736 .4913 L .55302 .48245 L 1 g
F
P
p
.55661 .4905 m .56381 .50445 L .56245 .50167 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.57503 .50498 m .56381 .50445 L p
.55304 .46873 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.553 .50394 m .56381 .50445 L p
.56241 .53676 L 1 g
F P
s
P
p
.002 w
.56381 .50445 m .56576 .50454 L p
.56541 .50789 L 1 g
F P
s
P
p
.56515 .50826 m .56725 .52457 L .56686 .51937 L 1 g
F
P
p
.002 w
.56751 .52875 m .56654 .52734 L p
.56512 .5377 L 1 g
F P
s
P
p
.002 w
.56512 .5377 m .56241 .53676 L .56725 .52457 L p
1 g
F P
s
P
p
.002 w
.56725 .52457 m .57145 .51399 L p
.56751 .52875 L 1 g
F P
s
P
p
.56751 .52875 m .56512 .5377 L .56725 .52457 L 1 g
F
P
p
.002 w
.57145 .51399 m .57503 .50498 L p
.56512 .5377 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56633 .50966 L p
1 g
F P
s
P
p
.002 w
.56633 .50966 m .56515 .50826 L p
.56697 .52009 L 1 g
F P
s
P
p
.56697 .52009 m .56854 .53025 L .56633 .50966 L 1 g
F
P
p
.56381 .50445 m .56541 .50789 L .56241 .53676 L 1 g
F
P
p
.002 w
.56725 .52457 m .56241 .53676 L p
.56576 .50454 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55802 .492 L p
1 g
F P
s
P
p
.002 w
.55802 .492 m .55661 .4905 L p
.56309 .50289 L 1 g
F P
s
P
p
.56309 .50289 m .56713 .51061 L .55802 .492 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .4913 L p
1 g
F P
s
P
p
.54174 .47608 m .55736 .4913 L .55302 .4871 L 1 g
F
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55302 .4871 m .553 .50394 L p
.53897 .47512 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5423 .47669 L p
1 g
F P
s
P
p
.52214 .46667 m .5423 .47669 L .53385 .47271 L 1 g
F
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53385 .47271 m .51899 .47579 L .5158 .46628 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46716 L p
1 g
F P
s
P
p
.5 .4634 m .52243 .46716 L .5158 .46628 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5158 .46628 m .51899 .47579 L p
.48895 .46541 L 1 g
F P
s
P
p
.5 .46374 m .5158 .46628 L .48895 .46541 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46374 L p
1 g
F P
s
P
p
.48503 .466 m .48895 .46541 L .51899 .47579 L 1 g
F
P
p
.002 w
.5 .46374 m .5 .46442 L p
.4863 .46581 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46374 L .4863 .46581 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46661 .4607 m .47024 .45894 L p
.48895 .46541 L 1 g
F P
s
P
p
.002 w
.47758 .46713 m .47786 .46667 L p
.4863 .46581 L 1 g
F P
s
P
p
.46661 .4607 m .48895 .46541 L .48503 .466 L 1 g
F
P
p
.47024 .45894 m .5 .46374 L .48895 .46541 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.51899 .47579 m .4875 .49093 L .47273 .46955 L p
1 g
F P
s
P
p
.48175 .46506 m .51899 .47579 L .47273 .46955 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47273 .46955 m .4875 .49093 L p
.44666 .4874 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44259 .49135 L p
1 g
F P
s
P
p
.43485 .50826 m .44259 .49135 L .44162 .49329 L 1 g
F
P
p
.002 w
.44115 .49422 m .43438 .48848 L p
.44381 .48892 L 1 g
F P
s
P
p
.43485 .50826 m .44241 .49154 L .43776 .50145 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.4875 .49093 m .4624 .51223 L .44115 .49422 L p
1 g
F P
s
P
p
.002 w
.44259 .49135 m .44339 .4905 L p
.44903 .4851 L 1 g
F P
s
P
p
.44259 .49135 m .4875 .49093 L .44115 .49422 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45781 .47657 L p
1 g
F P
s
P
p
.45781 .47657 m .47273 .46955 L .44666 .4874 L 1 g
F
P
p
.002 w
.45781 .47657 m .45698 .47747 L p
.44903 .4851 L 1 g
F P
s
P
p
.44339 .4905 m .45781 .47657 L .44903 .4851 L 1 g
F
P
p
.002 w
.43438 .48848 m .43665 .48653 L p
.44666 .4874 L 1 g
F P
s
P
p
.44504 .48897 m .44666 .4874 L .4875 .49093 L 1 g
F
P
p
.43438 .48848 m .44666 .4874 L .44504 .48897 L 1 g
F
P
p
.44381 .48892 m .44504 .48897 L .44259 .49135 L 1 g
F
P
p
.44504 .48897 m .4875 .49093 L .44259 .49135 L 1 g
F
P
p
.002 w
.44259 .49135 m .44241 .49154 L p
.44162 .49329 L 1 g
F P
s
P
p
.002 w
.41441 .52073 m .43438 .48848 L .44115 .49422 L p
1 g
F P
s
P
p
.41441 .52073 m .43494 .50038 L .43001 .51797 L 1 g
F
P
p
.43494 .50038 m .44115 .49422 L .43421 .50902 L 1 g
F
P
p
.43494 .50038 m .43421 .50902 L .43001 .51797 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43421 .50902 L p
1 g
F P
s
P
p
.43346 .52734 m .43421 .50902 L .43323 .5207 L 1 g
F
P
p
.002 w
.44115 .49422 m .4624 .51223 L p
.43351 .51735 L 1 g
F P
s
P
p
.43001 .51797 m .43421 .50902 L .43351 .51735 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.43421 .50902 m .44115 .49422 L .43351 .51735 L 1 g
F
P
p
.002 w
.43256 .52865 m .43346 .52734 L p
.43323 .5207 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43256 .52865 L p
1 g
F P
s
P
p
.43925 .54566 m .43256 .52865 L .43292 .53011 L 1 g
F
P
p
.43925 .54566 m .43292 .53011 L .43584 .53891 L 1 g
F
P
p
.002 w
.40856 .55344 m .41441 .52073 L .43292 .53011 L p
1 g
F P
s
P
p
.40856 .55344 m .43292 .53011 L .43664 .54132 L 1 g
F
P
p
.002 w
.44158 .56231 m .40856 .55344 L p
.43508 .54199 L 1 g
F P
s
P
p
.43508 .54199 m .43664 .54132 L .43769 .54581 L 1 g
F
P
p
.43508 .54199 m .43769 .54581 L .44158 .56231 L 1 g
F
P
p
.002 w
.44233 .5585 m .44158 .56231 L p
.43769 .54581 L 1 g
F P
s
P
p
.43664 .54132 m .43853 .54702 L .43769 .54581 L 1 g
F
P
p
.43853 .54702 m .44233 .5585 L .43769 .54581 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43853 .54702 L p
1 g
F P
s
P
p
.45146 .56129 m .43853 .54702 L .44324 .55389 L 1 g
F
P
p
.45146 .56129 m .44324 .55389 L .44393 .55475 L 1 g
F
P
p
.002 w
.44158 .56231 m .44324 .55389 L p
.44832 .56019 L 1 g
F P
s
P
p
.002 w
.45111 .56365 m .44158 .56231 L p
.44709 .56057 L 1 g
F P
s
P
p
.44709 .56057 m .44832 .56019 L .45075 .56321 L 1 g
F
P
p
.44709 .56057 m .45075 .56321 L .45111 .56365 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45075 .56321 L p
1 g
F P
s
P
p
.46872 .57265 m .45075 .56321 L .45143 .5637 L 1 g
F
P
p
.46872 .57265 m .45143 .5637 L .46014 .56922 L 1 g
F
P
p
.45146 .56129 m .44368 .55453 L .44685 .55915 L 1 g
F
P
p
.002 w
.44756 .58523 m .44158 .56231 L .45111 .56365 L p
1 g
F P
s
P
p
.002 w
.45036 .56426 m .45073 .56325 L p
.44685 .55915 L 1 g
F P
s
P
p
.002 w
.45073 .56325 m .45146 .56129 L p
.44685 .55915 L 1 g
F P
s
P
p
.002 w
.45111 .56365 m .45143 .5637 L p
.45139 .56395 L 1 g
F P
s
P
p
.44756 .58523 m .45111 .56365 L .45139 .56395 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.44756 .58523 m .45143 .5637 L .46674 .57341 L 1 g
F
P
p
.002 w
.48045 .58298 m .44756 .58523 L p
.4663 .57368 L 1 g
F P
s
P
p
.4663 .57368 m .46674 .57341 L .46803 .57431 L 1 g
F
P
p
.4663 .57368 m .46803 .57431 L .48045 .58298 L 1 g
F
P
p
.48921 .57862 m .4771 .57763 L .47937 .57845 L 1 g
F
P
p
.48921 .57862 m .47937 .57845 L .48288 .5793 L 1 g
F
P
p
.002 w
.48045 .58298 m .47937 .57845 L p
.48651 .58018 L 1 g
F P
s
P
p
.002 w
.49006 .58103 m .48045 .58298 L p
.48535 .58072 L 1 g
F P
s
P
p
.48535 .58072 m .48651 .58018 L .48905 .58079 L 1 g
F
P
p
.48535 .58072 m .48905 .58079 L .49006 .58103 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58079 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58079 L .49106 .58083 L 1 g
F
P
p
.5049 .58402 m .49106 .58083 L .50873 .58082 L 1 g
F
P
p
.49977 .58082 m .49106 .58083 L .49899 .58098 L 1 g
F
P
p
.51079 .57862 m .49106 .58083 L .49977 .58082 L 1 g
F
P
p
.002 w
.49006 .58103 m .49106 .58083 L p
.5049 .58402 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.49106 .58083 m .51438 .57609 L p
.50873 .58082 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51265 .56809 m .51438 .57609 L .49006 .58103 L p
1 g
F P
s
P
p
.002 w
.48905 .58079 m .48921 .57862 L p
.48288 .5793 L 1 g
F P
s
P
p
.48651 .58018 m .51265 .56809 L .49006 .58103 L 1 g
F
P
p
.002 w
.49108 .59557 m .48045 .58298 L .49006 .58103 L p
1 g
F P
s
P
p
.49108 .59557 m .49006 .58103 L .5049 .58402 L 1 g
F
P
p
.002 w
.48905 .58079 m .48889 .583 L p
.49899 .58098 L 1 g
F P
s
P
p
.002 w
.48905 .58083 m .48905 .58079 L p
.48195 .5794 L 1 g
F P
s
P
p
.48288 .5793 m .48195 .5794 L .48905 .58079 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46833 .57442 L p
1 g
F P
s
P
p
.48921 .57862 m .46833 .57442 L .4771 .57763 L 1 g
F
P
p
.002 w
.48021 .58195 m .48045 .58298 L p
.46674 .57341 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46833 .57442 L p
1 g
F P
s
P
p
.002 w
.46833 .57442 m .46872 .57265 L p
.46014 .56922 L 1 g
F P
s
P
p
.46014 .56922 m .45002 .56518 L .46833 .57442 L 1 g
F
P
p
.002 w
.4767 .56727 m .47937 .57845 L p
.46674 .57341 L 1 g
F P
s
P
p
.002 w
.47937 .57845 m .48021 .58195 L p
.46833 .57442 L 1 g
F P
s
P
p
.46674 .57341 m .47937 .57845 L .46833 .57442 L 1 g
F
P
p
.002 w
.46833 .57442 m .4678 .57686 L p
.4771 .57763 L 1 g
F P
s
P
p
.002 w
.4767 .56727 m .51265 .56809 L p
.48651 .58018 L 1 g
F P
s
P
p
.002 w
.47937 .57845 m .4767 .56727 L p
.48651 .58018 L 1 g
F P
s
P
p
.48288 .5793 m .47937 .57845 L .48195 .5794 L 1 g
F
P
p
.002 w
.48896 .58196 m .48905 .58083 L p
.48195 .5794 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48896 .58196 L p
1 g
F P
s
P
p
.4771 .57763 m .4678 .57686 L .48896 .58196 L 1 g
F
P
p
.002 w
.45143 .5637 m .4767 .56727 L p
.46674 .57341 L 1 g
F P
s
P
p
.45782 .56829 m .45143 .5637 L .45002 .56518 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48043 .55008 m .4767 .56727 L .45143 .5637 L p
1 g
F P
s
P
p
.002 w
.45143 .5637 m .45111 .56365 L p
.45126 .56358 L 1 g
F P
s
P
p
.45126 .56358 m .48043 .55008 L .45143 .5637 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.44832 .56019 m .48043 .55008 L .45111 .56365 L 1 g
F
P
p
.002 w
.45075 .56321 m .45073 .56325 L p
.45143 .5637 L 1 g
F P
s
P
p
.002 w
.45073 .56325 m .45002 .56518 L p
.45143 .5637 L 1 g
F P
s
P
p
.46014 .56922 m .45143 .5637 L .45782 .56829 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44658 .53702 m .48043 .55008 L p
.44832 .56019 L 1 g
F P
s
P
p
.002 w
.44324 .55389 m .44658 .53702 L p
.44832 .56019 L 1 g
F P
s
P
p
.002 w
.43853 .54702 m .43925 .54566 L p
.43584 .53891 L 1 g
F P
s
P
p
.002 w
.44658 .53702 m .44324 .55389 L p
.43664 .54132 L 1 g
F P
s
P
p
.002 w
.44324 .55389 m .44233 .5585 L p
.43853 .54702 L 1 g
F P
s
P
p
.43664 .54132 m .44324 .55389 L .43853 .54702 L 1 g
F
P
p
.44368 .55453 m .44324 .55389 L .43743 .5491 L 1 g
F
P
p
.002 w
.43853 .54702 m .4382 .54764 L p
.44324 .55389 L 1 g
F P
s
P
p
.002 w
.4382 .54764 m .43743 .5491 L p
.44324 .55389 L 1 g
F P
s
P
p
.44393 .55475 m .44324 .55389 L .44368 .55453 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43853 .54702 L p
1 g
F P
s
P
p
.43584 .53891 m .43146 .53025 L .43853 .54702 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45036 .56426 L p
1 g
F P
s
P
p
.44368 .55453 m .43743 .5491 L .45036 .56426 L 1 g
F
P
p
.002 w
.43292 .53011 m .44658 .53702 L p
.43664 .54132 L 1 g
F P
s
P
p
.43437 .536 m .43292 .53011 L .43146 .53025 L 1 g
F
P
p
.002 w
.43292 .53011 m .41441 .52073 L p
.42994 .51798 L 1 g
F P
s
P
p
.002 w
.43256 .52865 m .43248 .52877 L p
.43292 .53011 L 1 g
F P
s
P
p
.002 w
.43248 .52877 m .43146 .53025 L p
.43292 .53011 L 1 g
F P
s
P
p
.43584 .53891 m .43292 .53011 L .43437 .536 L 1 g
F
P
p
.002 w
.4624 .51223 m .44658 .53702 L .43292 .53011 L p
1 g
F P
s
P
p
.42994 .51798 m .4624 .51223 L .43292 .53011 L 1 g
F
P
p
.002 w
.43421 .50902 m .43287 .51061 L p
.43323 .5207 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43256 .52865 L p
1 g
F P
s
P
p
.43323 .5207 m .43287 .51061 L .43256 .52865 L 1 g
F
P
p
.002 w
.44241 .49154 m .44166 .49233 L p
.43776 .50145 L 1 g
F P
s
P
p
.43665 .48653 m .45781 .47657 L .44666 .4874 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44259 .49135 L p
1 g
F P
s
P
p
.44903 .4851 m .45698 .47747 L .44259 .49135 L 1 g
F
P
p
.002 w
.47747 .46732 m .47718 .46778 L p
.46695 .47227 L 1 g
F P
s
P
p
.45826 .47608 m .47747 .46732 L .46695 .47227 L 1 g
F
P
p
.002 w
.45713 .47732 m .45826 .47608 L p
.46959 .47111 L 1 g
F P
s
P
p
.002 w
.43665 .48653 m .46661 .4607 L .47273 .46955 L p
1 g
F P
s
P
p
.002 w
.47273 .46955 m .46661 .4607 L p
.48175 .46506 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45713 .47732 L p
1 g
F P
s
P
p
.46959 .47111 m .47718 .46778 L .45713 .47732 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47758 .46713 L p
1 g
F P
s
P
p
.4863 .46581 m .5 .46442 L .47758 .46713 L 1 g
F
P
p
.51071 .46546 m .5158 .46628 L .51314 .46593 L 1 g
F
P
p
.5 .4634 m .5158 .46628 L .51071 .46546 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.52243 .46716 m .53385 .47271 L .5158 .46628 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47024 .45894 m .50733 .44101 L .5158 .46628 L p
1 g
F P
s
P
p
.002 w
.5158 .46628 m .51486 .46348 L p
.52243 .46716 L 1 g
F P
s
P
p
.002 w
.52243 .46716 m .52282 .46778 L p
.51314 .46593 L 1 g
F P
s
P
p
.53315 .47237 m .53385 .47271 L .53338 .47249 L 1 g
F
P
p
.52214 .46667 m .53385 .47271 L .53315 .47237 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55304 .46873 m .53385 .47271 L p
.50733 .44101 L 1 g
F P
s
P
p
.5423 .47669 m .55302 .4871 L .53897 .47512 L 1 g
F
P
p
.002 w
.51899 .47579 m .53385 .47271 L p
.553 .50394 L 1 g
F P
s
P
p
.53385 .47271 m .53897 .47512 L .553 .50394 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52259 .46741 L p
1 g
F P
s
P
p
.002 w
.52259 .46741 m .52214 .46667 L p
.53338 .47249 L 1 g
F P
s
P
p
.53338 .47249 m .54302 .47747 L .52259 .46741 L 1 g
F
P
p
.002 w
.53385 .47271 m .53744 .47197 L p
.53897 .47512 L 1 g
F P
s
P
p
.002 w
.51486 .46348 m .50733 .44101 L p
.53385 .47271 L 1 g
F P
s
P
p
.53744 .47197 m .5423 .47669 L .53897 .47512 L 1 g
F
P
p
.002 w
.5423 .47669 m .54302 .47747 L p
.53338 .47249 L 1 g
F P
s
P
p
.54986 .48403 m .55302 .4871 L .55084 .48499 L 1 g
F
P
p
.54174 .47608 m .55302 .4871 L .54986 .48403 L 1 g
F
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56381 .50445 m .553 .50394 L .55302 .4871 L p
1 g
F P
s
P
p
.002 w
.55302 .4871 m .55302 .48245 L p
.55736 .4913 L 1 g
F P
s
P
p
.55736 .4913 m .56381 .50445 L .55302 .4871 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54262 .47704 L p
1 g
F P
s
P
p
.002 w
.54262 .47704 m .54174 .47608 L p
.55084 .48499 L 1 g
F P
s
P
p
.55084 .48499 m .55834 .49233 L .54262 .47704 L 1 g
F
P
p
.002 w
.53744 .47197 m .55304 .46873 L .55302 .4871 L p
1 g
F P
s
P
p
.002 w
.55736 .4913 m .55834 .49233 L p
.55084 .48499 L 1 g
F P
s
P
p
.56245 .50167 m .56381 .50445 L .56309 .50289 L 1 g
F
P
p
.002 w
.56612 .50942 m .56713 .51061 L p
.56309 .50289 L 1 g
F P
s
P
p
.56686 .51937 m .56725 .52457 L .56697 .52009 L 1 g
F
P
p
.002 w
.56751 .52875 m .56854 .53025 L p
.56697 .52009 L 1 g
F P
s
P
p
.002 w
.56808 .52958 m .56751 .52875 L p
.56512 .5377 L 1 g
F P
s
P
p
.002 w
.56241 .53676 m .56512 .5377 L p
.54912 .56372 L 1 g
F P
s
P
p
.002 w
.56512 .5377 m .56809 .53874 L p
.56165 .54722 L 1 g
F P
s
P
p
.56512 .5377 m .56165 .54722 L .54912 .56372 L 1 g
F
P
p
.002 w
.5496 .56322 m .54912 .56372 L p
.56809 .53874 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56808 .52958 L p
1 g
F P
s
P
p
.56417 .5403 m .56257 .5491 L .56808 .52958 L 1 g
F
P
p
.002 w
.56162 .54731 m .56257 .5491 L p
.56417 .5403 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54998 .56518 L p
.55503 .55604 L 1 g
F P
s
P
p
.002 w
.54835 .56433 m .56241 .53676 L p
.54912 .56372 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55133 .53632 m .56241 .53676 L .54835 .56433 L p
1 g
F P
s
P
p
.002 w
.54835 .56433 m .54814 .56475 L .54817 .56447 L p
1 g
F P
s
P
p
.54854 .56129 m .5479 .56467 L .54812 .56451 L 1 g
F
P
p
.54854 .56129 m .54812 .56451 L .54825 .56441 L 1 g
F
P
p
.002 w
.54817 .56447 m .55133 .53632 L p
.54835 .56433 L 1 g
F P
s
P
p
.54825 .56441 m .54812 .56451 L .54825 .56442 L 1 g
F
P
p
.002 w
.54939 .56359 m .54937 .56352 L p
.54825 .56442 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51471 .55942 m .52037 .55104 L .54793 .56464 L p
1 g
F P
s
P
p
.002 w
.54793 .56464 m .54814 .56475 L .54785 .5647 L p
1 g
F P
s
P
p
.002 w
.54785 .5647 m .51471 .55942 L p
.54793 .56464 L 1 g
F P
s
P
p
.002 w
.52037 .55104 m .52904 .54389 L .548 .56459 L p
1 g
F P
s
P
p
.002 w
.548 .56459 m .54814 .56475 L .54793 .56464 L p
1 g
F P
s
P
p
.002 w
.54793 .56464 m .52037 .55104 L p
.548 .56459 L 1 g
F P
s
P
p
.5479 .56467 m .54785 .5647 L .5479 .56467 L 1 g
F
P
p
.002 w
.54944 .56371 m .54939 .56359 L p
.5479 .56467 L 1 g
F P
s
P
p
.002 w
.52904 .54389 m .53977 .53879 L .54807 .56454 L p
1 g
F P
s
P
p
.002 w
.54807 .56454 m .54814 .56475 L .548 .56459 L p
1 g
F P
s
P
p
.002 w
.548 .56459 m .52904 .54389 L p
.54807 .56454 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.53977 .53879 m .55133 .53632 L .54817 .56447 L p
1 g
F P
s
P
p
.002 w
.54817 .56447 m .54814 .56475 L .54807 .56454 L p
1 g
F P
s
P
p
.002 w
.54807 .56454 m .53977 .53879 L p
.54817 .56447 L 1 g
F P
s
P
p
.002 w
.54944 .56372 m .54944 .56371 L p
.54793 .56465 L 1 g
F P
s
P
p
.54793 .56465 m .54736 .56501 L .5479 .56468 L 1 g
F
P
p
.54793 .56465 m .5479 .56468 L .54944 .56372 L 1 g
F
P
p
.002 w
.51438 .57609 m .51265 .56809 L .54771 .56479 L p
1 g
F P
s
P
p
.002 w
.54771 .56479 m .54814 .56475 L .54736 .56501 L p
1 g
F P
s
P
p
.002 w
.54736 .56501 m .51438 .57609 L p
.54771 .56479 L 1 g
F P
s
P
p
.002 w
.51438 .57609 m .54736 .56501 L p
.53235 .57424 L 1 g
F P
s
P
p
.002 w
.54736 .56501 m .54814 .56475 L p
.53235 .57424 L 1 g
F P
s
P
p
.002 w
.5602 .58373 m .54925 .58745 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.5698 .57775 m .5602 .58373 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.54925 .58745 m .53807 .58854 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.53807 .58854 m .52785 .58687 L .54814 .56475 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54944 .56372 L p
1 g
F P
s
P
p
.53969 .56973 m .5322 .57686 L .54944 .56372 L 1 g
F
P
p
.002 w
.5172 .57956 m .51438 .57609 L p
.53309 .57417 L 1 g
F P
s
P
p
.002 w
.53171 .57463 m .5322 .57686 L p
.53969 .56973 L 1 g
F P
s
P
p
.51903 .57894 m .5172 .57956 L .51822 .57935 L 1 g
F
P
p
.002 w
.51095 .58082 m .51111 .583 L p
.51822 .57935 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58082 L p
1 g
F P
s
P
p
.49977 .58082 m .48889 .583 L .51095 .58082 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.41441 .52073 m .40856 .55344 L .37878 .54104 L p
1 g
F P
s
P
p
.002 w
.37878 .54104 m .38511 .50183 L .41441 .52073 L p
1 g
F P
s
P
p
.002 w
.3856 .43675 m .35969 .48105 L .33897 .45918 L p
1 g
F P
s
P
p
.002 w
.33897 .45918 m .3666 .41075 L .3856 .43675 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45406 .28695 m .52284 .27386 L .53055 .29802 L p
1 g
F P
s
P
p
.002 w
.59476 .30413 m .53055 .29802 L .52284 .27386 L p
1 g
F P
s
P
p
.002 w
.53055 .29802 m .59476 .30413 L .59889 .33238 L p
1 g
F P
s
P
p
.002 w
.62787 .44841 m .65137 .47109 L .63098 .49803 L p
1 g
F P
s
P
p
.002 w
.65137 .47109 m .62787 .44841 L .6393 .41579 L p
1 g
F P
s
P
p
.002 w
.46265 .31109 m .40035 .34186 L .39103 .31821 L p
1 g
F P
s
P
p
.002 w
.39103 .31821 m .45406 .28695 L .46265 .31109 L p
1 g
F P
s
P
p
.002 w
.58116 .56167 m .58166 .55323 L .61242 .53814 L p
1 g
F P
s
P
p
.002 w
.60638 .52323 m .61242 .53814 L .58166 .55323 L p
1 g
F P
s
P
p
.002 w
.61242 .53814 m .60638 .52323 L .63098 .49803 L p
1 g
F P
s
P
p
.002 w
.413 .36892 m .3666 .41075 L .35204 .38594 L p
1 g
F P
s
P
p
.002 w
.35204 .38594 m .40035 .34186 L .413 .36892 L p
1 g
F P
s
P
p
.002 w
.60009 .36431 m .64636 .38411 L .6393 .41579 L p
1 g
F P
s
P
p
.002 w
.64636 .38411 m .60009 .36431 L .59889 .33238 L p
1 g
F P
s
P
p
.004 w
.6407 .36954 m
.67275 .35565 L
s
P
p
.002 w
.53055 .29802 m .46265 .31109 L .45406 .28695 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40846 .46299 m .38511 .50183 L .35969 .48105 L p
1 g
F P
s
P
p
.002 w
.35969 .48105 m .3856 .43675 L .40846 .46299 L p
1 g
F P
s
P
p
.002 w
.58166 .55323 m .57844 .54574 L .60638 .52323 L p
1 g
F P
s
P
p
.002 w
.61242 .48078 m .63098 .49803 L .60638 .52323 L p
1 g
F P
s
P
p
.002 w
.63098 .49803 m .61242 .48078 L .62787 .44841 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.5935 .51171 m .60638 .52323 L .57844 .54574 L p
1 g
F P
s
P
p
.002 w
.60638 .52323 m .5935 .51171 L .61242 .48078 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59823 .39883 m .6393 .41579 L .62787 .44841 L p
1 g
F P
s
P
p
.002 w
.6393 .41579 m .59823 .39883 L .60009 .36431 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.59883 .38768 L
s
P
p
.004 w
.62399 .37678 m
.6407 .36954 L
s
P
p
.004 w
.61589 .38029 m
.61684 .37988 L
s
P
p
.004 w
.61684 .37988 m
.62399 .37678 L
s
P
p
.002 w
.57844 .54574 m .57179 .54003 L .5935 .51171 L p
1 g
F P
s
P
p
.002 w
.53753 .32695 m .59889 .33238 L .60009 .36431 L p
1 g
F P
s
P
p
.002 w
.59889 .33238 m .53753 .32695 L .53055 .29802 L p
1 g
F P
s
P
p
.002 w
.51471 .55942 m .51265 .56809 L .4767 .56727 L p
1 g
F P
s
P
p
.002 w
.4767 .56727 m .48043 .55008 L .51471 .55942 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46265 .31109 m .53055 .29802 L .53753 .32695 L p
1 g
F P
s
P
p
.002 w
.43438 .48848 m .41441 .52073 L .38511 .50183 L p
1 g
F P
s
P
p
.002 w
.38511 .50183 m .40846 .46299 L .43438 .48848 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42864 .39849 m .3856 .43675 L .3666 .41075 L p
1 g
F P
s
P
p
.002 w
.3666 .41075 m .413 .36892 L .42864 .39849 L p
1 g
F P
s
P
p
.002 w
.47264 .33961 m .413 .36892 L .40035 .34186 L p
1 g
F P
s
P
p
.002 w
.40035 .34186 m .46265 .31109 L .47264 .33961 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57503 .50498 m .5935 .51171 L .57179 .54003 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52037 .55104 m .51471 .55942 L .48043 .55008 L p
1 g
F P
s
P
p
.002 w
.5933 .43469 m .62787 .44841 L .61242 .48078 L p
1 g
F P
s
P
p
.002 w
.62787 .44841 m .5933 .43469 L .59823 .39883 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.53753 .32695 m .47264 .33961 L .46265 .31109 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5935 .51171 m .57503 .50498 L .58546 .47053 L p
1 g
F P
s
P
p
.002 w
.58546 .47053 m .61242 .48078 L .5935 .51171 L p
1 g
F P
s
P
p
.002 w
.56241 .53676 m .55133 .53632 L .553 .50394 L p
1 g
F P
s
P
p
.002 w
.61242 .48078 m .58546 .47053 L .5933 .43469 L p
1 g
F P
s
P
p
.002 w
.52904 .54389 m .52037 .55104 L .49143 .53334 L p
1 g
F P
s
P
p
.002 w
.48043 .55008 m .49143 .53334 L .52037 .55104 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.49143 .53334 m .48043 .55008 L .44658 .53702 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5435 .35972 m .60009 .36431 L .59823 .39883 L p
1 g
F P
s
P
p
.002 w
.60009 .36431 m .5435 .35972 L .53753 .32695 L p
1 g
F P
s
P
p
.002 w
.44658 .53702 m .4624 .51223 L .49143 .53334 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55133 .53632 m .53977 .53879 L .52994 .5088 L p
1 g
F P
s
P
p
.002 w
.52994 .5088 m .553 .50394 L .55133 .53632 L p
1 g
F P
s
P
p
.002 w
.53977 .53879 m .52904 .54389 L .50858 .519 L p
1 g
F P
s
P
p
.002 w
.49143 .53334 m .50858 .519 L .52904 .54389 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.50858 .519 m .52994 .5088 L .53977 .53879 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44673 .42947 m .40846 .46299 L .3856 .43675 L p
1 g
F P
s
P
p
.002 w
.3856 .43675 m .42864 .39849 L .44673 .42947 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.47264 .33961 m .53753 .32695 L .5435 .35972 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.48369 .37156 m .42864 .39849 L .413 .36892 L p
1 g
F P
s
P
p
.002 w
.413 .36892 m .47264 .33961 L .48369 .37156 L p
1 g
F P
s
P
p
.002 w
.55304 .46873 m .58546 .47053 L .57503 .50498 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.5482 .39519 m .59823 .39883 L .5933 .43469 L p
1 g
F P
s
P
p
.002 w
.59823 .39883 m .5482 .39519 L .5435 .35972 L p
1 g
F P
s
P
p
.002 w
.50858 .519 m .49143 .53334 L .4624 .51223 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46661 .4607 m .43438 .48848 L .40846 .46299 L p
1 g
F P
s
P
p
.002 w
.40846 .46299 m .44673 .42947 L .46661 .4607 L p
1 g
F P
s
P
p
.002 w
.5435 .35972 m .48369 .37156 L .47264 .33961 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.58546 .47053 m .55304 .46873 L .55142 .432 L p
1 g
F P
s
P
p
.002 w
.55142 .432 m .5933 .43469 L .58546 .47053 L p
1 g
F P
s
P
p
.002 w
.5933 .43469 m .55142 .432 L .5482 .39519 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.553 .50394 m .52994 .5088 L .51899 .47579 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.4624 .51223 m .4875 .49093 L .50858 .519 L p
1 g
F P
s
P
p
.002 w
.52994 .5088 m .50858 .519 L .4875 .49093 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.4875 .49093 m .51899 .47579 L .52994 .5088 L p
1 g
F P
s
P
p
.002 w
.48369 .37156 m .5435 .35972 L .5482 .39519 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49541 .40581 m .44673 .42947 L .42864 .39849 L p
1 g
F P
s
P
p
.002 w
.42864 .39849 m .48369 .37156 L .49541 .40581 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.56461 .61067 m
.56786 .61973 L
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50733 .44101 m .55142 .432 L .55304 .46873 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.5482 .39519 m .49541 .40581 L .48369 .37156 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.49541 .40581 m .5482 .39519 L .55142 .432 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50733 .44101 m .46661 .4607 L .44673 .42947 L p
1 g
F P
s
P
p
.002 w
.44673 .42947 m .49541 .40581 L .50733 .44101 L p
1 g
F P
s
P
p
.002 w
.55142 .432 m .50733 .44101 L .49541 .40581 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .68718 .3494 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57642 .6436 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.075969)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.075969)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.43559 .46431 m .4824 .46956 L .4819 .44116 L p
1 g
F P
s
P
p
.002 w
.4819 .44116 m .44091 .43639 L .43559 .46431 L p
1 g
F P
s
P
p
.002 w
.52351 .43602 m .4819 .44116 L .4824 .46956 L p
1 g
F P
s
P
p
.002 w
.44091 .43639 m .4819 .44116 L .48184 .41258 L p
1 g
F P
s
P
p
.002 w
.4819 .44116 m .52351 .43602 L .51659 .40828 L p
1 g
F P
s
P
p
.002 w
.51659 .40828 m .48184 .41258 L .4819 .44116 L p
1 g
F P
s
P
p
.002 w
.4824 .46956 m .52988 .4637 L .52351 .43602 L p
1 g
F P
s
P
p
.002 w
.56198 .42141 m .52351 .43602 L .52988 .4637 L p
1 g
F P
s
P
p
.002 w
.52351 .43602 m .56198 .42141 L .54865 .39594 L p
1 g
F P
s
P
p
.002 w
.54865 .39594 m .51659 .40828 L .52351 .43602 L p
1 g
F P
s
P
p
.002 w
.48184 .41258 m .44764 .40845 L .44091 .43639 L p
1 g
F P
s
P
p
.002 w
.44764 .40845 m .48184 .41258 L .48222 .38431 L p
1 g
F P
s
P
p
.002 w
.48184 .41258 m .51659 .40828 L .50924 .38096 L p
1 g
F P
s
P
p
.002 w
.50924 .38096 m .48222 .38431 L .48184 .41258 L p
1 g
F P
s
P
p
.002 w
.51659 .40828 m .54865 .39594 L .53411 .37126 L p
1 g
F P
s
P
p
.002 w
.53411 .37126 m .50924 .38096 L .51659 .40828 L p
1 g
F P
s
P
p
.002 w
.43179 .49168 m .48333 .49725 L .4824 .46956 L p
1 g
F P
s
P
p
.002 w
.4824 .46956 m .43559 .46431 L .43179 .49168 L p
1 g
F P
s
P
p
.002 w
.52988 .4637 m .4824 .46956 L .48333 .49725 L p
1 g
F P
s
P
p
.002 w
.48333 .49725 m .53557 .49081 L .52988 .4637 L p
1 g
F P
s
P
p
.002 w
.57387 .44723 m .52988 .4637 L .53557 .49081 L p
1 g
F P
s
P
p
.002 w
.52988 .4637 m .57387 .44723 L .56198 .42141 L p
1 g
F P
s
P
p
.002 w
.48222 .38431 m .45565 .381 L .44764 .40845 L p
1 g
F P
s
P
p
.002 w
.45565 .381 m .48222 .38431 L .48304 .35689 L p
1 g
F P
s
P
p
.002 w
.48222 .38431 m .50924 .38096 L .50159 .35458 L p
1 g
F P
s
P
p
.002 w
.50159 .35458 m .48304 .35689 L .48222 .38431 L p
1 g
F P
s
P
p
.002 w
.50924 .38096 m .53411 .37126 L .51862 .34785 L p
1 g
F P
s
P
p
.002 w
.51862 .34785 m .50159 .35458 L .50924 .38096 L p
1 g
F P
s
P
p
.002 w
.40428 .42197 m .44091 .43639 L .44764 .40845 L p
1 g
F P
s
P
p
.002 w
.44764 .40845 m .41721 .39616 L .40428 .42197 L p
1 g
F P
s
P
p
.002 w
.41721 .39616 m .44764 .40845 L .45565 .381 L p
1 g
F P
s
P
p
.002 w
.39362 .44819 m .43559 .46431 L .44091 .43639 L p
1 g
F P
s
P
p
.002 w
.44091 .43639 m .40428 .42197 L .39362 .44819 L p
1 g
F P
s
P
p
.002 w
.57495 .3766 m .54865 .39594 L .56198 .42141 L p
1 g
F P
s
P
p
.002 w
.54865 .39594 m .57495 .3766 L .55437 .35608 L p
1 g
F P
s
P
p
.002 w
.55437 .35608 m .53411 .37126 L .54865 .39594 L p
1 g
F P
s
P
p
.002 w
.59374 .3985 m .56198 .42141 L .57387 .44723 L p
1 g
F P
s
P
p
.002 w
.56198 .42141 m .59374 .3985 L .57495 .3766 L p
1 g
F P
s
P
p
.002 w
.45565 .381 m .43213 .37125 L .41721 .39616 L p
1 g
F P
s
P
p
.002 w
.43213 .37125 m .45565 .381 L .46482 .35453 L p
1 g
F P
s
P
p
.002 w
.48304 .35689 m .46482 .35453 L .45565 .381 L p
1 g
F P
s
P
p
.002 w
.53411 .37126 m .55437 .35608 L .5324 .33733 L p
1 g
F P
s
P
p
.002 w
.5324 .33733 m .51862 .34785 L .53411 .37126 L p
1 g
F P
s
P
p
.002 w
.42963 .51798 m .48469 .52371 L .48333 .49725 L p
1 g
F P
s
P
p
.002 w
.48333 .49725 m .43179 .49168 L .42963 .51798 L p
1 g
F P
s
P
p
.002 w
.53557 .49081 m .48333 .49725 L .48469 .52371 L p
1 g
F P
s
P
p
.002 w
.48469 .52371 m .54048 .51684 L .53557 .49081 L p
1 g
F P
s
P
p
.002 w
.58406 .4729 m .53557 .49081 L .54048 .51684 L p
1 g
F P
s
P
p
.002 w
.53557 .49081 m .58406 .4729 L .57387 .44723 L p
1 g
F P
s
P
p
.002 w
.38546 .47433 m .43179 .49168 L .43559 .46431 L p
1 g
F P
s
P
p
.002 w
.43559 .46431 m .39362 .44819 L .38546 .47433 L p
1 g
F P
s
P
p
.002 w
.46482 .35453 m .48304 .35689 L .48428 .33082 L p
1 g
F P
s
P
p
.002 w
.48304 .35689 m .50159 .35458 L .49378 .32964 L p
1 g
F P
s
P
p
.002 w
.49378 .32964 m .48428 .33082 L .48304 .35689 L p
1 g
F P
s
P
p
.002 w
.61037 .42138 m .57387 .44723 L .58406 .4729 L p
1 g
F P
s
P
p
.002 w
.57387 .44723 m .61037 .42138 L .59374 .3985 L p
1 g
F P
s
P
p
.002 w
.50159 .35458 m .51862 .34785 L .50247 .32616 L p
1 g
F P
s
P
p
.002 w
.50247 .32616 m .49378 .32964 L .50159 .35458 L p
1 g
F P
s
P
p
.002 w
.46482 .35453 m .44877 .34773 L .43213 .37125 L p
1 g
F P
s
P
p
.002 w
.44877 .34773 m .46482 .35453 L .47497 .32958 L p
1 g
F P
s
P
p
.002 w
.48428 .33082 m .47497 .32958 L .46482 .35453 L p
1 g
F P
s
P
p
.002 w
.51862 .34785 m .5324 .33733 L .50945 .32074 L p
1 g
F P
s
P
p
.002 w
.50945 .32074 m .50247 .32616 L .51862 .34785 L p
1 g
F P
s
P
p
.002 w
.37566 .39891 m .40428 .42197 L .41721 .39616 L p
1 g
F P
s
P
p
.002 w
.41721 .39616 m .39362 .37665 L .37566 .39891 L p
1 g
F P
s
P
p
.002 w
.39362 .37665 m .41721 .39616 L .43213 .37125 L p
1 g
F P
s
P
p
.002 w
.43213 .37125 m .41407 .35591 L .39362 .37665 L p
1 g
F P
s
P
p
.002 w
.41407 .35591 m .43213 .37125 L .44877 .34773 L p
1 g
F P
s
P
p
.002 w
.38003 .49984 m .42963 .51798 L .43179 .49168 L p
1 g
F P
s
P
p
.002 w
.43179 .49168 m .38546 .47433 L .38003 .49984 L p
1 g
F P
s
P
p
.002 w
.56788 .3368 m .55437 .35608 L .57495 .3766 L p
1 g
F P
s
P
p
.002 w
.55437 .35608 m .56788 .3368 L .54144 .32405 L p
1 g
F P
s
P
p
.002 w
.54144 .32405 m .5324 .33733 L .55437 .35608 L p
1 g
F P
s
P
p
.002 w
.59274 .35193 m .57495 .3766 L .59374 .3985 L p
1 g
F P
s
P
p
.002 w
.57495 .3766 m .59274 .35193 L .56788 .3368 L p
1 g
F P
s
P
p
.002 w
.54048 .51684 m .59234 .49794 L .58406 .4729 L p
1 g
F P
s
P
p
.002 w
.62448 .4448 m .58406 .4729 L .59234 .49794 L p
1 g
F P
s
P
p
.002 w
.58406 .4729 m .62448 .4448 L .61037 .42138 L p
1 g
F P
s
P
p
.002 w
.42918 .54266 m .48645 .5484 L .48469 .52371 L p
1 g
F P
s
P
p
.002 w
.48469 .52371 m .42963 .51798 L .42918 .54266 L p
1 g
F P
s
P
p
.002 w
.54048 .51684 m .48469 .52371 L .48645 .5484 L p
1 g
F P
s
P
p
.002 w
.48645 .5484 m .54448 .54127 L .54048 .51684 L p
1 g
F P
s
P
p
.002 w
.59234 .49794 m .54048 .51684 L .54448 .54127 L p
1 g
F P
s
P
p
.002 w
.36059 .42226 m .39362 .44819 L .40428 .42197 L p
1 g
F P
s
P
p
.002 w
.40428 .42197 m .37566 .39891 L .36059 .42226 L p
1 g
F P
s
P
p
.002 w
.44877 .34773 m .43658 .33709 L .41407 .35591 L p
1 g
F P
s
P
p
.002 w
.43658 .33709 m .44877 .34773 L .46682 .32604 L p
1 g
F P
s
P
p
.002 w
.47497 .32958 m .46682 .32604 L .44877 .34773 L p
1 g
F P
s
P
p
.002 w
.5324 .33733 m .54144 .32405 L .51395 .31393 L p
1 g
F P
s
P
p
.002 w
.51395 .31393 m .50945 .32074 L .5324 .33733 L p
1 g
F P
s
P
p
.002 w
.6155 .36916 m .59374 .3985 L .61037 .42138 L p
1 g
F P
s
P
p
.002 w
.59374 .3985 m .6155 .36916 L .59274 .35193 L p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .47497 .32958 L .48428 .33082 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .48428 .33082 L .49378 .32964 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .49378 .32964 L .50247 .32616 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .46682 .32604 L .47497 .32958 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .50247 .32616 L .50945 .32074 L closepath p
1 g
F P
s
P
p
.002 w
.34879 .44623 m .38546 .47433 L .39362 .44819 L p
1 g
F P
s
P
p
.002 w
.39362 .44819 m .36059 .42226 L .34879 .44623 L p
1 g
F P
s
P
p
.002 w
.46682 .32604 m .4607 .32056 L .43658 .33709 L p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .4607 .32056 L .46682 .32604 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .50945 .32074 L .51395 .31393 L closepath p
1 g
F P
s
P
p
.002 w
.63566 .38818 m .61037 .42138 L .62448 .4448 L p
1 g
F P
s
P
p
.002 w
.61037 .42138 m .63566 .38818 L .6155 .36916 L p
1 g
F P
s
P
p
.002 w
.37753 .52419 m .42918 .54266 L .42963 .51798 L p
1 g
F P
s
P
p
.002 w
.42963 .51798 m .38003 .49984 L .37753 .52419 L p
1 g
F P
s
P
p
.002 w
.40351 .33638 m .41407 .35591 L .43658 .33709 L p
1 g
F P
s
P
p
.002 w
.43658 .33709 m .4296 .32367 L .40351 .33638 L p
1 g
F P
s
P
p
.002 w
.4296 .32367 m .43658 .33709 L .4607 .32056 L p
1 g
F P
s
P
p
.002 w
.37957 .35162 m .39362 .37665 L .41407 .35591 L p
1 g
F P
s
P
p
.002 w
.41407 .35591 m .40351 .33638 L .37957 .35162 L p
1 g
F P
s
P
p
.002 w
.54471 .30934 m .54144 .32405 L .56788 .3368 L p
1 g
F P
s
P
p
.002 w
.54144 .32405 m .54471 .30934 L .51548 .30645 L p
1 g
F P
s
P
p
.002 w
.51548 .30645 m .51395 .31393 L .54144 .32405 L p
1 g
F P
s
P
p
.002 w
.54448 .54127 m .59848 .52183 L .59234 .49794 L p
1 g
F P
s
P
p
.002 w
.63572 .4683 m .59234 .49794 L .59848 .52183 L p
1 g
F P
s
P
p
.002 w
.59234 .49794 m .63572 .4683 L .62448 .4448 L p
1 g
F P
s
P
p
.002 w
.57304 .31529 m .56788 .3368 L .59274 .35193 L p
1 g
F P
s
P
p
.002 w
.56788 .3368 m .57304 .31529 L .54471 .30934 L p
1 g
F P
s
P
p
.002 w
.4607 .32056 m .45727 .3137 L .4296 .32367 L p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .45727 .3137 L .4607 .32056 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .51395 .31393 L .51548 .30645 L closepath p
1 g
F P
s
P
p
.002 w
.43052 .56514 m .4886 .57078 L .48645 .5484 L p
1 g
F P
s
P
p
.002 w
.48645 .5484 m .42918 .54266 L .43052 .56514 L p
1 g
F P
s
P
p
.002 w
.54448 .54127 m .48645 .5484 L .4886 .57078 L p
1 g
F P
s
P
p
.002 w
.35831 .36911 m .37566 .39891 L .39362 .37665 L p
1 g
F P
s
P
p
.002 w
.39362 .37665 m .37957 .35162 L .35831 .36911 L p
1 g
F P
s
P
p
.002 w
.4886 .57078 m .54747 .56355 L .54448 .54127 L p
1 g
F P
s
P
p
.002 w
.59848 .52183 m .54448 .54127 L .54747 .56355 L p
1 g
F P
s
P
p
.002 w
.59985 .32423 m .59274 .35193 L .6155 .36916 L p
1 g
F P
s
P
p
.002 w
.59274 .35193 m .59985 .32423 L .57304 .31529 L p
1 g
F P
s
P
p
.002 w
.34063 .47034 m .38003 .49984 L .38546 .47433 L p
1 g
F P
s
P
p
.002 w
.38546 .47433 m .34879 .44623 L .34063 .47034 L p
1 g
F P
s
P
p
.002 w
.42872 .30882 m .4296 .32367 L .45727 .3137 L p
1 g
F P
s
P
p
.002 w
.45727 .3137 m .45696 .30617 L .42872 .30882 L p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .45696 .30617 L .45727 .3137 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .5019 .28789 L .49288 .28532 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .49288 .28532 L .4831 .28526 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .4831 .28526 L .47365 .28772 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .47365 .28772 L .46559 .29241 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .46559 .29241 L .45982 .29881 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .45982 .29881 L .45696 .30617 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .51548 .30645 L .51384 .29909 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .51384 .29909 L .50915 .29266 L closepath p
1 g
F P
s
P
p
.002 w
.48595 .30666 m .50915 .29266 L .5019 .28789 L closepath p
1 g
F P
s
P
p
.002 w
.51384 .29909 m .51548 .30645 L .54471 .30934 L p
1 g
F P
s
P
p
.002 w
.65273 .40863 m .62448 .4448 L .63572 .4683 L p
1 g
F P
s
P
p
.002 w
.62448 .4448 m .65273 .40863 L .63566 .38818 L p
1 g
F P
s
P
p
.002 w
.40186 .31459 m .40351 .33638 L .4296 .32367 L p
1 g
F P
s
P
p
.002 w
.4296 .32367 m .42872 .30882 L .40186 .31459 L p
1 g
F P
s
P
p
.002 w
.34029 .38852 m .36059 .42226 L .37566 .39891 L p
1 g
F P
s
P
p
.002 w
.37566 .39891 m .35831 .36911 L .34029 .38852 L p
1 g
F P
s
P
p
.002 w
.5417 .29474 m .54471 .30934 L .57304 .31529 L p
1 g
F P
s
P
p
.002 w
.54471 .30934 m .5417 .29474 L .51384 .29909 L p
1 g
F P
s
P
p
.002 w
.62456 .33603 m .6155 .36916 L .63566 .38818 L p
1 g
F P
s
P
p
.002 w
.6155 .36916 m .62456 .33603 L .59985 .32423 L p
1 g
F P
s
P
p
.002 w
.4342 .29415 m .42872 .30882 L .45696 .30617 L p
1 g
F P
s
P
p
.002 w
.45696 .30617 m .45982 .29881 L .4342 .29415 L p
1 g
F P
s
P
p
.002 w
.50915 .29266 m .51384 .29909 L .5417 .29474 L p
1 g
F P
s
P
p
.002 w
.37813 .54679 m .43052 .56514 L .42918 .54266 L p
1 g
F P
s
P
p
.002 w
.42918 .54266 m .37753 .52419 L .37813 .54679 L p
1 g
F P
s
P
p
.002 w
.54747 .56355 m .60228 .54404 L .59848 .52183 L p
1 g
F P
s
P
p
.002 w
.64376 .49139 m .59848 .52183 L .60228 .54404 L p
1 g
F P
s
P
p
.002 w
.59848 .52183 m .64376 .49139 L .63572 .4683 L p
1 g
F P
s
P
p
.002 w
.377 .32346 m .37957 .35162 L .40351 .33638 L p
1 g
F P
s
P
p
.002 w
.40351 .33638 m .40186 .31459 L .377 .32346 L p
1 g
F P
s
P
p
.002 w
.56896 .29378 m .57304 .31529 L .59985 .32423 L p
1 g
F P
s
P
p
.002 w
.57304 .31529 m .56896 .29378 L .5417 .29474 L p
1 g
F P
s
P
p
.002 w
.44557 .28132 m .4342 .29415 L .45982 .29881 L p
1 g
F P
s
P
p
.002 w
.45982 .29881 m .46559 .29241 L .44557 .28132 L p
1 g
F P
s
P
p
.002 w
.5417 .29474 m .53258 .28188 L .50915 .29266 L p
1 g
F P
s
P
p
.002 w
.5019 .28789 m .50915 .29266 L .53258 .28188 L p
1 g
F P
s
P
p
.002 w
.33641 .49402 m .37753 .52419 L .38003 .49984 L p
1 g
F P
s
P
p
.002 w
.38003 .49984 m .34063 .47034 L .33641 .49402 L p
1 g
F P
s
P
p
.002 w
.32601 .40948 m .34879 .44623 L .36059 .42226 L p
1 g
F P
s
P
p
.002 w
.36059 .42226 m .34029 .38852 L .32601 .40948 L p
1 g
F P
s
P
p
.002 w
.43369 .58485 m .49111 .59026 L .4886 .57078 L p
1 g
F P
s
P
p
.002 w
.4886 .57078 m .43052 .56514 L .43369 .58485 L p
1 g
F P
s
P
p
.002 w
.54747 .56355 m .4886 .57078 L .49111 .59026 L p
1 g
F P
s
P
p
.002 w
.66625 .43009 m .63572 .4683 L .64376 .49139 L p
1 g
F P
s
P
p
.002 w
.63572 .4683 m .66625 .43009 L .65273 .40863 L p
1 g
F P
s
P
p
.002 w
.40966 .29289 m .40186 .31459 L .42872 .30882 L p
1 g
F P
s
P
p
.002 w
.42872 .30882 m .4342 .29415 L .40966 .29289 L p
1 g
F P
s
P
p
.002 w
.49111 .59026 m .54933 .58312 L .54747 .56355 L p
1 g
F P
s
P
p
.002 w
.60228 .54404 m .54747 .56355 L .54933 .58312 L p
1 g
F P
s
P
p
.002 w
.53258 .28188 m .5417 .29474 L .56896 .29378 L p
1 g
F P
s
P
p
.002 w
.64655 .3505 m .63566 .38818 L .65273 .40863 L p
1 g
F P
s
P
p
.002 w
.63566 .38818 m .64655 .3505 L .62456 .33603 L p
1 g
F P
s
P
p
.002 w
.46163 .27185 m .44557 .28132 L .46559 .29241 L p
1 g
F P
s
P
p
.002 w
.46559 .29241 m .47365 .28772 L .46163 .27185 L p
1 g
F P
s
P
p
.002 w
.49288 .28532 m .5019 .28789 L .51824 .27225 L p
1 g
F P
s
P
p
.002 w
.53258 .28188 m .51824 .27225 L .5019 .28789 L p
1 g
F P
s
P
p
.002 w
.35475 .33533 m .35831 .36911 L .37957 .35162 L p
1 g
F P
s
P
p
.002 w
.37957 .35162 m .377 .32346 L .35475 .33533 L p
1 g
F P
s
P
p
.002 w
.48059 .26689 m .46163 .27185 L .47365 .28772 L p
1 g
F P
s
P
p
.002 w
.47365 .28772 m .4831 .28526 L .48059 .26689 L p
1 g
F P
s
P
p
.002 w
.51824 .27225 m .50022 .26704 L .49288 .28532 L p
1 g
F P
s
P
p
.002 w
.4831 .28526 m .49288 .28532 L .50022 .26704 L p
1 g
F P
s
P
p
.002 w
.59501 .29631 m .59985 .32423 L .62456 .33603 L p
1 g
F P
s
P
p
.002 w
.59985 .32423 m .59501 .29631 L .56896 .29378 L p
1 g
F P
s
P
p
.002 w
.50022 .26704 m .48059 .26689 L .4831 .28526 L p
1 g
F P
s
P
p
.002 w
.42634 .27377 m .40966 .29289 L .4342 .29415 L p
1 g
F P
s
P
p
.002 w
.4342 .29415 m .44557 .28132 L .42634 .27377 L p
1 g
F P
s
P
p
.002 w
.38195 .56704 m .43369 .58485 L .43052 .56514 L p
1 g
F P
s
P
p
.002 w
.43052 .56514 m .37813 .54679 L .38195 .56704 L p
1 g
F P
s
P
p
.002 w
.3868 .29518 m .377 .32346 L .40186 .31459 L p
1 g
F P
s
P
p
.002 w
.40186 .31459 m .40966 .29289 L .3868 .29518 L p
1 g
F P
s
P
p
.002 w
.31596 .43155 m .34063 .47034 L .34879 .44623 L p
1 g
F P
s
P
p
.002 w
.34879 .44623 m .32601 .40948 L .31596 .43155 L p
1 g
F P
s
P
p
.002 w
.56896 .29378 m .55575 .27467 L .53258 .28188 L p
1 g
F P
s
P
p
.002 w
.51824 .27225 m .53258 .28188 L .55575 .27467 L p
1 g
F P
s
P
p
.002 w
.54933 .58312 m .60356 .56401 L .60228 .54404 L p
1 g
F P
s
P
p
.002 w
.64829 .51355 m .60228 .54404 L .60356 .56401 L p
1 g
F P
s
P
p
.002 w
.60228 .54404 m .64829 .51355 L .64376 .49139 L p
1 g
F P
s
P
p
.002 w
.55575 .27467 m .56896 .29378 L .59501 .29631 L p
1 g
F P
s
P
p
.002 w
.3364 .51671 m .37813 .54679 L .37753 .52419 L p
1 g
F P
s
P
p
.002 w
.37753 .52419 m .33641 .49402 L .3364 .51671 L p
1 g
F P
s
P
p
.002 w
.66524 .36742 m .65273 .40863 L .66625 .43009 L p
1 g
F P
s
P
p
.002 w
.65273 .40863 m .66524 .36742 L .64655 .3505 L p
1 g
F P
s
P
p
.002 w
.33574 .35002 m .34029 .38852 L .35831 .36911 L p
1 g
F P
s
P
p
.002 w
.35831 .36911 m .35475 .33533 L .33574 .35002 L p
1 g
F P
s
P
p
.002 w
.67577 .45213 m .64376 .49139 L .64829 .51355 L p
1 g
F P
s
P
p
.002 w
.64376 .49139 m .67577 .45213 L .66625 .43009 L p
1 g
F P
s
P
p
.002 w
.6192 .30241 m .62456 .33603 L .64655 .3505 L p
1 g
F P
s
P
p
.002 w
.62456 .33603 m .6192 .30241 L .59501 .29631 L p
1 g
F P
s
P
p
.002 w
.4502 .25958 m .42634 .27377 L .44557 .28132 L p
1 g
F P
s
P
p
.002 w
.44557 .28132 m .46163 .27185 L .4502 .25958 L p
1 g
F P
s
P
p
.002 w
.55575 .27467 m .53461 .26025 L .51824 .27225 L p
1 g
F P
s
P
p
.002 w
.50022 .26704 m .51824 .27225 L .53461 .26025 L p
1 g
F P
s
P
p
.002 w
.43873 .6012 m .49394 .60627 L .49111 .59026 L p
1 g
F P
s
P
p
.002 w
.49111 .59026 m .43369 .58485 L .43873 .6012 L p
1 g
F P
s
P
p
.002 w
.54933 .58312 m .49111 .59026 L .49394 .60627 L p
1 g
F P
s
P
p
.002 w
.49394 .60627 m .54997 .5994 L .54933 .58312 L p
1 g
F P
s
P
p
.002 w
.60356 .56401 m .54933 .58312 L .54997 .5994 L p
1 g
F P
s
P
p
.002 w
.36623 .30114 m .35475 .33533 L .377 .32346 L p
1 g
F P
s
P
p
.002 w
.377 .32346 m .3868 .29518 L .36623 .30114 L p
1 g
F P
s
P
p
.002 w
.47849 .25213 m .4502 .25958 L .46163 .27185 L p
1 g
F P
s
P
p
.002 w
.46163 .27185 m .48059 .26689 L .47849 .25213 L p
1 g
F P
s
P
p
.002 w
.53461 .26025 m .50781 .25238 L .50022 .26704 L p
1 g
F P
s
P
p
.002 w
.48059 .26689 m .50022 .26704 L .50781 .25238 L p
1 g
F P
s
P
p
.002 w
.31055 .45423 m .33641 .49402 L .34063 .47034 L p
1 g
F P
s
P
p
.002 w
.34063 .47034 m .31596 .43155 L .31055 .45423 L p
1 g
F P
s
P
p
.002 w
.57813 .27132 m .59501 .29631 L .6192 .30241 L p
1 g
F P
s
P
p
.002 w
.59501 .29631 m .57813 .27132 L .55575 .27467 L p
1 g
F P
s
P
p
.002 w
.40841 .2701 m .3868 .29518 L .40966 .29289 L p
1 g
F P
s
P
p
.002 w
.40966 .29289 m .42634 .27377 L .40841 .2701 L p
1 g
F P
s
P
p
.002 w
.50781 .25238 m .47849 .25213 L .48059 .26689 L p
1 g
F P
s
P
p
.002 w
.32057 .3673 m .32601 .40948 L .34029 .38852 L p
1 g
F P
s
P
p
.002 w
.34029 .38852 m .33574 .35002 L .32057 .3673 L p
1 g
F P
s
P
p
.002 w
.53461 .26025 m .55575 .27467 L .57813 .27132 L p
1 g
F P
s
P
p
.002 w
.68005 .38645 m .66625 .43009 L .67577 .45213 L p
1 g
F P
s
P
p
.002 w
.66625 .43009 m .68005 .38645 L .66524 .36742 L p
1 g
F P
s
P
p
.002 w
.6409 .31206 m .64655 .3505 L .66524 .36742 L p
1 g
F P
s
P
p
.002 w
.64655 .3505 m .6409 .31206 L .6192 .30241 L p
1 g
F P
s
P
p
.002 w
.38906 .58435 m .43873 .6012 L .43369 .58485 L p
1 g
F P
s
P
p
.002 w
.43369 .58485 m .38195 .56704 L .38906 .58435 L p
1 g
F P
s
P
p
.002 w
.3408 .5378 m .38195 .56704 L .37813 .54679 L p
1 g
F P
s
P
p
.002 w
.37813 .54679 m .3364 .51671 L .3408 .5378 L p
1 g
F P
s
P
p
.002 w
.54997 .5994 m .60215 .58116 L .60356 .56401 L p
1 g
F P
s
P
p
.002 w
.64907 .53421 m .60356 .56401 L .60215 .58116 L p
1 g
F P
s
P
p
.002 w
.60356 .56401 m .64907 .53421 L .64829 .51355 L p
1 g
F P
s
P
p
.002 w
.6809 .47424 m .64829 .51355 L .64907 .53421 L p
1 g
F P
s
P
p
.002 w
.64829 .51355 m .6809 .47424 L .67577 .45213 L p
1 g
F P
s
P
p
.002 w
.43965 .25139 m .40841 .2701 L .42634 .27377 L p
1 g
F P
s
P
p
.002 w
.42634 .27377 m .4502 .25958 L .43965 .25139 L p
1 g
F P
s
P
p
.002 w
.34859 .3108 m .33574 .35002 L .35475 .33533 L p
1 g
F P
s
P
p
.002 w
.35475 .33533 m .36623 .30114 L .34859 .3108 L p
1 g
F P
s
P
p
.002 w
.50781 .25238 m .53461 .26025 L .55063 .25234 L p
1 g
F P
s
P
p
.002 w
.57813 .27132 m .55063 .25234 L .53461 .26025 L p
1 g
F P
s
P
p
.002 w
.59913 .27211 m .6192 .30241 L .6409 .31206 L p
1 g
F P
s
P
p
.002 w
.6192 .30241 m .59913 .27211 L .57813 .27132 L p
1 g
F P
s
P
p
.002 w
.30981 .38683 m .31596 .43155 L .32601 .40948 L p
1 g
F P
s
P
p
.002 w
.32601 .40948 m .32057 .3673 L .30981 .38683 L p
1 g
F P
s
P
p
.002 w
.31014 .47696 m .3364 .51671 L .33641 .49402 L p
1 g
F P
s
P
p
.002 w
.33641 .49402 m .31055 .45423 L .31014 .47696 L p
1 g
F P
s
P
p
.002 w
.4456 .6136 m .49705 .61823 L .49394 .60627 L p
1 g
F P
s
P
p
.002 w
.49394 .60627 m .43873 .6012 L .4456 .6136 L p
1 g
F P
s
P
p
.002 w
.54997 .5994 m .49394 .60627 L .49705 .61823 L p
1 g
F P
s
P
p
.002 w
.49705 .61823 m .54931 .61183 L .54997 .5994 L p
1 g
F P
s
P
p
.002 w
.60215 .58116 m .54997 .5994 L .54931 .61183 L p
1 g
F P
s
P
p
.002 w
.39227 .27062 m .36623 .30114 L .3868 .29518 L p
1 g
F P
s
P
p
.002 w
.3868 .29518 m .40841 .2701 L .39227 .27062 L p
1 g
F P
s
P
p
.002 w
.65947 .32518 m .66524 .36742 L .68005 .38645 L p
1 g
F P
s
P
p
.002 w
.66524 .36742 m .65947 .32518 L .6409 .31206 L p
1 g
F P
s
P
p
.002 w
.69044 .40723 m .67577 .45213 L .6809 .47424 L p
1 g
F P
s
P
p
.002 w
.67577 .45213 m .69044 .40723 L .68005 .38645 L p
1 g
F P
s
P
p
.002 w
.55063 .25234 m .57813 .27132 L .59913 .27211 L p
1 g
F P
s
P
p
.002 w
.47689 .24156 m .43965 .25139 L .4502 .25958 L p
1 g
F P
s
P
p
.002 w
.4502 .25958 m .47849 .25213 L .47689 .24156 L p
1 g
F P
s
P
p
.002 w
.55063 .25234 m .51549 .24192 L .50781 .25238 L p
1 g
F P
s
P
p
.002 w
.47849 .25213 m .50781 .25238 L .51549 .24192 L p
1 g
F P
s
P
p
.002 w
.51549 .24192 m .47689 .24156 L .47849 .25213 L p
1 g
F P
s
P
p
.002 w
.34969 .55665 m .38906 .58435 L .38195 .56704 L p
1 g
F P
s
P
p
.002 w
.38195 .56704 m .3408 .5378 L .34969 .55665 L p
1 g
F P
s
P
p
.002 w
.39945 .59809 m .4456 .6136 L .43873 .6012 L p
1 g
F P
s
P
p
.002 w
.43873 .6012 m .38906 .58435 L .39945 .59809 L p
1 g
F P
s
P
p
.002 w
.60215 .58116 m .64588 .55281 L .64907 .53421 L p
1 g
F P
s
P
p
.002 w
.68132 .49587 m .64907 .53421 L .64588 .55281 L p
1 g
F P
s
P
p
.002 w
.64907 .53421 m .68132 .49587 L .6809 .47424 L p
1 g
F P
s
P
p
.002 w
.54931 .61183 m .59794 .59493 L .60215 .58116 L p
1 g
F P
s
P
p
.002 w
.64588 .55281 m .60215 .58116 L .59794 .59493 L p
1 g
F P
s
P
p
.002 w
.33449 .32408 m .32057 .3673 L .33574 .35002 L p
1 g
F P
s
P
p
.002 w
.33574 .35002 m .34859 .3108 L .33449 .32408 L p
1 g
F P
s
P
p
.002 w
.30397 .4082 m .31055 .45423 L .31596 .43155 L p
1 g
F P
s
P
p
.002 w
.31596 .43155 m .30981 .38683 L .30397 .4082 L p
1 g
F P
s
P
p
.002 w
.61816 .2772 m .6409 .31206 L .65947 .32518 L p
1 g
F P
s
P
p
.002 w
.6409 .31206 m .61816 .2772 L .59913 .27211 L p
1 g
F P
s
P
p
.002 w
.43031 .24775 m .39227 .27062 L .40841 .2701 L p
1 g
F P
s
P
p
.002 w
.40841 .2701 m .43965 .25139 L .43031 .24775 L p
1 g
F P
s
P
p
.002 w
.31497 .49912 m .3408 .5378 L .3364 .51671 L p
1 g
F P
s
P
p
.002 w
.3364 .51671 m .31014 .47696 L .31497 .49912 L p
1 g
F P
s
P
p
.002 w
.59913 .27211 m .5659 .24894 L .55063 .25234 L p
1 g
F P
s
P
p
.002 w
.51549 .24192 m .55063 .25234 L .5659 .24894 L p
1 g
F P
s
P
p
.002 w
.67427 .34158 m .68005 .38645 L .69044 .40723 L p
1 g
F P
s
P
p
.002 w
.68005 .38645 m .67427 .34158 L .65947 .32518 L p
1 g
F P
s
P
p
.002 w
.37847 .27557 m .34859 .3108 L .36623 .30114 L p
1 g
F P
s
P
p
.002 w
.36623 .30114 m .39227 .27062 L .37847 .27557 L p
1 g
F P
s
P
p
.002 w
.69596 .42929 m .6809 .47424 L .68132 .49587 L p
1 g
F P
s
P
p
.002 w
.6809 .47424 m .69596 .42929 L .69044 .40723 L p
1 g
F P
s
P
p
.002 w
.5659 .24894 m .59913 .27211 L .61816 .2772 L p
1 g
F P
s
P
p
.002 w
.45424 .62149 m .50037 .62559 L .49705 .61823 L p
1 g
F P
s
P
p
.002 w
.49705 .61823 m .4456 .6136 L .45424 .62149 L p
1 g
F P
s
P
p
.002 w
.54931 .61183 m .49705 .61823 L .50037 .62559 L p
1 g
F P
s
P
p
.002 w
.50037 .62559 m .54728 .61985 L .54931 .61183 L p
1 g
F P
s
P
p
.002 w
.59794 .59493 m .54931 .61183 L .54728 .61985 L p
1 g
F P
s
P
p
.002 w
.47585 .2357 m .43031 .24775 L .43965 .25139 L p
1 g
F P
s
P
p
.002 w
.43965 .25139 m .47689 .24156 L .47585 .2357 L p
1 g
F P
s
P
p
.002 w
.5659 .24894 m .52307 .23616 L .51549 .24192 L p
1 g
F P
s
P
p
.002 w
.47689 .24156 m .51549 .24192 L .52307 .23616 L p
1 g
F P
s
P
p
.002 w
.36307 .57263 m .39945 .59809 L .38906 .58435 L p
1 g
F P
s
P
p
.002 w
.38906 .58435 m .34969 .55665 L .36307 .57263 L p
1 g
F P
s
P
p
.002 w
.32451 .34081 m .30981 .38683 L .32057 .3673 L p
1 g
F P
s
P
p
.002 w
.32057 .3673 m .33449 .32408 L .32451 .34081 L p
1 g
F P
s
P
p
.002 w
.52307 .23616 m .47585 .2357 L .47689 .24156 L p
1 g
F P
s
P
p
.002 w
.59794 .59493 m .63859 .56875 L .64588 .55281 L p
1 g
F P
s
P
p
.002 w
.67678 .51642 m .64588 .55281 L .63859 .56875 L p
1 g
F P
s
P
p
.002 w
.64588 .55281 m .67678 .51642 L .68132 .49587 L p
1 g
F P
s
P
p
.002 w
.30344 .4309 m .31014 .47696 L .31055 .45423 L p
1 g
F P
s
P
p
.002 w
.31055 .45423 m .30397 .4082 L .30344 .4309 L p
1 g
F P
s
P
p
.002 w
.41303 .60771 m .45424 .62149 L .4456 .6136 L p
1 g
F P
s
P
p
.002 w
.4456 .6136 m .39945 .59809 L .41303 .60771 L p
1 g
F P
s
P
p
.002 w
.63462 .28669 m .65947 .32518 L .67427 .34158 L p
1 g
F P
s
P
p
.002 w
.65947 .32518 m .63462 .28669 L .61816 .2772 L p
1 g
F P
s
P
p
.002 w
.54728 .61985 m .59087 .60475 L .59794 .59493 L p
1 g
F P
s
P
p
.002 w
.63859 .56875 m .59794 .59493 L .59087 .60475 L p
1 g
F P
s
P
p
.002 w
.68472 .36098 m .69044 .40723 L .69596 .42929 L p
1 g
F P
s
P
p
.002 w
.69044 .40723 m .68472 .36098 L .67427 .34158 L p
1 g
F P
s
P
p
.002 w
.32515 .52006 m .34969 .55665 L .3408 .5378 L p
1 g
F P
s
P
p
.002 w
.3408 .5378 m .31497 .49912 L .32515 .52006 L p
1 g
F P
s
P
p
.002 w
.69621 .45207 m .68132 .49587 L .67678 .51642 L p
1 g
F P
s
P
p
.002 w
.68132 .49587 m .69621 .45207 L .69596 .42929 L p
1 g
F P
s
P
p
.002 w
.42251 .24904 m .37847 .27557 L .39227 .27062 L p
1 g
F P
s
P
p
.002 w
.39227 .27062 m .43031 .24775 L .42251 .24904 L p
1 g
F P
s
P
p
.002 w
.36753 .28505 m .33449 .32408 L .34859 .3108 L p
1 g
F P
s
P
p
.002 w
.34859 .3108 m .37847 .27557 L .36753 .28505 L p
1 g
F P
s
P
p
.002 w
.52307 .23616 m .5659 .24894 L .57995 .25041 L p
1 g
F P
s
P
p
.002 w
.61816 .2772 m .57995 .25041 L .5659 .24894 L p
1 g
F P
s
P
p
.002 w
.57995 .25041 m .61816 .2772 L .63462 .28669 L p
1 g
F P
s
P
p
.002 w
.46452 .62437 m .50382 .62785 L .50037 .62559 L p
1 g
F P
s
P
p
.002 w
.50037 .62559 m .45424 .62149 L .46452 .62437 L p
1 g
F P
s
P
p
.002 w
.54728 .61985 m .50037 .62559 L .50382 .62785 L p
1 g
F P
s
P
p
.002 w
.31917 .36068 m .30397 .4082 L .30981 .38683 L p
1 g
F P
s
P
p
.002 w
.30981 .38683 m .32451 .34081 L .31917 .36068 L p
1 g
F P
s
P
p
.002 w
.50382 .62785 m .54384 .62295 L .54728 .61985 L p
1 g
F P
s
P
p
.002 w
.59087 .60475 m .54728 .61985 L .54384 .62295 L p
1 g
F P
s
P
p
.002 w
.38079 .58514 m .41303 .60771 L .39945 .59809 L p
1 g
F P
s
P
p
.002 w
.39945 .59809 m .36307 .57263 L .38079 .58514 L p
1 g
F P
s
P
p
.002 w
.3085 .4543 m .31497 .49912 L .31014 .47696 L p
1 g
F P
s
P
p
.002 w
.31014 .47696 m .30344 .4309 L .3085 .4543 L p
1 g
F P
s
P
p
.002 w
.47543 .23503 m .42251 .24904 L .43031 .24775 L p
1 g
F P
s
P
p
.002 w
.43031 .24775 m .47585 .2357 L .47543 .23503 L p
1 g
F P
s
P
p
.002 w
.67427 .34158 m .6479 .30056 L .63462 .28669 L p
1 g
F P
s
P
p
.002 w
.6479 .30056 m .67427 .34158 L .68472 .36098 L p
1 g
F P
s
P
p
.004 w
.52388 .64098 m
.52686 .6673 L
s
P
p
.004 w
.72927 .45012 m
.74785 .45171 L
s
P
p
.002 w
.57995 .25041 m .53033 .23557 L .52307 .23616 L p
1 g
F P
s
P
p
.002 w
.47585 .2357 m .52307 .23616 L .53033 .23557 L p
1 g
F P
s
P
p
.002 w
.59087 .60475 m .62717 .58145 L .63859 .56875 L p
1 g
F P
s
P
p
.002 w
.63859 .56875 m .66716 .53527 L .67678 .51642 L p
1 g
F P
s
P
p
.002 w
.66716 .53527 m .63859 .56875 L .62717 .58145 L p
1 g
F P
s
P
p
.002 w
.69596 .42929 m .69032 .38297 L .68472 .36098 L p
1 g
F P
s
P
p
.002 w
.69032 .38297 m .69596 .42929 L .69621 .45207 L p
1 g
F P
s
P
p
.002 w
.34065 .53909 m .36307 .57263 L .34969 .55665 L p
1 g
F P
s
P
p
.002 w
.34969 .55665 m .32515 .52006 L .34065 .53909 L p
1 g
F P
s
P
p
.002 w
.53033 .23557 m .47543 .23503 L .47585 .2357 L p
1 g
F P
s
P
p
.002 w
.42959 .61268 m .46452 .62437 L .45424 .62149 L p
1 g
F P
s
P
p
.002 w
.45424 .62149 m .41303 .60771 L .42959 .61268 L p
1 g
F P
s
P
p
.002 w
.54384 .62295 m .58097 .61011 L .59087 .60475 L p
1 g
F P
s
P
p
.002 w
.62717 .58145 m .59087 .60475 L .58097 .61011 L p
1 g
F P
s
P
p
.002 w
.67678 .51642 m .69094 .47497 L .69621 .45207 L p
1 g
F P
s
P
p
.002 w
.69094 .47497 m .67678 .51642 L .66716 .53527 L p
1 g
F P
s
P
p
.002 w
.35993 .29908 m .32451 .34081 L .33449 .32408 L p
1 g
F P
s
P
p
.002 w
.33449 .32408 m .36753 .28505 L .35993 .29908 L p
1 g
F P
s
P
p
.002 w
.41658 .25555 m .36753 .28505 L .37847 .27557 L p
1 g
F P
s
P
p
.002 w
.37847 .27557 m .42251 .24904 L .41658 .25555 L p
1 g
F P
s
P
p
.002 w
.63462 .28669 m .59232 .257 L .57995 .25041 L p
1 g
F P
s
P
p
.002 w
.59232 .257 m .63462 .28669 L .6479 .30056 L p
1 g
F P
s
P
p
.002 w
.53033 .23557 m .57995 .25041 L .59232 .257 L p
1 g
F P
s
P
p
.002 w
.31888 .38326 m .30344 .4309 L .30397 .4082 L p
1 g
F P
s
P
p
.002 w
.30397 .4082 m .31917 .36068 L .31888 .38326 L p
1 g
F P
s
P
p
.002 w
.31925 .47772 m .32515 .52006 L .31497 .49912 L p
1 g
F P
s
P
p
.002 w
.31497 .49912 m .3085 .4543 L .31925 .47772 L p
1 g
F P
s
P
p
.002 w
.65743 .31863 m .68472 .36098 L .69032 .38297 L p
1 g
F P
s
P
p
.002 w
.68472 .36098 m .65743 .31863 L .6479 .30056 L p
1 g
F P
s
P
p
.002 w
.69064 .40702 m .69621 .45207 L .69094 .47497 L p
1 g
F P
s
P
p
.002 w
.69621 .45207 m .69064 .40702 L .69032 .38297 L p
1 g
F P
s
P
p
.002 w
.40251 .59362 m .42959 .61268 L .41303 .60771 L p
1 g
F P
s
P
p
.002 w
.41303 .60771 m .38079 .58514 L .40251 .59362 L p
1 g
F P
s
P
p
.002 w
.47625 .62183 m .50731 .6246 L .50382 .62785 L p
1 g
F P
s
P
p
.002 w
.50382 .62785 m .46452 .62437 L .47625 .62183 L p
1 g
F P
s
P
p
.002 w
.54384 .62295 m .50382 .62785 L .50731 .6246 L p
1 g
F P
s
P
p
.002 w
.58097 .61011 m .61172 .59036 L .62717 .58145 L p
1 g
F P
s
P
p
.002 w
.65247 .55179 m .62717 .58145 L .61172 .59036 L p
1 g
F P
s
P
p
.002 w
.62717 .58145 m .65247 .55179 L .66716 .53527 L p
1 g
F P
s
P
p
.002 w
.50731 .6246 m .53901 .62072 L .54384 .62295 L p
1 g
F P
s
P
p
.002 w
.58097 .61011 m .54384 .62295 L .53901 .62072 L p
1 g
F P
s
P
p
.002 w
.3612 .55554 m .38079 .58514 L .36307 .57263 L p
1 g
F P
s
P
p
.002 w
.36307 .57263 m .34065 .53909 L .3612 .55554 L p
1 g
F P
s
P
p
.002 w
.47571 .23993 m .41658 .25555 L .42251 .24904 L p
1 g
F P
s
P
p
.002 w
.42251 .24904 m .47543 .23503 L .47571 .23993 L p
1 g
F P
s
P
p
.002 w
.59232 .257 m .53704 .2405 L .53033 .23557 L p
1 g
F P
s
P
p
.002 w
.47543 .23503 m .53033 .23557 L .53704 .2405 L p
1 g
F P
s
P
p
.002 w
.68004 .49731 m .66716 .53527 L .65247 .55179 L p
1 g
F P
s
P
p
.002 w
.66716 .53527 m .68004 .49731 L .69094 .47497 L p
1 g
F P
s
P
p
.002 w
.35613 .31747 m .31917 .36068 L .32451 .34081 L p
1 g
F P
s
P
p
.002 w
.32451 .34081 m .35993 .29908 L .35613 .31747 L p
1 g
F P
s
P
p
.002 w
.4488 .61259 m .47625 .62183 L .46452 .62437 L p
1 g
F P
s
P
p
.002 w
.46452 .62437 m .42959 .61268 L .4488 .61259 L p
1 g
F P
s
P
p
.002 w
.53704 .2405 m .47571 .23993 L .47543 .23503 L p
1 g
F P
s
P
p
.002 w
.53901 .62072 m .56834 .61056 L .58097 .61011 L p
1 g
F P
s
P
p
.002 w
.61172 .59036 m .58097 .61011 L .56834 .61056 L p
1 g
F P
s
P
p
.002 w
.60254 .26882 m .6479 .30056 L .65743 .31863 L p
1 g
F P
s
P
p
.002 w
.6479 .30056 m .60254 .26882 L .59232 .257 L p
1 g
F P
s
P
p
.002 w
.41281 .26742 m .35993 .29908 L .36753 .28505 L p
1 g
F P
s
P
p
.002 w
.36753 .28505 m .41658 .25555 L .41281 .26742 L p
1 g
F P
s
P
p
.002 w
.32389 .40794 m .3085 .4543 L .30344 .4309 L p
1 g
F P
s
P
p
.002 w
.30344 .4309 m .31888 .38326 L .32389 .40794 L p
1 g
F P
s
P
p
.002 w
.53704 .2405 m .59232 .257 L .60254 .26882 L p
1 g
F P
s
P
p
.002 w
.3356 .5004 m .34065 .53909 L .32515 .52006 L p
1 g
F P
s
P
p
.002 w
.32515 .52006 m .31925 .47772 L .3356 .5004 L p
1 g
F P
s
P
p
.002 w
.66274 .34056 m .69032 .38297 L .69064 .40702 L p
1 g
F P
s
P
p
.002 w
.69032 .38297 m .66274 .34056 L .65743 .31863 L p
1 g
F P
s
P
p
.002 w
.68545 .43248 m .69094 .47497 L .68004 .49731 L p
1 g
F P
s
P
p
.002 w
.69094 .47497 m .68545 .43248 L .69064 .40702 L p
1 g
F P
s
P
p
.004 w
.68772 .44657 m
.72927 .45012 L
s
P
p
.002 w
.42775 .5976 m .4488 .61259 L .42959 .61268 L p
1 g
F P
s
P
p
.002 w
.42959 .61268 m .40251 .59362 L .42775 .5976 L p
1 g
F P
s
P
p
.002 w
.38637 .56876 m .40251 .59362 L .38079 .58514 L p
1 g
F P
s
P
p
.002 w
.38079 .58514 m .3612 .55554 L .38637 .56876 L p
1 g
F P
s
P
p
.002 w
.56834 .61056 m .59248 .59498 L .61172 .59036 L p
1 g
F P
s
P
p
.002 w
.63292 .56535 m .61172 .59036 L .59248 .59498 L p
1 g
F P
s
P
p
.002 w
.61172 .59036 m .63292 .56535 L .65247 .55179 L p
1 g
F P
s
P
p
.002 w
.66361 .51834 m .65247 .55179 L .63292 .56535 L p
1 g
F P
s
P
p
.002 w
.65247 .55179 m .66361 .51834 L .68004 .49731 L p
1 g
F P
s
P
p
.002 w
.48915 .61363 m .51075 .61559 L .50731 .6246 L p
1 g
F P
s
P
p
.002 w
.50731 .6246 m .47625 .62183 L .48915 .61363 L p
1 g
F P
s
P
p
.002 w
.53901 .62072 m .50731 .6246 L .51075 .61559 L p
1 g
F P
s
P
p
.002 w
.51075 .61559 m .53283 .61288 L .53901 .62072 L p
1 g
F P
s
P
p
.002 w
.56834 .61056 m .53901 .62072 L .53283 .61288 L p
1 g
F P
s
P
p
.002 w
.35646 .33986 m .31888 .38326 L .31917 .36068 L p
1 g
F P
s
P
p
.002 w
.31917 .36068 m .35613 .31747 L .35646 .33986 L p
1 g
F P
s
P
p
.002 w
.4767 .25059 m .41281 .26742 L .41658 .25555 L p
1 g
F P
s
P
p
.002 w
.41658 .25555 m .47571 .23993 L .4767 .25059 L p
1 g
F P
s
P
p
.002 w
.60254 .26882 m .54296 .25117 L .53704 .2405 L p
1 g
F P
s
P
p
.002 w
.47571 .23993 m .53704 .2405 L .54296 .25117 L p
1 g
F P
s
P
p
.002 w
.61017 .28582 m .65743 .31863 L .66274 .34056 L p
1 g
F P
s
P
p
.002 w
.65743 .31863 m .61017 .28582 L .60254 .26882 L p
1 g
F P
s
P
p
.002 w
.33428 .434 m .31925 .47772 L .3085 .4543 L p
1 g
F P
s
P
p
.002 w
.3085 .4543 m .32389 .40794 L .33428 .434 L p
1 g
F P
s
P
p
.002 w
.35721 .52156 m .3612 .55554 L .34065 .53909 L p
1 g
F P
s
P
p
.002 w
.34065 .53909 m .3356 .5004 L .35721 .52156 L p
1 g
F P
s
P
p
.002 w
.47019 .60716 m .48915 .61363 L .47625 .62183 L p
1 g
F P
s
P
p
.002 w
.47625 .62183 m .4488 .61259 L .47019 .60716 L p
1 g
F P
s
P
p
.002 w
.53283 .61288 m .55321 .60578 L .56834 .61056 L p
1 g
F P
s
P
p
.002 w
.59248 .59498 m .56834 .61056 L .55321 .60578 L p
1 g
F P
s
P
p
.002 w
.54296 .25117 m .4767 .25059 L .47571 .23993 L p
1 g
F P
s
P
p
.002 w
.66342 .36584 m .69064 .40702 L .68545 .43248 L p
1 g
F P
s
P
p
.002 w
.69064 .40702 m .66342 .36584 L .66274 .34056 L p
1 g
F P
s
P
p
.002 w
.41148 .28459 m .35613 .31747 L .35993 .29908 L p
1 g
F P
s
P
p
.002 w
.35993 .29908 m .41281 .26742 L .41148 .28459 L p
1 g
F P
s
P
p
.002 w
.67467 .45857 m .68004 .49731 L .66361 .51834 L p
1 g
F P
s
P
p
.002 w
.68004 .49731 m .67467 .45857 L .68545 .43248 L p
1 g
F P
s
P
p
.002 w
.54296 .25117 m .60254 .26882 L .61017 .28582 L p
1 g
F P
s
P
p
.002 w
.41549 .57819 m .42775 .5976 L .40251 .59362 L p
1 g
F P
s
P
p
.002 w
.40251 .59362 m .38637 .56876 L .41549 .57819 L p
1 g
F P
s
P
p
.002 w
.59248 .59498 m .60889 .57538 L .63292 .56535 L p
1 g
F P
s
P
p
.002 w
.64195 .53735 m .63292 .56535 L .60889 .57538 L p
1 g
F P
s
P
p
.002 w
.63292 .56535 m .64195 .53735 L .66361 .51834 L p
1 g
F P
s
P
p
.002 w
.45583 .59676 m .47019 .60716 L .4488 .61259 L p
1 g
F P
s
P
p
.002 w
.4488 .61259 m .42775 .5976 L .45583 .59676 L p
1 g
F P
s
P
p
.002 w
.55321 .60578 m .56986 .59495 L .59248 .59498 L p
1 g
F P
s
P
p
.002 w
.60889 .57538 m .59248 .59498 L .56986 .59495 L p
1 g
F P
s
P
p
.002 w
.36111 .3657 m .32389 .40794 L .31888 .38326 L p
1 g
F P
s
P
p
.002 w
.31888 .38326 m .35646 .33986 L .36111 .3657 L p
1 g
F P
s
P
p
.002 w
.34991 .46058 m .3356 .5004 L .31925 .47772 L p
1 g
F P
s
P
p
.002 w
.31925 .47772 m .33428 .434 L .34991 .46058 L p
1 g
F P
s
P
p
.002 w
.38353 .54041 m .38637 .56876 L .3612 .55554 L p
1 g
F P
s
P
p
.002 w
.3612 .55554 m .35721 .52156 L .38353 .54041 L p
1 g
F P
s
P
p
.002 w
.6148 .30771 m .66274 .34056 L .66342 .36584 L p
1 g
F P
s
P
p
.002 w
.66274 .34056 m .6148 .30771 L .61017 .28582 L p
1 g
F P
s
P
p
.002 w
.65844 .48444 m .66361 .51834 L .64195 .53735 L p
1 g
F P
s
P
p
.002 w
.66361 .51834 m .65844 .48444 L .67467 .45857 L p
1 g
F P
s
P
p
.002 w
.65926 .39376 m .68545 .43248 L .67467 .45857 L p
1 g
F P
s
P
p
.002 w
.68545 .43248 m .65926 .39376 L .66342 .36584 L p
1 g
F P
s
P
p
.002 w
.50287 .59968 m .51401 .60072 L .51075 .61559 L p
1 g
F P
s
P
p
.002 w
.51075 .61559 m .48915 .61363 L .50287 .59968 L p
1 g
F P
s
P
p
.002 w
.53283 .61288 m .51075 .61559 L .51401 .60072 L p
1 g
F P
s
P
p
.002 w
.51401 .60072 m .52543 .59932 L .53283 .61288 L p
1 g
F P
s
P
p
.002 w
.55321 .60578 m .53283 .61288 L .52543 .59932 L p
1 g
F P
s
P
p
.002 w
.47843 .26706 m .41148 .28459 L .41281 .26742 L p
1 g
F P
s
P
p
.002 w
.41281 .26742 m .4767 .25059 L .47843 .26706 L p
1 g
F P
s
P
p
.002 w
.61017 .28582 m .54785 .26757 L .54296 .25117 L p
1 g
F P
s
P
p
.002 w
.4767 .25059 m .54296 .25117 L .54785 .26757 L p
1 g
F P
s
P
p
.002 w
.49315 .59631 m .50287 .59968 L .48915 .61363 L p
1 g
F P
s
P
p
.002 w
.48915 .61363 m .47019 .60716 L .49315 .59631 L p
1 g
F P
s
P
p
.002 w
.52543 .59932 m .53593 .59563 L .55321 .60578 L p
1 g
F P
s
P
p
.002 w
.56986 .59495 m .55321 .60578 L .53593 .59563 L p
1 g
F P
s
P
p
.002 w
.41276 .30678 m .35646 .33986 L .35613 .31747 L p
1 g
F P
s
P
p
.002 w
.35613 .31747 m .41148 .28459 L .41276 .30678 L p
1 g
F P
s
P
p
.002 w
.44769 .5834 m .45583 .59676 L .42775 .5976 L p
1 g
F P
s
P
p
.002 w
.42775 .5976 m .41549 .57819 L .44769 .5834 L p
1 g
F P
s
P
p
.002 w
.54785 .26757 m .61017 .28582 L .6148 .30771 L p
1 g
F P
s
P
p
.002 w
.54785 .26757 m .47843 .26706 L .4767 .25059 L p
1 g
F P
s
P
p
.002 w
.56986 .59495 m .58099 .58141 L .60889 .57538 L p
1 g
F P
s
P
p
.002 w
.6156 .55362 m .60889 .57538 L .58099 .58141 L p
1 g
F P
s
P
p
.002 w
.60889 .57538 m .6156 .55362 L .64195 .53735 L p
1 g
F P
s
P
p
.002 w
.4859 .59093 m .49315 .59631 L .47019 .60716 L p
1 g
F P
s
P
p
.002 w
.47019 .60716 m .45583 .59676 L .4859 .59093 L p
1 g
F P
s
P
p
.002 w
.41373 .55624 m .41549 .57819 L .38637 .56876 L p
1 g
F P
s
P
p
.002 w
.38637 .56876 m .38353 .54041 L .41373 .55624 L p
1 g
F P
s
P
p
.002 w
.53593 .59563 m .54443 .59002 L .56986 .59495 L p
1 g
F P
s
P
p
.002 w
.58099 .58141 m .56986 .59495 L .54443 .59002 L p
1 g
F P
s
P
p
.002 w
.37038 .48676 m .35721 .52156 L .3356 .5004 L p
1 g
F P
s
P
p
.002 w
.3356 .5004 m .34991 .46058 L .37038 .48676 L p
1 g
F P
s
P
p
.002 w
.63716 .50919 m .64195 .53735 L .6156 .55362 L p
1 g
F P
s
P
p
.002 w
.64195 .53735 m .63716 .50919 L .65844 .48444 L p
1 g
F P
s
P
p
.002 w
.37011 .3942 m .33428 .434 L .32389 .40794 L p
1 g
F P
s
P
p
.002 w
.32389 .40794 m .36111 .3657 L .37011 .3942 L p
1 g
F P
s
P
p
.002 w
.65019 .42345 m .67467 .45857 L .65844 .48444 L p
1 g
F P
s
P
p
.002 w
.67467 .45857 m .65019 .42345 L .65926 .39376 L p
1 g
F P
s
P
p
.004 w
.6733 .44534 m
.68772 .44657 L
s
P
p
.004 w
.66265 .44442 m
.66559 .44468 L
s
P
p
.004 w
.66559 .44468 m
.6733 .44534 L
s
P
p
.002 w
.61612 .33401 m .66342 .36584 L .65926 .39376 L p
1 g
F P
s
P
p
.002 w
.66342 .36584 m .61612 .33401 L .6148 .30771 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51325 .54728 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.48191 .58409 m .4859 .59093 L .45583 .59676 L p
1 g
F P
s
P
p
.002 w
.45583 .59676 m .44769 .5834 L .48191 .58409 L p
1 g
F P
s
P
p
.002 w
.54443 .59002 m .55002 .58306 L .58099 .58141 L p
1 g
F P
s
P
p
.002 w
.58531 .56651 m .58099 .58141 L .55002 .58306 L p
1 g
F P
s
P
p
.002 w
.58099 .58141 m .58531 .56651 L .6156 .55362 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.51401 .60072 m .50287 .59968 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.002 w
.52543 .59932 m .51401 .60072 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.002 w
.53593 .59563 m .52543 .59932 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.002 w
.48088 .28908 m .41276 .30678 L .41148 .28459 L p
1 g
F P
s
P
p
.002 w
.41148 .28459 m .47843 .26706 L .48088 .28908 L p
1 g
F P
s
P
p
.002 w
.44683 .56843 m .44769 .5834 L .41549 .57819 L p
1 g
F P
s
P
p
.002 w
.41549 .57819 m .41373 .55624 L .44683 .56843 L p
1 g
F P
s
P
p
.002 w
.6148 .30771 m .55148 .28949 L .54785 .26757 L p
1 g
F P
s
P
p
.002 w
.47843 .26706 m .54785 .26757 L .55148 .28949 L p
1 g
F P
s
P
p
.002 w
.41674 .33346 m .36111 .3657 L .35646 .33986 L p
1 g
F P
s
P
p
.002 w
.35646 .33986 m .41276 .30678 L .41674 .33346 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.39508 .51157 m .38353 .54041 L .35721 .52156 L p
1 g
F P
s
P
p
.002 w
.35721 .52156 m .37038 .48676 L .39508 .51157 L p
1 g
F P
s
P
p
.002 w
.50287 .59968 m .49315 .59631 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54443 .59002 m .53593 .59563 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.002 w
.61145 .53193 m .6156 .55362 L .58531 .56651 L p
1 g
F P
s
P
p
.002 w
.6156 .55362 m .61145 .53193 L .63716 .50919 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.55148 .28949 m .6148 .30771 L .61612 .33401 L p
1 g
F P
s
P
p
.002 w
.6364 .45392 m .65844 .48444 L .63716 .50919 L p
1 g
F P
s
P
p
.002 w
.65844 .48444 m .6364 .45392 L .65019 .42345 L p
1 g
F P
s
P
p
.004 w
.65525 .44379 m
.65649 .4439 L
s
P
p
.004 w
.5 .43051 m
.64152 .44262 L
s
P
p
.004 w
.65649 .4439 m
.66265 .44442 L
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.49315 .59631 m .4859 .59093 L .51477 .58092 L p
1 g
F P
s
P
p
.002 w
.4859 .59093 m .48191 .58409 L .51015 .58092 L p
1 g
F P
s
P
p
.002 w
.51096 .58092 m .51079 .57862 L p
.4995 .58088 L 1 g
F P
s
P
p
.002 w
.48191 .58409 m .4818 .58081 L p
.48905 .58084 L 1 g
F P
s
P
p
.002 w
.51015 .58092 m .49655 .58244 L p
.48905 .58084 L 1 g
F P
s
P
p
.002 w
.49655 .58244 m .48191 .58409 L p
.48905 .58084 L 1 g
F P
s
P
p
.002 w
.48905 .58084 m .48921 .57862 L p
.47697 .57761 L 1 g
F P
s
P
p
.002 w
.48191 .58409 m .44769 .5834 L p
.47667 .57751 L 1 g
F P
s
P
p
.002 w
.48175 .57927 m .48191 .58409 L p
.47667 .57751 L 1 g
F P
s
P
p
.002 w
.44769 .5834 m .44683 .56843 L .45773 .57095 L p
1 g
F P
s
P
p
.44769 .5834 m .45773 .57095 L .46829 .57461 L 1 g
F
P
p
.47397 .57806 m .46829 .57461 L .47667 .57751 L 1 g
F
P
p
.44769 .5834 m .46829 .57461 L .47397 .57806 L 1 g
F
P
p
.002 w
.46829 .57461 m .46872 .57265 L p
.45917 .56883 L 1 g
F P
s
P
p
.002 w
.46507 .57265 m .44683 .56843 L p
.45881 .5686 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44683 .56843 m .44947 .56256 L p
.45069 .56335 L 1 g
F P
s
P
p
.45537 .56855 m .45069 .56335 L .45881 .5686 L 1 g
F
P
p
.44683 .56843 m .45069 .56335 L .45537 .56855 L 1 g
F
P
p
.002 w
.45069 .56335 m .45146 .56129 L p
.44445 .5552 L 1 g
F P
s
P
p
.002 w
.44683 .56843 m .41373 .55624 L p
.44367 .55415 L 1 g
F P
s
P
p
.002 w
.44964 .56219 m .44683 .56843 L p
.44367 .55415 L 1 g
F P
s
P
p
.002 w
.41373 .55624 m .42315 .53408 L .43379 .54086 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.41373 .55624 m .43379 .54086 L .43846 .54714 L 1 g
F
P
p
.4411 .55433 m .43846 .54714 L .44367 .55415 L 1 g
F
P
p
.41373 .55624 m .43846 .54714 L .4411 .55433 L 1 g
F
P
p
.002 w
.43846 .54714 m .43925 .54566 L p
.43544 .53811 L 1 g
F P
s
P
p
.002 w
.43688 .54282 m .42315 .53408 L p
.43469 .53567 L 1 g
F P
s
P
p
.43544 .53811 m .43439 .53604 L .43688 .54282 L 1 g
F
P
p
.43544 .53811 m .43688 .54282 L .43846 .54714 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43846 .54714 L p
1 g
F P
s
P
p
.002 w
.43846 .54714 m .43743 .5491 L p
.44445 .5552 L 1 g
F P
s
P
p
.45146 .56129 m .43846 .54714 L .44445 .5552 L 1 g
F
P
p
.44367 .55415 m .43846 .54714 L .45358 .55345 L 1 g
F
P
p
.002 w
.43379 .54086 m .43688 .54282 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43254 .52868 L p
1 g
F P
s
P
p
.002 w
.42315 .53408 m .43163 .52569 L p
.43254 .52868 L 1 g
F P
s
P
p
.43223 .53533 m .43254 .52868 L .43469 .53567 L 1 g
F
P
p
.42315 .53408 m .43254 .52868 L .43223 .53533 L 1 g
F
P
p
.002 w
.43254 .52868 m .43346 .52734 L p
.43318 .51922 L 1 g
F P
s
P
p
.002 w
.43274 .52459 m .42315 .53408 L p
.43363 .51376 L 1 g
F P
s
P
p
.43318 .51922 m .4331 .51695 L .43274 .52459 L 1 g
F
P
p
.43318 .51922 m .43274 .52459 L .43254 .52868 L 1 g
F
P
p
.002 w
.42315 .53408 m .39508 .51157 L p
.43363 .51376 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43925 .54566 m .43254 .52868 L .43453 .53516 L 1 g
F
P
p
.43925 .54566 m .43198 .52949 L .43439 .53604 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43254 .52868 m .44313 .5143 L .43469 .53567 L 1 g
F
P
p
.002 w
.43163 .52569 m .43274 .52459 L p
.43254 .52868 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43399 .50928 L p
1 g
F P
s
P
p
.39508 .51157 m .43448 .50336 L .43399 .50928 L 1 g
F
P
p
.43197 .51366 m .43399 .50928 L .43363 .51376 L 1 g
F
P
p
.39508 .51157 m .43399 .50928 L .43197 .51366 L 1 g
F
P
p
.002 w
.43399 .50928 m .43485 .50826 L p
.43798 .50093 L 1 g
F P
s
P
p
.002 w
.4359 .50516 m .43261 .501 L p
.4426 .49157 L 1 g
F P
s
P
p
.002 w
.43261 .501 m .42046 .48564 L p
.4424 .49152 L 1 g
F P
s
P
p
.4424 .49152 m .4426 .49157 L .43261 .501 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43346 .52734 m .43399 .50928 L .43344 .51603 L 1 g
F
P
p
.43363 .51376 m .43399 .50928 L .44313 .5143 L 1 g
F
P
p
.002 w
.43448 .50336 m .4359 .50516 L p
.43399 .50928 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44284 .49109 L p
1 g
F P
s
P
p
.002 w
.42046 .48564 m .45452 .4674 L p
.4426 .49157 L 1 g
F P
s
P
p
.002 w
.44284 .49109 m .442 .49198 L p
.43873 .49941 L 1 g
F P
s
P
p
.43485 .50826 m .44284 .49109 L .43873 .49941 L 1 g
F
P
p
.002 w
.44284 .49109 m .44339 .4905 L p
.44833 .48577 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4577 .47669 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44292 .49101 m .4577 .47669 L .47164 .49935 L 1 g
F
P
p
.002 w
.4577 .47669 m .45826 .47608 L p
.467 .47225 L 1 g
F P
s
P
p
.46811 .47171 m .50537 .49119 L .46113 .47511 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.45717 .46598 m .50084 .45528 L .5009 .4557 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.46811 .47171 m .47763 .46706 L .50537 .49119 L 1 g
F
P
p
.47763 .46706 m .5 .46389 L .50537 .49119 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52235 .46702 L p
1 g
F P
s
P
p
.51228 .46564 m .54017 .4909 L .50197 .46422 L 1 g
F
P
p
.5 .4634 m .52235 .46702 L .51053 .4654 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.50084 .45528 m .54596 .45501 L .54355 .46994 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56609 .50938 L p
1 g
F P
s
P
p
.57177 .49845 m .57168 .52157 L .56609 .50938 L 1 g
F
P
p
.002 w
.56593 .50904 m .56605 .50882 L p
.56609 .50938 L 1 g
F P
s
P
p
.002 w
.56605 .50882 m .57177 .49845 L p
.56609 .50938 L 1 g
F P
s
P
p
.002 w
.56609 .50938 m .56515 .50826 L p
.56673 .51853 L 1 g
F P
s
P
p
.55661 .4905 m .56609 .50938 L .56593 .50904 L 1 g
F
P
p
.002 w
.55946 .49551 m .57177 .49845 L .56593 .50904 L p
1 g
F P
s
P
p
.56197 .50075 m .56593 .50904 L .56334 .50338 L 1 g
F
P
p
.55661 .4905 m .56593 .50904 L .56197 .50075 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.57177 .49845 m .55946 .49551 L p
.54596 .45501 L 1 g
F P
s
P
p
.002 w
.55735 .49129 m .55661 .4905 L p
.56445 .50549 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55735 .49129 L p
1 g
F P
s
P
p
.55839 .49229 m .55946 .49551 L .55735 .49129 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55735 .49129 L p
1 g
F P
s
P
p
.56445 .50549 m .56713 .51061 L .55735 .49129 L 1 g
F
P
p
.54174 .47608 m .55735 .49129 L .5493 .48348 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55946 .49551 m .54017 .4909 L .54244 .47683 L p
1 g
F P
s
P
p
.54174 .47608 m .5493 .48348 L .54244 .47683 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54244 .47683 m .54017 .4909 L p
.53532 .47333 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47674 L p
1 g
F P
s
P
p
.52214 .46667 m .54234 .47674 L .53003 .47075 L 1 g
F
P
p
.53403 .46863 m .54234 .47674 L .53532 .47333 L 1 g
F
P
p
.54234 .47674 m .54244 .47683 L .53532 .47333 L 1 g
F
P
p
.51228 .46564 m .52235 .46702 L .54017 .4909 L 1 g
F
P
p
.002 w
.52235 .46702 m .52214 .46667 L p
.53003 .47075 L 1 g
F P
s
P
p
.52235 .46702 m .53403 .46863 L .53532 .47333 L 1 g
F
P
p
.52235 .46702 m .53532 .47333 L .54017 .4909 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52235 .46702 L p
1 g
F P
s
P
p
.53003 .47075 m .54302 .47747 L .52235 .46702 L 1 g
F
P
p
.002 w
.54234 .47674 m .54302 .47747 L p
.53003 .47075 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54234 .47674 L p
.54244 .47683 L 1 g
F P
s
P
p
.002 w
.54234 .47674 m .54174 .47608 L p
.54244 .47683 L 1 g
F P
s
P
p
.002 w
.54355 .46994 m .54244 .47683 L p
.53403 .46863 L 1 g
F P
s
P
p
.002 w
.54244 .47683 m .54431 .4652 L p
.55735 .49129 L 1 g
F P
s
P
p
.55735 .49129 m .55946 .49551 L .54244 .47683 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54235 .47674 L p
1 g
F P
s
P
p
.5493 .48348 m .55834 .49233 L .54235 .47674 L 1 g
F
P
p
.002 w
.55735 .49129 m .55834 .49233 L p
.5493 .48348 L 1 g
F P
s
P
p
.002 w
.54431 .4652 m .54596 .45501 L p
.55839 .49229 L 1 g
F P
s
P
p
.55839 .49229 m .55735 .49129 L .54431 .4652 L 1 g
F
P
p
.002 w
.54017 .4909 m .55946 .49551 L p
.55469 .52945 L 1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52865 L p
1 g
F P
s
P
p
.56515 .50826 m .56744 .52865 L .56673 .51853 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55469 .52945 m .56593 .50904 L p
.56615 .51016 L 1 g
F P
s
P
p
.002 w
.57161 .53894 m .56802 .53693 L p
.56744 .52865 L 1 g
F P
s
P
p
.56871 .52369 m .57161 .53894 L .56744 .52865 L 1 g
F
P
p
.002 w
.56744 .52865 m .56654 .52734 L p
.56433 .53947 L 1 g
F P
s
P
p
.002 w
.57161 .53894 m .56157 .54745 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56566 .5356 m .56891 .53743 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56891 .53743 m .57161 .53894 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56162 .5473 m .56075 .54566 L p
.55517 .55578 L 1 g
F P
s
P
p
.002 w
.55206 .57548 m .52424 .57919 L p
.54768 .56918 L 1 g
F P
s
P
p
.002 w
.52424 .57919 m .51698 .58015 L .53102 .57506 L p
1 g
F P
s
P
p
.002 w
.53102 .57506 m .55027 .56807 L p
.52424 .57919 L 1 g
F P
s
P
p
.002 w
.51586 .58091 m .49315 .59631 L p
.51477 .58092 L 1 g
F P
s
P
p
.002 w
.55002 .58306 m .54443 .59002 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.002 w
.55206 .57548 m .55002 .58306 L .51698 .58015 L closepath p
1 g
F P
s
P
p
.54854 .56129 m .53973 .56969 L .5406 .56915 L 1 g
F
P
p
.002 w
.53171 .57463 m .53128 .57265 L p
.5189 .579 L 1 g
F P
s
P
p
.54137 .56867 m .53981 .57187 L .53171 .57463 L 1 g
F
P
p
.002 w
.55027 .56807 m .53981 .57187 L p
.54137 .56867 L 1 g
F P
s
P
p
.002 w
.54753 .56487 m .55027 .56807 L p
.54137 .56867 L 1 g
F P
s
P
p
.002 w
.51698 .58015 m .51851 .57913 L p
.53171 .57463 L 1 g
F P
s
P
p
.002 w
.53981 .57187 m .53102 .57506 L p
.53171 .57463 L 1 g
F P
s
P
p
.002 w
.53102 .57506 m .51698 .58015 L p
.53171 .57463 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57463 L p
1 g
F P
s
P
p
.002 w
.53171 .57463 m .5322 .57686 L p
.53973 .56969 L 1 g
F P
s
P
p
.54854 .56129 m .53171 .57463 L .53973 .56969 L 1 g
F
P
p
.002 w
.54934 .56343 m .54854 .56129 L p
.534 .57568 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51698 .58015 m .51477 .58092 L p
.51096 .58092 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58092 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58092 L .51098 .58092 L 1 g
F
P
p
.53128 .57265 m .51096 .58092 L .51545 .58 L 1 g
F
P
p
.53128 .57265 m .51545 .58 L .51588 .5799 L 1 g
F
P
p
.53128 .57265 m .51586 .57991 L .51614 .57984 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46792 .5763 L p
1 g
F P
s
P
p
.48921 .57862 m .46792 .5763 L .46829 .57638 L 1 g
F
P
p
.48921 .57862 m .46791 .57634 L .47179 .57719 L 1 g
F
P
p
.4995 .58088 m .51015 .58092 L .51096 .58092 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.48905 .58084 m .48166 .5765 L .51015 .58092 L 1 g
F
P
p
.002 w
.4818 .58081 m .48175 .57927 L p
.48905 .58084 L 1 g
F P
s
P
p
.47697 .57761 m .48175 .57927 L .48905 .58084 L 1 g
F
P
p
.002 w
.48175 .57927 m .48166 .5765 L p
.48905 .58084 L 1 g
F P
s
P
p
.002 w
.46792 .5763 m .46791 .57634 L p
.46829 .57638 L 1 g
F P
s
P
p
.002 w
.46791 .57634 m .4678 .57686 L p
.47179 .57719 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.48166 .5765 m .48524 .56898 L .51612 .57985 L p
1 g
F P
s
P
p
.002 w
.51612 .57985 m .51698 .58015 L .51545 .58 L p
1 g
F P
s
P
p
.002 w
.51545 .58 m .48166 .5765 L p
.51612 .57985 L 1 g
F P
s
P
p
.51588 .5799 m .51545 .58 L .51586 .57991 L 1 g
F
P
p
.51614 .57984 m .51586 .57991 L .51612 .57986 L 1 g
F
P
p
.53128 .57265 m .51612 .57986 L .51634 .5798 L 1 g
F
P
p
.53128 .57265 m .5163 .57982 L .5165 .57977 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48524 .56898 m .49232 .56238 L .51645 .57977 L p
1 g
F P
s
P
p
.002 w
.51645 .57977 m .51698 .58015 L .51612 .57985 L p
1 g
F P
s
P
p
.002 w
.51612 .57985 m .48524 .56898 L p
.51645 .57977 L 1 g
F P
s
P
p
.53128 .57265 m .51645 .57979 L .51664 .57973 L 1 g
F
P
p
.53128 .57265 m .51658 .57976 L .51756 .57945 L 1 g
F
P
p
.002 w
.51851 .57913 m .51698 .58015 L .51756 .57945 L p
1 g
F P
s
P
p
.51888 .57901 m .51756 .57945 L .51878 .57906 L 1 g
F
P
p
.53128 .57265 m .51756 .57945 L .51888 .57901 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53619 .55699 m .5448 .56167 L .51851 .57913 L p
1 g
F P
s
P
p
.002 w
.51756 .57945 m .53619 .55699 L p
.51851 .57913 L 1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.49232 .56238 m .50213 .55744 L .51669 .57971 L p
1 g
F P
s
P
p
.002 w
.51669 .57971 m .51698 .58015 L .51645 .57977 L p
1 g
F P
s
P
p
.002 w
.51645 .57977 m .49232 .56238 L p
.51669 .57971 L 1 g
F P
s
P
p
.51634 .5798 m .51612 .57986 L .5163 .57982 L 1 g
F
P
p
.5165 .57977 m .5163 .57982 L .51645 .57979 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50213 .55744 m .51358 .55473 L .51691 .57965 L p
1 g
F P
s
P
p
.002 w
.51691 .57965 m .51698 .58015 L .51669 .57971 L p
1 g
F P
s
P
p
.002 w
.51669 .57971 m .50213 .55744 L p
.51691 .57965 L 1 g
F P
s
P
p
.002 w
.51358 .55473 m .52538 .55458 L .51716 .57958 L p
1 g
F P
s
P
p
.002 w
.51716 .57958 m .51698 .58015 L .51691 .57965 L p
1 g
F P
s
P
p
.002 w
.51691 .57965 m .51358 .55473 L p
.51716 .57958 L 1 g
F P
s
P
p
.51664 .57973 m .51645 .57979 L .51658 .57976 L 1 g
F
P
p
.51878 .57906 m .51658 .57976 L .51798 .57947 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52538 .55458 m .53619 .55699 L .51756 .57945 L p
1 g
F P
s
P
p
.002 w
.51756 .57945 m .51698 .58015 L .51716 .57958 L p
1 g
F P
s
P
p
.002 w
.51716 .57958 m .52538 .55458 L p
.51756 .57945 L 1 g
F P
s
P
p
.002 w
.51015 .58092 m .51196 .58072 L p
.51096 .58092 L 1 g
F P
s
P
p
.002 w
.51196 .58072 m .51698 .58015 L p
.51096 .58092 L 1 g
F P
s
P
p
.002 w
.51096 .58092 m .51096 .58092 L p
.51098 .58092 L 1 g
F P
s
P
p
.002 w
.51545 .58 m .51698 .58015 L .51196 .58072 L p
1 g
F P
s
P
p
.002 w
.51477 .58092 m .4859 .59093 L p
.51015 .58092 L 1 g
F P
s
P
p
.002 w
.51477 .58092 m .51698 .58015 L .51586 .58091 L p
1 g
F P
s
P
p
.002 w
.51096 .58092 m .51111 .583 L p
.51798 .57947 L 1 g
F P
s
P
p
.002 w
.48166 .5765 m .51545 .58 L p
.51015 .58092 L 1 g
F P
s
P
p
.002 w
.51196 .58072 m .51015 .58092 L p
.51545 .58 L 1 g
F P
s
P
p
.002 w
.51851 .57913 m .5448 .56167 L p
.54137 .56867 L 1 g
F P
s
P
p
.54137 .56867 m .53171 .57463 L .51851 .57913 L 1 g
F
P
p
.54935 .56342 m .54791 .56531 L .54934 .56343 L 1 g
F
P
p
.55985 .55203 m .54791 .56531 L .56157 .54745 L 1 g
F
P
p
.002 w
.55027 .56807 m .54791 .56531 L p
.55025 .56271 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .534 .57568 L p
.53313 .58109 L 1 g
F P
s
P
p
.002 w
.534 .57568 m .5322 .57686 L .53225 .57708 L p
1 g
F P
s
P
p
.002 w
.53225 .57708 m .53313 .58109 L p
.534 .57568 L 1 g
F P
s
P
p
.55985 .55203 m .55641 .55779 L .55025 .56271 L 1 g
F
P
p
.55641 .55779 m .55027 .56807 L .55025 .56271 L 1 g
F
P
p
.57161 .53894 m .55755 .55813 L .55985 .55203 L 1 g
F
P
p
.55755 .55813 m .55027 .56807 L .55985 .55203 L 1 g
F
P
p
.002 w
.56157 .54745 m .57161 .53894 L p
.55985 .55203 L 1 g
F P
s
P
p
.56348 .5441 m .56257 .5491 L .56538 .53732 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56615 .51016 m .56744 .52865 L .55469 .52945 L 1 g
F
P
p
.002 w
.56802 .53693 m .56566 .5356 L p
.56744 .52865 L 1 g
F P
s
P
p
.56433 .53947 m .56566 .5356 L .56744 .52865 L 1 g
F
P
p
.002 w
.56566 .5356 m .55469 .52945 L p
.56744 .52865 L 1 g
F P
s
P
p
.56488 .53864 m .56538 .53732 L .56744 .52865 L 1 g
F
P
p
.56348 .5441 m .56538 .53732 L .56488 .53864 L 1 g
F
P
p
.55517 .55578 m .56141 .54759 L .56162 .5473 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56141 .54759 m .56157 .54745 L p
.54935 .56342 L 1 g
F P
s
P
p
.54935 .56342 m .54934 .56343 L .56141 .54759 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54946 .56376 L p
1 g
F P
s
P
p
.56075 .54566 m .54946 .56376 L .55461 .55679 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56566 .5356 m .56162 .5473 L .5448 .56167 L 1 g
F
P
p
.002 w
.56157 .54745 m .56141 .54759 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56141 .54759 m .5448 .56167 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.54946 .56376 m .54998 .56518 L p
.55461 .55679 L 1 g
F P
s
P
p
.002 w
.54791 .56531 m .5448 .56167 L .56141 .54759 L p
1 g
F P
s
P
p
.002 w
.534 .57568 m .54998 .56518 L .54944 .5637 L p
1 g
F P
s
P
p
.002 w
.54944 .5637 m .54934 .56343 L p
.54753 .56487 L 1 g
F P
s
P
p
.54753 .56487 m .534 .57568 L .54944 .5637 L 1 g
F
P
p
.5406 .56915 m .53952 .56988 L .54039 .56935 L 1 g
F
P
p
.53973 .56969 m .53952 .56988 L .5406 .56915 L 1 g
F
P
p
.002 w
.5448 .56167 m .54753 .56487 L p
.54137 .56867 L 1 g
F P
s
P
p
.002 w
.53171 .57464 m .53171 .57463 L p
.51882 .57904 L 1 g
F P
s
P
p
.5189 .579 m .51882 .57904 L .53171 .57463 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57464 L p
1 g
F P
s
P
p
.51882 .57904 m .51111 .583 L .53171 .57464 L 1 g
F
P
p
.002 w
.55027 .56807 m .55032 .56828 L p
.54768 .56918 L 1 g
F P
s
P
p
.002 w
.55032 .56828 m .55206 .57548 L p
.54768 .56918 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .534 .57568 L p
.54039 .56935 L 1 g
F P
s
P
p
.53952 .56988 m .5322 .57686 L .54039 .56935 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56821 .52978 L p
1 g
F P
s
P
p
.002 w
.56821 .52978 m .56744 .52865 L p
.56538 .53732 L 1 g
F P
s
P
p
.56538 .53732 m .56257 .5491 L .56821 .52978 L 1 g
F
P
p
.55517 .55578 m .55461 .55679 L .56141 .54759 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56162 .5473 L p
1 g
F P
s
P
p
.55461 .55679 m .54998 .56518 L .56162 .5473 L 1 g
F
P
p
.56433 .53947 m .56348 .5441 L .56566 .5356 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55469 .52945 m .56566 .5356 L p
.5448 .56167 L 1 g
F P
s
P
p
.56615 .51016 m .56871 .52369 L .56744 .52865 L 1 g
F
P
p
.002 w
.56744 .52865 m .56854 .53025 L p
.56673 .51853 L 1 g
F P
s
P
p
.002 w
.56593 .50904 m .55469 .52945 L p
.55946 .49551 L 1 g
F P
s
P
p
.57168 .52157 m .57161 .53894 L .56593 .50904 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56609 .50938 L p
1 g
F P
s
P
p
.56673 .51853 m .56854 .53025 L .56609 .50938 L 1 g
F
P
p
.002 w
.56609 .50938 m .56713 .51061 L p
.56334 .50338 L 1 g
F P
s
P
p
.50084 .45528 m .54355 .46994 L .51228 .46564 L 1 g
F
P
p
.51002 .46533 m .52277 .46772 L .52028 .4673 L 1 g
F
P
p
.5 .4634 m .51053 .4654 L .51002 .46533 L 1 g
F
P
p
.51053 .4654 m .52277 .46772 L .51002 .46533 L 1 g
F
P
p
.002 w
.52235 .46702 m .52277 .46772 L p
.51053 .4654 L 1 g
F P
s
P
p
.002 w
.54017 .4909 m .50537 .49119 L .50197 .46422 L p
1 g
F P
s
P
p
.002 w
.50197 .46422 m .50537 .49119 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.52028 .4673 L 1 g
F P
s
P
p
.52028 .4673 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.5009 .4557 m .50189 .46362 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.47763 .46706 m .47786 .46667 L p
.48677 .46576 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.48677 .46576 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .48677 .46576 L 1 g
F
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47723 .46771 L p
1 g
F P
s
P
p
.002 w
.47723 .46771 m .47718 .46778 L p
.47467 .46888 L 1 g
F P
s
P
p
.45826 .47608 m .47723 .46771 L .47467 .46888 L 1 g
F
P
p
.002 w
.45717 .46598 m .4606 .47389 L p
.4577 .47669 L 1 g
F P
s
P
p
.44339 .4905 m .4577 .47669 L .44833 .48577 L 1 g
F
P
p
.44292 .49101 m .44872 .48082 L .4577 .47669 L 1 g
F
P
p
.44872 .48082 m .45717 .46598 L .4577 .47669 L 1 g
F
P
p
.45717 .46598 m .5009 .4557 L .47763 .46706 L 1 g
F
P
p
.46315 .46911 m .47763 .46706 L .46811 .47171 L 1 g
F
P
p
.45717 .46598 m .47763 .46706 L .46315 .46911 L 1 g
F
P
p
.47763 .46706 m .48819 .4619 L .5 .46389 L 1 g
F
P
p
.48819 .4619 m .5009 .4557 L .5 .46389 L 1 g
F
P
p
.002 w
.50197 .46422 m .50084 .45528 L p
.51228 .46564 L 1 g
F P
s
P
p
.002 w
.50189 .46362 m .50197 .46422 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.52277 .46772 m .52282 .46778 L p
.52028 .4673 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47763 .46706 L p
1 g
F P
s
P
p
.48677 .46576 m .5 .46442 L .47763 .46706 L 1 g
F
P
p
.002 w
.50537 .49119 m .47164 .49935 L .46113 .47511 L p
1 g
F P
s
P
p
.002 w
.46113 .47511 m .47164 .49935 L p
.4577 .47669 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45754 .47686 L p
1 g
F P
s
P
p
.002 w
.45754 .47686 m .4577 .47669 L p
.46082 .47526 L 1 g
F P
s
P
p
.46082 .47526 m .47718 .46778 L .45754 .47686 L 1 g
F
P
p
.467 .47225 m .47467 .46888 L .46113 .47511 L 1 g
F
P
p
.467 .47225 m .46113 .47511 L .4577 .47669 L 1 g
F
P
p
.002 w
.46113 .47511 m .45717 .46598 L p
.46811 .47171 L 1 g
F P
s
P
p
.002 w
.4606 .47389 m .46113 .47511 L p
.4577 .47669 L 1 g
F P
s
P
p
.47467 .46888 m .47718 .46778 L .4577 .47669 L 1 g
F
P
p
.002 w
.4577 .47669 m .45698 .47747 L p
.44833 .48577 L 1 g
F P
s
P
p
.4426 .49157 m .44292 .49101 L .47164 .49935 L 1 g
F
P
p
.002 w
.45452 .4674 m .45717 .46598 L p
.4426 .49157 L 1 g
F P
s
P
p
.43485 .50826 m .442 .49198 L .43957 .49722 L 1 g
F
P
p
.43798 .50093 m .4359 .50516 L .43399 .50928 L 1 g
F
P
p
.002 w
.4359 .50516 m .44313 .5143 L p
.43399 .50928 L 1 g
F P
s
P
p
.002 w
.442 .49198 m .44166 .49233 L p
.43957 .49722 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44284 .49109 L p
1 g
F P
s
P
p
.44833 .48577 m .45698 .47747 L .44284 .49109 L 1 g
F
P
p
.43798 .50093 m .43957 .49722 L .4359 .50516 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.47164 .49935 m .44313 .5143 L .4359 .50516 L p
1 g
F P
s
P
p
.4426 .49157 m .47164 .49935 L .4359 .50516 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43399 .50928 L p
1 g
F P
s
P
p
.43957 .49722 m .44166 .49233 L .43399 .50928 L 1 g
F
P
p
.002 w
.43399 .50928 m .43343 .50995 L p
.43344 .51603 L 1 g
F P
s
P
p
.002 w
.39508 .51157 m .42046 .48564 L .43448 .50336 L p
1 g
F P
s
P
p
.43346 .52734 m .43343 .50995 L .4331 .51695 L 1 g
F
P
p
.002 w
.43274 .52459 m .44313 .5143 L p
.43254 .52868 L 1 g
F P
s
P
p
.002 w
.43343 .50995 m .43287 .51061 L p
.4331 .51695 L 1 g
F P
s
P
p
.002 w
.44313 .5143 m .43274 .52459 L p
.43363 .51376 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43254 .52868 L p
1 g
F P
s
P
p
.4331 .51695 m .43287 .51061 L .43254 .52868 L 1 g
F
P
p
.002 w
.43254 .52868 m .43198 .52949 L p
.43453 .53516 L 1 g
F P
s
P
p
.002 w
.44313 .5143 m .46739 .54018 L p
.43469 .53567 L 1 g
F P
s
P
p
.002 w
.43688 .54282 m .45358 .55345 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.43198 .52949 m .43146 .53025 L p
.43439 .53604 L 1 g
F P
s
P
p
.002 w
.46739 .54018 m .45358 .55345 L .43688 .54282 L p
1 g
F P
s
P
p
.43469 .53567 m .46739 .54018 L .43688 .54282 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43846 .54714 L p
1 g
F P
s
P
p
.43439 .53604 m .43146 .53025 L .43846 .54714 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45069 .56335 L p
1 g
F P
s
P
p
.002 w
.45069 .56335 m .45002 .56518 L p
.45917 .56883 L 1 g
F P
s
P
p
.46872 .57265 m .45069 .56335 L .45917 .56883 L 1 g
F
P
p
.45069 .56335 m .45358 .55345 L .45881 .5686 L 1 g
F
P
p
.002 w
.44947 .56256 m .44964 .56219 L p
.45069 .56335 L 1 g
F P
s
P
p
.44445 .5552 m .44964 .56219 L .45069 .56335 L 1 g
F
P
p
.002 w
.44964 .56219 m .45358 .55345 L p
.45069 .56335 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45063 .56352 L p
1 g
F P
s
P
p
.002 w
.45063 .56352 m .45069 .56335 L p
.44978 .56237 L 1 g
F P
s
P
p
.44978 .56237 m .43743 .5491 L .45063 .56352 L 1 g
F
P
p
.44445 .5552 m .43941 .55082 L .44964 .56219 L 1 g
F
P
p
.002 w
.45358 .55345 m .44964 .56219 L p
.44367 .55415 L 1 g
F P
s
P
p
.43941 .55082 m .43743 .5491 L .45069 .56335 L 1 g
F
P
p
.002 w
.45358 .55345 m .48524 .56898 L p
.45881 .5686 L 1 g
F P
s
P
p
.47667 .57751 m .46829 .57461 L .48166 .5765 L 1 g
F
P
p
.002 w
.45773 .57095 m .46507 .57265 L p
.46829 .57461 L 1 g
F P
s
P
p
.45917 .56883 m .46507 .57265 L .46829 .57461 L 1 g
F
P
p
.002 w
.46507 .57265 m .48166 .5765 L p
.46829 .57461 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57472 L p
1 g
F P
s
P
p
.002 w
.46827 .57472 m .46829 .57461 L p
.46731 .57411 L 1 g
F P
s
P
p
.46731 .57411 m .45002 .56518 L .46827 .57472 L 1 g
F
P
p
.45917 .56883 m .45804 .56838 L .46507 .57265 L 1 g
F
P
p
.002 w
.48524 .56898 m .48166 .5765 L .46507 .57265 L p
1 g
F P
s
P
p
.45881 .5686 m .48524 .56898 L .46507 .57265 L 1 g
F
P
p
.45804 .56838 m .45002 .56518 L .46829 .57461 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48898 .58177 L p
1 g
F P
s
P
p
.002 w
.48898 .58177 m .48905 .58084 L p
.48301 .57971 L 1 g
F P
s
P
p
.48301 .57971 m .4678 .57686 L .48898 .58177 L 1 g
F
P
p
.47697 .57761 m .4722 .57722 L .48175 .57927 L 1 g
F
P
p
.002 w
.48166 .5765 m .48175 .57927 L p
.47667 .57751 L 1 g
F P
s
P
p
.4722 .57722 m .4678 .57686 L .48905 .58084 L 1 g
F
P
p
.4995 .58088 m .4993 .58092 L .51015 .58092 L 1 g
F
P
p
.002 w
.51096 .58096 m .51096 .58092 L p
.49846 .58109 L 1 g
F P
s
P
p
.4993 .58092 m .49846 .58109 L .51096 .58092 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58096 L p
1 g
F P
s
P
p
.49846 .58109 m .48889 .583 L .51096 .58096 L 1 g
F
P
p
.002 w
.38329 .42443 m .34991 .46058 L .33428 .434 L p
1 g
F P
s
P
p
.002 w
.33428 .434 m .37011 .3942 L .38329 .42443 L p
1 g
F P
s
P
p
.002 w
.55148 .28949 m .48088 .28908 L .47843 .26706 L p
1 g
F P
s
P
p
.002 w
.61393 .36395 m .65926 .39376 L .65019 .42345 L p
1 g
F P
s
P
p
.002 w
.65926 .39376 m .61393 .36395 L .61612 .33401 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55002 .58306 m .55206 .57548 L .58531 .56651 L p
1 g
F P
s
P
p
.002 w
.58214 .55181 m .58531 .56651 L .55206 .57548 L p
1 g
F P
s
P
p
.002 w
.58531 .56651 m .58214 .55181 L .61145 .53193 L p
1 g
F P
s
P
p
.002 w
.42315 .53408 m .41373 .55624 L .38353 .54041 L p
1 g
F P
s
P
p
.002 w
.38353 .54041 m .39508 .51157 L .42315 .53408 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.61827 .48406 m .63716 .50919 L .61145 .53193 L p
1 g
F P
s
P
p
.002 w
.63716 .50919 m .61827 .48406 L .6364 .45392 L p
1 g
F P
s
P
p
.002 w
.55206 .57548 m .55027 .56807 L .58214 .55181 L p
1 g
F P
s
P
p
.002 w
.4234 .36384 m .37011 .3942 L .36111 .3657 L p
1 g
F P
s
P
p
.002 w
.36111 .3657 m .41674 .33346 L .4234 .36384 L p
1 g
F P
s
P
p
.002 w
.40027 .4553 m .37038 .48676 L .34991 .46058 L p
1 g
F P
s
P
p
.002 w
.34991 .46058 m .38329 .42443 L .40027 .4553 L p
1 g
F P
s
P
p
.002 w
.48399 .31615 m .41674 .33346 L .41276 .30678 L p
1 g
F P
s
P
p
.002 w
.41276 .30678 m .48088 .28908 L .48399 .31615 L p
1 g
F P
s
P
p
.002 w
.55365 .31643 m .61612 .33401 L .61393 .36395 L p
1 g
F P
s
P
p
.002 w
.61612 .33401 m .55365 .31643 L .55148 .28949 L p
1 g
F P
s
P
p
.002 w
.59641 .51276 m .61145 .53193 L .58214 .55181 L p
1 g
F P
s
P
p
.002 w
.61145 .53193 m .59641 .51276 L .61827 .48406 L p
1 g
F P
s
P
p
.002 w
.6082 .39658 m .65019 .42345 L .6364 .45392 L p
1 g
F P
s
P
p
.002 w
.65019 .42345 m .6082 .39658 L .61393 .36395 L p
1 g
F P
s
P
p
.002 w
.48088 .28908 m .55148 .28949 L .55365 .31643 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.57161 .53894 m .58214 .55181 L .55027 .56807 L p
1 g
F P
s
P
p
.002 w
.58214 .55181 m .57161 .53894 L .59641 .51276 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.55365 .31643 m .48399 .31615 L .48088 .28908 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.42046 .48564 m .39508 .51157 L .37038 .48676 L p
1 g
F P
s
P
p
.002 w
.37038 .48676 m .40027 .4553 L .42046 .48564 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49232 .56238 m .48524 .56898 L .45358 .55345 L p
1 g
F P
s
P
p
.002 w
.5448 .56167 m .53619 .55699 L .55469 .52945 L p
1 g
F P
s
P
p
.002 w
.59904 .43073 m .6364 .45392 L .61827 .48406 L p
1 g
F P
s
P
p
.002 w
.6364 .45392 m .59904 .43073 L .6082 .39658 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.43258 .39688 m .38329 .42443 L .37011 .3942 L p
1 g
F P
s
P
p
.002 w
.37011 .3942 m .4234 .36384 L .43258 .39688 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.50213 .55744 m .49232 .56238 L .46739 .54018 L p
1 g
F P
s
P
p
.002 w
.45358 .55345 m .46739 .54018 L .49232 .56238 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.55422 .34759 m .61393 .36395 L .6082 .39658 L p
1 g
F P
s
P
p
.002 w
.61393 .36395 m .55422 .34759 L .55365 .31643 L p
1 g
F P
s
P
p
.002 w
.53619 .55699 m .52538 .55458 L .53322 .5245 L p
1 g
F P
s
P
p
.002 w
.53322 .5245 m .55469 .52945 L .53619 .55699 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.57177 .49845 m .59641 .51276 L .57161 .53894 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58675 .46512 m .61827 .48406 L .59641 .51276 L p
1 g
F P
s
P
p
.002 w
.61827 .48406 m .58675 .46512 L .59904 .43073 L p
1 g
F P
s
P
p
.002 w
.48768 .34747 m .4234 .36384 L .41674 .33346 L p
1 g
F P
s
P
p
.002 w
.41674 .33346 m .48399 .31615 L .48768 .34747 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.51358 .55473 m .50213 .55744 L .48682 .53021 L p
1 g
F P
s
P
p
.002 w
.46739 .54018 m .48682 .53021 L .50213 .55744 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59641 .51276 m .57177 .49845 L .58675 .46512 L p
1 g
F P
s
P
p
.002 w
.52538 .55458 m .51358 .55473 L .50966 .52475 L p
1 g
F P
s
P
p
.002 w
.50966 .52475 m .53322 .5245 L .52538 .55458 L p
1 g
F P
s
P
p
.002 w
.48399 .31615 m .55365 .31643 L .55422 .34759 L p
1 g
F P
s
P
p
.002 w
.48682 .53021 m .50966 .52475 L .51358 .55473 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44397 .43137 m .40027 .4553 L .38329 .42443 L p
1 g
F P
s
P
p
.002 w
.38329 .42443 m .43258 .39688 L .44397 .43137 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55422 .34759 m .48768 .34747 L .48399 .31615 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.48682 .53021 m .46739 .54018 L .44313 .5143 L p
1 g
F P
s
P
p
.002 w
.55311 .38194 m .6082 .39658 L .59904 .43073 L p
1 g
F P
s
P
p
.002 w
.6082 .39658 m .55311 .38194 L .55422 .34759 L p
1 g
F P
s
P
p
.002 w
.55469 .52945 m .53322 .5245 L .54017 .4909 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.45717 .46598 m .42046 .48564 L .40027 .4553 L p
1 g
F P
s
P
p
.002 w
.40027 .4553 m .44397 .43137 L .45717 .46598 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.49182 .38198 m .43258 .39688 L .4234 .36384 L p
1 g
F P
s
P
p
.002 w
.4234 .36384 m .48768 .34747 L .49182 .38198 L p
1 g
F P
s
P
p
.002 w
.44313 .5143 m .47164 .49935 L .48682 .53021 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50966 .52475 m .48682 .53021 L .47164 .49935 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53322 .5245 m .50966 .52475 L .50537 .49119 L p
1 g
F P
s
P
p
.002 w
.50537 .49119 m .54017 .4909 L .53322 .5245 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48768 .34747 m .55422 .34759 L .55311 .38194 L p
1 g
F P
s
P
p
.002 w
.55033 .41821 m .59904 .43073 L .58675 .46512 L p
1 g
F P
s
P
p
.002 w
.59904 .43073 m .55033 .41821 L .55311 .38194 L p
1 g
F P
s
P
p
.002 w
.54596 .45501 m .58675 .46512 L .57177 .49845 L p
1 g
F P
s
P
p
.002 w
.47164 .49935 m .50537 .49119 L .50966 .52475 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.58675 .46512 m .54596 .45501 L .55033 .41821 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.55311 .38194 m .49182 .38198 L .48768 .34747 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.52268 .63049 m
.52388 .64098 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49627 .41839 m .44397 .43137 L .43258 .39688 L p
1 g
F P
s
P
p
.002 w
.43258 .39688 m .49182 .38198 L .49627 .41839 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.49182 .38198 m .55311 .38194 L .55033 .41821 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.50084 .45528 m .45717 .46598 L .44397 .43137 L p
1 g
F P
s
P
p
.002 w
.44397 .43137 m .49627 .41839 L .50084 .45528 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54596 .45501 m .50084 .45528 L .49627 .41839 L p
1 g
F P
s
P
p
.002 w
.49627 .41839 m .55033 .41821 L .54596 .45501 L p
1 g
F P
s
P
p
.002 w
.55033 .41821 m .49627 .41839 L .49182 .38198 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .74785 .45171 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .52686 .6673 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0813953)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0813953)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.43433 .45082 m .47918 .46578 L .48471 .43793 L p
1 g
F P
s
P
p
.002 w
.48471 .43793 m .44546 .42468 L .43433 .45082 L p
1 g
F P
s
P
p
.002 w
.52646 .44159 m .48471 .43793 L .47918 .46578 L p
1 g
F P
s
P
p
.002 w
.44546 .42468 m .48471 .43793 L .4906 .40997 L p
1 g
F P
s
P
p
.002 w
.48471 .43793 m .52646 .44159 L .52547 .413 L p
1 g
F P
s
P
p
.002 w
.52547 .413 m .4906 .40997 L .48471 .43793 L p
1 g
F P
s
P
p
.002 w
.4906 .40997 m .45788 .39878 L .44546 .42468 L p
1 g
F P
s
P
p
.002 w
.45788 .39878 m .4906 .40997 L .49674 .38239 L p
1 g
F P
s
P
p
.002 w
.4906 .40997 m .52547 .413 L .52386 .38472 L p
1 g
F P
s
P
p
.002 w
.52386 .38472 m .49674 .38239 L .4906 .40997 L p
1 g
F P
s
P
p
.002 w
.47918 .46578 m .52681 .46998 L .52646 .44159 L p
1 g
F P
s
P
p
.002 w
.56695 .43529 m .52646 .44159 L .52681 .46998 L p
1 g
F P
s
P
p
.002 w
.52646 .44159 m .56695 .43529 L .55923 .40757 L p
1 g
F P
s
P
p
.002 w
.55923 .40757 m .52547 .413 L .52646 .44159 L p
1 g
F P
s
P
p
.002 w
.52547 .413 m .55923 .40757 L .55007 .38038 L p
1 g
F P
s
P
p
.002 w
.55007 .38038 m .52386 .38472 L .52547 .413 L p
1 g
F P
s
P
p
.002 w
.42469 .47672 m .4741 .49301 L .47918 .46578 L p
1 g
F P
s
P
p
.002 w
.47918 .46578 m .43433 .45082 L .42469 .47672 L p
1 g
F P
s
P
p
.002 w
.52681 .46998 m .47918 .46578 L .4741 .49301 L p
1 g
F P
s
P
p
.002 w
.4741 .49301 m .52651 .49767 L .52681 .46998 L p
1 g
F P
s
P
p
.002 w
.57307 .46303 m .52681 .46998 L .52651 .49767 L p
1 g
F P
s
P
p
.002 w
.52681 .46998 m .57307 .46303 L .56695 .43529 L p
1 g
F P
s
P
p
.002 w
.49674 .38239 m .47134 .3736 L .45788 .39878 L p
1 g
F P
s
P
p
.002 w
.47134 .3736 m .49674 .38239 L .50303 .3557 L p
1 g
F P
s
P
p
.002 w
.49674 .38239 m .52386 .38472 L .52165 .35729 L p
1 g
F P
s
P
p
.002 w
.52165 .35729 m .50303 .3557 L .49674 .38239 L p
1 g
F P
s
P
p
.002 w
.52386 .38472 m .55007 .38038 L .53961 .35422 L p
1 g
F P
s
P
p
.002 w
.53961 .35422 m .52165 .35729 L .52386 .38472 L p
1 g
F P
s
P
p
.002 w
.41233 .4029 m .44546 .42468 L .45788 .39878 L p
1 g
F P
s
P
p
.002 w
.45788 .39878 m .4304 .38039 L .41233 .4029 L p
1 g
F P
s
P
p
.002 w
.4304 .38039 m .45788 .39878 L .47134 .3736 L p
1 g
F P
s
P
p
.002 w
.39629 .42625 m .43433 .45082 L .44546 .42468 L p
1 g
F P
s
P
p
.002 w
.44546 .42468 m .41233 .4029 L .39629 .42625 L p
1 g
F P
s
P
p
.002 w
.58868 .39405 m .55923 .40757 L .56695 .43529 L p
1 g
F P
s
P
p
.002 w
.55923 .40757 m .58868 .39405 L .5728 .36967 L p
1 g
F P
s
P
p
.002 w
.5728 .36967 m .55007 .38038 L .55923 .40757 L p
1 g
F P
s
P
p
.002 w
.47134 .3736 m .45014 .35916 L .4304 .38039 L p
1 g
F P
s
P
p
.002 w
.45014 .35916 m .47134 .3736 L .48562 .34961 L p
1 g
F P
s
P
p
.002 w
.50303 .3557 m .48562 .34961 L .47134 .3736 L p
1 g
F P
s
P
p
.002 w
.60243 .41941 m .56695 .43529 L .57307 .46303 L p
1 g
F P
s
P
p
.002 w
.56695 .43529 m .60243 .41941 L .58868 .39405 L p
1 g
F P
s
P
p
.002 w
.41676 .5019 m .46959 .51911 L .4741 .49301 L p
1 g
F P
s
P
p
.002 w
.4741 .49301 m .42469 .47672 L .41676 .5019 L p
1 g
F P
s
P
p
.002 w
.52651 .49767 m .4741 .49301 L .46959 .51911 L p
1 g
F P
s
P
p
.002 w
.38261 .45 m .42469 .47672 L .43433 .45082 L p
1 g
F P
s
P
p
.002 w
.43433 .45082 m .39629 .42625 L .38261 .45 L p
1 g
F P
s
P
p
.002 w
.55007 .38038 m .5728 .36967 L .55509 .34675 L p
1 g
F P
s
P
p
.002 w
.55509 .34675 m .53961 .35422 L .55007 .38038 L p
1 g
F P
s
P
p
.002 w
.46959 .51911 m .52555 .52412 L .52651 .49767 L p
1 g
F P
s
P
p
.002 w
.57746 .49028 m .52651 .49767 L .52555 .52412 L p
1 g
F P
s
P
p
.002 w
.52651 .49767 m .57746 .49028 L .57307 .46303 L p
1 g
F P
s
P
p
.002 w
.48562 .34961 m .50303 .3557 L .50934 .33041 L p
1 g
F P
s
P
p
.002 w
.50303 .3557 m .52165 .35729 L .51887 .33122 L p
1 g
F P
s
P
p
.002 w
.51887 .33122 m .50934 .33041 L .50303 .3557 L p
1 g
F P
s
P
p
.002 w
.52165 .35729 m .53961 .35422 L .52804 .32961 L p
1 g
F P
s
P
p
.002 w
.52804 .32961 m .51887 .33122 L .52165 .35729 L p
1 g
F P
s
P
p
.002 w
.61377 .44527 m .57307 .46303 L .57746 .49028 L p
1 g
F P
s
P
p
.002 w
.57307 .46303 m .61377 .44527 L .60243 .41941 L p
1 g
F P
s
P
p
.002 w
.48562 .34961 m .47118 .3396 L .45014 .35916 L p
1 g
F P
s
P
p
.002 w
.47118 .3396 m .48562 .34961 L .50045 .32727 L p
1 g
F P
s
P
p
.002 w
.50934 .33041 m .50045 .32727 L .48562 .34961 L p
1 g
F P
s
P
p
.002 w
.38865 .37435 m .41233 .4029 L .4304 .38039 L p
1 g
F P
s
P
p
.002 w
.4304 .38039 m .41098 .35638 L .38865 .37435 L p
1 g
F P
s
P
p
.002 w
.41098 .35638 m .4304 .38039 L .45014 .35916 L p
1 g
F P
s
P
p
.002 w
.53961 .35422 m .55509 .34675 L .5359 .32573 L p
1 g
F P
s
P
p
.002 w
.5359 .32573 m .52804 .32961 L .53961 .35422 L p
1 g
F P
s
P
p
.002 w
.45014 .35916 m .43533 .34038 L .41098 .35638 L p
1 g
F P
s
P
p
.002 w
.43533 .34038 m .45014 .35916 L .47118 .3396 L p
1 g
F P
s
P
p
.002 w
.37164 .47371 m .41676 .5019 L .42469 .47672 L p
1 g
F P
s
P
p
.002 w
.42469 .47672 m .38261 .45 L .37164 .47371 L p
1 g
F P
s
P
p
.002 w
.36884 .39396 m .39629 .42625 L .41233 .4029 L p
1 g
F P
s
P
p
.002 w
.41233 .4029 m .38865 .37435 L .36884 .39396 L p
1 g
F P
s
P
p
.002 w
.41074 .52583 m .46573 .54355 L .46959 .51911 L p
1 g
F P
s
P
p
.002 w
.46959 .51911 m .41676 .5019 L .41074 .52583 L p
1 g
F P
s
P
p
.002 w
.52555 .52412 m .46959 .51911 L .46573 .54355 L p
1 g
F P
s
P
p
.002 w
.58968 .35354 m .5728 .36967 L .58868 .39405 L p
1 g
F P
s
P
p
.002 w
.5728 .36967 m .58968 .35354 L .56646 .33558 L p
1 g
F P
s
P
p
.002 w
.56646 .33558 m .55509 .34675 L .5728 .36967 L p
1 g
F P
s
P
p
.002 w
.47118 .3396 m .46123 .32665 L .43533 .34038 L p
1 g
F P
s
P
p
.002 w
.46123 .32665 m .47118 .3396 L .49312 .32211 L p
1 g
F P
s
P
p
.002 w
.50045 .32727 m .49312 .32211 L .47118 .3396 L p
1 g
F P
s
P
p
.002 w
.61078 .3735 m .58868 .39405 L .60243 .41941 L p
1 g
F P
s
P
p
.002 w
.58868 .39405 m .61078 .3735 L .58968 .35354 L p
1 g
F P
s
P
p
.002 w
.46573 .54355 m .52395 .5488 L .52555 .52412 L p
1 g
F P
s
P
p
.002 w
.57999 .51648 m .52555 .52412 L .52395 .5488 L p
1 g
F P
s
P
p
.002 w
.52555 .52412 m .57999 .51648 L .57746 .49028 L p
1 g
F P
s
P
p
.002 w
.62243 .47114 m .57746 .49028 L .57999 .51648 L p
1 g
F P
s
P
p
.002 w
.57746 .49028 m .62243 .47114 L .61377 .44527 L p
1 g
F P
s
P
p
.002 w
.55509 .34675 m .56646 .33558 L .54159 .31998 L p
1 g
F P
s
P
p
.002 w
.54159 .31998 m .5359 .32573 L .55509 .34675 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .50045 .32727 L .50934 .33041 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .50934 .33041 L .51887 .33122 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .51887 .33122 L .52804 .32961 L closepath p
1 g
F P
s
P
p
.002 w
.62931 .3951 m .60243 .41941 L .61377 .44527 L p
1 g
F P
s
P
p
.002 w
.60243 .41941 m .62931 .3951 L .61078 .3735 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .49312 .32211 L .50045 .32727 L closepath p
1 g
F P
s
P
p
.002 w
.35202 .41483 m .38261 .45 L .39629 .42625 L p
1 g
F P
s
P
p
.002 w
.39629 .42625 m .36884 .39396 L .35202 .41483 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .52804 .32961 L .5359 .32573 L closepath p
1 g
F P
s
P
p
.002 w
.49312 .32211 m .48815 .31546 L .46123 .32665 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .48815 .31546 L .49312 .32211 L closepath p
1 g
F P
s
P
p
.002 w
.36367 .49686 m .41074 .52583 L .41676 .5019 L p
1 g
F P
s
P
p
.002 w
.41676 .5019 m .37164 .47371 L .36367 .49686 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .5359 .32573 L .54159 .31998 L closepath p
1 g
F P
s
P
p
.002 w
.42865 .31905 m .43533 .34038 L .46123 .32665 L p
1 g
F P
s
P
p
.002 w
.46123 .32665 m .45691 .31204 L .42865 .31905 L p
1 g
F P
s
P
p
.002 w
.45691 .31204 m .46123 .32665 L .48815 .31546 L p
1 g
F P
s
P
p
.002 w
.4019 .32894 m .41098 .35638 L .43533 .34038 L p
1 g
F P
s
P
p
.002 w
.43533 .34038 m .42865 .31905 L .4019 .32894 L p
1 g
F P
s
P
p
.002 w
.64484 .4179 m .61377 .44527 L .62243 .47114 L p
1 g
F P
s
P
p
.002 w
.61377 .44527 m .64484 .4179 L .62931 .3951 L p
1 g
F P
s
P
p
.002 w
.48815 .31546 m .48607 .30802 L .45691 .31204 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .48607 .30802 L .48815 .31546 L closepath p
1 g
F P
s
P
p
.002 w
.37724 .34156 m .38865 .37435 L .41098 .35638 L p
1 g
F P
s
P
p
.002 w
.41098 .35638 m .4019 .32894 L .37724 .34156 L p
1 g
F P
s
P
p
.002 w
.57242 .3218 m .56646 .33558 L .58968 .35354 L p
1 g
F P
s
P
p
.002 w
.56646 .33558 m .57242 .3218 L .54449 .31294 L p
1 g
F P
s
P
p
.002 w
.54449 .31294 m .54159 .31998 L .56646 .33558 L p
1 g
F P
s
P
p
.002 w
.52395 .5488 m .58058 .54111 L .57999 .51648 L p
1 g
F P
s
P
p
.002 w
.62816 .49647 m .57999 .51648 L .58058 .54111 L p
1 g
F P
s
P
p
.002 w
.57999 .51648 m .62816 .49647 L .62243 .47114 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .54159 .31998 L .54449 .31294 L closepath p
1 g
F P
s
P
p
.002 w
.40683 .54798 m .46264 .56578 L .46573 .54355 L p
1 g
F P
s
P
p
.002 w
.46573 .54355 m .41074 .52583 L .40683 .54798 L p
1 g
F P
s
P
p
.002 w
.52395 .5488 m .46573 .54355 L .46264 .56578 L p
1 g
F P
s
P
p
.002 w
.59876 .33346 m .58968 .35354 L .61078 .3735 L p
1 g
F P
s
P
p
.002 w
.58968 .35354 m .59876 .33346 L .57242 .3218 L p
1 g
F P
s
P
p
.002 w
.33862 .43656 m .37164 .47371 L .38261 .45 L p
1 g
F P
s
P
p
.002 w
.38261 .45 m .35202 .41483 L .33862 .43656 L p
1 g
F P
s
P
p
.002 w
.46264 .56578 m .52169 .57115 L .52395 .5488 L p
1 g
F P
s
P
p
.002 w
.58058 .54111 m .52395 .5488 L .52169 .57115 L p
1 g
F P
s
P
p
.002 w
.45881 .29729 m .45691 .31204 L .48607 .30802 L p
1 g
F P
s
P
p
.002 w
.48607 .30802 m .48717 .30057 L .45881 .29729 L p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .48717 .30057 L .48607 .30802 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .54085 .29809 L .53463 .29191 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .53463 .29191 L .52627 .28752 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .52627 .28752 L .51669 .28544 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .51669 .28544 L .50696 .2859 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .50696 .2859 L .49819 .28885 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .49819 .28885 L .49135 .29393 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .49135 .29393 L .48717 .30057 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .54449 .31294 L .54425 .30537 L closepath p
1 g
F P
s
P
p
.002 w
.51556 .30705 m .54425 .30537 L .54085 .29809 L closepath p
1 g
F P
s
P
p
.002 w
.62295 .34774 m .61078 .3735 L .62931 .3951 L p
1 g
F P
s
P
p
.002 w
.61078 .3735 m .62295 .34774 L .59876 .33346 L p
1 g
F P
s
P
p
.002 w
.35528 .3567 m .36884 .39396 L .38865 .37435 L p
1 g
F P
s
P
p
.002 w
.38865 .37435 m .37724 .34156 L .35528 .3567 L p
1 g
F P
s
P
p
.002 w
.54425 .30537 m .54449 .31294 L .57242 .3218 L p
1 g
F P
s
P
p
.002 w
.43109 .29735 m .42865 .31905 L .45691 .31204 L p
1 g
F P
s
P
p
.002 w
.45691 .31204 m .45881 .29729 L .43109 .29735 L p
1 g
F P
s
P
p
.002 w
.65696 .44146 m .62243 .47114 L .62816 .49647 L p
1 g
F P
s
P
p
.002 w
.62243 .47114 m .65696 .44146 L .64484 .4179 L p
1 g
F P
s
P
p
.002 w
.4669 .28404 m .45881 .29729 L .48717 .30057 L p
1 g
F P
s
P
p
.002 w
.48717 .30057 m .49135 .29393 L .4669 .28404 L p
1 g
F P
s
P
p
.002 w
.359 .51894 m .40683 .54798 L .41074 .52583 L p
1 g
F P
s
P
p
.002 w
.41074 .52583 m .36367 .49686 L .359 .51894 L p
1 g
F P
s
P
p
.002 w
.57219 .30683 m .57242 .3218 L .59876 .33346 L p
1 g
F P
s
P
p
.002 w
.57242 .3218 m .57219 .30683 L .54425 .30537 L p
1 g
F P
s
P
p
.002 w
.40462 .30082 m .4019 .32894 L .42865 .31905 L p
1 g
F P
s
P
p
.002 w
.42865 .31905 m .43109 .29735 L .40462 .30082 L p
1 g
F P
s
P
p
.002 w
.54085 .29809 m .54425 .30537 L .57219 .30683 L p
1 g
F P
s
P
p
.002 w
.6444 .36438 m .62931 .3951 L .64484 .4179 L p
1 g
F P
s
P
p
.002 w
.62931 .3951 m .6444 .36438 L .62295 .34774 L p
1 g
F P
s
P
p
.002 w
.32908 .45869 m .36367 .49686 L .37164 .47371 L p
1 g
F P
s
P
p
.002 w
.37164 .47371 m .33862 .43656 L .32908 .45869 L p
1 g
F P
s
P
p
.002 w
.33657 .37411 m .35202 .41483 L .36884 .39396 L p
1 g
F P
s
P
p
.002 w
.36884 .39396 m .35528 .3567 L .33657 .37411 L p
1 g
F P
s
P
p
.002 w
.52169 .57115 m .57912 .56357 L .58058 .54111 L p
1 g
F P
s
P
p
.002 w
.63074 .52072 m .58058 .54111 L .57912 .56357 L p
1 g
F P
s
P
p
.002 w
.58058 .54111 m .63074 .52072 L .62816 .49647 L p
1 g
F P
s
P
p
.002 w
.48042 .2738 m .4669 .28404 L .49135 .29393 L p
1 g
F P
s
P
p
.002 w
.49135 .29393 m .49819 .28885 L .48042 .2738 L p
1 g
F P
s
P
p
.002 w
.59877 .31147 m .59876 .33346 L .62295 .34774 L p
1 g
F P
s
P
p
.002 w
.59876 .33346 m .59877 .31147 L .57219 .30683 L p
1 g
F P
s
P
p
.002 w
.53463 .29191 m .54085 .29809 L .56563 .29231 L p
1 g
F P
s
P
p
.002 w
.57219 .30683 m .56563 .29231 L .54085 .29809 L p
1 g
F P
s
P
p
.002 w
.44275 .27768 m .43109 .29735 L .45881 .29729 L p
1 g
F P
s
P
p
.002 w
.45881 .29729 m .4669 .28404 L .44275 .27768 L p
1 g
F P
s
P
p
.002 w
.40519 .56779 m .46041 .58525 L .46264 .56578 L p
1 g
F P
s
P
p
.002 w
.46264 .56578 m .40683 .54798 L .40519 .56779 L p
1 g
F P
s
P
p
.002 w
.52169 .57115 m .46264 .56578 L .46041 .58525 L p
1 g
F P
s
P
p
.002 w
.38002 .30774 m .37724 .34156 L .4019 .32894 L p
1 g
F P
s
P
p
.002 w
.4019 .32894 m .40462 .30082 L .38002 .30774 L p
1 g
F P
s
P
p
.002 w
.49792 .26782 m .48042 .2738 L .49819 .28885 L p
1 g
F P
s
P
p
.002 w
.49819 .28885 m .50696 .2859 L .49792 .26782 L p
1 g
F P
s
P
p
.002 w
.46041 .58525 m .51881 .59059 L .52169 .57115 L p
1 g
F P
s
P
p
.002 w
.57912 .56357 m .52169 .57115 L .51881 .59059 L p
1 g
F P
s
P
p
.002 w
.56563 .29231 m .55334 .27989 L .53463 .29191 L p
1 g
F P
s
P
p
.002 w
.52627 .28752 m .53463 .29191 L .55334 .27989 L p
1 g
F P
s
P
p
.002 w
.56563 .29231 m .57219 .30683 L .59877 .31147 L p
1 g
F P
s
P
p
.002 w
.6653 .46527 m .62816 .49647 L .63074 .52072 L p
1 g
F P
s
P
p
.002 w
.62816 .49647 m .6653 .46527 L .65696 .44146 L p
1 g
F P
s
P
p
.002 w
.51741 .26685 m .49792 .26782 L .50696 .2859 L p
1 g
F P
s
P
p
.002 w
.50696 .2859 m .51669 .28544 L .51741 .26685 L p
1 g
F P
s
P
p
.002 w
.55334 .27989 m .53664 .27105 L .52627 .28752 L p
1 g
F P
s
P
p
.002 w
.51669 .28544 m .52627 .28752 L .53664 .27105 L p
1 g
F P
s
P
p
.002 w
.66257 .38308 m .64484 .4179 L .65696 .44146 L p
1 g
F P
s
P
p
.002 w
.64484 .4179 m .66257 .38308 L .6444 .36438 L p
1 g
F P
s
P
p
.002 w
.53664 .27105 m .51741 .26685 L .51669 .28544 L p
1 g
F P
s
P
p
.002 w
.62338 .31927 m .62295 .34774 L .6444 .36438 L p
1 g
F P
s
P
p
.002 w
.62295 .34774 m .62338 .31927 L .59877 .31147 L p
1 g
F P
s
P
p
.002 w
.32169 .39345 m .33862 .43656 L .35202 .41483 L p
1 g
F P
s
P
p
.002 w
.35202 .41483 m .33657 .37411 L .32169 .39345 L p
1 g
F P
s
P
p
.002 w
.35788 .5394 m .40519 .56779 L .40683 .54798 L p
1 g
F P
s
P
p
.002 w
.40683 .54798 m .359 .51894 L .35788 .5394 L p
1 g
F P
s
P
p
.002 w
.41943 .27513 m .40462 .30082 L .43109 .29735 L p
1 g
F P
s
P
p
.002 w
.43109 .29735 m .44275 .27768 L .41943 .27513 L p
1 g
F P
s
P
p
.002 w
.46262 .26236 m .44275 .27768 L .4669 .28404 L p
1 g
F P
s
P
p
.002 w
.4669 .28404 m .48042 .2738 L .46262 .26236 L p
1 g
F P
s
P
p
.002 w
.35794 .31806 m .35528 .3567 L .37724 .34156 L p
1 g
F P
s
P
p
.002 w
.37724 .34156 m .38002 .30774 L .35794 .31806 L p
1 g
F P
s
P
p
.002 w
.32378 .48071 m .359 .51894 L .36367 .49686 L p
1 g
F P
s
P
p
.002 w
.36367 .49686 m .32908 .45869 L .32378 .48071 L p
1 g
F P
s
P
p
.002 w
.55334 .27989 m .56563 .29231 L .58935 .28994 L p
1 g
F P
s
P
p
.002 w
.59877 .31147 m .58935 .28994 L .56563 .29231 L p
1 g
F P
s
P
p
.002 w
.58935 .28994 m .59877 .31147 L .62338 .31927 L p
1 g
F P
s
P
p
.002 w
.51881 .59059 m .57557 .5833 L .57912 .56357 L p
1 g
F P
s
P
p
.002 w
.63001 .54331 m .57912 .56357 L .57557 .5833 L p
1 g
F P
s
P
p
.002 w
.57912 .56357 m .63001 .54331 L .63074 .52072 L p
1 g
F P
s
P
p
.002 w
.67693 .40349 m .65696 .44146 L .6653 .46527 L p
1 g
F P
s
P
p
.002 w
.65696 .44146 m .67693 .40349 L .66257 .38308 L p
1 g
F P
s
P
p
.002 w
.48861 .25336 m .46262 .26236 L .48042 .2738 L p
1 g
F P
s
P
p
.002 w
.48042 .2738 m .49792 .26782 L .48861 .25336 L p
1 g
F P
s
P
p
.002 w
.64538 .33017 m .6444 .36438 L .66257 .38308 L p
1 g
F P
s
P
p
.002 w
.6444 .36438 m .64538 .33017 L .62338 .31927 L p
1 g
F P
s
P
p
.002 w
.66953 .48881 m .63074 .52072 L .63001 .54331 L p
1 g
F P
s
P
p
.002 w
.63074 .52072 m .66953 .48881 L .6653 .46527 L p
1 g
F P
s
P
p
.002 w
.406 .5847 m .45913 .60138 L .46041 .58525 L p
1 g
F P
s
P
p
.002 w
.46041 .58525 m .40519 .56779 L .406 .5847 L p
1 g
F P
s
P
p
.002 w
.51881 .59059 m .46041 .58525 L .45913 .60138 L p
1 g
F P
s
P
p
.002 w
.58935 .28994 m .57126 .27141 L .55334 .27989 L p
1 g
F P
s
P
p
.002 w
.53664 .27105 m .55334 .27989 L .57126 .27141 L p
1 g
F P
s
P
p
.002 w
.39755 .27662 m .38002 .30774 L .40462 .30082 L p
1 g
F P
s
P
p
.002 w
.40462 .30082 m .41943 .27513 L .39755 .27662 L p
1 g
F P
s
P
p
.002 w
.45913 .60138 m .51533 .60654 L .51881 .59059 L p
1 g
F P
s
P
p
.002 w
.57557 .5833 m .51881 .59059 L .51533 .60654 L p
1 g
F P
s
P
p
.002 w
.31115 .41434 m .32908 .45869 L .33862 .43656 L p
1 g
F P
s
P
p
.002 w
.33862 .43656 m .32169 .39345 L .31115 .41434 L p
1 g
F P
s
P
p
.002 w
.33903 .33168 m .33657 .37411 L .35528 .3567 L p
1 g
F P
s
P
p
.002 w
.35528 .3567 m .35794 .31806 L .33903 .33168 L p
1 g
F P
s
P
p
.002 w
.51771 .25187 m .48861 .25336 L .49792 .26782 L p
1 g
F P
s
P
p
.002 w
.49792 .26782 m .51741 .26685 L .51771 .25187 L p
1 g
F P
s
P
p
.002 w
.44521 .25499 m .41943 .27513 L .44275 .27768 L p
1 g
F P
s
P
p
.002 w
.44275 .27768 m .46262 .26236 L .44521 .25499 L p
1 g
F P
s
P
p
.002 w
.57126 .27141 m .54642 .25815 L .53664 .27105 L p
1 g
F P
s
P
p
.002 w
.51741 .26685 m .53664 .27105 L .54642 .25815 L p
1 g
F P
s
P
p
.002 w
.54642 .25815 m .51771 .25187 L .51741 .26685 L p
1 g
F P
s
P
p
.002 w
.61143 .29119 m .62338 .31927 L .64538 .33017 L p
1 g
F P
s
P
p
.002 w
.62338 .31927 m .61143 .29119 L .58935 .28994 L p
1 g
F P
s
P
p
.002 w
.32304 .50209 m .35788 .5394 L .359 .51894 L p
1 g
F P
s
P
p
.002 w
.359 .51894 m .32378 .48071 L .32304 .50209 L p
1 g
F P
s
P
p
.002 w
.57126 .27141 m .58935 .28994 L .61143 .29119 L p
1 g
F P
s
P
p
.002 w
.36051 .55766 m .406 .5847 L .40519 .56779 L p
1 g
F P
s
P
p
.002 w
.40519 .56779 m .35788 .5394 L .36051 .55766 L p
1 g
F P
s
P
p
.002 w
.68697 .42517 m .6653 .46527 L .66953 .48881 L p
1 g
F P
s
P
p
.002 w
.6653 .46527 m .68697 .42517 L .67693 .40349 L p
1 g
F P
s
P
p
.002 w
.66414 .34405 m .66257 .38308 L .67693 .40349 L p
1 g
F P
s
P
p
.002 w
.66257 .38308 m .66414 .34405 L .64538 .33017 L p
1 g
F P
s
P
p
.002 w
.51533 .60654 m .5699 .59969 L .57557 .5833 L p
1 g
F P
s
P
p
.002 w
.62581 .56363 m .57557 .5833 L .5699 .59969 L p
1 g
F P
s
P
p
.002 w
.57557 .5833 m .62581 .56363 L .63001 .54331 L p
1 g
F P
s
P
p
.002 w
.37771 .2823 m .35794 .31806 L .38002 .30774 L p
1 g
F P
s
P
p
.002 w
.38002 .30774 m .39755 .27662 L .37771 .2823 L p
1 g
F P
s
P
p
.002 w
.66936 .51148 m .63001 .54331 L .62581 .56363 L p
1 g
F P
s
P
p
.002 w
.63001 .54331 m .66936 .51148 L .66953 .48881 L p
1 g
F P
s
P
p
.002 w
.47925 .24306 m .44521 .25499 L .46262 .26236 L p
1 g
F P
s
P
p
.002 w
.46262 .26236 m .48861 .25336 L .47925 .24306 L p
1 g
F P
s
P
p
.002 w
.3239 .3484 m .32169 .39345 L .33657 .37411 L p
1 g
F P
s
P
p
.002 w
.33657 .37411 m .33903 .33168 L .3239 .3484 L p
1 g
F P
s
P
p
.002 w
.30542 .4363 m .32378 .48071 L .32908 .45869 L p
1 g
F P
s
P
p
.002 w
.32908 .45869 m .31115 .41434 L .30542 .4363 L p
1 g
F P
s
P
p
.002 w
.61143 .29119 m .58793 .26685 L .57126 .27141 L p
1 g
F P
s
P
p
.002 w
.54642 .25815 m .57126 .27141 L .58793 .26685 L p
1 g
F P
s
P
p
.002 w
.42863 .25207 m .39755 .27662 L .41943 .27513 L p
1 g
F P
s
P
p
.002 w
.41943 .27513 m .44521 .25499 L .42863 .25207 L p
1 g
F P
s
P
p
.002 w
.40935 .59813 m .45889 .6136 L .45913 .60138 L p
1 g
F P
s
P
p
.002 w
.45913 .60138 m .406 .5847 L .40935 .59813 L p
1 g
F P
s
P
p
.002 w
.51533 .60654 m .45913 .60138 L .45889 .6136 L p
1 g
F P
s
P
p
.002 w
.63125 .29619 m .64538 .33017 L .66414 .34405 L p
1 g
F P
s
P
p
.002 w
.64538 .33017 m .63125 .29619 L .61143 .29119 L p
1 g
F P
s
P
p
.002 w
.45889 .6136 m .5113 .61843 L .51533 .60654 L p
1 g
F P
s
P
p
.002 w
.5699 .59969 m .51533 .60654 L .5113 .61843 L p
1 g
F P
s
P
p
.002 w
.51755 .24107 m .47925 .24306 L .48861 .25336 L p
1 g
F P
s
P
p
.002 w
.48861 .25336 m .51771 .25187 L .51755 .24107 L p
1 g
F P
s
P
p
.002 w
.58793 .26685 m .61143 .29119 L .63125 .29619 L p
1 g
F P
s
P
p
.002 w
.58793 .26685 m .55535 .24936 L .54642 .25815 L p
1 g
F P
s
P
p
.002 w
.51771 .25187 m .54642 .25815 L .55535 .24936 L p
1 g
F P
s
P
p
.002 w
.67906 .36067 m .67693 .40349 L .68697 .42517 L p
1 g
F P
s
P
p
.002 w
.67693 .40349 m .67906 .36067 L .66414 .34405 L p
1 g
F P
s
P
p
.002 w
.3271 .52222 m .36051 .55766 L .35788 .5394 L p
1 g
F P
s
P
p
.002 w
.35788 .5394 m .32304 .50209 L .3271 .52222 L p
1 g
F P
s
P
p
.002 w
.69227 .44764 m .66953 .48881 L .66936 .51148 L p
1 g
F P
s
P
p
.002 w
.66953 .48881 m .69227 .44764 L .68697 .42517 L p
1 g
F P
s
P
p
.002 w
.55535 .24936 m .51755 .24107 L .51771 .25187 L p
1 g
F P
s
P
p
.002 w
.36703 .57314 m .40935 .59813 L .406 .5847 L p
1 g
F P
s
P
p
.002 w
.406 .5847 m .36051 .55766 L .36703 .57314 L p
1 g
F P
s
P
p
.002 w
.36054 .29224 m .33903 .33168 L .35794 .31806 L p
1 g
F P
s
P
p
.002 w
.35794 .31806 m .37771 .2823 L .36054 .29224 L p
1 g
F P
s
P
p
.002 w
.31314 .36792 m .31115 .41434 L .32169 .39345 L p
1 g
F P
s
P
p
.002 w
.32169 .39345 m .3239 .3484 L .31314 .36792 L p
1 g
F P
s
P
p
.002 w
.5113 .61843 m .56213 .61215 L .5699 .59969 L p
1 g
F P
s
P
p
.002 w
.6181 .58107 m .5699 .59969 L .56213 .61215 L p
1 g
F P
s
P
p
.002 w
.5699 .59969 m .6181 .58107 L .62581 .56363 L p
1 g
F P
s
P
p
.002 w
.66461 .53268 m .62581 .56363 L .6181 .58107 L p
1 g
F P
s
P
p
.002 w
.62581 .56363 m .66461 .53268 L .66936 .51148 L p
1 g
F P
s
P
p
.002 w
.30487 .4588 m .32304 .50209 L .32378 .48071 L p
1 g
F P
s
P
p
.002 w
.32378 .48071 m .30542 .4363 L .30487 .4588 L p
1 g
F P
s
P
p
.002 w
.47007 .23745 m .42863 .25207 L .44521 .25499 L p
1 g
F P
s
P
p
.002 w
.44521 .25499 m .47925 .24306 L .47007 .23745 L p
1 g
F P
s
P
p
.002 w
.41338 .25393 m .37771 .2823 L .39755 .27662 L p
1 g
F P
s
P
p
.002 w
.39755 .27662 m .42863 .25207 L .41338 .25393 L p
1 g
F P
s
P
p
.002 w
.6482 .305 m .66414 .34405 L .67906 .36067 L p
1 g
F P
s
P
p
.002 w
.66414 .34405 m .6482 .305 L .63125 .29619 L p
1 g
F P
s
P
p
.002 w
.63125 .29619 m .60286 .26654 L .58793 .26685 L p
1 g
F P
s
P
p
.002 w
.55535 .24936 m .58793 .26685 L .60286 .26654 L p
1 g
F P
s
P
p
.002 w
.68955 .37974 m .68697 .42517 L .69227 .44764 L p
1 g
F P
s
P
p
.002 w
.68697 .42517 m .68955 .37974 L .67906 .36067 L p
1 g
F P
s
P
p
.002 w
.41532 .60753 m .45976 .62136 L .45889 .6136 L p
1 g
F P
s
P
p
.002 w
.45889 .6136 m .40935 .59813 L .41532 .60753 L p
1 g
F P
s
P
p
.002 w
.5113 .61843 m .45889 .6136 L .45976 .62136 L p
1 g
F P
s
P
p
.002 w
.69245 .47034 m .66936 .51148 L .66461 .53268 L p
1 g
F P
s
P
p
.002 w
.66936 .51148 m .69245 .47034 L .69227 .44764 L p
1 g
F P
s
P
p
.002 w
.60286 .26654 m .63125 .29619 L .6482 .305 L p
1 g
F P
s
P
p
.002 w
.45976 .62136 m .5068 .6257 L .5113 .61843 L p
1 g
F P
s
P
p
.002 w
.56213 .61215 m .5113 .61843 L .5068 .6257 L p
1 g
F P
s
P
p
.002 w
.5169 .23498 m .47007 .23745 L .47925 .24306 L p
1 g
F P
s
P
p
.002 w
.47925 .24306 m .51755 .24107 L .5169 .23498 L p
1 g
F P
s
P
p
.002 w
.3361 .5405 m .36703 .57314 L .36051 .55766 L p
1 g
F P
s
P
p
.002 w
.36051 .55766 m .3271 .52222 L .3361 .5405 L p
1 g
F P
s
P
p
.002 w
.34665 .30638 m .3239 .3484 L .33903 .33168 L p
1 g
F P
s
P
p
.002 w
.33903 .33168 m .36054 .29224 L .34665 .30638 L p
1 g
F P
s
P
p
.002 w
.60286 .26654 m .56314 .24514 L .55535 .24936 L p
1 g
F P
s
P
p
.002 w
.51755 .24107 m .55535 .24936 L .56314 .24514 L p
1 g
F P
s
P
p
.002 w
.30726 .38982 m .30542 .4363 L .31115 .41434 L p
1 g
F P
s
P
p
.002 w
.31115 .41434 m .31314 .36792 L .30726 .38982 L p
1 g
F P
s
P
p
.002 w
.56314 .24514 m .5169 .23498 L .51755 .24107 L p
1 g
F P
s
P
p
.002 w
.37749 .58527 m .41532 .60753 L .40935 .59813 L p
1 g
F P
s
P
p
.002 w
.40935 .59813 m .36703 .57314 L .37749 .58527 L p
1 g
F P
s
P
p
.002 w
.30978 .48123 m .3271 .52222 L .32304 .50209 L p
1 g
F P
s
P
p
.002 w
.32304 .50209 m .30487 .4588 L .30978 .48123 L p
1 g
F P
s
P
p
.002 w
.56213 .61215 m .60687 .59503 L .6181 .58107 L p
1 g
F P
s
P
p
.002 w
.65517 .55177 m .6181 .58107 L .60687 .59503 L p
1 g
F P
s
P
p
.002 w
.6181 .58107 m .65517 .55177 L .66461 .53268 L p
1 g
F P
s
P
p
.002 w
.5068 .6257 m .55235 .62013 L .56213 .61215 L p
1 g
F P
s
P
p
.002 w
.60687 .59503 m .56213 .61215 L .55235 .62013 L p
1 g
F P
s
P
p
.002 w
.39995 .26081 m .36054 .29224 L .37771 .2823 L p
1 g
F P
s
P
p
.002 w
.37771 .2823 m .41338 .25393 L .39995 .26081 L p
1 g
F P
s
P
p
.002 w
.46133 .23697 m .41338 .25393 L .42863 .25207 L p
1 g
F P
s
P
p
.002 w
.42863 .25207 m .47007 .23745 L .46133 .23697 L p
1 g
F P
s
P
p
.002 w
.66167 .3176 m .67906 .36067 L .68955 .37974 L p
1 g
F P
s
P
p
.002 w
.67906 .36067 m .66167 .3176 L .6482 .305 L p
1 g
F P
s
P
p
.002 w
.69512 .40085 m .69227 .44764 L .69245 .47034 L p
1 g
F P
s
P
p
.002 w
.69227 .44764 m .69512 .40085 L .68955 .37974 L p
1 g
F P
s
P
p
.002 w
.6482 .305 m .61555 .27074 L .60286 .26654 L p
1 g
F P
s
P
p
.002 w
.56314 .24514 m .60286 .26654 L .61555 .27074 L p
1 g
F P
s
P
p
.002 w
.68729 .49265 m .66461 .53268 L .65517 .55177 L p
1 g
F P
s
P
p
.002 w
.66461 .53268 m .68729 .49265 L .69245 .47034 L p
1 g
F P
s
P
p
.002 w
.61555 .27074 m .6482 .305 L .66167 .3176 L p
1 g
F P
s
P
p
.002 w
.33662 .32454 m .31314 .36792 L .3239 .3484 L p
1 g
F P
s
P
p
.002 w
.3239 .3484 m .34665 .30638 L .33662 .32454 L p
1 g
F P
s
P
p
.002 w
.30668 .41357 m .30487 .4588 L .30542 .4363 L p
1 g
F P
s
P
p
.002 w
.30542 .4363 m .30726 .38982 L .30668 .41357 L p
1 g
F P
s
P
p
.002 w
.35004 .55632 m .37749 .58527 L .36703 .57314 L p
1 g
F P
s
P
p
.002 w
.36703 .57314 m .3361 .5405 L .35004 .55632 L p
1 g
F P
s
P
p
.002 w
.42391 .61238 m .46178 .62415 L .45976 .62136 L p
1 g
F P
s
P
p
.002 w
.45976 .62136 m .41532 .60753 L .42391 .61238 L p
1 g
F P
s
P
p
.002 w
.5068 .6257 m .45976 .62136 L .46178 .62415 L p
1 g
F P
s
P
p
.002 w
.46178 .62415 m .50192 .62786 L .5068 .6257 L p
1 g
F P
s
P
p
.002 w
.55235 .62013 m .5068 .6257 L .50192 .62786 L p
1 g
F P
s
P
p
.002 w
.51575 .2341 m .46133 .23697 L .47007 .23745 L p
1 g
F P
s
P
p
.002 w
.47007 .23745 m .5169 .23498 L .51575 .2341 L p
1 g
F P
s
P
p
.004 w
.47023 .66664 m
.47354 .64039 L
s
P
p
.004 w
.68786 .53063 m
.72799 .55202 L
s
P
p
.004 w
.72799 .55202 m
.74598 .5616 L
s
P
p
.002 w
.32025 .50292 m .3361 .5405 L .3271 .52222 L p
1 g
F P
s
P
p
.002 w
.3271 .52222 m .30978 .48123 L .32025 .50292 L p
1 g
F P
s
P
p
.002 w
.61555 .27074 m .56951 .24591 L .56314 .24514 L p
1 g
F P
s
P
p
.002 w
.5169 .23498 m .56314 .24514 L .56951 .24591 L p
1 g
F P
s
P
p
.002 w
.55235 .62013 m .59225 .60492 L .60687 .59503 L p
1 g
F P
s
P
p
.002 w
.60687 .59503 m .64108 .5681 L .65517 .55177 L p
1 g
F P
s
P
p
.002 w
.64108 .5681 m .60687 .59503 L .59225 .60492 L p
1 g
F P
s
P
p
.002 w
.39182 .59349 m .42391 .61238 L .41532 .60753 L p
1 g
F P
s
P
p
.002 w
.41532 .60753 m .37749 .58527 L .39182 .59349 L p
1 g
F P
s
P
p
.002 w
.68955 .37974 m .6711 .33383 L .66167 .3176 L p
1 g
F P
s
P
p
.002 w
.6711 .33383 m .68955 .37974 L .69512 .40085 L p
1 g
F P
s
P
p
.002 w
.56951 .24591 m .51575 .2341 L .5169 .23498 L p
1 g
F P
s
P
p
.002 w
.38884 .27281 m .34665 .30638 L .36054 .29224 L p
1 g
F P
s
P
p
.002 w
.36054 .29224 m .39995 .26081 L .38884 .27281 L p
1 g
F P
s
P
p
.002 w
.69245 .47034 m .69536 .42349 L .69512 .40085 L p
1 g
F P
s
P
p
.002 w
.69536 .42349 m .69245 .47034 L .68729 .49265 L p
1 g
F P
s
P
p
.002 w
.45331 .24197 m .39995 .26081 L .41338 .25393 L p
1 g
F P
s
P
p
.002 w
.41338 .25393 m .46133 .23697 L .45331 .24197 L p
1 g
F P
s
P
p
.002 w
.50192 .62786 m .54069 .62313 L .55235 .62013 L p
1 g
F P
s
P
p
.002 w
.59225 .60492 m .55235 .62013 L .54069 .62313 L p
1 g
F P
s
P
p
.002 w
.65517 .55177 m .67666 .5139 L .68729 .49265 L p
1 g
F P
s
P
p
.002 w
.67666 .5139 m .65517 .55177 L .64108 .5681 L p
1 g
F P
s
P
p
.002 w
.33095 .34638 m .30726 .38982 L .31314 .36792 L p
1 g
F P
s
P
p
.002 w
.31314 .36792 m .33662 .32454 L .33095 .34638 L p
1 g
F P
s
P
p
.002 w
.31165 .43852 m .30978 .48123 L .30487 .4588 L p
1 g
F P
s
P
p
.002 w
.30487 .4588 m .30668 .41357 L .31165 .43852 L p
1 g
F P
s
P
p
.002 w
.66167 .3176 m .6255 .27961 L .61555 .27074 L p
1 g
F P
s
P
p
.002 w
.56951 .24591 m .61555 .27074 L .6255 .27961 L p
1 g
F P
s
P
p
.002 w
.6255 .27961 m .66167 .3176 L .6711 .33383 L p
1 g
F P
s
P
p
.002 w
.36875 .56905 m .39182 .59349 L .37749 .58527 L p
1 g
F P
s
P
p
.002 w
.37749 .58527 m .35004 .55632 L .36875 .56905 L p
1 g
F P
s
P
p
.002 w
.33622 .52316 m .35004 .55632 L .3361 .5405 L p
1 g
F P
s
P
p
.002 w
.3361 .5405 m .32025 .50292 L .33622 .52316 L p
1 g
F P
s
P
p
.002 w
.43503 .61224 m .46498 .62157 L .46178 .62415 L p
1 g
F P
s
P
p
.002 w
.46178 .62415 m .42391 .61238 L .43503 .61224 L p
1 g
F P
s
P
p
.002 w
.50192 .62786 m .46178 .62415 L .46498 .62157 L p
1 g
F P
s
P
p
.002 w
.67597 .35341 m .69512 .40085 L .69536 .42349 L p
1 g
F P
s
P
p
.002 w
.69512 .40085 m .67597 .35341 L .6711 .33383 L p
1 g
F P
s
P
p
.002 w
.5141 .23879 m .45331 .24197 L .46133 .23697 L p
1 g
F P
s
P
p
.002 w
.46133 .23697 m .51575 .2341 L .5141 .23879 L p
1 g
F P
s
P
p
.002 w
.46498 .62157 m .49676 .6245 L .50192 .62786 L p
1 g
F P
s
P
p
.002 w
.54069 .62313 m .50192 .62786 L .49676 .6245 L p
1 g
F P
s
P
p
.002 w
.69 .44706 m .68729 .49265 L .67666 .5139 L p
1 g
F P
s
P
p
.002 w
.68729 .49265 m .69 .44706 L .69536 .42349 L p
1 g
F P
s
P
p
.002 w
.54069 .62313 m .57447 .61023 L .59225 .60492 L p
1 g
F P
s
P
p
.002 w
.62251 .58107 m .59225 .60492 L .57447 .61023 L p
1 g
F P
s
P
p
.002 w
.59225 .60492 m .62251 .58107 L .64108 .5681 L p
1 g
F P
s
P
p
.002 w
.38054 .28984 m .33662 .32454 L .34665 .30638 L p
1 g
F P
s
P
p
.002 w
.34665 .30638 m .38884 .27281 L .38054 .28984 L p
1 g
F P
s
P
p
.002 w
.6255 .27961 m .57418 .25198 L .56951 .24591 L p
1 g
F P
s
P
p
.002 w
.51575 .2341 m .56951 .24591 L .57418 .25198 L p
1 g
F P
s
P
p
.002 w
.4098 .59733 m .43503 .61224 L .42391 .61238 L p
1 g
F P
s
P
p
.002 w
.42391 .61238 m .39182 .59349 L .4098 .59733 L p
1 g
F P
s
P
p
.002 w
.66064 .53341 m .64108 .5681 L .62251 .58107 L p
1 g
F P
s
P
p
.002 w
.64108 .5681 m .66064 .53341 L .67666 .5139 L p
1 g
F P
s
P
p
.002 w
.57418 .25198 m .5141 .23879 L .51575 .2341 L p
1 g
F P
s
P
p
.002 w
.44631 .25265 m .38884 .27281 L .39995 .26081 L p
1 g
F P
s
P
p
.002 w
.39995 .26081 m .45331 .24197 L .44631 .25265 L p
1 g
F P
s
P
p
.002 w
.33005 .37137 m .30668 .41357 L .30726 .38982 L p
1 g
F P
s
P
p
.002 w
.30726 .38982 m .33095 .34638 L .33005 .37137 L p
1 g
F P
s
P
p
.002 w
.49676 .6245 m .52738 .62074 L .54069 .62313 L p
1 g
F P
s
P
p
.002 w
.57447 .61023 m .54069 .62313 L .52738 .62074 L p
1 g
F P
s
P
p
.002 w
.32226 .46395 m .32025 .50292 L .30978 .48123 L p
1 g
F P
s
P
p
.002 w
.30978 .48123 m .31165 .43852 L .32226 .46395 L p
1 g
F P
s
P
p
.002 w
.63225 .29317 m .6711 .33383 L .67597 .35341 L p
1 g
F P
s
P
p
.002 w
.6711 .33383 m .63225 .29317 L .6255 .27961 L p
1 g
F P
s
P
p
.002 w
.57418 .25198 m .6255 .27961 L .63225 .29317 L p
1 g
F P
s
P
p
.002 w
.35741 .54126 m .36875 .56905 L .35004 .55632 L p
1 g
F P
s
P
p
.002 w
.35004 .55632 m .33622 .52316 L .35741 .54126 L p
1 g
F P
s
P
p
.002 w
.39187 .57816 m .4098 .59733 L .39182 .59349 L p
1 g
F P
s
P
p
.002 w
.39182 .59349 m .36875 .56905 L .39187 .57816 L p
1 g
F P
s
P
p
.002 w
.6759 .37591 m .69536 .42349 L .69 .44706 L p
1 g
F P
s
P
p
.002 w
.69536 .42349 m .6759 .37591 L .67597 .35341 L p
1 g
F P
s
P
p
.002 w
.67895 .47084 m .67666 .5139 L .66064 .53341 L p
1 g
F P
s
P
p
.002 w
.67666 .5139 m .67895 .47084 L .69 .44706 L p
1 g
F P
s
P
p
.002 w
.37548 .31163 m .33095 .34638 L .33662 .32454 L p
1 g
F P
s
P
p
.002 w
.33662 .32454 m .38054 .28984 L .37548 .31163 L p
1 g
F P
s
P
p
.002 w
.52738 .62074 m .55388 .61055 L .57447 .61023 L p
1 g
F P
s
P
p
.002 w
.59981 .59011 m .57447 .61023 L .55388 .61055 L p
1 g
F P
s
P
p
.002 w
.57447 .61023 m .59981 .59011 L .62251 .58107 L p
1 g
F P
s
P
p
.002 w
.44851 .60681 m .46933 .61333 L .46498 .62157 L p
1 g
F P
s
P
p
.002 w
.46498 .62157 m .43503 .61224 L .44851 .60681 L p
1 g
F P
s
P
p
.002 w
.49676 .6245 m .46498 .62157 L .46933 .61333 L p
1 g
F P
s
P
p
.002 w
.51196 .24928 m .44631 .25265 L .45331 .24197 L p
1 g
F P
s
P
p
.002 w
.45331 .24197 m .5141 .23879 L .51196 .24928 L p
1 g
F P
s
P
p
.002 w
.6395 .55048 m .62251 .58107 L .59981 .59011 L p
1 g
F P
s
P
p
.002 w
.62251 .58107 m .6395 .55048 L .66064 .53341 L p
1 g
F P
s
P
p
.002 w
.33417 .39883 m .31165 .43852 L .30668 .41357 L p
1 g
F P
s
P
p
.002 w
.30668 .41357 m .33005 .37137 L .33417 .39883 L p
1 g
F P
s
P
p
.002 w
.46933 .61333 m .49148 .61537 L .49676 .6245 L p
1 g
F P
s
P
p
.002 w
.52738 .62074 m .49676 .6245 L .49148 .61537 L p
1 g
F P
s
P
p
.002 w
.33839 .48901 m .33622 .52316 L .32025 .50292 L p
1 g
F P
s
P
p
.002 w
.32025 .50292 m .32226 .46395 L .33839 .48901 L p
1 g
F P
s
P
p
.002 w
.63225 .29317 m .57689 .26349 L .57418 .25198 L p
1 g
F P
s
P
p
.002 w
.5141 .23879 m .57418 .25198 L .57689 .26349 L p
1 g
F P
s
P
p
.002 w
.43108 .59643 m .44851 .60681 L .43503 .61224 L p
1 g
F P
s
P
p
.002 w
.43503 .61224 m .4098 .59733 L .43108 .59643 L p
1 g
F P
s
P
p
.002 w
.44062 .26901 m .38054 .28984 L .38884 .27281 L p
1 g
F P
s
P
p
.002 w
.38884 .27281 m .44631 .25265 L .44062 .26901 L p
1 g
F P
s
P
p
.002 w
.57689 .26349 m .51196 .24928 L .5141 .23879 L p
1 g
F P
s
P
p
.002 w
.49148 .61537 m .51275 .61272 L .52738 .62074 L p
1 g
F P
s
P
p
.002 w
.55388 .61055 m .52738 .62074 L .51275 .61272 L p
1 g
F P
s
P
p
.002 w
.6354 .31127 m .67597 .35341 L .6759 .37591 L p
1 g
F P
s
P
p
.002 w
.67597 .35341 m .6354 .31127 L .63225 .29317 L p
1 g
F P
s
P
p
.002 w
.38334 .55652 m .39187 .57816 L .36875 .56905 L p
1 g
F P
s
P
p
.002 w
.36875 .56905 m .35741 .54126 L .38334 .55652 L p
1 g
F P
s
P
p
.002 w
.66233 .49408 m .66064 .53341 L .6395 .55048 L p
1 g
F P
s
P
p
.002 w
.66064 .53341 m .66233 .49408 L .67895 .47084 L p
1 g
F P
s
P
p
.004 w
.66622 .51909 m
.67377 .52312 L
s
P
p
.004 w
.67377 .52312 m
.68786 .53063 L
s
P
p
.002 w
.67063 .40075 m .69 .44706 L .67895 .47084 L p
1 g
F P
s
P
p
.002 w
.69 .44706 m .67063 .40075 L .6759 .37591 L p
1 g
F P
s
P
p
.002 w
.57689 .26349 m .63225 .29317 L .6354 .31127 L p
1 g
F P
s
P
p
.002 w
.41886 .58317 m .43108 .59643 L .4098 .59733 L p
1 g
F P
s
P
p
.002 w
.4098 .59733 m .39187 .57816 L .41886 .58317 L p
1 g
F P
s
P
p
.002 w
.37399 .33769 m .33005 .37137 L .33095 .34638 L p
1 g
F P
s
P
p
.002 w
.33095 .34638 m .37548 .31163 L .37399 .33769 L p
1 g
F P
s
P
p
.002 w
.34335 .42792 m .32226 .46395 L .31165 .43852 L p
1 g
F P
s
P
p
.002 w
.31165 .43852 m .33417 .39883 L .34335 .42792 L p
1 g
F P
s
P
p
.002 w
.55388 .61055 m .57352 .59474 L .59981 .59011 L p
1 g
F P
s
P
p
.002 w
.61372 .56444 m .59981 .59011 L .57352 .59474 L p
1 g
F P
s
P
p
.002 w
.59981 .59011 m .61372 .56444 L .6395 .55048 L p
1 g
F P
s
P
p
.002 w
.35968 .51285 m .35741 .54126 L .33622 .52316 L p
1 g
F P
s
P
p
.002 w
.33622 .52316 m .33839 .48901 L .35968 .51285 L p
1 g
F P
s
P
p
.002 w
.51275 .61272 m .53102 .6056 L .55388 .61055 L p
1 g
F P
s
P
p
.002 w
.57352 .59474 m .55388 .61055 L .53102 .6056 L p
1 g
F P
s
P
p
.002 w
.50938 .26559 m .44062 .26901 L .44631 .25265 L p
1 g
F P
s
P
p
.002 w
.44631 .25265 m .51196 .24928 L .50938 .26559 L p
1 g
F P
s
P
p
.002 w
.46403 .59595 m .47478 .59934 L .46933 .61333 L p
1 g
F P
s
P
p
.002 w
.46933 .61333 m .44851 .60681 L .46403 .59595 L p
1 g
F P
s
P
p
.002 w
.49148 .61537 m .46933 .61333 L .47478 .59934 L p
1 g
F P
s
P
p
.002 w
.47478 .59934 m .48622 .60038 L .49148 .61537 L p
1 g
F P
s
P
p
.002 w
.51275 .61272 m .49148 .61537 L .48622 .60038 L p
1 g
F P
s
P
p
.002 w
.43649 .29082 m .37548 .31163 L .38054 .28984 L p
1 g
F P
s
P
p
.002 w
.38054 .28984 m .44062 .26901 L .43649 .29082 L p
1 g
F P
s
P
p
.002 w
.63464 .33357 m .6759 .37591 L .67063 .40075 L p
1 g
F P
s
P
p
.002 w
.6759 .37591 m .63464 .33357 L .6354 .31127 L p
1 g
F P
s
P
p
.002 w
.64049 .51596 m .6395 .55048 L .61372 .56444 L p
1 g
F P
s
P
p
.002 w
.6395 .55048 m .64049 .51596 L .66233 .49408 L p
1 g
F P
s
P
p
.004 w
.65728 .51433 m
.66622 .51909 L
s
P
p
.004 w
.5 .43051 m
.64738 .50906 L
s
P
p
.004 w
.65606 .51368 m
.65728 .51433 L
s
P
p
.002 w
.6354 .31127 m .57743 .28042 L .57689 .26349 L p
1 g
F P
s
P
p
.002 w
.51196 .24928 m .57689 .26349 L .57743 .28042 L p
1 g
F P
s
P
p
.002 w
.45511 .59057 m .46403 .59595 L .44851 .60681 L p
1 g
F P
s
P
p
.002 w
.44851 .60681 m .43108 .59643 L .45511 .59057 L p
1 g
F P
s
P
p
.002 w
.66012 .42717 m .67895 .47084 L .66233 .49408 L p
1 g
F P
s
P
p
.002 w
.67895 .47084 m .66012 .42717 L .67063 .40075 L p
1 g
F P
s
P
p
.002 w
.41326 .56832 m .41886 .58317 L .39187 .57816 L p
1 g
F P
s
P
p
.002 w
.39187 .57816 m .38334 .55652 L .41326 .56832 L p
1 g
F P
s
P
p
.002 w
.48622 .60038 m .49719 .59899 L .51275 .61272 L p
1 g
F P
s
P
p
.002 w
.53102 .6056 m .51275 .61272 L .49719 .59899 L p
1 g
F P
s
P
p
.002 w
.57743 .28042 m .50938 .26559 L .51196 .24928 L p
1 g
F P
s
P
p
.002 w
.35745 .45765 m .33839 .48901 L .32226 .46395 L p
1 g
F P
s
P
p
.002 w
.32226 .46395 m .34335 .42792 L .35745 .45765 L p
1 g
F P
s
P
p
.002 w
.38551 .5346 m .38334 .55652 L .35741 .54126 L p
1 g
F P
s
P
p
.002 w
.35741 .54126 m .35968 .51285 L .38551 .5346 L p
1 g
F P
s
P
p
.002 w
.57743 .28042 m .6354 .31127 L .63464 .33357 L p
1 g
F P
s
P
p
.002 w
.37628 .36727 m .33417 .39883 L .33005 .37137 L p
1 g
F P
s
P
p
.002 w
.33005 .37137 m .37399 .33769 L .37628 .36727 L p
1 g
F P
s
P
p
.002 w
.53102 .6056 m .54437 .59464 L .57352 .59474 L p
1 g
F P
s
P
p
.002 w
.584 .57473 m .57352 .59474 L .54437 .59464 L p
1 g
F P
s
P
p
.002 w
.57352 .59474 m .584 .57473 L .61372 .56444 L p
1 g
F P
s
P
p
.002 w
.44895 .58375 m .45511 .59057 L .43108 .59643 L p
1 g
F P
s
P
p
.002 w
.43108 .59643 m .41886 .58317 L .44895 .58375 L p
1 g
F P
s
P
p
.002 w
.49719 .59899 m .50653 .59528 L .53102 .6056 L p
1 g
F P
s
P
p
.002 w
.54437 .59464 m .53102 .6056 L .50653 .59528 L p
1 g
F P
s
P
p
.002 w
.61403 .53568 m .61372 .56444 L .584 .57473 L p
1 g
F P
s
P
p
.002 w
.61372 .56444 m .61403 .53568 L .64049 .51596 L p
1 g
F P
s
P
p
.002 w
.64452 .45431 m .66233 .49408 L .64049 .51596 L p
1 g
F P
s
P
p
.002 w
.66233 .49408 m .64452 .45431 L .66012 .42717 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.48533 .54686 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.62979 .35951 m .67063 .40075 L .66012 .42717 L p
1 g
F P
s
P
p
.002 w
.67063 .40075 m .62979 .35951 L .63464 .33357 L p
1 g
F P
s
P
p
.002 w
.44625 .57618 m .44895 .58375 L .41886 .58317 L p
1 g
F P
s
P
p
.002 w
.41886 .58317 m .41326 .56832 L .44625 .57618 L p
1 g
F P
s
P
p
.002 w
.43418 .31759 m .37399 .33769 L .37548 .31163 L p
1 g
F P
s
P
p
.002 w
.37548 .31163 m .43649 .29082 L .43418 .31759 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.50642 .2875 m .43649 .29082 L .44062 .26901 L p
1 g
F P
s
P
p
.002 w
.44062 .26901 m .50938 .26559 L .50642 .2875 L p
1 g
F P
s
P
p
.002 w
.37609 .48699 m .35968 .51285 L .33839 .48901 L p
1 g
F P
s
P
p
.002 w
.33839 .48901 m .35745 .45765 L .37609 .48699 L p
1 g
F P
s
P
p
.002 w
.41508 .55344 m .41326 .56832 L .38334 .55652 L p
1 g
F P
s
P
p
.002 w
.38334 .55652 m .38551 .5346 L .41508 .55344 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.47478 .59934 m .46403 .59595 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.48622 .60038 m .47478 .59934 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.49719 .59899 m .48622 .60038 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.50653 .59528 m .51325 .58962 L .54437 .59464 L p
1 g
F P
s
P
p
.002 w
.55127 .58088 m .54437 .59464 L .51325 .58962 L p
1 g
F P
s
P
p
.002 w
.54437 .59464 m .55127 .58088 L .584 .57473 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.46403 .59595 m .45511 .59057 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63464 .33357 m .57566 .30251 L .57743 .28042 L p
1 g
F P
s
P
p
.002 w
.50938 .26559 m .57743 .28042 L .57566 .30251 L p
1 g
F P
s
P
p
.002 w
.38241 .39943 m .34335 .42792 L .33417 .39883 L p
1 g
F P
s
P
p
.002 w
.33417 .39883 m .37628 .36727 L .38241 .39943 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50653 .59528 m .49719 .59899 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.58378 .55249 m .584 .57473 L .55127 .58088 L p
1 g
F P
s
P
p
.002 w
.584 .57473 m .58378 .55249 L .61403 .53568 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.45511 .59057 m .44895 .58375 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.57566 .30251 m .63464 .33357 L .62979 .35951 L p
1 g
F P
s
P
p
.002 w
.57566 .30251 m .50642 .2875 L .50938 .26559 L p
1 g
F P
s
P
p
.002 w
.51325 .58962 m .50653 .59528 L .48294 .58079 L p
1 g
F P
s
P
p
.002 w
.48475 .58082 m .51325 .58962 L p
.48294 .58079 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58084 L p
1 g
F P
s
P
p
.002 w
.51325 .58962 m .48475 .58082 L p
.48758 .58083 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58084 L .49544 .58088 L 1 g
F
P
p
.002 w
.5165 .58093 m .51659 .58259 L .50678 .58179 L p
1 g
F P
s
P
p
.002 w
.50678 .58179 m .49544 .58088 L p
.51096 .58092 L 1 g
F P
s
P
p
.5165 .58093 m .50678 .58179 L .51096 .58092 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58092 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58092 L .51643 .57977 L 1 g
F
P
p
.002 w
.51659 .58259 m .51643 .57977 L p
.53169 .57453 L 1 g
F P
s
P
p
.53581 .57311 m .52642 .57774 L .53169 .57453 L 1 g
F
P
p
.52642 .57774 m .51659 .58259 L .53169 .57453 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57453 L p
1 g
F P
s
P
p
.54854 .56129 m .53169 .57453 L .53992 .5695 L 1 g
F
P
p
.53128 .57265 m .51643 .57977 L .51937 .57876 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.51079 .57862 m .49544 .58088 L .49946 .58089 L 1 g
F
P
p
.002 w
.48119 .57972 m .48275 .57951 L p
.48377 .57972 L 1 g
F P
s
P
p
.002 w
.44625 .57618 m .44735 .56867 L .47118 .57645 L p
1 g
F P
s
P
p
.002 w
.47118 .57645 m .48119 .57972 L .47557 .57915 L p
1 g
F P
s
P
p
.002 w
.47557 .57915 m .44625 .57618 L p
.47118 .57645 L 1 g
F P
s
P
p
.002 w
.46829 .57464 m .46872 .57265 L p
.45866 .56863 L 1 g
F P
s
P
p
.002 w
.48904 .58084 m .48921 .57862 L p
.47674 .5776 L 1 g
F P
s
P
p
.002 w
.48119 .57972 m .47118 .57645 L p
.46923 .57497 L 1 g
F P
s
P
p
.002 w
.479 .57838 m .48119 .57972 L p
.46923 .57497 L 1 g
F P
s
P
p
.47674 .5776 m .479 .57838 L .48904 .58084 L 1 g
F
P
p
.479 .57838 m .47999 .57872 L .48904 .58084 L 1 g
F
P
p
.47993 .57871 m .4805 .57889 L .48904 .58084 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46829 .57464 L p
1 g
F P
s
P
p
.002 w
.47118 .57645 m .44735 .56867 L .44813 .56761 L p
1 g
F P
s
P
p
.44813 .56761 m .46829 .57464 L .47118 .57645 L 1 g
F
P
p
.48921 .57862 m .46829 .57464 L .47674 .5776 L 1 g
F
P
p
.45744 .57086 m .45091 .56379 L .46829 .57464 L 1 g
F
P
p
.002 w
.44813 .56761 m .45086 .56387 L p
.45744 .57086 L 1 g
F P
s
P
p
.002 w
.45086 .56387 m .45091 .56379 L p
.45744 .57086 L 1 g
F P
s
P
p
.45146 .56129 m .44402 .55483 L .44513 .55633 L 1 g
F
P
p
.42433 .54016 m .43795 .54655 L .43843 .54721 L 1 g
F
P
p
.002 w
.4454 .5567 m .44034 .55273 L p
.43843 .54721 L 1 g
F P
s
P
p
.002 w
.44034 .55273 m .42433 .54016 L p
.43843 .54721 L 1 g
F P
s
P
p
.002 w
.43843 .54721 m .43925 .54566 L p
.43494 .53714 L 1 g
F P
s
P
p
.002 w
.44735 .56867 m .41508 .55344 L p
.44888 .56127 L 1 g
F P
s
P
p
.002 w
.45062 .56356 m .45146 .56129 L p
.44608 .5576 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45062 .56356 L p
1 g
F P
s
P
p
.002 w
.45091 .56379 m .45086 .56387 L p
.45062 .56356 L 1 g
F P
s
P
p
.002 w
.45086 .56387 m .44735 .56867 L p
.44888 .56127 L 1 g
F P
s
P
p
.002 w
.45062 .56356 m .45002 .56518 L p
.45521 .56725 L 1 g
F P
s
P
p
.46872 .57265 m .45062 .56356 L .45521 .56725 L 1 g
F
P
p
.002 w
.45219 .56204 m .45091 .56379 L p
.44888 .56127 L 1 g
F P
s
P
p
.44888 .56127 m .45091 .56379 L .45062 .56356 L 1 g
F
P
p
.45146 .56129 m .44513 .55633 L .44608 .5576 L 1 g
F
P
p
.002 w
.41508 .55344 m .42433 .54016 L .4454 .5567 L p
1 g
F P
s
P
p
.41508 .55344 m .4454 .5567 L .44888 .56127 L 1 g
F
P
p
.44513 .55633 m .44996 .56292 L .4506 .5636 L 1 g
F
P
p
.002 w
.4454 .5567 m .45219 .56204 L p
.44888 .56127 L 1 g
F P
s
P
p
.4454 .5567 m .43986 .55221 L .44996 .56292 L 1 g
F
P
p
.44513 .55633 m .4451 .55631 L .4454 .5567 L 1 g
F
P
p
.4451 .55631 m .43986 .55221 L .4454 .5567 L 1 g
F
P
p
.002 w
.4506 .5636 m .45062 .56356 L p
.44608 .5576 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43843 .54721 L p
1 g
F P
s
P
p
.002 w
.43843 .54721 m .43743 .5491 L p
.44402 .55483 L 1 g
F P
s
P
p
.45146 .56129 m .43843 .54721 L .44402 .55483 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.42433 .54016 m .39865 .51483 L p
.43206 .52706 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4325 .52874 L p
1 g
F P
s
P
p
.43925 .54566 m .4325 .52874 L .43326 .5317 L 1 g
F
P
p
.43206 .52706 m .4325 .52874 L .42433 .54016 L 1 g
F
P
p
.002 w
.43388 .53407 m .43208 .53522 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.43208 .53522 m .42433 .54016 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.4325 .52874 m .43346 .52734 L p
.43316 .51859 L 1 g
F P
s
P
p
.43925 .54566 m .43326 .5317 L .43494 .53714 L 1 g
F
P
p
.43326 .5317 m .43219 .52919 L .43388 .53407 L 1 g
F
P
p
.43326 .5317 m .43388 .53407 L .43494 .53714 L 1 g
F
P
p
.002 w
.44021 .53004 m .43388 .53407 L p
.43206 .52706 L 1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.39865 .51483 m .42171 .49961 L .43316 .51845 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43402 .50925 L p
1 g
F P
s
P
p
.42171 .49961 m .43419 .50746 L .43402 .50925 L 1 g
F
P
p
.002 w
.43316 .51845 m .43119 .5152 L p
.43402 .50925 L 1 g
F P
s
P
p
.002 w
.43119 .5152 m .42171 .49961 L p
.43402 .50925 L 1 g
F P
s
P
p
.002 w
.43402 .50925 m .43485 .50826 L p
.43806 .50074 L 1 g
F P
s
P
p
.43346 .52734 m .43402 .50925 L .43369 .51282 L 1 g
F
P
p
.43346 .52734 m .43374 .50958 L .43316 .51859 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.43402 .50925 m .46101 .52433 L .43316 .51845 L 1 g
F
P
p
.43419 .50746 m .43471 .50779 L .43402 .50925 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.44472 .48704 m .44258 .49136 L .42171 .49961 L 1 g
F
P
p
.002 w
.44124 .49406 m .43919 .49464 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.43919 .49464 m .42171 .49961 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44247 .49148 L p
.4419 .49273 L 1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .4419 .49273 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45094 .48327 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45778 .4766 m .48678 .49 L .45074 .48346 L 1 g
F
P
p
.002 w
.45778 .4766 m .45826 .47608 L p
.46518 .47305 L 1 g
F P
s
P
p
.46593 .47269 m .48678 .49 L .45778 .4766 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47763 .46706 L p
1 g
F P
s
P
p
.45826 .47608 m .47763 .46706 L .46518 .47305 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47763 .46706 m .47786 .46667 L p
.48946 .46549 L 1 g
F P
s
P
p
.49716 .46424 m .521 .49704 L .48871 .46561 L 1 g
F
P
p
.48946 .46549 m .49026 .46541 L .48871 .46561 L 1 g
F
P
p
.48946 .46549 m .48871 .46561 L .47763 .46706 L 1 g
F
P
p
.002 w
.521 .49704 m .48678 .49 L .48871 .46561 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46379 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.50206 .46409 m .51585 .46614 L .521 .49704 L 1 g
F
P
p
.5 .4634 m .52241 .46712 L .50883 .4651 L 1 g
F
P
p
.002 w
.53084 .47128 m .521 .49704 L p
.51585 .46614 L 1 g
F P
s
P
p
.51544 .46368 m .52241 .46712 L .51585 .46614 L 1 g
F
P
p
.52241 .46712 m .53084 .47128 L .51585 .46614 L 1 g
F
P
p
.49716 .46424 m .50206 .46409 L .521 .49704 L 1 g
F
P
p
.002 w
.5 .46379 m .5 .4634 L p
.50883 .4651 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.52095 .4604 m .53397 .4631 L p
.49716 .46424 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46379 L p
1 g
F P
s
P
p
.50883 .4651 m .52282 .46778 L .5 .46379 L 1 g
F
P
p
.002 w
.52241 .46712 m .52282 .46778 L p
.50883 .4651 L 1 g
F P
s
P
p
.50206 .46409 m .51544 .46368 L .51585 .46614 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54219 .47658 L p
1 g
F P
s
P
p
.53798 .47461 m .5507 .51113 L .53084 .47128 L 1 g
F
P
p
.52214 .46667 m .54219 .47658 L .53505 .47325 L 1 g
F
P
p
.002 w
.53397 .4631 m .57227 .48162 L .56737 .48832 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56586 .5091 L p
1 g
F P
s
P
p
.55661 .4905 m .56586 .5091 L .56257 .5021 L 1 g
F
P
p
.57227 .48162 m .57237 .52298 L .56586 .5091 L 1 g
F
P
p
.002 w
.56051 .49771 m .56433 .49248 L p
.56586 .5091 L 1 g
F P
s
P
p
.002 w
.56433 .49248 m .57227 .48162 L p
.56586 .5091 L 1 g
F P
s
P
p
.002 w
.56586 .5091 m .56515 .50826 L p
.56671 .51839 L 1 g
F P
s
P
p
.56168 .5002 m .56667 .51007 L .56321 .50312 L 1 g
F
P
p
.55661 .4905 m .56257 .5021 L .56168 .5002 L 1 g
F
P
p
.56257 .5021 m .56667 .51007 L .56168 .5002 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56757 .52884 L p
1 g
F P
s
P
p
.56515 .50826 m .56757 .52884 L .56749 .52737 L 1 g
F
P
p
.002 w
.57239 .53042 m .56783 .53356 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.56741 .52599 m .56821 .5267 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.56821 .5267 m .57239 .53042 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.56757 .52884 m .56654 .52734 L p
.56452 .53841 L 1 g
F P
s
P
p
.002 w
.56573 .535 m .57239 .53042 L p
.56614 .54064 L 1 g
F P
s
P
p
.56614 .54064 m .56041 .54999 L .56147 .54701 L 1 g
F
P
p
.56614 .54064 m .56147 .54701 L .56573 .535 L 1 g
F
P
p
.002 w
.56147 .54701 m .56075 .54566 L p
.55556 .55507 L 1 g
F P
s
P
p
.56452 .53841 m .56573 .535 L .56757 .52884 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54936 .5635 L p
1 g
F P
s
P
p
.56075 .54566 m .54936 .5635 L .54943 .56343 L 1 g
F
P
p
.002 w
.55076 .56574 m .54631 .56692 L p
.54936 .5635 L 1 g
F P
s
P
p
.002 w
.54948 .56337 m .5495 .56341 L p
.54936 .5635 L 1 g
F P
s
P
p
.002 w
.5495 .56341 m .55076 .56574 L p
.54936 .5635 L 1 g
F P
s
P
p
.55076 .56574 m .53581 .57311 L .53369 .57331 L 1 g
F
P
p
.002 w
.54936 .5635 m .54854 .56129 L p
.54223 .56809 L 1 g
F P
s
P
p
.54223 .56809 m .5425 .56793 L .54936 .5635 L 1 g
F
P
p
.002 w
.5425 .56793 m .55076 .56574 L p
.53369 .57331 L 1 g
F P
s
P
p
.54854 .56129 m .53963 .56979 L .54221 .56812 L 1 g
F
P
p
.56075 .54566 m .54943 .56343 L .55556 .55507 L 1 g
F
P
p
.54943 .56343 m .54937 .56352 L .54948 .56337 L 1 g
F
P
p
.54943 .56343 m .54948 .56337 L .55556 .55507 L 1 g
F
P
p
.54948 .56337 m .54936 .5635 L .51615 .57492 L 1 g
F
P
p
.002 w
.54631 .56692 m .5425 .56793 L p
.54936 .5635 L 1 g
F P
s
P
p
.002 w
.5425 .56793 m .51615 .57492 L p
.54936 .5635 L 1 g
F P
s
P
p
.002 w
.55127 .58088 m .51864 .58249 L p
.5382 .57229 L 1 g
F P
s
P
p
.55076 .56574 m .51864 .58249 L .52642 .57774 L 1 g
F
P
p
.002 w
.53212 .57648 m .53169 .57453 L p
.51807 .57943 L 1 g
F P
s
P
p
.002 w
.53169 .57453 m .53128 .57265 L p
.51937 .57876 L 1 g
F P
s
P
p
.51937 .57876 m .51807 .57943 L .53169 .57453 L 1 g
F
P
p
.002 w
.55076 .56574 m .55084 .56795 L p
.5382 .57229 L 1 g
F P
s
P
p
.002 w
.55084 .56795 m .55127 .58088 L p
.5382 .57229 L 1 g
F P
s
P
p
.002 w
.51864 .58249 m .51659 .58259 L p
.52642 .57774 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54936 .5635 L p
.54824 .56443 L 1 g
F P
s
P
p
.54824 .56443 m .53707 .57367 L .54835 .56436 L 1 g
F
P
p
.54824 .56443 m .54835 .56436 L .54937 .56352 L 1 g
F
P
p
.002 w
.5322 .57686 m .53707 .57367 L p
.54221 .56812 L 1 g
F P
s
P
p
.53963 .56979 m .5322 .57686 L .54221 .56812 L 1 g
F
P
p
.002 w
.51615 .57492 m .5425 .56793 L p
.53369 .57331 L 1 g
F P
s
P
p
.54223 .56809 m .54221 .56812 L .5425 .56793 L 1 g
F
P
p
.54221 .56812 m .53707 .57367 L .54936 .5635 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54269 .55084 m .54948 .56337 L p
.51615 .57492 L 1 g
F P
s
P
p
.002 w
.54936 .5635 m .54937 .56352 L p
.54943 .56343 L 1 g
F P
s
P
p
.55674 .55346 m .5535 .56011 L .5525 .55925 L 1 g
F
P
p
.002 w
.55076 .56574 m .5495 .56341 L p
.5535 .56011 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5495 .56341 m .54269 .55084 L p
.5535 .56011 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54998 .56518 L p
.55556 .55507 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56147 .54701 L p
1 g
F P
s
P
p
.57239 .53042 m .55549 .56384 L .56041 .54999 L 1 g
F
P
p
.002 w
.56147 .54701 m .5619 .54783 L p
.56317 .5422 L 1 g
F P
s
P
p
.56654 .52734 m .56147 .54701 L .56317 .5422 L 1 g
F
P
p
.002 w
.57239 .53042 m .58378 .55249 L .55549 .56384 L p
1 g
F P
s
P
p
.002 w
.55549 .56384 m .55076 .56574 L p
.56041 .54999 L 1 g
F P
s
P
p
.56654 .52734 m .5619 .54783 L .56422 .54006 L 1 g
F
P
p
.56515 .50826 m .56749 .52737 L .56671 .51839 L 1 g
F
P
p
.56749 .52737 m .56769 .52901 L .56741 .52599 L 1 g
F
P
p
.56749 .52737 m .56741 .52599 L .56671 .51839 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56741 .52599 m .56757 .52884 L .54269 .55084 L 1 g
F
P
p
.002 w
.56783 .53356 m .56573 .535 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.56573 .535 m .54269 .55084 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.5619 .54783 m .56257 .5491 L p
.56422 .54006 L 1 g
F P
s
P
p
.002 w
.54269 .55084 m .56573 .535 L p
.55674 .55346 L 1 g
F P
s
P
p
.55674 .55346 m .5525 .55925 L .54269 .55084 L 1 g
F
P
p
.002 w
.53707 .57367 m .54998 .56518 L .54937 .56352 L p
1 g
F P
s
P
p
.56041 .54999 m .55076 .56574 L .56573 .535 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56147 .54701 L p
1 g
F P
s
P
p
.55556 .55507 m .54998 .56518 L .56147 .54701 L 1 g
F
P
p
.56452 .53841 m .56422 .54006 L .56573 .535 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56757 .52884 L p
1 g
F P
s
P
p
.56422 .54006 m .56257 .5491 L .56757 .52884 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.5507 .51113 m .56741 .52599 L p
.54269 .55084 L 1 g
F P
s
P
p
.002 w
.56757 .52884 m .56769 .52901 L p
.56749 .52737 L 1 g
F P
s
P
p
.002 w
.57239 .53042 m .56741 .52599 L p
.56627 .51357 L 1 g
F P
s
P
p
.002 w
.56769 .52901 m .56854 .53025 L p
.56671 .51839 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56737 .48832 m .56195 .49574 L p
.55234 .48131 L 1 g
F P
s
P
p
.002 w
.56195 .49574 m .56051 .49771 L p
.55727 .4912 L 1 g
F P
s
P
p
.55234 .48131 m .56195 .49574 L .55727 .4912 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55727 .4912 L p
1 g
F P
s
P
p
.54174 .47608 m .55727 .4912 L .54782 .48204 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.53798 .47461 m .54219 .47658 L .5507 .51113 L 1 g
F
P
p
.002 w
.54219 .47658 m .54174 .47608 L p
.54782 .48204 L 1 g
F P
s
P
p
.54219 .47658 m .55234 .48131 L .55207 .48616 L 1 g
F
P
p
.54219 .47658 m .55207 .48616 L .5507 .51113 L 1 g
F
P
p
.002 w
.56051 .49771 m .5507 .51113 L p
.55234 .48131 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54219 .47658 L p
1 g
F P
s
P
p
.54782 .48204 m .55834 .49233 L .54219 .47658 L 1 g
F
P
p
.002 w
.55727 .4912 m .55834 .49233 L p
.54782 .48204 L 1 g
F P
s
P
p
.002 w
.5507 .51113 m .56051 .49771 L p
.56627 .51357 L 1 g
F P
s
P
p
.002 w
.56741 .52599 m .5507 .51113 L p
.56627 .51357 L 1 g
F P
s
P
p
.57237 .52298 m .57239 .53042 L .56051 .49771 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56586 .5091 L p
1 g
F P
s
P
p
.56671 .51839 m .56854 .53025 L .56586 .5091 L 1 g
F
P
p
.002 w
.56586 .5091 m .56667 .51007 L p
.56257 .5021 L 1 g
F P
s
P
p
.002 w
.56667 .51007 m .56713 .51061 L p
.56321 .50312 L 1 g
F P
s
P
p
.53397 .4631 m .56737 .48832 L .53798 .47461 L 1 g
F
P
p
.53293 .47226 m .54272 .47715 L .53537 .47352 L 1 g
F
P
p
.52214 .46667 m .53505 .47325 L .53293 .47226 L 1 g
F
P
p
.53505 .47325 m .54272 .47715 L .53293 .47226 L 1 g
F
P
p
.002 w
.54219 .47658 m .54272 .47715 L p
.53505 .47325 L 1 g
F P
s
P
p
.002 w
.5507 .51113 m .521 .49704 L .53084 .47128 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53084 .47128 m .53397 .4631 L p
.53798 .47461 L 1 g
F P
s
P
p
.002 w
.53397 .4631 m .53084 .47128 L p
.51544 .46368 L 1 g
F P
s
P
p
.002 w
.54272 .47715 m .54302 .47747 L p
.53537 .47352 L 1 g
F P
s
P
p
.002 w
.5 .46379 m .5 .46442 L p
.48946 .46549 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46379 L .48946 .46549 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48964 .45389 m .52095 .4604 L p
.49716 .46424 L 1 g
F P
s
P
p
.002 w
.48871 .46561 m .48964 .45389 L p
.49716 .46424 L 1 g
F P
s
P
p
.002 w
.44493 .45525 m .48964 .45389 L .48871 .46561 L p
1 g
F P
s
P
p
.002 w
.48871 .46561 m .48678 .49 L p
.46167 .46915 L 1 g
F P
s
P
p
.44493 .45525 m .48871 .46561 L .46167 .46915 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47763 .46706 L p
1 g
F P
s
P
p
.49026 .46541 m .5 .46442 L .47763 .46706 L 1 g
F
P
p
.002 w
.47763 .46706 m .47718 .46778 L p
.46518 .47305 L 1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43485 .50826 m .44247 .49148 L .43806 .50074 L 1 g
F
P
p
.002 w
.45227 .49092 m .44124 .49406 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45745 .47697 L p
1 g
F P
s
P
p
.44339 .4905 m .45745 .47697 L .45106 .48315 L 1 g
F
P
p
.44472 .48704 m .44624 .48782 L .44258 .49136 L 1 g
F
P
p
.44624 .48782 m .45227 .49092 L .44258 .49136 L 1 g
F
P
p
.002 w
.45745 .47697 m .45698 .47747 L p
.45106 .48315 L 1 g
F P
s
P
p
.44493 .45525 m .4637 .47084 L .45778 .4766 L 1 g
F
P
p
.002 w
.45074 .48346 m .45009 .4803 L p
.45778 .4766 L 1 g
F P
s
P
p
.002 w
.45009 .4803 m .44493 .45525 L p
.45778 .4766 L 1 g
F P
s
P
p
.4637 .47084 m .46593 .47269 L .45778 .4766 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45778 .4766 L p
1 g
F P
s
P
p
.46518 .47305 m .47718 .46778 L .45778 .4766 L 1 g
F
P
p
.45094 .48327 m .45106 .48315 L .45074 .48346 L 1 g
F
P
p
.45094 .48327 m .45074 .48346 L .44258 .49136 L 1 g
F
P
p
.002 w
.48678 .49 m .45227 .49092 L .45074 .48346 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.42171 .49961 m .45227 .49092 L .46101 .52433 L p
1 g
F P
s
P
p
.002 w
.44247 .49148 m .44166 .49233 L p
.43806 .50074 L 1 g
F P
s
P
p
.002 w
.40551 .46687 m .44493 .45525 L .45227 .49092 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44258 .49136 L p
1 g
F P
s
P
p
.45106 .48315 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.002 w
.42171 .49961 m .40551 .46687 L p
.44472 .48704 L 1 g
F P
s
P
p
.43471 .50779 m .46101 .52433 L .43402 .50925 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43402 .50925 L p
1 g
F P
s
P
p
.43806 .50074 m .44166 .49233 L .43402 .50925 L 1 g
F
P
p
.002 w
.43402 .50925 m .43374 .50958 L p
.43369 .51282 L 1 g
F P
s
P
p
.002 w
.46101 .52433 m .44021 .53004 L .43316 .51845 L p
1 g
F P
s
P
p
.002 w
.43316 .51845 m .44021 .53004 L p
.43259 .52725 L 1 g
F P
s
P
p
.39865 .51483 m .43316 .51845 L .43259 .52725 L 1 g
F
P
p
.002 w
.43374 .50958 m .43287 .51061 L p
.43316 .51859 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52874 L p
1 g
F P
s
P
p
.43316 .51859 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.002 w
.4325 .52874 m .43219 .52919 L p
.43326 .5317 L 1 g
F P
s
P
p
.002 w
.43041 .53628 m .44021 .53004 L p
.43795 .54655 L 1 g
F P
s
P
p
.002 w
.43219 .52919 m .43146 .53025 L p
.43494 .53714 L 1 g
F P
s
P
p
.002 w
.44021 .53004 m .46029 .55704 L p
.43825 .54669 L 1 g
F P
s
P
p
.43795 .54655 m .43802 .54603 L .43825 .54669 L 1 g
F
P
p
.43802 .54603 m .44021 .53004 L .43825 .54669 L 1 g
F
P
p
.002 w
.42433 .54016 m .43041 .53628 L p
.43795 .54655 L 1 g
F P
s
P
p
.43795 .54655 m .46029 .55704 L .4454 .5567 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43843 .54721 L p
1 g
F P
s
P
p
.43494 .53714 m .43146 .53025 L .43843 .54721 L 1 g
F
P
p
.002 w
.46029 .55704 m .45219 .56204 L .4454 .5567 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43986 .55221 L p
.44513 .55633 L 1 g
F P
s
P
p
.44402 .55483 m .43743 .5491 L .44513 .55633 L 1 g
F
P
p
.002 w
.43986 .55221 m .45002 .56518 L .4506 .5636 L p
1 g
F P
s
P
p
.002 w
.45091 .56379 m .45219 .56204 L p
.47118 .57645 L 1 g
F P
s
P
p
.002 w
.46829 .57464 m .4678 .57686 L p
.47674 .5776 L 1 g
F P
s
P
p
.002 w
.45219 .56204 m .46029 .55704 L .4804 .57886 L p
1 g
F P
s
P
p
.002 w
.4804 .57886 m .48119 .57972 L .479 .57838 L p
1 g
F P
s
P
p
.002 w
.479 .57838 m .45219 .56204 L p
.4804 .57886 L 1 g
F P
s
P
p
.479 .57838 m .47993 .57871 L .47999 .57872 L 1 g
F
P
p
.47993 .57871 m .4804 .57887 L .4805 .57889 L 1 g
F
P
p
.4804 .57887 m .48113 .5791 L .48904 .58084 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46029 .55704 m .47078 .55426 L .48091 .57903 L p
1 g
F P
s
P
p
.002 w
.48091 .57903 m .48119 .57972 L .4804 .57886 L p
1 g
F P
s
P
p
.002 w
.4804 .57886 m .46029 .55704 L p
.48091 .57903 L 1 g
F P
s
P
p
.48091 .57905 m .48175 .57927 L .48904 .58084 L 1 g
F
P
p
.48175 .57927 m .48202 .57934 L .48904 .58084 L 1 g
F
P
p
.4819 .57931 m .48192 .57932 L .48904 .58084 L 1 g
F
P
p
.002 w
.4821 .57936 m .48119 .57972 L .48175 .57927 L p
1 g
F P
s
P
p
.002 w
.48275 .57951 m .48119 .57972 L .4821 .57936 L p
1 g
F P
s
P
p
.002 w
.48122 .57913 m .48119 .57972 L .48091 .57903 L p
1 g
F P
s
P
p
.002 w
.48175 .57927 m .48119 .57972 L .48148 .5792 L p
1 g
F P
s
P
p
.002 w
.48148 .5792 m .48119 .57972 L .48122 .57913 L p
1 g
F P
s
P
p
.47208 .57721 m .4853 .58005 L .48904 .58084 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50428 .56103 m .51191 .56746 L .4821 .57936 L p
1 g
F P
s
P
p
.002 w
.48175 .57927 m .50428 .56103 L p
.4821 .57936 L 1 g
F P
s
P
p
.48175 .57927 m .4819 .57931 L .48202 .57934 L 1 g
F
P
p
.4819 .57931 m .48191 .57931 L .48192 .57932 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51191 .56746 m .51615 .57492 L .48275 .57951 L p
1 g
F P
s
P
p
.002 w
.4821 .57936 m .51191 .56746 L p
.48275 .57951 L 1 g
F P
s
P
p
.002 w
.47078 .55426 m .48249 .55402 L .48122 .57913 L p
1 g
F P
s
P
p
.002 w
.48091 .57903 m .47078 .55426 L p
.48122 .57913 L 1 g
F P
s
P
p
.4804 .57887 m .48091 .57905 L .48113 .5791 L 1 g
F
P
p
.48091 .57905 m .48128 .57918 L .48191 .57931 L 1 g
F
P
p
.002 w
.4941 .55637 m .50428 .56103 L .48175 .57927 L p
1 g
F P
s
P
p
.002 w
.48148 .5792 m .4941 .55637 L p
.48175 .57927 L 1 g
F P
s
P
p
.002 w
.48249 .55402 m .4941 .55637 L .48148 .5792 L p
1 g
F P
s
P
p
.002 w
.48122 .57913 m .48249 .55402 L p
.48148 .5792 L 1 g
F P
s
P
p
.48069 .57898 m .47208 .57721 L .48128 .57918 L 1 g
F
P
p
.47674 .5776 m .47555 .5775 L .48069 .57898 L 1 g
F
P
p
.47555 .5775 m .47208 .57721 L .48069 .57898 L 1 g
F
P
p
.002 w
.45219 .56204 m .479 .57838 L p
.46923 .57497 L 1 g
F P
s
P
p
.002 w
.46828 .57467 m .46829 .57464 L p
.45809 .5684 L 1 g
F P
s
P
p
.45866 .56863 m .45809 .5684 L .46829 .57464 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46828 .57467 L p
1 g
F P
s
P
p
.45809 .5684 m .45002 .56518 L .46828 .57467 L 1 g
F
P
p
.002 w
.51098 .5812 m .51079 .57862 L p
.49878 .58102 L 1 g
F P
s
P
p
.51643 .57977 m .51168 .58077 L .48424 .57983 L 1 g
F
P
p
.48377 .57972 m .48424 .57983 L .48119 .57972 L 1 g
F
P
p
.51643 .57977 m .48424 .57983 L .48377 .57972 L 1 g
F
P
p
.002 w
.49544 .58088 m .4853 .58005 L p
.5165 .58093 L 1 g
F P
s
P
p
.002 w
.4853 .58005 m .48119 .57972 L p
.48424 .57983 L 1 g
F P
s
P
p
.5165 .58093 m .4853 .58005 L .48424 .57983 L 1 g
F
P
p
.002 w
.48119 .57972 m .4853 .58005 L p
.48758 .58083 L 1 g
F P
s
P
p
.002 w
.51484 .58627 m .51325 .58962 L p
.4853 .58005 L 1 g
F P
s
P
p
.47163 .57718 m .4678 .57686 L .48845 .58073 L 1 g
F
P
p
.4853 .58005 m .48845 .58073 L .48904 .58084 L 1 g
F
P
p
.47163 .57718 m .48845 .58073 L .4853 .58005 L 1 g
F
P
p
.47208 .57721 m .47163 .57718 L .4853 .58005 L 1 g
F
P
p
.002 w
.48475 .58082 m .48119 .57972 L p
.48758 .58083 L 1 g
F P
s
P
p
.002 w
.48294 .58079 m .48119 .57972 L .48475 .58082 L p
1 g
F P
s
P
p
.002 w
.44895 .58375 m .44625 .57618 L .48119 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58086 L p
1 g
F P
s
P
p
.002 w
.48904 .58086 m .48904 .58084 L p
.48845 .58073 L 1 g
F P
s
P
p
.48845 .58073 m .4678 .57686 L .48904 .58086 L 1 g
F
P
p
.002 w
.51615 .57492 m .51643 .57977 L p
.48377 .57972 L 1 g
F P
s
P
p
.002 w
.48275 .57951 m .51615 .57492 L p
.48377 .57972 L 1 g
F P
s
P
p
.002 w
.51643 .57977 m .5165 .58093 L p
.51168 .58077 L 1 g
F P
s
P
p
.002 w
.51659 .58259 m .51484 .58627 L p
.5 .58315 L 1 g
F P
s
P
p
.002 w
.4853 .58005 m .50678 .58179 L p
.5 .58315 L 1 g
F P
s
P
p
.002 w
.50678 .58179 m .51659 .58259 L p
.5 .58315 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53217 .57671 L p
1 g
F P
s
P
p
.002 w
.53217 .57671 m .53212 .57648 L p
.52993 .57716 L 1 g
F P
s
P
p
.52993 .57716 m .51111 .583 L .53217 .57671 L 1 g
F
P
p
.51807 .57943 m .51111 .583 L .53212 .57648 L 1 g
F
P
p
.002 w
.51643 .57977 m .51615 .57492 L p
.53581 .57311 L 1 g
F P
s
P
p
.002 w
.53169 .57453 m .5322 .57686 L p
.53992 .5695 L 1 g
F P
s
P
p
.51937 .57876 m .51643 .57977 L .51807 .57943 L 1 g
F
P
p
.002 w
.51096 .58092 m .51111 .583 L p
.51807 .57943 L 1 g
F P
s
P
p
.49946 .58089 m .49544 .58088 L .49941 .5809 L 1 g
F
P
p
.002 w
.48904 .58084 m .48889 .583 L p
.49941 .5809 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .5812 L p
1 g
F P
s
P
p
.49878 .58102 m .48889 .583 L .51098 .5812 L 1 g
F
P
p
.002 w
.62424 .48123 m .64049 .51596 L .61403 .53568 L p
1 g
F P
s
P
p
.002 w
.64049 .51596 m .62424 .48123 L .64452 .45431 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44735 .56867 m .44625 .57618 L .41326 .56832 L p
1 g
F P
s
P
p
.002 w
.41326 .56832 m .41508 .55344 L .44735 .56867 L p
1 g
F P
s
P
p
.002 w
.39865 .51483 m .38551 .5346 L .35968 .51285 L p
1 g
F P
s
P
p
.002 w
.35968 .51285 m .37609 .48699 L .39865 .51483 L p
1 g
F P
s
P
p
.002 w
.62084 .38832 m .66012 .42717 L .64452 .45431 L p
1 g
F P
s
P
p
.002 w
.66012 .42717 m .62084 .38832 L .62979 .35951 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.51325 .58962 m .51659 .58259 L .55127 .58088 L p
1 g
F P
s
P
p
.002 w
.55127 .58088 m .55076 .56574 L .58378 .55249 L p
1 g
F P
s
P
p
.002 w
.39225 .43305 m .35745 .45765 L .34335 .42792 L p
1 g
F P
s
P
p
.002 w
.34335 .42792 m .38241 .39943 L .39225 .43305 L p
1 g
F P
s
P
p
.002 w
.43383 .34855 m .37628 .36727 L .37399 .33769 L p
1 g
F P
s
P
p
.002 w
.37399 .33769 m .43418 .31759 L .43383 .34855 L p
1 g
F P
s
P
p
.002 w
.59991 .50692 m .61403 .53568 L .58378 .55249 L p
1 g
F P
s
P
p
.002 w
.61403 .53568 m .59991 .50692 L .62424 .48123 L p
1 g
F P
s
P
p
.002 w
.42433 .54016 m .41508 .55344 L .38551 .5346 L p
1 g
F P
s
P
p
.002 w
.38551 .5346 m .39865 .51483 L .42433 .54016 L p
1 g
F P
s
P
p
.002 w
.50317 .31451 m .43418 .31759 L .43649 .29082 L p
1 g
F P
s
P
p
.002 w
.43649 .29082 m .50642 .2875 L .50317 .31451 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62979 .35951 m .57151 .32922 L .57566 .30251 L p
1 g
F P
s
P
p
.002 w
.50642 .2875 m .57566 .30251 L .57151 .32922 L p
1 g
F P
s
P
p
.002 w
.58378 .55249 m .57239 .53042 L .59991 .50692 L p
1 g
F P
s
P
p
.002 w
.57151 .32922 m .62979 .35951 L .62084 .38832 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.60799 .41903 m .64452 .45431 L .62424 .48123 L p
1 g
F P
s
P
p
.002 w
.64452 .45431 m .60799 .41903 L .62084 .38832 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51615 .57492 m .51191 .56746 L .54269 .55084 L p
1 g
F P
s
P
p
.002 w
.40551 .46687 m .37609 .48699 L .35745 .45765 L p
1 g
F P
s
P
p
.002 w
.35745 .45765 m .39225 .43305 L .40551 .46687 L p
1 g
F P
s
P
p
.002 w
.57151 .32922 m .50317 .31451 L .50642 .2875 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.43554 .38266 m .38241 .39943 L .37628 .36727 L p
1 g
F P
s
P
p
.002 w
.37628 .36727 m .43383 .34855 L .43554 .38266 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51191 .56746 m .50428 .56103 L .52774 .53791 L p
1 g
F P
s
P
p
.002 w
.52774 .53791 m .54269 .55084 L .51191 .56746 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.42171 .49961 m .39865 .51483 L .37609 .48699 L p
1 g
F P
s
P
p
.002 w
.37609 .48699 m .40551 .46687 L .42171 .49961 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5916 .45053 m .62424 .48123 L .59991 .50692 L p
1 g
F P
s
P
p
.002 w
.62424 .48123 m .5916 .45053 L .60799 .41903 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.47078 .55426 m .46029 .55704 L .44021 .53004 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.49974 .34581 m .43383 .34855 L .43418 .31759 L p
1 g
F P
s
P
p
.002 w
.43418 .31759 m .50317 .31451 L .49974 .34581 L p
1 g
F P
s
P
p
.002 w
.50428 .56103 m .4941 .55637 L .50753 .52851 L p
1 g
F P
s
P
p
.002 w
.50753 .52851 m .52774 .53791 L .50428 .56103 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.56504 .35976 m .62084 .38832 L .60799 .41903 L p
1 g
F P
s
P
p
.002 w
.62084 .38832 m .56504 .35976 L .57151 .32922 L p
1 g
F P
s
P
p
.002 w
.54269 .55084 m .52774 .53791 L .5507 .51113 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48249 .55402 m .47078 .55426 L .46101 .52433 L p
1 g
F P
s
P
p
.002 w
.44021 .53004 m .46101 .52433 L .47078 .55426 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.4941 .55637 m .48249 .55402 L .48437 .52379 L p
1 g
F P
s
P
p
.002 w
.48437 .52379 m .50753 .52851 L .4941 .55637 L p
1 g
F P
s
P
p
.002 w
.57227 .48162 m .59991 .50692 L .57239 .53042 L p
1 g
F P
s
P
p
.002 w
.59991 .50692 m .57227 .48162 L .5916 .45053 L p
1 g
F P
s
P
p
.002 w
.46101 .52433 m .48437 .52379 L .48249 .55402 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.50317 .31451 m .57151 .32922 L .56504 .35976 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.43928 .41869 m .39225 .43305 L .38241 .39943 L p
1 g
F P
s
P
p
.002 w
.38241 .39943 m .43554 .38266 L .43928 .41869 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.56504 .35976 m .49974 .34581 L .50317 .31451 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52774 .53791 m .50753 .52851 L .521 .49704 L p
1 g
F P
s
P
p
.002 w
.521 .49704 m .5507 .51113 L .52774 .53791 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.55642 .3931 m .60799 .41903 L .5916 .45053 L p
1 g
F P
s
P
p
.002 w
.60799 .41903 m .55642 .3931 L .56504 .35976 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44493 .45525 m .40551 .46687 L .39225 .43305 L p
1 g
F P
s
P
p
.002 w
.39225 .43305 m .43928 .41869 L .44493 .45525 L p
1 g
F P
s
P
p
.002 w
.49624 .38036 m .43554 .38266 L .43383 .34855 L p
1 g
F P
s
P
p
.002 w
.43383 .34855 m .49974 .34581 L .49624 .38036 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48437 .52379 m .46101 .52433 L .45227 .49092 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50753 .52851 m .48437 .52379 L .48678 .49 L p
1 g
F P
s
P
p
.002 w
.48678 .49 m .521 .49704 L .50753 .52851 L p
1 g
F P
s
P
p
.002 w
.49974 .34581 m .56504 .35976 L .55642 .3931 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.45227 .49092 m .48678 .49 L .48437 .52379 L p
1 g
F P
s
P
p
.002 w
.54594 .42799 m .5916 .45053 L .57227 .48162 L p
1 g
F P
s
P
p
.002 w
.5916 .45053 m .54594 .42799 L .55642 .3931 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.004 w
.47354 .64039 m
.47488 .62979 L
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57227 .48162 m .53397 .4631 L .54594 .42799 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.55642 .3931 m .49624 .38036 L .49974 .34581 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49283 .41686 m .43928 .41869 L .43554 .38266 L p
1 g
F P
s
P
p
.002 w
.43554 .38266 m .49624 .38036 L .49283 .41686 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49624 .38036 m .55642 .3931 L .54594 .42799 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.48964 .45389 m .44493 .45525 L .43928 .41869 L p
1 g
F P
s
P
p
.002 w
.43928 .41869 m .49283 .41686 L .48964 .45389 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54594 .42799 m .49283 .41686 L .49624 .38036 L p
1 g
F P
s
P
p
.002 w
.53397 .4631 m .48964 .45389 L .49283 .41686 L p
1 g
F P
s
P
p
.002 w
.49283 .41686 m .54594 .42799 L .53397 .4631 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .74598 .5616 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .47023 .66664 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0868217)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0868217)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44859 .42433 m .48437 .4456 L .49577 .41941 L p
1 g
F P
s
P
p
.002 w
.49577 .41941 m .46598 .40158 L .44859 .42433 L p
1 g
F P
s
P
p
.002 w
.5293 .42928 m .49577 .41941 L .48437 .4456 L p
1 g
F P
s
P
p
.002 w
.46598 .40158 m .49577 .41941 L .50729 .39344 L p
1 g
F P
s
P
p
.002 w
.49577 .41941 m .5293 .42928 L .53334 .40107 L p
1 g
F P
s
P
p
.002 w
.53334 .40107 m .50729 .39344 L .49577 .41941 L p
1 g
F P
s
P
p
.002 w
.43235 .44736 m .47329 .47154 L .48437 .4456 L p
1 g
F P
s
P
p
.002 w
.48437 .4456 m .44859 .42433 L .43235 .44736 L p
1 g
F P
s
P
p
.002 w
.52455 .45748 m .48437 .4456 L .47329 .47154 L p
1 g
F P
s
P
p
.002 w
.48437 .4456 m .52455 .45748 L .5293 .42928 L p
1 g
F P
s
P
p
.002 w
.56343 .43022 m .5293 .42928 L .52455 .45748 L p
1 g
F P
s
P
p
.002 w
.5293 .42928 m .56343 .43022 L .55983 .40167 L p
1 g
F P
s
P
p
.002 w
.55983 .40167 m .53334 .40107 L .5293 .42928 L p
1 g
F P
s
P
p
.002 w
.47329 .47154 m .51918 .48516 L .52455 .45748 L p
1 g
F P
s
P
p
.002 w
.56548 .45883 m .52455 .45748 L .51918 .48516 L p
1 g
F P
s
P
p
.002 w
.52455 .45748 m .56548 .45883 L .56343 .43022 L p
1 g
F P
s
P
p
.002 w
.50729 .39344 m .4842 .37952 L .46598 .40158 L p
1 g
F P
s
P
p
.002 w
.4842 .37952 m .50729 .39344 L .51873 .36815 L p
1 g
F P
s
P
p
.002 w
.50729 .39344 m .53334 .40107 L .53661 .37337 L p
1 g
F P
s
P
p
.002 w
.53661 .37337 m .51873 .36815 L .50729 .39344 L p
1 g
F P
s
P
p
.002 w
.53334 .40107 m .55983 .40167 L .55476 .37368 L p
1 g
F P
s
P
p
.002 w
.55476 .37368 m .53661 .37337 L .53334 .40107 L p
1 g
F P
s
P
p
.002 w
.42057 .3955 m .44859 .42433 L .46598 .40158 L p
1 g
F P
s
P
p
.002 w
.46598 .40158 m .4428 .3774 L .42057 .3955 L p
1 g
F P
s
P
p
.002 w
.4428 .3774 m .46598 .40158 L .4842 .37952 L p
1 g
F P
s
P
p
.002 w
.41757 .47026 m .46275 .49676 L .47329 .47154 L p
1 g
F P
s
P
p
.002 w
.47329 .47154 m .43235 .44736 L .41757 .47026 L p
1 g
F P
s
P
p
.002 w
.51918 .48516 m .47329 .47154 L .46275 .49676 L p
1 g
F P
s
P
p
.002 w
.40009 .41463 m .43235 .44736 L .44859 .42433 L p
1 g
F P
s
P
p
.002 w
.44859 .42433 m .42057 .3955 L .40009 .41463 L p
1 g
F P
s
P
p
.002 w
.4842 .37952 m .46636 .36064 L .4428 .3774 L p
1 g
F P
s
P
p
.002 w
.46636 .36064 m .4842 .37952 L .50293 .35857 L p
1 g
F P
s
P
p
.002 w
.51873 .36815 m .50293 .35857 L .4842 .37952 L p
1 g
F P
s
P
p
.002 w
.46275 .49676 m .51328 .51182 L .51918 .48516 L p
1 g
F P
s
P
p
.002 w
.56595 .48695 m .51918 .48516 L .51328 .51182 L p
1 g
F P
s
P
p
.002 w
.51918 .48516 m .56595 .48695 L .56548 .45883 L p
1 g
F P
s
P
p
.002 w
.5949 .42199 m .56343 .43022 L .56548 .45883 L p
1 g
F P
s
P
p
.002 w
.56343 .43022 m .5949 .42199 L .58415 .39506 L p
1 g
F P
s
P
p
.002 w
.58415 .39506 m .55983 .40167 L .56343 .43022 L p
1 g
F P
s
P
p
.002 w
.50293 .35857 m .51873 .36815 L .52988 .34403 L p
1 g
F P
s
P
p
.002 w
.51873 .36815 m .53661 .37337 L .53902 .34669 L p
1 g
F P
s
P
p
.002 w
.53902 .34669 m .52988 .34403 L .51873 .36815 L p
1 g
F P
s
P
p
.002 w
.55983 .40167 m .58415 .39506 L .57134 .36902 L p
1 g
F P
s
P
p
.002 w
.57134 .36902 m .55476 .37368 L .55983 .40167 L p
1 g
F P
s
P
p
.002 w
.53661 .37337 m .55476 .37368 L .54829 .3468 L p
1 g
F P
s
P
p
.002 w
.54829 .3468 m .53902 .34669 L .53661 .37337 L p
1 g
F P
s
P
p
.002 w
.38179 .43444 m .41757 .47026 L .43235 .44736 L p
1 g
F P
s
P
p
.002 w
.43235 .44736 m .40009 .41463 L .38179 .43444 L p
1 g
F P
s
P
p
.002 w
.60337 .44929 m .56548 .45883 L .56595 .48695 L p
1 g
F P
s
P
p
.002 w
.56548 .45883 m .60337 .44929 L .5949 .42199 L p
1 g
F P
s
P
p
.002 w
.50293 .35857 m .49081 .34556 L .46636 .36064 L p
1 g
F P
s
P
p
.002 w
.49081 .34556 m .50293 .35857 L .52182 .33911 L p
1 g
F P
s
P
p
.002 w
.52988 .34403 m .52182 .33911 L .50293 .35857 L p
1 g
F P
s
P
p
.002 w
.40458 .49257 m .45295 .52078 L .46275 .49676 L p
1 g
F P
s
P
p
.002 w
.46275 .49676 m .41757 .47026 L .40458 .49257 L p
1 g
F P
s
P
p
.002 w
.51328 .51182 m .46275 .49676 L .45295 .52078 L p
1 g
F P
s
P
p
.002 w
.42865 .34905 m .4428 .3774 L .46636 .36064 L p
1 g
F P
s
P
p
.002 w
.46636 .36064 m .45565 .33859 L .42865 .34905 L p
1 g
F P
s
P
p
.002 w
.45565 .33859 m .46636 .36064 L .49081 .34556 L p
1 g
F P
s
P
p
.002 w
.40318 .36163 m .42057 .3955 L .4428 .3774 L p
1 g
F P
s
P
p
.002 w
.4428 .3774 m .42865 .34905 L .40318 .36163 L p
1 g
F P
s
P
p
.002 w
.55476 .37368 m .57134 .36902 L .5567 .34435 L p
1 g
F P
s
P
p
.002 w
.5567 .34435 m .54829 .3468 L .55476 .37368 L p
1 g
F P
s
P
p
.002 w
.45295 .52078 m .50695 .53693 L .51328 .51182 L p
1 g
F P
s
P
p
.002 w
.5648 .51405 m .51328 .51182 L .50695 .53693 L p
1 g
F P
s
P
p
.002 w
.51328 .51182 m .5648 .51405 L .56595 .48695 L p
1 g
F P
s
P
p
.002 w
.49081 .34556 m .48366 .33042 L .45565 .33859 L p
1 g
F P
s
P
p
.002 w
.48366 .33042 m .49081 .34556 L .51568 .33244 L p
1 g
F P
s
P
p
.002 w
.52182 .33911 m .51568 .33244 L .49081 .34556 L p
1 g
F P
s
P
p
.002 w
.60937 .47644 m .56595 .48695 L .5648 .51405 L p
1 g
F P
s
P
p
.002 w
.56595 .48695 m .60937 .47644 L .60337 .44929 L p
1 g
F P
s
P
p
.002 w
.3798 .37611 m .40009 .41463 L .42057 .3955 L p
1 g
F P
s
P
p
.002 w
.42057 .3955 m .40318 .36163 L .3798 .37611 L p
1 g
F P
s
P
p
.002 w
.60378 .38176 m .58415 .39506 L .5949 .42199 L p
1 g
F P
s
P
p
.002 w
.58415 .39506 m .60378 .38176 L .5846 .35977 L p
1 g
F P
s
P
p
.002 w
.5846 .35977 m .57134 .36902 L .58415 .39506 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .52182 .33911 L .52988 .34403 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .52988 .34403 L .53902 .34669 L closepath p
1 g
F P
s
P
p
.002 w
.3661 .45453 m .40458 .49257 L .41757 .47026 L p
1 g
F P
s
P
p
.002 w
.41757 .47026 m .38179 .43444 L .3661 .45453 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .53902 .34669 L .54829 .3468 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .51568 .33244 L .52182 .33911 L closepath p
1 g
F P
s
P
p
.002 w
.57134 .36902 m .5846 .35977 L .56338 .33957 L p
1 g
F P
s
P
p
.002 w
.56338 .33957 m .5567 .34435 L .57134 .36902 L p
1 g
F P
s
P
p
.002 w
.6205 .40511 m .5949 .42199 L .60337 .44929 L p
1 g
F P
s
P
p
.002 w
.5949 .42199 m .6205 .40511 L .60378 .38176 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .54829 .3468 L .5567 .34435 L closepath p
1 g
F P
s
P
p
.002 w
.51568 .33244 m .51213 .3247 L .48366 .33042 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .51213 .3247 L .51568 .33244 L closepath p
1 g
F P
s
P
p
.002 w
.35902 .39223 m .38179 .43444 L .40009 .41463 L p
1 g
F P
s
P
p
.002 w
.40009 .41463 m .3798 .37611 L .35902 .39223 L p
1 g
F P
s
P
p
.002 w
.45336 .31553 m .45565 .33859 L .48366 .33042 L p
1 g
F P
s
P
p
.002 w
.48366 .33042 m .48233 .31468 L .45336 .31553 L p
1 g
F P
s
P
p
.002 w
.48233 .31468 m .48366 .33042 L .51213 .3247 L p
1 g
F P
s
P
p
.002 w
.39367 .51385 m .4441 .54309 L .45295 .52078 L p
1 g
F P
s
P
p
.002 w
.45295 .52078 m .40458 .49257 L .39367 .51385 L p
1 g
F P
s
P
p
.002 w
.50695 .53693 m .45295 .52078 L .4441 .54309 L p
1 g
F P
s
P
p
.002 w
.42527 .31926 m .42865 .34905 L .45565 .33859 L p
1 g
F P
s
P
p
.002 w
.45565 .33859 m .45336 .31553 L .42527 .31926 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .5567 .34435 L .56338 .33957 L closepath p
1 g
F P
s
P
p
.002 w
.6344 .42939 m .60337 .44929 L .60937 .47644 L p
1 g
F P
s
P
p
.002 w
.60337 .44929 m .6344 .42939 L .6205 .40511 L p
1 g
F P
s
P
p
.002 w
.50695 .53693 m .56201 .53957 L .5648 .51405 L p
1 g
F P
s
P
p
.002 w
.61273 .50288 m .5648 .51405 L .56201 .53957 L p
1 g
F P
s
P
p
.002 w
.5648 .51405 m .61273 .50288 L .60937 .47644 L p
1 g
F P
s
P
p
.002 w
.51213 .3247 m .51157 .31671 L .48233 .31468 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .51157 .31671 L .51213 .3247 L closepath p
1 g
F P
s
P
p
.002 w
.4441 .54309 m .50031 .55996 L .50695 .53693 L p
1 g
F P
s
P
p
.002 w
.56201 .53957 m .50695 .53693 L .50031 .55996 L p
1 g
F P
s
P
p
.002 w
.39864 .32587 m .40318 .36163 L .42865 .34905 L p
1 g
F P
s
P
p
.002 w
.42865 .34905 m .42527 .31926 L .39864 .32587 L p
1 g
F P
s
P
p
.002 w
.59308 .34681 m .5846 .35977 L .60378 .38176 L p
1 g
F P
s
P
p
.002 w
.5846 .35977 m .59308 .34681 L .56757 .33294 L p
1 g
F P
s
P
p
.002 w
.56757 .33294 m .56338 .33957 L .5846 .35977 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .56338 .33957 L .56757 .33294 L closepath p
1 g
F P
s
P
p
.002 w
.35342 .47452 m .39367 .51385 L .40458 .49257 L p
1 g
F P
s
P
p
.002 w
.40458 .49257 m .3661 .45453 L .35342 .47452 L p
1 g
F P
s
P
p
.002 w
.48708 .30003 m .48233 .31468 L .51157 .31671 L p
1 g
F P
s
P
p
.002 w
.51157 .31671 m .51409 .30934 L .48708 .30003 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .51409 .30934 L .51157 .31671 L closepath p
1 g
F P
s
P
p
.002 w
.61652 .36292 m .60378 .38176 L .6205 .40511 L p
1 g
F P
s
P
p
.002 w
.60378 .38176 m .61652 .36292 L .59308 .34681 L p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .5688 .32517 L .56689 .31709 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .56689 .31709 L .56203 .3096 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .56203 .3096 L .55472 .30353 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .55472 .30353 L .54579 .29958 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .54579 .29958 L .53623 .29819 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .53623 .29819 L .52712 .29951 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .52712 .29951 L .51946 .30338 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .51946 .30338 L .51409 .30934 L closepath p
1 g
F P
s
P
p
.002 w
.54051 .32157 m .56757 .33294 L .5688 .32517 L closepath p
1 g
F P
s
P
p
.002 w
.46003 .29389 m .45336 .31553 L .48233 .31468 L p
1 g
F P
s
P
p
.002 w
.48233 .31468 m .48708 .30003 L .46003 .29389 L p
1 g
F P
s
P
p
.002 w
.34138 .4097 m .3661 .45453 L .38179 .43444 L p
1 g
F P
s
P
p
.002 w
.38179 .43444 m .35902 .39223 L .34138 .4097 L p
1 g
F P
s
P
p
.002 w
.64514 .45411 m .60937 .47644 L .61273 .50288 L p
1 g
F P
s
P
p
.002 w
.60937 .47644 m .64514 .45411 L .6344 .42939 L p
1 g
F P
s
P
p
.002 w
.5688 .32517 m .56757 .33294 L .59308 .34681 L p
1 g
F P
s
P
p
.002 w
.37408 .33528 m .3798 .37611 L .40318 .36163 L p
1 g
F P
s
P
p
.002 w
.40318 .36163 m .39864 .32587 L .37408 .33528 L p
1 g
F P
s
P
p
.002 w
.49756 .28808 m .48708 .30003 L .51409 .30934 L p
1 g
F P
s
P
p
.002 w
.51409 .30934 m .51946 .30338 L .49756 .28808 L p
1 g
F P
s
P
p
.002 w
.63735 .38098 m .6205 .40511 L .6344 .42939 L p
1 g
F P
s
P
p
.002 w
.6205 .40511 m .63735 .38098 L .61652 .36292 L p
1 g
F P
s
P
p
.002 w
.4335 .29111 m .42527 .31926 L .45336 .31553 L p
1 g
F P
s
P
p
.002 w
.45336 .31553 m .46003 .29389 L .4335 .29111 L p
1 g
F P
s
P
p
.002 w
.59574 .33148 m .59308 .34681 L .61652 .36292 L p
1 g
F P
s
P
p
.002 w
.59308 .34681 m .59574 .33148 L .5688 .32517 L p
1 g
F P
s
P
p
.002 w
.50031 .55996 m .55759 .56296 L .56201 .53957 L p
1 g
F P
s
P
p
.002 w
.6133 .52806 m .56201 .53957 L .55759 .56296 L p
1 g
F P
s
P
p
.002 w
.56201 .53957 m .6133 .52806 L .61273 .50288 L p
1 g
F P
s
P
p
.002 w
.38517 .53361 m .43642 .56318 L .4441 .54309 L p
1 g
F P
s
P
p
.002 w
.4441 .54309 m .39367 .51385 L .38517 .53361 L p
1 g
F P
s
P
p
.002 w
.50031 .55996 m .4441 .54309 L .43642 .56318 L p
1 g
F P
s
P
p
.002 w
.56689 .31709 m .5688 .32517 L .59574 .33148 L p
1 g
F P
s
P
p
.002 w
.51271 .28026 m .49756 .28808 L .51946 .30338 L p
1 g
F P
s
P
p
.002 w
.51946 .30338 m .52712 .29951 L .51271 .28026 L p
1 g
F P
s
P
p
.002 w
.43642 .56318 m .49347 .58035 L .50031 .55996 L p
1 g
F P
s
P
p
.002 w
.55759 .56296 m .50031 .55996 L .49347 .58035 L p
1 g
F P
s
P
p
.002 w
.47524 .2761 m .46003 .29389 L .48708 .30003 L p
1 g
F P
s
P
p
.002 w
.48708 .30003 m .49756 .28808 L .47524 .2761 L p
1 g
F P
s
P
p
.002 w
.59574 .33148 m .59213 .3154 L .56689 .31709 L p
1 g
F P
s
P
p
.002 w
.56203 .3096 m .56689 .31709 L .59213 .3154 L p
1 g
F P
s
P
p
.002 w
.35221 .34738 m .35902 .39223 L .3798 .37611 L p
1 g
F P
s
P
p
.002 w
.3798 .37611 m .37408 .33528 L .35221 .34738 L p
1 g
F P
s
P
p
.002 w
.5309 .27752 m .51271 .28026 L .52712 .29951 L p
1 g
F P
s
P
p
.002 w
.52712 .29951 m .53623 .29819 L .5309 .27752 L p
1 g
F P
s
P
p
.002 w
.65238 .47874 m .61273 .50288 L .6133 .52806 L p
1 g
F P
s
P
p
.002 w
.61273 .50288 m .65238 .47874 L .64514 .45411 L p
1 g
F P
s
P
p
.002 w
.4081 .29187 m .39864 .32587 L .42527 .31926 L p
1 g
F P
s
P
p
.002 w
.42527 .31926 m .4335 .29111 L .4081 .29187 L p
1 g
F P
s
P
p
.002 w
.65506 .40064 m .6344 .42939 L .64514 .45411 L p
1 g
F P
s
P
p
.002 w
.6344 .42939 m .65506 .40064 L .63735 .38098 L p
1 g
F P
s
P
p
.002 w
.62074 .34041 m .61652 .36292 L .63735 .38098 L p
1 g
F P
s
P
p
.002 w
.61652 .36292 m .62074 .34041 L .59574 .33148 L p
1 g
F P
s
P
p
.002 w
.34417 .49396 m .38517 .53361 L .39367 .51385 L p
1 g
F P
s
P
p
.002 w
.39367 .51385 m .35342 .47452 L .34417 .49396 L p
1 g
F P
s
P
p
.002 w
.59213 .3154 m .58254 .30039 L .56203 .3096 L p
1 g
F P
s
P
p
.002 w
.55472 .30353 m .56203 .3096 L .58254 .30039 L p
1 g
F P
s
P
p
.002 w
.32738 .42819 m .35342 .47452 L .3661 .45453 L p
1 g
F P
s
P
p
.002 w
.3661 .45453 m .34138 .4097 L .32738 .42819 L p
1 g
F P
s
P
p
.002 w
.55006 .28026 m .5309 .27752 L .53623 .29819 L p
1 g
F P
s
P
p
.002 w
.53623 .29819 m .54579 .29958 L .55006 .28026 L p
1 g
F P
s
P
p
.002 w
.59213 .3154 m .59574 .33148 L .62074 .34041 L p
1 g
F P
s
P
p
.002 w
.58254 .30039 m .56797 .28819 L .55472 .30353 L p
1 g
F P
s
P
p
.002 w
.54579 .29958 m .55472 .30353 L .56797 .28819 L p
1 g
F P
s
P
p
.002 w
.56797 .28819 m .55006 .28026 L .54579 .29958 L p
1 g
F P
s
P
p
.002 w
.45299 .2678 m .4335 .29111 L .46003 .29389 L p
1 g
F P
s
P
p
.002 w
.46003 .29389 m .47524 .2761 L .45299 .2678 L p
1 g
F P
s
P
p
.002 w
.49757 .26433 m .47524 .2761 L .49756 .28808 L p
1 g
F P
s
P
p
.002 w
.49756 .28808 m .51271 .28026 L .49757 .26433 L p
1 g
F P
s
P
p
.002 w
.49347 .58035 m .55156 .58362 L .55759 .56296 L p
1 g
F P
s
P
p
.002 w
.61097 .55138 m .55759 .56296 L .55156 .58362 L p
1 g
F P
s
P
p
.002 w
.55759 .56296 m .61097 .55138 L .6133 .52806 L p
1 g
F P
s
P
p
.002 w
.38444 .29628 m .37408 .33528 L .39864 .32587 L p
1 g
F P
s
P
p
.002 w
.39864 .32587 m .4081 .29187 L .38444 .29628 L p
1 g
F P
s
P
p
.002 w
.6432 .35186 m .63735 .38098 L .65506 .40064 L p
1 g
F P
s
P
p
.002 w
.63735 .38098 m .6432 .35186 L .62074 .34041 L p
1 g
F P
s
P
p
.002 w
.33363 .36199 m .34138 .4097 L .35902 .39223 L p
1 g
F P
s
P
p
.002 w
.35902 .39223 m .35221 .34738 L .33363 .36199 L p
1 g
F P
s
P
p
.002 w
.66917 .42154 m .64514 .45411 L .65238 .47874 L p
1 g
F P
s
P
p
.002 w
.64514 .45411 m .66917 .42154 L .65506 .40064 L p
1 g
F P
s
P
p
.002 w
.37936 .55136 m .43012 .58051 L .43642 .56318 L p
1 g
F P
s
P
p
.002 w
.43642 .56318 m .38517 .53361 L .37936 .55136 L p
1 g
F P
s
P
p
.002 w
.49347 .58035 m .43642 .56318 L .43012 .58051 L p
1 g
F P
s
P
p
.002 w
.62074 .34041 m .61566 .31662 L .59213 .3154 L p
1 g
F P
s
P
p
.002 w
.58254 .30039 m .59213 .3154 L .61566 .31662 L p
1 g
F P
s
P
p
.002 w
.65585 .50274 m .6133 .52806 L .61097 .55138 L p
1 g
F P
s
P
p
.002 w
.6133 .52806 m .65585 .50274 L .65238 .47874 L p
1 g
F P
s
P
p
.002 w
.43012 .58051 m .48657 .59755 L .49347 .58035 L p
1 g
F P
s
P
p
.002 w
.55156 .58362 m .49347 .58035 L .48657 .59755 L p
1 g
F P
s
P
p
.002 w
.61566 .31662 m .62074 .34041 L .6432 .35186 L p
1 g
F P
s
P
p
.002 w
.52459 .26013 m .49757 .26433 L .51271 .28026 L p
1 g
F P
s
P
p
.002 w
.51271 .28026 m .5309 .27752 L .52459 .26013 L p
1 g
F P
s
P
p
.002 w
.31751 .4473 m .34417 .49396 L .35342 .47452 L p
1 g
F P
s
P
p
.002 w
.35342 .47452 m .32738 .42819 L .31751 .4473 L p
1 g
F P
s
P
p
.002 w
.61566 .31662 m .60157 .29426 L .58254 .30039 L p
1 g
F P
s
P
p
.002 w
.56797 .28819 m .58254 .30039 L .60157 .29426 L p
1 g
F P
s
P
p
.002 w
.3387 .51237 m .37936 .55136 L .38517 .53361 L p
1 g
F P
s
P
p
.002 w
.38517 .53361 m .34417 .49396 L .3387 .51237 L p
1 g
F P
s
P
p
.002 w
.43132 .26353 m .4081 .29187 L .4335 .29111 L p
1 g
F P
s
P
p
.002 w
.4335 .29111 m .45299 .2678 L .43132 .26353 L p
1 g
F P
s
P
p
.002 w
.55318 .26416 m .52459 .26013 L .5309 .27752 L p
1 g
F P
s
P
p
.002 w
.5309 .27752 m .55006 .28026 L .55318 .26416 L p
1 g
F P
s
P
p
.002 w
.482 .25224 m .45299 .2678 L .47524 .2761 L p
1 g
F P
s
P
p
.002 w
.47524 .2761 m .49757 .26433 L .482 .25224 L p
1 g
F P
s
P
p
.002 w
.60157 .29426 m .57991 .27602 L .56797 .28819 L p
1 g
F P
s
P
p
.002 w
.55006 .28026 m .56797 .28819 L .57991 .27602 L p
1 g
F P
s
P
p
.002 w
.36316 .30437 m .35221 .34738 L .37408 .33528 L p
1 g
F P
s
P
p
.002 w
.37408 .33528 m .38444 .29628 L .36316 .30437 L p
1 g
F P
s
P
p
.002 w
.66251 .36567 m .65506 .40064 L .66917 .42154 L p
1 g
F P
s
P
p
.002 w
.65506 .40064 m .66251 .36567 L .6432 .35186 L p
1 g
F P
s
P
p
.002 w
.57991 .27602 m .55318 .26416 L .55006 .28026 L p
1 g
F P
s
P
p
.002 w
.67922 .44322 m .65238 .47874 L .65585 .50274 L p
1 g
F P
s
P
p
.002 w
.65238 .47874 m .67922 .44322 L .66917 .42154 L p
1 g
F P
s
P
p
.002 w
.31892 .37886 m .32738 .42819 L .34138 .4097 L p
1 g
F P
s
P
p
.002 w
.34138 .4097 m .33363 .36199 L .31892 .37886 L p
1 g
F P
s
P
p
.002 w
.48657 .59755 m .54398 .60097 L .55156 .58362 L p
1 g
F P
s
P
p
.002 w
.60567 .57224 m .55156 .58362 L .54398 .60097 L p
1 g
F P
s
P
p
.002 w
.55156 .58362 m .60567 .57224 L .61097 .55138 L p
1 g
F P
s
P
p
.002 w
.6432 .35186 m .63687 .32084 L .61566 .31662 L p
1 g
F P
s
P
p
.002 w
.60157 .29426 m .61566 .31662 L .63687 .32084 L p
1 g
F P
s
P
p
.002 w
.63687 .32084 m .6432 .35186 L .66251 .36567 L p
1 g
F P
s
P
p
.002 w
.65531 .52552 m .61097 .55138 L .60567 .57224 L p
1 g
F P
s
P
p
.002 w
.61097 .55138 m .65531 .52552 L .65585 .50274 L p
1 g
F P
s
P
p
.002 w
.37652 .56657 m .42542 .59455 L .43012 .58051 L p
1 g
F P
s
P
p
.002 w
.43012 .58051 m .37936 .55136 L .37652 .56657 L p
1 g
F P
s
P
p
.002 w
.48657 .59755 m .43012 .58051 L .42542 .59455 L p
1 g
F P
s
P
p
.002 w
.5174 .2466 m .482 .25224 L .49757 .26433 L p
1 g
F P
s
P
p
.002 w
.49757 .26433 m .52459 .26013 L .5174 .2466 L p
1 g
F P
s
P
p
.002 w
.41078 .26358 m .38444 .29628 L .4081 .29187 L p
1 g
F P
s
P
p
.002 w
.4081 .29187 m .43132 .26353 L .41078 .26358 L p
1 g
F P
s
P
p
.002 w
.42542 .59455 m .47977 .61099 L .48657 .59755 L p
1 g
F P
s
P
p
.002 w
.54398 .60097 m .48657 .59755 L .47977 .61099 L p
1 g
F P
s
P
p
.002 w
.31222 .4666 m .3387 .51237 L .34417 .49396 L p
1 g
F P
s
P
p
.002 w
.34417 .49396 m .31751 .4473 L .31222 .4666 L p
1 g
F P
s
P
p
.002 w
.46635 .24448 m .43132 .26353 L .45299 .2678 L p
1 g
F P
s
P
p
.002 w
.45299 .2678 m .482 .25224 L .46635 .24448 L p
1 g
F P
s
P
p
.002 w
.6781 .3816 m .66917 .42154 L .67922 .44322 L p
1 g
F P
s
P
p
.002 w
.66917 .42154 m .6781 .3816 L .66251 .36567 L p
1 g
F P
s
P
p
.002 w
.3449 .31613 m .33363 .36199 L .35221 .34738 L p
1 g
F P
s
P
p
.002 w
.35221 .34738 m .36316 .30437 L .3449 .31613 L p
1 g
F P
s
P
p
.002 w
.63687 .32084 m .61858 .29151 L .60157 .29426 L p
1 g
F P
s
P
p
.002 w
.57991 .27602 m .60157 .29426 L .61858 .29151 L p
1 g
F P
s
P
p
.002 w
.33736 .52925 m .37652 .56657 L .37936 .55136 L p
1 g
F P
s
P
p
.002 w
.37936 .55136 m .3387 .51237 L .33736 .52925 L p
1 g
F P
s
P
p
.002 w
.68478 .4652 m .65585 .50274 L .65531 .52552 L p
1 g
F P
s
P
p
.002 w
.65585 .50274 m .68478 .4652 L .67922 .44322 L p
1 g
F P
s
P
p
.002 w
.55501 .25186 m .5174 .2466 L .52459 .26013 L p
1 g
F P
s
P
p
.002 w
.52459 .26013 m .55318 .26416 L .55501 .25186 L p
1 g
F P
s
P
p
.002 w
.30866 .39767 m .31751 .4473 L .32738 .42819 L p
1 g
F P
s
P
p
.002 w
.32738 .42819 m .31892 .37886 L .30866 .39767 L p
1 g
F P
s
P
p
.002 w
.61858 .29151 m .59019 .26748 L .57991 .27602 L p
1 g
F P
s
P
p
.002 w
.55318 .26416 m .57991 .27602 L .59019 .26748 L p
1 g
F P
s
P
p
.002 w
.59019 .26748 m .55501 .25186 L .55318 .26416 L p
1 g
F P
s
P
p
.002 w
.65514 .32812 m .66251 .36567 L .6781 .3816 L p
1 g
F P
s
P
p
.002 w
.66251 .36567 m .65514 .32812 L .63687 .32084 L p
1 g
F P
s
P
p
.002 w
.61858 .29151 m .63687 .32084 L .65514 .32812 L p
1 g
F P
s
P
p
.002 w
.47977 .61099 m .53496 .61442 L .54398 .60097 L p
1 g
F P
s
P
p
.002 w
.59739 .59003 m .54398 .60097 L .53496 .61442 L p
1 g
F P
s
P
p
.002 w
.54398 .60097 m .59739 .59003 L .60567 .57224 L p
1 g
F P
s
P
p
.002 w
.65059 .54647 m .60567 .57224 L .59739 .59003 L p
1 g
F P
s
P
p
.002 w
.60567 .57224 m .65059 .54647 L .65531 .52552 L p
1 g
F P
s
P
p
.002 w
.39196 .26818 m .36316 .30437 L .38444 .29628 L p
1 g
F P
s
P
p
.002 w
.38444 .29628 m .41078 .26358 L .39196 .26818 L p
1 g
F P
s
P
p
.002 w
.50944 .23751 m .46635 .24448 L .482 .25224 L p
1 g
F P
s
P
p
.002 w
.482 .25224 m .5174 .2466 L .50944 .23751 L p
1 g
F P
s
P
p
.002 w
.6894 .39935 m .67922 .44322 L .68478 .4652 L p
1 g
F P
s
P
p
.002 w
.67922 .44322 m .6894 .39935 L .6781 .3816 L p
1 g
F P
s
P
p
.002 w
.33029 .3314 m .31892 .37886 L .33363 .36199 L p
1 g
F P
s
P
p
.002 w
.33363 .36199 m .3449 .31613 L .33029 .3314 L p
1 g
F P
s
P
p
.002 w
.3769 .57871 m .42253 .60476 L .42542 .59455 L p
1 g
F P
s
P
p
.002 w
.42542 .59455 m .37652 .56657 L .3769 .57871 L p
1 g
F P
s
P
p
.002 w
.47977 .61099 m .42542 .59455 L .42253 .60476 L p
1 g
F P
s
P
p
.002 w
.45102 .24149 m .41078 .26358 L .43132 .26353 L p
1 g
F P
s
P
p
.002 w
.43132 .26353 m .46635 .24448 L .45102 .24149 L p
1 g
F P
s
P
p
.002 w
.31186 .48559 m .33736 .52925 L .3387 .51237 L p
1 g
F P
s
P
p
.002 w
.3387 .51237 m .31222 .4666 L .31186 .48559 L p
1 g
F P
s
P
p
.002 w
.42253 .60476 m .47323 .62012 L .47977 .61099 L p
1 g
F P
s
P
p
.002 w
.53496 .61442 m .47977 .61099 L .47323 .62012 L p
1 g
F P
s
P
p
.002 w
.68552 .48694 m .65531 .52552 L .65059 .54647 L p
1 g
F P
s
P
p
.002 w
.65531 .52552 m .68552 .48694 L .68478 .4652 L p
1 g
F P
s
P
p
.002 w
.65514 .32812 m .63307 .29239 L .61858 .29151 L p
1 g
F P
s
P
p
.002 w
.59019 .26748 m .61858 .29151 L .63307 .29239 L p
1 g
F P
s
P
p
.002 w
.30332 .41801 m .31222 .4666 L .31751 .4473 L p
1 g
F P
s
P
p
.002 w
.31751 .4473 m .30866 .39767 L .30332 .41801 L p
1 g
F P
s
P
p
.002 w
.3404 .54409 m .3769 .57871 L .37652 .56657 L p
1 g
F P
s
P
p
.002 w
.37652 .56657 m .33736 .52925 L .3404 .54409 L p
1 g
F P
s
P
p
.002 w
.66988 .33842 m .6781 .3816 L .6894 .39935 L p
1 g
F P
s
P
p
.002 w
.6781 .3816 m .66988 .33842 L .65514 .32812 L p
1 g
F P
s
P
p
.002 w
.55542 .24389 m .50944 .23751 L .5174 .2466 L p
1 g
F P
s
P
p
.002 w
.5174 .2466 m .55501 .25186 L .55542 .24389 L p
1 g
F P
s
P
p
.002 w
.63307 .29239 m .65514 .32812 L .66988 .33842 L p
1 g
F P
s
P
p
.002 w
.37546 .27743 m .3449 .31613 L .36316 .30437 L p
1 g
F P
s
P
p
.002 w
.36316 .30437 m .39196 .26818 L .37546 .27743 L p
1 g
F P
s
P
p
.002 w
.63307 .29239 m .59845 .26301 L .59019 .26748 L p
1 g
F P
s
P
p
.002 w
.55501 .25186 m .59019 .26748 L .59845 .26301 L p
1 g
F P
s
P
p
.002 w
.53496 .61442 m .58617 .60413 L .59739 .59003 L p
1 g
F P
s
P
p
.002 w
.64162 .56497 m .59739 .59003 L .58617 .60413 L p
1 g
F P
s
P
p
.002 w
.59739 .59003 m .64162 .56497 L .65059 .54647 L p
1 g
F P
s
P
p
.002 w
.59845 .26301 m .55542 .24389 L .55501 .25186 L p
1 g
F P
s
P
p
.002 w
.47323 .62012 m .52463 .62341 L .53496 .61442 L p
1 g
F P
s
P
p
.002 w
.58617 .60413 m .53496 .61442 L .52463 .62341 L p
1 g
F P
s
P
p
.002 w
.69589 .41857 m .68478 .4652 L .68552 .48694 L p
1 g
F P
s
P
p
.002 w
.68478 .4652 m .69589 .41857 L .6894 .39935 L p
1 g
F P
s
P
p
.002 w
.31992 .34996 m .30866 .39767 L .31892 .37886 L p
1 g
F P
s
P
p
.002 w
.31892 .37886 m .33029 .3314 L .31992 .34996 L p
1 g
F P
s
P
p
.002 w
.50089 .23335 m .45102 .24149 L .46635 .24448 L p
1 g
F P
s
P
p
.002 w
.46635 .24448 m .50944 .23751 L .50089 .23335 L p
1 g
F P
s
P
p
.002 w
.43646 .24363 m .39196 .26818 L .41078 .26358 L p
1 g
F P
s
P
p
.002 w
.41078 .26358 m .45102 .24149 L .43646 .24363 L p
1 g
F P
s
P
p
.002 w
.68117 .50784 m .65059 .54647 L .64162 .56497 L p
1 g
F P
s
P
p
.002 w
.65059 .54647 m .68117 .50784 L .68552 .48694 L p
1 g
F P
s
P
p
.002 w
.31673 .50374 m .3404 .54409 L .33736 .52925 L p
1 g
F P
s
P
p
.002 w
.33736 .52925 m .31186 .48559 L .31673 .50374 L p
1 g
F P
s
P
p
.002 w
.38068 .58729 m .42164 .61064 L .42253 .60476 L p
1 g
F P
s
P
p
.002 w
.42253 .60476 m .3769 .57871 L .38068 .58729 L p
1 g
F P
s
P
p
.002 w
.47323 .62012 m .42253 .60476 L .42164 .61064 L p
1 g
F P
s
P
p
.002 w
.30331 .4394 m .31186 .48559 L .31222 .4666 L p
1 g
F P
s
P
p
.002 w
.31222 .4666 m .30332 .41801 L .30331 .4394 L p
1 g
F P
s
P
p
.002 w
.42164 .61064 m .46715 .62444 L .47323 .62012 L p
1 g
F P
s
P
p
.002 w
.52463 .62341 m .47323 .62012 L .46715 .62444 L p
1 g
F P
s
P
p
.002 w
.66988 .33842 m .64448 .29709 L .63307 .29239 L p
1 g
F P
s
P
p
.002 w
.59845 .26301 m .63307 .29239 L .64448 .29709 L p
1 g
F P
s
P
p
.002 w
.68049 .35164 m .6894 .39935 L .69589 .41857 L p
1 g
F P
s
P
p
.002 w
.6894 .39935 m .68049 .35164 L .66988 .33842 L p
1 g
F P
s
P
p
.002 w
.34802 .55636 m .38068 .58729 L .3769 .57871 L p
1 g
F P
s
P
p
.002 w
.3769 .57871 m .3404 .54409 L .34802 .55636 L p
1 g
F P
s
P
p
.002 w
.36186 .29133 m .33029 .3314 L .3449 .31613 L p
1 g
F P
s
P
p
.002 w
.3449 .31613 m .37546 .27743 L .36186 .29133 L p
1 g
F P
s
P
p
.002 w
.64448 .29709 m .66988 .33842 L .68049 .35164 L p
1 g
F P
s
P
p
.002 w
.55432 .24074 m .50089 .23335 L .50944 .23751 L p
1 g
F P
s
P
p
.002 w
.50944 .23751 m .55542 .24389 L .55432 .24074 L p
1 g
F P
s
P
p
.002 w
.52463 .62341 m .57216 .61397 L .58617 .60413 L p
1 g
F P
s
P
p
.002 w
.62842 .58038 m .58617 .60413 L .57216 .61397 L p
1 g
F P
s
P
p
.002 w
.58617 .60413 m .62842 .58038 L .64162 .56497 L p
1 g
F P
s
P
p
.002 w
.69716 .43878 m .68552 .48694 L .68117 .50784 L p
1 g
F P
s
P
p
.002 w
.68552 .48694 m .69716 .43878 L .69589 .41857 L p
1 g
F P
s
P
p
.002 w
.3143 .37142 m .30332 .41801 L .30866 .39767 L p
1 g
F P
s
P
p
.002 w
.30866 .39767 m .31992 .34996 L .3143 .37142 L p
1 g
F P
s
P
p
.002 w
.64448 .29709 m .60435 .26298 L .59845 .26301 L p
1 g
F P
s
P
p
.002 w
.55542 .24389 m .59845 .26301 L .60435 .26298 L p
1 g
F P
s
P
p
.002 w
.46715 .62444 m .5132 .62742 L .52463 .62341 L p
1 g
F P
s
P
p
.002 w
.57216 .61397 m .52463 .62341 L .5132 .62742 L p
1 g
F P
s
P
p
.002 w
.60435 .26298 m .55432 .24074 L .55542 .24389 L p
1 g
F P
s
P
p
.002 w
.42311 .25115 m .37546 .27743 L .39196 .26818 L p
1 g
F P
s
P
p
.002 w
.39196 .26818 m .43646 .24363 L .42311 .25115 L p
1 g
F P
s
P
p
.002 w
.49195 .23457 m .43646 .24363 L .45102 .24149 L p
1 g
F P
s
P
p
.002 w
.45102 .24149 m .50089 .23335 L .49195 .23457 L p
1 g
F P
s
P
p
.002 w
.64162 .56497 m .67161 .52728 L .68117 .50784 L p
1 g
F P
s
P
p
.002 w
.67161 .52728 m .64162 .56497 L .62842 .58038 L p
1 g
F P
s
P
p
.004 w
.68492 .64831 m
.68962 .65385 L
s
P
p
.002 w
.32697 .52047 m .34802 .55636 L .3404 .54409 L p
1 g
F P
s
P
p
.002 w
.3404 .54409 m .31673 .50374 L .32697 .52047 L p
1 g
F P
s
P
p
.002 w
.3089 .46124 m .31673 .50374 L .31186 .48559 L p
1 g
F P
s
P
p
.002 w
.31186 .48559 m .30331 .4394 L .3089 .46124 L p
1 g
F P
s
P
p
.002 w
.69589 .41857 m .68645 .36757 L .68049 .35164 L p
1 g
F P
s
P
p
.002 w
.68645 .36757 m .69589 .41857 L .69716 .43878 L p
1 g
F P
s
P
p
.002 w
.38798 .59183 m .4229 .61173 L .42164 .61064 L p
1 g
F P
s
P
p
.002 w
.42164 .61064 m .38068 .58729 L .38798 .59183 L p
1 g
F P
s
P
p
.002 w
.46715 .62444 m .42164 .61064 L .4229 .61173 L p
1 g
F P
s
P
p
.002 w
.35174 .30972 m .31992 .34996 L .33029 .3314 L p
1 g
F P
s
P
p
.002 w
.33029 .3314 m .36186 .29133 L .35174 .30972 L p
1 g
F P
s
P
p
.002 w
.68049 .35164 m .65233 .30573 L .64448 .29709 L p
1 g
F P
s
P
p
.002 w
.60435 .26298 m .64448 .29709 L .65233 .30573 L p
1 g
F P
s
P
p
.002 w
.4229 .61173 m .46173 .62351 L .46715 .62444 L p
1 g
F P
s
P
p
.002 w
.5132 .62742 m .46715 .62444 L .46173 .62351 L p
1 g
F P
s
P
p
.002 w
.65233 .30573 m .68049 .35164 L .68645 .36757 L p
1 g
F P
s
P
p
.002 w
.68117 .50784 m .69289 .45946 L .69716 .43878 L p
1 g
F P
s
P
p
.002 w
.69289 .45946 m .68117 .50784 L .67161 .52728 L p
1 g
F P
s
P
p
.002 w
.36025 .56554 m .38798 .59183 L .38068 .58729 L p
1 g
F P
s
P
p
.002 w
.38068 .58729 m .34802 .55636 L .36025 .56554 L p
1 g
F P
s
P
p
.002 w
.31384 .39528 m .30331 .4394 L .30332 .41801 L p
1 g
F P
s
P
p
.002 w
.30332 .41801 m .3143 .37142 L .31384 .39528 L p
1 g
F P
s
P
p
.002 w
.5132 .62742 m .55559 .61903 L .57216 .61397 L p
1 g
F P
s
P
p
.002 w
.57216 .61397 m .61114 .5921 L .62842 .58038 L p
1 g
F P
s
P
p
.002 w
.61114 .5921 m .57216 .61397 L .55559 .61903 L p
1 g
F P
s
P
p
.002 w
.55162 .24284 m .49195 .23457 L .50089 .23335 L p
1 g
F P
s
P
p
.002 w
.50089 .23335 m .55432 .24074 L .55162 .24284 L p
1 g
F P
s
P
p
.002 w
.41145 .26413 m .36186 .29133 L .37546 .27743 L p
1 g
F P
s
P
p
.002 w
.37546 .27743 m .42311 .25115 L .41145 .26413 L p
1 g
F P
s
P
p
.002 w
.46173 .62351 m .50092 .62604 L .5132 .62742 L p
1 g
F P
s
P
p
.002 w
.55559 .61903 m .5132 .62742 L .50092 .62604 L p
1 g
F P
s
P
p
.002 w
.65686 .54461 m .62842 .58038 L .61114 .5921 L p
1 g
F P
s
P
p
.002 w
.62842 .58038 m .65686 .54461 L .67161 .52728 L p
1 g
F P
s
P
p
.002 w
.65233 .30573 m .60755 .2677 L .60435 .26298 L p
1 g
F P
s
P
p
.002 w
.55432 .24074 m .60435 .26298 L .60755 .2677 L p
1 g
F P
s
P
p
.002 w
.60755 .2677 m .55162 .24284 L .55432 .24074 L p
1 g
F P
s
P
p
.002 w
.48286 .24147 m .42311 .25115 L .43646 .24363 L p
1 g
F P
s
P
p
.002 w
.43646 .24363 m .49195 .23457 L .48286 .24147 L p
1 g
F P
s
P
p
.002 w
.32019 .4829 m .32697 .52047 L .31673 .50374 L p
1 g
F P
s
P
p
.002 w
.31673 .50374 m .3089 .46124 L .32019 .4829 L p
1 g
F P
s
P
p
.002 w
.68731 .38591 m .69716 .43878 L .69289 .45946 L p
1 g
F P
s
P
p
.002 w
.69716 .43878 m .68731 .38591 L .68645 .36757 L p
1 g
F P
s
P
p
.002 w
.34255 .5352 m .36025 .56554 L .34802 .55636 L p
1 g
F P
s
P
p
.002 w
.34802 .55636 m .32697 .52047 L .34255 .5352 L p
1 g
F P
s
P
p
.002 w
.3456 .33224 m .3143 .37142 L .31992 .34996 L p
1 g
F P
s
P
p
.002 w
.31992 .34996 m .35174 .30972 L .3456 .33224 L p
1 g
F P
s
P
p
.002 w
.68292 .48 m .67161 .52728 L .65686 .54461 L p
1 g
F P
s
P
p
.002 w
.67161 .52728 m .68292 .48 L .69289 .45946 L p
1 g
F P
s
P
p
.002 w
.39881 .59193 m .42643 .60768 L .4229 .61173 L p
1 g
F P
s
P
p
.002 w
.4229 .61173 m .38798 .59183 L .39881 .59193 L p
1 g
F P
s
P
p
.002 w
.46173 .62351 m .4229 .61173 L .42643 .60768 L p
1 g
F P
s
P
p
.002 w
.68645 .36757 m .65614 .3183 L .65233 .30573 L p
1 g
F P
s
P
p
.002 w
.60755 .2677 m .65233 .30573 L .65614 .3183 L p
1 g
F P
s
P
p
.002 w
.31881 .42088 m .3089 .46124 L .30331 .4394 L p
1 g
F P
s
P
p
.002 w
.30331 .4394 m .31384 .39528 L .31881 .42088 L p
1 g
F P
s
P
p
.002 w
.65614 .3183 m .68645 .36757 L .68731 .38591 L p
1 g
F P
s
P
p
.002 w
.42643 .60768 m .45717 .617 L .46173 .62351 L p
1 g
F P
s
P
p
.004 w
.42145 .64177 m
.43025 .61809 L
s
P
p
.002 w
.50092 .62604 m .46173 .62351 L .45717 .617 L p
1 g
F P
s
P
p
.002 w
.50092 .62604 m .5368 .61889 L .55559 .61903 L p
1 g
F P
s
P
p
.002 w
.59009 .59959 m .55559 .61903 L .5368 .61889 L p
1 g
F P
s
P
p
.002 w
.55559 .61903 m .59009 .59959 L .61114 .5921 L p
1 g
F P
s
P
p
.002 w
.377 .57117 m .39881 .59193 L .38798 .59183 L p
1 g
F P
s
P
p
.002 w
.38798 .59183 m .36025 .56554 L .377 .57117 L p
1 g
F P
s
P
p
.002 w
.63711 .55919 m .61114 .5921 L .59009 .59959 L p
1 g
F P
s
P
p
.002 w
.61114 .5921 m .63711 .55919 L .65686 .54461 L p
1 g
F P
s
P
p
.002 w
.54731 .25047 m .48286 .24147 L .49195 .23457 L p
1 g
F P
s
P
p
.002 w
.49195 .23457 m .55162 .24284 L .54731 .25047 L p
1 g
F P
s
P
p
.002 w
.40197 .28247 m .35174 .30972 L .36186 .29133 L p
1 g
F P
s
P
p
.002 w
.36186 .29133 m .41145 .26413 L .40197 .28247 L p
1 g
F P
s
P
p
.002 w
.45717 .617 m .48812 .61897 L .50092 .62604 L p
1 g
F P
s
P
p
.002 w
.5368 .61889 m .50092 .62604 L .48812 .61897 L p
1 g
F P
s
P
p
.002 w
.4739 .2542 m .41145 .26413 L .42311 .25115 L p
1 g
F P
s
P
p
.002 w
.42311 .25115 m .48286 .24147 L .4739 .2542 L p
1 g
F P
s
P
p
.002 w
.65614 .3183 m .60778 .27732 L .60755 .2677 L p
1 g
F P
s
P
p
.002 w
.55162 .24284 m .60755 .2677 L .60778 .27732 L p
1 g
F P
s
P
p
.002 w
.68275 .40621 m .69289 .45946 L .68292 .48 L p
1 g
F P
s
P
p
.002 w
.69289 .45946 m .68275 .40621 L .68731 .38591 L p
1 g
F P
s
P
p
.002 w
.33709 .50365 m .34255 .5352 L .32697 .52047 L p
1 g
F P
s
P
p
.002 w
.32697 .52047 m .32019 .4829 L .33709 .50365 L p
1 g
F P
s
P
p
.002 w
.34383 .35836 m .31384 .39528 L .3143 .37142 L p
1 g
F P
s
P
p
.002 w
.3143 .37142 m .3456 .33224 L .34383 .35836 L p
1 g
F P
s
P
p
.002 w
.60778 .27732 m .54731 .25047 L .55162 .24284 L p
1 g
F P
s
P
p
.002 w
.36326 .54735 m .377 .57117 L .36025 .56554 L p
1 g
F P
s
P
p
.002 w
.36025 .56554 m .34255 .5352 L .36326 .54735 L p
1 g
F P
s
P
p
.002 w
.6673 .49975 m .65686 .54461 L .63711 .55919 L p
1 g
F P
s
P
p
.002 w
.65686 .54461 m .6673 .49975 L .68292 .48 L p
1 g
F P
s
P
p
.002 w
.32927 .44747 m .32019 .4829 L .3089 .46124 L p
1 g
F P
s
P
p
.002 w
.3089 .46124 m .31881 .42088 L .32927 .44747 L p
1 g
F P
s
P
p
.002 w
.65556 .33464 m .68731 .38591 L .68275 .40621 L p
1 g
F P
s
P
p
.002 w
.68731 .38591 m .65556 .33464 L .65614 .3183 L p
1 g
F P
s
P
p
.002 w
.60778 .27732 m .65614 .3183 L .65556 .33464 L p
1 g
F P
s
P
p
.002 w
.48812 .61897 m .51628 .61326 L .5368 .61889 L p
1 g
F P
s
P
p
.002 w
.56575 .60241 m .5368 .61889 L .51628 .61326 L p
1 g
F P
s
P
p
.002 w
.5368 .61889 m .56575 .60241 L .59009 .59959 L p
1 g
F P
s
P
p
.002 w
.41305 .5873 m .43226 .59829 L .42643 .60768 L p
1 g
F P
s
P
p
.002 w
.42643 .60768 m .39881 .59193 L .41305 .5873 L p
1 g
F P
s
P
p
.002 w
.45717 .617 m .42643 .60768 L .43226 .59829 L p
1 g
F P
s
P
p
.002 w
.61276 .57043 m .59009 .59959 L .56575 .60241 L p
1 g
F P
s
P
p
.002 w
.59009 .59959 m .61276 .57043 L .63711 .55919 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.6171 .56843 L
s
P
p
.004 w
.62717 .58029 m
.62937 .58288 L
s
P
p
.004 w
.62161 .57374 m
.62254 .57484 L
s
P
p
.004 w
.62254 .57484 m
.62717 .58029 L
s
P
p
.004 w
.62937 .58288 m
.63623 .59097 L
s
P
p
.004 w
.63623 .59097 m
.68492 .64831 L
s
P
p
.002 w
.43226 .59829 m .45366 .60477 L .45717 .617 L p
1 g
F P
s
P
p
.002 w
.48812 .61897 m .45717 .617 L .45366 .60477 L p
1 g
F P
s
P
p
.002 w
.39509 .30585 m .3456 .33224 L .35174 .30972 L p
1 g
F P
s
P
p
.002 w
.35174 .30972 m .40197 .28247 L .39509 .30585 L p
1 g
F P
s
P
p
.002 w
.39799 .57287 m .41305 .5873 L .39881 .59193 L p
1 g
F P
s
P
p
.002 w
.39881 .59193 m .377 .57117 L .39799 .57287 L p
1 g
F P
s
P
p
.002 w
.54142 .26374 m .4739 .2542 L .48286 .24147 L p
1 g
F P
s
P
p
.002 w
.48286 .24147 m .54731 .25047 L .54142 .26374 L p
1 g
F P
s
P
p
.002 w
.67264 .42791 m .68292 .48 L .6673 .49975 L p
1 g
F P
s
P
p
.002 w
.68292 .48 m .67264 .42791 L .68275 .40621 L p
1 g
F P
s
P
p
.002 w
.34669 .38735 m .31881 .42088 L .31384 .39528 L p
1 g
F P
s
P
p
.002 w
.31384 .39528 m .34383 .35836 L .34669 .38735 L p
1 g
F P
s
P
p
.002 w
.35926 .52278 m .36326 .54735 L .34255 .5352 L p
1 g
F P
s
P
p
.002 w
.34255 .5352 m .33709 .50365 L .35926 .52278 L p
1 g
F P
s
P
p
.002 w
.45366 .60477 m .47516 .60608 L .48812 .61897 L p
1 g
F P
s
P
p
.002 w
.51628 .61326 m .48812 .61897 L .47516 .60608 L p
1 g
F P
s
P
p
.002 w
.46538 .27268 m .40197 .28247 L .41145 .26413 L p
1 g
F P
s
P
p
.002 w
.41145 .26413 m .4739 .2542 L .46538 .27268 L p
1 g
F P
s
P
p
.002 w
.64628 .51801 m .63711 .55919 L .61276 .57043 L p
1 g
F P
s
P
p
.002 w
.63711 .55919 m .64628 .51801 L .6673 .49975 L p
1 g
F P
s
P
p
.002 w
.65556 .33464 m .60484 .29187 L .60778 .27732 L p
1 g
F P
s
P
p
.002 w
.54731 .25047 m .60778 .27732 L .60484 .29187 L p
1 g
F P
s
P
p
.002 w
.34507 .47417 m .33709 .50365 L .32019 .4829 L p
1 g
F P
s
P
p
.002 w
.32019 .4829 m .32927 .44747 L .34507 .47417 L p
1 g
F P
s
P
p
.002 w
.38865 .55641 m .39799 .57287 L .377 .57117 L p
1 g
F P
s
P
p
.002 w
.377 .57117 m .36326 .54735 L .38865 .55641 L p
1 g
F P
s
P
p
.002 w
.60484 .29187 m .54142 .26374 L .54731 .25047 L p
1 g
F P
s
P
p
.002 w
.65034 .35444 m .68275 .40621 L .67264 .42791 L p
1 g
F P
s
P
p
.002 w
.68275 .40621 m .65034 .35444 L .65556 .33464 L p
1 g
F P
s
P
p
.002 w
.51628 .61326 m .53875 .60024 L .56575 .60241 L p
1 g
F P
s
P
p
.002 w
.58445 .57783 m .56575 .60241 L .53875 .60024 L p
1 g
F P
s
P
p
.002 w
.56575 .60241 m .58445 .57783 L .61276 .57043 L p
1 g
F P
s
P
p
.002 w
.47516 .60608 m .49458 .60204 L .51628 .61326 L p
1 g
F P
s
P
p
.002 w
.53875 .60024 m .51628 .61326 L .49458 .60204 L p
1 g
F P
s
P
p
.002 w
.39117 .3337 m .34383 .35836 L .3456 .33224 L p
1 g
F P
s
P
p
.002 w
.3456 .33224 m .39509 .30585 L .39117 .3337 L p
1 g
F P
s
P
p
.002 w
.60484 .29187 m .65556 .33464 L .65034 .35444 L p
1 g
F P
s
P
p
.002 w
.35424 .41829 m .32927 .44747 L .31881 .42088 L p
1 g
F P
s
P
p
.002 w
.31881 .42088 m .34669 .38735 L .35424 .41829 L p
1 g
F P
s
P
p
.002 w
.65707 .45034 m .6673 .49975 L .64628 .51801 L p
1 g
F P
s
P
p
.002 w
.6673 .49975 m .65707 .45034 L .67264 .42791 L p
1 g
F P
s
P
p
.002 w
.43044 .57783 m .44034 .58351 L .43226 .59829 L p
1 g
F P
s
P
p
.002 w
.43226 .59829 m .41305 .5873 L .43044 .57783 L p
1 g
F P
s
P
p
.002 w
.45366 .60477 m .43226 .59829 L .44034 .58351 L p
1 g
F P
s
P
p
.002 w
.44034 .58351 m .4514 .58685 L .45366 .60477 L p
1 g
F P
s
P
p
.002 w
.47516 .60608 m .45366 .60477 L .4514 .58685 L p
1 g
F P
s
P
p
.002 w
.38614 .53957 m .38865 .55641 L .36326 .54735 L p
1 g
F P
s
P
p
.002 w
.36326 .54735 m .35926 .52278 L .38614 .53957 L p
1 g
F P
s
P
p
.002 w
.62037 .5341 m .61276 .57043 L .58445 .57783 L p
1 g
F P
s
P
p
.002 w
.61276 .57043 m .62037 .5341 L .64628 .51801 L p
1 g
F P
s
P
p
.002 w
.42273 .57037 m .43044 .57783 L .41305 .5873 L p
1 g
F P
s
P
p
.002 w
.41305 .5873 m .39799 .57287 L .42273 .57037 L p
1 g
F P
s
P
p
.002 w
.36582 .50004 m .35926 .52278 L .33709 .50365 L p
1 g
F P
s
P
p
.002 w
.33709 .50365 m .34507 .47417 L .36582 .50004 L p
1 g
F P
s
P
p
.002 w
.53405 .28254 m .46538 .27268 L .4739 .2542 L p
1 g
F P
s
P
p
.002 w
.4739 .2542 m .54142 .26374 L .53405 .28254 L p
1 g
F P
s
P
p
.002 w
.45762 .29658 m .39509 .30585 L .40197 .28247 L p
1 g
F P
s
P
p
.002 w
.40197 .28247 m .46538 .27268 L .45762 .29658 L p
1 g
F P
s
P
p
.002 w
.4514 .58685 m .46248 .58749 L .47516 .60608 L p
1 g
F P
s
P
p
.002 w
.49458 .60204 m .47516 .60608 L .46248 .58749 L p
1 g
F P
s
P
p
.002 w
.41804 .56192 m .42273 .57037 L .39799 .57287 L p
1 g
F P
s
P
p
.002 w
.39799 .57287 m .38865 .55641 L .41804 .56192 L p
1 g
F P
s
P
p
.002 w
.49458 .60204 m .5099 .59296 L .53875 .60024 L p
1 g
F P
s
P
p
.002 w
.55299 .58098 m .53875 .60024 L .5099 .59296 L p
1 g
F P
s
P
p
.002 w
.53875 .60024 m .55299 .58098 L .58445 .57783 L p
1 g
F P
s
P
p
.002 w
.65034 .35444 m .59864 .31113 L .60484 .29187 L p
1 g
F P
s
P
p
.002 w
.54142 .26374 m .60484 .29187 L .59864 .31113 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.64042 .3772 m .67264 .42791 L .65707 .45034 L p
1 g
F P
s
P
p
.002 w
.67264 .42791 m .64042 .3772 L .65034 .35444 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.39048 .36517 m .34669 .38735 L .34383 .35836 L p
1 g
F P
s
P
p
.002 w
.34383 .35836 m .39117 .3337 L .39048 .36517 L p
1 g
F P
s
P
p
.002 w
.59864 .31113 m .53405 .28254 L .54142 .26374 L p
1 g
F P
s
P
p
.002 w
.46248 .58749 m .47241 .58535 L .49458 .60204 L p
1 g
F P
s
P
p
.002 w
.5099 .59296 m .49458 .60204 L .47241 .58535 L p
1 g
F P
s
P
p
.002 w
.36635 .45013 m .34507 .47417 L .32927 .44747 L p
1 g
F P
s
P
p
.002 w
.32927 .44747 m .35424 .41829 L .36635 .45013 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.63633 .47275 m .64628 .51801 L .62037 .5341 L p
1 g
F P
s
P
p
.002 w
.64628 .51801 m .63633 .47275 L .65707 .45034 L p
1 g
F P
s
P
p
.002 w
.59031 .54738 m .58445 .57783 L .55299 .58098 L p
1 g
F P
s
P
p
.002 w
.58445 .57783 m .59031 .54738 L .62037 .5341 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.46128 .53463 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.59864 .31113 m .65034 .35444 L .64042 .3772 L p
1 g
F P
s
P
p
.002 w
.39091 .52414 m .38614 .53957 L .35926 .52278 L p
1 g
F P
s
P
p
.002 w
.35926 .52278 m .36582 .50004 L .39091 .52414 L p
1 g
F P
s
P
p
.002 w
.4169 .55335 m .41804 .56192 L .38865 .55641 L p
1 g
F P
s
P
p
.002 w
.38865 .55641 m .38614 .53957 L .4169 .55335 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.44034 .58351 m .43044 .57783 L .45053 .56356 L closepath p
1 g
F P
s
P
p
.002 w
.4514 .58685 m .44034 .58351 L .45052 .56357 L p
1 g
F P
s
P
p
.002 w
.45053 .56357 m .4514 .58685 L p
.45052 .56357 L 1 g
F P
s
P
p
.002 w
.46248 .58749 m .4514 .58685 L .45053 .56357 L p
1 g
F P
s
P
p
.002 w
.45053 .56357 m .45053 .56356 L .45054 .56358 L p
1 g
F P
s
P
p
.002 w
.45054 .56358 m .46248 .58749 L p
.45053 .56357 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4506 .56361 L p
1 g
F P
s
P
p
.46872 .57265 m .4506 .56361 L .45061 .56362 L 1 g
F
P
p
.002 w
.479 .58133 m .47241 .58535 L .45805 .57105 L p
1 g
F P
s
P
p
.002 w
.42556 .53948 m .4309 .53725 L p
.4384 .5473 L 1 g
F P
s
P
p
.002 w
.44091 .55428 m .42556 .53948 L p
.4384 .5473 L 1 g
F P
s
P
p
.002 w
.43839 .54728 m .43925 .54566 L p
.43426 .53579 L 1 g
F P
s
P
p
.002 w
.43427 .53584 m .42556 .53948 L p
.43418 .53549 L 1 g
F P
s
P
p
.43426 .53579 m .43424 .53576 L .43427 .53584 L 1 g
F
P
p
.43426 .53579 m .43427 .53584 L .43839 .54728 L 1 g
F
P
p
.002 w
.42556 .53948 m .40265 .51186 L p
.43418 .53549 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43245 .52881 L p
1 g
F P
s
P
p
.42025 .50421 m .42881 .51464 L .43245 .52881 L 1 g
F
P
p
.002 w
.43387 .53432 m .4323 .53085 L p
.43245 .52881 L 1 g
F P
s
P
p
.002 w
.4323 .53085 m .42025 .50421 L p
.43245 .52881 L 1 g
F P
s
P
p
.002 w
.43245 .52881 m .43346 .52734 L p
.43318 .51918 L 1 g
F P
s
P
p
.43925 .54566 m .43245 .52881 L .43349 .53282 L 1 g
F
P
p
.002 w
.40265 .51186 m .42025 .50421 L .4323 .53085 L p
1 g
F P
s
P
p
.002 w
.4323 .53085 m .43387 .53432 L p
.43216 .53309 L 1 g
F P
s
P
p
.40265 .51186 m .4323 .53085 L .43216 .53309 L 1 g
F
P
p
.43925 .54566 m .43346 .53276 L .43426 .53579 L 1 g
F
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43245 .52881 m .44537 .53482 L .43387 .53432 L 1 g
F
P
p
.42881 .51464 m .43312 .51989 L .43245 .52881 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43391 .50937 L p
1 g
F P
s
P
p
.002 w
.42025 .50421 m .4344 .50288 L p
.43391 .50937 L 1 g
F P
s
P
p
.43051 .51671 m .43391 .50937 L .43312 .51989 L 1 g
F
P
p
.42025 .50421 m .43391 .50937 L .43051 .51671 L 1 g
F
P
p
.002 w
.43391 .50937 m .43485 .50826 L p
.43877 .49911 L 1 g
F P
s
P
p
.002 w
.42025 .50421 m .4083 .47009 L p
.43871 .49923 L 1 g
F P
s
P
p
.002 w
.43704 .50263 m .42025 .50421 L p
.43871 .49923 L 1 g
F P
s
P
p
.43877 .49911 m .43704 .50263 L .43391 .50937 L 1 g
F
P
p
.002 w
.4083 .47009 m .43998 .46681 L .44136 .49379 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.4083 .47009 m .44136 .49379 L .43871 .49923 L 1 g
F
P
p
.43346 .52734 m .43391 .50937 L .43318 .51918 L 1 g
F
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.43391 .50937 m .4418 .50219 L .43312 .51989 L 1 g
F
P
p
.002 w
.4344 .50288 m .43704 .50263 L p
.43391 .50937 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44257 .49137 L p
1 g
F P
s
P
p
.43998 .46681 m .44828 .47994 L .44257 .49137 L 1 g
F
P
p
.002 w
.44136 .49379 m .4413 .4926 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.4413 .4926 m .43998 .46681 L p
.44257 .49137 L 1 g
F P
s
P
p
.002 w
.44257 .49137 m .44198 .492 L p
.43996 .49661 L 1 g
F P
s
P
p
.43485 .50826 m .44257 .49137 L .43996 .49661 L 1 g
F
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44257 .49137 m .44339 .4905 L p
.44945 .48469 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44257 .49137 m .46483 .50611 L .44136 .49379 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45773 .47666 L p
1 g
F P
s
P
p
.44339 .4905 m .45773 .47666 L .44945 .48469 L 1 g
F
P
p
.44828 .47994 m .45059 .48359 L .44257 .49137 L 1 g
F
P
p
.45059 .48359 m .46483 .50611 L .44257 .49137 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47398 .47247 m .46483 .50611 L p
.44884 .48082 L 1 g
F P
s
P
p
.002 w
.45773 .47666 m .45826 .47608 L p
.46929 .47124 L 1 g
F P
s
P
p
.002 w
.47398 .47247 m .46861 .47157 L p
.47197 .46995 L 1 g
F P
s
P
p
.46929 .47124 m .46963 .47109 L .46861 .47157 L 1 g
F
P
p
.46929 .47124 m .46861 .47157 L .45773 .47666 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.50617 .48647 m .47398 .47247 L .47513 .46843 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47752 .46723 L p
1 g
F P
s
P
p
.45826 .47608 m .47752 .46723 L .47644 .46777 L 1 g
F
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.47752 .46723 m .50617 .48647 L .47513 .46843 L 1 g
F
P
p
.002 w
.47752 .46723 m .47786 .46667 L p
.48718 .46572 L 1 g
F P
s
P
p
.49623 .46431 m .50617 .48647 L .47752 .46723 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46373 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46373 L .48718 .46572 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46715 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.52243 .46715 m .53259 .50707 L .51858 .46666 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54219 .47657 L p
1 g
F P
s
P
p
.52214 .46667 m .54219 .47657 L .53052 .47101 L 1 g
F
P
p
.52759 .46961 m .53259 .50707 L .52243 .46715 L 1 g
F
P
p
.002 w
.52243 .46715 m .52214 .46667 L p
.53052 .47101 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56582 .50906 L p
1 g
F P
s
P
p
.55661 .4905 m .56582 .50906 L .56078 .49849 L 1 g
F
P
p
.002 w
.55967 .48219 m .58196 .51421 L .58141 .51451 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56729 .52844 L p
1 g
F P
s
P
p
.56515 .50826 m .56729 .52844 L .56717 .52446 L 1 g
F
P
p
.58196 .51421 m .56764 .53903 L .56729 .52844 L 1 g
F
P
p
.002 w
.5671 .52238 m .56962 .52099 L p
.56729 .52844 L 1 g
F P
s
P
p
.002 w
.56962 .52099 m .58196 .51421 L p
.56729 .52844 L 1 g
F P
s
P
p
.002 w
.56729 .52844 m .56654 .52734 L p
.56499 .53584 L 1 g
F P
s
P
p
.56515 .50826 m .56717 .52446 L .56672 .51846 L 1 g
F
P
p
.56717 .52446 m .56774 .52909 L .5671 .52238 L 1 g
F
P
p
.56717 .52446 m .5671 .52238 L .56672 .51846 L 1 g
F
P
p
.002 w
.55299 .58098 m .5335 .5802 L p
.5552 .55913 L 1 g
F P
s
P
p
.002 w
.54919 .56304 m .54854 .56129 L p
.54138 .56811 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .55335 .55849 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.5335 .5802 m .5194 .57965 L p
.52242 .57785 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58076 L p
1 g
F P
s
P
p
.002 w
.5099 .59296 m .49061 .58496 L p
.51334 .58077 L 1 g
F P
s
P
p
.002 w
.5194 .57965 m .5186 .58077 L p
.51334 .58077 L 1 g
F P
s
P
p
.002 w
.5186 .58077 m .5099 .59296 L p
.51334 .58077 L 1 g
F P
s
P
p
.002 w
.51095 .58076 m .51079 .57862 L p
.50009 .58076 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58076 L .51616 .57969 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58076 L p
1 g
F P
s
P
p
.002 w
.49061 .58496 m .48045 .58075 L p
.48775 .58076 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58076 L .50009 .58076 L 1 g
F
P
p
.002 w
.48905 .58076 m .48921 .57862 L p
.48093 .57904 L 1 g
F P
s
P
p
.002 w
.48118 .57913 m .48015 .58063 L .4721 .57599 L p
1 g
F P
s
P
p
.48093 .57904 m .48079 .57905 L .48118 .57913 L 1 g
F
P
p
.48093 .57904 m .48118 .57913 L .48905 .58076 L 1 g
F
P
p
.48921 .57862 m .47664 .57759 L .48079 .57905 L 1 g
F
P
p
.002 w
.45053 .56356 m .45055 .56357 L p
.45056 .56357 L 1 g
F P
s
P
p
.002 w
.45053 .56356 m .44091 .55428 L p
.4384 .5473 L 1 g
F P
s
P
p
.002 w
.45048 .56347 m .45053 .56356 L p
.4309 .53725 L 1 g
F P
s
P
p
.002 w
.4506 .56361 m .45146 .56129 L p
.44531 .55659 L 1 g
F P
s
P
p
.44531 .55659 m .44417 .55571 L .45044 .56343 L 1 g
F
P
p
.44531 .55659 m .45044 .56343 L .4506 .56361 L 1 g
F
P
p
.44417 .55571 m .45041 .56339 L .4506 .56361 L 1 g
F
P
p
.44344 .55516 m .45046 .56346 L .4506 .56361 L 1 g
F
P
p
.44258 .5545 m .4505 .56351 L .4506 .56361 L 1 g
F
P
p
.45146 .56129 m .44403 .55483 L .44537 .55664 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43451 .53574 m .44537 .53482 L .45052 .56353 L p
1 g
F P
s
P
p
.002 w
.45052 .56353 m .45053 .56356 L .45048 .56347 L p
1 g
F P
s
P
p
.002 w
.45048 .56347 m .43451 .53574 L p
.45052 .56353 L 1 g
F P
s
P
p
.44165 .55378 m .45053 .56355 L .4506 .56361 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46787 .54156 m .47697 .54848 L .45054 .56355 L p
1 g
F P
s
P
p
.002 w
.45054 .56355 m .45053 .56356 L .45053 .56355 L p
1 g
F P
s
P
p
.002 w
.45053 .56355 m .46787 .54156 L p
.45054 .56355 L 1 g
F P
s
P
p
.44417 .55571 m .44344 .55516 L .45041 .56339 L 1 g
F
P
p
.44344 .55516 m .44258 .5545 L .45046 .56346 L 1 g
F
P
p
.002 w
.47697 .54848 m .4832 .55679 L .45054 .56356 L p
1 g
F P
s
P
p
.002 w
.45054 .56356 m .45053 .56356 L .45054 .56355 L p
1 g
F P
s
P
p
.002 w
.45054 .56355 m .47697 .54848 L p
.45054 .56356 L 1 g
F P
s
P
p
.44081 .55315 m .45056 .56358 L .4506 .56361 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.4832 .55679 m .48591 .56555 L .45054 .56356 L p
1 g
F P
s
P
p
.002 w
.45054 .56356 m .45053 .56356 L .45054 .56356 L p
1 g
F P
s
P
p
.002 w
.45054 .56356 m .4832 .55679 L p
.45054 .56356 L 1 g
F P
s
P
p
.44258 .5545 m .44165 .55378 L .4505 .56351 L 1 g
F
P
p
.44165 .55378 m .44081 .55315 L .45053 .56355 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48591 .56555 m .48483 .57379 L .45055 .56357 L p
1 g
F P
s
P
p
.002 w
.45055 .56357 m .45053 .56356 L .45054 .56356 L p
1 g
F P
s
P
p
.002 w
.45054 .56356 m .48591 .56555 L p
.45055 .56357 L 1 g
F P
s
P
p
.002 w
.45805 .57105 m .45082 .56385 L p
.46828 .57465 L 1 g
F P
s
P
p
.46828 .57465 m .45082 .56385 L .4506 .56361 L 1 g
F
P
p
.45855 .56859 m .4506 .56362 L .4578 .56829 L 1 g
F
P
p
.46872 .57265 m .4506 .56362 L .45855 .56859 L 1 g
F
P
p
.4506 .56362 m .4506 .56362 L .45855 .56859 L 1 g
F
P
p
.479 .58133 m .45805 .57105 L .46828 .57465 L 1 g
F
P
p
.002 w
.46812 .5754 m .46872 .57265 L p
.45717 .56803 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46828 .57465 L p
1 g
F P
s
P
p
.002 w
.48015 .58063 m .479 .58133 L p
.4683 .57465 L 1 g
F P
s
P
p
.002 w
.4721 .57599 m .48015 .58063 L p
.4683 .57465 L 1 g
F P
s
P
p
.48921 .57862 m .46828 .57465 L .47664 .57759 L 1 g
F
P
p
.002 w
.45056 .56359 m .45053 .56356 L p
.479 .58133 L 1 g
F P
s
P
p
.002 w
.46828 .57465 m .4678 .57686 L p
.47664 .57759 L 1 g
F P
s
P
p
.002 w
.45053 .56356 m .4721 .57599 L p
.4683 .57465 L 1 g
F P
s
P
p
.002 w
.4721 .57599 m .45056 .56358 L p
.48118 .57913 L 1 g
F P
s
P
p
.002 w
.45056 .56358 m .45053 .56356 L p
.45056 .56357 L 1 g
F P
s
P
p
.48118 .57913 m .45056 .56358 L .45056 .56357 L 1 g
F
P
p
.44081 .55315 m .44028 .55274 L .45056 .56358 L 1 g
F
P
p
.002 w
.45053 .56354 m .45053 .56356 L .45052 .56353 L p
1 g
F P
s
P
p
.002 w
.45053 .56355 m .45053 .56356 L .45053 .56354 L p
1 g
F P
s
P
p
.002 w
.45052 .56357 m .45053 .56356 L .45053 .56357 L p
1 g
F P
s
P
p
.002 w
.43044 .57783 m .42273 .57037 L .45053 .56356 L closepath p
1 g
F P
s
P
p
.002 w
.46248 .58749 m .45053 .56356 L .45082 .56385 L p
1 g
F P
s
P
p
.002 w
.45082 .56385 m .47241 .58535 L .47144 .58556 L p
1 g
F P
s
P
p
.002 w
.47144 .58556 m .46248 .58749 L p
.45082 .56385 L 1 g
F P
s
P
p
.002 w
.42273 .57037 m .41804 .56192 L .45053 .56356 L closepath p
1 g
F P
s
P
p
.002 w
.41804 .56192 m .4169 .55335 L .45053 .56356 L closepath p
1 g
F P
s
P
p
.002 w
.4169 .55335 m .41948 .54558 L .45053 .56356 L closepath p
1 g
F P
s
P
p
.002 w
.41948 .54558 m .42556 .53948 L .45053 .56356 L closepath p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4506 .56361 L p
.45046 .56347 L 1 g
F P
s
P
p
.002 w
.44028 .55274 m .44035 .55283 L p
.45046 .56347 L 1 g
F P
s
P
p
.002 w
.44035 .55283 m .45002 .56518 L p
.45046 .56347 L 1 g
F P
s
P
p
.002 w
.4506 .56361 m .4506 .56361 L p
.45056 .56358 L 1 g
F P
s
P
p
.45056 .56358 m .44028 .55274 L .4506 .56361 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48483 .57379 m .48118 .57913 L p
.45056 .56357 L 1 g
F P
s
P
p
.002 w
.45055 .56357 m .48483 .57379 L p
.45056 .56357 L 1 g
F P
s
P
p
.51595 .57973 m .5 .58302 L .48754 .58044 L 1 g
F
P
p
.5 .58302 m .49061 .58496 L .48754 .58044 L 1 g
F
P
p
.002 w
.48905 .58076 m .48889 .583 L p
.50009 .58076 L 1 g
F P
s
P
p
.48754 .58044 m .48775 .58076 L .48015 .58063 L 1 g
F
P
p
.002 w
.48045 .58075 m .48015 .58063 L p
.48775 .58076 L 1 g
F P
s
P
p
.53128 .57265 m .51616 .57969 L .51773 .57936 L 1 g
F
P
p
.002 w
.5195 .57893 m .5194 .57965 L .51773 .57936 L p
1 g
F P
s
P
p
.5186 .57915 m .51773 .57936 L .5185 .57921 L 1 g
F
P
p
.53128 .57265 m .51773 .57936 L .5186 .57915 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51773 .57936 m .5194 .57965 L p
.51595 .57973 L 1 g
F P
s
P
p
.5194 .57965 m .49061 .58496 L .51595 .57973 L 1 g
F
P
p
.54243 .57044 m .5335 .5802 L .52541 .57849 L 1 g
F
P
p
.53167 .57443 m .52541 .57849 L .52242 .57785 L 1 g
F
P
p
.54243 .57044 m .52541 .57849 L .53167 .57443 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53167 .57443 L p
1 g
F P
s
P
p
.54854 .56129 m .53167 .57443 L .54138 .56811 L 1 g
F
P
p
.002 w
.5099 .59296 m .5194 .57965 L .55299 .58098 L p
1 g
F P
s
P
p
.002 w
.53167 .57443 m .53128 .57265 L p
.51779 .57957 L 1 g
F P
s
P
p
.56075 .54566 m .55335 .55849 L .55394 .55784 L 1 g
F
P
p
.002 w
.5564 .55471 m .55709 .55729 L .55394 .55784 L p
1 g
F P
s
P
p
.55425 .55745 m .55394 .55784 L .55417 .55759 L 1 g
F
P
p
.56075 .54566 m .55394 .55784 L .55425 .55745 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55394 .55784 m .55709 .55729 L p
.5513 .56073 L 1 g
F P
s
P
p
.55709 .55729 m .5335 .5802 L .5513 .56073 L 1 g
F
P
p
.56129 .54768 m .55709 .55729 L .55892 .55091 L 1 g
F
P
p
.56764 .53903 m .55971 .55277 L .56129 .54768 L 1 g
F
P
p
.55971 .55277 m .55709 .55729 L .56129 .54768 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56149 .54705 L p
1 g
F P
s
P
p
.56654 .52734 m .56149 .54705 L .56499 .53584 L 1 g
F
P
p
.56764 .53903 m .55892 .55091 L .5676 .53786 L 1 g
F
P
p
.002 w
.56149 .54705 m .56075 .54566 L p
.55263 .56038 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55709 .55729 m .55017 .53168 L .5671 .52238 L p
1 g
F P
s
P
p
.002 w
.58196 .51421 m .59031 .54738 L .55709 .55729 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56149 .54705 L p
1 g
F P
s
P
p
.55263 .56038 m .54998 .56518 L .56149 .54705 L 1 g
F
P
p
.5676 .53786 m .55892 .55091 L .5671 .52238 L 1 g
F
P
p
.002 w
.56149 .54705 m .56257 .5491 L p
.56499 .53584 L 1 g
F P
s
P
p
.002 w
.55017 .53168 m .5564 .55471 L p
.52187 .56344 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55394 .55784 m .52187 .56344 L p
.5564 .55471 L 1 g
F P
s
P
p
.002 w
.5194 .57965 m .52187 .56344 L .55394 .55784 L p
1 g
F P
s
P
p
.5513 .56073 m .5194 .57965 L .55394 .55784 L 1 g
F
P
p
.55417 .55759 m .54979 .56465 L .55263 .56038 L 1 g
F
P
p
.55335 .55849 m .54979 .56465 L .55417 .55759 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53167 .57443 L p
1 g
F P
s
P
p
.51779 .57957 m .51111 .583 L .53167 .57443 L 1 g
F
P
p
.5513 .56073 m .54243 .57044 L .52242 .57785 L 1 g
F
P
p
.002 w
.53167 .57443 m .5322 .57686 L p
.54138 .56811 L 1 g
F P
s
P
p
.002 w
.52187 .56344 m .5195 .57893 L p
.48483 .57379 L 1 g
F P
s
P
p
.002 w
.51773 .57936 m .48483 .57379 L p
.5195 .57893 L 1 g
F P
s
P
p
.002 w
.48015 .58063 m .48118 .57913 L p
.48728 .58039 L 1 g
F P
s
P
p
.51595 .57973 m .48015 .58063 L .51773 .57936 L 1 g
F
P
p
.48079 .57905 m .4678 .57686 L .48897 .58192 L 1 g
F
P
p
.47664 .57759 m .47185 .57719 L .48079 .57905 L 1 g
F
P
p
.47185 .57719 m .4678 .57686 L .48079 .57905 L 1 g
F
P
p
.002 w
.48483 .57379 m .51773 .57936 L p
.48728 .58039 L 1 g
F P
s
P
p
.002 w
.48118 .57913 m .48483 .57379 L p
.48728 .58039 L 1 g
F P
s
P
p
.5185 .57921 m .51104 .58207 L .51779 .57957 L 1 g
F
P
p
.51616 .57969 m .51104 .58207 L .5185 .57921 L 1 g
F
P
p
.002 w
.48897 .58192 m .48905 .58076 L p
.48079 .57905 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58076 L p
1 g
F P
s
P
p
.50009 .58076 m .48889 .583 L .51095 .58076 L 1 g
F
P
p
.002 w
.51095 .58076 m .51104 .58207 L p
.51616 .57969 L 1 g
F P
s
P
p
.002 w
.51104 .58207 m .51111 .583 L p
.51779 .57957 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54919 .56304 L p
1 g
F P
s
P
p
.54138 .56811 m .5322 .57686 L .54919 .56304 L 1 g
F
P
p
.002 w
.55709 .55729 m .55698 .55798 L p
.5552 .55913 L 1 g
F P
s
P
p
.002 w
.55698 .55798 m .55299 .58098 L p
.5552 .55913 L 1 g
F P
s
P
p
.002 w
.54919 .56304 m .54979 .56465 L p
.55335 .55849 L 1 g
F P
s
P
p
.002 w
.54979 .56465 m .54998 .56518 L p
.55263 .56038 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56729 .52844 L p
1 g
F P
s
P
p
.56499 .53584 m .56257 .5491 L .56729 .52844 L 1 g
F
P
p
.002 w
.56729 .52844 m .56774 .52909 L p
.56717 .52446 L 1 g
F P
s
P
p
.002 w
.58141 .51451 m .57112 .52017 L p
.56481 .49849 L 1 g
F P
s
P
p
.002 w
.57112 .52017 m .5671 .52238 L p
.56582 .50906 L 1 g
F P
s
P
p
.56481 .49849 m .57112 .52017 L .56582 .50906 L 1 g
F
P
p
.002 w
.55736 .49129 m .55661 .4905 L p
.56078 .49849 L 1 g
F P
s
P
p
.55783 .49175 m .56481 .49849 L .55017 .53168 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.5671 .52238 m .55017 .53168 L p
.56481 .49849 L 1 g
F P
s
P
p
.55783 .49175 m .55776 .49214 L .55736 .49129 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55736 .49129 L p
1 g
F P
s
P
p
.56078 .49849 m .56713 .51061 L .55736 .49129 L 1 g
F
P
p
.002 w
.56774 .52909 m .56854 .53025 L p
.56672 .51846 L 1 g
F P
s
P
p
.55967 .48219 m .58141 .51451 L .55783 .49175 L 1 g
F
P
p
.55736 .49129 m .55017 .53168 L .55365 .48772 L 1 g
F
P
p
.55776 .49214 m .55017 .53168 L .55736 .49129 L 1 g
F
P
p
.002 w
.55017 .53168 m .53259 .50707 L .55365 .48772 L p
1 g
F P
s
P
p
.002 w
.55365 .48772 m .53259 .50707 L p
.52648 .46129 L 1 g
F P
s
P
p
.002 w
.55767 .49163 m .55834 .49233 L p
.55179 .48592 L 1 g
F P
s
P
p
.54973 .48391 m .55365 .48772 L .55179 .48592 L 1 g
F
P
p
.55365 .48772 m .55767 .49163 L .55179 .48592 L 1 g
F
P
p
.002 w
.56582 .50906 m .56713 .51061 L p
.56078 .49849 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .49129 L p
1 g
F P
s
P
p
.002 w
.55736 .49129 m .55767 .49163 L p
.55491 .48893 L 1 g
F P
s
P
p
.54174 .47608 m .55736 .49129 L .55491 .48893 L 1 g
F
P
p
.54174 .47608 m .55767 .49163 L .54973 .48391 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55365 .48772 m .55967 .48219 L p
.55783 .49175 L 1 g
F P
s
P
p
.002 w
.52569 .45532 m .55967 .48219 L .55365 .48772 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.52569 .45532 m .55365 .48772 L .52648 .46129 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46715 L p
1 g
F P
s
P
p
.53052 .47101 m .54302 .47747 L .52243 .46715 L 1 g
F
P
p
.52569 .45532 m .52735 .46779 L .52243 .46715 L 1 g
F
P
p
.5 .4634 m .52243 .46715 L .51987 .46682 L 1 g
F
P
p
.5 .4634 m .52251 .46728 L .50945 .46522 L 1 g
F
P
p
.002 w
.51858 .46666 m .51923 .46563 L p
.52243 .46715 L 1 g
F P
s
P
p
.002 w
.51923 .46563 m .52569 .45532 L p
.52243 .46715 L 1 g
F P
s
P
p
.52735 .46779 m .52759 .46961 L .52243 .46715 L 1 g
F
P
p
.002 w
.54219 .47657 m .54302 .47747 L p
.53052 .47101 L 1 g
F P
s
P
p
.002 w
.52243 .46715 m .52251 .46728 L p
.51987 .46682 L 1 g
F P
s
P
p
.002 w
.53259 .50707 m .50617 .48647 L .51858 .46666 L p
1 g
F P
s
P
p
.002 w
.48405 .43715 m .52569 .45532 L .51858 .46666 L p
1 g
F P
s
P
p
.002 w
.51858 .46666 m .50617 .48647 L p
.49566 .46304 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.48405 .43715 m .51858 .46666 L .49566 .46304 L 1 g
F
P
p
.002 w
.52251 .46728 m .52282 .46778 L p
.50945 .46522 L 1 g
F P
s
P
p
.002 w
.5 .46373 m .5 .46442 L p
.48718 .46572 L 1 g
F P
s
P
p
.48405 .43715 m .49386 .45903 L .47752 .46723 L 1 g
F
P
p
.45826 .47608 m .47644 .46777 L .46929 .47124 L 1 g
F
P
p
.47644 .46777 m .47748 .46729 L .47513 .46843 L 1 g
F
P
p
.47644 .46777 m .47513 .46843 L .46929 .47124 L 1 g
F
P
p
.002 w
.47513 .46843 m .47538 .46756 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.47538 .46756 m .48405 .43715 L p
.47752 .46723 L 1 g
F P
s
P
p
.49386 .45903 m .49623 .46431 L .47752 .46723 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46723 L p
1 g
F P
s
P
p
.48718 .46572 m .5 .46442 L .47752 .46723 L 1 g
F
P
p
.002 w
.47752 .46723 m .47748 .46729 L p
.47644 .46777 L 1 g
F P
s
P
p
.002 w
.47513 .46843 m .47398 .47247 L p
.47197 .46995 L 1 g
F P
s
P
p
.002 w
.47748 .46729 m .47718 .46778 L p
.46929 .47124 L 1 g
F P
s
P
p
.002 w
.44002 .43001 m .48405 .43715 L .47513 .46843 L p
1 g
F P
s
P
p
.44002 .43001 m .47513 .46843 L .47197 .46995 L 1 g
F
P
p
.002 w
.43998 .46681 m .44002 .43001 L p
.47197 .46995 L 1 g
F P
s
P
p
.002 w
.46861 .47157 m .43998 .46681 L p
.47197 .46995 L 1 g
F P
s
P
p
.002 w
.43998 .46681 m .46861 .47157 L p
.44884 .48082 L 1 g
F P
s
P
p
.002 w
.46861 .47157 m .47398 .47247 L p
.44884 .48082 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45773 .47666 L p
1 g
F P
s
P
p
.46963 .47109 m .47718 .46778 L .45773 .47666 L 1 g
F
P
p
.002 w
.45773 .47666 m .45698 .47747 L p
.44945 .48469 L 1 g
F P
s
P
p
.002 w
.44198 .492 m .44166 .49233 L p
.4398 .4967 L 1 g
F P
s
P
p
.43485 .50826 m .44198 .492 L .4398 .4967 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44257 .49137 L p
1 g
F P
s
P
p
.44945 .48469 m .45698 .47747 L .44257 .49137 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46483 .50611 m .4418 .50219 L .44136 .49379 L p
1 g
F P
s
P
p
.002 w
.43704 .50263 m .4418 .50219 L p
.43391 .50937 L 1 g
F P
s
P
p
.002 w
.44136 .49379 m .4418 .50219 L p
.43871 .49923 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43351 .50985 L p
1 g
F P
s
P
p
.002 w
.43351 .50985 m .43391 .50937 L p
.43614 .50447 L 1 g
F P
s
P
p
.43614 .50447 m .44166 .49233 L .43351 .50985 L 1 g
F
P
p
.43877 .49911 m .4398 .4967 L .43704 .50263 L 1 g
F
P
p
.002 w
.4418 .50219 m .43704 .50263 L p
.43871 .49923 L 1 g
F P
s
P
p
.4398 .4967 m .44166 .49233 L .43391 .50937 L 1 g
F
P
p
.002 w
.43391 .50937 m .43287 .51061 L p
.43318 .51918 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.4418 .50219 m .44537 .53482 L p
.43312 .51989 L 1 g
F P
s
P
p
.43312 .51989 m .44537 .53482 L .43245 .52881 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43242 .52885 L p
1 g
F P
s
P
p
.002 w
.43242 .52885 m .43245 .52881 L p
.43247 .52804 L 1 g
F P
s
P
p
.43247 .52804 m .43287 .51061 L .43242 .52885 L 1 g
F
P
p
.40265 .51186 m .43387 .53432 L .43418 .53549 L 1 g
F
P
p
.43426 .53579 m .43199 .52949 L .43424 .53576 L 1 g
F
P
p
.43346 .53276 m .43199 .52949 L .43426 .53579 L 1 g
F
P
p
.002 w
.43387 .53432 m .43451 .53574 L p
.43418 .53549 L 1 g
F P
s
P
p
.43318 .51918 m .43287 .51061 L .43245 .52881 L 1 g
F
P
p
.002 w
.43245 .52881 m .43199 .52949 L p
.43349 .53282 L 1 g
F P
s
P
p
.002 w
.44537 .53482 m .43451 .53574 L .43387 .53432 L p
1 g
F P
s
P
p
.002 w
.43451 .53574 m .45048 .56347 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.4309 .53725 m .43427 .53584 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.43427 .53584 m .43451 .53574 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.43199 .52949 m .43146 .53025 L p
.43424 .53576 L 1 g
F P
s
P
p
.002 w
.43451 .53574 m .43427 .53584 L p
.43418 .53549 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43839 .54728 L p
1 g
F P
s
P
p
.43424 .53576 m .43146 .53025 L .43839 .54728 L 1 g
F
P
p
.44537 .55664 m .44359 .55446 L .4451 .55642 L 1 g
F
P
p
.44403 .55483 m .44359 .55446 L .44537 .55664 L 1 g
F
P
p
.4451 .55642 m .44299 .55393 L .44472 .55613 L 1 g
F
P
p
.44359 .55446 m .44299 .55393 L .4451 .55642 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44537 .53482 m .45693 .53683 L .45053 .56354 L p
1 g
F P
s
P
p
.002 w
.45052 .56353 m .44537 .53482 L p
.45053 .56354 L 1 g
F P
s
P
p
.002 w
.45693 .53683 m .46787 .54156 L .45053 .56355 L p
1 g
F P
s
P
p
.002 w
.45053 .56354 m .45693 .53683 L p
.45053 .56355 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .44028 .55274 L p
.44472 .55613 L 1 g
F P
s
P
p
.44299 .55393 m .43743 .5491 L .44472 .55613 L 1 g
F
P
p
.002 w
.45082 .56385 m .45056 .56359 L p
.4506 .56361 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48897 .58192 L p
1 g
F P
s
P
p
.002 w
.4506 .56361 m .4506 .56362 L p
.45061 .56362 L 1 g
F P
s
P
p
.002 w
.4506 .56362 m .45002 .56518 L p
.4578 .56829 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46812 .5754 L p
1 g
F P
s
P
p
.45717 .56803 m .45002 .56518 L .46812 .5754 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.45094 .32527 m .39117 .3337 L .39509 .30585 L p
1 g
F P
s
P
p
.002 w
.39509 .30585 m .45762 .29658 L .45094 .32527 L p
1 g
F P
s
P
p
.002 w
.47241 .58535 m .48015 .58063 L .5099 .59296 L p
1 g
F P
s
P
p
.002 w
.5254 .3065 m .45762 .29658 L .46538 .27268 L p
1 g
F P
s
P
p
.002 w
.46538 .27268 m .53405 .28254 L .5254 .3065 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.38267 .48171 m .36582 .50004 L .34507 .47417 L p
1 g
F P
s
P
p
.002 w
.34507 .47417 m .36635 .45013 L .38267 .48171 L p
1 g
F P
s
P
p
.002 w
.55299 .58098 m .55709 .55729 L .59031 .54738 L p
1 g
F P
s
P
p
.002 w
.39316 .39923 m .35424 .41829 L .34669 .38735 L p
1 g
F P
s
P
p
.002 w
.34669 .38735 m .39048 .36517 L .39316 .39923 L p
1 g
F P
s
P
p
.002 w
.61102 .49431 m .62037 .5341 L .59031 .54738 L p
1 g
F P
s
P
p
.002 w
.62037 .5341 m .61102 .49431 L .63633 .47275 L p
1 g
F P
s
P
p
.002 w
.62592 .40225 m .65707 .45034 L .63633 .47275 L p
1 g
F P
s
P
p
.002 w
.65707 .45034 m .62592 .40225 L .64042 .3772 L p
1 g
F P
s
P
p
.002 w
.41948 .54558 m .4169 .55335 L .38614 .53957 L p
1 g
F P
s
P
p
.002 w
.38614 .53957 m .39091 .52414 L .41948 .54558 L p
1 g
F P
s
P
p
.002 w
.64042 .3772 m .58922 .33469 L .59864 .31113 L p
1 g
F P
s
P
p
.002 w
.53405 .28254 m .59864 .31113 L .58922 .33469 L p
1 g
F P
s
P
p
.002 w
.58922 .33469 m .5254 .3065 L .53405 .28254 L p
1 g
F P
s
P
p
.002 w
.40265 .51186 m .39091 .52414 L .36582 .50004 L p
1 g
F P
s
P
p
.002 w
.36582 .50004 m .38267 .48171 L .40265 .51186 L p
1 g
F P
s
P
p
.002 w
.58922 .33469 m .64042 .3772 L .62592 .40225 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59031 .54738 m .58196 .51421 L .61102 .49431 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.39916 .43465 m .36635 .45013 L .35424 .41829 L p
1 g
F P
s
P
p
.002 w
.35424 .41829 m .39316 .39923 L .39916 .43465 L p
1 g
F P
s
P
p
.002 w
.44563 .35786 m .39048 .36517 L .39117 .3337 L p
1 g
F P
s
P
p
.002 w
.39117 .3337 m .45094 .32527 L .44563 .35786 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.48483 .57379 m .48591 .56555 L .52187 .56344 L p
1 g
F P
s
P
p
.002 w
.42556 .53948 m .41948 .54558 L .39091 .52414 L p
1 g
F P
s
P
p
.002 w
.39091 .52414 m .40265 .51186 L .42556 .53948 L p
1 g
F P
s
P
p
.002 w
.60721 .42875 m .63633 .47275 L .61102 .49431 L p
1 g
F P
s
P
p
.002 w
.63633 .47275 m .60721 .42875 L .62592 .40225 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.51571 .33497 m .45094 .32527 L .45762 .29658 L p
1 g
F P
s
P
p
.002 w
.45762 .29658 m .5254 .3065 L .51571 .33497 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.48591 .56555 m .4832 .55679 L .51683 .54605 L p
1 g
F P
s
P
p
.002 w
.51683 .54605 m .52187 .56344 L .48591 .56555 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4083 .47009 m .38267 .48171 L .36635 .45013 L p
1 g
F P
s
P
p
.002 w
.36635 .45013 m .39916 .43465 L .4083 .47009 L p
1 g
F P
s
P
p
.002 w
.52187 .56344 m .51683 .54605 L .55017 .53168 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.62592 .40225 m .57678 .36188 L .58922 .33469 L p
1 g
F P
s
P
p
.002 w
.5254 .3065 m .58922 .33469 L .57678 .36188 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.57678 .36188 m .62592 .40225 L .60721 .42875 L p
1 g
F P
s
P
p
.002 w
.58486 .45574 m .61102 .49431 L .58196 .51421 L p
1 g
F P
s
P
p
.002 w
.61102 .49431 m .58486 .45574 L .60721 .42875 L p
1 g
F P
s
P
p
.002 w
.42025 .50421 m .40265 .51186 L .38267 .48171 L p
1 g
F P
s
P
p
.002 w
.38267 .48171 m .4083 .47009 L .42025 .50421 L p
1 g
F P
s
P
p
.002 w
.44193 .39322 m .39316 .39923 L .39048 .36517 L p
1 g
F P
s
P
p
.002 w
.39048 .36517 m .44563 .35786 L .44193 .39322 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.4832 .55679 m .47697 .54848 L .50466 .52944 L p
1 g
F P
s
P
p
.002 w
.50466 .52944 m .51683 .54605 L .4832 .55679 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.57678 .36188 m .51571 .33497 L .5254 .3065 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.47697 .54848 m .46787 .54156 L .48665 .51557 L p
1 g
F P
s
P
p
.002 w
.48665 .51557 m .50466 .52944 L .47697 .54848 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.45693 .53683 m .44537 .53482 L .4418 .50219 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58196 .51421 m .55967 .48219 L .58486 .45574 L p
1 g
F P
s
P
p
.002 w
.51683 .54605 m .50466 .52944 L .53259 .50707 L p
1 g
F P
s
P
p
.002 w
.53259 .50707 m .55017 .53168 L .51683 .54605 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.50533 .36704 m .44563 .35786 L .45094 .32527 L p
1 g
F P
s
P
p
.002 w
.45094 .32527 m .51571 .33497 L .50533 .36704 L p
1 g
F P
s
P
p
.002 w
.46787 .54156 m .45693 .53683 L .46483 .50611 L p
1 g
F P
s
P
p
.002 w
.46483 .50611 m .48665 .51557 L .46787 .54156 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.4418 .50219 m .46483 .50611 L .45693 .53683 L p
1 g
F P
s
P
p
.002 w
.44002 .43001 m .39916 .43465 L .39316 .39923 L p
1 g
F P
s
P
p
.002 w
.39316 .39923 m .44193 .39322 L .44002 .43001 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.56168 .39179 m .60721 .42875 L .58486 .45574 L p
1 g
F P
s
P
p
.002 w
.60721 .42875 m .56168 .39179 L .57678 .36188 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.51571 .33497 m .57678 .36188 L .56168 .39179 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.43998 .46681 m .4083 .47009 L .39916 .43465 L p
1 g
F P
s
P
p
.002 w
.39916 .43465 m .44002 .43001 L .43998 .46681 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50466 .52944 m .48665 .51557 L .50617 .48647 L p
1 g
F P
s
P
p
.002 w
.50617 .48647 m .53259 .50707 L .50466 .52944 L p
1 g
F P
s
P
p
.002 w
.56168 .39179 m .50533 .36704 L .51571 .33497 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.49463 .40154 m .44193 .39322 L .44563 .35786 L p
1 g
F P
s
P
p
.002 w
.44563 .35786 m .50533 .36704 L .49463 .40154 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54443 .42335 m .58486 .45574 L .55967 .48219 L p
1 g
F P
s
P
p
.002 w
.58486 .45574 m .54443 .42335 L .56168 .39179 L p
1 g
F P
s
P
p
.002 w
.48665 .51557 m .46483 .50611 L .47398 .47247 L p
1 g
F P
s
P
p
.002 w
.47398 .47247 m .50617 .48647 L .48665 .51557 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55967 .48219 m .52569 .45532 L .54443 .42335 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.50533 .36704 m .56168 .39179 L .54443 .42335 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48405 .43715 m .44002 .43001 L .44193 .39322 L p
1 g
F P
s
P
p
.002 w
.44193 .39322 m .49463 .40154 L .48405 .43715 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.54443 .42335 m .49463 .40154 L .50533 .36704 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.004 w
.43025 .61809 m
.43349 .60939 L
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49463 .40154 m .54443 .42335 L .52569 .45532 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52569 .45532 m .48405 .43715 L .49463 .40154 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .68962 .65385 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .42145 .64177 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0922481)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0922481)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44389 .43205 m .47504 .46 L .49094 .43648 L p
1 g
F P
s
P
p
.002 w
.49094 .43648 m .46506 .41316 L .44389 .43205 L p
1 g
F P
s
P
p
.002 w
.52222 .45204 m .49094 .43648 L .47504 .46 L p
1 g
F P
s
P
p
.002 w
.46506 .41316 m .49094 .43648 L .50702 .41287 L p
1 g
F P
s
P
p
.002 w
.49094 .43648 m .52222 .45204 L .53128 .4249 L p
1 g
F P
s
P
p
.002 w
.53128 .4249 m .50702 .41287 L .49094 .43648 L p
1 g
F P
s
P
p
.002 w
.50702 .41287 m .48701 .39475 L .46506 .41316 L p
1 g
F P
s
P
p
.002 w
.48701 .39475 m .50702 .41287 L .523 .38959 L p
1 g
F P
s
P
p
.002 w
.50702 .41287 m .53128 .4249 L .53962 .3978 L p
1 g
F P
s
P
p
.002 w
.53962 .3978 m .523 .38959 L .50702 .41287 L p
1 g
F P
s
P
p
.002 w
.47504 .46 m .51259 .47874 L .52222 .45204 L p
1 g
F P
s
P
p
.002 w
.55592 .4583 m .52222 .45204 L .51259 .47874 L p
1 g
F P
s
P
p
.002 w
.52222 .45204 m .55592 .4583 L .55741 .42962 L p
1 g
F P
s
P
p
.002 w
.55741 .42962 m .53128 .4249 L .52222 .45204 L p
1 g
F P
s
P
p
.002 w
.53128 .4249 m .55741 .42962 L .5575 .40094 L p
1 g
F P
s
P
p
.002 w
.5575 .40094 m .53962 .3978 L .53128 .4249 L p
1 g
F P
s
P
p
.002 w
.44712 .38426 m .46506 .41316 L .48701 .39475 L p
1 g
F P
s
P
p
.002 w
.48701 .39475 m .47325 .3723 L .44712 .38426 L p
1 g
F P
s
P
p
.002 w
.47325 .3723 m .48701 .39475 L .50933 .37716 L p
1 g
F P
s
P
p
.002 w
.523 .38959 m .50933 .37716 L .48701 .39475 L p
1 g
F P
s
P
p
.002 w
.42389 .45109 m .45962 .483 L .47504 .46 L p
1 g
F P
s
P
p
.002 w
.47504 .46 m .44389 .43205 L .42389 .45109 L p
1 g
F P
s
P
p
.002 w
.51259 .47874 m .47504 .46 L .45962 .483 L p
1 g
F P
s
P
p
.002 w
.42213 .39744 m .44389 .43205 L .46506 .41316 L p
1 g
F P
s
P
p
.002 w
.46506 .41316 m .44712 .38426 L .42213 .39744 L p
1 g
F P
s
P
p
.002 w
.50933 .37716 m .523 .38959 L .53858 .36706 L p
1 g
F P
s
P
p
.002 w
.523 .38959 m .53962 .3978 L .54707 .37124 L p
1 g
F P
s
P
p
.002 w
.54707 .37124 m .53858 .36706 L .523 .38959 L p
1 g
F P
s
P
p
.002 w
.45962 .483 m .50257 .50451 L .51259 .47874 L p
1 g
F P
s
P
p
.002 w
.55307 .48646 m .51259 .47874 L .50257 .50451 L p
1 g
F P
s
P
p
.002 w
.51259 .47874 m .55307 .48646 L .55592 .4583 L p
1 g
F P
s
P
p
.002 w
.53962 .3978 m .5575 .40094 L .55618 .3728 L p
1 g
F P
s
P
p
.002 w
.55618 .3728 m .54707 .37124 L .53962 .3978 L p
1 g
F P
s
P
p
.002 w
.50933 .37716 m .50001 .36176 L .47325 .3723 L p
1 g
F P
s
P
p
.002 w
.50001 .36176 m .50933 .37716 L .53162 .36071 L p
1 g
F P
s
P
p
.002 w
.53858 .36706 m .53162 .36071 L .50933 .37716 L p
1 g
F P
s
P
p
.002 w
.39875 .41159 m .42389 .45109 L .44389 .43205 L p
1 g
F P
s
P
p
.002 w
.44389 .43205 m .42213 .39744 L .39875 .41159 L p
1 g
F P
s
P
p
.002 w
.5828 .42647 m .55741 .42962 L .55592 .4583 L p
1 g
F P
s
P
p
.002 w
.55741 .42962 m .5828 .42647 L .57481 .39865 L p
1 g
F P
s
P
p
.002 w
.57481 .39865 m .5575 .40094 L .55741 .42962 L p
1 g
F P
s
P
p
.002 w
.58879 .4545 m .55592 .4583 L .55307 .48646 L p
1 g
F P
s
P
p
.002 w
.55592 .4583 m .58879 .4545 L .5828 .42647 L p
1 g
F P
s
P
p
.002 w
.43905 .35253 m .44712 .38426 L .47325 .3723 L p
1 g
F P
s
P
p
.002 w
.47325 .3723 m .46723 .34771 L .43905 .35253 L p
1 g
F P
s
P
p
.002 w
.46723 .34771 m .47325 .3723 L .50001 .36176 L p
1 g
F P
s
P
p
.002 w
.5575 .40094 m .57481 .39865 L .56498 .37156 L p
1 g
F P
s
P
p
.002 w
.56498 .37156 m .55618 .3728 L .5575 .40094 L p
1 g
F P
s
P
p
.002 w
.40545 .46992 m .44495 .50506 L .45962 .483 L p
1 g
F P
s
P
p
.002 w
.45962 .483 m .42389 .45109 L .40545 .46992 L p
1 g
F P
s
P
p
.002 w
.50257 .50451 m .45962 .483 L .44495 .50506 L p
1 g
F P
s
P
p
.002 w
.50001 .36176 m .49605 .34494 L .46723 .34771 L p
1 g
F P
s
P
p
.002 w
.49605 .34494 m .50001 .36176 L .52692 .35284 L p
1 g
F P
s
P
p
.002 w
.53162 .36071 m .52692 .35284 L .50001 .36176 L p
1 g
F P
s
P
p
.002 w
.41208 .35933 m .42213 .39744 L .44712 .38426 L p
1 g
F P
s
P
p
.002 w
.44712 .38426 m .43905 .35253 L .41208 .35933 L p
1 g
F P
s
P
p
.002 w
.44495 .50506 m .49233 .52885 L .50257 .50451 L p
1 g
F P
s
P
p
.002 w
.54887 .51357 m .50257 .50451 L .49233 .52885 L p
1 g
F P
s
P
p
.002 w
.50257 .50451 m .54887 .51357 L .55307 .48646 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .53162 .36071 L .53858 .36706 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .53858 .36706 L .54707 .37124 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .54707 .37124 L .55618 .3728 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .52692 .35284 L .53162 .36071 L closepath p
1 g
F P
s
P
p
.002 w
.59265 .4822 m .55307 .48646 L .54887 .51357 L p
1 g
F P
s
P
p
.002 w
.55307 .48646 m .59265 .4822 L .58879 .4545 L p
1 g
F P
s
P
p
.002 w
.37747 .42646 m .40545 .46992 L .42389 .45109 L p
1 g
F P
s
P
p
.002 w
.42389 .45109 m .39875 .41159 L .37747 .42646 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .55618 .3728 L .56498 .37156 L closepath p
1 g
F P
s
P
p
.002 w
.58975 .39108 m .57481 .39865 L .5828 .42647 L p
1 g
F P
s
P
p
.002 w
.57481 .39865 m .58975 .39108 L .57251 .36764 L p
1 g
F P
s
P
p
.002 w
.57251 .36764 m .56498 .37156 L .57481 .39865 L p
1 g
F P
s
P
p
.002 w
.52692 .35284 m .52498 .34427 L .49605 .34494 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .52498 .34427 L .52692 .35284 L closepath p
1 g
F P
s
P
p
.002 w
.60485 .4156 m .5828 .42647 L .58879 .4545 L p
1 g
F P
s
P
p
.002 w
.5828 .42647 m .60485 .4156 L .58975 .39108 L p
1 g
F P
s
P
p
.002 w
.38687 .36802 m .39875 .41159 L .42213 .39744 L p
1 g
F P
s
P
p
.002 w
.42213 .39744 m .41208 .35933 L .38687 .36802 L p
1 g
F P
s
P
p
.002 w
.46975 .32347 m .46723 .34771 L .49605 .34494 L p
1 g
F P
s
P
p
.002 w
.49605 .34494 m .49796 .32846 L .46975 .32347 L p
1 g
F P
s
P
p
.002 w
.49796 .32846 m .49605 .34494 L .52498 .34427 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .56498 .37156 L .57251 .36764 L closepath p
1 g
F P
s
P
p
.002 w
.44197 .32108 m .43905 .35253 L .46723 .34771 L p
1 g
F P
s
P
p
.002 w
.46723 .34771 m .46975 .32347 L .44197 .32108 L p
1 g
F P
s
P
p
.002 w
.52498 .34427 m .52605 .33593 L .49796 .32846 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .52605 .33593 L .52498 .34427 L closepath p
1 g
F P
s
P
p
.002 w
.61749 .44073 m .58879 .4545 L .59265 .4822 L p
1 g
F P
s
P
p
.002 w
.58879 .4545 m .61749 .44073 L .60485 .4156 L p
1 g
F P
s
P
p
.002 w
.38897 .48817 m .43135 .52572 L .44495 .50506 L p
1 g
F P
s
P
p
.002 w
.44495 .50506 m .40545 .46992 L .38897 .48817 L p
1 g
F P
s
P
p
.002 w
.49233 .52885 m .44495 .50506 L .43135 .52572 L p
1 g
F P
s
P
p
.002 w
.57796 .36143 m .57251 .36764 L .58975 .39108 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .57251 .36764 L .57796 .36143 L closepath p
1 g
F P
s
P
p
.002 w
.49233 .52885 m .54339 .53908 L .54887 .51357 L p
1 g
F P
s
P
p
.002 w
.59425 .50904 m .54887 .51357 L .54339 .53908 L p
1 g
F P
s
P
p
.002 w
.54887 .51357 m .59425 .50904 L .59265 .4822 L p
1 g
F P
s
P
p
.002 w
.60067 .37894 m .58975 .39108 L .60485 .4156 L p
1 g
F P
s
P
p
.002 w
.58975 .39108 m .60067 .37894 L .57796 .36143 L p
1 g
F P
s
P
p
.002 w
.50564 .31407 m .49796 .32846 L .52605 .33593 L p
1 g
F P
s
P
p
.002 w
.52605 .33593 m .53002 .3287 L .50564 .31407 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .53002 .3287 L .52605 .33593 L closepath p
1 g
F P
s
P
p
.002 w
.43135 .52572 m .48207 .55126 L .49233 .52885 L p
1 g
F P
s
P
p
.002 w
.54339 .53908 m .49233 .52885 L .48207 .55126 L p
1 g
F P
s
P
p
.002 w
.41519 .32141 m .41208 .35933 L .43905 .35253 L p
1 g
F P
s
P
p
.002 w
.43905 .35253 m .44197 .32108 L .41519 .32141 L p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .57796 .36143 L .58071 .35357 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .58071 .35357 L .58043 .34493 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .58043 .34493 L .57714 .33643 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .57714 .33643 L .57116 .32904 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .57116 .32904 L .56317 .32358 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .56317 .32358 L .55404 .32066 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .55404 .32066 L .54482 .3206 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .54482 .3206 L .53651 .32339 L closepath p
1 g
F P
s
P
p
.002 w
.55347 .34572 m .53651 .32339 L .53002 .3287 L closepath p
1 g
F P
s
P
p
.002 w
.48079 .30216 m .46975 .32347 L .49796 .32846 L p
1 g
F P
s
P
p
.002 w
.49796 .32846 m .50564 .31407 L .48079 .30216 L p
1 g
F P
s
P
p
.002 w
.35878 .44178 m .38897 .48817 L .40545 .46992 L p
1 g
F P
s
P
p
.002 w
.40545 .46992 m .37747 .42646 L .35878 .44178 L p
1 g
F P
s
P
p
.002 w
.36398 .37847 m .37747 .42646 L .39875 .41159 L p
1 g
F P
s
P
p
.002 w
.39875 .41159 m .38687 .36802 L .36398 .37847 L p
1 g
F P
s
P
p
.002 w
.58071 .35357 m .57796 .36143 L .60067 .37894 L p
1 g
F P
s
P
p
.002 w
.62112 .39794 m .60485 .4156 L .61749 .44073 L p
1 g
F P
s
P
p
.002 w
.60485 .4156 m .62112 .39794 L .60067 .37894 L p
1 g
F P
s
P
p
.002 w
.62738 .46598 m .59265 .4822 L .59425 .50904 L p
1 g
F P
s
P
p
.002 w
.59265 .4822 m .62738 .46598 L .61749 .44073 L p
1 g
F P
s
P
p
.002 w
.51838 .3034 m .50564 .31407 L .53002 .3287 L p
1 g
F P
s
P
p
.002 w
.53002 .3287 m .53651 .32339 L .51838 .3034 L p
1 g
F P
s
P
p
.002 w
.45598 .29327 m .44197 .32108 L .46975 .32347 L p
1 g
F P
s
P
p
.002 w
.46975 .32347 m .48079 .30216 L .45598 .29327 L p
1 g
F P
s
P
p
.002 w
.60067 .37894 m .6063 .36345 L .58071 .35357 L p
1 g
F P
s
P
p
.002 w
.58043 .34493 m .58071 .35357 L .6063 .36345 L p
1 g
F P
s
P
p
.002 w
.6063 .36345 m .60067 .37894 L .62112 .39794 L p
1 g
F P
s
P
p
.002 w
.39 .32452 m .38687 .36802 L .41208 .35933 L p
1 g
F P
s
P
p
.002 w
.41208 .35933 m .41519 .32141 L .39 .32452 L p
1 g
F P
s
P
p
.002 w
.53485 .2977 m .51838 .3034 L .53651 .32339 L p
1 g
F P
s
P
p
.002 w
.53651 .32339 m .54482 .3206 L .53485 .2977 L p
1 g
F P
s
P
p
.002 w
.49942 .28621 m .48079 .30216 L .50564 .31407 L p
1 g
F P
s
P
p
.002 w
.50564 .31407 m .51838 .3034 L .49942 .28621 L p
1 g
F P
s
P
p
.002 w
.48207 .55126 m .5367 .56244 L .54339 .53908 L p
1 g
F P
s
P
p
.002 w
.59352 .53444 m .54339 .53908 L .5367 .56244 L p
1 g
F P
s
P
p
.002 w
.54339 .53908 m .59352 .53444 L .59425 .50904 L p
1 g
F P
s
P
p
.002 w
.37485 .50545 m .41912 .54453 L .43135 .52572 L p
1 g
F P
s
P
p
.002 w
.43135 .52572 m .38897 .48817 L .37485 .50545 L p
1 g
F P
s
P
p
.002 w
.48207 .55126 m .43135 .52572 L .41912 .54453 L p
1 g
F P
s
P
p
.002 w
.6063 .36345 m .60591 .34626 L .58043 .34493 L p
1 g
F P
s
P
p
.002 w
.57714 .33643 m .58043 .34493 L .60591 .34626 L p
1 g
F P
s
P
p
.002 w
.63887 .41807 m .61749 .44073 L .62738 .46598 L p
1 g
F P
s
P
p
.002 w
.61749 .44073 m .63887 .41807 L .62112 .39794 L p
1 g
F P
s
P
p
.002 w
.55327 .29772 m .53485 .2977 L .54482 .3206 L p
1 g
F P
s
P
p
.002 w
.54482 .3206 m .55404 .32066 L .55327 .29772 L p
1 g
F P
s
P
p
.002 w
.60591 .34626 m .59944 .32928 L .57714 .33643 L p
1 g
F P
s
P
p
.002 w
.57116 .32904 m .57714 .33643 L .59944 .32928 L p
1 g
F P
s
P
p
.002 w
.41912 .54453 m .47198 .57122 L .48207 .55126 L p
1 g
F P
s
P
p
.002 w
.5367 .56244 m .48207 .55126 L .47198 .57122 L p
1 g
F P
s
P
p
.002 w
.57153 .30352 m .55327 .29772 L .55404 .32066 L p
1 g
F P
s
P
p
.002 w
.55404 .32066 m .56317 .32358 L .57153 .30352 L p
1 g
F P
s
P
p
.002 w
.34399 .39053 m .35878 .44178 L .37747 .42646 L p
1 g
F P
s
P
p
.002 w
.37747 .42646 m .36398 .37847 L .34399 .39053 L p
1 g
F P
s
P
p
.002 w
.63424 .49083 m .59425 .50904 L .59352 .53444 L p
1 g
F P
s
P
p
.002 w
.59425 .50904 m .63424 .49083 L .62738 .46598 L p
1 g
F P
s
P
p
.002 w
.43173 .28769 m .41519 .32141 L .44197 .32108 L p
1 g
F P
s
P
p
.002 w
.44197 .32108 m .45598 .29327 L .43173 .28769 L p
1 g
F P
s
P
p
.002 w
.59944 .32928 m .58754 .31446 L .57116 .32904 L p
1 g
F P
s
P
p
.002 w
.56317 .32358 m .57116 .32904 L .58754 .31446 L p
1 g
F P
s
P
p
.002 w
.58754 .31446 m .57153 .30352 L .56317 .32358 L p
1 g
F P
s
P
p
.002 w
.34319 .45724 m .37485 .50545 L .38897 .48817 L p
1 g
F P
s
P
p
.002 w
.38897 .48817 m .35878 .44178 L .34319 .45724 L p
1 g
F P
s
P
p
.002 w
.62968 .3752 m .62112 .39794 L .63887 .41807 L p
1 g
F P
s
P
p
.002 w
.62112 .39794 m .62968 .3752 L .6063 .36345 L p
1 g
F P
s
P
p
.002 w
.60591 .34626 m .6063 .36345 L .62968 .3752 L p
1 g
F P
s
P
p
.002 w
.52374 .27759 m .49942 .28621 L .51838 .3034 L p
1 g
F P
s
P
p
.002 w
.51838 .3034 m .53485 .2977 L .52374 .27759 L p
1 g
F P
s
P
p
.002 w
.367 .33045 m .36398 .37847 L .38687 .36802 L p
1 g
F P
s
P
p
.002 w
.38687 .36802 m .39 .32452 L .367 .33045 L p
1 g
F P
s
P
p
.002 w
.48 .27229 m .45598 .29327 L .48079 .30216 L p
1 g
F P
s
P
p
.002 w
.48079 .30216 m .49942 .28621 L .48 .27229 L p
1 g
F P
s
P
p
.002 w
.65345 .43894 m .62738 .46598 L .63424 .49083 L p
1 g
F P
s
P
p
.002 w
.62738 .46598 m .65345 .43894 L .63887 .41807 L p
1 g
F P
s
P
p
.002 w
.62968 .3752 m .62933 .34977 L .60591 .34626 L p
1 g
F P
s
P
p
.002 w
.59944 .32928 m .60591 .34626 L .62933 .34977 L p
1 g
F P
s
P
p
.002 w
.47198 .57122 m .52889 .58309 L .5367 .56244 L p
1 g
F P
s
P
p
.002 w
.59038 .55783 m .5367 .56244 L .52889 .58309 L p
1 g
F P
s
P
p
.002 w
.5367 .56244 m .59038 .55783 L .59352 .53444 L p
1 g
F P
s
P
p
.002 w
.5511 .27749 m .52374 .27759 L .53485 .2977 L p
1 g
F P
s
P
p
.002 w
.53485 .2977 m .55327 .29772 L .5511 .27749 L p
1 g
F P
s
P
p
.002 w
.40859 .28566 m .39 .32452 L .41519 .32141 L p
1 g
F P
s
P
p
.002 w
.41519 .32141 m .43173 .28769 L .40859 .28566 L p
1 g
F P
s
P
p
.002 w
.6503 .38863 m .63887 .41807 L .65345 .43894 L p
1 g
F P
s
P
p
.002 w
.63887 .41807 m .6503 .38863 L .62968 .3752 L p
1 g
F P
s
P
p
.002 w
.36351 .52135 m .40858 .56101 L .41912 .54453 L p
1 g
F P
s
P
p
.002 w
.41912 .54453 m .37485 .50545 L .36351 .52135 L p
1 g
F P
s
P
p
.002 w
.47198 .57122 m .41912 .54453 L .40858 .56101 L p
1 g
F P
s
P
p
.002 w
.63783 .51474 m .59352 .53444 L .59038 .55783 L p
1 g
F P
s
P
p
.002 w
.59352 .53444 m .63783 .51474 L .63424 .49083 L p
1 g
F P
s
P
p
.002 w
.62933 .34977 m .62968 .3752 L .6503 .38863 L p
1 g
F P
s
P
p
.002 w
.32746 .404 m .34319 .45724 L .35878 .44178 L p
1 g
F P
s
P
p
.002 w
.35878 .44178 m .34399 .39053 L .32746 .404 L p
1 g
F P
s
P
p
.002 w
.62933 .34977 m .61986 .32451 L .59944 .32928 L p
1 g
F P
s
P
p
.002 w
.58754 .31446 m .59944 .32928 L .61986 .32451 L p
1 g
F P
s
P
p
.002 w
.57833 .28607 m .5511 .27749 L .55327 .29772 L p
1 g
F P
s
P
p
.002 w
.55327 .29772 m .57153 .30352 L .57833 .28607 L p
1 g
F P
s
P
p
.002 w
.40858 .56101 m .4623 .5882 L .47198 .57122 L p
1 g
F P
s
P
p
.002 w
.52889 .58309 m .47198 .57122 L .4623 .5882 L p
1 g
F P
s
P
p
.002 w
.46054 .26209 m .43173 .28769 L .45598 .29327 L p
1 g
F P
s
P
p
.002 w
.45598 .29327 m .48 .27229 L .46054 .26209 L p
1 g
F P
s
P
p
.002 w
.51167 .26083 m .48 .27229 L .49942 .28621 L p
1 g
F P
s
P
p
.002 w
.49942 .28621 m .52374 .27759 L .51167 .26083 L p
1 g
F P
s
P
p
.002 w
.61986 .32451 m .60219 .30239 L .58754 .31446 L p
1 g
F P
s
P
p
.002 w
.57153 .30352 m .58754 .31446 L .60219 .30239 L p
1 g
F P
s
P
p
.002 w
.3468 .33917 m .34399 .39053 L .36398 .37847 L p
1 g
F P
s
P
p
.002 w
.36398 .37847 m .367 .33045 L .3468 .33917 L p
1 g
F P
s
P
p
.002 w
.60219 .30239 m .57833 .28607 L .57153 .30352 L p
1 g
F P
s
P
p
.002 w
.33117 .47251 m .36351 .52135 L .37485 .50545 L p
1 g
F P
s
P
p
.002 w
.37485 .50545 m .34319 .45724 L .33117 .47251 L p
1 g
F P
s
P
p
.002 w
.66445 .46013 m .63424 .49083 L .63783 .51474 L p
1 g
F P
s
P
p
.002 w
.63424 .49083 m .66445 .46013 L .65345 .43894 L p
1 g
F P
s
P
p
.002 w
.6503 .38863 m .65009 .35547 L .62933 .34977 L p
1 g
F P
s
P
p
.002 w
.61986 .32451 m .62933 .34977 L .65009 .35547 L p
1 g
F P
s
P
p
.002 w
.38716 .28739 m .367 .33045 L .39 .32452 L p
1 g
F P
s
P
p
.002 w
.39 .32452 m .40859 .28566 L .38716 .28739 L p
1 g
F P
s
P
p
.002 w
.66759 .40351 m .65345 .43894 L .66445 .46013 L p
1 g
F P
s
P
p
.002 w
.65345 .43894 m .66759 .40351 L .6503 .38863 L p
1 g
F P
s
P
p
.002 w
.54752 .26055 m .51167 .26083 L .52374 .27759 L p
1 g
F P
s
P
p
.002 w
.52374 .27759 m .5511 .27749 L .54752 .26055 L p
1 g
F P
s
P
p
.002 w
.4623 .5882 m .52007 .60044 L .52889 .58309 L p
1 g
F P
s
P
p
.002 w
.58481 .57861 m .52889 .58309 L .52007 .60044 L p
1 g
F P
s
P
p
.002 w
.52889 .58309 m .58481 .57861 L .59038 .55783 L p
1 g
F P
s
P
p
.002 w
.65009 .35547 m .6503 .38863 L .66759 .40351 L p
1 g
F P
s
P
p
.002 w
.63793 .53715 m .59038 .55783 L .58481 .57861 L p
1 g
F P
s
P
p
.002 w
.59038 .55783 m .63793 .53715 L .63783 .51474 L p
1 g
F P
s
P
p
.002 w
.44149 .256 m .40859 .28566 L .43173 .28769 L p
1 g
F P
s
P
p
.002 w
.43173 .28769 m .46054 .26209 L .44149 .256 L p
1 g
F P
s
P
p
.002 w
.31495 .41862 m .33117 .47251 L .34319 .45724 L p
1 g
F P
s
P
p
.002 w
.34319 .45724 m .32746 .404 L .31495 .41862 L p
1 g
F P
s
P
p
.002 w
.35534 .53544 m .40004 .57468 L .40858 .56101 L p
1 g
F P
s
P
p
.002 w
.40858 .56101 m .36351 .52135 L .35534 .53544 L p
1 g
F P
s
P
p
.002 w
.4623 .5882 m .40858 .56101 L .40004 .57468 L p
1 g
F P
s
P
p
.002 w
.49888 .24796 m .46054 .26209 L .48 .27229 L p
1 g
F P
s
P
p
.002 w
.48 .27229 m .51167 .26083 L .49888 .24796 L p
1 g
F P
s
P
p
.002 w
.65009 .35547 m .63784 .32235 L .61986 .32451 L p
1 g
F P
s
P
p
.002 w
.60219 .30239 m .61986 .32451 L .63784 .32235 L p
1 g
F P
s
P
p
.002 w
.33004 .35061 m .32746 .404 L .34399 .39053 L p
1 g
F P
s
P
p
.002 w
.34399 .39053 m .3468 .33917 L .33004 .35061 L p
1 g
F P
s
P
p
.002 w
.58332 .27177 m .54752 .26055 L .5511 .27749 L p
1 g
F P
s
P
p
.002 w
.5511 .27749 m .57833 .28607 L .58332 .27177 L p
1 g
F P
s
P
p
.002 w
.67145 .48116 m .63783 .51474 L .63793 .53715 L p
1 g
F P
s
P
p
.002 w
.63783 .51474 m .67145 .48116 L .66445 .46013 L p
1 g
F P
s
P
p
.002 w
.40004 .57468 m .45325 .60166 L .4623 .5882 L p
1 g
F P
s
P
p
.002 w
.52007 .60044 m .4623 .5882 L .45325 .60166 L p
1 g
F P
s
P
p
.002 w
.63784 .32235 m .6147 .29324 L .60219 .30239 L p
1 g
F P
s
P
p
.002 w
.57833 .28607 m .60219 .30239 L .6147 .29324 L p
1 g
F P
s
P
p
.002 w
.3232 .48721 m .35534 .53544 L .36351 .52135 L p
1 g
F P
s
P
p
.002 w
.36351 .52135 m .33117 .47251 L .3232 .48721 L p
1 g
F P
s
P
p
.002 w
.6147 .29324 m .58332 .27177 L .57833 .28607 L p
1 g
F P
s
P
p
.002 w
.36804 .29302 m .3468 .33917 L .367 .33045 L p
1 g
F P
s
P
p
.002 w
.367 .33045 m .38716 .28739 L .36804 .29302 L p
1 g
F P
s
P
p
.002 w
.68101 .41957 m .66445 .46013 L .67145 .48116 L p
1 g
F P
s
P
p
.002 w
.66445 .46013 m .68101 .41957 L .66759 .40351 L p
1 g
F P
s
P
p
.002 w
.66759 .40351 m .66759 .36333 L .65009 .35547 L p
1 g
F P
s
P
p
.002 w
.63784 .32235 m .65009 .35547 L .66759 .36333 L p
1 g
F P
s
P
p
.002 w
.66759 .36333 m .66759 .40351 L .68101 .41957 L p
1 g
F P
s
P
p
.002 w
.54254 .24749 m .49888 .24796 L .51167 .26083 L p
1 g
F P
s
P
p
.002 w
.51167 .26083 m .54752 .26055 L .54254 .24749 L p
1 g
F P
s
P
p
.002 w
.52007 .60044 m .57681 .59618 L .58481 .57861 L p
1 g
F P
s
P
p
.002 w
.63438 .55744 m .58481 .57861 L .57681 .59618 L p
1 g
F P
s
P
p
.002 w
.58481 .57861 m .63438 .55744 L .63793 .53715 L p
1 g
F P
s
P
p
.002 w
.45325 .60166 m .51041 .61392 L .52007 .60044 L p
1 g
F P
s
P
p
.002 w
.57681 .59618 m .52007 .60044 L .51041 .61392 L p
1 g
F P
s
P
p
.002 w
.42334 .25439 m .38716 .28739 L .40859 .28566 L p
1 g
F P
s
P
p
.002 w
.40859 .28566 m .44149 .256 L .42334 .25439 L p
1 g
F P
s
P
p
.002 w
.48564 .23952 m .44149 .256 L .46054 .26209 L p
1 g
F P
s
P
p
.002 w
.46054 .26209 m .49888 .24796 L .48564 .23952 L p
1 g
F P
s
P
p
.002 w
.30699 .43409 m .3232 .48721 L .33117 .47251 L p
1 g
F P
s
P
p
.002 w
.33117 .47251 m .31495 .41862 L .30699 .43409 L p
1 g
F P
s
P
p
.002 w
.67412 .50152 m .63793 .53715 L .63438 .55744 L p
1 g
F P
s
P
p
.002 w
.63793 .53715 m .67412 .50152 L .67145 .48116 L p
1 g
F P
s
P
p
.002 w
.31729 .36461 m .31495 .41862 L .32746 .404 L p
1 g
F P
s
P
p
.002 w
.32746 .404 m .33004 .35061 L .31729 .36461 L p
1 g
F P
s
P
p
.002 w
.66759 .36333 m .65284 .32298 L .63784 .32235 L p
1 g
F P
s
P
p
.002 w
.6147 .29324 m .63784 .32235 L .65284 .32298 L p
1 g
F P
s
P
p
.002 w
.35072 .54728 m .39383 .58505 L .40004 .57468 L p
1 g
F P
s
P
p
.002 w
.40004 .57468 m .35534 .53544 L .35072 .54728 L p
1 g
F P
s
P
p
.002 w
.45325 .60166 m .40004 .57468 L .39383 .58505 L p
1 g
F P
s
P
p
.002 w
.58629 .26114 m .54254 .24749 L .54752 .26055 L p
1 g
F P
s
P
p
.002 w
.54752 .26055 m .58332 .27177 L .58629 .26114 L p
1 g
F P
s
P
p
.002 w
.39383 .58505 m .4451 .61108 L .45325 .60166 L p
1 g
F P
s
P
p
.002 w
.51041 .61392 m .45325 .60166 L .4451 .61108 L p
1 g
F P
s
P
p
.002 w
.35185 .30259 m .33004 .35061 L .3468 .33917 L p
1 g
F P
s
P
p
.002 w
.3468 .33917 m .36804 .29302 L .35185 .30259 L p
1 g
F P
s
P
p
.002 w
.3197 .50095 m .35072 .54728 L .35534 .53544 L p
1 g
F P
s
P
p
.002 w
.35534 .53544 m .3232 .48721 L .3197 .50095 L p
1 g
F P
s
P
p
.002 w
.69004 .43647 m .67145 .48116 L .67412 .50152 L p
1 g
F P
s
P
p
.002 w
.67145 .48116 m .69004 .43647 L .68101 .41957 L p
1 g
F P
s
P
p
.002 w
.65284 .32298 m .62465 .2874 L .6147 .29324 L p
1 g
F P
s
P
p
.002 w
.58332 .27177 m .6147 .29324 L .62465 .2874 L p
1 g
F P
s
P
p
.002 w
.62465 .2874 m .58629 .26114 L .58332 .27177 L p
1 g
F P
s
P
p
.002 w
.68101 .41957 m .68125 .37328 L .66759 .36333 L p
1 g
F P
s
P
p
.002 w
.65284 .32298 m .66759 .36333 L .68125 .37328 L p
1 g
F P
s
P
p
.002 w
.68125 .37328 m .68101 .41957 L .69004 .43647 L p
1 g
F P
s
P
p
.002 w
.40662 .25756 m .36804 .29302 L .38716 .28739 L p
1 g
F P
s
P
p
.002 w
.38716 .28739 m .42334 .25439 L .40662 .25756 L p
1 g
F P
s
P
p
.002 w
.5362 .23887 m .48564 .23952 L .49888 .24796 L p
1 g
F P
s
P
p
.002 w
.49888 .24796 m .54254 .24749 L .5362 .23887 L p
1 g
F P
s
P
p
.002 w
.51041 .61392 m .56646 .60993 L .57681 .59618 L p
1 g
F P
s
P
p
.002 w
.62708 .57501 m .57681 .59618 L .56646 .60993 L p
1 g
F P
s
P
p
.002 w
.57681 .59618 m .62708 .57501 L .63438 .55744 L p
1 g
F P
s
P
p
.002 w
.4451 .61108 m .50009 .62299 L .51041 .61392 L p
1 g
F P
s
P
p
.002 w
.56646 .60993 m .51041 .61392 L .50009 .62299 L p
1 g
F P
s
P
p
.002 w
.47227 .23598 m .42334 .25439 L .44149 .256 L p
1 g
F P
s
P
p
.002 w
.44149 .256 m .48564 .23952 L .47227 .23598 L p
1 g
F P
s
P
p
.002 w
.67215 .52066 m .63438 .55744 L .62708 .57501 L p
1 g
F P
s
P
p
.002 w
.63438 .55744 m .67215 .52066 L .67412 .50152 L p
1 g
F P
s
P
p
.002 w
.30912 .38094 m .30699 .43409 L .31495 .41862 L p
1 g
F P
s
P
p
.002 w
.31495 .41862 m .31729 .36461 L .30912 .38094 L p
1 g
F P
s
P
p
.002 w
.30403 .45005 m .3197 .50095 L .3232 .48721 L p
1 g
F P
s
P
p
.002 w
.3232 .48721 m .30699 .43409 L .30403 .45005 L p
1 g
F P
s
P
p
.002 w
.68125 .37328 m .66429 .32655 L .65284 .32298 L p
1 g
F P
s
P
p
.002 w
.62465 .2874 m .65284 .32298 L .66429 .32655 L p
1 g
F P
s
P
p
.002 w
.34997 .55642 m .39023 .59166 L .39383 .58505 L p
1 g
F P
s
P
p
.002 w
.39383 .58505 m .35072 .54728 L .34997 .55642 L p
1 g
F P
s
P
p
.002 w
.4451 .61108 m .39383 .58505 L .39023 .59166 L p
1 g
F P
s
P
p
.002 w
.33918 .31607 m .31729 .36461 L .33004 .35061 L p
1 g
F P
s
P
p
.002 w
.33004 .35061 m .35185 .30259 L .33918 .31607 L p
1 g
F P
s
P
p
.002 w
.58702 .25469 m .5362 .23887 L .54254 .24749 L p
1 g
F P
s
P
p
.002 w
.54254 .24749 m .58629 .26114 L .58702 .25469 L p
1 g
F P
s
P
p
.002 w
.69422 .45382 m .67412 .50152 L .67215 .52066 L p
1 g
F P
s
P
p
.002 w
.67412 .50152 m .69422 .45382 L .69004 .43647 L p
1 g
F P
s
P
p
.002 w
.39023 .59166 m .4381 .61598 L .4451 .61108 L p
1 g
F P
s
P
p
.002 w
.50009 .62299 m .4451 .61108 L .4381 .61598 L p
1 g
F P
s
P
p
.002 w
.32103 .51331 m .34997 .55642 L .35072 .54728 L p
1 g
F P
s
P
p
.002 w
.35072 .54728 m .3197 .50095 L .32103 .51331 L p
1 g
F P
s
P
p
.002 w
.66429 .32655 m .63161 .28522 L .62465 .2874 L p
1 g
F P
s
P
p
.002 w
.58629 .26114 m .62465 .2874 L .63161 .28522 L p
1 g
F P
s
P
p
.002 w
.69004 .43647 m .69048 .38517 L .68125 .37328 L p
1 g
F P
s
P
p
.002 w
.66429 .32655 m .68125 .37328 L .69048 .38517 L p
1 g
F P
s
P
p
.002 w
.63161 .28522 m .58702 .25469 L .58629 .26114 L p
1 g
F P
s
P
p
.002 w
.69048 .38517 m .69004 .43647 L .69422 .45382 L p
1 g
F P
s
P
p
.002 w
.39187 .26568 m .35185 .30259 L .36804 .29302 L p
1 g
F P
s
P
p
.002 w
.36804 .29302 m .40662 .25756 L .39187 .26568 L p
1 g
F P
s
P
p
.002 w
.50009 .62299 m .5539 .61929 L .56646 .60993 L p
1 g
F P
s
P
p
.002 w
.61604 .58926 m .56646 .60993 L .5539 .61929 L p
1 g
F P
s
P
p
.002 w
.56646 .60993 m .61604 .58926 L .62708 .57501 L p
1 g
F P
s
P
p
.002 w
.52858 .23521 m .47227 .23598 L .48564 .23952 L p
1 g
F P
s
P
p
.002 w
.48564 .23952 m .5362 .23887 L .52858 .23521 L p
1 g
F P
s
P
p
.002 w
.45913 .23773 m .40662 .25756 L .42334 .25439 L p
1 g
F P
s
P
p
.002 w
.42334 .25439 m .47227 .23598 L .45913 .23773 L p
1 g
F P
s
P
p
.002 w
.66536 .53799 m .62708 .57501 L .61604 .58926 L p
1 g
F P
s
P
p
.002 w
.62708 .57501 m .66536 .53799 L .67215 .52066 L p
1 g
F P
s
P
p
.002 w
.4381 .61598 m .48934 .62714 L .50009 .62299 L p
1 g
F P
s
P
p
.002 w
.5539 .61929 m .50009 .62299 L .48934 .62714 L p
1 g
F P
s
P
p
.002 w
.30602 .39927 m .30403 .45005 L .30699 .43409 L p
1 g
F P
s
P
p
.002 w
.30699 .43409 m .30912 .38094 L .30602 .39927 L p
1 g
F P
s
P
p
.002 w
.30645 .46608 m .32103 .51331 L .3197 .50095 L p
1 g
F P
s
P
p
.002 w
.3197 .50095 m .30403 .45005 L .30645 .46608 L p
1 g
F P
s
P
p
.002 w
.3306 .33327 m .30912 .38094 L .31729 .36461 L p
1 g
F P
s
P
p
.002 w
.31729 .36461 m .33918 .31607 L .3306 .33327 L p
1 g
F P
s
P
p
.002 w
.69315 .47117 m .67215 .52066 L .66536 .53799 L p
1 g
F P
s
P
p
.002 w
.67215 .52066 m .69315 .47117 L .69422 .45382 L p
1 g
F P
s
P
p
.002 w
.69048 .38517 m .67168 .33315 L .66429 .32655 L p
1 g
F P
s
P
p
.002 w
.63161 .28522 m .66429 .32655 L .67168 .33315 L p
1 g
F P
s
P
p
.002 w
.35338 .56246 m .38953 .59408 L .39023 .59166 L p
1 g
F P
s
P
p
.002 w
.39023 .59166 m .34997 .55642 L .35338 .56246 L p
1 g
F P
s
P
p
.002 w
.4381 .61598 m .39023 .59166 L .38953 .59408 L p
1 g
F P
s
P
p
.002 w
.58535 .25286 m .52858 .23521 L .5362 .23887 L p
1 g
F P
s
P
p
.002 w
.5362 .23887 m .58702 .25469 L .58535 .25286 L p
1 g
F P
s
P
p
.002 w
.38953 .59408 m .43251 .61593 L .4381 .61598 L p
1 g
F P
s
P
p
.002 w
.48934 .62714 m .4381 .61598 L .43251 .61593 L p
1 g
F P
s
P
p
.002 w
.69422 .45382 m .69477 .39879 L .69048 .38517 L p
1 g
F P
s
P
p
.002 w
.69477 .39879 m .69422 .45382 L .69315 .47117 L p
1 g
F P
s
P
p
.004 w
.56907 .63215 m
.59643 .71201 L
s
P
p
.002 w
.37964 .2788 m .33918 .31607 L .35185 .30259 L p
1 g
F P
s
P
p
.002 w
.35185 .30259 m .39187 .26568 L .37964 .2788 L p
1 g
F P
s
P
p
.002 w
.67168 .33315 m .69048 .38517 L .69477 .39879 L p
1 g
F P
s
P
p
.002 w
.32746 .52385 m .35338 .56246 L .34997 .55642 L p
1 g
F P
s
P
p
.002 w
.34997 .55642 m .32103 .51331 L .32746 .52385 L p
1 g
F P
s
P
p
.002 w
.67168 .33315 m .6352 .287 L .63161 .28522 L p
1 g
F P
s
P
p
.002 w
.58702 .25469 m .63161 .28522 L .6352 .287 L p
1 g
F P
s
P
p
.002 w
.6352 .287 m .58535 .25286 L .58702 .25469 L p
1 g
F P
s
P
p
.002 w
.48934 .62714 m .53934 .62375 L .5539 .61929 L p
1 g
F P
s
P
p
.002 w
.5539 .61929 m .60134 .59959 L .61604 .58926 L p
1 g
F P
s
P
p
.002 w
.60134 .59959 m .5539 .61929 L .53934 .62375 L p
1 g
F P
s
P
p
.002 w
.51983 .23692 m .45913 .23773 L .47227 .23598 L p
1 g
F P
s
P
p
.002 w
.47227 .23598 m .52858 .23521 L .51983 .23692 L p
1 g
F P
s
P
p
.002 w
.44662 .24506 m .39187 .26568 L .40662 .25756 L p
1 g
F P
s
P
p
.002 w
.40662 .25756 m .45913 .23773 L .44662 .24506 L p
1 g
F P
s
P
p
.002 w
.61604 .58926 m .65367 .55295 L .66536 .53799 L p
1 g
F P
s
P
p
.002 w
.65367 .55295 m .61604 .58926 L .60134 .59959 L p
1 g
F P
s
P
p
.002 w
.43251 .61593 m .47844 .62594 L .48934 .62714 L p
1 g
F P
s
P
p
.002 w
.53934 .62375 m .48934 .62714 L .47844 .62594 L p
1 g
F P
s
P
p
.002 w
.30835 .41916 m .30645 .46608 L .30403 .45005 L p
1 g
F P
s
P
p
.002 w
.30403 .45005 m .30602 .39927 L .30835 .41916 L p
1 g
F P
s
P
p
.002 w
.3145 .48171 m .32746 .52385 L .32103 .51331 L p
1 g
F P
s
P
p
.002 w
.32103 .51331 m .30645 .46608 L .3145 .48171 L p
1 g
F P
s
P
p
.002 w
.32658 .35389 m .30602 .39927 L .30912 .38094 L p
1 g
F P
s
P
p
.002 w
.30912 .38094 m .3306 .33327 L .32658 .35389 L p
1 g
F P
s
P
p
.002 w
.66536 .53799 m .68658 .48802 L .69315 .47117 L p
1 g
F P
s
P
p
.002 w
.68658 .48802 m .66536 .53799 L .65367 .55295 L p
1 g
F P
s
P
p
.002 w
.69477 .39879 m .67452 .34278 L .67168 .33315 L p
1 g
F P
s
P
p
.002 w
.6352 .287 m .67168 .33315 L .67452 .34278 L p
1 g
F P
s
P
p
.002 w
.58117 .25604 m .51983 .23692 L .52858 .23521 L p
1 g
F P
s
P
p
.002 w
.52858 .23521 m .58535 .25286 L .58117 .25604 L p
1 g
F P
s
P
p
.002 w
.69371 .41386 m .69315 .47117 L .68658 .48802 L p
1 g
F P
s
P
p
.002 w
.69315 .47117 m .69371 .41386 L .69477 .39879 L p
1 g
F P
s
P
p
.002 w
.37044 .29679 m .3306 .33327 L .33918 .31607 L p
1 g
F P
s
P
p
.002 w
.33918 .31607 m .37964 .2788 L .37044 .29679 L p
1 g
F P
s
P
p
.002 w
.36112 .56499 m .39194 .59197 L .38953 .59408 L p
1 g
F P
s
P
p
.002 w
.38953 .59408 m .35338 .56246 L .36112 .56499 L p
1 g
F P
s
P
p
.002 w
.43251 .61593 m .38953 .59408 L .39194 .59197 L p
1 g
F P
s
P
p
.002 w
.67452 .34278 m .69477 .39879 L .69371 .41386 L p
1 g
F P
s
P
p
.002 w
.39194 .59197 m .4286 .6106 L .43251 .61593 L p
1 g
F P
s
P
p
.002 w
.47844 .62594 m .43251 .61593 L .4286 .6106 L p
1 g
F P
s
P
p
.002 w
.3391 .53213 m .36112 .56499 L .35338 .56246 L p
1 g
F P
s
P
p
.002 w
.35338 .56246 m .32746 .52385 L .3391 .53213 L p
1 g
F P
s
P
p
.002 w
.47844 .62594 m .52308 .62289 L .53934 .62375 L p
1 g
F P
s
P
p
.002 w
.58321 .60551 m .53934 .62375 L .52308 .62289 L p
1 g
F P
s
P
p
.002 w
.53934 .62375 m .58321 .60551 L .60134 .59959 L p
1 g
F P
s
P
p
.004 w
.56271 .61359 m
.56505 .62042 L
s
P
p
.004 w
.5 .43051 m
.56204 .61163 L
s
P
p
.004 w
.56224 .61222 m
.56271 .61359 L
s
P
p
.002 w
.67452 .34278 m .63509 .29296 L .6352 .287 L p
1 g
F P
s
P
p
.002 w
.58535 .25286 m .6352 .287 L .63509 .29296 L p
1 g
F P
s
P
p
.002 w
.43518 .25806 m .37964 .2788 L .39187 .26568 L p
1 g
F P
s
P
p
.002 w
.39187 .26568 m .44662 .24506 L .43518 .25806 L p
1 g
F P
s
P
p
.002 w
.63717 .56493 m .60134 .59959 L .58321 .60551 L p
1 g
F P
s
P
p
.002 w
.60134 .59959 m .63717 .56493 L .65367 .55295 L p
1 g
F P
s
P
p
.002 w
.63509 .29296 m .58117 .25604 L .58535 .25286 L p
1 g
F P
s
P
p
.002 w
.51012 .24432 m .44662 .24506 L .45913 .23773 L p
1 g
F P
s
P
p
.002 w
.45913 .23773 m .51983 .23692 L .51012 .24432 L p
1 g
F P
s
P
p
.002 w
.31634 .44006 m .3145 .48171 L .30645 .46608 L p
1 g
F P
s
P
p
.002 w
.30645 .46608 m .30835 .41916 L .31634 .44006 L p
1 g
F P
s
P
p
.002 w
.4286 .6106 m .46771 .61909 L .47844 .62594 L p
1 g
F P
s
P
p
.002 w
.52308 .62289 m .47844 .62594 L .46771 .61909 L p
1 g
F P
s
P
p
.002 w
.6744 .50384 m .65367 .55295 L .63717 .56493 L p
1 g
F P
s
P
p
.002 w
.65367 .55295 m .6744 .50384 L .68658 .48802 L p
1 g
F P
s
P
p
.002 w
.32751 .37745 m .30835 .41916 L .30602 .39927 L p
1 g
F P
s
P
p
.002 w
.30602 .39927 m .32658 .35389 L .32751 .37745 L p
1 g
F P
s
P
p
.002 w
.32824 .49643 m .3391 .53213 L .32746 .52385 L p
1 g
F P
s
P
p
.002 w
.32746 .52385 m .3145 .48171 L .32824 .49643 L p
1 g
F P
s
P
p
.002 w
.69371 .41386 m .67245 .35536 L .67452 .34278 L p
1 g
F P
s
P
p
.002 w
.63509 .29296 m .67452 .34278 L .67245 .35536 L p
1 g
F P
s
P
p
.002 w
.36475 .31935 m .32658 .35389 L .3306 .33327 L p
1 g
F P
s
P
p
.002 w
.3306 .33327 m .37044 .29679 L .36475 .31935 L p
1 g
F P
s
P
p
.002 w
.68701 .43001 m .68658 .48802 L .6744 .50384 L p
1 g
F P
s
P
p
.002 w
.68658 .48802 m .68701 .43001 L .69371 .41386 L p
1 g
F P
s
P
p
.002 w
.57444 .26444 m .51012 .24432 L .51983 .23692 L p
1 g
F P
s
P
p
.002 w
.51983 .23692 m .58117 .25604 L .57444 .26444 L p
1 g
F P
s
P
p
.002 w
.67245 .35536 m .69371 .41386 L .68701 .43001 L p
1 g
F P
s
P
p
.002 w
.37322 .56372 m .39759 .58508 L .39194 .59197 L p
1 g
F P
s
P
p
.002 w
.39194 .59197 m .36112 .56499 L .37322 .56372 L p
1 g
F P
s
P
p
.002 w
.4286 .6106 m .39194 .59197 L .39759 .58508 L p
1 g
F P
s
P
p
.002 w
.52308 .62289 m .56203 .60656 L .58321 .60551 L p
1 g
F P
s
P
p
.004 w
.56505 .62042 m
.56907 .63215 L
s
P
p
.002 w
.61612 .57342 m .58321 .60551 L .56203 .60656 L p
1 g
F P
s
P
p
.002 w
.58321 .60551 m .61612 .57342 L .63717 .56493 L p
1 g
F P
s
P
p
.002 w
.46771 .61909 m .50554 .61642 L .52308 .62289 L p
1 g
F P
s
P
p
.002 w
.56203 .60656 m .52308 .62289 L .50554 .61642 L p
1 g
F P
s
P
p
.002 w
.39759 .58508 m .4266 .59981 L .4286 .6106 L p
1 g
F P
s
P
p
.002 w
.46771 .61909 m .4286 .6106 L .4266 .59981 L p
1 g
F P
s
P
p
.002 w
.42522 .27665 m .37044 .29679 L .37964 .2788 L p
1 g
F P
s
P
p
.002 w
.37964 .2788 m .43518 .25806 L .42522 .27665 L p
1 g
F P
s
P
p
.002 w
.35592 .53777 m .37322 .56372 L .36112 .56499 L p
1 g
F P
s
P
p
.002 w
.36112 .56499 m .3391 .53213 L .35592 .53777 L p
1 g
F P
s
P
p
.002 w
.49973 .25751 m .43518 .25806 L .44662 .24506 L p
1 g
F P
s
P
p
.002 w
.44662 .24506 m .51012 .24432 L .49973 .25751 L p
1 g
F P
s
P
p
.002 w
.67245 .35536 m .63104 .30318 L .63509 .29296 L p
1 g
F P
s
P
p
.002 w
.58117 .25604 m .63509 .29296 L .63104 .30318 L p
1 g
F P
s
P
p
.002 w
.33 .46136 m .32824 .49643 L .3145 .48171 L p
1 g
F P
s
P
p
.002 w
.3145 .48171 m .31634 .44006 L .33 .46136 L p
1 g
F P
s
P
p
.002 w
.63104 .30318 m .57444 .26444 L .58117 .25604 L p
1 g
F P
s
P
p
.002 w
.65668 .51806 m .63717 .56493 L .61612 .57342 L p
1 g
F P
s
P
p
.002 w
.63717 .56493 m .65668 .51806 L .6744 .50384 L p
1 g
F P
s
P
p
.002 w
.33357 .40329 m .31634 .44006 L .30835 .41916 L p
1 g
F P
s
P
p
.002 w
.30835 .41916 m .32751 .37745 L .33357 .40329 L p
1 g
F P
s
P
p
.002 w
.4266 .59981 m .45748 .60646 L .46771 .61909 L p
1 g
F P
s
P
p
.002 w
.50554 .61642 m .46771 .61909 L .45748 .60646 L p
1 g
F P
s
P
p
.002 w
.34752 .50971 m .35592 .53777 L .3391 .53213 L p
1 g
F P
s
P
p
.002 w
.3391 .53213 m .32824 .49643 L .34752 .50971 L p
1 g
F P
s
P
p
.002 w
.36292 .34592 m .32751 .37745 L .32658 .35389 L p
1 g
F P
s
P
p
.002 w
.32658 .35389 m .36475 .31935 L .36292 .34592 L p
1 g
F P
s
P
p
.002 w
.67455 .44676 m .6744 .50384 L .65668 .51806 L p
1 g
F P
s
P
p
.002 w
.6744 .50384 m .67455 .44676 L .68701 .43001 L p
1 g
F P
s
P
p
.002 w
.68701 .43001 m .66522 .37065 L .67245 .35536 L p
1 g
F P
s
P
p
.002 w
.63104 .30318 m .67245 .35536 L .66522 .37065 L p
1 g
F P
s
P
p
.002 w
.66522 .37065 m .68701 .43001 L .67455 .44676 L p
1 g
F P
s
P
p
.002 w
.50554 .61642 m .53831 .60248 L .56203 .60656 L p
1 g
F P
s
P
p
.002 w
.59097 .57797 m .56203 .60656 L .53831 .60248 L p
1 g
F P
s
P
p
.002 w
.56203 .60656 m .59097 .57797 L .61612 .57342 L p
1 g
F P
s
P
p
.002 w
.56522 .27812 m .49973 .25751 L .51012 .24432 L p
1 g
F P
s
P
p
.002 w
.51012 .24432 m .57444 .26444 L .56522 .27812 L p
1 g
F P
s
P
p
.002 w
.41719 .30047 m .36475 .31935 L .37044 .29679 L p
1 g
F P
s
P
p
.002 w
.37044 .29679 m .42522 .27665 L .41719 .30047 L p
1 g
F P
s
P
p
.002 w
.45748 .60646 m .48721 .60424 L .50554 .61642 L p
1 g
F P
s
P
p
.002 w
.53831 .60248 m .50554 .61642 L .48721 .60424 L p
1 g
F P
s
P
p
.002 w
.38958 .55845 m .4065 .57332 L .39759 .58508 L p
1 g
F P
s
P
p
.002 w
.39759 .58508 m .37322 .56372 L .38958 .55845 L p
1 g
F P
s
P
p
.002 w
.4266 .59981 m .39759 .58508 L .4065 .57332 L p
1 g
F P
s
P
p
.004 w
.39387 .5988 m
.40593 .57967 L
s
P
p
.002 w
.4065 .57332 m .42669 .58356 L .4266 .59981 L p
1 g
F P
s
P
p
.002 w
.45748 .60646 m .4266 .59981 L .42669 .58356 L p
1 g
F P
s
P
p
.002 w
.48896 .27638 m .42522 .27665 L .43518 .25806 L p
1 g
F P
s
P
p
.002 w
.43518 .25806 m .49973 .25751 L .48896 .27638 L p
1 g
F P
s
P
p
.002 w
.63376 .53012 m .61612 .57342 L .59097 .57797 L p
1 g
F P
s
P
p
.002 w
.61612 .57342 m .63376 .53012 L .65668 .51806 L p
1 g
F P
s
P
p
.002 w
.34914 .48234 m .34752 .50971 L .32824 .49643 L p
1 g
F P
s
P
p
.002 w
.32824 .49643 m .33 .46136 L .34914 .48234 L p
1 g
F P
s
P
p
.002 w
.34479 .43065 m .33 .46136 L .31634 .44006 L p
1 g
F P
s
P
p
.002 w
.31634 .44006 m .33357 .40329 L .34479 .43065 L p
1 g
F P
s
P
p
.002 w
.37764 .54042 m .38958 .55845 L .37322 .56372 L p
1 g
F P
s
P
p
.002 w
.37322 .56372 m .35592 .53777 L .37764 .54042 L p
1 g
F P
s
P
p
.002 w
.66522 .37065 m .62293 .3176 L .63104 .30318 L p
1 g
F P
s
P
p
.002 w
.57444 .26444 m .63104 .30318 L .62293 .3176 L p
1 g
F P
s
P
p
.002 w
.62293 .3176 m .56522 .27812 L .57444 .26444 L p
1 g
F P
s
P
p
.002 w
.42669 .58356 m .44813 .58811 L .45748 .60646 L p
1 g
F P
s
P
p
.002 w
.48721 .60424 m .45748 .60646 L .44813 .58811 L p
1 g
F P
s
P
p
.002 w
.36518 .37575 m .33357 .40329 L .32751 .37745 L p
1 g
F P
s
P
p
.002 w
.32751 .37745 m .36292 .34592 L .36518 .37575 L p
1 g
F P
s
P
p
.002 w
.37197 .52102 m .37764 .54042 L .35592 .53777 L p
1 g
F P
s
P
p
.002 w
.35592 .53777 m .34752 .50971 L .37197 .52102 L p
1 g
F P
s
P
p
.002 w
.65645 .46359 m .65668 .51806 L .63376 .53012 L p
1 g
F P
s
P
p
.002 w
.65668 .51806 m .65645 .46359 L .67455 .44676 L p
1 g
F P
s
P
p
.002 w
.48721 .60424 m .51274 .59314 L .53831 .60248 L p
1 g
F P
s
P
p
.002 w
.56239 .57823 m .53831 .60248 L .51274 .59314 L p
1 g
F P
s
P
p
.002 w
.53831 .60248 m .56239 .57823 L .59097 .57797 L p
1 g
F P
s
P
p
.002 w
.67455 .44676 m .65277 .38829 L .66522 .37065 L p
1 g
F P
s
P
p
.002 w
.62293 .3176 m .66522 .37065 L .65277 .38829 L p
1 g
F P
s
P
p
.002 w
.65277 .38829 m .67455 .44676 L .65645 .46359 L p
1 g
F P
s
P
p
.002 w
.41144 .32894 m .36292 .34592 L .36475 .31935 L p
1 g
F P
s
P
p
.002 w
.36475 .31935 m .41719 .30047 L .41144 .32894 L p
1 g
F P
s
P
p
.002 w
.44813 .58811 m .46866 .58646 L .48721 .60424 L p
1 g
F P
s
P
p
.002 w
.51274 .59314 m .48721 .60424 L .46866 .58646 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.60617 .53952 m .59097 .57797 L .56239 .57823 L p
1 g
F P
s
P
p
.002 w
.59097 .57797 m .60617 .53952 L .63376 .53012 L p
1 g
F P
s
P
p
.002 w
.55369 .29692 m .48896 .27638 L .49973 .25751 L p
1 g
F P
s
P
p
.002 w
.49973 .25751 m .56522 .27812 L .55369 .29692 L p
1 g
F P
s
P
p
.002 w
.36096 .45858 m .34914 .48234 L .33 .46136 L p
1 g
F P
s
P
p
.002 w
.33 .46136 m .34479 .43065 L .36096 .45858 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37329 .50224 m .37197 .52102 L .34752 .50971 L p
1 g
F P
s
P
p
.002 w
.34752 .50971 m .34914 .48234 L .37329 .50224 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.47817 .30057 m .41719 .30047 L .42522 .27665 L p
1 g
F P
s
P
p
.002 w
.42522 .27665 m .48896 .27638 L .47817 .30057 L p
1 g
F P
s
P
p
.002 w
.40986 .54913 m .41857 .55682 L .4065 .57332 L p
1 g
F P
s
P
p
.002 w
.4065 .57332 m .38958 .55845 L .40986 .54913 L p
1 g
F P
s
P
p
.002 w
.42669 .58356 m .4065 .57332 L .41857 .55682 L p
1 g
F P
s
P
p
.002 w
.41857 .55682 m .42899 .56209 L .42669 .58356 L p
1 g
F P
s
P
p
.002 w
.44813 .58811 m .42669 .58356 L .42899 .56209 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.40376 .53983 m .40986 .54913 L .38958 .55845 L p
1 g
F P
s
P
p
.002 w
.38958 .55845 m .37764 .54042 L .40376 .53983 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.3716 .40789 m .34479 .43065 L .33357 .40329 L p
1 g
F P
s
P
p
.002 w
.33357 .40329 m .36518 .37575 L .3716 .40789 L p
1 g
F P
s
P
p
.002 w
.65277 .38829 m .61081 .33597 L .62293 .3176 L p
1 g
F P
s
P
p
.002 w
.56522 .27812 m .62293 .3176 L .61081 .33597 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63309 .47991 m .63376 .53012 L .60617 .53952 L p
1 g
F P
s
P
p
.002 w
.63376 .53012 m .63309 .47991 L .65645 .46359 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.42899 .56209 m .44004 .56439 L .44813 .58811 L p
1 g
F P
s
P
p
.002 w
.46866 .58646 m .44813 .58811 L .44004 .56439 L p
1 g
F P
s
P
p
.002 w
.61081 .33597 m .55369 .29692 L .56522 .27812 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.004 w
.44855 .51209 m
.5 .43051 L
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.40095 .52988 m .40376 .53983 L .37764 .54042 L p
1 g
F P
s
P
p
.002 w
.37764 .54042 m .37197 .52102 L .40095 .52988 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.46866 .58646 m .48163 .58067 L p
.51274 .59314 L 1 g
F P
s
P
p
.002 w
.48163 .58067 m .48371 .57975 L p
.48606 .58083 L 1 g
F P
s
P
p
.51274 .59314 m .48163 .58067 L .48606 .58083 L 1 g
F
P
p
.002 w
.49121 .58143 m .51274 .59314 L p
.48606 .58083 L 1 g
F P
s
P
p
.48606 .58083 m .48371 .57975 L .48904 .58094 L 1 g
F
P
p
.48606 .58083 m .48904 .58094 L .49121 .58143 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58094 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58094 L .49041 .58099 L 1 g
F
P
p
.002 w
.52564 .57985 m .51274 .59314 L .49594 .584 L p
1 g
F P
s
P
p
.002 w
.49594 .584 m .49041 .58099 L p
.51092 .58032 L 1 g
F P
s
P
p
.52564 .57985 m .49594 .584 L .51092 .58032 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58032 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58032 L .52128 .57778 L 1 g
F
P
p
.51079 .57862 m .49041 .58099 L .50059 .58066 L 1 g
F
P
p
.002 w
.51102 .58173 m .51079 .57862 L p
.49763 .58125 L 1 g
F P
s
P
p
.002 w
.48904 .58094 m .48921 .57862 L p
.47759 .57767 L 1 g
F P
s
P
p
.002 w
.46866 .58646 m .45591 .57028 L p
.46832 .5745 L 1 g
F P
s
P
p
.002 w
.48371 .57975 m .47973 .58152 L p
.46832 .5745 L 1 g
F P
s
P
p
.002 w
.47973 .58152 m .46866 .58646 L p
.46832 .5745 L 1 g
F P
s
P
p
.002 w
.46832 .5745 m .46872 .57265 L p
.45895 .56875 L 1 g
F P
s
P
p
.47759 .57767 m .48371 .57975 L .48904 .58094 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4506 .56361 L p
1 g
F P
s
P
p
.46866 .58646 m .4504 .56348 L .4506 .56361 L 1 g
F
P
p
.002 w
.45072 .56369 m .45097 .564 L p
.4506 .56361 L 1 g
F P
s
P
p
.002 w
.45097 .564 m .46866 .58646 L p
.4506 .56361 L 1 g
F P
s
P
p
.45146 .56129 m .44402 .55482 L .44518 .55638 L 1 g
F
P
p
.002 w
.44004 .56439 m .43515 .54294 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.45047 .56347 m .44441 .564 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.44441 .564 m .44004 .56439 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.43839 .54728 m .43925 .54566 L p
.43433 .53593 L 1 g
F P
s
P
p
.43433 .53593 m .43435 .53598 L .43839 .54728 L 1 g
F
P
p
.43432 .53591 m .4344 .53615 L .43839 .54728 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43438 .53607 m .43354 .53589 L .4343 .53584 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52882 L p
1 g
F P
s
P
p
.002 w
.43363 .53336 m .43354 .53589 L p
.43231 .5307 L 1 g
F P
s
P
p
.42592 .50376 m .43244 .52882 L .43231 .5307 L 1 g
F
P
p
.43244 .52882 m .43363 .53336 L .43231 .5307 L 1 g
F
P
p
.002 w
.43354 .53589 m .42347 .50363 L .42592 .50376 L p
1 g
F P
s
P
p
.002 w
.43244 .52882 m .43346 .52734 L p
.43316 .51872 L 1 g
F P
s
P
p
.43925 .54566 m .43244 .52882 L .43248 .52897 L 1 g
F
P
p
.43925 .54566 m .43243 .52884 L .43254 .52925 L 1 g
F
P
p
.43925 .54566 m .43239 .52889 L .43257 .52954 L 1 g
F
P
p
.43925 .54566 m .43234 .52898 L .43258 .52981 L 1 g
F
P
p
.43925 .54566 m .43227 .52908 L .43322 .53224 L 1 g
F
P
p
.002 w
.43401 .53482 m .43354 .53589 L .43363 .53336 L p
1 g
F P
s
P
p
.002 w
.43415 .53531 m .43354 .53589 L .43401 .53482 L p
1 g
F P
s
P
p
.002 w
.43423 .53561 m .43354 .53589 L .43415 .53531 L p
1 g
F P
s
P
p
.43925 .54566 m .43198 .52949 L .43423 .53573 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43381 .50949 L p
1 g
F P
s
P
p
.43346 .52734 m .43381 .50949 L .43316 .51872 L 1 g
F
P
p
.002 w
.43461 .50419 m .43448 .50805 L p
.43422 .50861 L 1 g
F P
s
P
p
.002 w
.42592 .50376 m .43419 .50417 L p
.43244 .52882 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43461 .50419 m .43511 .49859 L p
.44238 .49181 L 1 g
F P
s
P
p
.44233 .4916 m .44238 .49181 L .43511 .49859 L 1 g
F
P
p
.002 w
.43603 .50469 m .43461 .50419 L p
.44238 .49181 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44263 .49131 L p
1 g
F P
s
P
p
.002 w
.43773 .46963 m .45107 .47418 L p
.44238 .49181 L 1 g
F P
s
P
p
.002 w
.44263 .49131 m .44166 .49233 L p
.43864 .4994 L 1 g
F P
s
P
p
.43485 .50826 m .44263 .49131 L .43864 .4994 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45997 .47723 m .44578 .50806 L p
.44238 .49181 L 1 g
F P
s
P
p
.002 w
.44263 .49131 m .44339 .4905 L p
.45031 .48387 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45753 .47688 L p
1 g
F P
s
P
p
.45753 .47688 m .45997 .47723 L .44263 .49131 L 1 g
F
P
p
.002 w
.47977 .49067 m .45997 .47723 L .4609 .47528 L p
1 g
F P
s
P
p
.002 w
.45753 .47688 m .45826 .47608 L p
.46642 .47258 L 1 g
F P
s
P
p
.46642 .47258 m .46145 .47501 L .45753 .47688 L 1 g
F
P
p
.46784 .47197 m .45813 .4766 L .45753 .47688 L 1 g
F
P
p
.4776 .4671 m .47977 .49067 L .4609 .47528 L 1 g
F
P
p
.002 w
.4776 .4671 m .47786 .46667 L p
.48784 .46565 L 1 g
F P
s
P
p
.47764 .46708 m .47764 .4671 L .4776 .4671 L 1 g
F
P
p
.47764 .4671 m .47977 .49067 L .4776 .4671 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.49481 .50837 m .47977 .49067 L .50441 .46469 L p
1 g
F P
s
P
p
.50466 .46472 m .49481 .50837 L .50441 .46469 L 1 g
F
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52674 .49048 m .50514 .4648 L p
.52237 .46706 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54228 .47667 L p
1 g
F P
s
P
p
.52214 .46667 m .54228 .47667 L .53007 .47077 L 1 g
F
P
p
.52788 .46972 m .52674 .49048 L .52237 .46706 L 1 g
F
P
p
.002 w
.52237 .46706 m .52214 .46667 L p
.53007 .47077 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.57338 .50857 m .56676 .51073 L p
.56574 .50612 L 1 g
F P
s
P
p
.002 w
.56612 .50942 m .56515 .50826 L p
.56668 .51816 L 1 g
F P
s
P
p
.002 w
.56629 .51088 m .56676 .51073 L p
.56632 .51137 L 1 g
F P
s
P
p
.56668 .51816 m .56629 .51088 L .56612 .50942 L 1 g
F
P
p
.56849 .51454 m .56661 .51684 L .56676 .51073 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56721 .52832 L p
1 g
F P
s
P
p
.57338 .50857 m .56817 .54638 L .56721 .52832 L 1 g
F
P
p
.57282 .50926 m .56721 .52832 L .56661 .51684 L 1 g
F
P
p
.57338 .50857 m .56721 .52832 L .57282 .50926 L 1 g
F
P
p
.002 w
.56721 .52832 m .56654 .52734 L p
.56496 .53601 L 1 g
F P
s
P
p
.56515 .50826 m .56721 .52832 L .56668 .51816 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54901 .56256 L p
1 g
F P
s
P
p
.57474 .54583 m .53874 .57505 L .54901 .56256 L 1 g
F
P
p
.54947 .56223 m .54901 .56256 L .54908 .56248 L 1 g
F
P
p
.57474 .54583 m .54901 .56256 L .54947 .56223 L 1 g
F
P
p
.002 w
.54901 .56256 m .54854 .56129 L p
.54109 .56839 L 1 g
F P
s
P
p
.56075 .54566 m .54901 .56256 L .55632 .55369 L 1 g
F
P
p
.53128 .57265 m .52519 .57682 L .52963 .57573 L 1 g
F
P
p
.002 w
.53371 .57437 m .56239 .57823 L p
.53042 .57579 L 1 g
F P
s
P
p
.53042 .57579 m .52963 .57573 L .5318 .57501 L 1 g
F
P
p
.53042 .57579 m .5318 .57501 L .53371 .57437 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5318 .57501 L p
1 g
F P
s
P
p
.002 w
.51274 .59314 m .52963 .57573 L p
.56239 .57823 L 1 g
F P
s
P
p
.54854 .56129 m .5318 .57501 L .53308 .57428 L 1 g
F
P
p
.54901 .56256 m .54246 .57053 L .535 .57287 L 1 g
F
P
p
.54854 .56129 m .53308 .57428 L .54109 .56839 L 1 g
F
P
p
.002 w
.53371 .57437 m .53308 .57428 L p
.54246 .57053 L 1 g
F P
s
P
p
.002 w
.5318 .57501 m .53128 .57265 L p
.52963 .57573 L 1 g
F P
s
P
p
.002 w
.53308 .57428 m .53127 .57404 L p
.535 .57287 L 1 g
F P
s
P
p
.54246 .57053 m .53308 .57428 L .535 .57287 L 1 g
F
P
p
.002 w
.52963 .57573 m .53127 .57404 L .53308 .57428 L p
1 g
F P
s
P
p
.002 w
.53308 .57428 m .53371 .57437 L p
.5318 .57501 L 1 g
F P
s
P
p
.5318 .57501 m .52963 .57573 L .53308 .57428 L 1 g
F
P
p
.002 w
.53874 .57505 m .53371 .57437 L p
.54246 .57053 L 1 g
F P
s
P
p
.53759 .57173 m .53308 .57428 L .5322 .57686 L 1 g
F
P
p
.002 w
.5318 .57501 m .53184 .5752 L p
.53308 .57428 L 1 g
F P
s
P
p
.002 w
.53184 .5752 m .5322 .57686 L p
.53308 .57428 L 1 g
F P
s
P
p
.54109 .56839 m .53308 .57428 L .53759 .57173 L 1 g
F
P
p
.54908 .56248 m .54901 .56256 L .53127 .57404 L 1 g
F
P
p
.54901 .56256 m .535 .57287 L .53127 .57404 L 1 g
F
P
p
.002 w
.53183 .57519 m .5318 .57501 L p
.52963 .57573 L 1 g
F P
s
P
p
.002 w
.52963 .57573 m .52564 .57985 L p
.51425 .57951 L 1 g
F P
s
P
p
.52564 .57985 m .51092 .58032 L .51425 .57951 L 1 g
F
P
p
.002 w
.51111 .583 m .51991 .58044 L p
.52519 .57682 L 1 g
F P
s
P
p
.53128 .57265 m .52128 .57778 L .52519 .57682 L 1 g
F
P
p
.52128 .57778 m .51111 .583 L .52519 .57682 L 1 g
F
P
p
.002 w
.49041 .58099 m .48614 .57867 L p
.51425 .57951 L 1 g
F P
s
P
p
.51092 .58032 m .49041 .58099 L .51425 .57951 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53127 .57404 m .52963 .57573 L p
.48614 .57867 L 1 g
F P
s
P
p
.52963 .57573 m .51425 .57951 L .48614 .57867 L 1 g
F
P
p
.002 w
.53184 .5752 m .53183 .57519 L p
.51991 .58044 L 1 g
F P
s
P
p
.52519 .57682 m .51991 .58044 L .53183 .57519 L 1 g
F
P
p
.002 w
.51991 .58044 m .5322 .57686 L .53184 .5752 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54901 .56256 L p
1 g
F P
s
P
p
.54109 .56839 m .5322 .57686 L .54901 .56256 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.57474 .54583 m .55762 .55694 L .56161 .54727 L 1 g
F
P
p
.002 w
.56161 .54727 m .56075 .54566 L p
.55632 .55369 L 1 g
F P
s
P
p
.002 w
.56175 .54692 m .56191 .54691 L p
.56161 .54727 L 1 g
F P
s
P
p
.002 w
.56191 .54691 m .57474 .54583 L p
.56161 .54727 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56163 .54732 L p
1 g
F P
s
P
p
.56654 .52734 m .56163 .54732 L .56496 .53601 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56661 .51684 m .56721 .52832 L .5405 .54871 L 1 g
F
P
p
.002 w
.56817 .54638 m .56175 .54692 L p
.56721 .52832 L 1 g
F P
s
P
p
.002 w
.56175 .54692 m .5405 .54871 L p
.56721 .52832 L 1 g
F P
s
P
p
.002 w
.56163 .54732 m .56257 .5491 L p
.56496 .53601 L 1 g
F P
s
P
p
.55762 .55694 m .53127 .57404 L .56175 .54692 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56161 .54727 L p
1 g
F P
s
P
p
.55632 .55369 m .54998 .56518 L .56161 .54727 L 1 g
F
P
p
.002 w
.53127 .57404 m .5405 .54871 L .56175 .54692 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56721 .52832 L p
.56461 .53999 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56828 .53108 L p
.56461 .53999 L 1 g
F P
s
P
p
.002 w
.56828 .53108 m .56854 .53025 L p
.56461 .53999 L 1 g
F P
s
P
p
.002 w
.54901 .56256 m .54998 .56518 L p
.55632 .55369 L 1 g
F P
s
P
p
.002 w
.57474 .54583 m .56239 .57823 L .53874 .57505 L p
1 g
F P
s
P
p
.56496 .53601 m .56257 .5491 L .56721 .52832 L 1 g
F
P
p
.002 w
.56721 .52832 m .56854 .53025 L p
.56668 .51816 L 1 g
F P
s
P
p
.002 w
.57338 .50857 m .57474 .54583 L .56817 .54638 L p
1 g
F P
s
P
p
.56661 .51684 m .5405 .54871 L .56632 .51137 L 1 g
F
P
p
.56661 .51684 m .56632 .51137 L .56676 .51073 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56612 .50942 L p
1 g
F P
s
P
p
.55661 .4905 m .56612 .50942 L .56499 .5071 L 1 g
F
P
p
.56384 .49756 m .56676 .51073 L .55719 .49111 L 1 g
F
P
p
.55661 .4905 m .56622 .50953 L .56398 .50459 L 1 g
F
P
p
.002 w
.56676 .51073 m .57338 .50857 L p
.56849 .51454 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55719 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55719 .49111 L .54908 .48326 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55198 .48608 m .56612 .50942 L .53905 .51977 L 1 g
F
P
p
.55319 .48293 m .55719 .49111 L .55198 .48608 L 1 g
F
P
p
.55719 .49111 m .56612 .50942 L .55198 .48608 L 1 g
F
P
p
.002 w
.54241 .47682 m .54174 .47608 L p
.54908 .48326 L 1 g
F P
s
P
p
.002 w
.52969 .4368 m .55788 .47069 L .54472 .47905 L p
1 g
F P
s
P
p
.002 w
.54472 .47905 m .52674 .49048 L p
.52825 .46299 L 1 g
F P
s
P
p
.52969 .4368 m .54472 .47905 L .52825 .46299 L 1 g
F
P
p
.002 w
.53905 .51977 m .52674 .49048 L .55788 .47069 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54241 .47682 L p
1 g
F P
s
P
p
.54908 .48326 m .55834 .49233 L .54241 .47682 L 1 g
F
P
p
.002 w
.55719 .49111 m .55834 .49233 L p
.54908 .48326 L 1 g
F P
s
P
p
.55788 .47069 m .56384 .49756 L .55319 .48293 L 1 g
F
P
p
.56384 .49756 m .55719 .49111 L .55319 .48293 L 1 g
F
P
p
.002 w
.56676 .51073 m .56629 .51088 L p
.56612 .50942 L 1 g
F P
s
P
p
.002 w
.56629 .51088 m .53905 .51977 L p
.56612 .50942 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56622 .50953 L p
1 g
F P
s
P
p
.002 w
.56622 .50953 m .56612 .50942 L p
.56629 .51087 L 1 g
F P
s
P
p
.56629 .51087 m .56854 .53025 L .56622 .50953 L 1 g
F
P
p
.56668 .51816 m .5685 .52997 L .56629 .51088 L 1 g
F
P
p
.002 w
.5405 .54871 m .53905 .51977 L .56629 .51088 L p
1 g
F P
s
P
p
.56632 .51137 m .5405 .54871 L .56629 .51088 L 1 g
F
P
p
.5685 .52997 m .56854 .53025 L .56612 .50942 L 1 g
F
P
p
.002 w
.55788 .47069 m .56313 .48351 L p
.56574 .50612 L 1 g
F P
s
P
p
.002 w
.56313 .48351 m .57338 .50857 L p
.56574 .50612 L 1 g
F P
s
P
p
.002 w
.56612 .50942 m .56622 .50953 L p
.56499 .5071 L 1 g
F P
s
P
p
.002 w
.56622 .50953 m .56713 .51061 L p
.56398 .50459 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46706 L p
1 g
F P
s
P
p
.53007 .47077 m .54302 .47747 L .52237 .46706 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52282 .46778 L p
1 g
F P
s
P
p
.52969 .4368 m .52799 .4678 L .52208 .46692 L 1 g
F
P
p
.51119 .46559 m .51503 .46629 L .51384 .46611 L 1 g
F
P
p
.5 .4634 m .51185 .46568 L .51119 .46559 L 1 g
F
P
p
.51185 .46568 m .51503 .46629 L .51119 .46559 L 1 g
F
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50475 .46433 m .50839 .46031 L p
.52208 .46692 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.50839 .46031 m .52969 .4368 L p
.52208 .46692 L 1 g
F P
s
P
p
.52799 .4678 m .52788 .46972 L .52237 .46706 L 1 g
F
P
p
.002 w
.54228 .47667 m .54302 .47747 L p
.53007 .47077 L 1 g
F P
s
P
p
.002 w
.5 .46393 m .5 .4634 L p
.51119 .46559 L 1 g
F P
s
P
p
.51119 .46559 m .50724 .46507 L .5 .46393 L 1 g
F
P
p
.51384 .46611 m .50441 .46469 L .5 .46393 L 1 g
F
P
p
.002 w
.50514 .4648 m .50475 .46433 L p
.52799 .4678 L 1 g
F P
s
P
p
.51119 .46559 m .51384 .46611 L .50724 .46507 L 1 g
F
P
p
.002 w
.52674 .49048 m .49481 .50837 L p
.50466 .46472 L 1 g
F P
s
P
p
.002 w
.50514 .4648 m .52674 .49048 L p
.50466 .46472 L 1 g
F P
s
P
p
.51384 .46611 m .52114 .46754 L .50441 .46469 L 1 g
F
P
p
.002 w
.50475 .46433 m .50514 .4648 L p
.50466 .46472 L 1 g
F P
s
P
p
.002 w
.50441 .46469 m .50475 .46433 L p
.50466 .46472 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .52114 .46754 L p
.51384 .46611 L 1 g
F P
s
P
p
.51503 .46629 m .52282 .46778 L .51384 .46611 L 1 g
F
P
p
.47764 .46708 m .50323 .46448 L .47977 .49067 L 1 g
F
P
p
.002 w
.50441 .46469 m .47977 .49067 L p
.50323 .46448 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46393 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46393 L .48784 .46565 L 1 g
F
P
p
.002 w
.49575 .45822 m .50345 .46345 L p
.47764 .46708 L 1 g
F P
s
P
p
.002 w
.50345 .46345 m .50475 .46433 L p
.47801 .46705 L 1 g
F P
s
P
p
.50345 .46345 m .47801 .46705 L .47764 .46708 L 1 g
F
P
p
.002 w
.5 .46393 m .5 .46442 L p
.48784 .46565 L 1 g
F P
s
P
p
.002 w
.52114 .46754 m .5 .46442 L .5 .46393 L p
1 g
F P
s
P
p
.002 w
.50475 .46433 m .50441 .46469 L p
.50323 .46448 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .4671 L p
1 g
F P
s
P
p
.002 w
.4756 .44452 m .49575 .45822 L p
.47764 .46708 L 1 g
F P
s
P
p
.002 w
.4776 .4671 m .47718 .46778 L p
.4679 .47185 L 1 g
F P
s
P
p
.45826 .47608 m .4776 .4671 L .4679 .47185 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .4671 L p
1 g
F P
s
P
p
.48784 .46565 m .5 .46442 L .4776 .4671 L 1 g
F
P
p
.002 w
.47718 .46778 m .47371 .46945 L p
.46784 .47197 L 1 g
F P
s
P
p
.45826 .47608 m .47013 .47087 L .46784 .47197 L 1 g
F
P
p
.47013 .47087 m .47718 .46778 L .46784 .47197 L 1 g
F
P
p
.002 w
.44283 .43347 m .4756 .44452 L .4609 .47528 L p
1 g
F P
s
P
p
.002 w
.4609 .47528 m .45997 .47723 L p
.45948 .47596 L 1 g
F P
s
P
p
.44283 .43347 m .4609 .47528 L .45948 .47596 L 1 g
F
P
p
.002 w
.4609 .47528 m .4756 .44452 L p
.47764 .46708 L 1 g
F P
s
P
p
.46642 .47258 m .46784 .47197 L .46145 .47501 L 1 g
F
P
p
.002 w
.45997 .47723 m .45813 .4766 L p
.45948 .47596 L 1 g
F P
s
P
p
.46784 .47197 m .47371 .46945 L .45813 .4766 L 1 g
F
P
p
.002 w
.43773 .46963 m .44283 .43347 L p
.45948 .47596 L 1 g
F P
s
P
p
.002 w
.45813 .4766 m .43773 .46963 L p
.45948 .47596 L 1 g
F P
s
P
p
.002 w
.4579 .47652 m .45813 .4766 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.45813 .4766 m .45997 .47723 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.47371 .46945 m .45698 .47747 L .45753 .47688 L p
1 g
F P
s
P
p
.002 w
.45753 .47688 m .45698 .47747 L p
.45031 .48387 L 1 g
F P
s
P
p
.44339 .4905 m .45753 .47688 L .45031 .48387 L 1 g
F
P
p
.44263 .49131 m .45997 .47723 L .44238 .49181 L 1 g
F
P
p
.002 w
.45107 .47418 m .4579 .47652 L p
.44263 .49131 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44263 .49131 L p
1 g
F P
s
P
p
.45031 .48387 m .45698 .47747 L .44263 .49131 L 1 g
F
P
p
.002 w
.43511 .49859 m .43773 .46963 L p
.44233 .4916 L 1 g
F P
s
P
p
.002 w
.43381 .50949 m .43485 .50826 L p
.43864 .4994 L 1 g
F P
s
P
p
.43864 .4994 m .43606 .50463 L .43381 .50949 L 1 g
F
P
p
.44062 .49476 m .43448 .50805 L .43381 .50949 L 1 g
F
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44578 .50806 m .43603 .50469 L p
.44238 .49181 L 1 g
F P
s
P
p
.43864 .4994 m .44062 .49476 L .43606 .50463 L 1 g
F
P
p
.002 w
.43461 .50419 m .43603 .50469 L p
.43453 .50793 L 1 g
F P
s
P
p
.002 w
.43363 .53336 m .43448 .50805 L p
.43401 .53482 L 1 g
F P
s
P
p
.002 w
.43448 .50805 m .43461 .50419 L p
.43453 .50793 L 1 g
F P
s
P
p
.43453 .50793 m .43401 .53482 L .43448 .50805 L 1 g
F
P
p
.002 w
.43419 .50417 m .43461 .50419 L p
.43422 .50861 L 1 g
F P
s
P
p
.43381 .50949 m .43422 .50861 L .43244 .52882 L 1 g
F
P
p
.43419 .50417 m .43422 .50861 L .43381 .50949 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43381 .5095 L p
1 g
F P
s
P
p
.002 w
.43381 .5095 m .43381 .50949 L p
.43406 .50895 L 1 g
F P
s
P
p
.43406 .50895 m .44166 .49233 L .43381 .5095 L 1 g
F
P
p
.44062 .49476 m .44095 .49399 L .43448 .50805 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44578 .50806 m .43401 .53482 L p
.43453 .50793 L 1 g
F P
s
P
p
.002 w
.43603 .50469 m .44578 .50806 L p
.43453 .50793 L 1 g
F P
s
P
p
.44095 .49399 m .44166 .49233 L .43381 .50949 L 1 g
F
P
p
.43244 .52882 m .43422 .50861 L .43363 .53336 L 1 g
F
P
p
.002 w
.43448 .50805 m .43363 .53336 L p
.43422 .50861 L 1 g
F P
s
P
p
.002 w
.43381 .50949 m .43287 .51061 L p
.43316 .51872 L 1 g
F P
s
P
p
.002 w
.41361 .50642 m .42347 .50363 L .43224 .53171 L p
1 g
F P
s
P
p
.002 w
.43224 .53171 m .43354 .53589 L .4321 .53376 L p
1 g
F P
s
P
p
.002 w
.4321 .53376 m .41361 .50642 L p
.43224 .53171 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43243 .52884 L p
1 g
F P
s
P
p
.002 w
.43243 .52884 m .43244 .52882 L p
.43245 .52858 L 1 g
F P
s
P
p
.43245 .52858 m .43287 .51061 L .43243 .52884 L 1 g
F
P
p
.43316 .51872 m .43287 .51061 L .43244 .52882 L 1 g
F
P
p
.002 w
.43244 .52882 m .43243 .52884 L p
.43248 .52897 L 1 g
F P
s
P
p
.002 w
.43243 .52884 m .43239 .52889 L p
.43254 .52925 L 1 g
F P
s
P
p
.002 w
.43239 .52889 m .43234 .52898 L p
.43257 .52954 L 1 g
F P
s
P
p
.002 w
.44578 .50806 m .45574 .51481 L .43415 .53531 L p
1 g
F P
s
P
p
.002 w
.43401 .53482 m .44578 .50806 L p
.43415 .53531 L 1 g
F P
s
P
p
.002 w
.45574 .51481 m .46335 .52368 L .43423 .53561 L p
1 g
F P
s
P
p
.002 w
.43415 .53531 m .45574 .51481 L p
.43423 .53561 L 1 g
F P
s
P
p
.002 w
.43234 .52898 m .43227 .52908 L p
.43258 .52981 L 1 g
F P
s
P
p
.002 w
.43227 .52908 m .43198 .52949 L p
.43322 .53224 L 1 g
F P
s
P
p
.002 w
.46335 .52368 m .46778 .53367 L .4343 .53584 L p
1 g
F P
s
P
p
.002 w
.4343 .53584 m .43354 .53589 L .43423 .53561 L p
1 g
F P
s
P
p
.002 w
.43423 .53561 m .46335 .52368 L p
.4343 .53584 L 1 g
F P
s
P
p
.4343 .53587 m .43457 .53665 L .43839 .54728 L 1 g
F
P
p
.002 w
.43448 .53637 m .43354 .53589 L .43438 .53607 L p
1 g
F P
s
P
p
.43427 .53581 m .43533 .53879 L .43839 .54728 L 1 g
F
P
p
.002 w
.4506 .56361 m .45146 .56129 L p
.44518 .55638 L 1 g
F P
s
P
p
.44518 .55638 m .43989 .55224 L .45047 .56347 L 1 g
F
P
p
.44518 .55638 m .45047 .56347 L .4506 .56361 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.45055 .56347 m .45047 .56347 L p
.43534 .53882 L 1 g
F P
s
P
p
.002 w
.43354 .53589 m .43533 .53879 L p
.43534 .53882 L 1 g
F P
s
P
p
.002 w
.43533 .53879 m .45055 .56347 L p
.43534 .53882 L 1 g
F P
s
P
p
.002 w
.43198 .52949 m .43146 .53025 L p
.43423 .53573 L 1 g
F P
s
P
p
.002 w
.46778 .53367 m .46857 .54366 L .43438 .53607 L p
1 g
F P
s
P
p
.002 w
.4343 .53584 m .46778 .53367 L p
.43438 .53607 L 1 g
F P
s
P
p
.43433 .53593 m .43432 .53591 L .43435 .53598 L 1 g
F
P
p
.43432 .53591 m .4343 .53587 L .4344 .53615 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46857 .54366 m .46565 .55255 L .43448 .53637 L p
1 g
F P
s
P
p
.002 w
.43438 .53607 m .46857 .54366 L p
.43448 .53637 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46565 .55255 m .45941 .55939 L .43466 .5369 L p
1 g
F P
s
P
p
.002 w
.43466 .5369 m .43354 .53589 L .43448 .53637 L p
1 g
F P
s
P
p
.002 w
.43448 .53637 m .46565 .55255 L p
.43466 .5369 L 1 g
F P
s
P
p
.4343 .53587 m .43427 .53581 L .43457 .53665 L 1 g
F
P
p
.43427 .53581 m .43423 .53573 L .43533 .53879 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45941 .55939 m .45055 .56347 L .43533 .53879 L p
1 g
F P
s
P
p
.002 w
.43533 .53879 m .43354 .53589 L .43466 .5369 L p
1 g
F P
s
P
p
.002 w
.43466 .5369 m .45941 .55939 L p
.43533 .53879 L 1 g
F P
s
P
p
.002 w
.43515 .54294 m .43354 .53589 L p
.45047 .56347 L 1 g
F P
s
P
p
.002 w
.41857 .55682 m .40986 .54913 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.42899 .56209 m .41857 .55682 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.44004 .56439 m .42899 .56209 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.40986 .54913 m .40376 .53983 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.40376 .53983 m .40095 .52988 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.40095 .52988 m .40174 .52033 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.40174 .52033 m .40611 .51221 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.40611 .51221 m .41361 .50642 L .43354 .53589 L closepath p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43839 .54728 L p
1 g
F P
s
P
p
.43423 .53573 m .43146 .53025 L .43839 .54728 L 1 g
F
P
p
.002 w
.43743 .5491 m .43989 .55224 L p
.44518 .55638 L 1 g
F P
s
P
p
.44402 .55482 m .43743 .5491 L .44518 .55638 L 1 g
F
P
p
.002 w
.44004 .56439 m .4504 .56348 L p
.46866 .58646 L 1 g
F P
s
P
p
.002 w
.43989 .55224 m .45002 .56518 L .4506 .56361 L p
1 g
F P
s
P
p
.002 w
.4506 .56361 m .4506 .56361 L p
.45063 .56363 L 1 g
F P
s
P
p
.46872 .57265 m .4506 .56361 L .45063 .56363 L 1 g
F
P
p
.002 w
.4504 .56348 m .45055 .56347 L .45072 .56369 L p
1 g
F P
s
P
p
.46872 .57265 m .4506 .56361 L .45895 .56875 L 1 g
F
P
p
.48371 .57975 m .46832 .5745 L .45055 .56347 L 1 g
F
P
p
.002 w
.45591 .57028 m .45072 .56369 L p
.46832 .5745 L 1 g
F P
s
P
p
.002 w
.45072 .56369 m .45055 .56347 L p
.46832 .5745 L 1 g
F P
s
P
p
.002 w
.4506 .56361 m .45002 .56518 L p
.45895 .56875 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46832 .5745 L p
1 g
F P
s
P
p
.45895 .56875 m .45002 .56518 L .46832 .5745 L 1 g
F
P
p
.47759 .57767 m .47252 .57725 L .48371 .57975 L 1 g
F
P
p
.002 w
.48614 .57867 m .48371 .57975 L p
.45055 .56347 L 1 g
F P
s
P
p
.002 w
.51092 .58032 m .51111 .583 L p
.52128 .57778 L 1 g
F P
s
P
p
.50059 .58066 m .49041 .58099 L .49763 .58125 L 1 g
F
P
p
.002 w
.48371 .57975 m .48614 .57867 L .49121 .58143 L p
1 g
F P
s
P
p
.002 w
.48904 .58094 m .48889 .583 L p
.49763 .58125 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51102 .58173 L p
1 g
F P
s
P
p
.49763 .58125 m .48889 .583 L .51102 .58173 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58094 L p
1 g
F P
s
P
p
.47252 .57725 m .4678 .57686 L .48904 .58094 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.40828 .36118 m .36518 .37575 L .36292 .34592 L p
1 g
F P
s
P
p
.002 w
.36292 .34592 m .41144 .32894 L .40828 .36118 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.56239 .57823 m .57474 .54583 L .60617 .53952 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.63528 .4078 m .65645 .46359 L .63309 .47991 L p
1 g
F P
s
P
p
.002 w
.65645 .46359 m .63528 .4078 L .65277 .38829 L p
1 g
F P
s
P
p
.002 w
.38162 .48611 m .37329 .50224 L .34914 .48234 L p
1 g
F P
s
P
p
.002 w
.34914 .48234 m .36096 .45858 L .38162 .48611 L p
1 g
F P
s
P
p
.002 w
.61081 .33597 m .65277 .38829 L .63528 .4078 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.40174 .52033 m .40095 .52988 L .37197 .52102 L p
1 g
F P
s
P
p
.002 w
.37197 .52102 m .37329 .50224 L .40174 .52033 L p
1 g
F P
s
P
p
.002 w
.38206 .4412 m .36096 .45858 L .34479 .43065 L p
1 g
F P
s
P
p
.002 w
.34479 .43065 m .3716 .40789 L .38206 .4412 L p
1 g
F P
s
P
p
.002 w
.54013 .32043 m .47817 .30057 L .48896 .27638 L p
1 g
F P
s
P
p
.002 w
.48896 .27638 m .55369 .29692 L .54013 .32043 L p
1 g
F P
s
P
p
.002 w
.46777 .32941 m .41144 .32894 L .41719 .30047 L p
1 g
F P
s
P
p
.002 w
.41719 .30047 m .47817 .30057 L .46777 .32941 L p
1 g
F P
s
P
p
.002 w
.6051 .4951 m .60617 .53952 L .57474 .54583 L p
1 g
F P
s
P
p
.002 w
.60617 .53952 m .6051 .4951 L .63309 .47991 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.45055 .56347 m .45941 .55939 L .48614 .57867 L p
1 g
F P
s
P
p
.002 w
.49863 .56541 m .48614 .57867 L .45941 .55939 L p
1 g
F P
s
P
p
.002 w
.48614 .57867 m .49863 .56541 L .53127 .57404 L p
1 g
F P
s
P
p
.002 w
.5405 .54871 m .53127 .57404 L .49863 .56541 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.63528 .4078 m .5949 .35783 L .61081 .33597 L p
1 g
F P
s
P
p
.002 w
.55369 .29692 m .61081 .33597 L .5949 .35783 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40611 .51221 m .40174 .52033 L .37329 .50224 L p
1 g
F P
s
P
p
.002 w
.37329 .50224 m .38162 .48611 L .40611 .51221 L p
1 g
F P
s
P
p
.002 w
.4079 .39609 m .3716 .40789 L .36518 .37575 L p
1 g
F P
s
P
p
.002 w
.36518 .37575 m .40828 .36118 L .4079 .39609 L p
1 g
F P
s
P
p
.002 w
.5949 .35783 m .54013 .32043 L .55369 .29692 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.61315 .42854 m .63309 .47991 L .6051 .4951 L p
1 g
F P
s
P
p
.002 w
.63309 .47991 m .61315 .42854 L .63528 .4078 L p
1 g
F P
s
P
p
.002 w
.39623 .47446 m .38162 .48611 L .36096 .45858 L p
1 g
F P
s
P
p
.002 w
.36096 .45858 m .38206 .4412 L .39623 .47446 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57474 .54583 m .57338 .50857 L .6051 .4951 L p
1 g
F P
s
P
p
.002 w
.5949 .35783 m .63528 .4078 L .61315 .42854 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.45941 .55939 m .46565 .55255 L .49863 .56541 L p
1 g
F P
s
P
p
.002 w
.50467 .54799 m .49863 .56541 L .46565 .55255 L p
1 g
F P
s
P
p
.002 w
.49863 .56541 m .50467 .54799 L .5405 .54871 L p
1 g
F P
s
P
p
.002 w
.45816 .36198 m .40828 .36118 L .41144 .32894 L p
1 g
F P
s
P
p
.002 w
.41144 .32894 m .46777 .32941 L .45816 .36198 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.52498 .34796 m .46777 .32941 L .47817 .30057 L p
1 g
F P
s
P
p
.002 w
.47817 .30057 m .54013 .32043 L .52498 .34796 L p
1 g
F P
s
P
p
.002 w
.41361 .50642 m .40611 .51221 L .38162 .48611 L p
1 g
F P
s
P
p
.002 w
.38162 .48611 m .39623 .47446 L .41361 .50642 L p
1 g
F P
s
P
p
.002 w
.41038 .43239 m .38206 .4412 L .3716 .40789 L p
1 g
F P
s
P
p
.002 w
.3716 .40789 m .4079 .39609 L .41038 .43239 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46565 .55255 m .46857 .54366 L .50467 .54799 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.53905 .51977 m .5405 .54871 L .50467 .54799 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58705 .44977 m .6051 .4951 L .57338 .50857 L p
1 g
F P
s
P
p
.002 w
.6051 .4951 m .58705 .44977 L .61315 .42854 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.61315 .42854 m .57563 .38252 L .5949 .35783 L p
1 g
F P
s
P
p
.002 w
.54013 .32043 m .5949 .35783 L .57563 .38252 L p
1 g
F P
s
P
p
.002 w
.41564 .4687 m .39623 .47446 L .38206 .4412 L p
1 g
F P
s
P
p
.002 w
.38206 .4412 m .41038 .43239 L .41564 .4687 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5034 .52824 m .50467 .54799 L .46857 .54366 L p
1 g
F P
s
P
p
.002 w
.50467 .54799 m .5034 .52824 L .53905 .51977 L p
1 g
F P
s
P
p
.002 w
.46857 .54366 m .46778 .53367 L .5034 .52824 L p
1 g
F P
s
P
p
.002 w
.57563 .38252 m .52498 .34796 L .54013 .32043 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.42347 .50363 m .41361 .50642 L .39623 .47446 L p
1 g
F P
s
P
p
.002 w
.44973 .39711 m .4079 .39609 L .40828 .36118 L p
1 g
F P
s
P
p
.002 w
.40828 .36118 m .45816 .36198 L .44973 .39711 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57563 .38252 m .61315 .42854 L .58705 .44977 L p
1 g
F P
s
P
p
.002 w
.39623 .47446 m .41564 .4687 L .42347 .50363 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46778 .53367 m .46335 .52368 L .49481 .50837 L p
1 g
F P
s
P
p
.002 w
.49481 .50837 m .5034 .52824 L .46778 .53367 L p
1 g
F P
s
P
p
.002 w
.57338 .50857 m .55788 .47069 L .58705 .44977 L p
1 g
F P
s
P
p
.002 w
.50876 .3786 m .45816 .36198 L .46777 .32941 L p
1 g
F P
s
P
p
.002 w
.46777 .32941 m .52498 .34796 L .50876 .3786 L p
1 g
F P
s
P
p
.002 w
.43461 .50419 m .42347 .50363 L .41564 .4687 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.46335 .52368 m .45574 .51481 L .47977 .49067 L p
1 g
F P
s
P
p
.002 w
.47977 .49067 m .49481 .50837 L .46335 .52368 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.41564 .4687 m .43773 .46963 L .43461 .50419 L p
1 g
F P
s
P
p
.002 w
.44283 .43347 m .41038 .43239 L .4079 .39609 L p
1 g
F P
s
P
p
.002 w
.4079 .39609 m .44973 .39711 L .44283 .43347 L p
1 g
F P
s
P
p
.002 w
.5034 .52824 m .49481 .50837 L .52674 .49048 L p
1 g
F P
s
P
p
.002 w
.52674 .49048 m .53905 .51977 L .5034 .52824 L p
1 g
F P
s
P
p
.002 w
.45574 .51481 m .44578 .50806 L .45997 .47723 L p
1 g
F P
s
P
p
.002 w
.45997 .47723 m .47977 .49067 L .45574 .51481 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43773 .46963 m .41564 .4687 L .41038 .43239 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.41038 .43239 m .44283 .43347 L .43773 .46963 L p
1 g
F P
s
P
p
.002 w
.58705 .44977 m .55363 .40917 L .57563 .38252 L p
1 g
F P
s
P
p
.002 w
.52498 .34796 m .57563 .38252 L .55363 .40917 L p
1 g
F P
s
P
p
.002 w
.55363 .40917 m .58705 .44977 L .55788 .47069 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55363 .40917 m .50876 .3786 L .52498 .34796 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49208 .41121 m .44973 .39711 L .45816 .36198 L p
1 g
F P
s
P
p
.002 w
.45816 .36198 m .50876 .3786 L .49208 .41121 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55788 .47069 m .52969 .4368 L .55363 .40917 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.4756 .44452 m .44283 .43347 L .44973 .39711 L p
1 g
F P
s
P
p
.002 w
.44973 .39711 m .49208 .41121 L .4756 .44452 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.50876 .3786 m .55363 .40917 L .52969 .4368 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52969 .4368 m .49208 .41121 L .50876 .3786 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50475 .46433 m .4756 .44452 L .49208 .41121 L p
1 g
F P
s
P
p
.002 w
.49208 .41121 m .52969 .4368 L .50475 .46433 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.004 w
.40593 .57967 m
.41111 .57145 L
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .59643 .71201 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39387 .5988 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.0976744)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.0976744)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45209 .42668 m .47381 .4541 L .49324 .43334 L p
1 g
F P
s
P
p
.002 w
.49324 .43334 m .47649 .41212 L .45209 .42668 L p
1 g
F P
s
P
p
.002 w
.5155 .44876 m .49324 .43334 L .47381 .4541 L p
1 g
F P
s
P
p
.002 w
.47649 .41212 m .49324 .43334 L .51281 .41254 L p
1 g
F P
s
P
p
.002 w
.49324 .43334 m .5155 .44876 L .52801 .42305 L p
1 g
F P
s
P
p
.002 w
.52801 .42305 m .51281 .41254 L .49324 .43334 L p
1 g
F P
s
P
p
.002 w
.51281 .41254 m .5014 .39804 L .47649 .41212 L p
1 g
F P
s
P
p
.002 w
.5014 .39804 m .51281 .41254 L .53216 .39208 L p
1 g
F P
s
P
p
.002 w
.51281 .41254 m .52801 .42305 L .5399 .39742 L p
1 g
F P
s
P
p
.002 w
.5399 .39742 m .53216 .39208 L .51281 .41254 L p
1 g
F P
s
P
p
.002 w
.47381 .4541 m .50259 .47408 L .5155 .44876 L p
1 g
F P
s
P
p
.002 w
.54103 .45681 m .5155 .44876 L .50259 .47408 L p
1 g
F P
s
P
p
.002 w
.5155 .44876 m .54103 .45681 L .54545 .42848 L p
1 g
F P
s
P
p
.002 w
.54545 .42848 m .52801 .42305 L .5155 .44876 L p
1 g
F P
s
P
p
.002 w
.52801 .42305 m .54545 .42848 L .54878 .40015 L p
1 g
F P
s
P
p
.002 w
.54878 .40015 m .5399 .39742 L .52801 .42305 L p
1 g
F P
s
P
p
.002 w
.43963 .3945 m .45209 .42668 L .47649 .41212 L p
1 g
F P
s
P
p
.002 w
.47649 .41212 m .46697 .38722 L .43963 .3945 L p
1 g
F P
s
P
p
.002 w
.46697 .38722 m .47649 .41212 L .5014 .39804 L p
1 g
F P
s
P
p
.002 w
.5014 .39804 m .49498 .38103 L .46697 .38722 L p
1 g
F P
s
P
p
.002 w
.49498 .38103 m .5014 .39804 L .52637 .38469 L p
1 g
F P
s
P
p
.002 w
.53216 .39208 m .52637 .38469 L .5014 .39804 L p
1 g
F P
s
P
p
.002 w
.42865 .44146 m .45487 .47445 L .47381 .4541 L p
1 g
F P
s
P
p
.002 w
.47381 .4541 m .45209 .42668 L .42865 .44146 L p
1 g
F P
s
P
p
.002 w
.50259 .47408 m .47381 .4541 L .45487 .47445 L p
1 g
F P
s
P
p
.002 w
.45487 .47445 m .4895 .49855 L .50259 .47408 L p
1 g
F P
s
P
p
.002 w
.5356 .48463 m .50259 .47408 L .4895 .49855 L p
1 g
F P
s
P
p
.002 w
.50259 .47408 m .5356 .48463 L .54103 .45681 L p
1 g
F P
s
P
p
.002 w
.56332 .42822 m .54545 .42848 L .54103 .45681 L p
1 g
F P
s
P
p
.002 w
.54545 .42848 m .56332 .42822 L .55785 .39996 L p
1 g
F P
s
P
p
.002 w
.55785 .39996 m .54878 .40015 L .54545 .42848 L p
1 g
F P
s
P
p
.002 w
.41346 .40274 m .42865 .44146 L .45209 .42668 L p
1 g
F P
s
P
p
.002 w
.45209 .42668 m .43963 .3945 L .41346 .40274 L p
1 g
F P
s
P
p
.002 w
.56727 .45659 m .54103 .45681 L .5356 .48463 L p
1 g
F P
s
P
p
.002 w
.54103 .45681 m .56727 .45659 L .56332 .42822 L p
1 g
F P
s
P
p
.002 w
.46574 .36115 m .46697 .38722 L .49498 .38103 L p
1 g
F P
s
P
p
.002 w
.49498 .38103 m .49426 .36327 L .46574 .36115 L p
1 g
F P
s
P
p
.002 w
.49426 .36327 m .49498 .38103 L .52314 .37603 L p
1 g
F P
s
P
p
.002 w
.52637 .38469 m .52314 .37603 L .49498 .38103 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .52637 .38469 L .53216 .39208 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .53216 .39208 L .5399 .39742 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .5399 .39742 L .54878 .40015 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .52314 .37603 L .52637 .38469 L closepath p
1 g
F P
s
P
p
.002 w
.43781 .36071 m .43963 .3945 L .46697 .38722 L p
1 g
F P
s
P
p
.002 w
.46697 .38722 m .46574 .36115 L .43781 .36071 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .54878 .40015 L .55785 .39996 L closepath p
1 g
F P
s
P
p
.002 w
.52314 .37603 m .52284 .36702 L .49426 .36327 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .52284 .36702 L .52314 .37603 L closepath p
1 g
F P
s
P
p
.002 w
.40661 .4562 m .43676 .49401 L .45487 .47445 L p
1 g
F P
s
P
p
.002 w
.45487 .47445 m .42865 .44146 L .40661 .4562 L p
1 g
F P
s
P
p
.002 w
.4895 .49855 m .45487 .47445 L .43676 .49401 L p
1 g
F P
s
P
p
.002 w
.57975 .42223 m .56332 .42822 L .56727 .45659 L p
1 g
F P
s
P
p
.002 w
.56332 .42822 m .57975 .42223 L .56615 .39686 L p
1 g
F P
s
P
p
.002 w
.56615 .39686 m .55785 .39996 L .56332 .42822 L p
1 g
F P
s
P
p
.002 w
.4895 .49855 m .52923 .51141 L .5356 .48463 L p
1 g
F P
s
P
p
.002 w
.56959 .48455 m .5356 .48463 L .52923 .51141 L p
1 g
F P
s
P
p
.002 w
.5356 .48463 m .56959 .48455 L .56727 .45659 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .55785 .39996 L .56615 .39686 L closepath p
1 g
F P
s
P
p
.002 w
.49939 .34663 m .49426 .36327 L .52284 .36702 L p
1 g
F P
s
P
p
.002 w
.52284 .36702 m .5255 .35861 L .49939 .34663 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .5255 .35861 L .52284 .36702 L closepath p
1 g
F P
s
P
p
.002 w
.47308 .33661 m .46574 .36115 L .49426 .36327 L p
1 g
F P
s
P
p
.002 w
.49426 .36327 m .49939 .34663 L .47308 .33661 L p
1 g
F P
s
P
p
.002 w
.43676 .49401 m .47648 .52171 L .4895 .49855 L p
1 g
F P
s
P
p
.002 w
.52923 .51141 m .4895 .49855 L .47648 .52171 L p
1 g
F P
s
P
p
.002 w
.41101 .362 m .41346 .40274 L .43963 .3945 L p
1 g
F P
s
P
p
.002 w
.43963 .3945 m .43781 .36071 L .41101 .362 L p
1 g
F P
s
P
p
.002 w
.59149 .44799 m .56727 .45659 L .56959 .48455 L p
1 g
F P
s
P
p
.002 w
.56727 .45659 m .59149 .44799 L .57975 .42223 L p
1 g
F P
s
P
p
.002 w
.38899 .41181 m .40661 .4562 L .42865 .44146 L p
1 g
F P
s
P
p
.002 w
.42865 .44146 m .41346 .40274 L .38899 .41181 L p
1 g
F P
s
P
p
.002 w
.57277 .39116 m .56615 .39686 L .57975 .42223 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .56615 .39686 L .57277 .39116 L closepath p
1 g
F P
s
P
p
.002 w
.5099 .3329 m .49939 .34663 L .5255 .35861 L p
1 g
F P
s
P
p
.002 w
.5255 .35861 m .53088 .35172 L .5099 .3329 L p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .53088 .35172 L .5255 .35861 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .57277 .39116 L .57699 .38346 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .57699 .38346 L .57833 .37458 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .57833 .37458 L .57662 .3655 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .57662 .3655 L .57202 .35721 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .57202 .35721 L .56505 .35065 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .56505 .35065 L .55647 .34653 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .55647 .34653 L .54725 .34531 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .54725 .34531 L .53839 .34712 L closepath p
1 g
F P
s
P
p
.002 w
.55094 .37232 m .53839 .34712 L .53088 .35172 L closepath p
1 g
F P
s
P
p
.002 w
.44707 .32878 m .43781 .36071 L .46574 .36115 L p
1 g
F P
s
P
p
.002 w
.46574 .36115 m .47308 .33661 L .44707 .32878 L p
1 g
F P
s
P
p
.002 w
.59296 .41108 m .57975 .42223 L .59149 .44799 L p
1 g
F P
s
P
p
.002 w
.57975 .42223 m .59296 .41108 L .57277 .39116 L p
1 g
F P
s
P
p
.002 w
.57699 .38346 m .57277 .39116 L .59296 .41108 L p
1 g
F P
s
P
p
.002 w
.48839 .31624 m .47308 .33661 L .49939 .34663 L p
1 g
F P
s
P
p
.002 w
.49939 .34663 m .5099 .3329 L .48839 .31624 L p
1 g
F P
s
P
p
.002 w
.52473 .32364 m .5099 .3329 L .53088 .35172 L p
1 g
F P
s
P
p
.002 w
.53088 .35172 m .53839 .34712 L .52473 .32364 L p
1 g
F P
s
P
p
.002 w
.47648 .52171 m .52204 .53662 L .52923 .51141 L p
1 g
F P
s
P
p
.002 w
.57023 .51155 m .52923 .51141 L .52204 .53662 L p
1 g
F P
s
P
p
.002 w
.52923 .51141 m .57023 .51155 L .56959 .48455 L p
1 g
F P
s
P
p
.002 w
.60112 .47362 m .56959 .48455 L .57023 .51155 L p
1 g
F P
s
P
p
.002 w
.56959 .48455 m .60112 .47362 L .59149 .44799 L p
1 g
F P
s
P
p
.002 w
.38643 .4706 m .41986 .51238 L .43676 .49401 L p
1 g
F P
s
P
p
.002 w
.43676 .49401 m .40661 .4562 L .38643 .4706 L p
1 g
F P
s
P
p
.002 w
.47648 .52171 m .43676 .49401 L .41986 .51238 L p
1 g
F P
s
P
p
.002 w
.59296 .41108 m .60146 .39589 L .57699 .38346 L p
1 g
F P
s
P
p
.002 w
.57833 .37458 m .57699 .38346 L .60146 .39589 L p
1 g
F P
s
P
p
.002 w
.38589 .36503 m .38899 .41181 L .41346 .40274 L p
1 g
F P
s
P
p
.002 w
.41346 .40274 m .41101 .362 L .38589 .36503 L p
1 g
F P
s
P
p
.002 w
.54232 .31994 m .52473 .32364 L .53839 .34712 L p
1 g
F P
s
P
p
.002 w
.53839 .34712 m .54725 .34531 L .54232 .31994 L p
1 g
F P
s
P
p
.002 w
.61109 .43173 m .59149 .44799 L .60112 .47362 L p
1 g
F P
s
P
p
.002 w
.59149 .44799 m .61109 .43173 L .59296 .41108 L p
1 g
F P
s
P
p
.002 w
.4219 .32335 m .41101 .362 L .43781 .36071 L p
1 g
F P
s
P
p
.002 w
.43781 .36071 m .44707 .32878 L .4219 .32335 L p
1 g
F P
s
P
p
.002 w
.41986 .51238 m .46378 .54308 L .47648 .52171 L p
1 g
F P
s
P
p
.002 w
.52204 .53662 m .47648 .52171 L .46378 .54308 L p
1 g
F P
s
P
p
.002 w
.60146 .39589 m .59296 .41108 L .61109 .43173 L p
1 g
F P
s
P
p
.002 w
.60146 .39589 m .60424 .37826 L .57833 .37458 L p
1 g
F P
s
P
p
.002 w
.57662 .3655 m .57833 .37458 L .60424 .37826 L p
1 g
F P
s
P
p
.002 w
.36675 .42155 m .38643 .4706 L .40661 .4562 L p
1 g
F P
s
P
p
.002 w
.40661 .4562 m .38899 .41181 L .36675 .42155 L p
1 g
F P
s
P
p
.002 w
.56072 .32228 m .54232 .31994 L .54725 .34531 L p
1 g
F P
s
P
p
.002 w
.54725 .34531 m .55647 .34653 L .56072 .32228 L p
1 g
F P
s
P
p
.002 w
.46676 .30214 m .44707 .32878 L .47308 .33661 L p
1 g
F P
s
P
p
.002 w
.47308 .33661 m .48839 .31624 L .46676 .30214 L p
1 g
F P
s
P
p
.002 w
.51019 .30239 m .48839 .31624 L .5099 .3329 L p
1 g
F P
s
P
p
.002 w
.5099 .3329 m .52473 .32364 L .51019 .30239 L p
1 g
F P
s
P
p
.002 w
.60424 .37826 m .60091 .36015 L .57662 .3655 L p
1 g
F P
s
P
p
.002 w
.57202 .35721 m .57662 .3655 L .60091 .36015 L p
1 g
F P
s
P
p
.002 w
.57786 .33046 m .56072 .32228 L .55647 .34653 L p
1 g
F P
s
P
p
.002 w
.55647 .34653 m .56505 .35065 L .57786 .33046 L p
1 g
F P
s
P
p
.002 w
.60091 .36015 m .59179 .34359 L .57202 .35721 L p
1 g
F P
s
P
p
.002 w
.56505 .35065 m .57202 .35721 L .59179 .34359 L p
1 g
F P
s
P
p
.002 w
.59179 .34359 m .57786 .33046 L .56505 .35065 L p
1 g
F P
s
P
p
.002 w
.61109 .43173 m .62383 .4094 L .60146 .39589 L p
1 g
F P
s
P
p
.002 w
.60424 .37826 m .60146 .39589 L .62383 .4094 L p
1 g
F P
s
P
p
.002 w
.52204 .53662 m .56913 .53706 L .57023 .51155 L p
1 g
F P
s
P
p
.002 w
.60839 .49865 m .57023 .51155 L .56913 .53706 L p
1 g
F P
s
P
p
.002 w
.57023 .51155 m .60839 .49865 L .60112 .47362 L p
1 g
F P
s
P
p
.002 w
.46378 .54308 m .51414 .55974 L .52204 .53662 L p
1 g
F P
s
P
p
.002 w
.56913 .53706 m .52204 .53662 L .51414 .55974 L p
1 g
F P
s
P
p
.002 w
.53621 .29675 m .51019 .30239 L .52473 .32364 L p
1 g
F P
s
P
p
.002 w
.52473 .32364 m .54232 .31994 L .53621 .29675 L p
1 g
F P
s
P
p
.002 w
.62677 .4527 m .60112 .47362 L .60839 .49865 L p
1 g
F P
s
P
p
.002 w
.60112 .47362 m .62677 .4527 L .61109 .43173 L p
1 g
F P
s
P
p
.002 w
.62383 .4094 m .61109 .43173 L .62677 .4527 L p
1 g
F P
s
P
p
.002 w
.39811 .32051 m .38589 .36503 L .41101 .362 L p
1 g
F P
s
P
p
.002 w
.41101 .362 m .4219 .32335 L .39811 .32051 L p
1 g
F P
s
P
p
.002 w
.36304 .36979 m .36675 .42155 L .38899 .41181 L p
1 g
F P
s
P
p
.002 w
.38899 .41181 m .38589 .36503 L .36304 .36979 L p
1 g
F P
s
P
p
.002 w
.36859 .48437 m .40454 .52917 L .41986 .51238 L p
1 g
F P
s
P
p
.002 w
.41986 .51238 m .38643 .4706 L .36859 .48437 L p
1 g
F P
s
P
p
.002 w
.46378 .54308 m .41986 .51238 L .40454 .52917 L p
1 g
F P
s
P
p
.002 w
.44547 .29095 m .4219 .32335 L .44707 .32878 L p
1 g
F P
s
P
p
.002 w
.44707 .32878 m .46676 .30214 L .44547 .29095 L p
1 g
F P
s
P
p
.002 w
.49505 .28387 m .46676 .30214 L .48839 .31624 L p
1 g
F P
s
P
p
.002 w
.48839 .31624 m .51019 .30239 L .49505 .28387 L p
1 g
F P
s
P
p
.002 w
.62383 .4094 m .62812 .38334 L .60424 .37826 L p
1 g
F P
s
P
p
.002 w
.60091 .36015 m .60424 .37826 L .62812 .38334 L p
1 g
F P
s
P
p
.002 w
.40454 .52917 m .45166 .56217 L .46378 .54308 L p
1 g
F P
s
P
p
.002 w
.51414 .55974 m .46378 .54308 L .45166 .56217 L p
1 g
F P
s
P
p
.002 w
.56354 .30012 m .53621 .29675 L .54232 .31994 L p
1 g
F P
s
P
p
.002 w
.54232 .31994 m .56072 .32228 L .56354 .30012 L p
1 g
F P
s
P
p
.002 w
.34729 .43179 m .36859 .48437 L .38643 .4706 L p
1 g
F P
s
P
p
.002 w
.38643 .4706 m .36675 .42155 L .34729 .43179 L p
1 g
F P
s
P
p
.002 w
.62812 .38334 m .6233 .35644 L .60091 .36015 L p
1 g
F P
s
P
p
.002 w
.59179 .34359 m .60091 .36015 L .6233 .35644 L p
1 g
F P
s
P
p
.002 w
.58906 .31224 m .56354 .30012 L .56072 .32228 L p
1 g
F P
s
P
p
.002 w
.56072 .32228 m .57786 .33046 L .58906 .31224 L p
1 g
F P
s
P
p
.002 w
.62677 .4527 m .64358 .42375 L .62383 .4094 L p
1 g
F P
s
P
p
.002 w
.62812 .38334 m .62383 .4094 L .64358 .42375 L p
1 g
F P
s
P
p
.002 w
.6233 .35644 m .60978 .33178 L .59179 .34359 L p
1 g
F P
s
P
p
.002 w
.57786 .33046 m .59179 .34359 L .60978 .33178 L p
1 g
F P
s
P
p
.002 w
.60978 .33178 m .58906 .31224 L .57786 .33046 L p
1 g
F P
s
P
p
.002 w
.51414 .55974 m .56626 .56049 L .56913 .53706 L p
1 g
F P
s
P
p
.002 w
.61308 .52252 m .56913 .53706 L .56626 .56049 L p
1 g
F P
s
P
p
.002 w
.56913 .53706 m .61308 .52252 L .60839 .49865 L p
1 g
F P
s
P
p
.002 w
.63959 .4736 m .60839 .49865 L .61308 .52252 L p
1 g
F P
s
P
p
.002 w
.60839 .49865 m .63959 .4736 L .62677 .4527 L p
1 g
F P
s
P
p
.002 w
.529 .27631 m .49505 .28387 L .51019 .30239 L p
1 g
F P
s
P
p
.002 w
.51019 .30239 m .53621 .29675 L .529 .27631 L p
1 g
F P
s
P
p
.002 w
.64358 .42375 m .62677 .4527 L .63959 .4736 L p
1 g
F P
s
P
p
.002 w
.45166 .56217 m .50567 .58021 L .51414 .55974 L p
1 g
F P
s
P
p
.002 w
.56626 .56049 m .51414 .55974 L .50567 .58021 L p
1 g
F P
s
P
p
.002 w
.37626 .32043 m .36304 .36979 L .38589 .36503 L p
1 g
F P
s
P
p
.002 w
.38589 .36503 m .39811 .32051 L .37626 .32043 L p
1 g
F P
s
P
p
.002 w
.42497 .28304 m .39811 .32051 L .4219 .32335 L p
1 g
F P
s
P
p
.002 w
.4219 .32335 m .44547 .29095 L .42497 .28304 L p
1 g
F P
s
P
p
.002 w
.4796 .2686 m .44547 .29095 L .46676 .30214 L p
1 g
F P
s
P
p
.002 w
.46676 .30214 m .49505 .28387 L .4796 .2686 L p
1 g
F P
s
P
p
.002 w
.34304 .37627 m .34729 .43179 L .36675 .42155 L p
1 g
F P
s
P
p
.002 w
.36675 .42155 m .36304 .36979 L .34304 .37627 L p
1 g
F P
s
P
p
.002 w
.64358 .42375 m .64938 .38976 L .62812 .38334 L p
1 g
F P
s
P
p
.002 w
.6233 .35644 m .62812 .38334 L .64938 .38976 L p
1 g
F P
s
P
p
.002 w
.35356 .49718 m .39118 .54396 L .40454 .52917 L p
1 g
F P
s
P
p
.002 w
.40454 .52917 m .36859 .48437 L .35356 .49718 L p
1 g
F P
s
P
p
.002 w
.45166 .56217 m .40454 .52917 L .39118 .54396 L p
1 g
F P
s
P
p
.002 w
.56482 .28061 m .529 .27631 L .53621 .29675 L p
1 g
F P
s
P
p
.002 w
.53621 .29675 m .56354 .30012 L .56482 .28061 L p
1 g
F P
s
P
p
.002 w
.39118 .54396 m .4404 .57848 L .45166 .56217 L p
1 g
F P
s
P
p
.002 w
.50567 .58021 m .45166 .56217 L .4404 .57848 L p
1 g
F P
s
P
p
.002 w
.33115 .44233 m .35356 .49718 L .36859 .48437 L p
1 g
F P
s
P
p
.002 w
.36859 .48437 m .34729 .43179 L .33115 .44233 L p
1 g
F P
s
P
p
.002 w
.63959 .4736 m .66019 .43867 L .64358 .42375 L p
1 g
F P
s
P
p
.002 w
.64938 .38976 m .64358 .42375 L .66019 .43867 L p
1 g
F P
s
P
p
.002 w
.64938 .38976 m .64321 .35451 L .6233 .35644 L p
1 g
F P
s
P
p
.002 w
.60978 .33178 m .6233 .35644 L .64321 .35451 L p
1 g
F P
s
P
p
.002 w
.59834 .29647 m .56482 .28061 L .56354 .30012 L p
1 g
F P
s
P
p
.002 w
.56354 .30012 m .58906 .31224 L .59834 .29647 L p
1 g
F P
s
P
p
.002 w
.56626 .56049 m .61501 .5447 L .61308 .52252 L p
1 g
F P
s
P
p
.002 w
.64919 .49396 m .61308 .52252 L .61501 .5447 L p
1 g
F P
s
P
p
.002 w
.61308 .52252 m .64919 .49396 L .63959 .4736 L p
1 g
F P
s
P
p
.002 w
.50567 .58021 m .56159 .58127 L .56626 .56049 L p
1 g
F P
s
P
p
.002 w
.61501 .5447 m .56626 .56049 L .56159 .58127 L p
1 g
F P
s
P
p
.002 w
.66019 .43867 m .63959 .4736 L .64919 .49396 L p
1 g
F P
s
P
p
.002 w
.5208 .25922 m .4796 .2686 L .49505 .28387 L p
1 g
F P
s
P
p
.002 w
.49505 .28387 m .529 .27631 L .5208 .25922 L p
1 g
F P
s
P
p
.002 w
.64321 .35451 m .62554 .32212 L .60978 .33178 L p
1 g
F P
s
P
p
.002 w
.58906 .31224 m .60978 .33178 L .62554 .32212 L p
1 g
F P
s
P
p
.002 w
.62554 .32212 m .59834 .29647 L .58906 .31224 L p
1 g
F P
s
P
p
.002 w
.4404 .57848 m .49677 .59748 L .50567 .58021 L p
1 g
F P
s
P
p
.002 w
.56159 .58127 m .50567 .58021 L .49677 .59748 L p
1 g
F P
s
P
p
.002 w
.35693 .32322 m .34304 .37627 L .36304 .36979 L p
1 g
F P
s
P
p
.002 w
.36304 .36979 m .37626 .32043 L .35693 .32322 L p
1 g
F P
s
P
p
.002 w
.46417 .25705 m .42497 .28304 L .44547 .29095 L p
1 g
F P
s
P
p
.002 w
.44547 .29095 m .4796 .2686 L .46417 .25705 L p
1 g
F P
s
P
p
.002 w
.40577 .27874 m .37626 .32043 L .39811 .32051 L p
1 g
F P
s
P
p
.002 w
.39811 .32051 m .42497 .28304 L .40577 .27874 L p
1 g
F P
s
P
p
.002 w
.32648 .38439 m .33115 .44233 L .34729 .43179 L p
1 g
F P
s
P
p
.002 w
.34729 .43179 m .34304 .37627 L .32648 .38439 L p
1 g
F P
s
P
p
.002 w
.66019 .43867 m .66745 .39744 L .64938 .38976 L p
1 g
F P
s
P
p
.002 w
.64321 .35451 m .64938 .38976 L .66745 .39744 L p
1 g
F P
s
P
p
.002 w
.56445 .26432 m .5208 .25922 L .529 .27631 L p
1 g
F P
s
P
p
.002 w
.529 .27631 m .56482 .28061 L .56445 .26432 L p
1 g
F P
s
P
p
.002 w
.34182 .50872 m .38018 .55632 L .39118 .54396 L p
1 g
F P
s
P
p
.002 w
.39118 .54396 m .35356 .49718 L .34182 .50872 L p
1 g
F P
s
P
p
.002 w
.4404 .57848 m .39118 .54396 L .38018 .55632 L p
1 g
F P
s
P
p
.002 w
.38018 .55632 m .43029 .59151 L .4404 .57848 L p
1 g
F P
s
P
p
.002 w
.49677 .59748 m .4404 .57848 L .43029 .59151 L p
1 g
F P
s
P
p
.002 w
.64919 .49396 m .67316 .45385 L .66019 .43867 L p
1 g
F P
s
P
p
.002 w
.66745 .39744 m .66019 .43867 L .67316 .45385 L p
1 g
F P
s
P
p
.002 w
.31888 .45293 m .34182 .50872 L .35356 .49718 L p
1 g
F P
s
P
p
.002 w
.35356 .49718 m .33115 .44233 L .31888 .45293 L p
1 g
F P
s
P
p
.002 w
.65519 .51331 m .61501 .5447 L .61399 .56461 L p
1 g
F P
s
P
p
.002 w
.56159 .58127 m .61399 .56461 L .61501 .5447 L p
1 g
F P
s
P
p
.002 w
.61501 .5447 m .65519 .51331 L .64919 .49396 L p
1 g
F P
s
P
p
.002 w
.67316 .45385 m .64919 .49396 L .65519 .51331 L p
1 g
F P
s
P
p
.002 w
.66745 .39744 m .66008 .35451 L .64321 .35451 L p
1 g
F P
s
P
p
.002 w
.62554 .32212 m .64321 .35451 L .66008 .35451 L p
1 g
F P
s
P
p
.002 w
.49677 .59748 m .55516 .5988 L .56159 .58127 L p
1 g
F P
s
P
p
.002 w
.61399 .56461 m .56159 .58127 L .55516 .5988 L p
1 g
F P
s
P
p
.002 w
.51175 .24603 m .46417 .25705 L .4796 .2686 L p
1 g
F P
s
P
p
.002 w
.4796 .2686 m .5208 .25922 L .51175 .24603 L p
1 g
F P
s
P
p
.002 w
.60538 .28363 m .56445 .26432 L .56482 .28061 L p
1 g
F P
s
P
p
.002 w
.56482 .28061 m .59834 .29647 L .60538 .28363 L p
1 g
F P
s
P
p
.002 w
.44914 .24971 m .40577 .27874 L .42497 .28304 L p
1 g
F P
s
P
p
.002 w
.42497 .28304 m .46417 .25705 L .44914 .24971 L p
1 g
F P
s
P
p
.002 w
.38841 .27833 m .35693 .32322 L .37626 .32043 L p
1 g
F P
s
P
p
.002 w
.37626 .32043 m .40577 .27874 L .38841 .27833 L p
1 g
F P
s
P
p
.002 w
.66008 .35451 m .63859 .31496 L .62554 .32212 L p
1 g
F P
s
P
p
.002 w
.59834 .29647 m .62554 .32212 L .63859 .31496 L p
1 g
F P
s
P
p
.002 w
.34074 .32898 m .32648 .38439 L .34304 .37627 L p
1 g
F P
s
P
p
.002 w
.34304 .37627 m .35693 .32322 L .34074 .32898 L p
1 g
F P
s
P
p
.002 w
.63859 .31496 m .60538 .28363 L .59834 .29647 L p
1 g
F P
s
P
p
.002 w
.43029 .59151 m .48765 .61097 L .49677 .59748 L p
1 g
F P
s
P
p
.002 w
.55516 .5988 m .49677 .59748 L .48765 .61097 L p
1 g
F P
s
P
p
.002 w
.31394 .39404 m .31888 .45293 L .33115 .44233 L p
1 g
F P
s
P
p
.002 w
.33115 .44233 m .32648 .38439 L .31394 .39404 L p
1 g
F P
s
P
p
.002 w
.67316 .45385 m .68175 .40627 L .66745 .39744 L p
1 g
F P
s
P
p
.002 w
.66008 .35451 m .66745 .39744 L .68175 .40627 L p
1 g
F P
s
P
p
.002 w
.56234 .25183 m .51175 .24603 L .5208 .25922 L p
1 g
F P
s
P
p
.002 w
.5208 .25922 m .56445 .26432 L .56234 .25183 L p
1 g
F P
s
P
p
.002 w
.33384 .51862 m .37193 .56583 L .38018 .55632 L p
1 g
F P
s
P
p
.002 w
.38018 .55632 m .34182 .50872 L .33384 .51862 L p
1 g
F P
s
P
p
.002 w
.43029 .59151 m .38018 .55632 L .37193 .56583 L p
1 g
F P
s
P
p
.002 w
.65519 .51331 m .68199 .46896 L .67316 .45385 L p
1 g
F P
s
P
p
.002 w
.68175 .40627 m .67316 .45385 L .68199 .46896 L p
1 g
F P
s
P
p
.002 w
.37193 .56583 m .42165 .60077 L .43029 .59151 L p
1 g
F P
s
P
p
.002 w
.48765 .61097 m .43029 .59151 L .42165 .60077 L p
1 g
F P
s
P
p
.002 w
.61399 .56461 m .65727 .53113 L .65519 .51331 L p
1 g
F P
s
P
p
.002 w
.68199 .46896 m .65519 .51331 L .65727 .53113 L p
1 g
F P
s
P
p
.002 w
.65727 .53113 m .61399 .56461 L .60991 .58166 L p
1 g
F P
s
P
p
.002 w
.55516 .5988 m .60991 .58166 L .61399 .56461 L p
1 g
F P
s
P
p
.002 w
.31099 .46336 m .33384 .51862 L .34182 .50872 L p
1 g
F P
s
P
p
.002 w
.34182 .50872 m .31888 .45293 L .31099 .46336 L p
1 g
F P
s
P
p
.002 w
.48765 .61097 m .54702 .6125 L .55516 .5988 L p
1 g
F P
s
P
p
.002 w
.60991 .58166 m .55516 .5988 L .54702 .6125 L p
1 g
F P
s
P
p
.002 w
.50202 .2373 m .44914 .24971 L .46417 .25705 L p
1 g
F P
s
P
p
.002 w
.46417 .25705 m .51175 .24603 L .50202 .2373 L p
1 g
F P
s
P
p
.002 w
.68175 .40627 m .67334 .35653 L .66008 .35451 L p
1 g
F P
s
P
p
.002 w
.63859 .31496 m .66008 .35451 L .67334 .35653 L p
1 g
F P
s
P
p
.002 w
.60987 .2742 m .56234 .25183 L .56445 .26432 L p
1 g
F P
s
P
p
.002 w
.56445 .26432 m .60538 .28363 L .60987 .2742 L p
1 g
F P
s
P
p
.002 w
.43491 .24699 m .38841 .27833 L .40577 .27874 L p
1 g
F P
s
P
p
.002 w
.40577 .27874 m .44914 .24971 L .43491 .24699 L p
1 g
F P
s
P
p
.002 w
.37341 .28205 m .34074 .32898 L .35693 .32322 L p
1 g
F P
s
P
p
.002 w
.35693 .32322 m .38841 .27833 L .37341 .28205 L p
1 g
F P
s
P
p
.002 w
.32826 .33773 m .31394 .39404 L .32648 .38439 L p
1 g
F P
s
P
p
.002 w
.32648 .38439 m .34074 .32898 L .32826 .33773 L p
1 g
F P
s
P
p
.002 w
.67334 .35653 m .64845 .3106 L .63859 .31496 L p
1 g
F P
s
P
p
.002 w
.60538 .28363 m .63859 .31496 L .64845 .3106 L p
1 g
F P
s
P
p
.002 w
.64845 .3106 m .60987 .2742 L .60538 .28363 L p
1 g
F P
s
P
p
.002 w
.42165 .60077 m .47849 .62015 L .48765 .61097 L p
1 g
F P
s
P
p
.002 w
.54702 .6125 m .48765 .61097 L .47849 .62015 L p
1 g
F P
s
P
p
.002 w
.30598 .40507 m .31099 .46336 L .31888 .45293 L p
1 g
F P
s
P
p
.002 w
.31888 .45293 m .31394 .39404 L .30598 .40507 L p
1 g
F P
s
P
p
.002 w
.68199 .46896 m .6917 .41609 L .68175 .40627 L p
1 g
F P
s
P
p
.002 w
.67334 .35653 m .68175 .40627 L .6917 .41609 L p
1 g
F P
s
P
p
.002 w
.55844 .2437 m .50202 .2373 L .51175 .24603 L p
1 g
F P
s
P
p
.002 w
.51175 .24603 m .56234 .25183 L .55844 .2437 L p
1 g
F P
s
P
p
.002 w
.65727 .53113 m .68624 .48359 L .68199 .46896 L p
1 g
F P
s
P
p
.002 w
.6917 .41609 m .68199 .46896 L .68624 .48359 L p
1 g
F P
s
P
p
.002 w
.33004 .52654 m .36681 .57206 L .37193 .56583 L p
1 g
F P
s
P
p
.002 w
.37193 .56583 m .33384 .51862 L .33004 .52654 L p
1 g
F P
s
P
p
.002 w
.42165 .60077 m .37193 .56583 L .36681 .57206 L p
1 g
F P
s
P
p
.002 w
.60991 .58166 m .65518 .5469 L .65727 .53113 L p
1 g
F P
s
P
p
.002 w
.68624 .48359 m .65727 .53113 L .65518 .5469 L p
1 g
F P
s
P
p
.002 w
.54702 .6125 m .60269 .59525 L .60991 .58166 L p
1 g
F P
s
P
p
.002 w
.65518 .5469 m .60991 .58166 L .60269 .59525 L p
1 g
F P
s
P
p
.002 w
.36681 .57206 m .41477 .60579 L .42165 .60077 L p
1 g
F P
s
P
p
.002 w
.47849 .62015 m .42165 .60077 L .41477 .60579 L p
1 g
F P
s
P
p
.002 w
.49183 .23354 m .43491 .24699 L .44914 .24971 L p
1 g
F P
s
P
p
.002 w
.44914 .24971 m .50202 .2373 L .49183 .23354 L p
1 g
F P
s
P
p
.002 w
.47849 .62015 m .53729 .62179 L .54702 .6125 L p
1 g
F P
s
P
p
.002 w
.60269 .59525 m .54702 .6125 L .53729 .62179 L p
1 g
F P
s
P
p
.002 w
.30797 .47331 m .33004 .52654 L .33384 .51862 L p
1 g
F P
s
P
p
.002 w
.33384 .51862 m .31099 .46336 L .30797 .47331 L p
1 g
F P
s
P
p
.002 w
.6917 .41609 m .68242 .36065 L .67334 .35653 L p
1 g
F P
s
P
p
.002 w
.64845 .3106 m .67334 .35653 L .68242 .36065 L p
1 g
F P
s
P
p
.002 w
.42191 .24925 m .37341 .28205 L .38841 .27833 L p
1 g
F P
s
P
p
.002 w
.38841 .27833 m .43491 .24699 L .42191 .24925 L p
1 g
F P
s
P
p
.002 w
.36134 .29003 m .32826 .33773 L .34074 .32898 L p
1 g
F P
s
P
p
.002 w
.34074 .32898 m .37341 .28205 L .36134 .29003 L p
1 g
F P
s
P
p
.002 w
.61155 .26866 m .55844 .2437 L .56234 .25183 L p
1 g
F P
s
P
p
.002 w
.56234 .25183 m .60987 .2742 L .61155 .26866 L p
1 g
F P
s
P
p
.002 w
.32005 .3494 m .30598 .40507 L .31394 .39404 L p
1 g
F P
s
P
p
.002 w
.31394 .39404 m .32826 .33773 L .32005 .3494 L p
1 g
F P
s
P
p
.002 w
.68242 .36065 m .65466 .30935 L .64845 .3106 L p
1 g
F P
s
P
p
.002 w
.60987 .2742 m .64845 .3106 L .65466 .30935 L p
1 g
F P
s
P
p
.002 w
.41477 .60579 m .46954 .62453 L .47849 .62015 L p
1 g
F P
s
P
p
.002 w
.53729 .62179 m .47849 .62015 L .46954 .62453 L p
1 g
F P
s
P
p
.002 w
.65466 .30935 m .61155 .26866 L .60987 .2742 L p
1 g
F P
s
P
p
.002 w
.3031 .41725 m .30797 .47331 L .31099 .46336 L p
1 g
F P
s
P
p
.002 w
.31099 .46336 m .30598 .40507 L .3031 .41725 L p
1 g
F P
s
P
p
.002 w
.68624 .48359 m .6968 .42672 L .6917 .41609 L p
1 g
F P
s
P
p
.002 w
.68242 .36065 m .6917 .41609 L .6968 .42672 L p
1 g
F P
s
P
p
.002 w
.55274 .24041 m .49183 .23354 L .50202 .2373 L p
1 g
F P
s
P
p
.002 w
.50202 .2373 m .55844 .2437 L .55274 .24041 L p
1 g
F P
s
P
p
.002 w
.65518 .5469 m .68551 .49735 L .68624 .48359 L p
1 g
F P
s
P
p
.002 w
.6968 .42672 m .68624 .48359 L .68551 .49735 L p
1 g
F P
s
P
p
.002 w
.60269 .59525 m .64872 .56007 L .65518 .5469 L p
1 g
F P
s
P
p
.002 w
.68551 .49735 m .65518 .5469 L .64872 .56007 L p
1 g
F P
s
P
p
.002 w
.53729 .62179 m .59235 .60484 L .60269 .59525 L p
1 g
F P
s
P
p
.002 w
.64872 .56007 m .60269 .59525 L .59235 .60484 L p
1 g
F P
s
P
p
.002 w
.3308 .53213 m .36516 .57465 L .36681 .57206 L p
1 g
F P
s
P
p
.002 w
.36681 .57206 m .33004 .52654 L .3308 .53213 L p
1 g
F P
s
P
p
.002 w
.41477 .60579 m .36681 .57206 L .36516 .57465 L p
1 g
F P
s
P
p
.002 w
.48145 .23517 m .42191 .24925 L .43491 .24699 L p
1 g
F P
s
P
p
.002 w
.43491 .24699 m .49183 .23354 L .48145 .23517 L p
1 g
F P
s
P
p
.002 w
.46954 .62453 m .52612 .62616 L .53729 .62179 L p
1 g
F P
s
P
p
.002 w
.59235 .60484 m .53729 .62179 L .52612 .62616 L p
1 g
F P
s
P
p
.002 w
.36516 .57465 m .40995 .60616 L .41477 .60579 L p
1 g
F P
s
P
p
.002 w
.46954 .62453 m .41477 .60579 L .40995 .60616 L p
1 g
F P
s
P
p
.002 w
.41059 .25672 m .36134 .29003 L .37341 .28205 L p
1 g
F P
s
P
p
.002 w
.37341 .28205 m .42191 .24925 L .41059 .25672 L p
1 g
F P
s
P
p
.002 w
.3527 .30231 m .32005 .3494 L .32826 .33773 L p
1 g
F P
s
P
p
.002 w
.32826 .33773 m .36134 .29003 L .3527 .30231 L p
1 g
F P
s
P
p
.002 w
.31021 .48249 m .3308 .53213 L .33004 .52654 L p
1 g
F P
s
P
p
.002 w
.33004 .52654 m .30797 .47331 L .31021 .48249 L p
1 g
F P
s
P
p
.002 w
.6968 .42672 m .68682 .36689 L .68242 .36065 L p
1 g
F P
s
P
p
.002 w
.65466 .30935 m .68242 .36065 L .68682 .36689 L p
1 g
F P
s
P
p
.004 w
.4873 .72827 m
.49142 .63158 L
s
P
p
.002 w
.3166 .36383 m .3031 .41725 L .30598 .40507 L p
1 g
F P
s
P
p
.002 w
.30598 .40507 m .32005 .3494 L .3166 .36383 L p
1 g
F P
s
P
p
.002 w
.61018 .26741 m .55274 .24041 L .55844 .2437 L p
1 g
F P
s
P
p
.002 w
.55844 .2437 m .61155 .26866 L .61018 .26741 L p
1 g
F P
s
P
p
.002 w
.40995 .60616 m .46106 .62366 L .46954 .62453 L p
1 g
F P
s
P
p
.002 w
.52612 .62616 m .46954 .62453 L .46106 .62366 L p
1 g
F P
s
P
p
.002 w
.68682 .36689 m .65682 .31143 L .65466 .30935 L p
1 g
F P
s
P
p
.002 w
.61155 .26866 m .65466 .30935 L .65682 .31143 L p
1 g
F P
s
P
p
.002 w
.65682 .31143 m .61018 .26741 L .61155 .26866 L p
1 g
F P
s
P
p
.002 w
.30569 .43032 m .31021 .48249 L .30797 .47331 L p
1 g
F P
s
P
p
.002 w
.30797 .47331 m .3031 .41725 L .30569 .43032 L p
1 g
F P
s
P
p
.002 w
.68551 .49735 m .69658 .43789 L .6968 .42672 L p
1 g
F P
s
P
p
.002 w
.68682 .36689 m .6968 .42672 L .69658 .43789 L p
1 g
F P
s
P
p
.002 w
.5453 .2424 m .48145 .23517 L .49183 .23354 L p
1 g
F P
s
P
p
.002 w
.49183 .23354 m .55274 .24041 L .5453 .2424 L p
1 g
F P
s
P
p
.002 w
.64872 .56007 m .67954 .50978 L .68551 .49735 L p
1 g
F P
s
P
p
.002 w
.69658 .43789 m .68551 .49735 L .67954 .50978 L p
1 g
F P
s
P
p
.002 w
.59235 .60484 m .63781 .57012 L .64872 .56007 L p
1 g
F P
s
P
p
.002 w
.67954 .50978 m .64872 .56007 L .63781 .57012 L p
1 g
F P
s
P
p
.002 w
.52612 .62616 m .57899 .6099 L .59235 .60484 L p
1 g
F P
s
P
p
.002 w
.63781 .57012 m .59235 .60484 L .57899 .6099 L p
1 g
F P
s
P
p
.002 w
.47116 .24247 m .41059 .25672 L .42191 .24925 L p
1 g
F P
s
P
p
.002 w
.42191 .24925 m .48145 .23517 L .47116 .24247 L p
1 g
F P
s
P
p
.002 w
.33641 .53508 m .36725 .57326 L .36516 .57465 L p
1 g
F P
s
P
p
.002 w
.36516 .57465 m .3308 .53213 L .33641 .53508 L p
1 g
F P
s
P
p
.002 w
.40995 .60616 m .36516 .57465 L .36725 .57326 L p
1 g
F P
s
P
p
.002 w
.46106 .62366 m .51374 .62517 L .52612 .62616 L p
1 g
F P
s
P
p
.002 w
.57899 .6099 m .52612 .62616 L .51374 .62517 L p
1 g
F P
s
P
p
.002 w
.40138 .2695 m .3527 .30231 L .36134 .29003 L p
1 g
F P
s
P
p
.002 w
.36134 .29003 m .41059 .25672 L .40138 .2695 L p
1 g
F P
s
P
p
.002 w
.34797 .31877 m .3166 .36383 L .32005 .3494 L p
1 g
F P
s
P
p
.002 w
.32005 .3494 m .3527 .30231 L .34797 .31877 L p
1 g
F P
s
P
p
.002 w
.36725 .57326 m .40748 .60156 L .40995 .60616 L p
1 g
F P
s
P
p
.002 w
.46106 .62366 m .40995 .60616 L .40748 .60156 L p
1 g
F P
s
P
p
.002 w
.31797 .49057 m .33641 .53508 L .3308 .53213 L p
1 g
F P
s
P
p
.002 w
.3308 .53213 m .31021 .48249 L .31797 .49057 L p
1 g
F P
s
P
p
.002 w
.69658 .43789 m .68611 .37521 L .68682 .36689 L p
1 g
F P
s
P
p
.002 w
.65682 .31143 m .68682 .36689 L .68611 .37521 L p
1 g
F P
s
P
p
.002 w
.31831 .38075 m .30569 .43032 L .3031 .41725 L p
1 g
F P
s
P
p
.002 w
.3031 .41725 m .3166 .36383 L .31831 .38075 L p
1 g
F P
s
P
p
.002 w
.60559 .27077 m .5453 .2424 L .55274 .24041 L p
1 g
F P
s
P
p
.002 w
.55274 .24041 m .61018 .26741 L .60559 .27077 L p
1 g
F P
s
P
p
.002 w
.40748 .60156 m .45333 .61723 L .46106 .62366 L p
1 g
F P
s
P
p
.002 w
.51374 .62517 m .46106 .62366 L .45333 .61723 L p
1 g
F P
s
P
p
.002 w
.68611 .37521 m .65459 .31701 L .65682 .31143 L p
1 g
F P
s
P
p
.002 w
.61018 .26741 m .65682 .31143 L .65459 .31701 L p
1 g
F P
s
P
p
.002 w
.65459 .31701 m .60559 .27077 L .61018 .26741 L p
1 g
F P
s
P
p
.002 w
.31402 .44392 m .31797 .49057 L .31021 .48249 L p
1 g
F P
s
P
p
.002 w
.31021 .48249 m .30569 .43032 L .31402 .44392 L p
1 g
F P
s
P
p
.002 w
.67954 .50978 m .69073 .44932 L .69658 .43789 L p
1 g
F P
s
P
p
.002 w
.68611 .37521 m .69658 .43789 L .69073 .44932 L p
1 g
F P
s
P
p
.002 w
.63781 .57012 m .66817 .52043 L .67954 .50978 L p
1 g
F P
s
P
p
.002 w
.69073 .44932 m .67954 .50978 L .66817 .52043 L p
1 g
F P
s
P
p
.002 w
.53621 .24995 m .47116 .24247 L .48145 .23517 L p
1 g
F P
s
P
p
.002 w
.48145 .23517 m .5453 .2424 L .53621 .24995 L p
1 g
F P
s
P
p
.002 w
.57899 .6099 m .62252 .57656 L .63781 .57012 L p
1 g
F P
s
P
p
.002 w
.66817 .52043 m .63781 .57012 L .62252 .57656 L p
1 g
F P
s
P
p
.002 w
.51374 .62517 m .56283 .61 L .57899 .6099 L p
1 g
F P
s
P
p
.002 w
.62252 .57656 m .57899 .6099 L .56283 .61 L p
1 g
F P
s
P
p
.002 w
.4613 .25558 m .40138 .2695 L .41059 .25672 L p
1 g
F P
s
P
p
.002 w
.41059 .25672 m .47116 .24247 L .4613 .25558 L p
1 g
F P
s
P
p
.002 w
.39472 .2875 m .34797 .31877 L .3527 .30231 L p
1 g
F P
s
P
p
.002 w
.3527 .30231 m .40138 .2695 L .39472 .2875 L p
1 g
F P
s
P
p
.002 w
.45333 .61723 m .50047 .61852 L .51374 .62517 L p
1 g
F P
s
P
p
.004 w
.49199 .61829 m
.5 .43051 L
s
P
p
.004 w
.49173 .62437 m
.49179 .62292 L
s
P
p
.004 w
.49142 .63158 m
.49173 .62437 L
s
P
p
.002 w
.56283 .61 m .51374 .62517 L .50047 .61852 L p
1 g
F P
s
P
p
.002 w
.34753 .33912 m .31831 .38075 L .3166 .36383 L p
1 g
F P
s
P
p
.002 w
.3166 .36383 m .34797 .31877 L .34753 .33912 L p
1 g
F P
s
P
p
.002 w
.347 .53513 m .37328 .56769 L .36725 .57326 L p
1 g
F P
s
P
p
.002 w
.36725 .57326 m .33641 .53508 L .347 .53513 L p
1 g
F P
s
P
p
.002 w
.40748 .60156 m .36725 .57326 L .37328 .56769 L p
1 g
F P
s
P
p
.002 w
.37328 .56769 m .40758 .59181 L .40748 .60156 L p
1 g
F P
s
P
p
.002 w
.45333 .61723 m .40748 .60156 L .40758 .59181 L p
1 g
F P
s
P
p
.002 w
.32542 .39977 m .31402 .44392 L .30569 .43032 L p
1 g
F P
s
P
p
.002 w
.30569 .43032 m .31831 .38075 L .32542 .39977 L p
1 g
F P
s
P
p
.002 w
.33137 .49722 m .347 .53513 L .33641 .53508 L p
1 g
F P
s
P
p
.002 w
.33641 .53508 m .31797 .49057 L .33137 .49722 L p
1 g
F P
s
P
p
.002 w
.69073 .44932 m .67996 .38549 L .68611 .37521 L p
1 g
F P
s
P
p
.002 w
.65459 .31701 m .68611 .37521 L .67996 .38549 L p
1 g
F P
s
P
p
.002 w
.59771 .27895 m .53621 .24995 L .5453 .2424 L p
1 g
F P
s
P
p
.002 w
.5453 .2424 m .60559 .27077 L .59771 .27895 L p
1 g
F P
s
P
p
.002 w
.40758 .59181 m .44664 .6051 L .45333 .61723 L p
1 g
F P
s
P
p
.002 w
.50047 .61852 m .45333 .61723 L .44664 .6051 L p
1 g
F P
s
P
p
.002 w
.67996 .38549 m .64774 .32615 L .65459 .31701 L p
1 g
F P
s
P
p
.002 w
.60559 .27077 m .65459 .31701 L .64774 .32615 L p
1 g
F P
s
P
p
.002 w
.32814 .45764 m .33137 .49722 L .31797 .49057 L p
1 g
F P
s
P
p
.002 w
.31797 .49057 m .31402 .44392 L .32814 .45764 L p
1 g
F P
s
P
p
.002 w
.66817 .52043 m .67908 .46066 L .69073 .44932 L p
1 g
F P
s
P
p
.002 w
.67996 .38549 m .69073 .44932 L .67908 .46066 L p
1 g
F P
s
P
p
.002 w
.64774 .32615 m .59771 .27895 L .60559 .27077 L p
1 g
F P
s
P
p
.002 w
.62252 .57656 m .65145 .52887 L .66817 .52043 L p
1 g
F P
s
P
p
.002 w
.67908 .46066 m .66817 .52043 L .65145 .52887 L p
1 g
F P
s
P
p
.002 w
.56283 .61 m .60307 .57898 L .62252 .57656 L p
1 g
F P
s
P
p
.002 w
.65145 .52887 m .62252 .57656 L .60307 .57898 L p
1 g
F P
s
P
p
.002 w
.52569 .26315 m .4613 .25558 L .47116 .24247 L p
1 g
F P
s
P
p
.002 w
.47116 .24247 m .53621 .24995 L .52569 .26315 L p
1 g
F P
s
P
p
.002 w
.50047 .61852 m .54421 .60486 L .56283 .61 L p
1 g
F P
s
P
p
.002 w
.60307 .57898 m .56283 .61 L .54421 .60486 L p
1 g
F P
s
P
p
.002 w
.45223 .2744 m .39472 .2875 L .40138 .2695 L p
1 g
F P
s
P
p
.002 w
.40138 .2695 m .4613 .25558 L .45223 .2744 L p
1 g
F P
s
P
p
.002 w
.39097 .3104 m .34753 .33912 L .34797 .31877 L p
1 g
F P
s
P
p
.002 w
.34797 .31877 m .39472 .2875 L .39097 .3104 L p
1 g
F P
s
P
p
.002 w
.35162 .36288 m .32542 .39977 L .31831 .38075 L p
1 g
F P
s
P
p
.002 w
.31831 .38075 m .34753 .33912 L .35162 .36288 L p
1 g
F P
s
P
p
.002 w
.44664 .6051 m .48666 .60609 L .50047 .61852 L p
1 g
F P
s
P
p
.002 w
.54421 .60486 m .50047 .61852 L .48666 .60609 L p
1 g
F P
s
P
p
.002 w
.36256 .53208 m .3833 .55783 L .37328 .56769 L p
1 g
F P
s
P
p
.002 w
.37328 .56769 m .347 .53513 L .36256 .53208 L p
1 g
F P
s
P
p
.002 w
.40758 .59181 m .37328 .56769 L .3833 .55783 L p
1 g
F P
s
P
p
.002 w
.33798 .42035 m .32814 .45764 L .31402 .44392 L p
1 g
F P
s
P
p
.002 w
.31402 .44392 m .32542 .39977 L .33798 .42035 L p
1 g
F P
s
P
p
.002 w
.3833 .55783 m .41042 .57688 L .40758 .59181 L p
1 g
F P
s
P
p
.002 w
.44664 .6051 m .40758 .59181 L .41042 .57688 L p
1 g
F P
s
P
p
.002 w
.67908 .46066 m .66825 .39752 L .67996 .38549 L p
1 g
F P
s
P
p
.002 w
.64774 .32615 m .67996 .38549 L .66825 .39752 L p
1 g
F P
s
P
p
.002 w
.3503 .50216 m .36256 .53208 L .347 .53513 L p
1 g
F P
s
P
p
.002 w
.347 .53513 m .33137 .49722 L .3503 .50216 L p
1 g
F P
s
P
p
.002 w
.5866 .29198 m .52569 .26315 L .53621 .24995 L p
1 g
F P
s
P
p
.002 w
.53621 .24995 m .59771 .27895 L .5866 .29198 L p
1 g
F P
s
P
p
.002 w
.41042 .57688 m .44126 .5873 L .44664 .6051 L p
1 g
F P
s
P
p
.002 w
.48666 .60609 m .44664 .6051 L .44126 .5873 L p
1 g
F P
s
P
p
.002 w
.65145 .52887 m .66166 .47153 L .67908 .46066 L p
1 g
F P
s
P
p
.002 w
.66825 .39752 m .67908 .46066 L .66166 .47153 L p
1 g
F P
s
P
p
.002 w
.3479 .47102 m .3503 .50216 L .33137 .49722 L p
1 g
F P
s
P
p
.002 w
.33137 .49722 m .32814 .45764 L .3479 .47102 L p
1 g
F P
s
P
p
.002 w
.66825 .39752 m .63621 .33877 L .64774 .32615 L p
1 g
F P
s
P
p
.002 w
.59771 .27895 m .64774 .32615 L .63621 .33877 L p
1 g
F P
s
P
p
.002 w
.54421 .60486 m .57988 .57706 L .60307 .57898 L p
1 g
F P
s
P
p
.002 w
.62963 .53468 m .60307 .57898 L .57988 .57706 L p
1 g
F P
s
P
p
.002 w
.60307 .57898 m .62963 .53468 L .65145 .52887 L p
1 g
F P
s
P
p
.002 w
.66166 .47153 m .65145 .52887 L .62963 .53468 L p
1 g
F P
s
P
p
.002 w
.63621 .33877 m .5866 .29198 L .59771 .27895 L p
1 g
F P
s
P
p
.002 w
.57988 .57706 m .54421 .60486 L .52363 .59435 L p
1 g
F P
s
P
p
.002 w
.48666 .60609 m .52363 .59435 L .54421 .60486 L p
1 g
F P
s
P
p
.002 w
.514 .28188 m .45223 .2744 L .4613 .25558 L p
1 g
F P
s
P
p
.002 w
.4613 .25558 m .52569 .26315 L .514 .28188 L p
1 g
F P
s
P
p
.002 w
.3904 .33764 m .35162 .36288 L .34753 .33912 L p
1 g
F P
s
P
p
.002 w
.34753 .33912 m .39097 .3104 L .3904 .33764 L p
1 g
F P
s
P
p
.002 w
.44429 .29857 m .39097 .3104 L .39472 .2875 L p
1 g
F P
s
P
p
.002 w
.39472 .2875 m .45223 .2744 L .44429 .29857 L p
1 g
F P
s
P
p
.002 w
.36032 .38941 m .33798 .42035 L .32542 .39977 L p
1 g
F P
s
P
p
.002 w
.32542 .39977 m .35162 .36288 L .36032 .38941 L p
1 g
F P
s
P
p
.002 w
.44126 .5873 m .47276 .58796 L .48666 .60609 L p
1 g
F P
s
P
p
.002 w
.52363 .59435 m .48666 .60609 L .47276 .58796 L p
1 g
F P
s
P
p
.002 w
.35582 .44186 m .3479 .47102 L .32814 .45764 L p
1 g
F P
s
P
p
.002 w
.32814 .45764 m .33798 .42035 L .35582 .44186 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.38284 .52586 m .39722 .54376 L .3833 .55783 L p
1 g
F P
s
P
p
.002 w
.3833 .55783 m .36256 .53208 L .38284 .52586 L p
1 g
F P
s
P
p
.002 w
.41042 .57688 m .3833 .55783 L .39722 .54376 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.39722 .54376 m .41607 .55697 L .41042 .57688 L p
1 g
F P
s
P
p
.002 w
.44126 .5873 m .41042 .57688 L .41607 .55697 L p
1 g
F P
s
P
p
.002 w
.66166 .47153 m .65104 .41098 L .66825 .39752 L p
1 g
F P
s
P
p
.002 w
.63621 .33877 m .66825 .39752 L .65104 .41098 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37441 .5051 m .38284 .52586 L .36256 .53208 L p
1 g
F P
s
P
p
.002 w
.36256 .53208 m .3503 .50216 L .37441 .5051 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.57246 .30969 m .514 .28188 L .52569 .26315 L p
1 g
F P
s
P
p
.002 w
.52569 .26315 m .5866 .29198 L .57246 .30969 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.41607 .55697 m .43747 .56414 L .44126 .5873 L p
1 g
F P
s
P
p
.002 w
.47276 .58796 m .44126 .5873 L .43747 .56414 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52363 .59435 m .55356 .57068 L .57988 .57706 L p
1 g
F P
s
P
p
.002 w
.60321 .53754 m .57988 .57706 L .55356 .57068 L p
1 g
F P
s
P
p
.002 w
.57988 .57706 m .60321 .53754 L .62963 .53468 L p
1 g
F P
s
P
p
.002 w
.62963 .53468 m .63878 .48153 L .66166 .47153 L p
1 g
F P
s
P
p
.002 w
.65104 .41098 m .66166 .47153 L .63878 .48153 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.63878 .48153 m .62963 .53468 L .60321 .53754 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.37288 .48358 m .37441 .5051 L .3503 .50216 L p
1 g
F P
s
P
p
.002 w
.3503 .50216 m .3479 .47102 L .37288 .48358 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.48921 .57862 m .47961 .57783 L .47965 .57784 L 1 g
F
P
p
.002 w
.49235 .5816 m .47276 .58796 L .46762 .57903 L p
1 g
F P
s
P
p
.002 w
.46762 .57903 m .46433 .57331 L p
.46832 .57449 L 1 g
F P
s
P
p
.002 w
.46832 .57449 m .46872 .57265 L p
.45856 .56859 L 1 g
F P
s
P
p
.002 w
.46341 .5717 m .47276 .58796 L p
.45199 .56437 L 1 g
F P
s
P
p
.45856 .56859 m .45643 .56774 L .46341 .5717 L 1 g
F
P
p
.45856 .56859 m .46341 .5717 L .46832 .57449 L 1 g
F
P
p
.45146 .56129 m .44451 .55525 L .44562 .55671 L 1 g
F
P
p
.002 w
.45146 .56436 m .43747 .56414 L .43663 .55239 L p
1 g
F P
s
P
p
.002 w
.43663 .55239 m .43605 .54415 L p
.43841 .54725 L 1 g
F P
s
P
p
.002 w
.43841 .54725 m .43925 .54566 L p
.43429 .53585 L 1 g
F P
s
P
p
.002 w
.42446 .53254 m .43427 .53578 L p
.43747 .56414 L 1 g
F P
s
P
p
.002 w
.43575 .53999 m .43747 .56414 L p
.43427 .53578 L 1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.42446 .53254 m .42981 .51875 L p
.43245 .52882 L 1 g
F P
s
P
p
.002 w
.43427 .53578 m .43201 .53503 L p
.43245 .52882 L 1 g
F P
s
P
p
.002 w
.43201 .53503 m .42446 .53254 L p
.43245 .52882 L 1 g
F P
s
P
p
.002 w
.43245 .52882 m .43346 .52734 L p
.43316 .51874 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43245 .52882 L p
1 g
F P
s
P
p
.002 w
.43245 .52882 m .43146 .53025 L p
.43428 .53583 L 1 g
F P
s
P
p
.43925 .54566 m .43245 .52882 L .43428 .53583 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43382 .50949 L p
1 g
F P
s
P
p
.002 w
.42981 .51875 m .43122 .51513 L p
.43245 .52882 L 1 g
F P
s
P
p
.002 w
.43122 .51513 m .43391 .50819 L p
.43382 .50949 L 1 g
F P
s
P
p
.43245 .52882 m .43122 .51513 L .43382 .50949 L 1 g
F
P
p
.002 w
.43382 .50949 m .43485 .50826 L p
.43872 .4992 L 1 g
F P
s
P
p
.002 w
.43864 .49937 m .43543 .50427 L p
.44167 .49224 L 1 g
F P
s
P
p
.45079 .47467 m .44258 .49136 L .44167 .49224 L 1 g
F
P
p
.44258 .49136 m .43864 .49937 L .44167 .49224 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44179 .4922 L p
1 g
F P
s
P
p
.43485 .50826 m .44179 .4922 L .44084 .49426 L 1 g
F
P
p
.43872 .4992 m .43872 .49921 L .43382 .50949 L 1 g
F
P
p
.43872 .4992 m .4385 .49965 L .43382 .50949 L 1 g
F
P
p
.43878 .49906 m .43831 .50002 L .43382 .50949 L 1 g
F
P
p
.002 w
.43668 .50336 m .43543 .50427 L .43864 .49937 L p
1 g
F P
s
P
p
.43891 .49877 m .43812 .5004 L .43382 .50949 L 1 g
F
P
p
.4391 .49832 m .43787 .50087 L .43382 .50949 L 1 g
F
P
p
.43938 .49768 m .43753 .50155 L .43382 .50949 L 1 g
F
P
p
.43973 .49685 m .43704 .50255 L .43382 .50949 L 1 g
F
P
p
.002 w
.43637 .504 m .43543 .50427 L .43668 .50336 L p
1 g
F P
s
P
p
.44014 .49589 m .43636 .50399 L .43382 .50949 L 1 g
F
P
p
.002 w
.43622 .50431 m .43543 .50427 L .43637 .504 L p
1 g
F P
s
P
p
.44054 .49495 m .43543 .50599 L .43382 .50949 L 1 g
F
P
p
.43346 .52734 m .43382 .50949 L .43316 .51874 L 1 g
F
P
p
.43427 .53578 m .43245 .52882 L .43515 .50661 L 1 g
F
P
p
.43536 .50614 m .43515 .50661 L .43543 .50427 L 1 g
F
P
p
.43427 .53578 m .43515 .50661 L .43536 .50614 L 1 g
F
P
p
.002 w
.44179 .4922 m .44166 .49233 L p
.44084 .49426 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45092 .48328 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45608 .47829 m .46269 .48449 L p
.44691 .48717 L 1 g
F P
s
P
p
.45092 .48328 m .44618 .48787 L .44258 .49136 L 1 g
F
P
p
.002 w
.43864 .49937 m .44618 .48787 L p
.43668 .50336 L 1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45755 .47686 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46269 .48449 m .45608 .47829 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.45755 .47686 m .45826 .47608 L p
.46778 .4719 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46717 L p
1 g
F P
s
P
p
.45826 .47608 m .47756 .46717 L .46778 .4719 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47756 .46717 m .47786 .46667 L p
.49136 .4653 L 1 g
F P
s
P
p
.48949 .46556 m .46865 .49481 L .48736 .46586 L 1 g
F
P
p
.49136 .4653 m .48736 .46586 L .47756 .46717 L 1 g
F
P
p
.002 w
.50322 .48323 m .46865 .49481 L p
.48949 .46556 L 1 g
F P
s
P
p
.002 w
.49284 .46509 m .50322 .48323 L p
.48949 .46556 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50322 .48323 m .49284 .46509 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46713 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46713 L .51017 .46536 L 1 g
F
P
p
.51043 .46539 m .50322 .48323 L .5 .46388 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53781 .46997 m .57106 .45554 L p
.55555 .48278 L 1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56585 .50909 L p
1 g
F P
s
P
p
.002 w
.57915 .49735 m .57444 .52754 L p
.56601 .50944 L 1 g
F P
s
P
p
.55661 .4905 m .56585 .50909 L .56193 .50068 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56158 .49994 m .56511 .49942 L p
.5628 .50254 L 1 g
F P
s
P
p
.002 w
.56511 .49942 m .57915 .49735 L p
.56588 .50956 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56733 .52849 L p
1 g
F P
s
P
p
.56515 .50826 m .56733 .52849 L .5664 .51639 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.57293 .53721 m .56795 .53666 L p
.56736 .52836 L 1 g
F P
s
P
p
.56601 .50944 m .56907 .52173 L .56736 .52836 L 1 g
F
P
p
.56907 .52173 m .57293 .53721 L .56736 .52836 L 1 g
F
P
p
.002 w
.57293 .53721 m .55356 .57068 L .55282 .5704 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55356 .57068 m .52363 .59435 L .51151 .58563 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58063 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58063 L .49417 .58101 L 1 g
F
P
p
.002 w
.50522 .58111 m .51087 .58517 L p
.49417 .58101 L 1 g
F P
s
P
p
.49865 .58105 m .49417 .58101 L .49758 .58126 L 1 g
F
P
p
.51079 .57862 m .49417 .58101 L .49865 .58105 L 1 g
F
P
p
.002 w
.49235 .5816 m .49417 .58101 L p
.51087 .58517 L 1 g
F P
s
P
p
.002 w
.51151 .58563 m .50641 .58196 L p
.52232 .57938 L 1 g
F P
s
P
p
.002 w
.50641 .58196 m .50522 .58111 L p
.51093 .58053 L 1 g
F P
s
P
p
.52232 .57938 m .50641 .58196 L .51093 .58053 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58053 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58053 L .52388 .57644 L 1 g
F
P
p
.002 w
.47276 .58796 m .49235 .5816 L p
.52363 .59435 L 1 g
F P
s
P
p
.002 w
.51087 .58517 m .52363 .59435 L p
.49235 .5816 L 1 g
F P
s
P
p
.002 w
.51093 .58053 m .51079 .57862 L p
.49129 .58252 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.53157 .57402 m .52232 .57938 L .51545 .57911 L 1 g
F
P
p
.002 w
.53158 .57402 m .53128 .57265 L p
.52388 .57644 L 1 g
F P
s
P
p
.53157 .57402 m .51545 .57911 L .50169 .57856 L 1 g
F
P
p
.53157 .57402 m .51545 .57911 L .53157 .57402 L 1 g
F
P
p
.002 w
.50522 .58111 m .50169 .57856 L p
.52232 .57938 L 1 g
F P
s
P
p
.55356 .57068 m .51151 .58563 L .53157 .57402 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53158 .57402 L p
1 g
F P
s
P
p
.54854 .56129 m .53158 .57402 L .53907 .56968 L 1 g
F
P
p
.54854 .56129 m .53907 .56968 L .54076 .56871 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54376 .56697 m .55356 .57068 L p
.53157 .57402 L 1 g
F P
s
P
p
.002 w
.55282 .5704 m .54547 .56762 L p
.55809 .55603 L 1 g
F P
s
P
p
.002 w
.54547 .56762 m .54376 .56697 L p
.54913 .56287 L 1 g
F P
s
P
p
.55809 .55603 m .54547 .56762 L .54913 .56287 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54913 .56287 L p
1 g
F P
s
P
p
.56075 .54566 m .54913 .56287 L .5566 .55319 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56143 .54693 m .56075 .54566 L p
.5566 .55319 L 1 g
F P
s
P
p
.57293 .53721 m .55282 .5704 L .56333 .54174 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56143 .54693 L p
1 g
F P
s
P
p
.002 w
.5653 .53637 m .57293 .53721 L p
.56333 .54174 L 1 g
F P
s
P
p
.002 w
.56143 .54693 m .5622 .5484 L p
.56388 .54024 L 1 g
F P
s
P
p
.56654 .52734 m .56143 .54693 L .56388 .54024 L 1 g
F
P
p
.56654 .52734 m .5622 .5484 L .5639 .5418 L 1 g
F
P
p
.002 w
.56733 .52849 m .56654 .52734 L p
.56449 .53859 L 1 g
F P
s
P
p
.56449 .53859 m .5639 .5418 L .5653 .53637 L 1 g
F
P
p
.56449 .53859 m .5653 .53637 L .56733 .52849 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.52493 .55985 m .53978 .53358 L .5653 .53637 L p
1 g
F P
s
P
p
.56333 .54174 m .52493 .55985 L .5653 .53637 L 1 g
F
P
p
.002 w
.56585 .50909 m .56515 .50826 L p
.5664 .51639 L 1 g
F P
s
P
p
.56588 .50956 m .56733 .52849 L .53978 .53358 L 1 g
F
P
p
.002 w
.56795 .53666 m .5653 .53637 L p
.56733 .52849 L 1 g
F P
s
P
p
.002 w
.5653 .53637 m .53978 .53358 L p
.56733 .52849 L 1 g
F P
s
P
p
.002 w
.5622 .5484 m .56257 .5491 L p
.5639 .5418 L 1 g
F P
s
P
p
.56333 .54174 m .56143 .54693 L .52493 .55985 L 1 g
F
P
p
.56143 .54693 m .55809 .55603 L .55405 .5565 L 1 g
F
P
p
.56143 .54693 m .55405 .5565 L .52493 .55985 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54913 .56287 L p
1 g
F P
s
P
p
.002 w
.54913 .56287 m .54854 .56129 L p
.53783 .5715 L 1 g
F P
s
P
p
.53783 .5715 m .5322 .57686 L .54913 .56287 L 1 g
F
P
p
.002 w
.54376 .56697 m .52493 .55985 L p
.55809 .55603 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56143 .54693 L p
1 g
F P
s
P
p
.5566 .55319 m .54998 .56518 L .56143 .54693 L 1 g
F
P
p
.002 w
.54913 .56287 m .54998 .56518 L p
.5566 .55319 L 1 g
F P
s
P
p
.002 w
.50169 .57856 m .52493 .55985 L .54376 .56697 L p
1 g
F P
s
P
p
.53157 .57402 m .50169 .57856 L .54376 .56697 L 1 g
F
P
p
.54076 .56871 m .532 .57595 L .53783 .5715 L 1 g
F
P
p
.53907 .56968 m .532 .57595 L .54076 .56871 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53158 .57402 L p
1 g
F P
s
P
p
.52388 .57644 m .51111 .583 L .53158 .57402 L 1 g
F
P
p
.002 w
.51093 .58053 m .51111 .583 L p
.52388 .57644 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58053 L p
1 g
F P
s
P
p
.49129 .58252 m .48889 .583 L .51093 .58053 L 1 g
F
P
p
.002 w
.49417 .58101 m .50169 .57856 L .50522 .58111 L p
1 g
F P
s
P
p
.002 w
.53158 .57402 m .532 .57595 L p
.53907 .56968 L 1 g
F P
s
P
p
.002 w
.532 .57595 m .5322 .57686 L p
.53783 .5715 L 1 g
F P
s
P
p
.56601 .50944 m .56795 .53666 L .56588 .50956 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56789 .52931 L p
1 g
F P
s
P
p
.002 w
.56789 .52931 m .56733 .52849 L p
.56587 .53482 L 1 g
F P
s
P
p
.56587 .53482 m .56257 .5491 L .56789 .52931 L 1 g
F
P
p
.5639 .5418 m .56257 .5491 L .56733 .52849 L 1 g
F
P
p
.002 w
.57444 .52754 m .57293 .53721 L p
.56601 .50944 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56585 .50909 L p
1 g
F P
s
P
p
.5664 .51639 m .56854 .53025 L .56585 .50909 L 1 g
F
P
p
.56588 .50956 m .53978 .53358 L .56511 .49942 L 1 g
F
P
p
.002 w
.57106 .45554 m .57915 .49735 L .56158 .49994 L p
1 g
F P
s
P
p
.55661 .4905 m .56193 .50068 L .56158 .49994 L 1 g
F
P
p
.002 w
.55723 .49116 m .55661 .4905 L p
.56158 .49994 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55723 .49116 L p
1 g
F P
s
P
p
.54174 .47608 m .55723 .49116 L .54876 .48296 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56158 .49994 m .54434 .50247 L p
.55423 .48511 L 1 g
F P
s
P
p
.56239 .49616 m .56158 .49994 L .55723 .49116 L 1 g
F
P
p
.002 w
.55776 .49172 m .55723 .49116 L p
.56158 .49994 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55776 .49172 L p
1 g
F P
s
P
p
.56193 .50068 m .56713 .51061 L .55776 .49172 L 1 g
F
P
p
.55307 .48713 m .54434 .50247 L .54234 .47673 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54234 .47673 L p
1 g
F P
s
P
p
.002 w
.54234 .47673 m .54174 .47608 L p
.54876 .48296 L 1 g
F P
s
P
p
.54876 .48296 m .55834 .49233 L .54234 .47673 L 1 g
F
P
p
.57106 .45554 m .56239 .49616 L .55423 .48511 L 1 g
F
P
p
.56239 .49616 m .55723 .49116 L .55423 .48511 L 1 g
F
P
p
.002 w
.53978 .53358 m .54434 .50247 L .56158 .49994 L p
1 g
F P
s
P
p
.5628 .50254 m .53978 .53358 L .56158 .49994 L 1 g
F
P
p
.002 w
.56733 .52849 m .56854 .53025 L p
.5664 .51639 L 1 g
F P
s
P
p
.002 w
.56585 .50909 m .56713 .51061 L p
.56193 .50068 L 1 g
F P
s
P
p
.002 w
.55723 .49116 m .55834 .49233 L p
.54876 .48296 L 1 g
F P
s
P
p
.002 w
.54434 .50247 m .53885 .47513 L p
.54234 .47673 L 1 g
F P
s
P
p
.55555 .48278 m .55307 .48713 L .54234 .47673 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54234 .47673 L .54077 .47601 L 1 g
F
P
p
.52214 .46667 m .54245 .47686 L .53418 .4729 L 1 g
F
P
p
.002 w
.53885 .47513 m .53781 .46997 L p
.55555 .48278 L 1 g
F P
s
P
p
.002 w
.54234 .47673 m .54245 .47686 L p
.54077 .47601 L 1 g
F P
s
P
p
.002 w
.54434 .50247 m .50784 .5054 L p
.535 .47329 L 1 g
F P
s
P
p
.002 w
.53885 .47513 m .54434 .50247 L p
.535 .47329 L 1 g
F P
s
P
p
.002 w
.50784 .5054 m .50322 .48323 L .53239 .47205 L p
1 g
F P
s
P
p
.52214 .46667 m .53418 .4729 L .53239 .47205 L 1 g
F
P
p
.002 w
.52074 .43985 m .53781 .46997 L .53239 .47205 L p
1 g
F P
s
P
p
.002 w
.53239 .47205 m .50322 .48323 L p
.51183 .46191 L 1 g
F P
s
P
p
.002 w
.52242 .46713 m .52214 .46667 L p
.53239 .47205 L 1 g
F P
s
P
p
.52074 .43985 m .53239 .47205 L .51183 .46191 L 1 g
F
P
p
.002 w
.52254 .46734 m .52242 .46713 L p
.53239 .47205 L 1 g
F P
s
P
p
.002 w
.53239 .47205 m .53781 .46997 L p
.535 .47329 L 1 g
F P
s
P
p
.535 .47329 m .50784 .5054 L .53239 .47205 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52254 .46734 L p
1 g
F P
s
P
p
.53418 .4729 m .54302 .47747 L .52254 .46734 L 1 g
F
P
p
.002 w
.54245 .47686 m .54302 .47747 L p
.53418 .4729 L 1 g
F P
s
P
p
.002 w
.53781 .46997 m .53885 .47513 L p
.535 .47329 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51017 .46536 L 1 g
F P
s
P
p
.51017 .46536 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .49197 .46523 L 1 g
F
P
p
.002 w
.49284 .46509 m .4915 .46274 L p
.49196 .46272 L 1 g
F P
s
P
p
.51184 .46189 m .5 .46388 L .49196 .46272 L 1 g
F
P
p
.5 .46388 m .49284 .46509 L .49196 .46272 L 1 g
F
P
p
.51184 .46189 m .51043 .46539 L .5 .46388 L 1 g
F
P
p
.002 w
.52242 .46713 m .52282 .46778 L p
.51017 .46536 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49197 .46523 L 1 g
F P
s
P
p
.002 w
.4915 .46274 m .52074 .43985 L p
.51184 .46189 L 1 g
F P
s
P
p
.002 w
.4915 .46274 m .49284 .46509 L p
.48949 .46556 L 1 g
F P
s
P
p
.002 w
.46865 .49481 m .46269 .48449 L .48736 .46586 L p
1 g
F P
s
P
p
.002 w
.48736 .46586 m .46269 .48449 L p
.4674 .46853 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47751 .46725 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47756 .46717 L p
.48135 .46671 L 1 g
F P
s
P
p
.48135 .46671 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.49136 .4653 m .49223 .46521 L .48736 .46586 L 1 g
F
P
p
.002 w
.48736 .46586 m .4915 .46274 L p
.48949 .46556 L 1 g
F P
s
P
p
.002 w
.47397 .44628 m .4915 .46274 L .48736 .46586 L p
1 g
F P
s
P
p
.47397 .44628 m .48736 .46586 L .4674 .46853 L 1 g
F
P
p
.49223 .46521 m .5 .46442 L .47756 .46717 L 1 g
F
P
p
.002 w
.47756 .46717 m .47718 .46778 L p
.46778 .4719 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.46793 .46674 m .45755 .47686 L .45385 .47619 L 1 g
F
P
p
.44339 .4905 m .45755 .47686 L .4565 .47788 L 1 g
F
P
p
.002 w
.45608 .47829 m .45557 .47781 L p
.45755 .47686 L 1 g
F P
s
P
p
.002 w
.45557 .47781 m .45385 .47619 L p
.45755 .47686 L 1 g
F P
s
P
p
.46793 .46674 m .46617 .47268 L .45755 .47686 L 1 g
F
P
p
.46617 .47268 m .46269 .48449 L .45755 .47686 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45755 .47686 L p
1 g
F P
s
P
p
.46778 .4719 m .47718 .46778 L .45755 .47686 L 1 g
F
P
p
.002 w
.45755 .47686 m .45745 .47696 L p
.4565 .47788 L 1 g
F P
s
P
p
.002 w
.45385 .47619 m .47397 .44628 L p
.46793 .46674 L 1 g
F P
s
P
p
.44339 .4905 m .45745 .47696 L .45103 .48318 L 1 g
F
P
p
.002 w
.45079 .47467 m .45385 .47619 L .44618 .48787 L p
1 g
F P
s
P
p
.002 w
.44618 .48787 m .43864 .49937 L p
.44258 .49136 L 1 g
F P
s
P
p
.45079 .47467 m .44618 .48787 L .44258 .49136 L 1 g
F
P
p
.002 w
.45745 .47696 m .45698 .47747 L p
.45103 .48318 L 1 g
F P
s
P
p
.002 w
.44618 .48787 m .45385 .47619 L p
.44691 .48717 L 1 g
F P
s
P
p
.44691 .48717 m .43668 .50336 L .44618 .48787 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.46269 .48449 m .43668 .50336 L p
.44691 .48717 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44257 .49137 L p
1 g
F P
s
P
p
.002 w
.44257 .49137 m .44258 .49136 L p
.44277 .49117 L 1 g
F P
s
P
p
.44277 .49117 m .45698 .47747 L .44257 .49137 L 1 g
F
P
p
.45092 .48328 m .45103 .48318 L .44618 .48787 L 1 g
F
P
p
.002 w
.45385 .47619 m .45608 .47829 L p
.44691 .48717 L 1 g
F P
s
P
p
.45103 .48318 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.43872 .4992 m .43872 .4992 L .43872 .49921 L 1 g
F
P
p
.002 w
.43543 .50427 m .4431 .47085 L .45079 .47467 L p
1 g
F P
s
P
p
.43872 .4992 m .43878 .49906 L .4385 .49965 L 1 g
F
P
p
.43878 .49906 m .43891 .49877 L .43831 .50002 L 1 g
F
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.46269 .48449 m .46865 .49481 L .43637 .504 L p
1 g
F P
s
P
p
.002 w
.43668 .50336 m .46269 .48449 L p
.43637 .504 L 1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.46865 .49481 m .47107 .506 L .43622 .50431 L p
1 g
F P
s
P
p
.002 w
.43637 .504 m .46865 .49481 L p
.43622 .50431 L 1 g
F P
s
P
p
.43891 .49877 m .4391 .49832 L .43812 .5004 L 1 g
F
P
p
.4391 .49832 m .43938 .49768 L .43787 .50087 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.47107 .506 m .46971 .51682 L .43612 .50452 L p
1 g
F P
s
P
p
.002 w
.43612 .50452 m .43543 .50427 L .43622 .50431 L p
1 g
F P
s
P
p
.002 w
.43622 .50431 m .47107 .506 L p
.43612 .50452 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.46971 .51682 m .46475 .52609 L .43603 .50471 L p
1 g
F P
s
P
p
.002 w
.43603 .50471 m .43543 .50427 L .43612 .50452 L p
1 g
F P
s
P
p
.002 w
.43612 .50452 m .46971 .51682 L p
.43603 .50471 L 1 g
F P
s
P
p
.43938 .49768 m .43973 .49685 L .43753 .50155 L 1 g
F
P
p
.43973 .49685 m .44014 .49589 L .43704 .50255 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.46475 .52609 m .45676 .53281 L .43592 .50493 L p
1 g
F P
s
P
p
.002 w
.43592 .50493 m .43543 .50427 L .43603 .50471 L p
1 g
F P
s
P
p
.002 w
.43603 .50471 m .46475 .52609 L p
.43592 .50493 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.45676 .53281 m .44664 .53629 L .43577 .50525 L p
1 g
F P
s
P
p
.002 w
.43577 .50525 m .43543 .50427 L .43592 .50493 L p
1 g
F P
s
P
p
.002 w
.43592 .50493 m .45676 .53281 L p
.43577 .50525 L 1 g
F P
s
P
p
.44014 .49589 m .44054 .49495 L .43636 .50399 L 1 g
F
P
p
.44054 .49495 m .44084 .49426 L .43543 .50599 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44664 .53629 m .43548 .53618 L .43543 .50599 L p
1 g
F P
s
P
p
.002 w
.43543 .50599 m .43543 .50427 L .43577 .50525 L p
1 g
F P
s
P
p
.002 w
.43577 .50525 m .44664 .53629 L p
.43543 .50599 L 1 g
F P
s
P
p
.002 w
.43391 .50819 m .43543 .50427 L p
.43245 .52882 L 1 g
F P
s
P
p
.002 w
.43543 .50427 m .43548 .53618 L .43427 .53578 L p
1 g
F P
s
P
p
.002 w
.43382 .50949 m .43381 .50949 L p
.43316 .51874 L 1 g
F P
s
P
p
.002 w
.43391 .50819 m .43122 .51513 L p
.4341 .50565 L 1 g
F P
s
P
p
.002 w
.43381 .50949 m .43287 .51061 L p
.43315 .51849 L 1 g
F P
s
P
p
.43316 .51874 m .43381 .50949 L .43315 .51849 L 1 g
F
P
p
.002 w
.41475 .52574 m .4341 .50565 L p
.43122 .51513 L 1 g
F P
s
P
p
.002 w
.4341 .50565 m .43543 .50427 L .43391 .50819 L p
1 g
F P
s
P
p
.002 w
.43122 .51513 m .42446 .53254 L .4235 .53186 L p
1 g
F P
s
P
p
.002 w
.4235 .53186 m .41475 .52574 L p
.43122 .51513 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43381 .50949 L p
1 g
F P
s
P
p
.002 w
.43381 .50949 m .43382 .50949 L p
.43403 .50901 L 1 g
F P
s
P
p
.43403 .50901 m .44166 .49233 L .43381 .50949 L 1 g
F
P
p
.44084 .49426 m .44166 .49233 L .43382 .50949 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43245 .52882 L p
1 g
F P
s
P
p
.43316 .51874 m .43287 .51061 L .43245 .52882 L 1 g
F
P
p
.43429 .53585 m .43428 .53583 L .43575 .53999 L 1 g
F
P
p
.43428 .53583 m .43409 .53546 L .43441 .53632 L 1 g
F
P
p
.43428 .53583 m .43441 .53632 L .43575 .53999 L 1 g
F
P
p
.43429 .53585 m .43575 .53999 L .43841 .54725 L 1 g
F
P
p
.002 w
.43427 .53578 m .43548 .53618 L .43575 .53999 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45069 .56336 L p
1 g
F P
s
P
p
.46872 .57265 m .45069 .56336 L .45598 .56749 L 1 g
F
P
p
.46872 .57265 m .45598 .56749 L .45643 .56774 L 1 g
F
P
p
.48906 .58063 m .47762 .57977 L .46832 .57449 L 1 g
F
P
p
.47762 .57977 m .46762 .57903 L .46832 .57449 L 1 g
F
P
p
.49235 .5816 m .46762 .57903 L .48906 .58063 L 1 g
F
P
p
.002 w
.48904 .58096 m .48906 .58063 L p
.46787 .57688 L 1 g
F P
s
P
p
.002 w
.48906 .58063 m .48921 .57862 L p
.47965 .57784 L 1 g
F P
s
P
p
.47965 .57784 m .46787 .57688 L .48906 .58063 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.49235 .5816 m .46832 .57449 L .45925 .56448 L 1 g
F
P
p
.002 w
.46433 .57331 m .46341 .5717 L p
.46832 .57449 L 1 g
F P
s
P
p
.002 w
.46341 .5717 m .45925 .56448 L p
.46832 .57449 L 1 g
F P
s
P
p
.45643 .56774 m .45598 .56749 L .45618 .56764 L 1 g
F
P
p
.45069 .56336 m .44175 .55638 L .43841 .54725 L 1 g
F
P
p
.44175 .55638 m .43663 .55239 L .43841 .54725 L 1 g
F
P
p
.45146 .56436 m .43663 .55239 L .45069 .56336 L 1 g
F
P
p
.002 w
.45064 .5635 m .45069 .56336 L p
.43984 .55217 L 1 g
F P
s
P
p
.002 w
.45069 .56336 m .45146 .56129 L p
.44562 .55671 L 1 g
F P
s
P
p
.44562 .55671 m .43984 .55217 L .45069 .56336 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43605 .54415 m .43548 .53618 L p
.45146 .56436 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43841 .54725 L p
1 g
F P
s
P
p
.43409 .53546 m .43146 .53025 L .43841 .54725 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45925 .56448 m .45146 .56436 L p
.43548 .53618 L 1 g
F P
s
P
p
.002 w
.43747 .56414 m .45146 .56436 L p
.47276 .58796 L 1 g
F P
s
P
p
.002 w
.45146 .56436 m .45199 .56437 L p
.45834 .57159 L 1 g
F P
s
P
p
.47276 .58796 m .45146 .56436 L .45834 .57159 L 1 g
F
P
p
.002 w
.45069 .56336 m .45002 .56518 L p
.45618 .56764 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .43984 .55217 L p
.44562 .55671 L 1 g
F P
s
P
p
.44451 .55525 m .43743 .5491 L .44562 .55671 L 1 g
F
P
p
.002 w
.43984 .55217 m .45002 .56518 L .45064 .5635 L p
1 g
F P
s
P
p
.002 w
.45199 .56437 m .45925 .56448 L .46341 .5717 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46832 .57449 L p
1 g
F P
s
P
p
.45643 .56774 m .45002 .56518 L .46832 .57449 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.50169 .57856 m .49235 .5816 L p
.45925 .56448 L 1 g
F P
s
P
p
.002 w
.48906 .58063 m .48889 .583 L p
.49758 .58126 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .46787 .57688 L p
.47965 .57784 L 1 g
F P
s
P
p
.47961 .57783 m .4678 .57686 L .47965 .57784 L 1 g
F
P
p
.002 w
.46787 .57688 m .48889 .583 L .48904 .58096 L p
1 g
F P
s
P
p
.004 w
.48068 .45258 m
.5 .43051 L
s
P
p
.002 w
.65104 .41098 m .62014 .35463 L .63621 .33877 L p
1 g
F P
s
P
p
.002 w
.5866 .29198 m .63621 .33877 L .62014 .35463 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.62014 .35463 m .57246 .30969 L .5866 .29198 L p
1 g
F P
s
P
p
.002 w
.50151 .30576 m .44429 .29857 L .45223 .2744 L p
1 g
F P
s
P
p
.002 w
.45223 .2744 m .514 .28188 L .50151 .30576 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.39317 .36843 m .36032 .38941 L .35162 .36288 L p
1 g
F P
s
P
p
.002 w
.35162 .36288 m .3904 .33764 L .39317 .36843 L p
1 g
F P
s
P
p
.002 w
.37349 .41784 m .35582 .44186 L .33798 .42035 L p
1 g
F P
s
P
p
.002 w
.33798 .42035 m .36032 .38941 L .37349 .41784 L p
1 g
F P
s
P
p
.002 w
.43785 .32747 m .3904 .33764 L .39097 .3104 L p
1 g
F P
s
P
p
.002 w
.39097 .3104 m .44429 .29857 L .43785 .32747 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.3785 .46355 m .37288 .48358 L .3479 .47102 L p
1 g
F P
s
P
p
.002 w
.3479 .47102 m .35582 .44186 L .3785 .46355 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.40737 .51652 m .41475 .52574 L .39722 .54376 L p
1 g
F P
s
P
p
.002 w
.39722 .54376 m .38284 .52586 L .40737 .51652 L p
1 g
F P
s
P
p
.002 w
.41607 .55697 m .39722 .54376 L .41475 .52574 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.63878 .48153 m .62866 .42548 L .65104 .41098 L p
1 g
F P
s
P
p
.002 w
.62014 .35463 m .65104 .41098 L .62866 .42548 L p
1 g
F P
s
P
p
.002 w
.41475 .52574 m .42446 .53254 L .41607 .55697 L p
1 g
F P
s
P
p
.002 w
.43747 .56414 m .41607 .55697 L .42446 .53254 L p
1 g
F P
s
P
p
.002 w
.40308 .50584 m .40737 .51652 L .38284 .52586 L p
1 g
F P
s
P
p
.002 w
.38284 .52586 m .37441 .5051 L .40308 .50584 L p
1 g
F P
s
P
p
.002 w
.55356 .57068 m .57293 .53721 L .60321 .53754 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.55564 .33167 m .50151 .30576 L .514 .28188 L p
1 g
F P
s
P
p
.002 w
.514 .28188 m .57246 .30969 L .55564 .33167 L p
1 g
F P
s
P
p
.002 w
.611 .49026 m .60321 .53754 L .57293 .53721 L p
1 g
F P
s
P
p
.002 w
.60321 .53754 m .611 .49026 L .63878 .48153 L p
1 g
F P
s
P
p
.002 w
.52493 .55985 m .50169 .57856 L .47913 .55785 L p
1 g
F P
s
P
p
.002 w
.45925 .56448 m .47913 .55785 L .50169 .57856 L p
1 g
F P
s
P
p
.002 w
.62866 .42548 m .63878 .48153 L .611 .49026 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.40238 .49481 m .40308 .50584 L .37441 .5051 L p
1 g
F P
s
P
p
.002 w
.37441 .5051 m .37288 .48358 L .40238 .49481 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39928 .40174 m .37349 .41784 L .36032 .38941 L p
1 g
F P
s
P
p
.002 w
.36032 .38941 m .39317 .36843 L .39928 .40174 L p
1 g
F P
s
P
p
.002 w
.39081 .44719 m .3785 .46355 L .35582 .44186 L p
1 g
F P
s
P
p
.002 w
.35582 .44186 m .37349 .41784 L .39081 .44719 L p
1 g
F P
s
P
p
.002 w
.43318 .36019 m .39317 .36843 L .3904 .33764 L p
1 g
F P
s
P
p
.002 w
.3904 .33764 m .43785 .32747 L .43318 .36019 L p
1 g
F P
s
P
p
.002 w
.48864 .33413 m .43785 .32747 L .44429 .29857 L p
1 g
F P
s
P
p
.002 w
.44429 .29857 m .50151 .30576 L .48864 .33413 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.62866 .42548 m .59986 .37332 L .62014 .35463 L p
1 g
F P
s
P
p
.002 w
.57246 .30969 m .62014 .35463 L .59986 .37332 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59986 .37332 m .55564 .33167 L .57246 .30969 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.43548 .53618 m .44664 .53629 L .45925 .56448 L p
1 g
F P
s
P
p
.002 w
.47913 .55785 m .45925 .56448 L .44664 .53629 L p
1 g
F P
s
P
p
.002 w
.40534 .48462 m .40238 .49481 L .37288 .48358 L p
1 g
F P
s
P
p
.002 w
.37288 .48358 m .3785 .46355 L .40534 .48462 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.47913 .55785 m .49496 .54484 L .52493 .55985 L p
1 g
F P
s
P
p
.002 w
.53978 .53358 m .52493 .55985 L .49496 .54484 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.57293 .53721 m .57915 .49735 L .611 .49026 L p
1 g
F P
s
P
p
.002 w
.49496 .54484 m .47913 .55785 L .45676 .53281 L p
1 g
F P
s
P
p
.002 w
.44664 .53629 m .45676 .53281 L .47913 .55785 L p
1 g
F P
s
P
p
.002 w
.611 .49026 m .60171 .44052 L .62866 .42548 L p
1 g
F P
s
P
p
.002 w
.59986 .37332 m .62866 .42548 L .60171 .44052 L p
1 g
F P
s
P
p
.002 w
.41475 .52574 m .40737 .51652 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.4086 .43635 m .39081 .44719 L .37349 .41784 L p
1 g
F P
s
P
p
.002 w
.37349 .41784 m .39928 .40174 L .4086 .43635 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.40737 .51652 m .40308 .50584 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.60171 .44052 m .611 .49026 L .57915 .49735 L p
1 g
F P
s
P
p
.002 w
.41171 .47637 m .40534 .48462 L .3785 .46355 L p
1 g
F P
s
P
p
.002 w
.3785 .46355 m .39081 .44719 L .41171 .47637 L p
1 g
F P
s
P
p
.002 w
.53667 .35728 m .48864 .33413 L .50151 .30576 L p
1 g
F P
s
P
p
.002 w
.50151 .30576 m .55564 .33167 L .53667 .35728 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.43052 .3956 m .39928 .40174 L .39317 .36843 L p
1 g
F P
s
P
p
.002 w
.39317 .36843 m .43318 .36019 L .43052 .3956 L p
1 g
F P
s
P
p
.002 w
.40308 .50584 m .40238 .49481 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.47588 .36605 m .43318 .36019 L .43785 .32747 L p
1 g
F P
s
P
p
.002 w
.43785 .32747 m .48864 .33413 L .47588 .36605 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.40238 .49481 m .40534 .48462 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.60171 .44052 m .57597 .39427 L .59986 .37332 L p
1 g
F P
s
P
p
.002 w
.55564 .33167 m .59986 .37332 L .57597 .39427 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45676 .53281 m .46475 .52609 L .49496 .54484 L p
1 g
F P
s
P
p
.002 w
.50494 .52672 m .49496 .54484 L .46475 .52609 L p
1 g
F P
s
P
p
.002 w
.49496 .54484 m .50494 .52672 L .53978 .53358 L p
1 g
F P
s
P
p
.002 w
.57597 .39427 m .53667 .35728 L .55564 .33167 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.54434 .50247 m .53978 .53358 L .50494 .52672 L p
1 g
F P
s
P
p
.002 w
.4208 .47097 m .41171 .47637 L .39081 .44719 L p
1 g
F P
s
P
p
.002 w
.39081 .44719 m .4086 .43635 L .4208 .47097 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.40534 .48462 m .41171 .47637 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.43 .43236 m .4086 .43635 L .39928 .40174 L p
1 g
F P
s
P
p
.002 w
.39928 .40174 m .43052 .3956 L .43 .43236 L p
1 g
F P
s
P
p
.002 w
.57915 .49735 m .57106 .45554 L .60171 .44052 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57597 .39427 m .60171 .44052 L .57106 .45554 L p
1 g
F P
s
P
p
.002 w
.46475 .52609 m .46971 .51682 L .50494 .52672 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.41171 .47637 m .4208 .47097 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.43167 .46905 m .4431 .47085 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.4208 .47097 m .43167 .46905 L .43543 .50427 L closepath p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51621 .38564 m .47588 .36605 L .48864 .33413 L p
1 g
F P
s
P
p
.002 w
.48864 .33413 m .53667 .35728 L .51621 .38564 L p
1 g
F P
s
P
p
.002 w
.46372 .40037 m .43052 .3956 L .43318 .36019 L p
1 g
F P
s
P
p
.002 w
.43318 .36019 m .47588 .36605 L .46372 .40037 L p
1 g
F P
s
P
p
.002 w
.50784 .5054 m .50494 .52672 L .46971 .51682 L p
1 g
F P
s
P
p
.002 w
.50494 .52672 m .50784 .5054 L .54434 .50247 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43167 .46905 m .4208 .47097 L .4086 .43635 L p
1 g
F P
s
P
p
.002 w
.4086 .43635 m .43 .43236 L .43167 .46905 L p
1 g
F P
s
P
p
.002 w
.46971 .51682 m .47107 .506 L .50784 .5054 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.004 w
.43387 .50605 m
.43465 .50516 L
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57106 .45554 m .54927 .41673 L .57597 .39427 L p
1 g
F P
s
P
p
.002 w
.53667 .35728 m .57597 .39427 L .54927 .41673 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54927 .41673 m .51621 .38564 L .53667 .35728 L p
1 g
F P
s
P
p
.002 w
.47107 .506 m .46865 .49481 L .50322 .48323 L p
1 g
F P
s
P
p
.002 w
.50322 .48323 m .50784 .5054 L .47107 .506 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.4431 .47085 m .43167 .46905 L .43 .43236 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.45265 .43577 m .43 .43236 L .43052 .3956 L p
1 g
F P
s
P
p
.002 w
.43052 .3956 m .46372 .40037 L .45265 .43577 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.004 w
.43196 .50823 m
.43275 .50733 L
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54927 .41673 m .57106 .45554 L .53781 .46997 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.43 .43236 m .45265 .43577 L .4431 .47085 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.45385 .47619 m .4431 .47085 L .45265 .43577 L p
1 g
F P
s
P
p
.002 w
.49504 .4157 m .46372 .40037 L .47588 .36605 L p
1 g
F P
s
P
p
.002 w
.47588 .36605 m .51621 .38564 L .49504 .4157 L p
1 g
F P
s
P
p
.002 w
.45265 .43577 m .47397 .44628 L .45385 .47619 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.004 w
.43004 .51042 m
.43084 .50952 L
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.004 w
.42889 .51173 m
.42891 .51171 L
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53781 .46997 m .52074 .43985 L .54927 .41673 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51621 .38564 m .54927 .41673 L .52074 .43985 L p
1 g
F P
s
P
p
.002 w
.52074 .43985 m .49504 .4157 L .51621 .38564 L p
1 g
F P
s
P
p
.002 w
.47397 .44628 m .45265 .43577 L .46372 .40037 L p
1 g
F P
s
P
p
.002 w
.46372 .40037 m .49504 .4157 L .47397 .44628 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.004 w
.42811 .51262 m
.42889 .51173 L
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.4915 .46274 m .47397 .44628 L .49504 .4157 L p
1 g
F P
s
P
p
.002 w
.49504 .4157 m .52074 .43985 L .4915 .46274 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.004 w
.42617 .51485 m
.42697 .51393 L
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.004 w
.42421 .51709 m
.42502 .51616 L
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.004 w
.42223 .51934 m
.42305 .51841 L
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.004 w
.42025 .52161 m
.42107 .52067 L
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.004 w
.41824 .5239 m
.41907 .52295 L
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.004 w
.41623 .5262 m
.41706 .52525 L
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.3962 .54908 m
.41503 .52757 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .4873 .72827 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .3962 .54908 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.103101)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.103101)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45429 .42411 m .46793 .44753 L .48988 .42945 L p
1 g
F P
s
P
p
.002 w
.48988 .42945 m .48062 .4135 L .45429 .42411 L p
1 g
F P
s
P
p
.002 w
.50368 .44175 m .48988 .42945 L .46793 .44753 L p
1 g
F P
s
P
p
.002 w
.48062 .4135 m .48988 .42945 L .51203 .41143 L p
1 g
F P
s
P
p
.002 w
.48988 .42945 m .50368 .44175 L .51903 .41767 L p
1 g
F P
s
P
p
.002 w
.51903 .41767 m .51203 .41143 L .48988 .42945 L p
1 g
F P
s
P
p
.002 w
.46793 .44753 m .48821 .4656 L .50368 .44175 L p
1 g
F P
s
P
p
.002 w
.52058 .44911 m .50368 .44175 L .48821 .4656 L p
1 g
F P
s
P
p
.002 w
.50368 .44175 m .52058 .44911 L .52761 .42138 L p
1 g
F P
s
P
p
.002 w
.52761 .42138 m .51903 .41767 L .50368 .44175 L p
1 g
F P
s
P
p
.002 w
.51203 .41143 m .50735 .40333 L .48062 .4135 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .50735 .40333 L .51203 .41143 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .51203 .41143 L .51903 .41767 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .51903 .41767 L .52761 .42138 L closepath p
1 g
F P
s
P
p
.002 w
.44872 .39776 m .45429 .42411 L .48062 .4135 L p
1 g
F P
s
P
p
.002 w
.48062 .4135 m .47689 .39557 L .44872 .39776 L p
1 g
F P
s
P
p
.002 w
.47689 .39557 m .48062 .4135 L .50735 .40333 L p
1 g
F P
s
P
p
.002 w
.48821 .4656 m .51303 .47646 L .52058 .44911 L p
1 g
F P
s
P
p
.002 w
.5388 .45073 m .52058 .44911 L .51303 .47646 L p
1 g
F P
s
P
p
.002 w
.52058 .44911 m .5388 .45073 L .53685 .42217 L p
1 g
F P
s
P
p
.002 w
.53685 .42217 m .52761 .42138 L .52058 .44911 L p
1 g
F P
s
P
p
.002 w
.50735 .40333 m .50549 .39424 L .47689 .39557 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .50549 .39424 L .50735 .40333 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .52761 .42138 L .53685 .42217 L closepath p
1 g
F P
s
P
p
.002 w
.42883 .43497 m .4466 .46534 L .46793 .44753 L p
1 g
F P
s
P
p
.002 w
.46793 .44753 m .45429 .42411 L .42883 .43497 L p
1 g
F P
s
P
p
.002 w
.48821 .4656 m .46793 .44753 L .4466 .46534 L p
1 g
F P
s
P
p
.002 w
.47913 .37754 m .47689 .39557 L .50549 .39424 L p
1 g
F P
s
P
p
.002 w
.50549 .39424 m .50666 .38512 L .47913 .37754 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .50666 .38512 L .50549 .39424 L closepath p
1 g
F P
s
P
p
.002 w
.4466 .46534 m .47291 .48879 L .48821 .4656 L p
1 g
F P
s
P
p
.002 w
.51303 .47646 m .48821 .4656 L .47291 .48879 L p
1 g
F P
s
P
p
.002 w
.54576 .41994 m .53685 .42217 L .5388 .45073 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .53685 .42217 L .54576 .41994 L closepath p
1 g
F P
s
P
p
.002 w
.4519 .37121 m .44872 .39776 L .47689 .39557 L p
1 g
F P
s
P
p
.002 w
.47689 .39557 m .47913 .37754 L .4519 .37121 L p
1 g
F P
s
P
p
.002 w
.55643 .44641 m .5388 .45073 L .53982 .47894 L p
1 g
F P
s
P
p
.002 w
.51303 .47646 m .53982 .47894 L .5388 .45073 L p
1 g
F P
s
P
p
.002 w
.5388 .45073 m .55643 .44641 L .54576 .41994 L p
1 g
F P
s
P
p
.002 w
.48714 .36135 m .47913 .37754 L .50666 .38512 L p
1 g
F P
s
P
p
.002 w
.50666 .38512 m .51076 .37696 L .48714 .36135 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .51076 .37696 L .50666 .38512 L closepath p
1 g
F P
s
P
p
.002 w
.4215 .40077 m .42883 .43497 L .45429 .42411 L p
1 g
F P
s
P
p
.002 w
.45429 .42411 m .44872 .39776 L .4215 .40077 L p
1 g
F P
s
P
p
.002 w
.55338 .41492 m .54576 .41994 L .55643 .44641 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .54576 .41994 L .55338 .41492 L closepath p
1 g
F P
s
P
p
.002 w
.47291 .48879 m .50509 .50295 L .51303 .47646 L p
1 g
F P
s
P
p
.002 w
.53982 .47894 m .51303 .47646 L .50509 .50295 L p
1 g
F P
s
P
p
.002 w
.534 .39378 m .55338 .41492 L .55888 .40763 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .55888 .40763 L .56165 .39886 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .56165 .39886 L .56137 .38956 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .56137 .38956 L .55806 .38075 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .55806 .38075 L .55209 .37339 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .55209 .37339 L .5441 .36831 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .5441 .36831 L .53497 .36605 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .53497 .36605 L .52572 .36686 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .52572 .36686 L .51734 .37064 L closepath p
1 g
F P
s
P
p
.002 w
.534 .39378 m .51734 .37064 L .51076 .37696 L closepath p
1 g
F P
s
P
p
.002 w
.50012 .34876 m .48714 .36135 L .51076 .37696 L p
1 g
F P
s
P
p
.002 w
.51076 .37696 m .51734 .37064 L .50012 .34876 L p
1 g
F P
s
P
p
.002 w
.55643 .44641 m .57156 .43655 L .55338 .41492 L p
1 g
F P
s
P
p
.002 w
.55888 .40763 m .55338 .41492 L .57156 .43655 L p
1 g
F P
s
P
p
.002 w
.46358 .34727 m .4519 .37121 L .47913 .37754 L p
1 g
F P
s
P
p
.002 w
.47913 .37754 m .48714 .36135 L .46358 .34727 L p
1 g
F P
s
P
p
.002 w
.53982 .47894 m .56581 .4727 L .55643 .44641 L p
1 g
F P
s
P
p
.002 w
.57156 .43655 m .55643 .44641 L .56581 .4727 L p
1 g
F P
s
P
p
.002 w
.42547 .36624 m .4215 .40077 L .44872 .39776 L p
1 g
F P
s
P
p
.002 w
.44872 .39776 m .4519 .37121 L .42547 .36624 L p
1 g
F P
s
P
p
.002 w
.51671 .34118 m .50012 .34876 L .51734 .37064 L p
1 g
F P
s
P
p
.002 w
.51734 .37064 m .52572 .36686 L .51671 .34118 L p
1 g
F P
s
P
p
.002 w
.50509 .50295 m .53988 .50628 L .53982 .47894 L p
1 g
F P
s
P
p
.002 w
.56581 .4727 m .53982 .47894 L .53988 .50628 L p
1 g
F P
s
P
p
.002 w
.57156 .43655 m .58254 .42217 L .55888 .40763 L p
1 g
F P
s
P
p
.002 w
.56165 .39886 m .55888 .40763 L .58254 .42217 L p
1 g
F P
s
P
p
.002 w
.40475 .44589 m .42627 .48254 L .4466 .46534 L p
1 g
F P
s
P
p
.002 w
.4466 .46534 m .42883 .43497 L .40475 .44589 L p
1 g
F P
s
P
p
.002 w
.47291 .48879 m .4466 .46534 L .42627 .48254 L p
1 g
F P
s
P
p
.002 w
.42627 .48254 m .45805 .51088 L .47291 .48879 L p
1 g
F P
s
P
p
.002 w
.50509 .50295 m .47291 .48879 L .45805 .51088 L p
1 g
F P
s
P
p
.002 w
.5351 .3395 m .51671 .34118 L .52572 .36686 L p
1 g
F P
s
P
p
.002 w
.52572 .36686 m .53497 .36605 L .5351 .3395 L p
1 g
F P
s
P
p
.002 w
.58254 .42217 m .58812 .40478 L .56165 .39886 L p
1 g
F P
s
P
p
.002 w
.56137 .38956 m .56165 .39886 L .58812 .40478 L p
1 g
F P
s
P
p
.002 w
.48265 .32858 m .46358 .34727 L .48714 .36135 L p
1 g
F P
s
P
p
.002 w
.48714 .36135 m .50012 .34876 L .48265 .32858 L p
1 g
F P
s
P
p
.002 w
.39575 .40457 m .40475 .44589 L .42883 .43497 L p
1 g
F P
s
P
p
.002 w
.42883 .43497 m .4215 .40077 L .39575 .40457 L p
1 g
F P
s
P
p
.002 w
.56581 .4727 m .5882 .45828 L .57156 .43655 L p
1 g
F P
s
P
p
.002 w
.58254 .42217 m .57156 .43655 L .5882 .45828 L p
1 g
F P
s
P
p
.002 w
.45805 .51088 m .49691 .52806 L .50509 .50295 L p
1 g
F P
s
P
p
.002 w
.53988 .50628 m .50509 .50295 L .49691 .52806 L p
1 g
F P
s
P
p
.002 w
.55328 .34395 m .5351 .3395 L .53497 .36605 L p
1 g
F P
s
P
p
.002 w
.53497 .36605 m .5441 .36831 L .55328 .34395 L p
1 g
F P
s
P
p
.002 w
.58812 .40478 m .58764 .38629 L .56137 .38956 L p
1 g
F P
s
P
p
.002 w
.55806 .38075 m .56137 .38956 L .58764 .38629 L p
1 g
F P
s
P
p
.002 w
.56921 .35407 m .55328 .34395 L .5441 .36831 L p
1 g
F P
s
P
p
.002 w
.5441 .36831 m .55209 .37339 L .56921 .35407 L p
1 g
F P
s
P
p
.002 w
.44053 .33502 m .42547 .36624 L .4519 .37121 L p
1 g
F P
s
P
p
.002 w
.4519 .37121 m .46358 .34727 L .44053 .33502 L p
1 g
F P
s
P
p
.002 w
.58764 .38629 m .58111 .36872 L .55806 .38075 L p
1 g
F P
s
P
p
.002 w
.55209 .37339 m .55806 .38075 L .58111 .36872 L p
1 g
F P
s
P
p
.002 w
.58111 .36872 m .56921 .35407 L .55209 .37339 L p
1 g
F P
s
P
p
.002 w
.53988 .50628 m .5737 .49832 L .56581 .4727 L p
1 g
F P
s
P
p
.002 w
.5882 .45828 m .56581 .4727 L .5737 .49832 L p
1 g
F P
s
P
p
.002 w
.50713 .31726 m .48265 .32858 L .50012 .34876 L p
1 g
F P
s
P
p
.002 w
.50012 .34876 m .51671 .34118 L .50713 .31726 L p
1 g
F P
s
P
p
.002 w
.5882 .45828 m .60452 .43713 L .58254 .42217 L p
1 g
F P
s
P
p
.002 w
.58812 .40478 m .58254 .42217 L .60452 .43713 L p
1 g
F P
s
P
p
.002 w
.40039 .36277 m .39575 .40457 L .4215 .40077 L p
1 g
F P
s
P
p
.002 w
.4215 .40077 m .42547 .36624 L .40039 .36277 L p
1 g
F P
s
P
p
.002 w
.5737 .49832 m .53988 .50628 L .53896 .53222 L p
1 g
F P
s
P
p
.002 w
.49691 .52806 m .53896 .53222 L .53988 .50628 L p
1 g
F P
s
P
p
.002 w
.38252 .45665 m .40735 .4988 L .42627 .48254 L p
1 g
F P
s
P
p
.002 w
.42627 .48254 m .40475 .44589 L .38252 .45665 L p
1 g
F P
s
P
p
.002 w
.45805 .51088 m .42627 .48254 L .40735 .4988 L p
1 g
F P
s
P
p
.002 w
.40735 .4988 m .44393 .53143 L .45805 .51088 L p
1 g
F P
s
P
p
.002 w
.49691 .52806 m .45805 .51088 L .44393 .53143 L p
1 g
F P
s
P
p
.002 w
.46526 .31053 m .44053 .33502 L .46358 .34727 L p
1 g
F P
s
P
p
.002 w
.46358 .34727 m .48265 .32858 L .46526 .31053 L p
1 g
F P
s
P
p
.002 w
.53437 .31467 m .50713 .31726 L .51671 .34118 L p
1 g
F P
s
P
p
.002 w
.51671 .34118 m .5351 .3395 L .53437 .31467 L p
1 g
F P
s
P
p
.002 w
.60452 .43713 m .6129 .41145 L .58812 .40478 L p
1 g
F P
s
P
p
.002 w
.58764 .38629 m .58812 .40478 L .6129 .41145 L p
1 g
F P
s
P
p
.002 w
.5737 .49832 m .60294 .4797 L .5882 .45828 L p
1 g
F P
s
P
p
.002 w
.60452 .43713 m .5882 .45828 L .60294 .4797 L p
1 g
F P
s
P
p
.002 w
.37203 .4091 m .38252 .45665 L .40475 .44589 L p
1 g
F P
s
P
p
.002 w
.40475 .44589 m .39575 .40457 L .37203 .4091 L p
1 g
F P
s
P
p
.002 w
.56134 .3212 m .53437 .31467 L .5351 .3395 L p
1 g
F P
s
P
p
.002 w
.5351 .3395 m .55328 .34395 L .56134 .3212 L p
1 g
F P
s
P
p
.002 w
.44393 .53143 m .48863 .55127 L .49691 .52806 L p
1 g
F P
s
P
p
.002 w
.53896 .53222 m .49691 .52806 L .48863 .55127 L p
1 g
F P
s
P
p
.002 w
.6129 .41145 m .61229 .38404 L .58764 .38629 L p
1 g
F P
s
P
p
.002 w
.58111 .36872 m .58764 .38629 L .61229 .38404 L p
1 g
F P
s
P
p
.002 w
.41844 .32488 m .40039 .36277 L .42547 .36624 L p
1 g
F P
s
P
p
.002 w
.42547 .36624 m .44053 .33502 L .41844 .32488 L p
1 g
F P
s
P
p
.002 w
.53896 .53222 m .57991 .52276 L .5737 .49832 L p
1 g
F P
s
P
p
.002 w
.60294 .4797 m .5737 .49832 L .57991 .52276 L p
1 g
F P
s
P
p
.002 w
.585 .3362 m .56134 .3212 L .55328 .34395 L p
1 g
F P
s
P
p
.002 w
.55328 .34395 m .56921 .35407 L .585 .3362 L p
1 g
F P
s
P
p
.002 w
.61229 .38404 m .60264 .35797 L .58111 .36872 L p
1 g
F P
s
P
p
.002 w
.56921 .35407 m .58111 .36872 L .60264 .35797 L p
1 g
F P
s
P
p
.002 w
.60264 .35797 m .585 .3362 L .56921 .35407 L p
1 g
F P
s
P
p
.002 w
.49714 .29561 m .46526 .31053 L .48265 .32858 L p
1 g
F P
s
P
p
.002 w
.48265 .32858 m .50713 .31726 L .49714 .29561 L p
1 g
F P
s
P
p
.002 w
.60294 .4797 m .62436 .45223 L .60452 .43713 L p
1 g
F P
s
P
p
.002 w
.6129 .41145 m .60452 .43713 L .62436 .45223 L p
1 g
F P
s
P
p
.002 w
.37719 .36093 m .37203 .4091 L .39575 .40457 L p
1 g
F P
s
P
p
.002 w
.39575 .40457 m .40039 .36277 L .37719 .36093 L p
1 g
F P
s
P
p
.002 w
.57991 .52276 m .53896 .53222 L .53704 .55621 L p
1 g
F P
s
P
p
.002 w
.48863 .55127 m .53704 .55621 L .53896 .53222 L p
1 g
F P
s
P
p
.002 w
.44829 .29505 m .41844 .32488 L .44053 .33502 L p
1 g
F P
s
P
p
.002 w
.44053 .33502 m .46526 .31053 L .44829 .29505 L p
1 g
F P
s
P
p
.002 w
.53274 .29211 m .49714 .29561 L .50713 .31726 L p
1 g
F P
s
P
p
.002 w
.50713 .31726 m .53437 .31467 L .53274 .29211 L p
1 g
F P
s
P
p
.002 w
.57991 .52276 m .61543 .50037 L .60294 .4797 L p
1 g
F P
s
P
p
.002 w
.62436 .45223 m .60294 .4797 L .61543 .50037 L p
1 g
F P
s
P
p
.002 w
.62436 .45223 m .63544 .41875 L .6129 .41145 L p
1 g
F P
s
P
p
.002 w
.61229 .38404 m .6129 .41145 L .63544 .41875 L p
1 g
F P
s
P
p
.002 w
.36267 .46703 m .39028 .51377 L .40735 .4988 L p
1 g
F P
s
P
p
.002 w
.40735 .4988 m .38252 .45665 L .36267 .46703 L p
1 g
F P
s
P
p
.002 w
.44393 .53143 m .40735 .4988 L .39028 .51377 L p
1 g
F P
s
P
p
.002 w
.39028 .51377 m .43086 .54996 L .44393 .53143 L p
1 g
F P
s
P
p
.002 w
.48863 .55127 m .44393 .53143 L .43086 .54996 L p
1 g
F P
s
P
p
.002 w
.3509 .4143 m .36267 .46703 L .38252 .45665 L p
1 g
F P
s
P
p
.002 w
.38252 .45665 m .37203 .4091 L .3509 .4143 L p
1 g
F P
s
P
p
.002 w
.39782 .31715 m .37719 .36093 L .40039 .36277 L p
1 g
F P
s
P
p
.002 w
.40039 .36277 m .41844 .32488 L .39782 .31715 L p
1 g
F P
s
P
p
.002 w
.56808 .30059 m .53274 .29211 L .53437 .31467 L p
1 g
F P
s
P
p
.002 w
.53437 .31467 m .56134 .3212 L .56808 .30059 L p
1 g
F P
s
P
p
.002 w
.43086 .54996 m .48042 .57205 L .48863 .55127 L p
1 g
F P
s
P
p
.002 w
.53704 .55621 m .48863 .55127 L .48042 .57205 L p
1 g
F P
s
P
p
.002 w
.63544 .41875 m .63475 .38291 L .61229 .38404 L p
1 g
F P
s
P
p
.002 w
.60264 .35797 m .61229 .38404 L .63475 .38291 L p
1 g
F P
s
P
p
.002 w
.53704 .55621 m .58426 .54549 L .57991 .52276 L p
1 g
F P
s
P
p
.002 w
.61543 .50037 m .57991 .52276 L .58426 .54549 L p
1 g
F P
s
P
p
.002 w
.48694 .27678 m .44829 .29505 L .46526 .31053 L p
1 g
F P
s
P
p
.002 w
.46526 .31053 m .49714 .29561 L .48694 .27678 L p
1 g
F P
s
P
p
.002 w
.59909 .32021 m .56808 .30059 L .56134 .3212 L p
1 g
F P
s
P
p
.002 w
.56134 .3212 m .585 .3362 L .59909 .32021 L p
1 g
F P
s
P
p
.002 w
.63475 .38291 m .62219 .34875 L .60264 .35797 L p
1 g
F P
s
P
p
.002 w
.585 .3362 m .60264 .35797 L .62219 .34875 L p
1 g
F P
s
P
p
.002 w
.61543 .50037 m .64156 .46718 L .62436 .45223 L p
1 g
F P
s
P
p
.002 w
.63544 .41875 m .62436 .45223 L .64156 .46718 L p
1 g
F P
s
P
p
.002 w
.62219 .34875 m .59909 .32021 L .585 .3362 L p
1 g
F P
s
P
p
.002 w
.35644 .36081 m .3509 .4143 L .37203 .4091 L p
1 g
F P
s
P
p
.002 w
.37203 .4091 m .37719 .36093 L .35644 .36081 L p
1 g
F P
s
P
p
.002 w
.48042 .57205 m .53412 .57768 L .53704 .55621 L p
1 g
F P
s
P
p
.002 w
.58426 .54549 m .53704 .55621 L .53412 .57768 L p
1 g
F P
s
P
p
.002 w
.43214 .28258 m .39782 .31715 L .41844 .32488 L p
1 g
F P
s
P
p
.002 w
.41844 .32488 m .44829 .29505 L .43214 .28258 L p
1 g
F P
s
P
p
.002 w
.58426 .54549 m .62533 .51985 L .61543 .50037 L p
1 g
F P
s
P
p
.002 w
.64156 .46718 m .61543 .50037 L .62533 .51985 L p
1 g
F P
s
P
p
.002 w
.53023 .27239 m .48694 .27678 L .49714 .29561 L p
1 g
F P
s
P
p
.002 w
.49714 .29561 m .53274 .29211 L .53023 .27239 L p
1 g
F P
s
P
p
.002 w
.64156 .46718 m .65517 .42657 L .63544 .41875 L p
1 g
F P
s
P
p
.002 w
.63475 .38291 m .63544 .41875 L .65517 .42657 L p
1 g
F P
s
P
p
.002 w
.34572 .47681 m .37549 .52707 L .39028 .51377 L p
1 g
F P
s
P
p
.002 w
.39028 .51377 m .36267 .46703 L .34572 .47681 L p
1 g
F P
s
P
p
.002 w
.43086 .54996 m .39028 .51377 L .37549 .52707 L p
1 g
F P
s
P
p
.002 w
.37549 .52707 m .41915 .56602 L .43086 .54996 L p
1 g
F P
s
P
p
.002 w
.48042 .57205 m .43086 .54996 L .41915 .56602 L p
1 g
F P
s
P
p
.002 w
.37918 .3121 m .35644 .36081 L .37719 .36093 L p
1 g
F P
s
P
p
.002 w
.37719 .36093 m .39782 .31715 L .37918 .3121 L p
1 g
F P
s
P
p
.002 w
.33292 .4201 m .34572 .47681 L .36267 .46703 L p
1 g
F P
s
P
p
.002 w
.36267 .46703 m .3509 .4143 L .33292 .4201 L p
1 g
F P
s
P
p
.002 w
.57328 .28265 m .53023 .27239 L .53274 .29211 L p
1 g
F P
s
P
p
.002 w
.53274 .29211 m .56808 .30059 L .57328 .28265 L p
1 g
F P
s
P
p
.002 w
.53412 .57768 m .58659 .56595 L .58426 .54549 L p
1 g
F P
s
P
p
.002 w
.62533 .51985 m .58426 .54549 L .58659 .56595 L p
1 g
F P
s
P
p
.002 w
.41915 .56602 m .47245 .58986 L .48042 .57205 L p
1 g
F P
s
P
p
.002 w
.53412 .57768 m .48042 .57205 L .47245 .58986 L p
1 g
F P
s
P
p
.002 w
.65517 .42657 m .65445 .38297 L .63475 .38291 L p
1 g
F P
s
P
p
.002 w
.62219 .34875 m .63475 .38291 L .65445 .38297 L p
1 g
F P
s
P
p
.002 w
.47674 .26131 m .43214 .28258 L .44829 .29505 L p
1 g
F P
s
P
p
.002 w
.44829 .29505 m .48694 .27678 L .47674 .26131 L p
1 g
F P
s
P
p
.002 w
.62533 .51985 m .65565 .48164 L .64156 .46718 L p
1 g
F P
s
P
p
.002 w
.65517 .42657 m .64156 .46718 L .65565 .48164 L p
1 g
F P
s
P
p
.002 w
.61109 .30654 m .57328 .28265 L .56808 .30059 L p
1 g
F P
s
P
p
.002 w
.56808 .30059 m .59909 .32021 L .61109 .30654 L p
1 g
F P
s
P
p
.002 w
.65445 .38297 m .63922 .34134 L .62219 .34875 L p
1 g
F P
s
P
p
.002 w
.59909 .32021 m .62219 .34875 L .63922 .34134 L p
1 g
F P
s
P
p
.002 w
.63922 .34134 m .61109 .30654 L .59909 .32021 L p
1 g
F P
s
P
p
.002 w
.33873 .36251 m .33292 .4201 L .3509 .4143 L p
1 g
F P
s
P
p
.002 w
.3509 .4143 m .35644 .36081 L .33873 .36251 L p
1 g
F P
s
P
p
.002 w
.58659 .56595 m .53412 .57768 L .53023 .59605 L p
1 g
F P
s
P
p
.002 w
.47245 .58986 m .53023 .59605 L .53412 .57768 L p
1 g
F P
s
P
p
.002 w
.4172 .27355 m .37918 .3121 L .39782 .31715 L p
1 g
F P
s
P
p
.002 w
.39782 .31715 m .43214 .28258 L .4172 .27355 L p
1 g
F P
s
P
p
.002 w
.58659 .56595 m .63231 .53764 L .62533 .51985 L p
1 g
F P
s
P
p
.002 w
.65565 .48164 m .62533 .51985 L .63231 .53764 L p
1 g
F P
s
P
p
.002 w
.52683 .25611 m .47674 .26131 L .48694 .27678 L p
1 g
F P
s
P
p
.002 w
.48694 .27678 m .53023 .27239 L .52683 .25611 L p
1 g
F P
s
P
p
.002 w
.65565 .48164 m .67154 .43475 L .65517 .42657 L p
1 g
F P
s
P
p
.002 w
.65445 .38297 m .65517 .42657 L .67154 .43475 L p
1 g
F P
s
P
p
.002 w
.33219 .48573 m .36341 .53833 L .37549 .52707 L p
1 g
F P
s
P
p
.002 w
.37549 .52707 m .34572 .47681 L .33219 .48573 L p
1 g
F P
s
P
p
.002 w
.41915 .56602 m .37549 .52707 L .36341 .53833 L p
1 g
F P
s
P
p
.002 w
.36341 .53833 m .40913 .57912 L .41915 .56602 L p
1 g
F P
s
P
p
.002 w
.47245 .58986 m .41915 .56602 L .40913 .57912 L p
1 g
F P
s
P
p
.002 w
.36305 .30999 m .33873 .36251 L .35644 .36081 L p
1 g
F P
s
P
p
.002 w
.35644 .36081 m .37918 .3121 L .36305 .30999 L p
1 g
F P
s
P
p
.002 w
.53023 .59605 m .58673 .58359 L .58659 .56595 L p
1 g
F P
s
P
p
.002 w
.63231 .53764 m .58659 .56595 L .58673 .58359 L p
1 g
F P
s
P
p
.002 w
.57674 .26792 m .52683 .25611 L .53023 .27239 L p
1 g
F P
s
P
p
.002 w
.53023 .27239 m .57328 .28265 L .57674 .26792 L p
1 g
F P
s
P
p
.002 w
.31869 .42637 m .33219 .48573 L .34572 .47681 L p
1 g
F P
s
P
p
.002 w
.34572 .47681 m .33292 .4201 L .31869 .42637 L p
1 g
F P
s
P
p
.002 w
.67154 .43475 m .67082 .38427 L .65445 .38297 L p
1 g
F P
s
P
p
.002 w
.63922 .34134 m .65445 .38297 L .67082 .38427 L p
1 g
F P
s
P
p
.002 w
.40913 .57912 m .46492 .60414 L .47245 .58986 L p
1 g
F P
s
P
p
.002 w
.53023 .59605 m .47245 .58986 L .46492 .60414 L p
1 g
F P
s
P
p
.002 w
.46677 .24974 m .4172 .27355 L .43214 .28258 L p
1 g
F P
s
P
p
.002 w
.43214 .28258 m .47674 .26131 L .46677 .24974 L p
1 g
F P
s
P
p
.002 w
.63231 .53764 m .66615 .49528 L .65565 .48164 L p
1 g
F P
s
P
p
.002 w
.67154 .43475 m .65565 .48164 L .66615 .49528 L p
1 g
F P
s
P
p
.002 w
.62061 .29561 m .57674 .26792 L .57328 .28265 L p
1 g
F P
s
P
p
.002 w
.57328 .28265 m .61109 .30654 L .62061 .29561 L p
1 g
F P
s
P
p
.002 w
.67082 .38427 m .65324 .33599 L .63922 .34134 L p
1 g
F P
s
P
p
.002 w
.61109 .30654 m .63922 .34134 L .65324 .33599 L p
1 g
F P
s
P
p
.002 w
.65324 .33599 m .62061 .29561 L .61109 .30654 L p
1 g
F P
s
P
p
.002 w
.32463 .36608 m .31869 .42637 L .33292 .4201 L p
1 g
F P
s
P
p
.002 w
.33292 .4201 m .33873 .36251 L .32463 .36608 L p
1 g
F P
s
P
p
.002 w
.58673 .58359 m .53023 .59605 L .52539 .61073 L p
1 g
F P
s
P
p
.002 w
.46492 .60414 m .52539 .61073 L .53023 .59605 L p
1 g
F P
s
P
p
.002 w
.4039 .26835 m .36305 .30999 L .37918 .3121 L p
1 g
F P
s
P
p
.002 w
.37918 .3121 m .4172 .27355 L .4039 .26835 L p
1 g
F P
s
P
p
.002 w
.58673 .58359 m .63605 .55326 L .63231 .53764 L p
1 g
F P
s
P
p
.002 w
.66615 .49528 m .63231 .53764 L .63605 .55326 L p
1 g
F P
s
P
p
.002 w
.52259 .24383 m .46677 .24974 L .47674 .26131 L p
1 g
F P
s
P
p
.002 w
.47674 .26131 m .52683 .25611 L .52259 .24383 L p
1 g
F P
s
P
p
.002 w
.66615 .49528 m .68398 .44312 L .67154 .43475 L p
1 g
F P
s
P
p
.002 w
.67082 .38427 m .67154 .43475 L .68398 .44312 L p
1 g
F P
s
P
p
.002 w
.3226 .49353 m .35449 .54716 L .36341 .53833 L p
1 g
F P
s
P
p
.002 w
.36341 .53833 m .33219 .48573 L .3226 .49353 L p
1 g
F P
s
P
p
.002 w
.40913 .57912 m .36341 .53833 L .35449 .54716 L p
1 g
F P
s
P
p
.002 w
.35449 .54716 m .40113 .58878 L .40913 .57912 L p
1 g
F P
s
P
p
.002 w
.46492 .60414 m .40913 .57912 L .40113 .58878 L p
1 g
F P
s
P
p
.002 w
.34997 .31104 m .32463 .36608 L .33873 .36251 L p
1 g
F P
s
P
p
.002 w
.33873 .36251 m .36305 .30999 L .34997 .31104 L p
1 g
F P
s
P
p
.002 w
.52539 .61073 m .58457 .59783 L .58673 .58359 L p
1 g
F P
s
P
p
.002 w
.63605 .55326 m .58673 .58359 L .58457 .59783 L p
1 g
F P
s
P
p
.002 w
.5783 .25696 m .52259 .24383 L .52683 .25611 L p
1 g
F P
s
P
p
.002 w
.52683 .25611 m .57674 .26792 L .5783 .25696 L p
1 g
F P
s
P
p
.002 w
.30875 .43301 m .3226 .49353 L .33219 .48573 L p
1 g
F P
s
P
p
.002 w
.33219 .48573 m .31869 .42637 L .30875 .43301 L p
1 g
F P
s
P
p
.002 w
.68398 .44312 m .68329 .38686 L .67082 .38427 L p
1 g
F P
s
P
p
.002 w
.65324 .33599 m .67082 .38427 L .68329 .38686 L p
1 g
F P
s
P
p
.002 w
.40113 .58878 m .45802 .61435 L .46492 .60414 L p
1 g
F P
s
P
p
.002 w
.52539 .61073 m .46492 .60414 L .45802 .61435 L p
1 g
F P
s
P
p
.002 w
.4573 .24258 m .4039 .26835 L .4172 .27355 L p
1 g
F P
s
P
p
.002 w
.4172 .27355 m .46677 .24974 L .4573 .24258 L p
1 g
F P
s
P
p
.002 w
.63605 .55326 m .67263 .50771 L .66615 .49528 L p
1 g
F P
s
P
p
.002 w
.68398 .44312 m .66615 .49528 L .67263 .50771 L p
1 g
F P
s
P
p
.002 w
.62729 .28785 m .5783 .25696 L .57674 .26792 L p
1 g
F P
s
P
p
.002 w
.57674 .26792 m .62061 .29561 L .62729 .28785 L p
1 g
F P
s
P
p
.002 w
.68329 .38686 m .66371 .33296 L .65324 .33599 L p
1 g
F P
s
P
p
.002 w
.62061 .29561 m .65324 .33599 L .66371 .33296 L p
1 g
F P
s
P
p
.002 w
.66371 .33296 m .62729 .28785 L .62061 .29561 L p
1 g
F P
s
P
p
.002 w
.31471 .37154 m .30875 .43301 L .31869 .42637 L p
1 g
F P
s
P
p
.002 w
.31869 .42637 m .32463 .36608 L .31471 .37154 L p
1 g
F P
s
P
p
.002 w
.58457 .59783 m .52539 .61073 L .51968 .62116 L p
1 g
F P
s
P
p
.002 w
.45802 .61435 m .51968 .62116 L .52539 .61073 L p
1 g
F P
s
P
p
.002 w
.39267 .26736 m .34997 .31104 L .36305 .30999 L p
1 g
F P
s
P
p
.002 w
.36305 .30999 m .4039 .26835 L .39267 .26736 L p
1 g
F P
s
P
p
.002 w
.58457 .59783 m .63627 .56618 L .63605 .55326 L p
1 g
F P
s
P
p
.002 w
.67263 .50771 m .63605 .55326 L .63627 .56618 L p
1 g
F P
s
P
p
.002 w
.51756 .23613 m .4573 .24258 L .46677 .24974 L p
1 g
F P
s
P
p
.002 w
.46677 .24974 m .52259 .24383 L .51756 .23613 L p
1 g
F P
s
P
p
.002 w
.67263 .50771 m .69196 .4515 L .68398 .44312 L p
1 g
F P
s
P
p
.002 w
.68329 .38686 m .68398 .44312 L .69196 .4515 L p
1 g
F P
s
P
p
.002 w
.31743 .49994 m .34914 .5532 L .35449 .54716 L p
1 g
F P
s
P
p
.002 w
.35449 .54716 m .3226 .49353 L .31743 .49994 L p
1 g
F P
s
P
p
.002 w
.40113 .58878 m .35449 .54716 L .34914 .5532 L p
1 g
F P
s
P
p
.002 w
.34914 .5532 m .39548 .59456 L .40113 .58878 L p
1 g
F P
s
P
p
.002 w
.45802 .61435 m .40113 .58878 L .39548 .59456 L p
1 g
F P
s
P
p
.002 w
.34046 .31542 m .31471 .37154 L .32463 .36608 L p
1 g
F P
s
P
p
.002 w
.32463 .36608 m .34997 .31104 L .34046 .31542 L p
1 g
F P
s
P
p
.002 w
.51968 .62116 m .58003 .6081 L .58457 .59783 L p
1 g
F P
s
P
p
.002 w
.63627 .56618 m .58457 .59783 L .58003 .6081 L p
1 g
F P
s
P
p
.002 w
.57777 .25027 m .51756 .23613 L .52259 .24383 L p
1 g
F P
s
P
p
.002 w
.52259 .24383 m .5783 .25696 L .57777 .25027 L p
1 g
F P
s
P
p
.002 w
.30364 .43987 m .31743 .49994 L .3226 .49353 L p
1 g
F P
s
P
p
.002 w
.3226 .49353 m .30875 .43301 L .30364 .43987 L p
1 g
F P
s
P
p
.002 w
.69196 .4515 m .69128 .39074 L .68329 .38686 L p
1 g
F P
s
P
p
.002 w
.66371 .33296 m .68329 .38686 L .69128 .39074 L p
1 g
F P
s
P
p
.002 w
.44861 .24029 m .39267 .26736 L .4039 .26835 L p
1 g
F P
s
P
p
.002 w
.4039 .26835 m .4573 .24258 L .44861 .24029 L p
1 g
F P
s
P
p
.002 w
.39548 .59456 m .45198 .61999 L .45802 .61435 L p
1 g
F P
s
P
p
.002 w
.51968 .62116 m .45802 .61435 L .45198 .61999 L p
1 g
F P
s
P
p
.002 w
.63627 .56618 m .67466 .51854 L .67263 .50771 L p
1 g
F P
s
P
p
.002 w
.69196 .4515 m .67263 .50771 L .67466 .51854 L p
1 g
F P
s
P
p
.002 w
.63077 .28368 m .57777 .25027 L .5783 .25696 L p
1 g
F P
s
P
p
.002 w
.5783 .25696 m .62729 .28785 L .63077 .28368 L p
1 g
F P
s
P
p
.002 w
.69128 .39074 m .67015 .33247 L .66371 .33296 L p
1 g
F P
s
P
p
.002 w
.62729 .28785 m .66371 .33296 L .67015 .33247 L p
1 g
F P
s
P
p
.002 w
.67015 .33247 m .63077 .28368 L .62729 .28785 L p
1 g
F P
s
P
p
.002 w
.30951 .37886 m .30364 .43987 L .30875 .43301 L p
1 g
F P
s
P
p
.002 w
.30875 .43301 m .31471 .37154 L .30951 .37886 L p
1 g
F P
s
P
p
.002 w
.58003 .6081 m .51968 .62116 L .51319 .62679 L p
1 g
F P
s
P
p
.002 w
.45198 .61999 m .51319 .62679 L .51968 .62116 L p
1 g
F P
s
P
p
.002 w
.38395 .27086 m .34046 .31542 L .34997 .31104 L p
1 g
F P
s
P
p
.002 w
.34997 .31104 m .39267 .26736 L .38395 .27086 L p
1 g
F P
s
P
p
.002 w
.58003 .6081 m .63276 .57591 L .63627 .56618 L p
1 g
F P
s
P
p
.002 w
.67466 .51854 m .63627 .56618 L .63276 .57591 L p
1 g
F P
s
P
p
.002 w
.51182 .23349 m .44861 .24029 L .4573 .24258 L p
1 g
F P
s
P
p
.002 w
.4573 .24258 m .51756 .23613 L .51182 .23349 L p
1 g
F P
s
P
p
.002 w
.67466 .51854 m .69498 .45964 L .69196 .4515 L p
1 g
F P
s
P
p
.002 w
.69128 .39074 m .69196 .4515 L .69498 .45964 L p
1 g
F P
s
P
p
.002 w
.33503 .32321 m .30951 .37886 L .31471 .37154 L p
1 g
F P
s
P
p
.002 w
.31471 .37154 m .34046 .31542 L .33503 .32321 L p
1 g
F P
s
P
p
.002 w
.31712 .5047 m .34774 .55611 L .34914 .5532 L p
1 g
F P
s
P
p
.002 w
.34914 .5532 m .31743 .49994 L .31712 .5047 L p
1 g
F P
s
P
p
.002 w
.39548 .59456 m .34914 .5532 L .34774 .55611 L p
1 g
F P
s
P
p
.002 w
.34774 .55611 m .39248 .59604 L .39548 .59456 L p
1 g
F P
s
P
p
.002 w
.45198 .61999 m .39548 .59456 L .39248 .59604 L p
1 g
F P
s
P
p
.002 w
.51319 .62679 m .57307 .61387 L .58003 .6081 L p
1 g
F P
s
P
p
.002 w
.63276 .57591 m .58003 .6081 L .57307 .61387 L p
1 g
F P
s
P
p
.002 w
.57505 .24834 m .51182 .23349 L .51756 .23613 L p
1 g
F P
s
P
p
.002 w
.51756 .23613 m .57777 .25027 L .57505 .24834 L p
1 g
F P
s
P
p
.002 w
.44098 .24325 m .38395 .27086 L .39267 .26736 L p
1 g
F P
s
P
p
.002 w
.39267 .26736 m .44861 .24029 L .44098 .24325 L p
1 g
F P
s
P
p
.002 w
.3038 .44676 m .31712 .5047 L .31743 .49994 L p
1 g
F P
s
P
p
.002 w
.31743 .49994 m .30364 .43987 L .3038 .44676 L p
1 g
F P
s
P
p
.002 w
.69498 .45964 m .69429 .3959 L .69128 .39074 L p
1 g
F P
s
P
p
.002 w
.67015 .33247 m .69128 .39074 L .69429 .3959 L p
1 g
F P
s
P
p
.002 w
.39248 .59604 m .447 .62059 L .45198 .61999 L p
1 g
F P
s
P
p
.002 w
.51319 .62679 m .45198 .61999 L .447 .62059 L p
1 g
F P
s
P
p
.002 w
.63276 .57591 m .67192 .52738 L .67466 .51854 L p
1 g
F P
s
P
p
.002 w
.69498 .45964 m .67466 .51854 L .67192 .52738 L p
1 g
F P
s
P
p
.004 w
.38332 .70194 m
.41279 .63339 L
s
P
p
.002 w
.63073 .28344 m .57505 .24834 L .57777 .25027 L p
1 g
F P
s
P
p
.002 w
.57777 .25027 m .63077 .28368 L .63073 .28344 L p
1 g
F P
s
P
p
.002 w
.69429 .3959 m .67211 .3347 L .67015 .33247 L p
1 g
F P
s
P
p
.002 w
.63077 .28368 m .67015 .33247 L .67211 .3347 L p
1 g
F P
s
P
p
.002 w
.30947 .38797 m .3038 .44676 L .30364 .43987 L p
1 g
F P
s
P
p
.002 w
.30364 .43987 m .30951 .37886 L .30947 .38797 L p
1 g
F P
s
P
p
.002 w
.67211 .3347 m .63073 .28344 L .63077 .28368 L p
1 g
F P
s
P
p
.002 w
.37815 .27905 m .33503 .32321 L .34046 .31542 L p
1 g
F P
s
P
p
.002 w
.34046 .31542 m .38395 .27086 L .37815 .27905 L p
1 g
F P
s
P
p
.002 w
.447 .62059 m .50605 .62716 L .51319 .62679 L p
1 g
F P
s
P
p
.002 w
.57307 .61387 m .51319 .62679 L .50605 .62716 L p
1 g
F P
s
P
p
.002 w
.57307 .61387 m .62536 .58197 L .63276 .57591 L p
1 g
F P
s
P
p
.002 w
.67192 .52738 m .63276 .57591 L .62536 .58197 L p
1 g
F P
s
P
p
.002 w
.50549 .23634 m .44098 .24325 L .44861 .24029 L p
1 g
F P
s
P
p
.002 w
.44861 .24029 m .51182 .23349 L .50549 .23634 L p
1 g
F P
s
P
p
.002 w
.67192 .52738 m .69264 .46732 L .69498 .45964 L p
1 g
F P
s
P
p
.002 w
.69429 .3959 m .69498 .45964 L .69264 .46732 L p
1 g
F P
s
P
p
.002 w
.33408 .3344 m .30947 .38797 L .30951 .37886 L p
1 g
F P
s
P
p
.002 w
.30951 .37886 m .33503 .32321 L .33408 .3344 L p
1 g
F P
s
P
p
.002 w
.322 .50756 m .35059 .55559 L .34774 .55611 L p
1 g
F P
s
P
p
.002 w
.34774 .55611 m .31712 .5047 L .322 .50756 L p
1 g
F P
s
P
p
.002 w
.39248 .59604 m .34774 .55611 L .35059 .55559 L p
1 g
F P
s
P
p
.002 w
.35059 .55559 m .39239 .59289 L .39248 .59604 L p
1 g
F P
s
P
p
.002 w
.447 .62059 m .39248 .59604 L .39239 .59289 L p
1 g
F P
s
P
p
.002 w
.50605 .62716 m .56374 .61471 L .57307 .61387 L p
1 g
F P
s
P
p
.002 w
.62536 .58197 m .57307 .61387 L .56374 .61471 L p
1 g
F P
s
P
p
.002 w
.57006 .25153 m .50549 .23634 L .51182 .23349 L p
1 g
F P
s
P
p
.002 w
.51182 .23349 m .57505 .24834 L .57006 .25153 L p
1 g
F P
s
P
p
.002 w
.43473 .25172 m .37815 .27905 L .38395 .27086 L p
1 g
F P
s
P
p
.002 w
.38395 .27086 m .44098 .24325 L .43473 .25172 L p
1 g
F P
s
P
p
.002 w
.3096 .45348 m .322 .50756 L .31712 .5047 L p
1 g
F P
s
P
p
.002 w
.31712 .5047 m .3038 .44676 L .3096 .45348 L p
1 g
F P
s
P
p
.002 w
.69264 .46732 m .69191 .40227 L .69429 .3959 L p
1 g
F P
s
P
p
.002 w
.67211 .3347 m .69429 .3959 L .69191 .40227 L p
1 g
F P
s
P
p
.002 w
.62536 .58197 m .66417 .53385 L .67192 .52738 L p
1 g
F P
s
P
p
.002 w
.69264 .46732 m .67192 .52738 L .66417 .53385 L p
1 g
F P
s
P
p
.002 w
.39239 .59289 m .44332 .61582 L .447 .62059 L p
1 g
F P
s
P
p
.002 w
.50605 .62716 m .447 .62059 L .44332 .61582 L p
1 g
F P
s
P
p
.002 w
.62695 .2874 m .57006 .25153 L .57505 .24834 L p
1 g
F P
s
P
p
.002 w
.57505 .24834 m .63073 .28344 L .62695 .2874 L p
1 g
F P
s
P
p
.002 w
.69191 .40227 m .66923 .33977 L .67211 .3347 L p
1 g
F P
s
P
p
.002 w
.63073 .28344 m .67211 .3347 L .66923 .33977 L p
1 g
F P
s
P
p
.002 w
.31494 .39868 m .3096 .45348 L .3038 .44676 L p
1 g
F P
s
P
p
.002 w
.3038 .44676 m .30947 .38797 L .31494 .39868 L p
1 g
F P
s
P
p
.002 w
.37564 .29197 m .33408 .3344 L .33503 .32321 L p
1 g
F P
s
P
p
.002 w
.33503 .32321 m .37815 .27905 L .37564 .29197 L p
1 g
F P
s
P
p
.002 w
.66923 .33977 m .62695 .2874 L .63073 .28344 L p
1 g
F P
s
P
p
.002 w
.56374 .61471 m .50605 .62716 L .49842 .62192 L p
1 g
F P
s
P
p
.002 w
.44332 .61582 m .49842 .62192 L .50605 .62716 L p
1 g
F P
s
P
p
.002 w
.56374 .61471 m .61406 .58395 L .62536 .58197 L p
1 g
F P
s
P
p
.002 w
.66417 .53385 m .62536 .58197 L .61406 .58395 L p
1 g
F P
s
P
p
.002 w
.49873 .24494 m .43473 .25172 L .44098 .24325 L p
1 g
F P
s
P
p
.002 w
.44098 .24325 m .50549 .23634 L .49873 .24494 L p
1 g
F P
s
P
p
.002 w
.66417 .53385 m .68466 .47428 L .69264 .46732 L p
1 g
F P
s
P
p
.002 w
.69191 .40227 m .69264 .46732 L .68466 .47428 L p
1 g
F P
s
P
p
.002 w
.33794 .34885 m .31494 .39868 L .30947 .38797 L p
1 g
F P
s
P
p
.002 w
.30947 .38797 m .33408 .3344 L .33794 .34885 L p
1 g
F P
s
P
p
.002 w
.49842 .62192 m .55218 .61025 L .56374 .61471 L p
1 g
F P
s
P
p
.002 w
.61406 .58395 m .56374 .61471 L .55218 .61025 L p
1 g
F P
s
P
p
.002 w
.33226 .50831 m .35789 .55142 L .35059 .55559 L p
1 g
F P
s
P
p
.002 w
.35059 .55559 m .322 .50756 L .33226 .50831 L p
1 g
F P
s
P
p
.002 w
.39239 .59289 m .35059 .55559 L .35789 .55142 L p
1 g
F P
s
P
p
.002 w
.35789 .55142 m .39541 .58491 L .39239 .59289 L p
1 g
F P
s
P
p
.002 w
.44332 .61582 m .39239 .59289 L .39541 .58491 L p
1 g
F P
s
P
p
.002 w
.43013 .26578 m .37564 .29197 L .37815 .27905 L p
1 g
F P
s
P
p
.002 w
.37815 .27905 m .43473 .25172 L .43013 .26578 L p
1 g
F P
s
P
p
.002 w
.56281 .26007 m .49873 .24494 L .50549 .23634 L p
1 g
F P
s
P
p
.002 w
.50549 .23634 m .57006 .25153 L .56281 .26007 L p
1 g
F P
s
P
p
.002 w
.61406 .58395 m .65133 .53759 L .66417 .53385 L p
1 g
F P
s
P
p
.002 w
.68466 .47428 m .66417 .53385 L .65133 .53759 L p
1 g
F P
s
P
p
.002 w
.68466 .47428 m .68386 .40973 L .69191 .40227 L p
1 g
F P
s
P
p
.002 w
.66923 .33977 m .69191 .40227 L .68386 .40973 L p
1 g
F P
s
P
p
.002 w
.32119 .45981 m .33226 .50831 L .322 .50756 L p
1 g
F P
s
P
p
.002 w
.322 .50756 m .3096 .45348 L .32119 .45981 L p
1 g
F P
s
P
p
.002 w
.39541 .58491 m .44113 .60545 L .44332 .61582 L p
1 g
F P
s
P
p
.004 w
.42744 .5993 m
.5 .43051 L
s
P
p
.004 w
.42437 .60644 m
.42494 .60511 L
s
P
p
.004 w
.42153 .61304 m
.42437 .60644 L
s
P
p
.004 w
.41279 .63339 m
.42153 .61304 L
s
P
p
.002 w
.49842 .62192 m .44332 .61582 L .44113 .60545 L p
1 g
F P
s
P
p
.002 w
.61929 .29572 m .56281 .26007 L .57006 .25153 L p
1 g
F P
s
P
p
.002 w
.57006 .25153 m .62695 .2874 L .61929 .29572 L p
1 g
F P
s
P
p
.002 w
.68386 .40973 m .66129 .34772 L .66923 .33977 L p
1 g
F P
s
P
p
.002 w
.62695 .2874 m .66923 .33977 L .66129 .34772 L p
1 g
F P
s
P
p
.002 w
.32607 .41077 m .32119 .45981 L .3096 .45348 L p
1 g
F P
s
P
p
.002 w
.3096 .45348 m .31494 .39868 L .32607 .41077 L p
1 g
F P
s
P
p
.002 w
.3767 .30949 m .33794 .34885 L .33408 .3344 L p
1 g
F P
s
P
p
.002 w
.33408 .3344 m .37564 .29197 L .3767 .30949 L p
1 g
F P
s
P
p
.002 w
.55218 .61025 m .49842 .62192 L .49052 .61086 L p
1 g
F P
s
P
p
.002 w
.44113 .60545 m .49052 .61086 L .49842 .62192 L p
1 g
F P
s
P
p
.002 w
.66129 .34772 m .61929 .29572 L .62695 .2874 L p
1 g
F P
s
P
p
.002 w
.55218 .61025 m .59896 .58153 L .61406 .58395 L p
1 g
F P
s
P
p
.002 w
.65133 .53759 m .61406 .58395 L .59896 .58153 L p
1 g
F P
s
P
p
.002 w
.49173 .25938 m .43013 .26578 L .43473 .25172 L p
1 g
F P
s
P
p
.002 w
.43473 .25172 m .49873 .24494 L .49173 .25938 L p
1 g
F P
s
P
p
.002 w
.65133 .53759 m .67093 .48023 L .68466 .47428 L p
1 g
F P
s
P
p
.002 w
.68386 .40973 m .68466 .47428 L .67093 .48023 L p
1 g
F P
s
P
p
.002 w
.34677 .3663 m .32607 .41077 L .31494 .39868 L p
1 g
F P
s
P
p
.002 w
.31494 .39868 m .33794 .34885 L .34677 .3663 L p
1 g
F P
s
P
p
.002 w
.49052 .61086 m .53861 .60031 L .55218 .61025 L p
1 g
F P
s
P
p
.002 w
.59896 .58153 m .55218 .61025 L .53861 .60031 L p
1 g
F P
s
P
p
.002 w
.3479 .50679 m .36969 .54351 L .35789 .55142 L p
1 g
F P
s
P
p
.002 w
.35789 .55142 m .33226 .50831 L .3479 .50679 L p
1 g
F P
s
P
p
.002 w
.39541 .58491 m .35789 .55142 L .36969 .54351 L p
1 g
F P
s
P
p
.002 w
.36969 .54351 m .40165 .57203 L .39541 .58491 L p
1 g
F P
s
P
p
.002 w
.44113 .60545 m .39541 .58491 L .40165 .57203 L p
1 g
F P
s
P
p
.002 w
.42743 .2853 m .3767 .30949 L .37564 .29197 L p
1 g
F P
s
P
p
.002 w
.37564 .29197 m .43013 .26578 L .42743 .2853 L p
1 g
F P
s
P
p
.002 w
.5534 .27404 m .49173 .25938 L .49873 .24494 L p
1 g
F P
s
P
p
.002 w
.49873 .24494 m .56281 .26007 L .5534 .27404 L p
1 g
F P
s
P
p
.002 w
.59896 .58153 m .63351 .53831 L .65133 .53759 L p
1 g
F P
s
P
p
.002 w
.67093 .48023 m .65133 .53759 L .63351 .53831 L p
1 g
F P
s
P
p
.002 w
.67093 .48023 m .67004 .41812 L .68386 .40973 L p
1 g
F P
s
P
p
.002 w
.66129 .34772 m .68386 .40973 L .67004 .41812 L p
1 g
F P
s
P
p
.002 w
.33857 .46553 m .3479 .50679 L .33226 .50831 L p
1 g
F P
s
P
p
.002 w
.33226 .50831 m .32119 .45981 L .33857 .46553 L p
1 g
F P
s
P
p
.002 w
.40165 .57203 m .44058 .58947 L .44113 .60545 L p
1 g
F P
s
P
p
.002 w
.49052 .61086 m .44113 .60545 L .44058 .58947 L p
1 g
F P
s
P
p
.002 w
.60776 .3084 m .5534 .27404 L .56281 .26007 L p
1 g
F P
s
P
p
.002 w
.56281 .26007 m .61929 .29572 L .60776 .3084 L p
1 g
F P
s
P
p
.002 w
.3815 .33128 m .34677 .3663 L .33794 .34885 L p
1 g
F P
s
P
p
.002 w
.33794 .34885 m .3767 .30949 L .3815 .33128 L p
1 g
F P
s
P
p
.002 w
.67004 .41812 m .64823 .35845 L .66129 .34772 L p
1 g
F P
s
P
p
.002 w
.61929 .29572 m .66129 .34772 L .64823 .35845 L p
1 g
F P
s
P
p
.002 w
.34284 .42391 m .33857 .46553 L .32119 .45981 L p
1 g
F P
s
P
p
.002 w
.32119 .45981 m .32607 .41077 L .34284 .42391 L p
1 g
F P
s
P
p
.002 w
.44058 .58947 m .48259 .59399 L .49052 .61086 L p
1 g
F P
s
P
p
.002 w
.53861 .60031 m .49052 .61086 L .48259 .59399 L p
1 g
F P
s
P
p
.002 w
.53861 .60031 m .58034 .57451 L .59896 .58153 L p
1 g
F P
s
P
p
.002 w
.63351 .53831 m .59896 .58153 L .58034 .57451 L p
1 g
F P
s
P
p
.002 w
.64823 .35845 m .60776 .3084 L .61929 .29572 L p
1 g
F P
s
P
p
.002 w
.48472 .27951 m .42743 .2853 L .43013 .26578 L p
1 g
F P
s
P
p
.002 w
.43013 .26578 m .49173 .25938 L .48472 .27951 L p
1 g
F P
s
P
p
.002 w
.63351 .53831 m .65157 .48493 L .67093 .48023 L p
1 g
F P
s
P
p
.002 w
.67004 .41812 m .67093 .48023 L .65157 .48493 L p
1 g
F P
s
P
p
.002 w
.36053 .38628 m .34284 .42391 L .32607 .41077 L p
1 g
F P
s
P
p
.002 w
.32607 .41077 m .34677 .3663 L .36053 .38628 L p
1 g
F P
s
P
p
.002 w
.48259 .59399 m .52338 .58491 L .53861 .60031 L p
1 g
F P
s
P
p
.002 w
.58034 .57451 m .53861 .60031 L .52338 .58491 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.42684 .30989 m .3815 .33128 L .3767 .30949 L p
1 g
F P
s
P
p
.002 w
.3767 .30949 m .42743 .2853 L .42684 .30989 L p
1 g
F P
s
P
p
.002 w
.36872 .50291 m .38587 .53189 L .36969 .54351 L p
1 g
F P
s
P
p
.002 w
.36969 .54351 m .3479 .50679 L .36872 .50291 L p
1 g
F P
s
P
p
.002 w
.40165 .57203 m .36969 .54351 L .38587 .53189 L p
1 g
F P
s
P
p
.002 w
.38587 .53189 m .41109 .55439 L .40165 .57203 L p
1 g
F P
s
P
p
.002 w
.44058 .58947 m .40165 .57203 L .41109 .55439 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.58034 .57451 m .61103 .53582 L .63351 .53831 L p
1 g
F P
s
P
p
.002 w
.65157 .48493 m .63351 .53831 L .61103 .53582 L p
1 g
F P
s
P
p
.002 w
.54202 .29326 m .48472 .27951 L .49173 .25938 L p
1 g
F P
s
P
p
.002 w
.49173 .25938 m .5534 .27404 L .54202 .29326 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.65157 .48493 m .65058 .42719 L .67004 .41812 L p
1 g
F P
s
P
p
.002 w
.64823 .35845 m .67004 .41812 L .65058 .42719 L p
1 g
F P
s
P
p
.002 w
.36145 .47039 m .36872 .50291 L .3479 .50679 L p
1 g
F P
s
P
p
.002 w
.3479 .50679 m .33857 .46553 L .36145 .47039 L p
1 g
F P
s
P
p
.002 w
.41109 .55439 m .44181 .56811 L .44058 .58947 L p
1 g
F P
s
P
p
.002 w
.48259 .59399 m .44058 .58947 L .44181 .56811 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.39006 .3568 m .36053 .38628 L .34677 .3663 L p
1 g
F P
s
P
p
.002 w
.34677 .3663 m .3815 .33128 L .39006 .3568 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.59254 .32524 m .54202 .29326 L .5534 .27404 L p
1 g
F P
s
P
p
.002 w
.5534 .27404 m .60776 .3084 L .59254 .32524 L p
1 g
F P
s
P
p
.002 w
.36493 .43768 m .36145 .47039 L .33857 .46553 L p
1 g
F P
s
P
p
.002 w
.33857 .46553 m .34284 .42391 L .36493 .43768 L p
1 g
F P
s
P
p
.002 w
.52338 .58491 m .55865 .5629 L .58034 .57451 L p
1 g
F P
s
P
p
.002 w
.61103 .53582 m .58034 .57451 L .55865 .5629 L p
1 g
F P
s
P
p
.002 w
.65058 .42719 m .63019 .37175 L .64823 .35845 L p
1 g
F P
s
P
p
.002 w
.60776 .3084 m .64823 .35845 L .63019 .37175 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51735 .58625 m .48259 .59399 L .4778 .58004 L p
1 g
F P
s
P
p
.002 w
.4778 .58004 m .47693 .57749 L p
.4891 .58013 L 1 g
F P
s
P
p
.51735 .58625 m .4778 .58004 L .4891 .58013 L 1 g
F
P
p
.002 w
.51092 .5803 m .51079 .57862 L p
.50272 .58023 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .5803 L p
1 g
F P
s
P
p
.002 w
.52338 .58491 m .51735 .58625 L p
.50409 .58167 L 1 g
F P
s
P
p
.52338 .58491 m .50409 .58167 L .50563 .58136 L 1 g
F
P
p
.52338 .58491 m .49988 .58021 L .50649 .58026 L 1 g
F
P
p
.53128 .57265 m .51092 .5803 L .51849 .57877 L 1 g
F
P
p
.002 w
.55205 .56702 m .52338 .58491 L .52049 .58128 L p
1 g
F P
s
P
p
.002 w
.52049 .58128 m .51849 .57877 L p
.53161 .57418 L 1 g
F P
s
P
p
.55205 .56702 m .52049 .58128 L .53161 .57418 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53161 .57418 L p
1 g
F P
s
P
p
.54854 .56129 m .53161 .57418 L .54194 .56758 L 1 g
F
P
p
.53128 .57265 m .51849 .57877 L .52119 .57783 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.4749 .57158 m .50694 .56431 L .51849 .57877 L p
1 g
F P
s
P
p
.002 w
.51849 .57877 m .52338 .58491 L p
.50843 .5808 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58013 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58013 L .50272 .58023 L 1 g
F
P
p
.50843 .5808 m .4749 .57158 L .51849 .57877 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53202 .57605 L p
1 g
F P
s
P
p
.002 w
.53202 .57605 m .53128 .57265 L p
.5199 .57849 L 1 g
F P
s
P
p
.5199 .57849 m .51111 .583 L .53202 .57605 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54916 .56296 m .54854 .56129 L p
.54194 .56758 L 1 g
F P
s
P
p
.002 w
.51849 .57877 m .50694 .56431 L p
.54361 .56651 L 1 g
F P
s
P
p
.55205 .56702 m .53161 .57418 L .54361 .56651 L 1 g
F
P
p
.53161 .57418 m .51849 .57877 L .54361 .56651 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55865 .5629 m .55205 .56702 L p
.54582 .56665 L 1 g
F P
s
P
p
.54898 .56317 m .54582 .56665 L .50694 .56431 L 1 g
F
P
p
.55865 .5629 m .54582 .56665 L .54898 .56317 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54916 .56296 L p
1 g
F P
s
P
p
.56075 .54566 m .54916 .56296 L .55276 .559 L 1 g
F
P
p
.58445 .53004 m .55932 .55301 L .56966 .53503 L 1 g
F
P
p
.55932 .55301 m .55276 .559 L .56136 .54681 L 1 g
F
P
p
.55932 .55301 m .56136 .54681 L .56966 .53503 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56136 .54681 L p
1 g
F P
s
P
p
.56654 .52734 m .56136 .54681 L .56501 .5357 L 1 g
F
P
p
.56075 .54566 m .55276 .559 L .55565 .5549 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.58445 .53004 m .55865 .5629 L .55276 .559 L p
1 g
F P
s
P
p
.002 w
.50694 .56431 m .53452 .5469 L .55276 .559 L p
1 g
F P
s
P
p
.002 w
.55276 .559 m .55865 .5629 L p
.54898 .56317 L 1 g
F P
s
P
p
.54898 .56317 m .50694 .56431 L .55276 .559 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56227 .54853 L p
1 g
F P
s
P
p
.002 w
.56227 .54853 m .56075 .54566 L p
.55436 .55724 L 1 g
F P
s
P
p
.55436 .55724 m .54998 .56518 L .56227 .54853 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55276 .559 m .53452 .5469 L p
.56468 .53671 L 1 g
F P
s
P
p
.56966 .53503 m .56136 .54681 L .56468 .53671 L 1 g
F
P
p
.56136 .54681 m .55276 .559 L .56468 .53671 L 1 g
F
P
p
.002 w
.56737 .52854 m .56654 .52734 L p
.56501 .5357 L 1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56737 .52854 L p
1 g
F P
s
P
p
.56515 .50826 m .56737 .52854 L .56726 .52486 L 1 g
F
P
p
.5977 .48967 m .56726 .52486 L .5662 .51259 L 1 g
F
P
p
.56669 .51822 m .56726 .52486 L .56716 .5213 L 1 g
F
P
p
.56515 .50826 m .56726 .52486 L .56669 .51822 L 1 g
F
P
p
.002 w
.5977 .48967 m .58445 .53004 L .56726 .52486 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56726 .52486 m .58445 .53004 L p
.56757 .53574 L 1 g
F P
s
P
p
.002 w
.56477 .4894 m .5977 .48967 L p
.56717 .51188 L 1 g
F P
s
P
p
.56717 .51188 m .5662 .51259 L .566 .50936 L 1 g
F
P
p
.56717 .51188 m .566 .50936 L .56477 .4894 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5659 .50915 L p
1 g
F P
s
P
p
.55661 .4905 m .5659 .50915 L .56211 .50102 L 1 g
F
P
p
.002 w
.5659 .50915 m .56515 .50826 L p
.56669 .51822 L 1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.55661 .4905 m .56211 .50102 L .56147 .49964 L 1 g
F
P
p
.002 w
.56477 .4894 m .56147 .49964 L p
.55801 .49254 L 1 g
F P
s
P
p
.002 w
.55746 .4914 m .55661 .4905 L p
.56147 .49964 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.002 w
.52244 .50905 m .5293 .48729 L .55478 .48881 L p
1 g
F P
s
P
p
.55539 .4894 m .52244 .50905 L .55478 .48881 L 1 g
F
P
p
.002 w
.55624 .48889 m .56477 .4894 L p
.55801 .49254 L 1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55478 .48881 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55478 .48881 m .5293 .48729 L p
.5413 .47619 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54226 .47664 L p
1 g
F P
s
P
p
.52214 .46667 m .54226 .47664 L .53328 .47244 L 1 g
F
P
p
.54155 .47596 m .54226 .47664 L .5413 .47619 L 1 g
F
P
p
.54226 .47664 m .55478 .48881 L .5413 .47619 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52849 .46401 m .56376 .45544 L p
.5413 .47619 L 1 g
F P
s
P
p
.002 w
.5293 .48729 m .5287 .47029 L p
.5413 .47619 L 1 g
F P
s
P
p
.52214 .46667 m .53328 .47244 L .5287 .47029 L 1 g
F
P
p
.002 w
.5287 .47029 m .5293 .48729 L p
.5225 .46725 L 1 g
F P
s
P
p
.002 w
.52248 .46724 m .52214 .46667 L p
.5287 .47029 L 1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49263 .48338 m .49216 .47157 L .51689 .46643 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46724 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46724 L .51689 .46643 L 1 g
F
P
p
.002 w
.51689 .46643 m .49216 .47157 L p
.49924 .46401 L 1 g
F P
s
P
p
.5 .46388 m .51689 .46643 L .49924 .46401 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .49136 .4653 L 1 g
F
P
p
.47786 .46667 m .49136 .4653 L .48984 .46554 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48984 .46554 m .49216 .47157 L p
.4761 .4679 L 1 g
F P
s
P
p
.48984 .46554 m .4761 .4679 L .47754 .46721 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .46721 L p
1 g
F P
s
P
p
.4761 .4679 m .49216 .47157 L .46064 .47537 L 1 g
F
P
p
.002 w
.47754 .46721 m .47718 .46778 L p
.46819 .47173 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .46721 L .46819 .47173 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .4391 .49845 L 1 g
F
P
p
.002 w
.4298 .49856 m .44485 .48674 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.43623 .5043 m .43258 .50104 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.43258 .50104 m .4298 .49856 L p
.44258 .49136 L 1 g
F P
s
P
p
.43485 .50826 m .44182 .49217 L .44065 .4947 L 1 g
F
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45092 .48328 L 1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.4298 .49856 m .43437 .50264 L p
.42377 .5313 L 1 g
F P
s
P
p
.002 w
.43437 .50264 m .43623 .5043 L p
.43384 .50946 L 1 g
F P
s
P
p
.42377 .5313 m .43437 .50264 L .43384 .50946 L 1 g
F
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.42357 .53236 m .42377 .5313 L .43339 .51544 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43384 .50946 L p
1 g
F P
s
P
p
.43346 .52734 m .43384 .50946 L .43336 .51574 L 1 g
F
P
p
.002 w
.43204 .53613 m .42357 .53236 L .43036 .52084 L p
1 g
F P
s
P
p
.002 w
.43036 .52084 m .43336 .51574 L p
.43252 .52871 L 1 g
F P
s
P
p
.43204 .53613 m .43036 .52084 L .43252 .52871 L 1 g
F
P
p
.43925 .54566 m .43471 .53669 L .43491 .53741 L 1 g
F
P
p
.002 w
.44283 .55932 m .44181 .56811 L p
.43652 .54454 L 1 g
F P
s
P
p
.43652 .54454 m .43491 .53741 L .43844 .54718 L 1 g
F
P
p
.43652 .54454 m .43844 .54718 L .44283 .55932 L 1 g
F
P
p
.002 w
.42357 .53236 m .42955 .53502 L p
.44181 .56811 L 1 g
F P
s
P
p
.002 w
.42955 .53502 m .43491 .53741 L p
.43652 .54454 L 1 g
F P
s
P
p
.44181 .56811 m .42955 .53502 L .43652 .54454 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43844 .54718 L p
1 g
F P
s
P
p
.45146 .56129 m .43844 .54718 L .44345 .55401 L 1 g
F
P
p
.002 w
.45637 .56963 m .44181 .56811 L .44305 .55744 L p
1 g
F P
s
P
p
.002 w
.44305 .55744 m .44345 .55401 L p
.45084 .56295 L 1 g
F P
s
P
p
.45637 .56963 m .44305 .55744 L .45084 .56295 L 1 g
F
P
p
.46872 .57265 m .45913 .56882 L .46096 .57011 L 1 g
F
P
p
.002 w
.47785 .58016 m .48259 .59399 L p
.46336 .57277 L 1 g
F P
s
P
p
.46336 .57277 m .46096 .57011 L .46832 .57449 L 1 g
F
P
p
.46336 .57277 m .46832 .57449 L .47785 .58016 L 1 g
F
P
p
.002 w
.46832 .57449 m .46872 .57265 L p
.46096 .57011 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47693 .57749 m .47785 .58016 L p
.46832 .57449 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45084 .56295 L p
1 g
F P
s
P
p
.46872 .57265 m .45084 .56295 L .45913 .56882 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.4749 .57158 m .46096 .57011 L p
.44486 .54183 L 1 g
F P
s
P
p
.002 w
.46096 .57011 m .45637 .56963 L p
.45475 .56572 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.46096 .57011 m .45475 .56572 L .44486 .54183 L 1 g
F
P
p
.45146 .56129 m .44345 .55401 L .44437 .55513 L 1 g
F
P
p
.002 w
.45055 .56373 m .45146 .56129 L p
.44408 .55488 L 1 g
F P
s
P
p
.002 w
.44345 .55401 m .44486 .54183 L p
.45637 .56963 L 1 g
F P
s
P
p
.002 w
.45084 .56295 m .45002 .56518 L p
.45913 .56882 L 1 g
F P
s
P
p
.002 w
.46096 .57011 m .4749 .57158 L .47693 .57749 L p
1 g
F P
s
P
p
.46832 .57449 m .46096 .57011 L .47693 .57749 L 1 g
F
P
p
.47782 .57768 m .47738 .57765 L .4891 .58013 L 1 g
F
P
p
.47738 .57765 m .4678 .57686 L .48089 .57887 L 1 g
F
P
p
.47738 .57765 m .48089 .57887 L .4891 .58013 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48898 .58169 L p
1 g
F P
s
P
p
.002 w
.48898 .58169 m .4891 .58013 L p
.48089 .57887 L 1 g
F P
s
P
p
.48089 .57887 m .4678 .57686 L .48898 .58169 L 1 g
F
P
p
.002 w
.46816 .57521 m .46832 .57449 L p
.46096 .57011 L 1 g
F P
s
P
p
.002 w
.44181 .56811 m .46096 .57011 L p
.48259 .59399 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46816 .57521 L p
1 g
F P
s
P
p
.45913 .56882 m .45002 .56518 L .46816 .57521 L 1 g
F
P
p
.44437 .55513 m .44345 .55401 L .44408 .55488 L 1 g
F
P
p
.002 w
.43844 .54718 m .43925 .54566 L p
.43491 .53741 L 1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43252 .52871 L p
1 g
F P
s
P
p
.43925 .54566 m .43252 .52871 L .43471 .53669 L 1 g
F
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44486 .54183 m .43491 .53741 L p
.43877 .50656 L 1 g
F P
s
P
p
.002 w
.43491 .53741 m .43204 .53613 L p
.43318 .53111 L 1 g
F P
s
P
p
.43491 .53741 m .43318 .53111 L .43877 .50656 L 1 g
F
P
p
.43346 .52734 m .43336 .51574 L .43316 .51882 L 1 g
F
P
p
.002 w
.43235 .52895 m .43346 .52734 L p
.43315 .51851 L 1 g
F P
s
P
p
.002 w
.43336 .51574 m .43877 .50656 L p
.43204 .53613 L 1 g
F P
s
P
p
.002 w
.43252 .52871 m .43146 .53025 L p
.43471 .53669 L 1 g
F P
s
P
p
.002 w
.43491 .53741 m .44486 .54183 L .44283 .55932 L p
1 g
F P
s
P
p
.002 w
.43844 .54718 m .43743 .5491 L p
.44408 .55488 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45055 .56373 L p
1 g
F P
s
P
p
.44408 .55488 m .43743 .5491 L .45055 .56373 L 1 g
F
P
p
.002 w
.43789 .54823 m .43844 .54718 L p
.43491 .53741 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43789 .54823 L p
1 g
F P
s
P
p
.43471 .53669 m .43146 .53025 L .43789 .54823 L 1 g
F
P
p
.43316 .51882 m .43336 .51574 L .43315 .51851 L 1 g
F
P
p
.002 w
.43877 .50656 m .43336 .51574 L p
.43339 .51544 L 1 g
F P
s
P
p
.002 w
.43336 .51574 m .42357 .53236 L p
.43339 .51544 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43384 .50946 L p
1 g
F P
s
P
p
.002 w
.43384 .50946 m .43485 .50826 L p
.44065 .4947 L 1 g
F P
s
P
p
.44065 .4947 m .44166 .49233 L .43384 .50946 L 1 g
F
P
p
.002 w
.43623 .5043 m .43877 .50656 L p
.42377 .5313 L 1 g
F P
s
P
p
.002 w
.43384 .50946 m .43287 .51061 L p
.43315 .51851 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43235 .52895 L p
1 g
F P
s
P
p
.43315 .51851 m .43287 .51061 L .43235 .52895 L 1 g
F
P
p
.002 w
.46143 .51254 m .4497 .5114 L .45612 .47825 L p
1 g
F P
s
P
p
.002 w
.48233 .50362 m .47271 .50986 L .45632 .47806 L p
1 g
F P
s
P
p
.002 w
.49263 .48338 m .48922 .49447 L .45643 .47795 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.4562 .47783 m .48013 .45091 L .48192 .4531 L p
1 g
F P
s
P
p
.45826 .47608 m .46819 .47173 L .46064 .47537 L 1 g
F
P
p
.002 w
.46064 .47537 m .45701 .47739 L p
.45752 .47688 L 1 g
F P
s
P
p
.002 w
.45752 .47688 m .45752 .47688 L p
.46064 .47537 L 1 g
F P
s
P
p
.002 w
.45752 .47688 m .45826 .47608 L p
.46064 .47537 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48192 .4531 m .48784 .46033 L .46064 .47537 L p
1 g
F P
s
P
p
.48192 .4531 m .46064 .47537 L .45752 .47688 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45752 .47688 L p
1 g
F P
s
P
p
.002 w
.45701 .47739 m .4562 .47783 L p
.48192 .4531 L 1 g
F P
s
P
p
.002 w
.45752 .47688 m .45752 .47689 L p
.45746 .47694 L 1 g
F P
s
P
p
.44339 .4905 m .45752 .47688 L .45746 .47694 L 1 g
F
P
p
.002 w
.45752 .47689 m .45751 .4769 L p
.45743 .47697 L 1 g
F P
s
P
p
.44339 .4905 m .45752 .47689 L .45743 .47697 L 1 g
F
P
p
.002 w
.49216 .47157 m .49263 .48338 L .45651 .47788 L p
1 g
F P
s
P
p
.002 w
.45651 .47788 m .4562 .47783 L .45663 .47776 L p
1 g
F P
s
P
p
.002 w
.45663 .47776 m .49216 .47157 L p
.45651 .47788 L 1 g
F P
s
P
p
.002 w
.45643 .47795 m .4562 .47783 L .45651 .47788 L p
1 g
F P
s
P
p
.002 w
.45651 .47788 m .49263 .48338 L p
.45643 .47795 L 1 g
F P
s
P
p
.002 w
.45751 .4769 m .4575 .47691 L p
.45739 .47701 L 1 g
F P
s
P
p
.44339 .4905 m .45751 .4769 L .45739 .47701 L 1 g
F
P
p
.002 w
.4575 .47691 m .45749 .47692 L p
.45736 .47705 L 1 g
F P
s
P
p
.44339 .4905 m .4575 .47691 L .45736 .47705 L 1 g
F
P
p
.002 w
.48922 .49447 m .48233 .50362 L .45638 .478 L p
1 g
F P
s
P
p
.002 w
.45638 .478 m .4562 .47783 L .45643 .47795 L p
1 g
F P
s
P
p
.002 w
.45643 .47795 m .48922 .49447 L p
.45638 .478 L 1 g
F P
s
P
p
.002 w
.45632 .47806 m .4562 .47783 L .45638 .478 L p
1 g
F P
s
P
p
.002 w
.45638 .478 m .48233 .50362 L p
.45632 .47806 L 1 g
F P
s
P
p
.002 w
.45749 .47692 m .45748 .47693 L p
.45733 .47707 L 1 g
F P
s
P
p
.44339 .4905 m .45749 .47692 L .45733 .47707 L 1 g
F
P
p
.002 w
.45748 .47693 m .45747 .47694 L p
.45732 .47709 L 1 g
F P
s
P
p
.44339 .4905 m .45748 .47693 L .45732 .47709 L 1 g
F
P
p
.002 w
.47271 .50986 m .46143 .51254 L .45625 .47813 L p
1 g
F P
s
P
p
.002 w
.45625 .47813 m .4562 .47783 L .45632 .47806 L p
1 g
F P
s
P
p
.002 w
.45632 .47806 m .47271 .50986 L p
.45625 .47813 L 1 g
F P
s
P
p
.002 w
.45612 .47825 m .4562 .47783 L .45625 .47813 L p
1 g
F P
s
P
p
.002 w
.45625 .47813 m .46143 .51254 L p
.45612 .47825 L 1 g
F P
s
P
p
.002 w
.45747 .47694 m .45747 .47694 L p
.45734 .47707 L 1 g
F P
s
P
p
.44339 .4905 m .45747 .47694 L .45734 .47707 L 1 g
F
P
p
.002 w
.45747 .47694 m .45746 .47695 L p
.45738 .47703 L 1 g
F P
s
P
p
.44339 .4905 m .45747 .47694 L .45738 .47703 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4497 .5114 m .43877 .50656 L .45571 .47865 L p
1 g
F P
s
P
p
.002 w
.45571 .47865 m .4562 .47783 L .45612 .47825 L p
1 g
F P
s
P
p
.002 w
.45612 .47825 m .4497 .5114 L p
.45571 .47865 L 1 g
F P
s
P
p
.002 w
.49216 .47157 m .45663 .47776 L p
.46064 .47537 L 1 g
F P
s
P
p
.44339 .4905 m .45746 .47695 L .45092 .48328 L 1 g
F
P
p
.002 w
.44485 .48674 m .4562 .47783 L p
.45526 .47909 L 1 g
F P
s
P
p
.43623 .5043 m .44258 .49136 L .45526 .47909 L 1 g
F
P
p
.44258 .49136 m .44485 .48674 L .45526 .47909 L 1 g
F
P
p
.002 w
.4562 .47783 m .43877 .50656 L .43623 .5043 L p
1 g
F P
s
P
p
.002 w
.45701 .47739 m .46064 .47537 L p
.45663 .47776 L 1 g
F P
s
P
p
.002 w
.45746 .47695 m .45698 .47747 L p
.45092 .48328 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44182 .49217 L p
.4391 .49845 L 1 g
F P
s
P
p
.002 w
.44182 .49217 m .44166 .49233 L p
.44065 .4947 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44258 .49136 L p
.45302 .48127 L 1 g
F P
s
P
p
.45092 .48328 m .45302 .48127 L .44258 .49136 L 1 g
F
P
p
.002 w
.45698 .47747 m .44318 .49087 L p
.45302 .48127 L 1 g
F P
s
P
p
.002 w
.44318 .49087 m .44166 .49233 L p
.45302 .48127 L 1 g
F P
s
P
p
.002 w
.45663 .47776 m .4562 .47783 L .45701 .47739 L p
1 g
F P
s
P
p
.002 w
.46064 .47537 m .47473 .46758 L p
.4761 .4679 L 1 g
F P
s
P
p
.47754 .46721 m .4761 .4679 L .47473 .46758 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45752 .47688 L p
1 g
F P
s
P
p
.46819 .47173 m .47718 .46778 L .45752 .47688 L 1 g
F
P
p
.002 w
.4773 .4676 m .47754 .46721 L p
.48984 .46554 L 1 g
F P
s
P
p
.002 w
.47754 .46721 m .47786 .46667 L p
.48984 .46554 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47473 .46758 m .48784 .46033 L .48984 .46554 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.49216 .47157 m .48784 .46033 L .52003 .4418 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49136 .4653 L 1 g
F P
s
P
p
.5 .4634 m .51689 .46643 L .51159 .46563 L 1 g
F
P
p
.5225 .46724 m .49263 .48338 L .51689 .46643 L 1 g
F
P
p
.002 w
.5293 .48729 m .49263 .48338 L p
.5225 .46725 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.52003 .4418 m .51758 .46101 L .49944 .4638 L 1 g
F
P
p
.51758 .46101 m .51689 .46643 L .5 .46388 L 1 g
F
P
p
.51758 .46101 m .5 .46388 L .49944 .4638 L 1 g
F
P
p
.49944 .4638 m .5 .46388 L .49924 .46401 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4773 .4676 L p
1 g
F P
s
P
p
.49136 .4653 m .5 .46442 L .4773 .4676 L 1 g
F
P
p
.51159 .46563 m .51689 .46643 L .51216 .46574 L 1 g
F
P
p
.002 w
.52003 .4418 m .52849 .46401 L .51689 .46643 L p
1 g
F P
s
P
p
.002 w
.51689 .46643 m .52849 .46401 L p
.5225 .46724 L 1 g
F P
s
P
p
.002 w
.52248 .46724 m .52282 .46778 L p
.51216 .46574 L 1 g
F P
s
P
p
.002 w
.5226 .46743 m .52248 .46724 L p
.5287 .47029 L 1 g
F P
s
P
p
.002 w
.52849 .46401 m .5287 .47029 L p
.5225 .46725 L 1 g
F P
s
P
p
.002 w
.5287 .47029 m .52849 .46401 L p
.5413 .47619 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5226 .46743 L p
1 g
F P
s
P
p
.53328 .47244 m .54302 .47747 L .5226 .46743 L 1 g
F
P
p
.002 w
.54226 .47664 m .54302 .47747 L p
.53328 .47244 L 1 g
F P
s
P
p
.54963 .4838 m .55478 .48881 L .55117 .48531 L 1 g
F
P
p
.54174 .47608 m .55478 .48881 L .54963 .4838 L 1 g
F
P
p
.002 w
.56376 .45544 m .56477 .4894 L .55478 .48881 L p
1 g
F P
s
P
p
.56376 .45544 m .55478 .48881 L .54155 .47596 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.55801 .49254 m .52244 .50905 L .55624 .48889 L 1 g
F
P
p
.002 w
.56147 .49964 m .56431 .49082 L p
.5659 .50915 L 1 g
F P
s
P
p
.002 w
.56431 .49082 m .56477 .4894 L p
.5662 .51259 L 1 g
F P
s
P
p
.56147 .49964 m .56713 .51061 L .55779 .49175 L 1 g
F
P
p
.002 w
.55779 .49175 m .55746 .4914 L p
.56147 .49964 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55779 .49175 L p
1 g
F P
s
P
p
.002 w
.55746 .4914 m .55834 .49233 L p
.55117 .48531 L 1 g
F P
s
P
p
.002 w
.55478 .48881 m .55624 .48889 L p
.55539 .4894 L 1 g
F P
s
P
p
.56211 .50102 m .56252 .5018 L .56147 .49964 L 1 g
F
P
p
.56252 .5018 m .56713 .51061 L .56147 .49964 L 1 g
F
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55458 .52103 m .52244 .50905 L p
.55801 .49254 L 1 g
F P
s
P
p
.002 w
.56147 .49964 m .55458 .52103 L p
.55801 .49254 L 1 g
F P
s
P
p
.002 w
.55458 .52103 m .56147 .49964 L p
.5662 .51259 L 1 g
F P
s
P
p
.5662 .51259 m .56147 .49964 L .5659 .50915 L 1 g
F
P
p
.002 w
.5659 .50915 m .56713 .51061 L p
.56211 .50102 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5659 .50915 L p
1 g
F P
s
P
p
.56669 .51822 m .56854 .53025 L .5659 .50915 L 1 g
F
P
p
.002 w
.56726 .52486 m .55458 .52103 L p
.5662 .51259 L 1 g
F P
s
P
p
.002 w
.53452 .5469 m .55458 .52103 L .56726 .52486 L p
1 g
F P
s
P
p
.56757 .53574 m .53452 .5469 L .56726 .52486 L 1 g
F
P
p
.002 w
.56737 .52854 m .56854 .53025 L p
.56716 .5213 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56737 .52854 L p
1 g
F P
s
P
p
.56501 .5357 m .56257 .5491 L .56737 .52854 L 1 g
F
P
p
.002 w
.56136 .54681 m .56257 .5491 L p
.56501 .5357 L 1 g
F P
s
P
p
.55565 .5549 m .55276 .559 L .55436 .55724 L 1 g
F
P
p
.002 w
.54916 .56296 m .54998 .56518 L p
.55436 .55724 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54916 .56296 L p
1 g
F P
s
P
p
.54194 .56758 m .5322 .57686 L .54916 .56296 L 1 g
F
P
p
.002 w
.53161 .57418 m .5322 .57686 L p
.54194 .56758 L 1 g
F P
s
P
p
.52119 .57783 m .51849 .57877 L .5199 .57849 L 1 g
F
P
p
.002 w
.51092 .5803 m .51111 .583 L p
.5199 .57849 L 1 g
F P
s
P
p
.50563 .58136 m .50409 .58167 L .49988 .58021 L 1 g
F
P
p
.50649 .58026 m .49988 .58021 L .4749 .57158 L 1 g
F
P
p
.002 w
.4891 .58013 m .48921 .57862 L p
.47782 .57768 L 1 g
F P
s
P
p
.002 w
.47693 .57749 m .4749 .57158 L p
.51735 .58625 L 1 g
F P
s
P
p
.002 w
.4891 .58013 m .48889 .583 L p
.50272 .58023 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .5803 L p
1 g
F P
s
P
p
.50272 .58023 m .48889 .583 L .51092 .5803 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.63019 .37175 m .59254 .32524 L .60776 .3084 L p
1 g
F P
s
P
p
.002 w
.47794 .30492 m .42684 .30989 L .42743 .2853 L p
1 g
F P
s
P
p
.002 w
.42743 .2853 m .48472 .27951 L .47794 .30492 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.61103 .53582 m .62694 .48814 L .65157 .48493 L p
1 g
F P
s
P
p
.002 w
.65058 .42719 m .65157 .48493 L .62694 .48814 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.004 w
.4806 .45148 m
.5 .43051 L
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.37897 .40822 m .36493 .43768 L .34284 .42391 L p
1 g
F P
s
P
p
.002 w
.34284 .42391 m .36053 .38628 L .37897 .40822 L p
1 g
F P
s
P
p
.002 w
.42848 .33891 m .39006 .3568 L .3815 .33128 L p
1 g
F P
s
P
p
.002 w
.3815 .33128 m .42684 .30989 L .42848 .33891 L p
1 g
F P
s
P
p
.002 w
.55865 .5629 m .58445 .53004 L .61103 .53582 L p
1 g
F P
s
P
p
.002 w
.62694 .48814 m .61103 .53582 L .58445 .53004 L p
1 g
F P
s
P
p
.002 w
.39424 .49668 m .40609 .51677 L .38587 .53189 L p
1 g
F P
s
P
p
.002 w
.38587 .53189 m .36872 .50291 L .39424 .49668 L p
1 g
F P
s
P
p
.002 w
.41109 .55439 m .38587 .53189 L .40609 .51677 L p
1 g
F P
s
P
p
.002 w
.40609 .51677 m .42357 .53236 L .41109 .55439 L p
1 g
F P
s
P
p
.002 w
.44181 .56811 m .41109 .55439 L .42357 .53236 L p
1 g
F P
s
P
p
.002 w
.52899 .3173 m .47794 .30492 L .48472 .27951 L p
1 g
F P
s
P
p
.002 w
.48472 .27951 m .54202 .29326 L .52899 .3173 L p
1 g
F P
s
P
p
.002 w
.62694 .48814 m .62588 .43666 L .65058 .42719 L p
1 g
F P
s
P
p
.002 w
.63019 .37175 m .65058 .42719 L .62588 .43666 L p
1 g
F P
s
P
p
.002 w
.38929 .47418 m .39424 .49668 L .36872 .50291 L p
1 g
F P
s
P
p
.002 w
.36872 .50291 m .36145 .47039 L .38929 .47418 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.40224 .38526 m .37897 .40822 L .36053 .38628 L p
1 g
F P
s
P
p
.002 w
.36053 .38628 m .39006 .3568 L .40224 .38526 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.3918 .4516 m .38929 .47418 L .36145 .47039 L p
1 g
F P
s
P
p
.002 w
.36145 .47039 m .36493 .43768 L .3918 .4516 L p
1 g
F P
s
P
p
.002 w
.57399 .34586 m .52899 .3173 L .54202 .29326 L p
1 g
F P
s
P
p
.002 w
.54202 .29326 m .59254 .32524 L .57399 .34586 L p
1 g
F P
s
P
p
.002 w
.50694 .56431 m .4749 .57158 L .46775 .54415 L p
1 g
F P
s
P
p
.002 w
.44486 .54183 m .46775 .54415 L .4749 .57158 L p
1 g
F P
s
P
p
.002 w
.62588 .43666 m .60759 .38729 L .63019 .37175 L p
1 g
F P
s
P
p
.002 w
.59254 .32524 m .63019 .37175 L .60759 .38729 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.47166 .33489 m .42848 .33891 L .42684 .30989 L p
1 g
F P
s
P
p
.002 w
.42684 .30989 m .47794 .30492 L .47166 .33489 L p
1 g
F P
s
P
p
.002 w
.60759 .38729 m .57399 .34586 L .59254 .32524 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58445 .53004 m .5977 .48967 L .62694 .48814 L p
1 g
F P
s
P
p
.002 w
.62588 .43666 m .62694 .48814 L .5977 .48967 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40159 .43136 m .3918 .4516 L .36493 .43768 L p
1 g
F P
s
P
p
.002 w
.36493 .43768 m .37897 .40822 L .40159 .43136 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.46775 .54415 m .48984 .53903 L .50694 .56431 L p
1 g
F P
s
P
p
.002 w
.53452 .5469 m .50694 .56431 L .48984 .53903 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.43238 .37143 m .40224 .38526 L .39006 .3568 L p
1 g
F P
s
P
p
.002 w
.39006 .3568 m .42848 .33891 L .43238 .37143 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51473 .34548 m .47166 .33489 L .47794 .30492 L p
1 g
F P
s
P
p
.002 w
.47794 .30492 m .52899 .3173 L .51473 .34548 L p
1 g
F P
s
P
p
.002 w
.42374 .48824 m .4298 .49856 L .40609 .51677 L p
1 g
F P
s
P
p
.002 w
.40609 .51677 m .39424 .49668 L .42374 .48824 L p
1 g
F P
s
P
p
.002 w
.42357 .53236 m .40609 .51677 L .4298 .49856 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5977 .48967 m .59662 .4462 L .62588 .43666 L p
1 g
F P
s
P
p
.002 w
.60759 .38729 m .62588 .43666 L .59662 .4462 L p
1 g
F P
s
P
p
.002 w
.42124 .4767 m .42374 .48824 L .39424 .49668 L p
1 g
F P
s
P
p
.002 w
.39424 .49668 m .38929 .47418 L .42124 .4767 L p
1 g
F P
s
P
p
.002 w
.43877 .50656 m .4497 .5114 L .44486 .54183 L p
1 g
F P
s
P
p
.002 w
.46775 .54415 m .44486 .54183 L .4497 .5114 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4177 .41568 m .40159 .43136 L .37897 .40822 L p
1 g
F P
s
P
p
.002 w
.37897 .40822 m .40224 .38526 L .4177 .41568 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.48984 .53903 m .50877 .52692 L .53452 .5469 L p
1 g
F P
s
P
p
.002 w
.55458 .52103 m .53452 .5469 L .50877 .52692 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42258 .46516 m .42124 .4767 L .38929 .47418 L p
1 g
F P
s
P
p
.002 w
.38929 .47418 m .3918 .4516 L .42258 .46516 L p
1 g
F P
s
P
p
.002 w
.48984 .53903 m .46775 .54415 L .46143 .51254 L p
1 g
F P
s
P
p
.002 w
.4497 .5114 m .46143 .51254 L .46775 .54415 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55268 .36962 m .51473 .34548 L .52899 .3173 L p
1 g
F P
s
P
p
.002 w
.52899 .3173 m .57399 .34586 L .55268 .36962 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46614 .36846 m .43238 .37143 L .42848 .33891 L p
1 g
F P
s
P
p
.002 w
.42848 .33891 m .47166 .33489 L .46614 .36846 L p
1 g
F P
s
P
p
.002 w
.59662 .4462 m .58106 .40456 L .60759 .38729 L p
1 g
F P
s
P
p
.002 w
.57399 .34586 m .60759 .38729 L .58106 .40456 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59662 .4462 m .5977 .48967 L .56477 .4894 L p
1 g
F P
s
P
p
.002 w
.58106 .40456 m .55268 .36962 L .57399 .34586 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42765 .45487 m .42258 .46516 L .3918 .4516 L p
1 g
F P
s
P
p
.002 w
.3918 .4516 m .40159 .43136 L .42765 .45487 L p
1 g
F P
s
P
p
.002 w
.46143 .51254 m .47271 .50986 L .48984 .53903 L p
1 g
F P
s
P
p
.002 w
.50877 .52692 m .48984 .53903 L .47271 .50986 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.43845 .40632 m .4177 .41568 L .40224 .38526 L p
1 g
F P
s
P
p
.002 w
.40224 .38526 m .43238 .37143 L .43845 .40632 L p
1 g
F P
s
P
p
.002 w
.50877 .52692 m .52244 .50905 L .55458 .52103 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49974 .37684 m .46614 .36846 L .47166 .33489 L p
1 g
F P
s
P
p
.002 w
.47166 .33489 m .51473 .34548 L .49974 .37684 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43591 .44694 m .42765 .45487 L .40159 .43136 L p
1 g
F P
s
P
p
.002 w
.40159 .43136 m .4177 .41568 L .43591 .44694 L p
1 g
F P
s
P
p
.002 w
.56477 .4894 m .56376 .45544 L .59662 .4462 L p
1 g
F P
s
P
p
.002 w
.58106 .40456 m .59662 .4462 L .56376 .45544 L p
1 g
F P
s
P
p
.002 w
.4298 .49856 m .42374 .48824 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.47271 .50986 m .48233 .50362 L .50877 .52692 L p
1 g
F P
s
P
p
.002 w
.52244 .50905 m .50877 .52692 L .48233 .50362 L p
1 g
F P
s
P
p
.002 w
.42374 .48824 m .42124 .4767 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42124 .4767 m .42258 .46516 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.4616 .40441 m .43845 .40632 L .43238 .37143 L p
1 g
F P
s
P
p
.002 w
.43238 .37143 m .46614 .36846 L .4616 .40441 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52933 .39572 m .49974 .37684 L .51473 .34548 L p
1 g
F P
s
P
p
.002 w
.51473 .34548 m .55268 .36962 L .52933 .39572 L p
1 g
F P
s
P
p
.002 w
.56376 .45544 m .55151 .42296 L .58106 .40456 L p
1 g
F P
s
P
p
.002 w
.55268 .36962 m .58106 .40456 L .55151 .42296 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.42258 .46516 m .42765 .45487 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.44649 .44225 m .43591 .44694 L .4177 .41568 L p
1 g
F P
s
P
p
.002 w
.4177 .41568 m .43845 .40632 L .44649 .44225 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.48233 .50362 m .48922 .49447 L .52244 .50905 L p
1 g
F P
s
P
p
.002 w
.5293 .48729 m .52244 .50905 L .48922 .49447 L p
1 g
F P
s
P
p
.002 w
.55151 .42296 m .52933 .39572 L .55268 .36962 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.42765 .45487 m .43591 .44694 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.48459 .41022 m .4616 .40441 L .46614 .36846 L p
1 g
F P
s
P
p
.002 w
.46614 .36846 m .49974 .37684 L .48459 .41022 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55151 .42296 m .56376 .45544 L .52849 .46401 L p
1 g
F P
s
P
p
.002 w
.43591 .44694 m .44649 .44225 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.45825 .44135 m .44649 .44225 L .43845 .40632 L p
1 g
F P
s
P
p
.002 w
.43845 .40632 m .4616 .40441 L .45825 .44135 L p
1 g
F P
s
P
p
.002 w
.48922 .49447 m .49263 .48338 L .5293 .48729 L p
1 g
F P
s
P
p
.002 w
.46989 .44434 m .48013 .45091 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.45825 .44135 m .46989 .44434 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.44649 .44225 m .45825 .44135 L .4562 .47783 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.004 w
.45479 .47936 m
.4562 .47783 L
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50483 .42317 m .48459 .41022 L .49974 .37684 L p
1 g
F P
s
P
p
.002 w
.49974 .37684 m .52933 .39572 L .50483 .42317 L p
1 g
F P
s
P
p
.002 w
.52849 .46401 m .52003 .4418 L .55151 .42296 L p
1 g
F P
s
P
p
.002 w
.52933 .39572 m .55151 .42296 L .52003 .4418 L p
1 g
F P
s
P
p
.002 w
.46989 .44434 m .45825 .44135 L .4616 .40441 L p
1 g
F P
s
P
p
.002 w
.4616 .40441 m .48459 .41022 L .46989 .44434 L p
1 g
F P
s
P
p
.002 w
.52003 .4418 m .50483 .42317 L .52933 .39572 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.48013 .45091 m .46989 .44434 L .48459 .41022 L p
1 g
F P
s
P
p
.002 w
.48784 .46033 m .48013 .45091 L .50483 .42317 L p
1 g
F P
s
P
p
.002 w
.50483 .42317 m .52003 .4418 L .48784 .46033 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.48459 .41022 m .50483 .42317 L .48013 .45091 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.42921 .507 m
.45479 .47936 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .38332 .70194 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .42921 .507 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.108527)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.108527)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50697 .43275 m .49777 .43099 L .48796 .45775 L p
1 g
F P
s
P
p
.002 w
.47185 .44864 m .48796 .45775 L .49777 .43099 L p
1 g
F P
s
P
p
.002 w
.49777 .43099 m .48962 .42638 L .47185 .44864 L p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .49777 .43099 L .50697 .43275 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .48962 .42638 L .49777 .43099 L closepath p
1 g
F P
s
P
p
.002 w
.48796 .45775 m .50615 .46123 L .50697 .43275 L p
1 g
F P
s
P
p
.002 w
.51624 .43146 m .50697 .43275 L .50615 .46123 L p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .50697 .43275 L .51624 .43146 L closepath p
1 g
F P
s
P
p
.002 w
.45953 .43486 m .47185 .44864 L .48962 .42638 L p
1 g
F P
s
P
p
.002 w
.48962 .42638 m .4834 .4194 L .45953 .43486 L p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .4834 .4194 L .48962 .42638 L closepath p
1 g
F P
s
P
p
.002 w
.50615 .46123 m .52447 .45871 L .51624 .43146 L p
1 g
F P
s
P
p
.002 w
.52457 .42726 m .51624 .43146 L .52447 .45871 L p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .51624 .43146 L .52457 .42726 L closepath p
1 g
F P
s
P
p
.002 w
.45234 .41787 m .45953 .43486 L .4834 .4194 L p
1 g
F P
s
P
p
.002 w
.4834 .4194 m .47978 .4108 L .45234 .41787 L p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .47978 .4108 L .4834 .4194 L closepath p
1 g
F P
s
P
p
.002 w
.52447 .45871 m .54098 .45043 L .52457 .42726 L p
1 g
F P
s
P
p
.002 w
.53108 .42059 m .52457 .42726 L .54098 .45043 L p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .52457 .42726 L .53108 .42059 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .53108 .42059 L .53504 .41217 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .53504 .41217 L .53603 .40291 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .53603 .40291 L .53392 .39381 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .53392 .39381 L .52895 .38586 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .52895 .38586 L .52164 .37993 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .52164 .37993 L .51279 .37668 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .51279 .37668 L .50337 .37646 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .50337 .37646 L .49442 .37928 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .49442 .37928 L .48689 .38485 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .48689 .38485 L .48162 .39254 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .48162 .39254 L .47916 .40151 L closepath p
1 g
F P
s
P
p
.002 w
.50762 .40423 m .47916 .40151 L .47978 .4108 L closepath p
1 g
F P
s
P
p
.002 w
.45107 .39949 m .45234 .41787 L .47978 .4108 L p
1 g
F P
s
P
p
.002 w
.47978 .4108 m .47916 .40151 L .45107 .39949 L p
1 g
F P
s
P
p
.002 w
.50615 .46123 m .48796 .45775 L .47839 .48403 L p
1 g
F P
s
P
p
.002 w
.45464 .47062 m .47839 .48403 L .48796 .45775 L p
1 g
F P
s
P
p
.002 w
.48796 .45775 m .47185 .44864 L .45464 .47062 L p
1 g
F P
s
P
p
.002 w
.47839 .48403 m .50517 .48916 L .50615 .46123 L p
1 g
F P
s
P
p
.002 w
.52447 .45871 m .50615 .46123 L .50517 .48916 L p
1 g
F P
s
P
p
.002 w
.54098 .45043 m .55388 .43727 L .53108 .42059 L p
1 g
F P
s
P
p
.002 w
.53504 .41217 m .53108 .42059 L .55388 .43727 L p
1 g
F P
s
P
p
.002 w
.43646 .45034 m .45464 .47062 L .47185 .44864 L p
1 g
F P
s
P
p
.002 w
.47185 .44864 m .45953 .43486 L .43646 .45034 L p
1 g
F P
s
P
p
.002 w
.45588 .38168 m .45107 .39949 L .47916 .40151 L p
1 g
F P
s
P
p
.002 w
.47916 .40151 m .48162 .39254 L .45588 .38168 L p
1 g
F P
s
P
p
.002 w
.50517 .48916 m .53218 .48547 L .52447 .45871 L p
1 g
F P
s
P
p
.002 w
.54098 .45043 m .52447 .45871 L .53218 .48547 L p
1 g
F P
s
P
p
.002 w
.55388 .43727 m .56178 .42061 L .53504 .41217 L p
1 g
F P
s
P
p
.002 w
.53603 .40291 m .53504 .41217 L .56178 .42061 L p
1 g
F P
s
P
p
.002 w
.4258 .42532 m .43646 .45034 L .45953 .43486 L p
1 g
F P
s
P
p
.002 w
.45953 .43486 m .45234 .41787 L .4258 .42532 L p
1 g
F P
s
P
p
.002 w
.4663 .3664 m .45588 .38168 L .48162 .39254 L p
1 g
F P
s
P
p
.002 w
.48162 .39254 m .48689 .38485 L .4663 .3664 L p
1 g
F P
s
P
p
.002 w
.56178 .42061 m .56379 .40225 L .53603 .40291 L p
1 g
F P
s
P
p
.002 w
.53392 .39381 m .53603 .40291 L .56379 .40225 L p
1 g
F P
s
P
p
.002 w
.53218 .48547 m .55653 .47332 L .54098 .45043 L p
1 g
F P
s
P
p
.002 w
.55388 .43727 m .54098 .45043 L .55653 .47332 L p
1 g
F P
s
P
p
.002 w
.48121 .35532 m .4663 .3664 L .48689 .38485 L p
1 g
F P
s
P
p
.002 w
.48689 .38485 m .49442 .37928 L .48121 .35532 L p
1 g
F P
s
P
p
.002 w
.42384 .39819 m .4258 .42532 L .45234 .41787 L p
1 g
F P
s
P
p
.002 w
.45234 .41787 m .45107 .39949 L .42384 .39819 L p
1 g
F P
s
P
p
.002 w
.56379 .40225 m .55966 .38418 L .53392 .39381 L p
1 g
F P
s
P
p
.002 w
.52895 .38586 m .53392 .39381 L .55966 .38418 L p
1 g
F P
s
P
p
.002 w
.499 .34967 m .48121 .35532 L .49442 .37928 L p
1 g
F P
s
P
p
.002 w
.49442 .37928 m .50337 .37646 L .499 .34967 L p
1 g
F P
s
P
p
.002 w
.55966 .38418 m .54981 .36837 L .52895 .38586 L p
1 g
F P
s
P
p
.002 w
.52164 .37993 m .52895 .38586 L .54981 .36837 L p
1 g
F P
s
P
p
.002 w
.51771 .35011 m .499 .34967 L .50337 .37646 L p
1 g
F P
s
P
p
.002 w
.50337 .37646 m .51279 .37668 L .51771 .35011 L p
1 g
F P
s
P
p
.002 w
.55653 .47332 m .57562 .45395 L .55388 .43727 L p
1 g
F P
s
P
p
.002 w
.56178 .42061 m .55388 .43727 L .57562 .45395 L p
1 g
F P
s
P
p
.002 w
.54981 .36837 m .5353 .35658 L .52164 .37993 L p
1 g
F P
s
P
p
.002 w
.51279 .37668 m .52164 .37993 L .5353 .35658 L p
1 g
F P
s
P
p
.002 w
.5353 .35658 m .51771 .35011 L .51279 .37668 L p
1 g
F P
s
P
p
.002 w
.50517 .48916 m .47839 .48403 L .46922 .50933 L p
1 g
F P
s
P
p
.002 w
.43832 .49191 m .46922 .50933 L .47839 .48403 L p
1 g
F P
s
P
p
.002 w
.47839 .48403 m .45464 .47062 L .43832 .49191 L p
1 g
F P
s
P
p
.002 w
.43088 .37188 m .42384 .39819 L .45107 .39949 L p
1 g
F P
s
P
p
.002 w
.45107 .39949 m .45588 .38168 L .43088 .37188 L p
1 g
F P
s
P
p
.002 w
.46922 .50933 m .50406 .51601 L .50517 .48916 L p
1 g
F P
s
P
p
.002 w
.53218 .48547 m .50517 .48916 L .50406 .51601 L p
1 g
F P
s
P
p
.002 w
.41462 .46556 m .43832 .49191 L .45464 .47062 L p
1 g
F P
s
P
p
.002 w
.45464 .47062 m .43646 .45034 L .41462 .46556 L p
1 g
F P
s
P
p
.002 w
.57562 .45395 m .58735 .4294 L .56178 .42061 L p
1 g
F P
s
P
p
.002 w
.56379 .40225 m .56178 .42061 L .58735 .4294 L p
1 g
F P
s
P
p
.002 w
.50406 .51601 m .5392 .51126 L .53218 .48547 L p
1 g
F P
s
P
p
.002 w
.55653 .47332 m .53218 .48547 L .5392 .51126 L p
1 g
F P
s
P
p
.002 w
.44622 .34925 m .43088 .37188 L .45588 .38168 L p
1 g
F P
s
P
p
.002 w
.45588 .38168 m .4663 .3664 L .44622 .34925 L p
1 g
F P
s
P
p
.002 w
.40066 .43301 m .41462 .46556 L .43646 .45034 L p
1 g
F P
s
P
p
.002 w
.43646 .45034 m .4258 .42532 L .40066 .43301 L p
1 g
F P
s
P
p
.002 w
.58735 .4294 m .5904 .40228 L .56379 .40225 L p
1 g
F P
s
P
p
.002 w
.55966 .38418 m .56379 .40225 L .5904 .40228 L p
1 g
F P
s
P
p
.002 w
.5392 .51126 m .57092 .4955 L .55653 .47332 L p
1 g
F P
s
P
p
.002 w
.57562 .45395 m .55653 .47332 L .57092 .4955 L p
1 g
F P
s
P
p
.002 w
.46824 .3328 m .44622 .34925 L .4663 .3664 L p
1 g
F P
s
P
p
.002 w
.4663 .3664 m .48121 .35532 L .46824 .3328 L p
1 g
F P
s
P
p
.002 w
.39803 .39768 m .40066 .43301 L .4258 .42532 L p
1 g
F P
s
P
p
.002 w
.4258 .42532 m .42384 .39819 L .39803 .39768 L p
1 g
F P
s
P
p
.002 w
.5904 .40228 m .58435 .37553 L .55966 .38418 L p
1 g
F P
s
P
p
.002 w
.54981 .36837 m .55966 .38418 L .58435 .37553 L p
1 g
F P
s
P
p
.002 w
.49456 .32441 m .46824 .3328 L .48121 .35532 L p
1 g
F P
s
P
p
.002 w
.48121 .35532 m .499 .34967 L .49456 .32441 L p
1 g
F P
s
P
p
.002 w
.57092 .4955 m .59585 .47034 L .57562 .45395 L p
1 g
F P
s
P
p
.002 w
.58735 .4294 m .57562 .45395 L .59585 .47034 L p
1 g
F P
s
P
p
.002 w
.58435 .37553 m .56981 .35211 L .54981 .36837 L p
1 g
F P
s
P
p
.002 w
.5353 .35658 m .54981 .36837 L .56981 .35211 L p
1 g
F P
s
P
p
.002 w
.52229 .32503 m .49456 .32441 L .499 .34967 L p
1 g
F P
s
P
p
.002 w
.499 .34967 m .51771 .35011 L .52229 .32503 L p
1 g
F P
s
P
p
.002 w
.56981 .35211 m .54833 .33462 L .5353 .35658 L p
1 g
F P
s
P
p
.002 w
.51771 .35011 m .5353 .35658 L .54833 .33462 L p
1 g
F P
s
P
p
.002 w
.54833 .33462 m .52229 .32503 L .51771 .35011 L p
1 g
F P
s
P
p
.002 w
.40711 .36334 m .39803 .39768 L .42384 .39819 L p
1 g
F P
s
P
p
.002 w
.42384 .39819 m .43088 .37188 L .40711 .36334 L p
1 g
F P
s
P
p
.002 w
.50406 .51601 m .46922 .50933 L .46064 .53316 L p
1 g
F P
s
P
p
.002 w
.4232 .51209 m .46064 .53316 L .46922 .50933 L p
1 g
F P
s
P
p
.002 w
.46922 .50933 m .43832 .49191 L .4232 .51209 L p
1 g
F P
s
P
p
.002 w
.46064 .53316 m .50283 .54127 L .50406 .51601 L p
1 g
F P
s
P
p
.002 w
.5392 .51126 m .50406 .51601 L .50283 .54127 L p
1 g
F P
s
P
p
.002 w
.39445 .48021 m .4232 .51209 L .43832 .49191 L p
1 g
F P
s
P
p
.002 w
.43832 .49191 m .41462 .46556 L .39445 .48021 L p
1 g
F P
s
P
p
.002 w
.59585 .47034 m .61123 .43838 L .58735 .4294 L p
1 g
F P
s
P
p
.002 w
.5904 .40228 m .58735 .4294 L .61123 .43838 L p
1 g
F P
s
P
p
.002 w
.50283 .54127 m .54539 .53555 L .5392 .51126 L p
1 g
F P
s
P
p
.002 w
.57092 .4955 m .5392 .51126 L .54539 .53555 L p
1 g
F P
s
P
p
.002 w
.42705 .33375 m .40711 .36334 L .43088 .37188 L p
1 g
F P
s
P
p
.002 w
.43088 .37188 m .44622 .34925 L .42705 .33375 L p
1 g
F P
s
P
p
.002 w
.37746 .4408 m .39445 .48021 L .41462 .46556 L p
1 g
F P
s
P
p
.002 w
.41462 .46556 m .40066 .43301 L .37746 .4408 L p
1 g
F P
s
P
p
.002 w
.61123 .43838 m .6153 .40301 L .5904 .40228 L p
1 g
F P
s
P
p
.002 w
.58435 .37553 m .5904 .40228 L .6153 .40301 L p
1 g
F P
s
P
p
.002 w
.54539 .53555 m .58386 .51653 L .57092 .4955 L p
1 g
F P
s
P
p
.002 w
.59585 .47034 m .57092 .4955 L .58386 .51653 L p
1 g
F P
s
P
p
.002 w
.45577 .31222 m .42705 .33375 L .44622 .34925 L p
1 g
F P
s
P
p
.002 w
.44622 .34925 m .46824 .3328 L .45577 .31222 L p
1 g
F P
s
P
p
.002 w
.37416 .39797 m .37746 .4408 L .40066 .43301 L p
1 g
F P
s
P
p
.002 w
.40066 .43301 m .39803 .39768 L .37416 .39797 L p
1 g
F P
s
P
p
.002 w
.6153 .40301 m .60748 .36807 L .58435 .37553 L p
1 g
F P
s
P
p
.002 w
.56981 .35211 m .58435 .37553 L .60748 .36807 L p
1 g
F P
s
P
p
.002 w
.49016 .30119 m .45577 .31222 L .46824 .3328 L p
1 g
F P
s
P
p
.002 w
.46824 .3328 m .49456 .32441 L .49016 .30119 L p
1 g
F P
s
P
p
.002 w
.58386 .51653 m .61414 .4861 L .59585 .47034 L p
1 g
F P
s
P
p
.002 w
.61123 .43838 m .59585 .47034 L .61414 .4861 L p
1 g
F P
s
P
p
.002 w
.60748 .36807 m .58853 .33743 L .56981 .35211 L p
1 g
F P
s
P
p
.002 w
.54833 .33462 m .56981 .35211 L .58853 .33743 L p
1 g
F P
s
P
p
.002 w
.52642 .30199 m .49016 .30119 L .49456 .32441 L p
1 g
F P
s
P
p
.002 w
.49456 .32441 m .52229 .32503 L .52642 .30199 L p
1 g
F P
s
P
p
.002 w
.38508 .35628 m .37416 .39797 L .39803 .39768 L p
1 g
F P
s
P
p
.002 w
.39803 .39768 m .40711 .36334 L .38508 .35628 L p
1 g
F P
s
P
p
.002 w
.58853 .33743 m .56047 .31454 L .54833 .33462 L p
1 g
F P
s
P
p
.002 w
.52229 .32503 m .54833 .33462 L .56047 .31454 L p
1 g
F P
s
P
p
.002 w
.56047 .31454 m .52642 .30199 L .52229 .32503 L p
1 g
F P
s
P
p
.002 w
.50283 .54127 m .46064 .53316 L .45283 .55501 L p
1 g
F P
s
P
p
.002 w
.40964 .53073 m .45283 .55501 L .46064 .53316 L p
1 g
F P
s
P
p
.002 w
.46064 .53316 m .4232 .51209 L .40964 .53073 L p
1 g
F P
s
P
p
.002 w
.45283 .55501 m .50149 .56437 L .50283 .54127 L p
1 g
F P
s
P
p
.002 w
.54539 .53555 m .50283 .54127 L .50149 .56437 L p
1 g
F P
s
P
p
.002 w
.61414 .4861 m .63289 .44738 L .61123 .43838 L p
1 g
F P
s
P
p
.002 w
.6153 .40301 m .61123 .43838 L .63289 .44738 L p
1 g
F P
s
P
p
.002 w
.37642 .49399 m .40964 .53073 L .4232 .51209 L p
1 g
F P
s
P
p
.002 w
.4232 .51209 m .39445 .48021 L .37642 .49399 L p
1 g
F P
s
P
p
.002 w
.50149 .56437 m .55059 .55783 L .54539 .53555 L p
1 g
F P
s
P
p
.002 w
.58386 .51653 m .54539 .53555 L .55059 .55783 L p
1 g
F P
s
P
p
.002 w
.40921 .32029 m .38508 .35628 L .40711 .36334 L p
1 g
F P
s
P
p
.002 w
.40711 .36334 m .42705 .33375 L .40921 .32029 L p
1 g
F P
s
P
p
.002 w
.35672 .44855 m .37642 .49399 L .39445 .48021 L p
1 g
F P
s
P
p
.002 w
.39445 .48021 m .37746 .4408 L .35672 .44855 L p
1 g
F P
s
P
p
.002 w
.63289 .44738 m .63793 .40445 L .6153 .40301 L p
1 g
F P
s
P
p
.002 w
.60748 .36807 m .6153 .40301 L .63793 .40445 L p
1 g
F P
s
P
p
.002 w
.55059 .55783 m .59502 .53595 L .58386 .51653 L p
1 g
F P
s
P
p
.002 w
.61414 .4861 m .58386 .51653 L .59502 .53595 L p
1 g
F P
s
P
p
.002 w
.44408 .29405 m .40921 .32029 L .42705 .33375 L p
1 g
F P
s
P
p
.002 w
.42705 .33375 m .45577 .31222 L .44408 .29405 L p
1 g
F P
s
P
p
.002 w
.35281 .3991 m .35672 .44855 L .37746 .4408 L p
1 g
F P
s
P
p
.002 w
.37746 .4408 m .37416 .39797 L .35281 .3991 L p
1 g
F P
s
P
p
.002 w
.63793 .40445 m .62853 .36198 L .60748 .36807 L p
1 g
F P
s
P
p
.002 w
.58853 .33743 m .60748 .36807 L .62853 .36198 L p
1 g
F P
s
P
p
.002 w
.48588 .28059 m .44408 .29405 L .45577 .31222 L p
1 g
F P
s
P
p
.002 w
.45577 .31222 m .49016 .30119 L .48588 .28059 L p
1 g
F P
s
P
p
.002 w
.59502 .53595 m .63005 .50089 L .61414 .4861 L p
1 g
F P
s
P
p
.002 w
.63289 .44738 m .61414 .4861 L .63005 .50089 L p
1 g
F P
s
P
p
.002 w
.62853 .36198 m .60554 .32469 L .58853 .33743 L p
1 g
F P
s
P
p
.002 w
.56047 .31454 m .58853 .33743 L .60554 .32469 L p
1 g
F P
s
P
p
.002 w
.52999 .28153 m .48588 .28059 L .49016 .30119 L p
1 g
F P
s
P
p
.002 w
.49016 .30119 m .52642 .30199 L .52999 .28153 L p
1 g
F P
s
P
p
.002 w
.36532 .3509 m .35281 .3991 L .37416 .39797 L p
1 g
F P
s
P
p
.002 w
.37416 .39797 m .38508 .35628 L .36532 .3509 L p
1 g
F P
s
P
p
.002 w
.60554 .32469 m .57144 .29681 L .56047 .31454 L p
1 g
F P
s
P
p
.002 w
.52642 .30199 m .56047 .31454 L .57144 .29681 L p
1 g
F P
s
P
p
.002 w
.57144 .29681 m .52999 .28153 L .52642 .30199 L p
1 g
F P
s
P
p
.002 w
.50149 .56437 m .45283 .55501 L .44599 .57434 L p
1 g
F P
s
P
p
.002 w
.39797 .54738 m .44599 .57434 L .45283 .55501 L p
1 g
F P
s
P
p
.002 w
.45283 .55501 m .40964 .53073 L .39797 .54738 L p
1 g
F P
s
P
p
.002 w
.44599 .57434 m .50007 .58476 L .50149 .56437 L p
1 g
F P
s
P
p
.002 w
.55059 .55783 m .50149 .56437 L .50007 .58476 L p
1 g
F P
s
P
p
.002 w
.63005 .50089 m .65181 .45621 L .63289 .44738 L p
1 g
F P
s
P
p
.002 w
.63793 .40445 m .63289 .44738 L .65181 .45621 L p
1 g
F P
s
P
p
.002 w
.36099 .50658 m .39797 .54738 L .40964 .53073 L p
1 g
F P
s
P
p
.002 w
.40964 .53073 m .37642 .49399 L .36099 .50658 L p
1 g
F P
s
P
p
.002 w
.39314 .30923 m .36532 .3509 L .38508 .35628 L p
1 g
F P
s
P
p
.002 w
.38508 .35628 m .40921 .32029 L .39314 .30923 L p
1 g
F P
s
P
p
.002 w
.50007 .58476 m .55466 .57753 L .55059 .55783 L p
1 g
F P
s
P
p
.002 w
.59502 .53595 m .55059 .55783 L .55466 .57753 L p
1 g
F P
s
P
p
.002 w
.33901 .45608 m .36099 .50658 L .37642 .49399 L p
1 g
F P
s
P
p
.002 w
.37642 .49399 m .35672 .44855 L .33901 .45608 L p
1 g
F P
s
P
p
.002 w
.65181 .45621 m .65774 .4066 L .63793 .40445 L p
1 g
F P
s
P
p
.002 w
.62853 .36198 m .63793 .40445 L .65774 .4066 L p
1 g
F P
s
P
p
.002 w
.55466 .57753 m .6041 .55328 L .59502 .53595 L p
1 g
F P
s
P
p
.002 w
.63005 .50089 m .59502 .53595 L .6041 .55328 L p
1 g
F P
s
P
p
.002 w
.43343 .2788 m .39314 .30923 L .40921 .32029 L p
1 g
F P
s
P
p
.002 w
.40921 .32029 m .44408 .29405 L .43343 .2788 L p
1 g
F P
s
P
p
.002 w
.33455 .40107 m .33901 .45608 L .35672 .44855 L p
1 g
F P
s
P
p
.002 w
.35672 .44855 m .35281 .3991 L .33455 .40107 L p
1 g
F P
s
P
p
.002 w
.65774 .4066 m .64695 .35745 L .62853 .36198 L p
1 g
F P
s
P
p
.002 w
.60554 .32469 m .62853 .36198 L .64695 .35745 L p
1 g
F P
s
P
p
.002 w
.48183 .26317 m .43343 .2788 L .44408 .29405 L p
1 g
F P
s
P
p
.002 w
.44408 .29405 m .48588 .28059 L .48183 .26317 L p
1 g
F P
s
P
p
.002 w
.6041 .55328 m .64313 .51435 L .63005 .50089 L p
1 g
F P
s
P
p
.002 w
.65181 .45621 m .63005 .50089 L .64313 .51435 L p
1 g
F P
s
P
p
.002 w
.64695 .35745 m .6204 .31425 L .60554 .32469 L p
1 g
F P
s
P
p
.002 w
.57144 .29681 m .60554 .32469 L .6204 .31425 L p
1 g
F P
s
P
p
.002 w
.34837 .3474 m .33455 .40107 L .35281 .3991 L p
1 g
F P
s
P
p
.002 w
.35281 .3991 m .36532 .3509 L .34837 .3474 L p
1 g
F P
s
P
p
.002 w
.53292 .26423 m .48183 .26317 L .48588 .28059 L p
1 g
F P
s
P
p
.002 w
.48588 .28059 m .52999 .28153 L .53292 .26423 L p
1 g
F P
s
P
p
.002 w
.6204 .31425 m .58092 .28194 L .57144 .29681 L p
1 g
F P
s
P
p
.002 w
.52999 .28153 m .57144 .29681 L .58092 .28194 L p
1 g
F P
s
P
p
.002 w
.58092 .28194 m .53292 .26423 L .52999 .28153 L p
1 g
F P
s
P
p
.002 w
.50007 .58476 m .44599 .57434 L .44031 .59061 L p
1 g
F P
s
P
p
.002 w
.38854 .56157 m .44031 .59061 L .44599 .57434 L p
1 g
F P
s
P
p
.002 w
.44599 .57434 m .39797 .54738 L .38854 .56157 L p
1 g
F P
s
P
p
.002 w
.64313 .51435 m .66744 .46468 L .65181 .45621 L p
1 g
F P
s
P
p
.002 w
.65774 .4066 m .65181 .45621 L .66744 .46468 L p
1 g
F P
s
P
p
.002 w
.44031 .59061 m .49861 .60185 L .50007 .58476 L p
1 g
F P
s
P
p
.002 w
.55466 .57753 m .50007 .58476 L .49861 .60185 L p
1 g
F P
s
P
p
.002 w
.34863 .51763 m .38854 .56157 L .39797 .54738 L p
1 g
F P
s
P
p
.002 w
.39797 .54738 m .36099 .50658 L .34863 .51763 L p
1 g
F P
s
P
p
.002 w
.37929 .30094 m .34837 .3474 L .36532 .3509 L p
1 g
F P
s
P
p
.002 w
.36532 .3509 m .39314 .30923 L .37929 .30094 L p
1 g
F P
s
P
p
.002 w
.49861 .60185 m .55746 .5941 L .55466 .57753 L p
1 g
F P
s
P
p
.002 w
.6041 .55328 m .55466 .57753 L .55746 .5941 L p
1 g
F P
s
P
p
.002 w
.32487 .46321 m .34863 .51763 L .36099 .50658 L p
1 g
F P
s
P
p
.002 w
.36099 .50658 m .33901 .45608 L .32487 .46321 L p
1 g
F P
s
P
p
.002 w
.66744 .46468 m .67414 .40945 L .65774 .4066 L p
1 g
F P
s
P
p
.002 w
.64695 .35745 m .65774 .4066 L .67414 .40945 L p
1 g
F P
s
P
p
.002 w
.55746 .5941 m .61078 .56802 L .6041 .55328 L p
1 g
F P
s
P
p
.002 w
.64313 .51435 m .6041 .55328 L .61078 .56802 L p
1 g
F P
s
P
p
.002 w
.42415 .26697 m .37929 .30094 L .39314 .30923 L p
1 g
F P
s
P
p
.002 w
.39314 .30923 m .43343 .2788 L .42415 .26697 L p
1 g
F P
s
P
p
.002 w
.31997 .4039 m .32487 .46321 L .33901 .45608 L p
1 g
F P
s
P
p
.002 w
.33901 .45608 m .33455 .40107 L .31997 .4039 L p
1 g
F P
s
P
p
.002 w
.67414 .40945 m .66219 .35467 L .64695 .35745 L p
1 g
F P
s
P
p
.002 w
.6204 .31425 m .64695 .35745 L .66219 .35467 L p
1 g
F P
s
P
p
.002 w
.47809 .2495 m .42415 .26697 L .43343 .2788 L p
1 g
F P
s
P
p
.002 w
.43343 .2788 m .48183 .26317 L .47809 .2495 L p
1 g
F P
s
P
p
.002 w
.61078 .56802 m .65293 .52611 L .64313 .51435 L p
1 g
F P
s
P
p
.002 w
.66744 .46468 m .64313 .51435 L .65293 .52611 L p
1 g
F P
s
P
p
.002 w
.66219 .35467 m .63264 .30648 L .6204 .31425 L p
1 g
F P
s
P
p
.002 w
.58092 .28194 m .6204 .31425 L .63264 .30648 L p
1 g
F P
s
P
p
.002 w
.3348 .34597 m .31997 .4039 L .33455 .40107 L p
1 g
F P
s
P
p
.002 w
.33455 .40107 m .34837 .3474 L .3348 .34597 L p
1 g
F P
s
P
p
.002 w
.53509 .25066 m .47809 .2495 L .48183 .26317 L p
1 g
F P
s
P
p
.002 w
.48183 .26317 m .53292 .26423 L .53509 .25066 L p
1 g
F P
s
P
p
.002 w
.63264 .30648 m .58863 .27042 L .58092 .28194 L p
1 g
F P
s
P
p
.002 w
.53292 .26423 m .58092 .28194 L .58863 .27042 L p
1 g
F P
s
P
p
.002 w
.58863 .27042 m .53509 .25066 L .53292 .26423 L p
1 g
F P
s
P
p
.002 w
.49861 .60185 m .44031 .59061 L .436 .60328 L p
1 g
F P
s
P
p
.002 w
.3817 .57284 m .436 .60328 L .44031 .59061 L p
1 g
F P
s
P
p
.002 w
.44031 .59061 m .38854 .56157 L .3817 .57284 L p
1 g
F P
s
P
p
.002 w
.65293 .52611 m .67923 .47256 L .66744 .46468 L p
1 g
F P
s
P
p
.002 w
.67414 .40945 m .66744 .46468 L .67923 .47256 L p
1 g
F P
s
P
p
.002 w
.436 .60328 m .49712 .61507 L .49861 .60185 L p
1 g
F P
s
P
p
.002 w
.55746 .5941 m .49861 .60185 L .49712 .61507 L p
1 g
F P
s
P
p
.002 w
.33982 .5268 m .3817 .57284 L .38854 .56157 L p
1 g
F P
s
P
p
.002 w
.38854 .56157 m .34863 .51763 L .33982 .5268 L p
1 g
F P
s
P
p
.002 w
.36811 .29578 m .3348 .34597 L .34837 .3474 L p
1 g
F P
s
P
p
.002 w
.34837 .3474 m .37929 .30094 L .36811 .29578 L p
1 g
F P
s
P
p
.002 w
.49712 .61507 m .55884 .60698 L .55746 .5941 L p
1 g
F P
s
P
p
.002 w
.61078 .56802 m .55746 .5941 L .55884 .60698 L p
1 g
F P
s
P
p
.002 w
.31484 .46975 m .33982 .5268 L .34863 .51763 L p
1 g
F P
s
P
p
.002 w
.34863 .51763 m .32487 .46321 L .31484 .46975 L p
1 g
F P
s
P
p
.002 w
.67923 .47256 m .68654 .41297 L .67414 .40945 L p
1 g
F P
s
P
p
.002 w
.66219 .35467 m .67414 .40945 L .68654 .41297 L p
1 g
F P
s
P
p
.002 w
.55884 .60698 m .61478 .57968 L .61078 .56802 L p
1 g
F P
s
P
p
.002 w
.65293 .52611 m .61078 .56802 L .61478 .57968 L p
1 g
F P
s
P
p
.002 w
.41652 .25905 m .36811 .29578 L .37929 .30094 L p
1 g
F P
s
P
p
.002 w
.37929 .30094 m .42415 .26697 L .41652 .25905 L p
1 g
F P
s
P
p
.002 w
.30964 .40755 m .31484 .46975 L .32487 .46321 L p
1 g
F P
s
P
p
.002 w
.32487 .46321 m .31997 .4039 L .30964 .40755 L p
1 g
F P
s
P
p
.002 w
.68654 .41297 m .6737 .35382 L .66219 .35467 L p
1 g
F P
s
P
p
.002 w
.63264 .30648 m .66219 .35467 L .6737 .35382 L p
1 g
F P
s
P
p
.002 w
.4748 .24014 m .41652 .25905 L .42415 .26697 L p
1 g
F P
s
P
p
.002 w
.42415 .26697 m .47809 .2495 L .4748 .24014 L p
1 g
F P
s
P
p
.002 w
.61478 .57968 m .65903 .53577 L .65293 .52611 L p
1 g
F P
s
P
p
.002 w
.67923 .47256 m .65293 .52611 L .65903 .53577 L p
1 g
F P
s
P
p
.002 w
.6737 .35382 m .64182 .30173 L .63264 .30648 L p
1 g
F P
s
P
p
.002 w
.58863 .27042 m .63264 .30648 L .64182 .30173 L p
1 g
F P
s
P
p
.002 w
.32513 .34677 m .30964 .40755 L .31997 .4039 L p
1 g
F P
s
P
p
.002 w
.31997 .4039 m .3348 .34597 L .32513 .34677 L p
1 g
F P
s
P
p
.002 w
.5364 .24138 m .4748 .24014 L .47809 .2495 L p
1 g
F P
s
P
p
.002 w
.47809 .2495 m .53509 .25066 L .5364 .24138 L p
1 g
F P
s
P
p
.002 w
.64182 .30173 m .59428 .26274 L .58863 .27042 L p
1 g
F P
s
P
p
.002 w
.53509 .25066 m .58863 .27042 L .59428 .26274 L p
1 g
F P
s
P
p
.002 w
.59428 .26274 m .5364 .24138 L .53509 .25066 L p
1 g
F P
s
P
p
.002 w
.65903 .53577 m .68667 .47963 L .67923 .47256 L p
1 g
F P
s
P
p
.002 w
.68654 .41297 m .67923 .47256 L .68667 .47963 L p
1 g
F P
s
P
p
.002 w
.49712 .61507 m .436 .60328 L .43323 .6118 L p
1 g
F P
s
P
p
.002 w
.37777 .58073 m .43323 .6118 L .436 .60328 L p
1 g
F P
s
P
p
.002 w
.436 .60328 m .3817 .57284 L .37777 .58073 L p
1 g
F P
s
P
p
.002 w
.43323 .6118 m .49565 .62385 L .49712 .61507 L p
1 g
F P
s
P
p
.002 w
.55884 .60698 m .49712 .61507 L .49565 .62385 L p
1 g
F P
s
P
p
.002 w
.33499 .53373 m .37777 .58073 L .3817 .57284 L p
1 g
F P
s
P
p
.002 w
.3817 .57284 m .33982 .5268 L .33499 .53373 L p
1 g
F P
s
P
p
.002 w
.36005 .29407 m .32513 .34677 L .3348 .34597 L p
1 g
F P
s
P
p
.002 w
.3348 .34597 m .36811 .29578 L .36005 .29407 L p
1 g
F P
s
P
p
.002 w
.49565 .62385 m .55868 .61561 L .55884 .60698 L p
1 g
F P
s
P
p
.002 w
.61478 .57968 m .55884 .60698 L .55868 .61561 L p
1 g
F P
s
P
p
.002 w
.30944 .4755 m .33499 .53373 L .33982 .5268 L p
1 g
F P
s
P
p
.002 w
.33982 .5268 m .31484 .46975 L .30944 .4755 L p
1 g
F P
s
P
p
.002 w
.68667 .47963 m .6944 .41712 L .68654 .41297 L p
1 g
F P
s
P
p
.002 w
.6737 .35382 m .68654 .41297 L .6944 .41712 L p
1 g
F P
s
P
p
.002 w
.55868 .61561 m .61582 .58777 L .61478 .57968 L p
1 g
F P
s
P
p
.002 w
.65903 .53577 m .61478 .57968 L .61582 .58777 L p
1 g
F P
s
P
p
.002 w
.41085 .25549 m .36005 .29407 L .36811 .29578 L p
1 g
F P
s
P
p
.002 w
.36811 .29578 m .41652 .25905 L .41085 .25549 L p
1 g
F P
s
P
p
.002 w
.30409 .412 m .30944 .4755 L .31484 .46975 L p
1 g
F P
s
P
p
.002 w
.31484 .46975 m .30964 .40755 L .30409 .412 L p
1 g
F P
s
P
p
.002 w
.6944 .41712 m .68096 .35502 L .6737 .35382 L p
1 g
F P
s
P
p
.002 w
.64182 .30173 m .6737 .35382 L .68096 .35502 L p
1 g
F P
s
P
p
.002 w
.47205 .2356 m .41085 .25549 L .41652 .25905 L p
1 g
F P
s
P
p
.002 w
.41652 .25905 m .4748 .24014 L .47205 .2356 L p
1 g
F P
s
P
p
.002 w
.61582 .58777 m .66102 .54296 L .65903 .53577 L p
1 g
F P
s
P
p
.002 w
.68667 .47963 m .65903 .53577 L .66102 .54296 L p
1 g
F P
s
P
p
.002 w
.68096 .35502 m .6475 .30031 L .64182 .30173 L p
1 g
F P
s
P
p
.002 w
.59428 .26274 m .64182 .30173 L .6475 .30031 L p
1 g
F P
s
P
p
.002 w
.31989 .34992 m .30409 .412 L .30964 .40755 L p
1 g
F P
s
P
p
.002 w
.30964 .40755 m .32513 .34677 L .31989 .34992 L p
1 g
F P
s
P
p
.002 w
.53676 .2369 m .47205 .2356 L .4748 .24014 L p
1 g
F P
s
P
p
.002 w
.4748 .24014 m .5364 .24138 L .53676 .2369 L p
1 g
F P
s
P
p
.002 w
.6475 .30031 m .59757 .25934 L .59428 .26274 L p
1 g
F P
s
P
p
.002 w
.5364 .24138 m .59428 .26274 L .59757 .25934 L p
1 g
F P
s
P
p
.002 w
.59757 .25934 m .53676 .2369 L .5364 .24138 L p
1 g
F P
s
P
p
.002 w
.66102 .54296 m .68928 .48566 L .68667 .47963 L p
1 g
F P
s
P
p
.002 w
.6944 .41712 m .68667 .47963 L .68928 .48566 L p
1 g
F P
s
P
p
.002 w
.49565 .62385 m .43323 .6118 L .43218 .61569 L p
1 g
F P
s
P
p
.002 w
.37705 .58481 m .43218 .61569 L .43323 .6118 L p
1 g
F P
s
P
p
.002 w
.43323 .6118 m .37777 .58073 L .37705 .58481 L p
1 g
F P
s
P
p
.002 w
.43218 .61569 m .49424 .62768 L .49565 .62385 L p
1 g
F P
s
P
p
.002 w
.55868 .61561 m .49565 .62385 L .49424 .62768 L p
1 g
F P
s
P
p
.002 w
.33452 .53811 m .37705 .58481 L .37777 .58073 L p
1 g
F P
s
P
p
.002 w
.37777 .58073 m .33499 .53373 L .33452 .53811 L p
1 g
F P
s
P
p
.002 w
.35553 .29609 m .31989 .34992 L .32513 .34677 L p
1 g
F P
s
P
p
.002 w
.32513 .34677 m .36005 .29407 L .35553 .29609 L p
1 g
F P
s
P
p
.002 w
.49424 .62768 m .55689 .6195 L .55868 .61561 L p
1 g
F P
s
P
p
.002 w
.61582 .58777 m .55868 .61561 L .55689 .6195 L p
1 g
F P
s
P
p
.002 w
.30912 .48025 m .33452 .53811 L .33499 .53373 L p
1 g
F P
s
P
p
.002 w
.33499 .53373 m .30944 .4755 L .30912 .48025 L p
1 g
F P
s
P
p
.002 w
.68928 .48566 m .6972 .42182 L .6944 .41712 L p
1 g
F P
s
P
p
.002 w
.68096 .35502 m .6944 .41712 L .6972 .42182 L p
1 g
F P
s
P
p
.002 w
.55689 .6195 m .61368 .59184 L .61582 .58777 L p
1 g
F P
s
P
p
.002 w
.66102 .54296 m .61582 .58777 L .61368 .59184 L p
1 g
F P
s
P
p
.002 w
.40743 .25667 m .35553 .29609 L .36005 .29407 L p
1 g
F P
s
P
p
.002 w
.36005 .29407 m .41085 .25549 L .40743 .25667 L p
1 g
F P
s
P
p
.004 w
.33172 .60954 m
.35476 .58503 L
s
P
p
.004 w
.30439 .63862 m
.33172 .60954 L
s
P
p
.002 w
.3038 .41716 m .30912 .48025 L .30944 .4755 L p
1 g
F P
s
P
p
.002 w
.30944 .4755 m .30409 .412 L .3038 .41716 L p
1 g
F P
s
P
p
.002 w
.6972 .42182 m .68348 .35838 L .68096 .35502 L p
1 g
F P
s
P
p
.002 w
.6475 .30031 m .68096 .35502 L .68348 .35838 L p
1 g
F P
s
P
p
.002 w
.61368 .59184 m .6586 .54732 L .66102 .54296 L p
1 g
F P
s
P
p
.002 w
.68928 .48566 m .66102 .54296 L .6586 .54732 L p
1 g
F P
s
P
p
.002 w
.46997 .23635 m .40743 .25667 L .41085 .25549 L p
1 g
F P
s
P
p
.002 w
.41085 .25549 m .47205 .2356 L .46997 .23635 L p
1 g
F P
s
P
p
.002 w
.68348 .35838 m .64929 .30249 L .6475 .30031 L p
1 g
F P
s
P
p
.002 w
.59757 .25934 m .6475 .30031 L .64929 .30249 L p
1 g
F P
s
P
p
.002 w
.3195 .35549 m .3038 .41716 L .30409 .412 L p
1 g
F P
s
P
p
.002 w
.30409 .412 m .31989 .34992 L .3195 .35549 L p
1 g
F P
s
P
p
.002 w
.53611 .23768 m .46997 .23635 L .47205 .2356 L p
1 g
F P
s
P
p
.002 w
.47205 .2356 m .53676 .2369 L .53611 .23768 L p
1 g
F P
s
P
p
.002 w
.64929 .30249 m .59826 .26061 L .59757 .25934 L p
1 g
F P
s
P
p
.002 w
.53676 .2369 m .59757 .25934 L .59826 .26061 L p
1 g
F P
s
P
p
.002 w
.59826 .26061 m .53611 .23768 L .53676 .2369 L p
1 g
F P
s
P
p
.002 w
.6586 .54732 m .68668 .49039 L .68928 .48566 L p
1 g
F P
s
P
p
.002 w
.6972 .42182 m .68928 .48566 L .68668 .49039 L p
1 g
F P
s
P
p
.002 w
.37977 .58472 m .43301 .61454 L .43218 .61569 L p
1 g
F P
s
P
p
.002 w
.43218 .61569 m .37705 .58481 L .37977 .58472 L p
1 g
F P
s
P
p
.002 w
.49424 .62768 m .43218 .61569 L .43301 .61454 L p
1 g
F P
s
P
p
.002 w
.43301 .61454 m .49292 .6261 L .49424 .62768 L p
1 g
F P
s
P
p
.002 w
.55689 .6195 m .49424 .62768 L .49292 .6261 L p
1 g
F P
s
P
p
.002 w
.33872 .53963 m .37977 .58472 L .37705 .58481 L p
1 g
F P
s
P
p
.002 w
.37705 .58481 m .33452 .53811 L .33872 .53963 L p
1 g
F P
s
P
p
.002 w
.35493 .30202 m .3195 .35549 L .31989 .34992 L p
1 g
F P
s
P
p
.002 w
.31989 .34992 m .35553 .29609 L .35493 .30202 L p
1 g
F P
s
P
p
.002 w
.49292 .6261 m .55341 .6182 L .55689 .6195 L p
1 g
F P
s
P
p
.002 w
.61368 .59184 m .55689 .6195 L .55341 .6182 L p
1 g
F P
s
P
p
.002 w
.31423 .48379 m .33872 .53963 L .33452 .53811 L p
1 g
F P
s
P
p
.002 w
.33452 .53811 m .30912 .48025 L .31423 .48379 L p
1 g
F P
s
P
p
.002 w
.68668 .49039 m .69452 .42698 L .6972 .42182 L p
1 g
F P
s
P
p
.002 w
.68348 .35838 m .6972 .42182 L .69452 .42698 L p
1 g
F P
s
P
p
.002 w
.55341 .6182 m .60821 .5915 L .61368 .59184 L p
1 g
F P
s
P
p
.002 w
.6586 .54732 m .61368 .59184 L .60821 .5915 L p
1 g
F P
s
P
p
.002 w
.4065 .26287 m .35493 .30202 L .35553 .29609 L p
1 g
F P
s
P
p
.002 w
.35553 .29609 m .40743 .25667 L .4065 .26287 L p
1 g
F P
s
P
p
.002 w
.30913 .42292 m .31423 .48379 L .30912 .48025 L p
1 g
F P
s
P
p
.002 w
.30912 .48025 m .3038 .41716 L .30913 .42292 L p
1 g
F P
s
P
p
.002 w
.69452 .42698 m .68087 .36395 L .68348 .35838 L p
1 g
F P
s
P
p
.002 w
.64929 .30249 m .68348 .35838 L .68087 .36395 L p
1 g
F P
s
P
p
.002 w
.60821 .5915 m .65154 .54854 L .6586 .54732 L p
1 g
F P
s
P
p
.002 w
.68668 .49039 m .6586 .54732 L .65154 .54854 L p
1 g
F P
s
P
p
.002 w
.46865 .2427 m .4065 .26287 L .40743 .25667 L p
1 g
F P
s
P
p
.002 w
.40743 .25667 m .46997 .23635 L .46865 .2427 L p
1 g
F P
s
P
p
.002 w
.68087 .36395 m .64688 .30843 L .64929 .30249 L p
1 g
F P
s
P
p
.002 w
.59826 .26061 m .64929 .30249 L .64688 .30843 L p
1 g
F P
s
P
p
.002 w
.32431 .36346 m .30913 .42292 L .3038 .41716 L p
1 g
F P
s
P
p
.002 w
.3038 .41716 m .3195 .35549 L .32431 .36346 L p
1 g
F P
s
P
p
.002 w
.53439 .24403 m .46865 .2427 L .46997 .23635 L p
1 g
F P
s
P
p
.002 w
.46997 .23635 m .53611 .23768 L .53439 .24403 L p
1 g
F P
s
P
p
.002 w
.64688 .30843 m .59616 .26683 L .59826 .26061 L p
1 g
F P
s
P
p
.002 w
.53611 .23768 m .59826 .26061 L .59616 .26683 L p
1 g
F P
s
P
p
.002 w
.59616 .26683 m .53439 .24403 L .53611 .23768 L p
1 g
F P
s
P
p
.002 w
.65154 .54854 m .67858 .49361 L .68668 .49039 L p
1 g
F P
s
P
p
.002 w
.69452 .42698 m .68668 .49039 L .67858 .49361 L p
1 g
F P
s
P
p
.002 w
.49292 .6261 m .43301 .61454 L .43579 .60802 L p
1 g
F P
s
P
p
.002 w
.38609 .58017 m .43579 .60802 L .43301 .61454 L p
1 g
F P
s
P
p
.002 w
.43301 .61454 m .37977 .58472 L .38609 .58017 L p
1 g
F P
s
P
p
.002 w
.43579 .60802 m .49176 .61882 L .49292 .6261 L p
1 g
F P
s
P
p
.002 w
.55341 .6182 m .49292 .6261 L .49176 .61882 L p
1 g
F P
s
P
p
.002 w
.34778 .53805 m .38609 .58017 L .37977 .58472 L p
1 g
F P
s
P
p
.002 w
.37977 .58472 m .33872 .53963 L .34778 .53805 L p
1 g
F P
s
P
p
.002 w
.35851 .31194 m .32431 .36346 L .3195 .35549 L p
1 g
F P
s
P
p
.002 w
.3195 .35549 m .35493 .30202 L .35851 .31194 L p
1 g
F P
s
P
p
.002 w
.49176 .61882 m .54823 .61143 L .55341 .6182 L p
1 g
F P
s
P
p
.002 w
.60821 .5915 m .55341 .6182 L .54823 .61143 L p
1 g
F P
s
P
p
.002 w
.32496 .48593 m .34778 .53805 L .33872 .53963 L p
1 g
F P
s
P
p
.002 w
.33872 .53963 m .31423 .48379 L .32496 .48593 L p
1 g
F P
s
P
p
.002 w
.67858 .49361 m .6861 .43246 L .69452 .42698 L p
1 g
F P
s
P
p
.002 w
.68087 .36395 m .69452 .42698 L .6861 .43246 L p
1 g
F P
s
P
p
.002 w
.54823 .61143 m .59937 .58647 L .60821 .5915 L p
1 g
F P
s
P
p
.002 w
.65154 .54854 m .60821 .5915 L .59937 .58647 L p
1 g
F P
s
P
p
.002 w
.40827 .27424 m .35851 .31194 L .35493 .30202 L p
1 g
F P
s
P
p
.002 w
.35493 .30202 m .4065 .26287 L .40827 .27424 L p
1 g
F P
s
P
p
.002 w
.32027 .42916 m .32496 .48593 L .31423 .48379 L p
1 g
F P
s
P
p
.002 w
.31423 .48379 m .30913 .42292 L .32027 .42916 L p
1 g
F P
s
P
p
.002 w
.6861 .43246 m .67288 .37171 L .68087 .36395 L p
1 g
F P
s
P
p
.002 w
.64688 .30843 m .68087 .36395 L .67288 .37171 L p
1 g
F P
s
P
p
.002 w
.59937 .58647 m .63975 .54635 L .65154 .54854 L p
1 g
F P
s
P
p
.002 w
.67858 .49361 m .65154 .54854 L .63975 .54635 L p
1 g
F P
s
P
p
.002 w
.4682 .25484 m .40827 .27424 L .4065 .26287 L p
1 g
F P
s
P
p
.002 w
.4065 .26287 m .46865 .2427 L .4682 .25484 L p
1 g
F P
s
P
p
.002 w
.33449 .37375 m .32027 .42916 L .30913 .42292 L p
1 g
F P
s
P
p
.002 w
.30913 .42292 m .32431 .36346 L .33449 .37375 L p
1 g
F P
s
P
p
.002 w
.67288 .37171 m .64007 .3182 L .64688 .30843 L p
1 g
F P
s
P
p
.002 w
.59616 .26683 m .64688 .30843 L .64007 .3182 L p
1 g
F P
s
P
p
.002 w
.53158 .25614 m .4682 .25484 L .46865 .2427 L p
1 g
F P
s
P
p
.002 w
.46865 .2427 m .53439 .24403 L .53158 .25614 L p
1 g
F P
s
P
p
.002 w
.64007 .3182 m .59114 .27811 L .59616 .26683 L p
1 g
F P
s
P
p
.002 w
.53439 .24403 m .59616 .26683 L .59114 .27811 L p
1 g
F P
s
P
p
.002 w
.59114 .27811 m .53158 .25614 L .53439 .24403 L p
1 g
F P
s
P
p
.002 w
.63975 .54635 m .6649 .49511 L .67858 .49361 L p
1 g
F P
s
P
p
.002 w
.6861 .43246 m .67858 .49361 L .6649 .49511 L p
1 g
F P
s
P
p
.002 w
.49176 .61882 m .43579 .60802 L .44059 .59601 L p
1 g
F P
s
P
p
.002 w
.39602 .57102 m .44059 .59601 L .43579 .60802 L p
1 g
F P
s
P
p
.002 w
.43579 .60802 m .38609 .58017 L .39602 .57102 L p
1 g
F P
s
P
p
.002 w
.44059 .59601 m .49078 .60569 L .49176 .61882 L p
1 g
F P
s
P
p
.002 w
.54823 .61143 m .49176 .61882 L .49078 .60569 L p
1 g
F P
s
P
p
.002 w
.36171 .53324 m .39602 .57102 L .38609 .58017 L p
1 g
F P
s
P
p
.002 w
.38609 .58017 m .34778 .53805 L .36171 .53324 L p
1 g
F P
s
P
p
.004 w
.38222 .55582 m
.5 .43051 L
s
P
p
.004 w
.37438 .56416 m
.37535 .56313 L
s
P
p
.004 w
.36958 .56926 m
.37438 .56416 L
s
P
p
.004 w
.36017 .57928 m
.36958 .56926 L
s
P
p
.004 w
.35476 .58503 m
.36017 .57928 L
s
P
p
.002 w
.36643 .32579 m .33449 .37375 L .32431 .36346 L p
1 g
F P
s
P
p
.002 w
.32431 .36346 m .35851 .31194 L .36643 .32579 L p
1 g
F P
s
P
p
.002 w
.49078 .60569 m .54141 .59903 L .54823 .61143 L p
1 g
F P
s
P
p
.002 w
.59937 .58647 m .54823 .61143 L .54141 .59903 L p
1 g
F P
s
P
p
.002 w
.34133 .48652 m .36171 .53324 L .34778 .53805 L p
1 g
F P
s
P
p
.002 w
.34778 .53805 m .32496 .48593 L .34133 .48652 L p
1 g
F P
s
P
p
.002 w
.6649 .49511 m .67182 .43811 L .6861 .43246 L p
1 g
F P
s
P
p
.002 w
.67288 .37171 m .6861 .43246 L .67182 .43811 L p
1 g
F P
s
P
p
.002 w
.54141 .59903 m .58721 .57662 L .59937 .58647 L p
1 g
F P
s
P
p
.002 w
.63975 .54635 m .59937 .58647 L .58721 .57662 L p
1 g
F P
s
P
p
.002 w
.41284 .29072 m .36643 .32579 L .35851 .31194 L p
1 g
F P
s
P
p
.002 w
.35851 .31194 m .40827 .27424 L .41284 .29072 L p
1 g
F P
s
P
p
.002 w
.33721 .43568 m .34133 .48652 L .32496 .48593 L p
1 g
F P
s
P
p
.002 w
.32496 .48593 m .32027 .42916 L .33721 .43568 L p
1 g
F P
s
P
p
.002 w
.67182 .43811 m .65943 .38152 L .67288 .37171 L p
1 g
F P
s
P
p
.002 w
.64007 .3182 m .67288 .37171 L .65943 .38152 L p
1 g
F P
s
P
p
.002 w
.58721 .57662 m .62332 .54064 L .63975 .54635 L p
1 g
F P
s
P
p
.002 w
.6649 .49511 m .63975 .54635 L .62332 .54064 L p
1 g
F P
s
P
p
.002 w
.46869 .2727 m .41284 .29072 L .40827 .27424 L p
1 g
F P
s
P
p
.002 w
.40827 .27424 m .4682 .25484 L .46869 .2727 L p
1 g
F P
s
P
p
.002 w
.35003 .38613 m .33721 .43568 L .32027 .42916 L p
1 g
F P
s
P
p
.002 w
.32027 .42916 m .33449 .37375 L .35003 .38613 L p
1 g
F P
s
P
p
.002 w
.65943 .38152 m .62881 .33171 L .64007 .3182 L p
1 g
F P
s
P
p
.002 w
.59114 .27811 m .64007 .3182 L .62881 .33171 L p
1 g
F P
s
P
p
.002 w
.52772 .27395 m .46869 .2727 L .4682 .25484 L p
1 g
F P
s
P
p
.002 w
.4682 .25484 m .53158 .25614 L .52772 .27395 L p
1 g
F P
s
P
p
.002 w
.62881 .33171 m .5832 .2944 L .59114 .27811 L p
1 g
F P
s
P
p
.002 w
.53158 .25614 m .59114 .27811 L .5832 .2944 L p
1 g
F P
s
P
p
.002 w
.5832 .2944 m .52772 .27395 L .53158 .25614 L p
1 g
F P
s
P
p
.002 w
.62332 .54064 m .64575 .49474 L .6649 .49511 L p
1 g
F P
s
P
p
.002 w
.67182 .43811 m .6649 .49511 L .64575 .49474 L p
1 g
F P
s
P
p
.002 w
.49078 .60569 m .44059 .59601 L .44736 .57856 L p
1 g
F P
s
P
p
.002 w
.40947 .55729 m .44736 .57856 L .44059 .59601 L p
1 g
F P
s
P
p
.002 w
.44059 .59601 m .39602 .57102 L .40947 .55729 L p
1 g
F P
s
P
p
.002 w
.44736 .57856 m .49004 .58679 L .49078 .60569 L p
1 g
F P
s
P
p
.002 w
.54141 .59903 m .49078 .60569 L .49004 .58679 L p
1 g
F P
s
P
p
.002 w
.37868 .3433 m .35003 .38613 L .33449 .37375 L p
1 g
F P
s
P
p
.002 w
.33449 .37375 m .36643 .32579 L .37868 .3433 L p
1 g
F P
s
P
p
.002 w
.38034 .52515 m .40947 .55729 L .39602 .57102 L p
1 g
F P
s
P
p
.002 w
.39602 .57102 m .36171 .53324 L .38034 .52515 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.49004 .58679 m .53308 .58109 L .54141 .59903 L p
1 g
F P
s
P
p
.002 w
.58721 .57662 m .54141 .59903 L .53308 .58109 L p
1 g
F P
s
P
p
.002 w
.36309 .48543 m .38034 .52515 L .36171 .53324 L p
1 g
F P
s
P
p
.002 w
.36171 .53324 m .34133 .48652 L .36309 .48543 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.64575 .49474 m .65184 .44374 L .67182 .43811 L p
1 g
F P
s
P
p
.002 w
.65943 .38152 m .67182 .43811 L .65184 .44374 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.53308 .58109 m .57197 .56199 L .58721 .57662 L p
1 g
F P
s
P
p
.002 w
.62332 .54064 m .58721 .57662 L .57197 .56199 L p
1 g
F P
s
P
p
.002 w
.42021 .31204 m .37868 .3433 L .36643 .32579 L p
1 g
F P
s
P
p
.002 w
.36643 .32579 m .41284 .29072 L .42021 .31204 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.35969 .44228 m .36309 .48543 L .34133 .48652 L p
1 g
F P
s
P
p
.002 w
.34133 .48652 m .33721 .43568 L .35969 .44228 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.65184 .44374 m .64066 .39318 L .65943 .38152 L p
1 g
F P
s
P
p
.002 w
.62881 .33171 m .65943 .38152 L .64066 .39318 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.57197 .56199 m .60257 .53138 L .62332 .54064 L p
1 g
F P
s
P
p
.002 w
.64575 .49474 m .62332 .54064 L .60257 .53138 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47014 .29601 m .42021 .31204 L .41284 .29072 L p
1 g
F P
s
P
p
.002 w
.41284 .29072 m .46869 .2727 L .47014 .29601 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.37067 .4003 m .35969 .44228 L .33721 .43568 L p
1 g
F P
s
P
p
.002 w
.33721 .43568 m .35003 .38613 L .37067 .4003 L p
1 g
F P
s
P
p
.002 w
.64066 .39318 m .61322 .34871 L .62881 .33171 L p
1 g
F P
s
P
p
.002 w
.5832 .2944 m .62881 .33171 L .61322 .34871 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52288 .29715 m .47014 .29601 L .46869 .2727 L p
1 g
F P
s
P
p
.002 w
.46869 .2727 m .52772 .27395 L .52288 .29715 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.61322 .34871 m .57245 .31542 L .5832 .2944 L p
1 g
F P
s
P
p
.002 w
.52772 .27395 m .5832 .2944 L .57245 .31542 L p
1 g
F P
s
P
p
.002 w
.60257 .53138 m .62149 .4924 L .64575 .49474 L p
1 g
F P
s
P
p
.002 w
.65184 .44374 m .64575 .49474 L .62149 .4924 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.57245 .31542 m .52288 .29715 L .52772 .27395 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44736 .57856 m .45126 .56834 L p
.48841 .58601 L 1 g
F P
s
P
p
.002 w
.49004 .58679 m .48954 .58669 L p
.48841 .58601 L 1 g
F P
s
P
p
.002 w
.48954 .58669 m .44736 .57856 L p
.48841 .58601 L 1 g
F P
s
P
p
.002 w
.46843 .57398 m .46872 .57265 L p
.46128 .56968 L 1 g
F P
s
P
p
.48261 .58007 m .45126 .56834 L .48013 .57783 L 1 g
F
P
p
.49004 .58679 m .47397 .57914 L .48261 .58007 L 1 g
F
P
p
.47397 .57914 m .45126 .56834 L .48261 .58007 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46843 .57398 L p
1 g
F P
s
P
p
.002 w
.48993 .58105 m .49004 .58679 L p
.48261 .58007 L 1 g
F P
s
P
p
.48261 .58007 m .48013 .57783 L .48905 .58076 L 1 g
F
P
p
.48261 .58007 m .48905 .58076 L .48993 .58105 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58014 L p
1 g
F P
s
P
p
.53308 .58109 m .49002 .58546 L .50774 .58095 L 1 g
F
P
p
.53128 .57265 m .5109 .58014 L .52235 .57723 L 1 g
F
P
p
.002 w
.5109 .58014 m .51079 .57862 L p
.50159 .58046 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49002 .58546 m .48993 .58086 L p
.50774 .58095 L 1 g
F P
s
P
p
.53308 .58109 m .48993 .58086 L .52942 .57952 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58076 L p
1 g
F P
s
P
p
.002 w
.48993 .58086 m .48993 .58105 L p
.48962 .58082 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58076 L .49623 .58153 L 1 g
F
P
p
.48921 .57862 m .46843 .57398 L .48032 .57789 L 1 g
F
P
p
.002 w
.48905 .58076 m .48921 .57862 L p
.48032 .57789 L 1 g
F P
s
P
p
.48013 .57783 m .45597 .55599 L .48993 .58105 L 1 g
F
P
p
.002 w
.48905 .58076 m .48889 .583 L p
.49623 .58153 L 1 g
F P
s
P
p
.002 w
.45597 .55599 m .48958 .56246 L .48993 .58086 L p
1 g
F P
s
P
p
.48962 .58082 m .45597 .55599 L .48993 .58086 L 1 g
F
P
p
.53128 .57265 m .52235 .57723 L .53061 .57513 L 1 g
F
P
p
.002 w
.57197 .56199 m .53308 .58109 L .53071 .57538 L p
1 g
F P
s
P
p
.002 w
.53071 .57538 m .53061 .57513 L p
.53146 .57486 L 1 g
F P
s
P
p
.57197 .56199 m .53071 .57538 L .53146 .57486 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57467 L p
1 g
F P
s
P
p
.54854 .56129 m .53172 .57467 L .54234 .5672 L 1 g
F
P
p
.002 w
.53172 .57467 m .53128 .57265 L p
.53061 .57513 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.549 .56252 m .54854 .56129 L p
.54234 .5672 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .549 .56252 L p
1 g
F P
s
P
p
.5521 .56033 m .54909 .5624 L .55093 .56023 L 1 g
F
P
p
.56435 .56135 m .53172 .57467 L .5521 .56033 L 1 g
F
P
p
.56075 .54566 m .549 .56252 L .55605 .55418 L 1 g
F
P
p
.53172 .57467 m .53061 .57513 L .5521 .56033 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56075 .54566 m .55605 .55418 L .56013 .54936 L 1 g
F
P
p
.60257 .53138 m .561 .54899 L .56646 .53991 L 1 g
F
P
p
.561 .54899 m .56013 .54936 L .56157 .54721 L 1 g
F
P
p
.561 .54899 m .56157 .54721 L .56646 .53991 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56157 .54721 L p
1 g
F P
s
P
p
.002 w
.60257 .53138 m .57197 .56199 L .56013 .54936 L p
1 g
F P
s
P
p
.56654 .52734 m .56157 .54721 L .56465 .53766 L 1 g
F
P
p
.002 w
.56157 .54721 m .56075 .54566 L p
.56013 .54936 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56013 .54936 m .55403 .54285 L p
.56372 .54056 L 1 g
F P
s
P
p
.56646 .53991 m .56157 .54721 L .56372 .54056 L 1 g
F
P
p
.56157 .54721 m .56013 .54936 L .56372 .54056 L 1 g
F
P
p
.56654 .52734 m .56465 .53766 L .56728 .52953 L 1 g
F
P
p
.002 w
.57801 .51874 m .56753 .52927 L p
.57016 .51891 L 1 g
F P
s
P
p
.002 w
.56753 .52927 m .56728 .52953 L p
.5675 .52873 L 1 g
F P
s
P
p
.56753 .52927 m .5675 .52873 L .57016 .51891 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5675 .52873 L p
1 g
F P
s
P
p
.56515 .50826 m .5675 .52873 L .56681 .51904 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56515 .50826 m .56681 .51904 L .56632 .51208 L 1 g
F
P
p
.59278 .48809 m .56704 .51143 L .56484 .49795 L 1 g
F
P
p
.56704 .51143 m .56632 .51208 L .56603 .50931 L 1 g
F
P
p
.56704 .51143 m .56603 .50931 L .56484 .49795 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56603 .50931 L p
1 g
F P
s
P
p
.55661 .4905 m .56603 .50931 L .56172 .50027 L 1 g
F
P
p
.002 w
.56603 .50931 m .56515 .50826 L p
.56632 .51208 L 1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55751 .49146 m .55661 .4905 L p
.56172 .50027 L 1 g
F P
s
P
p
.002 w
.56632 .51208 m .55042 .50304 L p
.56122 .49922 L 1 g
F P
s
P
p
.56484 .49795 m .56603 .50931 L .56122 .49922 L 1 g
F
P
p
.56603 .50931 m .56632 .51208 L .56122 .49922 L 1 g
F
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.56052 .48188 m .59278 .48809 L p
.5644 .4981 L 1 g
F P
s
P
p
.002 w
.55042 .50304 m .55644 .49043 L p
.5644 .4981 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55751 .49146 L p
1 g
F P
s
P
p
.54174 .47608 m .55751 .49146 L .55644 .49043 L 1 g
F
P
p
.002 w
.55644 .49043 m .55042 .50304 L p
.54854 .48276 L 1 g
F P
s
P
p
.55047 .48463 m .55644 .49043 L .55308 .48718 L 1 g
F
P
p
.54174 .47608 m .55644 .49043 L .55047 .48463 L 1 g
F
P
p
.002 w
.55042 .50304 m .52074 .48478 L p
.54854 .48276 L 1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55751 .49146 L p
1 g
F P
s
P
p
.56172 .50027 m .56713 .51061 L .55751 .49146 L 1 g
F
P
p
.002 w
.52074 .48478 m .52586 .47397 L .54368 .47804 L p
1 g
F P
s
P
p
.54854 .48276 m .52074 .48478 L .54368 .47804 L 1 g
F
P
p
.54174 .47608 m .55047 .48463 L .54368 .47804 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5631 .45852 m .56052 .48188 L .54368 .47804 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.54233 .47673 m .54368 .47804 L .53152 .47162 L 1 g
F
P
p
.002 w
.54233 .47673 m .54302 .47747 L p
.53358 .47259 L 1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .53358 .47259 L 1 g
F
P
p
.002 w
.54368 .47804 m .52586 .47397 L p
.53152 .47162 L 1 g
F P
s
P
p
.002 w
.52586 .47397 m .52637 .46919 L p
.53152 .47162 L 1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52586 .47397 m .49219 .46518 L p
.50192 .46419 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .5225 .46727 L p
1 g
F P
s
P
p
.5 .4634 m .5225 .46727 L .51183 .46567 L 1 g
F
P
p
.51777 .46656 m .52586 .47397 L .50192 .46419 L 1 g
F
P
p
.002 w
.49956 .46398 m .50019 .46394 L p
.49219 .46518 L 1 g
F P
s
P
p
.50192 .46419 m .49219 .46518 L .50019 .46394 L 1 g
F
P
p
.002 w
.52637 .46919 m .52586 .47397 L p
.51386 .46298 L 1 g
F P
s
P
p
.5 .4634 m .51183 .46567 L .50019 .46394 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.52439 .45035 m .52712 .46206 L .50019 .46394 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.50019 .46394 m .49956 .46398 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.52586 .47397 m .52074 .48478 L .49118 .46534 L p
1 g
F P
s
P
p
.002 w
.49219 .46518 m .52586 .47397 L p
.49118 .46534 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46391 L .49219 .46518 L 1 g
F
P
p
.49166 .46527 m .49219 .46518 L .49171 .46526 L 1 g
F
P
p
.47786 .46667 m .49219 .46518 L .49166 .46527 L 1 g
F
P
p
.002 w
.52074 .48478 m .51234 .49333 L .49071 .46542 L p
1 g
F P
s
P
p
.002 w
.49118 .46534 m .52074 .48478 L p
.49071 .46542 L 1 g
F P
s
P
p
.002 w
.50158 .49871 m .4896 .50034 L .49009 .46551 L p
1 g
F P
s
P
p
.47786 .46667 m .49165 .46527 L .49118 .46534 L 1 g
F
P
p
.49087 .46539 m .49118 .46534 L .49091 .46539 L 1 g
F
P
p
.47786 .46667 m .49118 .46534 L .49087 .46539 L 1 g
F
P
p
.002 w
.51234 .49333 m .50158 .49871 L .49039 .46547 L p
1 g
F P
s
P
p
.47786 .46667 m .49091 .46539 L .49065 .46543 L 1 g
F
P
p
.002 w
.49071 .46542 m .51234 .49333 L p
.49039 .46547 L 1 g
F P
s
P
p
.002 w
.49039 .46547 m .50158 .49871 L p
.49009 .46551 L 1 g
F P
s
P
p
.47786 .46667 m .49071 .46542 L .48976 .46556 L 1 g
F
P
p
.002 w
.47771 .49806 m .46717 .49211 L .48928 .46562 L p
1 g
F P
s
P
p
.002 w
.48976 .46556 m .47771 .49806 L p
.48928 .46562 L 1 g
F P
s
P
p
.002 w
.46717 .49211 m .45911 .48313 L .4882 .46577 L p
1 g
F P
s
P
p
.002 w
.48928 .46562 m .46717 .49211 L p
.4882 .46577 L 1 g
F P
s
P
p
.47786 .46667 m .48976 .46556 L .48888 .46568 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45911 .48313 m .45677 .47762 L p
.47822 .46711 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45677 .47762 m .45753 .47688 L .47822 .46711 L 1 g
F
P
p
.002 w
.45753 .47688 m .45826 .47608 L p
.46815 .47174 L 1 g
F P
s
P
p
.002 w
.47735 .46729 m .47822 .46711 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45441 .47208 m .45358 .46014 L .48431 .46392 L p
1 g
F P
s
P
p
.002 w
.47822 .46711 m .47735 .46729 L p
.47754 .46721 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .47754 .46721 L p
.47822 .46711 L 1 g
F P
s
P
p
.002 w
.4882 .46577 m .45911 .48313 L p
.47822 .46711 L 1 g
F P
s
P
p
.47822 .46711 m .48888 .46568 L .4882 .46577 L 1 g
F
P
p
.47822 .46711 m .4882 .46577 L .4775 .46727 L 1 g
F
P
p
.47786 .46667 m .48888 .46568 L .47822 .46711 L 1 g
F
P
p
.002 w
.47754 .46721 m .47754 .46721 L p
.47822 .46711 L 1 g
F P
s
P
p
.002 w
.47754 .46721 m .47786 .46667 L p
.47822 .46711 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .46721 L p
1 g
F P
s
P
p
.45826 .47608 m .47754 .46721 L .47753 .46721 L 1 g
F
P
p
.45826 .47608 m .47754 .46721 L .46815 .47174 L 1 g
F
P
p
.002 w
.47735 .46729 m .45441 .47208 L p
.46717 .4686 L 1 g
F P
s
P
p
.46717 .4686 m .48431 .46392 L .47754 .46721 L 1 g
F
P
p
.46717 .4686 m .47754 .46721 L .47735 .46729 L 1 g
F
P
p
.002 w
.48431 .46392 m .49011 .46464 L .47822 .46711 L p
1 g
F P
s
P
p
.47754 .46721 m .48431 .46392 L .47822 .46711 L 1 g
F
P
p
.002 w
.47754 .46721 m .47754 .46721 L p
.47753 .46721 L 1 g
F P
s
P
p
.002 w
.47754 .46721 m .47718 .46778 L p
.46815 .47174 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45753 .47688 L p
1 g
F P
s
P
p
.44339 .4905 m .45753 .47688 L .45296 .48133 L 1 g
F
P
p
.002 w
.45441 .47208 m .45677 .47762 L p
.4298 .49974 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44181 .49294 m .43975 .49411 L p
.44259 .49135 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.42614 .53922 m .43085 .52202 L .43256 .52865 L 1 g
F
P
p
.002 w
.43323 .53122 m .43231 .53225 L p
.43256 .52865 L 1 g
F P
s
P
p
.002 w
.43231 .53225 m .42614 .53922 L p
.43256 .52865 L 1 g
F P
s
P
p
.002 w
.43256 .52865 m .43346 .52734 L p
.43319 .51956 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43246 .52879 L p
1 g
F P
s
P
p
.002 w
.43783 .54579 m .42614 .53922 L .43323 .53122 L p
1 g
F P
s
P
p
.002 w
.43246 .52879 m .43146 .53025 L p
.43535 .53795 L 1 g
F P
s
P
p
.43925 .54566 m .43246 .52879 L .43535 .53795 L 1 g
F
P
p
.43925 .54566 m .43456 .53638 L .43545 .53983 L 1 g
F
P
p
.002 w
.42614 .53922 m .43682 .54522 L p
.44736 .57856 L 1 g
F P
s
P
p
.002 w
.43682 .54522 m .43783 .54579 L p
.43816 .54693 L 1 g
F P
s
P
p
.44736 .57856 m .43682 .54522 L .43816 .54693 L 1 g
F
P
p
.002 w
.45081 .56303 m .45146 .56129 L p
.44511 .55578 L 1 g
F P
s
P
p
.002 w
.43841 .54725 m .43925 .54566 L p
.43545 .53983 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45271 .56452 m .4491 .57401 L p
.44191 .55603 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45071 .56331 L p
1 g
F P
s
P
p
.46872 .57265 m .45071 .56331 L .46128 .56968 L 1 g
F
P
p
.48013 .57783 m .46843 .57398 L .45597 .55599 L 1 g
F
P
p
.002 w
.45126 .56834 m .45271 .56452 L p
.46843 .57398 L 1 g
F P
s
P
p
.002 w
.45271 .56452 m .45597 .55599 L p
.46843 .57398 L 1 g
F P
s
P
p
.002 w
.45071 .56331 m .45002 .56518 L p
.46128 .56968 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43841 .54725 L p
1 g
F P
s
P
p
.44191 .55603 m .43841 .54725 L .45081 .56303 L 1 g
F
P
p
.002 w
.4491 .57401 m .44736 .57856 L p
.43783 .54579 L 1 g
F P
s
P
p
.002 w
.43841 .54725 m .43743 .5491 L p
.44511 .55578 L 1 g
F P
s
P
p
.45146 .56129 m .43841 .54725 L .44511 .55578 L 1 g
F
P
p
.45081 .56303 m .43783 .54579 L .45271 .56452 L 1 g
F
P
p
.43841 .54725 m .43783 .54579 L .45081 .56303 L 1 g
F
P
p
.002 w
.43783 .54579 m .45597 .55599 L .45271 .56452 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46789 .57645 L p
1 g
F P
s
P
p
.002 w
.46789 .57645 m .46843 .57398 L p
.45903 .56949 L 1 g
F P
s
P
p
.45903 .56949 m .45002 .56518 L .46789 .57645 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45081 .56303 L p
1 g
F P
s
P
p
.44511 .55578 m .43743 .5491 L .45081 .56303 L 1 g
F
P
p
.002 w
.4377 .54858 m .43841 .54725 L p
.43545 .53983 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45597 .55599 m .43783 .54579 L p
.44559 .51727 L 1 g
F P
s
P
p
.002 w
.43323 .53122 m .44559 .51727 L p
.43783 .54579 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44559 .51727 m .43323 .53122 L p
.43256 .52865 L 1 g
F P
s
P
p
.43256 .52865 m .43085 .52202 L .43307 .52131 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43389 .5094 L p
1 g
F P
s
P
p
.43346 .52734 m .43389 .5094 L .43319 .51956 L 1 g
F
P
p
.43256 .52865 m .43307 .52131 L .44559 .51727 L 1 g
F
P
p
.002 w
.4298 .49974 m .43544 .506 L p
.42764 .52306 L 1 g
F P
s
P
p
.002 w
.43544 .506 m .4298 .49974 L .44181 .49294 L p
1 g
F P
s
P
p
.4364 .50404 m .43882 .49898 L .43664 .50339 L 1 g
F
P
p
.43485 .50826 m .4385 .49974 L .4364 .50404 L 1 g
F
P
p
.4385 .49974 m .43882 .49898 L .4364 .50404 L 1 g
F
P
p
.002 w
.43389 .5094 m .43485 .50826 L p
.43664 .50339 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44259 .49135 L p
1 g
F P
s
P
p
.002 w
.44259 .49135 m .44166 .49233 L p
.43882 .49898 L 1 g
F P
s
P
p
.43485 .50826 m .44259 .49135 L .43882 .49898 L 1 g
F
P
p
.002 w
.43975 .49411 m .4298 .49974 L p
.44434 .48782 L 1 g
F P
s
P
p
.44434 .48782 m .45677 .47762 L .44259 .49135 L 1 g
F
P
p
.44434 .48782 m .44259 .49135 L .43975 .49411 L 1 g
F
P
p
.002 w
.44559 .51727 m .43544 .506 L p
.45911 .48313 L 1 g
F P
s
P
p
.002 w
.44181 .49294 m .45911 .48313 L p
.43544 .506 L 1 g
F P
s
P
p
.002 w
.43544 .506 m .44559 .51727 L p
.42764 .52306 L 1 g
F P
s
P
p
.002 w
.43389 .5094 m .43287 .51061 L p
.43319 .51956 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43256 .52865 L p
1 g
F P
s
P
p
.43319 .51956 m .43287 .51061 L .43256 .52865 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4377 .54858 L p
1 g
F P
s
P
p
.43456 .53638 m .43146 .53025 L .4377 .54858 L 1 g
F
P
p
.42614 .53922 m .42764 .52306 L .43085 .52202 L 1 g
F
P
p
.002 w
.43335 .51005 m .43389 .5094 L p
.43664 .50339 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43335 .51005 L p
1 g
F P
s
P
p
.43882 .49898 m .44166 .49233 L .43335 .51005 L 1 g
F
P
p
.002 w
.45677 .47762 m .45911 .48313 L .44181 .49294 L p
1 g
F P
s
P
p
.44259 .49135 m .45677 .47762 L .44181 .49294 L 1 g
F
P
p
.45296 .48133 m .45677 .47762 L .45698 .47747 L 1 g
F
P
p
.002 w
.45753 .47688 m .45749 .47692 L p
.45677 .47762 L 1 g
F P
s
P
p
.002 w
.45749 .47692 m .45698 .47747 L p
.45677 .47762 L 1 g
F P
s
P
p
.002 w
.45441 .47208 m .46465 .46994 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.45677 .47762 m .45664 .47731 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.45664 .47731 m .45441 .47208 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.46465 .46994 m .47735 .46729 L p
.45753 .47688 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45753 .47688 L p
1 g
F P
s
P
p
.46815 .47174 m .47718 .46778 L .45753 .47688 L 1 g
F
P
p
.002 w
.44166 .49233 m .44339 .4905 L p
.45296 .48133 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44293 .4911 L p
.45296 .48133 L 1 g
F P
s
P
p
.002 w
.44293 .4911 m .44166 .49233 L p
.45296 .48133 L 1 g
F P
s
P
p
.002 w
.47822 .46711 m .49011 .46464 L .4882 .46577 L p
1 g
F P
s
P
p
.002 w
.4882 .46577 m .49011 .46464 L .48928 .46562 L p
1 g
F P
s
P
p
.002 w
.47746 .46733 m .4775 .46727 L p
.48928 .46562 L 1 g
F P
s
P
p
.48928 .46562 m .48976 .46556 L .48956 .46559 L 1 g
F
P
p
.48928 .46562 m .48956 .46559 L .47746 .46733 L 1 g
F
P
p
.002 w
.48928 .46562 m .49011 .46464 L .48976 .46556 L p
1 g
F P
s
P
p
.002 w
.49039 .46547 m .49011 .46464 L .49071 .46542 L p
1 g
F P
s
P
p
.002 w
.49009 .46551 m .49011 .46464 L .49039 .46547 L p
1 g
F P
s
P
p
.49065 .46543 m .49091 .46539 L .49071 .46542 L 1 g
F
P
p
.002 w
.4896 .50034 m .47771 .49806 L .48976 .46556 L p
1 g
F P
s
P
p
.002 w
.49009 .46551 m .4896 .50034 L p
.48976 .46556 L 1 g
F P
s
P
p
.002 w
.47729 .46761 m .47746 .46733 L p
.49071 .46542 L 1 g
F P
s
P
p
.002 w
.48976 .46556 m .49011 .46464 L .49009 .46551 L p
1 g
F P
s
P
p
.002 w
.49071 .46542 m .49011 .46464 L .49118 .46534 L p
1 g
F P
s
P
p
.002 w
.49118 .46534 m .49011 .46464 L .49219 .46518 L p
1 g
F P
s
P
p
.49171 .46526 m .49355 .46496 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46391 m .5 .46392 L p
.49355 .46496 L 1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .46442 L p
.49355 .46496 L 1 g
F P
s
P
p
.002 w
.49011 .46464 m .49401 .46301 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.49956 .46398 m .49011 .46464 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .4634 L p
.50019 .46394 L 1 g
F P
s
P
p
.002 w
.49401 .46301 m .52439 .45035 L p
.50019 .46394 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .46391 L p
.50019 .46394 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46391 L p
1 g
F P
s
P
p
.51183 .46567 m .52282 .46778 L .5 .46391 L 1 g
F
P
p
.002 w
.50019 .46394 m .51386 .46298 L p
.50192 .46419 L 1 g
F P
s
P
p
.51386 .46298 m .51777 .46656 L .50192 .46419 L 1 g
F
P
p
.002 w
.5225 .46727 m .52282 .46778 L p
.51183 .46567 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47729 .46761 L p
1 g
F P
s
P
p
.49165 .46527 m .5 .46442 L .47729 .46761 L 1 g
F
P
p
.002 w
.49219 .46518 m .49011 .46464 L .49956 .46398 L p
1 g
F P
s
P
p
.52214 .46667 m .53358 .47259 L .52637 .46919 L 1 g
F
P
p
.002 w
.5225 .46727 m .52214 .46667 L p
.52637 .46919 L 1 g
F P
s
P
p
.002 w
.51386 .46298 m .52712 .46206 L .52637 .46919 L p
1 g
F P
s
P
p
.002 w
.52258 .4674 m .5225 .46727 L p
.52637 .46919 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52258 .4674 L p
1 g
F P
s
P
p
.53358 .47259 m .54302 .47747 L .52258 .4674 L 1 g
F
P
p
.002 w
.52712 .46206 m .5631 .45852 L p
.53152 .47162 L 1 g
F P
s
P
p
.002 w
.52637 .46919 m .52712 .46206 L p
.53152 .47162 L 1 g
F P
s
P
p
.53542 .47 m .54233 .47673 L .53152 .47162 L 1 g
F
P
p
.002 w
.54233 .47673 m .54174 .47608 L p
.54368 .47804 L 1 g
F P
s
P
p
.5631 .45852 m .54368 .47804 L .53542 .47 L 1 g
F
P
p
.002 w
.54235 .47674 m .54233 .47673 L p
.54368 .47804 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54235 .47674 L p
1 g
F P
s
P
p
.55047 .48463 m .55834 .49233 L .54235 .47674 L 1 g
F
P
p
.002 w
.54368 .47804 m .56052 .48188 L p
.54854 .48276 L 1 g
F P
s
P
p
.002 w
.56052 .48188 m .55644 .49043 L p
.54854 .48276 L 1 g
F P
s
P
p
.002 w
.55644 .49043 m .56052 .48188 L p
.5644 .4981 L 1 g
F P
s
P
p
.002 w
.55751 .49146 m .55834 .49233 L p
.55308 .48718 L 1 g
F P
s
P
p
.002 w
.56603 .50931 m .56713 .51061 L p
.56172 .50027 L 1 g
F P
s
P
p
.002 w
.56613 .50943 m .56603 .50931 L p
.56632 .51208 L 1 g
F P
s
P
p
.002 w
.59278 .48809 m .57801 .51874 L .56632 .51208 L p
1 g
F P
s
P
p
.002 w
.55403 .54285 m .53392 .51972 L p
.56681 .51899 L 1 g
F P
s
P
p
.57016 .51891 m .56712 .52342 L .56681 .51899 L 1 g
F
P
p
.56712 .52342 m .55403 .54285 L .56681 .51899 L 1 g
F
P
p
.002 w
.5675 .52873 m .56654 .52734 L p
.56728 .52953 L 1 g
F P
s
P
p
.002 w
.56728 .52953 m .55403 .54285 L p
.57016 .51891 L 1 g
F P
s
P
p
.002 w
.57801 .51874 m .60257 .53138 L p
.56775 .53961 L 1 g
F P
s
P
p
.002 w
.55403 .54285 m .56753 .52927 L p
.56775 .53961 L 1 g
F P
s
P
p
.002 w
.56753 .52927 m .57801 .51874 L p
.56775 .53961 L 1 g
F P
s
P
p
.002 w
.53392 .51972 m .55042 .50304 L .57801 .51874 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56613 .50943 L p
.56734 .51989 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56716 .51114 L p
.56734 .51989 L 1 g
F P
s
P
p
.002 w
.56716 .51114 m .56713 .51061 L p
.56734 .51989 L 1 g
F P
s
P
p
.56681 .51904 m .56854 .53025 L .56613 .50943 L 1 g
F
P
p
.002 w
.5675 .52873 m .56854 .53025 L p
.56681 .51904 L 1 g
F P
s
P
p
.002 w
.56752 .52877 m .5675 .52873 L p
.56728 .52953 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56752 .52877 L p
1 g
F P
s
P
p
.56465 .53766 m .56257 .5491 L .56752 .52877 L 1 g
F
P
p
.002 w
.56157 .54721 m .56257 .5491 L p
.56465 .53766 L 1 g
F P
s
P
p
.002 w
.56172 .54749 m .56157 .54721 L p
.56013 .54936 L 1 g
F P
s
P
p
.002 w
.52346 .55794 m .55403 .54285 L .56013 .54936 L p
1 g
F P
s
P
p
.002 w
.56013 .54936 m .57197 .56199 L p
.55093 .56023 L 1 g
F P
s
P
p
.55093 .56023 m .52346 .55794 L .56013 .54936 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56172 .54749 L p
1 g
F P
s
P
p
.55605 .55418 m .54998 .56518 L .56172 .54749 L 1 g
F
P
p
.002 w
.549 .56252 m .54998 .56518 L p
.55605 .55418 L 1 g
F P
s
P
p
.002 w
.53061 .57513 m .52346 .55794 L p
.55093 .56023 L 1 g
F P
s
P
p
.54909 .5624 m .53061 .57513 L .55093 .56023 L 1 g
F
P
p
.57197 .56199 m .53061 .57513 L .56435 .56135 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .549 .56252 L p
1 g
F P
s
P
p
.54234 .5672 m .5322 .57686 L .549 .56252 L 1 g
F
P
p
.002 w
.53172 .57467 m .5322 .57686 L p
.54234 .5672 L 1 g
F P
s
P
p
.002 w
.53176 .57484 m .53172 .57467 L p
.53061 .57513 L 1 g
F P
s
P
p
.002 w
.48993 .58086 m .48958 .56246 L p
.52343 .57696 L 1 g
F P
s
P
p
.52942 .57952 m .5109 .58014 L .52343 .57696 L 1 g
F
P
p
.5109 .58014 m .48993 .58086 L .52343 .57696 L 1 g
F
P
p
.002 w
.48958 .56246 m .52346 .55794 L .53308 .58109 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53176 .57484 L p
1 g
F P
s
P
p
.52235 .57723 m .51111 .583 L .53176 .57484 L 1 g
F
P
p
.002 w
.5109 .58014 m .51111 .583 L p
.52235 .57723 L 1 g
F P
s
P
p
.002 w
.53308 .58109 m .49004 .58679 L .49002 .58546 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5109 .58014 L p
.49623 .58153 L 1 g
F P
s
P
p
.50159 .58046 m .49623 .58153 L .5109 .58014 L 1 g
F
P
p
.002 w
.48889 .583 m .50987 .583 L p
.49623 .58153 L 1 g
F P
s
P
p
.002 w
.50987 .583 m .51111 .583 L p
.49623 .58153 L 1 g
F P
s
P
p
.002 w
.46843 .57398 m .4678 .57686 L p
.48032 .57789 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .48857 .5874 L p
.51067 .58308 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .50987 .583 L p
.51067 .58308 L 1 g
F P
s
P
p
.002 w
.50987 .583 m .48889 .583 L p
.51067 .58308 L 1 g
F P
s
P
p
.46128 .56968 m .45002 .56518 L .46843 .57398 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58076 L p
1 g
F P
s
P
p
.48032 .57789 m .4678 .57686 L .48905 .58076 L 1 g
F
P
p
.002 w
.44736 .57856 m .40947 .55729 L .42614 .53922 L p
1 g
F P
s
P
p
.002 w
.39504 .36407 m .37067 .4003 L .35003 .38613 L p
1 g
F P
s
P
p
.002 w
.35003 .38613 m .37868 .3433 L .39504 .36407 L p
1 g
F P
s
P
p
.002 w
.40325 .51389 m .42614 .53922 L .40947 .55729 L p
1 g
F P
s
P
p
.002 w
.40947 .55729 m .38034 .52515 L .40325 .51389 L p
1 g
F P
s
P
p
.002 w
.38976 .48263 m .40325 .51389 L .38034 .52515 L p
1 g
F P
s
P
p
.002 w
.38034 .52515 m .36309 .48543 L .38976 .48263 L p
1 g
F P
s
P
p
.002 w
.62149 .4924 m .62654 .44916 L .65184 .44374 L p
1 g
F P
s
P
p
.002 w
.64066 .39318 m .65184 .44374 L .62654 .44916 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.43027 .33768 m .39504 .36407 L .37868 .3433 L p
1 g
F P
s
P
p
.002 w
.37868 .3433 m .42021 .31204 L .43027 .33768 L p
1 g
F P
s
P
p
.002 w
.38718 .44872 m .38976 .48263 L .36309 .48543 L p
1 g
F P
s
P
p
.002 w
.36309 .48543 m .35969 .44228 L .38718 .44872 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.62654 .44916 m .61697 .40636 L .64066 .39318 L p
1 g
F P
s
P
p
.002 w
.61322 .34871 m .64066 .39318 L .61697 .40636 L p
1 g
F P
s
P
p
.002 w
.62149 .4924 m .60257 .53138 L .57801 .51874 L p
1 g
F P
s
P
p
.002 w
.47255 .32417 m .43027 .33768 L .42021 .31204 L p
1 g
F P
s
P
p
.002 w
.42021 .31204 m .47014 .29601 L .47255 .32417 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.3959 .4158 m .38718 .44872 L .35969 .44228 L p
1 g
F P
s
P
p
.002 w
.35969 .44228 m .37067 .4003 L .3959 .4158 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.61697 .40636 m .59367 .36876 L .61322 .34871 L p
1 g
F P
s
P
p
.002 w
.57245 .31542 m .61322 .34871 L .59367 .36876 L p
1 g
F P
s
P
p
.002 w
.51718 .32518 m .47255 .32417 L .47014 .29601 L p
1 g
F P
s
P
p
.002 w
.47014 .29601 m .52288 .29715 L .51718 .32518 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.57801 .51874 m .59278 .48809 L .62149 .4924 L p
1 g
F P
s
P
p
.002 w
.62654 .44916 m .62149 .4924 L .59278 .48809 L p
1 g
F P
s
P
p
.002 w
.59367 .36876 m .55913 .34062 L .57245 .31542 L p
1 g
F P
s
P
p
.002 w
.52288 .29715 m .57245 .31542 L .55913 .34062 L p
1 g
F P
s
P
p
.002 w
.55913 .34062 m .51718 .32518 L .52288 .29715 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48958 .56246 m .45597 .55599 L .46619 .52887 L p
1 g
F P
s
P
p
.002 w
.44559 .51727 m .46619 .52887 L .45597 .55599 L p
1 g
F P
s
P
p
.002 w
.41509 .38745 m .3959 .4158 L .37067 .4003 L p
1 g
F P
s
P
p
.002 w
.37067 .4003 m .39504 .36407 L .41509 .38745 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46619 .52887 m .48943 .53333 L .48958 .56246 L p
1 g
F P
s
P
p
.002 w
.52346 .55794 m .48958 .56246 L .48943 .53333 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42614 .53922 m .40325 .51389 L .4298 .49974 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48943 .53333 m .51284 .53018 L .52346 .55794 L p
1 g
F P
s
P
p
.002 w
.55403 .54285 m .52346 .55794 L .51284 .53018 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.59278 .48809 m .59664 .45416 L .62654 .44916 L p
1 g
F P
s
P
p
.002 w
.61697 .40636 m .62654 .44916 L .59664 .45416 L p
1 g
F P
s
P
p
.002 w
.42054 .47814 m .4298 .49974 L .40325 .51389 L p
1 g
F P
s
P
p
.002 w
.40325 .51389 m .38976 .48263 L .42054 .47814 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51284 .53018 m .53392 .51972 L .55403 .54285 L p
1 g
F P
s
P
p
.002 w
.44275 .36684 m .41509 .38745 L .39504 .36407 L p
1 g
F P
s
P
p
.002 w
.39504 .36407 m .43027 .33768 L .44275 .36684 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41884 .45476 m .42054 .47814 L .38976 .48263 L p
1 g
F P
s
P
p
.002 w
.38976 .48263 m .38718 .44872 L .41884 .45476 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.59664 .45416 m .58904 .42063 L .61697 .40636 L p
1 g
F P
s
P
p
.002 w
.59367 .36876 m .61697 .40636 L .58904 .42063 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47588 .35633 m .44275 .36684 L .43027 .33768 L p
1 g
F P
s
P
p
.002 w
.43027 .33768 m .47255 .32417 L .47588 .35633 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42492 .4321 m .41884 .45476 L .38718 .44872 L p
1 g
F P
s
P
p
.002 w
.38718 .44872 m .3959 .4158 L .42492 .4321 L p
1 g
F P
s
P
p
.002 w
.58904 .42063 m .57073 .39122 L .59367 .36876 L p
1 g
F P
s
P
p
.002 w
.55913 .34062 m .59367 .36876 L .57073 .39122 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.51081 .35714 m .47588 .35633 L .47255 .32417 L p
1 g
F P
s
P
p
.002 w
.47255 .32417 m .51718 .32518 L .51081 .35714 L p
1 g
F P
s
P
p
.002 w
.59664 .45416 m .59278 .48809 L .56052 .48188 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57073 .39122 m .54365 .36923 L .55913 .34062 L p
1 g
F P
s
P
p
.002 w
.51718 .32518 m .55913 .34062 L .54365 .36923 L p
1 g
F P
s
P
p
.002 w
.54365 .36923 m .51081 .35714 L .51718 .32518 L p
1 g
F P
s
P
p
.002 w
.43819 .41264 m .42492 .4321 L .3959 .4158 L p
1 g
F P
s
P
p
.002 w
.3959 .4158 m .41509 .38745 L .43819 .41264 L p
1 g
F P
s
P
p
.002 w
.48943 .53333 m .46619 .52887 L .47771 .49806 L p
1 g
F P
s
P
p
.002 w
.46717 .49211 m .47771 .49806 L .46619 .52887 L p
1 g
F P
s
P
p
.002 w
.46619 .52887 m .44559 .51727 L .46717 .49211 L p
1 g
F P
s
P
p
.002 w
.47771 .49806 m .4896 .50034 L .48943 .53333 L p
1 g
F P
s
P
p
.002 w
.51284 .53018 m .48943 .53333 L .4896 .50034 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.45911 .48313 m .46717 .49211 L .44559 .51727 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.4896 .50034 m .50158 .49871 L .51284 .53018 L p
1 g
F P
s
P
p
.002 w
.53392 .51972 m .51284 .53018 L .50158 .49871 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56052 .48188 m .5631 .45852 L .59664 .45416 L p
1 g
F P
s
P
p
.002 w
.58904 .42063 m .59664 .45416 L .5631 .45852 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4298 .49974 m .42054 .47814 L .45441 .47208 L p
1 g
F P
s
P
p
.002 w
.50158 .49871 m .51234 .49333 L .53392 .51972 L p
1 g
F P
s
P
p
.002 w
.55042 .50304 m .53392 .51972 L .51234 .49333 L p
1 g
F P
s
P
p
.002 w
.45724 .39853 m .43819 .41264 L .41509 .38745 L p
1 g
F P
s
P
p
.002 w
.41509 .38745 m .44275 .36684 L .45724 .39853 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.45358 .46014 m .45441 .47208 L .42054 .47814 L p
1 g
F P
s
P
p
.002 w
.42054 .47814 m .41884 .45476 L .45358 .46014 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.5631 .45852 m .5578 .43548 L .58904 .42063 L p
1 g
F P
s
P
p
.002 w
.57073 .39122 m .58904 .42063 L .5578 .43548 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.51234 .49333 m .52074 .48478 L .55042 .50304 L p
1 g
F P
s
P
p
.002 w
.48002 .39136 m .45724 .39853 L .44275 .36684 L p
1 g
F P
s
P
p
.002 w
.44275 .36684 m .47588 .35633 L .48002 .39136 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.45673 .44859 m .45358 .46014 L .41884 .45476 L p
1 g
F P
s
P
p
.002 w
.41884 .45476 m .42492 .4321 L .45673 .44859 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.5578 .43548 m .54516 .41531 L .57073 .39122 L p
1 g
F P
s
P
p
.002 w
.54365 .36923 m .57073 .39122 L .54516 .41531 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.504 .39194 m .48002 .39136 L .47588 .35633 L p
1 g
F P
s
P
p
.002 w
.47588 .35633 m .51081 .35714 L .504 .39194 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54516 .41531 m .52655 .40023 L .54365 .36923 L p
1 g
F P
s
P
p
.002 w
.51081 .35714 m .54365 .36923 L .52655 .40023 L p
1 g
F P
s
P
p
.002 w
.46352 .43871 m .45673 .44859 L .42492 .4321 L p
1 g
F P
s
P
p
.002 w
.42492 .4321 m .43819 .41264 L .46352 .43871 L p
1 g
F P
s
P
p
.002 w
.52655 .40023 m .504 .39194 L .51081 .35714 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.5578 .43548 m .5631 .45852 L .52712 .46206 L p
1 g
F P
s
P
p
.002 w
.47324 .43156 m .46352 .43871 L .43819 .41264 L p
1 g
F P
s
P
p
.002 w
.43819 .41264 m .45724 .39853 L .47324 .43156 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52712 .46206 m .52439 .45035 L .5578 .43548 L p
1 g
F P
s
P
p
.002 w
.54516 .41531 m .5578 .43548 L .52439 .45035 L p
1 g
F P
s
P
p
.002 w
.45358 .46014 m .45673 .44859 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48482 .42794 m .47324 .43156 L .45724 .39853 L p
1 g
F P
s
P
p
.002 w
.45724 .39853 m .48002 .39136 L .48482 .42794 L p
1 g
F P
s
P
p
.002 w
.52439 .45035 m .51794 .4401 L .54516 .41531 L p
1 g
F P
s
P
p
.002 w
.52655 .40023 m .54516 .41531 L .51794 .4401 L p
1 g
F P
s
P
p
.002 w
.45673 .44859 m .46352 .43871 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49701 .42825 m .48482 .42794 L .48002 .39136 L p
1 g
F P
s
P
p
.002 w
.48002 .39136 m .504 .39194 L .49701 .42825 L p
1 g
F P
s
P
p
.002 w
.51794 .4401 m .50847 .43246 L .52655 .40023 L p
1 g
F P
s
P
p
.002 w
.504 .39194 m .52655 .40023 L .50847 .43246 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.50847 .43246 m .49701 .42825 L .504 .39194 L p
1 g
F P
s
P
p
.002 w
.46352 .43871 m .47324 .43156 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51794 .4401 m .52439 .45035 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.50847 .43246 m .51794 .4401 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.49701 .42825 m .50847 .43246 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.48482 .42794 m .49701 .42825 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.47324 .43156 m .48482 .42794 L .49011 .46464 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.48396 .48583 m
.49011 .46464 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .30439 .63862 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .48396 .48583 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.113953)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.113953)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49022 .45685 m .50752 .45033 L .49326 .42558 L p
1 g
F P
s
P
p
.002 w
.49326 .42558 m .4845 .42888 L .49022 .45685 L p
1 g
F P
s
P
p
.002 w
.50053 .41966 m .49326 .42558 L .50752 .45033 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .4845 .42888 L .49326 .42558 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .49326 .42558 L .50053 .41966 L closepath p
1 g
F P
s
P
p
.002 w
.50752 .45033 m .52186 .43865 L .50053 .41966 L p
1 g
F P
s
P
p
.002 w
.50552 .41175 m .50053 .41966 L .52186 .43865 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .50053 .41966 L .50552 .41175 L closepath p
1 g
F P
s
P
p
.002 w
.47181 .45752 m .49022 .45685 L .4845 .42888 L p
1 g
F P
s
P
p
.002 w
.4845 .42888 m .47518 .42919 L .47181 .45752 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .47518 .42919 L .4845 .42888 L closepath p
1 g
F P
s
P
p
.002 w
.52186 .43865 m .53174 .42304 L .50552 .41175 L p
1 g
F P
s
P
p
.002 w
.50769 .4027 m .50552 .41175 L .53174 .42304 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .50552 .41175 L .50769 .4027 L closepath p
1 g
F P
s
P
p
.002 w
.49621 .48434 m .52166 .47471 L .50752 .45033 L p
1 g
F P
s
P
p
.002 w
.50752 .45033 m .49022 .45685 L .49621 .48434 L p
1 g
F P
s
P
p
.002 w
.52186 .43865 m .50752 .45033 L .52166 .47471 L p
1 g
F P
s
P
p
.002 w
.52166 .47471 m .54277 .45752 L .52186 .43865 L p
1 g
F P
s
P
p
.002 w
.53174 .42304 m .52186 .43865 L .54277 .45752 L p
1 g
F P
s
P
p
.002 w
.45423 .45223 m .47181 .45752 L .47518 .42919 L p
1 g
F P
s
P
p
.002 w
.47518 .42919 m .46629 .42649 L .45423 .45223 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .46629 .42649 L .47518 .42919 L closepath p
1 g
F P
s
P
p
.002 w
.4691 .48538 m .49621 .48434 L .49022 .45685 L p
1 g
F P
s
P
p
.002 w
.49022 .45685 m .47181 .45752 L .4691 .48538 L p
1 g
F P
s
P
p
.002 w
.53174 .42304 m .53607 .40516 L .50769 .4027 L p
1 g
F P
s
P
p
.002 w
.5068 .39347 m .50769 .4027 L .53607 .40516 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .50769 .4027 L .5068 .39347 L closepath p
1 g
F P
s
P
p
.002 w
.54277 .45752 m .55734 .43458 L .53174 .42304 L p
1 g
F P
s
P
p
.002 w
.53607 .40516 m .53174 .42304 L .55734 .43458 L p
1 g
F P
s
P
p
.002 w
.43937 .44152 m .45423 .45223 L .46629 .42649 L p
1 g
F P
s
P
p
.002 w
.46629 .42649 m .45881 .42105 L .43937 .44152 L p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .45881 .42105 L .46629 .42649 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .5068 .39347 L .50294 .38507 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .50294 .38507 L .49652 .3784 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .49652 .3784 L .48822 .3742 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .48822 .3742 L .47895 .37293 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .47895 .37293 L .46971 .37475 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .46971 .37475 L .46152 .37945 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .46152 .37945 L .45528 .38652 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .45528 .38652 L .45166 .39519 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .45166 .39519 L .45106 .40451 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .45106 .40451 L .45354 .41345 L closepath p
1 g
F P
s
P
p
.002 w
.47915 .40091 m .45354 .41345 L .45881 .42105 L closepath p
1 g
F P
s
P
p
.002 w
.53607 .40516 m .53439 .38691 L .5068 .39347 L p
1 g
F P
s
P
p
.002 w
.50294 .38507 m .5068 .39347 L .53439 .38691 L p
1 g
F P
s
P
p
.002 w
.44317 .47767 m .4691 .48538 L .47181 .45752 L p
1 g
F P
s
P
p
.002 w
.47181 .45752 m .45423 .45223 L .44317 .47767 L p
1 g
F P
s
P
p
.002 w
.42887 .4265 m .43937 .44152 L .45881 .42105 L p
1 g
F P
s
P
p
.002 w
.45881 .42105 m .45354 .41345 L .42887 .4265 L p
1 g
F P
s
P
p
.002 w
.55734 .43458 m .5638 .40826 L .53607 .40516 L p
1 g
F P
s
P
p
.002 w
.53439 .38691 m .53607 .40516 L .5638 .40826 L p
1 g
F P
s
P
p
.002 w
.53439 .38691 m .52681 .37023 L .50294 .38507 L p
1 g
F P
s
P
p
.002 w
.49652 .3784 m .50294 .38507 L .52681 .37023 L p
1 g
F P
s
P
p
.002 w
.50236 .51083 m .53542 .49828 L .52166 .47471 L p
1 g
F P
s
P
p
.002 w
.52166 .47471 m .49621 .48434 L .50236 .51083 L p
1 g
F P
s
P
p
.002 w
.54277 .45752 m .52166 .47471 L .53542 .49828 L p
1 g
F P
s
P
p
.002 w
.42389 .40878 m .42887 .4265 L .45354 .41345 L p
1 g
F P
s
P
p
.002 w
.45354 .41345 m .45106 .40451 L .42389 .40878 L p
1 g
F P
s
P
p
.002 w
.53542 .49828 m .56287 .47595 L .54277 .45752 L p
1 g
F P
s
P
p
.002 w
.55734 .43458 m .54277 .45752 L .56287 .47595 L p
1 g
F P
s
P
p
.002 w
.4212 .46194 m .44317 .47767 L .45423 .45223 L p
1 g
F P
s
P
p
.002 w
.45423 .45223 m .43937 .44152 L .4212 .46194 L p
1 g
F P
s
P
p
.002 w
.52681 .37023 m .51413 .35696 L .49652 .3784 L p
1 g
F P
s
P
p
.002 w
.48822 .3742 m .49652 .3784 L .51413 .35696 L p
1 g
F P
s
P
p
.002 w
.46711 .51225 m .50236 .51083 L .49621 .48434 L p
1 g
F P
s
P
p
.002 w
.49621 .48434 m .4691 .48538 L .46711 .51225 L p
1 g
F P
s
P
p
.002 w
.42502 .39027 m .42389 .40878 L .45106 .40451 L p
1 g
F P
s
P
p
.002 w
.45106 .40451 m .45166 .39519 L .42502 .39027 L p
1 g
F P
s
P
p
.002 w
.5638 .40826 m .5614 .38134 L .53439 .38691 L p
1 g
F P
s
P
p
.002 w
.52681 .37023 m .53439 .38691 L .5614 .38134 L p
1 g
F P
s
P
p
.002 w
.56287 .47595 m .58185 .44615 L .55734 .43458 L p
1 g
F P
s
P
p
.002 w
.5638 .40826 m .55734 .43458 L .58185 .44615 L p
1 g
F P
s
P
p
.002 w
.51413 .35696 m .49769 .34857 L .48822 .3742 L p
1 g
F P
s
P
p
.002 w
.47895 .37293 m .48822 .3742 L .49769 .34857 L p
1 g
F P
s
P
p
.002 w
.43218 .37302 m .42502 .39027 L .45166 .39519 L p
1 g
F P
s
P
p
.002 w
.45166 .39519 m .45528 .38652 L .43218 .37302 L p
1 g
F P
s
P
p
.002 w
.49769 .34857 m .47927 .346 L .47895 .37293 L p
1 g
F P
s
P
p
.002 w
.46971 .37475 m .47895 .37293 L .47927 .346 L p
1 g
F P
s
P
p
.002 w
.4056 .43983 m .4212 .46194 L .43937 .44152 L p
1 g
F P
s
P
p
.002 w
.43937 .44152 m .42887 .4265 L .4056 .43983 L p
1 g
F P
s
P
p
.002 w
.44459 .35893 m .43218 .37302 L .45528 .38652 L p
1 g
F P
s
P
p
.002 w
.45528 .38652 m .46152 .37945 L .44459 .35893 L p
1 g
F P
s
P
p
.002 w
.43334 .50232 m .46711 .51225 L .4691 .48538 L p
1 g
F P
s
P
p
.002 w
.4691 .48538 m .44317 .47767 L .43334 .50232 L p
1 g
F P
s
P
p
.002 w
.47927 .346 m .46089 .34959 L .46971 .37475 L p
1 g
F P
s
P
p
.002 w
.46152 .37945 m .46971 .37475 L .46089 .34959 L p
1 g
F P
s
P
p
.002 w
.46089 .34959 m .44459 .35893 L .46152 .37945 L p
1 g
F P
s
P
p
.002 w
.5614 .38134 m .55032 .35669 L .52681 .37023 L p
1 g
F P
s
P
p
.002 w
.51413 .35696 m .52681 .37023 L .55032 .35669 L p
1 g
F P
s
P
p
.002 w
.58185 .44615 m .59033 .41195 L .5638 .40826 L p
1 g
F P
s
P
p
.002 w
.5614 .38134 m .5638 .40826 L .59033 .41195 L p
1 g
F P
s
P
p
.002 w
.39815 .41365 m .4056 .43983 L .42887 .4265 L p
1 g
F P
s
P
p
.002 w
.42887 .4265 m .42389 .40878 L .39815 .41365 L p
1 g
F P
s
P
p
.002 w
.40466 .48194 m .43334 .50232 L .44317 .47767 L p
1 g
F P
s
P
p
.002 w
.44317 .47767 m .4212 .46194 L .40466 .48194 L p
1 g
F P
s
P
p
.002 w
.55032 .35669 m .53166 .33702 L .51413 .35696 L p
1 g
F P
s
P
p
.002 w
.49769 .34857 m .51413 .35696 L .53166 .33702 L p
1 g
F P
s
P
p
.002 w
.50856 .5358 m .54855 .52058 L .53542 .49828 L p
1 g
F P
s
P
p
.002 w
.53542 .49828 m .50236 .51083 L .50856 .5358 L p
1 g
F P
s
P
p
.002 w
.56287 .47595 m .53542 .49828 L .54855 .52058 L p
1 g
F P
s
P
p
.002 w
.54855 .52058 m .58176 .49358 L .56287 .47595 L p
1 g
F P
s
P
p
.002 w
.58185 .44615 m .56287 .47595 L .58176 .49358 L p
1 g
F P
s
P
p
.002 w
.59033 .41195 m .58733 .3769 L .5614 .38134 L p
1 g
F P
s
P
p
.002 w
.55032 .35669 m .5614 .38134 L .58733 .3769 L p
1 g
F P
s
P
p
.002 w
.39975 .38625 m .39815 .41365 L .42389 .40878 L p
1 g
F P
s
P
p
.002 w
.42389 .40878 m .42502 .39027 L .39975 .38625 L p
1 g
F P
s
P
p
.002 w
.4659 .53761 m .50856 .5358 L .50236 .51083 L p
1 g
F P
s
P
p
.002 w
.50236 .51083 m .46711 .51225 L .4659 .53761 L p
1 g
F P
s
P
p
.002 w
.53166 .33702 m .50737 .32452 L .49769 .34857 L p
1 g
F P
s
P
p
.002 w
.47927 .346 m .49769 .34857 L .50737 .32452 L p
1 g
F P
s
P
p
.002 w
.58176 .49358 m .60478 .45755 L .58185 .44615 L p
1 g
F P
s
P
p
.002 w
.59033 .41195 m .58185 .44615 L .60478 .45755 L p
1 g
F P
s
P
p
.002 w
.38423 .45318 m .40466 .48194 L .4212 .46194 L p
1 g
F P
s
P
p
.002 w
.4212 .46194 m .4056 .43983 L .38423 .45318 L p
1 g
F P
s
P
p
.002 w
.4103 .36067 m .39975 .38625 L .42502 .39027 L p
1 g
F P
s
P
p
.002 w
.42502 .39027 m .43218 .37302 L .4103 .36067 L p
1 g
F P
s
P
p
.002 w
.50737 .32452 m .4801 .32066 L .47927 .346 L p
1 g
F P
s
P
p
.002 w
.46089 .34959 m .47927 .346 L .4801 .32066 L p
1 g
F P
s
P
p
.002 w
.42497 .52569 m .4659 .53761 L .46711 .51225 L p
1 g
F P
s
P
p
.002 w
.46711 .51225 m .43334 .50232 L .42497 .52569 L p
1 g
F P
s
P
p
.002 w
.42868 .33978 m .4103 .36067 L .43218 .37302 L p
1 g
F P
s
P
p
.002 w
.43218 .37302 m .44459 .35893 L .42868 .33978 L p
1 g
F P
s
P
p
.002 w
.58733 .3769 m .57301 .34473 L .55032 .35669 L p
1 g
F P
s
P
p
.002 w
.53166 .33702 m .55032 .35669 L .57301 .34473 L p
1 g
F P
s
P
p
.002 w
.4801 .32066 m .45285 .32593 L .46089 .34959 L p
1 g
F P
s
P
p
.002 w
.44459 .35893 m .46089 .34959 L .45285 .32593 L p
1 g
F P
s
P
p
.002 w
.45285 .32593 m .42868 .33978 L .44459 .35893 L p
1 g
F P
s
P
p
.002 w
.60478 .45755 m .61515 .41617 L .59033 .41195 L p
1 g
F P
s
P
p
.002 w
.58733 .3769 m .59033 .41195 L .61515 .41617 L p
1 g
F P
s
P
p
.002 w
.37439 .41905 m .38423 .45318 L .4056 .43983 L p
1 g
F P
s
P
p
.002 w
.4056 .43983 m .39815 .41365 L .37439 .41905 L p
1 g
F P
s
P
p
.002 w
.39013 .50112 m .42497 .52569 L .43334 .50232 L p
1 g
F P
s
P
p
.002 w
.43334 .50232 m .40466 .48194 L .39013 .50112 L p
1 g
F P
s
P
p
.002 w
.57301 .34473 m .54875 .31898 L .53166 .33702 L p
1 g
F P
s
P
p
.002 w
.50737 .32452 m .53166 .33702 L .54875 .31898 L p
1 g
F P
s
P
p
.002 w
.5147 .55873 m .56077 .54115 L .54855 .52058 L p
1 g
F P
s
P
p
.002 w
.54855 .52058 m .50856 .5358 L .5147 .55873 L p
1 g
F P
s
P
p
.002 w
.58176 .49358 m .54855 .52058 L .56077 .54115 L p
1 g
F P
s
P
p
.002 w
.61515 .41617 m .61164 .37369 L .58733 .3769 L p
1 g
F P
s
P
p
.002 w
.57301 .34473 m .58733 .3769 L .61164 .37369 L p
1 g
F P
s
P
p
.002 w
.37638 .38325 m .37439 .41905 L .39815 .41365 L p
1 g
F P
s
P
p
.002 w
.39815 .41365 m .39975 .38625 L .37638 .38325 L p
1 g
F P
s
P
p
.002 w
.56077 .54115 m .59905 .51004 L .58176 .49358 L p
1 g
F P
s
P
p
.002 w
.60478 .45755 m .58176 .49358 L .59905 .51004 L p
1 g
F P
s
P
p
.002 w
.46551 .56091 m .5147 .55873 L .50856 .5358 L p
1 g
F P
s
P
p
.002 w
.50856 .5358 m .4659 .53761 L .46551 .56091 L p
1 g
F P
s
P
p
.002 w
.54875 .31898 m .5171 .30257 L .50737 .32452 L p
1 g
F P
s
P
p
.002 w
.4801 .32066 m .50737 .32452 L .5171 .30257 L p
1 g
F P
s
P
p
.002 w
.59905 .51004 m .62564 .46854 L .60478 .45755 L p
1 g
F P
s
P
p
.002 w
.61515 .41617 m .60478 .45755 L .62564 .46854 L p
1 g
F P
s
P
p
.002 w
.36522 .4663 m .39013 .50112 L .40466 .48194 L p
1 g
F P
s
P
p
.002 w
.40466 .48194 m .38423 .45318 L .36522 .4663 L p
1 g
F P
s
P
p
.002 w
.39013 .34977 m .37638 .38325 L .39975 .38625 L p
1 g
F P
s
P
p
.002 w
.39975 .38625 m .4103 .36067 L .39013 .34977 L p
1 g
F P
s
P
p
.002 w
.5171 .30257 m .48145 .29744 L .4801 .32066 L p
1 g
F P
s
P
p
.002 w
.45285 .32593 m .4801 .32066 L .48145 .29744 L p
1 g
F P
s
P
p
.002 w
.41827 .54728 m .46551 .56091 L .4659 .53761 L p
1 g
F P
s
P
p
.002 w
.4659 .53761 m .42497 .52569 L .41827 .54728 L p
1 g
F P
s
P
p
.002 w
.61164 .37369 m .5944 .33464 L .57301 .34473 L p
1 g
F P
s
P
p
.002 w
.54875 .31898 m .57301 .34473 L .5944 .33464 L p
1 g
F P
s
P
p
.002 w
.41416 .32241 m .39013 .34977 L .4103 .36067 L p
1 g
F P
s
P
p
.002 w
.4103 .36067 m .42868 .33978 L .41416 .32241 L p
1 g
F P
s
P
p
.002 w
.48145 .29744 m .4458 .30429 L .45285 .32593 L p
1 g
F P
s
P
p
.002 w
.42868 .33978 m .45285 .32593 L .4458 .30429 L p
1 g
F P
s
P
p
.002 w
.4458 .30429 m .41416 .32241 L .42868 .33978 L p
1 g
F P
s
P
p
.002 w
.62564 .46854 m .6377 .42085 L .61515 .41617 L p
1 g
F P
s
P
p
.002 w
.61164 .37369 m .61515 .41617 L .6377 .42085 L p
1 g
F P
s
P
p
.002 w
.35315 .42488 m .36522 .4663 L .38423 .45318 L p
1 g
F P
s
P
p
.002 w
.38423 .45318 m .37439 .41905 L .35315 .42488 L p
1 g
F P
s
P
p
.002 w
.37798 .51903 m .41827 .54728 L .42497 .52569 L p
1 g
F P
s
P
p
.002 w
.42497 .52569 m .39013 .50112 L .37798 .51903 L p
1 g
F P
s
P
p
.002 w
.5944 .33464 m .56507 .3033 L .54875 .31898 L p
1 g
F P
s
P
p
.002 w
.5171 .30257 m .54875 .31898 L .56507 .3033 L p
1 g
F P
s
P
p
.002 w
.6377 .42085 m .63378 .37184 L .61164 .37369 L p
1 g
F P
s
P
p
.002 w
.5944 .33464 m .61164 .37369 L .63378 .37184 L p
1 g
F P
s
P
p
.002 w
.35548 .38135 m .35315 .42488 L .37439 .41905 L p
1 g
F P
s
P
p
.002 w
.37439 .41905 m .37638 .38325 L .35548 .38135 L p
1 g
F P
s
P
p
.002 w
.52063 .57906 m .57179 .5595 L .56077 .54115 L p
1 g
F P
s
P
p
.002 w
.56077 .54115 m .5147 .55873 L .52063 .57906 L p
1 g
F P
s
P
p
.002 w
.59905 .51004 m .56077 .54115 L .57179 .5595 L p
1 g
F P
s
P
p
.002 w
.57179 .5595 m .61432 .52495 L .59905 .51004 L p
1 g
F P
s
P
p
.002 w
.62564 .46854 m .59905 .51004 L .61432 .52495 L p
1 g
F P
s
P
p
.002 w
.466 .58157 m .52063 .57906 L .5147 .55873 L p
1 g
F P
s
P
p
.002 w
.5147 .55873 m .46551 .56091 L .466 .58157 L p
1 g
F P
s
P
p
.002 w
.56507 .3033 m .52666 .28325 L .5171 .30257 L p
1 g
F P
s
P
p
.002 w
.48145 .29744 m .5171 .30257 L .52666 .28325 L p
1 g
F P
s
P
p
.002 w
.3491 .47891 m .37798 .51903 L .39013 .50112 L p
1 g
F P
s
P
p
.002 w
.39013 .50112 m .36522 .4663 L .3491 .47891 L p
1 g
F P
s
P
p
.002 w
.61432 .52495 m .64391 .47889 L .62564 .46854 L p
1 g
F P
s
P
p
.002 w
.6377 .42085 m .62564 .46854 L .64391 .47889 L p
1 g
F P
s
P
p
.002 w
.37214 .34059 m .35548 .38135 L .37638 .38325 L p
1 g
F P
s
P
p
.002 w
.37638 .38325 m .39013 .34977 L .37214 .34059 L p
1 g
F P
s
P
p
.002 w
.52666 .28325 m .48332 .27692 L .48145 .29744 L p
1 g
F P
s
P
p
.002 w
.4458 .30429 m .48145 .29744 L .48332 .27692 L p
1 g
F P
s
P
p
.002 w
.63378 .37184 m .61402 .3267 L .5944 .33464 L p
1 g
F P
s
P
p
.002 w
.56507 .3033 m .5944 .33464 L .61402 .3267 L p
1 g
F P
s
P
p
.002 w
.41347 .56655 m .466 .58157 L .46551 .56091 L p
1 g
F P
s
P
p
.002 w
.46551 .56091 m .41827 .54728 L .41347 .56655 L p
1 g
F P
s
P
p
.002 w
.40138 .30726 m .37214 .34059 L .39013 .34977 L p
1 g
F P
s
P
p
.002 w
.39013 .34977 m .41416 .32241 L .40138 .30726 L p
1 g
F P
s
P
p
.002 w
.48332 .27692 m .43991 .28521 L .4458 .30429 L p
1 g
F P
s
P
p
.002 w
.41416 .32241 m .4458 .30429 L .43991 .28521 L p
1 g
F P
s
P
p
.002 w
.64391 .47889 m .65741 .42593 L .6377 .42085 L p
1 g
F P
s
P
p
.002 w
.63378 .37184 m .6377 .42085 L .65741 .42593 L p
1 g
F P
s
P
p
.002 w
.43991 .28521 m .40138 .30726 L .41416 .32241 L p
1 g
F P
s
P
p
.002 w
.33502 .43106 m .3491 .47891 L .36522 .4663 L p
1 g
F P
s
P
p
.002 w
.36522 .4663 m .35315 .42488 L .33502 .43106 L p
1 g
F P
s
P
p
.002 w
.36859 .53525 m .41347 .56655 L .41827 .54728 L p
1 g
F P
s
P
p
.002 w
.41827 .54728 m .37798 .51903 L .36859 .53525 L p
1 g
F P
s
P
p
.002 w
.61402 .3267 m .58022 .29038 L .56507 .3033 L p
1 g
F P
s
P
p
.002 w
.52666 .28325 m .56507 .3033 L .58022 .29038 L p
1 g
F P
s
P
p
.002 w
.65741 .42593 m .65319 .37144 L .63378 .37184 L p
1 g
F P
s
P
p
.002 w
.61402 .3267 m .63378 .37184 L .65319 .37144 L p
1 g
F P
s
P
p
.002 w
.33761 .38067 m .33502 .43106 L .35315 .42488 L p
1 g
F P
s
P
p
.002 w
.35315 .42488 m .35548 .38135 L .33761 .38067 L p
1 g
F P
s
P
p
.002 w
.52623 .59624 m .58133 .57513 L .57179 .5595 L p
1 g
F P
s
P
p
.002 w
.57179 .5595 m .52063 .57906 L .52623 .59624 L p
1 g
F P
s
P
p
.002 w
.61432 .52495 m .57179 .5595 L .58133 .57513 L p
1 g
F P
s
P
p
.002 w
.58133 .57513 m .62715 .53792 L .61432 .52495 L p
1 g
F P
s
P
p
.002 w
.64391 .47889 m .61432 .52495 L .62715 .53792 L p
1 g
F P
s
P
p
.002 w
.58022 .29038 m .53585 .26709 L .52666 .28325 L p
1 g
F P
s
P
p
.002 w
.48332 .27692 m .52666 .28325 L .53585 .26709 L p
1 g
F P
s
P
p
.002 w
.46738 .59902 m .52623 .59624 L .52063 .57906 L p
1 g
F P
s
P
p
.002 w
.52063 .57906 m .466 .58157 L .46738 .59902 L p
1 g
F P
s
P
p
.002 w
.33634 .49069 m .36859 .53525 L .37798 .51903 L p
1 g
F P
s
P
p
.002 w
.37798 .51903 m .3491 .47891 L .33634 .49069 L p
1 g
F P
s
P
p
.002 w
.62715 .53792 m .65907 .48834 L .64391 .47889 L p
1 g
F P
s
P
p
.002 w
.65741 .42593 m .64391 .47889 L .65907 .48834 L p
1 g
F P
s
P
p
.002 w
.35685 .33343 m .33761 .38067 L .35548 .38135 L p
1 g
F P
s
P
p
.002 w
.35548 .38135 m .37214 .34059 L .35685 .33343 L p
1 g
F P
s
P
p
.002 w
.65319 .37144 m .63133 .32118 L .61402 .3267 L p
1 g
F P
s
P
p
.002 w
.58022 .29038 m .61402 .3267 L .63133 .32118 L p
1 g
F P
s
P
p
.002 w
.53585 .26709 m .48569 .25968 L .48332 .27692 L p
1 g
F P
s
P
p
.002 w
.43991 .28521 m .48332 .27692 L .48569 .25968 L p
1 g
F P
s
P
p
.002 w
.41075 .58294 m .46738 .59902 L .466 .58157 L p
1 g
F P
s
P
p
.002 w
.466 .58157 m .41347 .56655 L .41075 .58294 L p
1 g
F P
s
P
p
.002 w
.39072 .29479 m .35685 .33343 L .37214 .34059 L p
1 g
F P
s
P
p
.002 w
.37214 .34059 m .40138 .30726 L .39072 .29479 L p
1 g
F P
s
P
p
.002 w
.48569 .25968 m .43538 .26923 L .43991 .28521 L p
1 g
F P
s
P
p
.002 w
.40138 .30726 m .43991 .28521 L .43538 .26923 L p
1 g
F P
s
P
p
.002 w
.65907 .48834 m .67371 .4313 L .65741 .42593 L p
1 g
F P
s
P
p
.002 w
.65319 .37144 m .65741 .42593 L .67371 .4313 L p
1 g
F P
s
P
p
.002 w
.43538 .26923 m .39072 .29479 L .40138 .30726 L p
1 g
F P
s
P
p
.002 w
.32055 .43744 m .33634 .49069 L .3491 .47891 L p
1 g
F P
s
P
p
.002 w
.3491 .47891 m .33502 .43106 L .32055 .43744 L p
1 g
F P
s
P
p
.002 w
.36231 .54931 m .41075 .58294 L .41347 .56655 L p
1 g
F P
s
P
p
.002 w
.41347 .56655 m .36859 .53525 L .36231 .54931 L p
1 g
F P
s
P
p
.002 w
.63133 .32118 m .59382 .28067 L .58022 .29038 L p
1 g
F P
s
P
p
.002 w
.53585 .26709 m .58022 .29038 L .59382 .28067 L p
1 g
F P
s
P
p
.002 w
.67371 .4313 m .66928 .37258 L .65319 .37144 L p
1 g
F P
s
P
p
.002 w
.63133 .32118 m .65319 .37144 L .66928 .37258 L p
1 g
F P
s
P
p
.002 w
.32335 .38128 m .32055 .43744 L .33502 .43106 L p
1 g
F P
s
P
p
.002 w
.33502 .43106 m .33761 .38067 L .32335 .38128 L p
1 g
F P
s
P
p
.002 w
.53136 .6097 m .58909 .58755 L .58133 .57513 L p
1 g
F P
s
P
p
.002 w
.58133 .57513 m .52623 .59624 L .53136 .6097 L p
1 g
F P
s
P
p
.002 w
.62715 .53792 m .58133 .57513 L .58909 .58755 L p
1 g
F P
s
P
p
.002 w
.58909 .58755 m .63712 .54856 L .62715 .53792 L p
1 g
F P
s
P
p
.002 w
.65907 .48834 m .62715 .53792 L .63712 .54856 L p
1 g
F P
s
P
p
.002 w
.59382 .28067 m .54443 .25464 L .53585 .26709 L p
1 g
F P
s
P
p
.002 w
.48569 .25968 m .53585 .26709 L .54443 .25464 L p
1 g
F P
s
P
p
.002 w
.46968 .61268 m .53136 .6097 L .52623 .59624 L p
1 g
F P
s
P
p
.002 w
.52623 .59624 m .46738 .59902 L .46968 .61268 L p
1 g
F P
s
P
p
.002 w
.32744 .50132 m .36231 .54931 L .36859 .53525 L p
1 g
F P
s
P
p
.002 w
.36859 .53525 m .33634 .49069 L .32744 .50132 L p
1 g
F P
s
P
p
.002 w
.63712 .54856 m .67061 .49662 L .65907 .48834 L p
1 g
F P
s
P
p
.002 w
.67371 .4313 m .65907 .48834 L .67061 .49662 L p
1 g
F P
s
P
p
.002 w
.34476 .32857 m .32335 .38128 L .33761 .38067 L p
1 g
F P
s
P
p
.002 w
.33761 .38067 m .35685 .33343 L .34476 .32857 L p
1 g
F P
s
P
p
.002 w
.66928 .37258 m .64583 .31834 L .63133 .32118 L p
1 g
F P
s
P
p
.002 w
.59382 .28067 m .63133 .32118 L .64583 .31834 L p
1 g
F P
s
P
p
.002 w
.54443 .25464 m .48852 .2463 L .48569 .25968 L p
1 g
F P
s
P
p
.002 w
.43538 .26923 m .48569 .25968 L .48852 .2463 L p
1 g
F P
s
P
p
.002 w
.4103 .59591 m .46968 .61268 L .46738 .59902 L p
1 g
F P
s
P
p
.002 w
.46738 .59902 m .41075 .58294 L .4103 .59591 L p
1 g
F P
s
P
p
.002 w
.38254 .28543 m .34476 .32857 L .35685 .33343 L p
1 g
F P
s
P
p
.002 w
.35685 .33343 m .39072 .29479 L .38254 .28543 L p
1 g
F P
s
P
p
.002 w
.67061 .49662 m .68603 .43685 L .67371 .4313 L p
1 g
F P
s
P
p
.002 w
.66928 .37258 m .67371 .4313 L .68603 .43685 L p
1 g
F P
s
P
p
.002 w
.48852 .2463 m .43239 .25691 L .43538 .26923 L p
1 g
F P
s
P
p
.002 w
.39072 .29479 m .43538 .26923 L .43239 .25691 L p
1 g
F P
s
P
p
.002 w
.43239 .25691 m .38254 .28543 L .39072 .29479 L p
1 g
F P
s
P
p
.002 w
.31032 .44389 m .32744 .50132 L .33634 .49069 L p
1 g
F P
s
P
p
.002 w
.33634 .49069 m .32055 .43744 L .31032 .44389 L p
1 g
F P
s
P
p
.002 w
.35948 .56074 m .4103 .59591 L .41075 .58294 L p
1 g
F P
s
P
p
.002 w
.41075 .58294 m .36231 .54931 L .35948 .56074 L p
1 g
F P
s
P
p
.002 w
.64583 .31834 m .60544 .27458 L .59382 .28067 L p
1 g
F P
s
P
p
.002 w
.54443 .25464 m .59382 .28067 L .60544 .27458 L p
1 g
F P
s
P
p
.002 w
.68603 .43685 m .68148 .37531 L .66928 .37258 L p
1 g
F P
s
P
p
.002 w
.64583 .31834 m .66928 .37258 L .68148 .37531 L p
1 g
F P
s
P
p
.002 w
.31328 .38324 m .31032 .44389 L .32055 .43744 L p
1 g
F P
s
P
p
.002 w
.32055 .43744 m .32335 .38128 L .31328 .38324 L p
1 g
F P
s
P
p
.002 w
.53584 .61889 m .59477 .59625 L .58909 .58755 L p
1 g
F P
s
P
p
.002 w
.58909 .58755 m .53136 .6097 L .53584 .61889 L p
1 g
F P
s
P
p
.002 w
.63712 .54856 m .58909 .58755 L .59477 .59625 L p
1 g
F P
s
P
p
.002 w
.59477 .59625 m .64381 .55646 L .63712 .54856 L p
1 g
F P
s
P
p
.002 w
.67061 .49662 m .63712 .54856 L .64381 .55646 L p
1 g
F P
s
P
p
.002 w
.60544 .27458 m .55217 .2464 L .54443 .25464 L p
1 g
F P
s
P
p
.002 w
.48852 .2463 m .54443 .25464 L .55217 .2464 L p
1 g
F P
s
P
p
.002 w
.32286 .51047 m .35948 .56074 L .36231 .54931 L p
1 g
F P
s
P
p
.002 w
.36231 .54931 m .32744 .50132 L .32286 .51047 L p
1 g
F P
s
P
p
.002 w
.47289 .62198 m .53584 .61889 L .53136 .6097 L p
1 g
F P
s
P
p
.002 w
.53136 .6097 m .46968 .61268 L .47289 .62198 L p
1 g
F P
s
P
p
.002 w
.64381 .55646 m .67803 .50345 L .67061 .49662 L p
1 g
F P
s
P
p
.002 w
.68603 .43685 m .67061 .49662 L .67803 .50345 L p
1 g
F P
s
P
p
.002 w
.33637 .32626 m .31328 .38324 L .32335 .38128 L p
1 g
F P
s
P
p
.002 w
.32335 .38128 m .34476 .32857 L .33637 .32626 L p
1 g
F P
s
P
p
.002 w
.68148 .37531 m .65698 .31842 L .64583 .31834 L p
1 g
F P
s
P
p
.002 w
.60544 .27458 m .64583 .31834 L .65698 .31842 L p
1 g
F P
s
P
p
.002 w
.55217 .2464 m .49178 .23735 L .48852 .2463 L p
1 g
F P
s
P
p
.002 w
.43239 .25691 m .48852 .2463 L .49178 .23735 L p
1 g
F P
s
P
p
.002 w
.41228 .60492 m .47289 .62198 L .46968 .61268 L p
1 g
F P
s
P
p
.002 w
.46968 .61268 m .4103 .59591 L .41228 .60492 L p
1 g
F P
s
P
p
.002 w
.3772 .27961 m .33637 .32626 L .34476 .32857 L p
1 g
F P
s
P
p
.002 w
.34476 .32857 m .38254 .28543 L .3772 .27961 L p
1 g
F P
s
P
p
.002 w
.67803 .50345 m .69382 .44247 L .68603 .43685 L p
1 g
F P
s
P
p
.002 w
.68148 .37531 m .68603 .43685 L .69382 .44247 L p
1 g
F P
s
P
p
.002 w
.49178 .23735 m .4311 .24879 L .43239 .25691 L p
1 g
F P
s
P
p
.002 w
.38254 .28543 m .43239 .25691 L .4311 .24879 L p
1 g
F P
s
P
p
.002 w
.30484 .45024 m .32286 .51047 L .32744 .50132 L p
1 g
F P
s
P
p
.002 w
.32744 .50132 m .31032 .44389 L .30484 .45024 L p
1 g
F P
s
P
p
.002 w
.4311 .24879 m .3772 .27961 L .38254 .28543 L p
1 g
F P
s
P
p
.002 w
.36039 .56907 m .41228 .60492 L .4103 .59591 L p
1 g
F P
s
P
p
.002 w
.4103 .59591 m .35948 .56074 L .36039 .56907 L p
1 g
F P
s
P
p
.002 w
.65698 .31842 m .61468 .27248 L .60544 .27458 L p
1 g
F P
s
P
p
.002 w
.55217 .2464 m .60544 .27458 L .61468 .27248 L p
1 g
F P
s
P
p
.002 w
.69382 .44247 m .68923 .37966 L .68148 .37531 L p
1 g
F P
s
P
p
.002 w
.65698 .31842 m .68148 .37531 L .68923 .37966 L p
1 g
F P
s
P
p
.002 w
.3079 .38659 m .30484 .45024 L .31032 .44389 L p
1 g
F P
s
P
p
.002 w
.31032 .44389 m .31328 .38324 L .3079 .38659 L p
1 g
F P
s
P
p
.002 w
.53954 .62331 m .59811 .6008 L .59477 .59625 L p
1 g
F P
s
P
p
.002 w
.59477 .59625 m .53584 .61889 L .53954 .62331 L p
1 g
F P
s
P
p
.002 w
.64381 .55646 m .59477 .59625 L .59811 .6008 L p
1 g
F P
s
P
p
.002 w
.59811 .6008 m .64685 .56124 L .64381 .55646 L p
1 g
F P
s
P
p
.002 w
.67803 .50345 m .64381 .55646 L .64685 .56124 L p
1 g
F P
s
P
p
.002 w
.61468 .27248 m .55881 .24287 L .55217 .2464 L p
1 g
F P
s
P
p
.002 w
.49178 .23735 m .55217 .2464 L .55881 .24287 L p
1 g
F P
s
P
p
.002 w
.32298 .5178 m .36039 .56907 L .35948 .56074 L p
1 g
F P
s
P
p
.002 w
.35948 .56074 m .32286 .51047 L .32298 .5178 L p
1 g
F P
s
P
p
.002 w
.47699 .6264 m .53954 .62331 L .53584 .61889 L p
1 g
F P
s
P
p
.002 w
.53584 .61889 m .47289 .62198 L .47699 .6264 L p
1 g
F P
s
P
p
.002 w
.64685 .56124 m .68087 .50858 L .67803 .50345 L p
1 g
F P
s
P
p
.002 w
.69382 .44247 m .67803 .50345 L .68087 .50858 L p
1 g
F P
s
P
p
.002 w
.33214 .32674 m .3079 .38659 L .31328 .38324 L p
1 g
F P
s
P
p
.002 w
.31328 .38324 m .33637 .32626 L .33214 .32674 L p
1 g
F P
s
P
p
.002 w
.68923 .37966 m .66427 .32159 L .65698 .31842 L p
1 g
F P
s
P
p
.002 w
.61468 .27248 m .65698 .31842 L .66427 .32159 L p
1 g
F P
s
P
p
.002 w
.55881 .24287 m .49541 .23333 L .49178 .23735 L p
1 g
F P
s
P
p
.002 w
.4311 .24879 m .49178 .23735 L .49541 .23333 L p
1 g
F P
s
P
p
.002 w
.41678 .60948 m .47699 .6264 L .47289 .62198 L p
1 g
F P
s
P
p
.002 w
.47289 .62198 m .41228 .60492 L .41678 .60948 L p
1 g
F P
s
P
p
.002 w
.37503 .27772 m .33214 .32674 L .33637 .32626 L p
1 g
F P
s
P
p
.002 w
.33637 .32626 m .3772 .27961 L .37503 .27772 L p
1 g
F P
s
P
p
.002 w
.68087 .50858 m .69658 .448 L .69382 .44247 L p
1 g
F P
s
P
p
.002 w
.68923 .37966 m .69382 .44247 L .69658 .448 L p
1 g
F P
s
P
p
.002 w
.49541 .23333 m .43167 .24534 L .4311 .24879 L p
1 g
F P
s
P
p
.002 w
.3772 .27961 m .4311 .24879 L .43167 .24534 L p
1 g
F P
s
P
p
.002 w
.30457 .45632 m .32298 .5178 L .32286 .51047 L p
1 g
F P
s
P
p
.002 w
.32286 .51047 m .30484 .45024 L .30457 .45632 L p
1 g
F P
s
P
p
.002 w
.43167 .24534 m .37503 .27772 L .3772 .27961 L p
1 g
F P
s
P
p
.002 w
.36525 .57389 m .41678 .60948 L .41228 .60492 L p
1 g
F P
s
P
p
.002 w
.41228 .60492 m .36039 .56907 L .36525 .57389 L p
1 g
F P
s
P
p
.002 w
.66427 .32159 m .62112 .27468 L .61468 .27248 L p
1 g
F P
s
P
p
.002 w
.55881 .24287 m .61468 .27248 L .62112 .27468 L p
1 g
F P
s
P
p
.004 w
.30809 .52954 m
.31637 .52527 L
s
P
p
.004 w
.28489 .54151 m
.30809 .52954 L
s
P
p
.004 w
.26754 .55046 m
.28489 .54151 L
s
P
p
.002 w
.69658 .448 m .69204 .38562 L .68923 .37966 L p
1 g
F P
s
P
p
.002 w
.66427 .32159 m .68923 .37966 L .69204 .38562 L p
1 g
F P
s
P
p
.002 w
.3077 .39132 m .30457 .45632 L .30484 .45024 L p
1 g
F P
s
P
p
.002 w
.30484 .45024 m .3079 .38659 L .3077 .39132 L p
1 g
F P
s
P
p
.002 w
.54229 .6225 m .59884 .60077 L .59811 .6008 L p
1 g
F P
s
P
p
.002 w
.59811 .6008 m .53954 .62331 L .54229 .6225 L p
1 g
F P
s
P
p
.002 w
.64685 .56124 m .59811 .6008 L .59884 .60077 L p
1 g
F P
s
P
p
.002 w
.59884 .60077 m .6459 .56257 L .64685 .56124 L p
1 g
F P
s
P
p
.002 w
.68087 .50858 m .64685 .56124 L .6459 .56257 L p
1 g
F P
s
P
p
.002 w
.62112 .27468 m .56409 .24444 L .55881 .24287 L p
1 g
F P
s
P
p
.002 w
.49541 .23333 m .55881 .24287 L .56409 .24444 L p
1 g
F P
s
P
p
.002 w
.32813 .52298 m .36525 .57389 L .36039 .56907 L p
1 g
F P
s
P
p
.002 w
.36039 .56907 m .32298 .5178 L .32813 .52298 L p
1 g
F P
s
P
p
.002 w
.48192 .62548 m .54229 .6225 L .53954 .62331 L p
1 g
F P
s
P
p
.002 w
.53954 .62331 m .47699 .6264 L .48192 .62548 L p
1 g
F P
s
P
p
.002 w
.6459 .56257 m .67875 .51173 L .68087 .50858 L p
1 g
F P
s
P
p
.002 w
.69658 .448 m .68087 .50858 L .67875 .51173 L p
1 g
F P
s
P
p
.002 w
.33248 .33017 m .3077 .39132 L .3079 .38659 L p
1 g
F P
s
P
p
.002 w
.3079 .38659 m .33214 .32674 L .33248 .33017 L p
1 g
F P
s
P
p
.002 w
.69204 .38562 m .66726 .32796 L .66427 .32159 L p
1 g
F P
s
P
p
.002 w
.62112 .27468 m .66427 .32159 L .66726 .32796 L p
1 g
F P
s
P
p
.002 w
.56409 .24444 m .49933 .23471 L .49541 .23333 L p
1 g
F P
s
P
p
.002 w
.43167 .24534 m .49541 .23333 L .49933 .23471 L p
1 g
F P
s
P
p
.002 w
.42384 .60914 m .48192 .62548 L .47699 .6264 L p
1 g
F P
s
P
p
.002 w
.47699 .6264 m .41678 .60948 L .42384 .60914 L p
1 g
F P
s
P
p
.002 w
.37631 .28008 m .33248 .33017 L .33214 .32674 L p
1 g
F P
s
P
p
.002 w
.33214 .32674 m .37503 .27772 L .37631 .28008 L p
1 g
F P
s
P
p
.002 w
.67875 .51173 m .6939 .45328 L .69658 .448 L p
1 g
F P
s
P
p
.002 w
.69204 .38562 m .69658 .448 L .6939 .45328 L p
1 g
F P
s
P
p
.002 w
.30987 .46194 m .32813 .52298 L .32298 .5178 L p
1 g
F P
s
P
p
.002 w
.32298 .5178 m .30457 .45632 L .30987 .46194 L p
1 g
F P
s
P
p
.002 w
.49933 .23471 m .4342 .24698 L .43167 .24534 L p
1 g
F P
s
P
p
.002 w
.37503 .27772 m .43167 .24534 L .4342 .24698 L p
1 g
F P
s
P
p
.002 w
.4342 .24698 m .37631 .28008 L .37503 .27772 L p
1 g
F P
s
P
p
.002 w
.37418 .5748 m .42384 .60914 L .41678 .60948 L p
1 g
F P
s
P
p
.002 w
.41678 .60948 m .36525 .57389 L .37418 .5748 L p
1 g
F P
s
P
p
.002 w
.66726 .32796 m .62441 .28141 L .62112 .27468 L p
1 g
F P
s
P
p
.002 w
.56409 .24444 m .62112 .27468 L .62441 .28141 L p
1 g
F P
s
P
p
.002 w
.6939 .45328 m .6895 .39311 L .69204 .38562 L p
1 g
F P
s
P
p
.002 w
.66726 .32796 m .69204 .38562 L .6895 .39311 L p
1 g
F P
s
P
p
.002 w
.31302 .39738 m .30987 .46194 L .30457 .45632 L p
1 g
F P
s
P
p
.002 w
.30457 .45632 m .3077 .39132 L .31302 .39738 L p
1 g
F P
s
P
p
.002 w
.54395 .61615 m .59677 .59586 L .59884 .60077 L p
1 g
F P
s
P
p
.002 w
.59884 .60077 m .54229 .6225 L .54395 .61615 L p
1 g
F P
s
P
p
.002 w
.6459 .56257 m .59884 .60077 L .59677 .59586 L p
1 g
F P
s
P
p
.002 w
.62441 .28141 m .56777 .25141 L .56409 .24444 L p
1 g
F P
s
P
p
.002 w
.49933 .23471 m .56409 .24444 L .56777 .25141 L p
1 g
F P
s
P
p
.002 w
.59677 .59586 m .64073 .56018 L .6459 .56257 L p
1 g
F P
s
P
p
.002 w
.67875 .51173 m .6459 .56257 L .64073 .56018 L p
1 g
F P
s
P
p
.002 w
.33845 .52571 m .37418 .5748 L .36525 .57389 L p
1 g
F P
s
P
p
.002 w
.36525 .57389 m .32813 .52298 L .33845 .52571 L p
1 g
F P
s
P
p
.002 w
.48759 .61891 m .54395 .61615 L .54229 .6225 L p
1 g
F P
s
P
p
.002 w
.54229 .6225 m .48192 .62548 L .48759 .61891 L p
1 g
F P
s
P
p
.002 w
.64073 .56018 m .67139 .51269 L .67875 .51173 L p
1 g
F P
s
P
p
.002 w
.6939 .45328 m .67875 .51173 L .67139 .51269 L p
1 g
F P
s
P
p
.002 w
.33766 .33666 m .31302 .39738 L .3077 .39132 L p
1 g
F P
s
P
p
.002 w
.3077 .39132 m .33248 .33017 L .33766 .33666 L p
1 g
F P
s
P
p
.002 w
.6895 .39311 m .66557 .33756 L .66726 .32796 L p
1 g
F P
s
P
p
.002 w
.62441 .28141 m .66726 .32796 L .66557 .33756 L p
1 g
F P
s
P
p
.002 w
.43342 .60361 m .48759 .61891 L .48192 .62548 L p
1 g
F P
s
P
p
.002 w
.48192 .62548 m .42384 .60914 L .43342 .60361 L p
1 g
F P
s
P
p
.002 w
.56777 .25141 m .50344 .24179 L .49933 .23471 L p
1 g
F P
s
P
p
.002 w
.4342 .24698 m .49933 .23471 L .50344 .24179 L p
1 g
F P
s
P
p
.002 w
.38123 .2869 m .33766 .33666 L .33248 .33017 L p
1 g
F P
s
P
p
.002 w
.33248 .33017 m .37631 .28008 L .38123 .2869 L p
1 g
F P
s
P
p
.002 w
.67139 .51269 m .6855 .45812 L .6939 .45328 L p
1 g
F P
s
P
p
.002 w
.6895 .39311 m .6939 .45328 L .6855 .45812 L p
1 g
F P
s
P
p
.002 w
.32094 .46687 m .33845 .52571 L .32813 .52298 L p
1 g
F P
s
P
p
.002 w
.32813 .52298 m .30987 .46194 L .32094 .46687 L p
1 g
F P
s
P
p
.002 w
.50344 .24179 m .43875 .25401 L .4342 .24698 L p
1 g
F P
s
P
p
.002 w
.37631 .28008 m .4342 .24698 L .43875 .25401 L p
1 g
F P
s
P
p
.002 w
.43875 .25401 m .38123 .2869 L .37631 .28008 L p
1 g
F P
s
P
p
.002 w
.66557 .33756 m .62423 .29275 L .62441 .28141 L p
1 g
F P
s
P
p
.002 w
.56777 .25141 m .62441 .28141 L .62423 .29275 L p
1 g
F P
s
P
p
.002 w
.38717 .57154 m .43342 .60361 L .42384 .60914 L p
1 g
F P
s
P
p
.002 w
.42384 .60914 m .37418 .5748 L .38717 .57154 L p
1 g
F P
s
P
p
.002 w
.6855 .45812 m .68133 .40202 L .6895 .39311 L p
1 g
F P
s
P
p
.002 w
.66557 .33756 m .6895 .39311 L .68133 .40202 L p
1 g
F P
s
P
p
.002 w
.32406 .40468 m .32094 .46687 L .30987 .46194 L p
1 g
F P
s
P
p
.002 w
.30987 .46194 m .31302 .39738 L .32406 .40468 L p
1 g
F P
s
P
p
.002 w
.5444 .60409 m .59178 .58591 L .59677 .59586 L p
1 g
F P
s
P
p
.002 w
.59677 .59586 m .54395 .61615 L .5444 .60409 L p
1 g
F P
s
P
p
.002 w
.64073 .56018 m .59677 .59586 L .59178 .58591 L p
1 g
F P
s
P
p
.002 w
.62423 .29275 m .56962 .26392 L .56777 .25141 L p
1 g
F P
s
P
p
.002 w
.50344 .24179 m .56777 .25141 L .56962 .26392 L p
1 g
F P
s
P
p
.002 w
.35397 .52574 m .38717 .57154 L .37418 .5748 L p
1 g
F P
s
P
p
.002 w
.37418 .5748 m .33845 .52571 L .35397 .52574 L p
1 g
F P
s
P
p
.002 w
.59178 .58591 m .63123 .55389 L .64073 .56018 L p
1 g
F P
s
P
p
.002 w
.67139 .51269 m .64073 .56018 L .63123 .55389 L p
1 g
F P
s
P
p
.002 w
.49386 .60651 m .5444 .60409 L .54395 .61615 L p
1 g
F P
s
P
p
.002 w
.54395 .61615 m .48759 .61891 L .49386 .60651 L p
1 g
F P
s
P
p
.002 w
.63123 .55389 m .6587 .51128 L .67139 .51269 L p
1 g
F P
s
P
p
.002 w
.6855 .45812 m .67139 .51269 L .6587 .51128 L p
1 g
F P
s
P
p
.002 w
.34786 .34619 m .32406 .40468 L .31302 .39738 L p
1 g
F P
s
P
p
.002 w
.31302 .39738 m .33766 .33666 L .34786 .34619 L p
1 g
F P
s
P
p
.002 w
.68133 .40202 m .65895 .35029 L .66557 .33756 L p
1 g
F P
s
P
p
.002 w
.62423 .29275 m .66557 .33756 L .65895 .35029 L p
1 g
F P
s
P
p
.002 w
.44536 .59274 m .49386 .60651 L .48759 .61891 L p
1 g
F P
s
P
p
.002 w
.48759 .61891 m .43342 .60361 L .44536 .59274 L p
1 g
F P
s
P
p
.002 w
.56962 .26392 m .50763 .25471 L .50344 .24179 L p
1 g
F P
s
P
p
.002 w
.43875 .25401 m .50344 .24179 L .50763 .25471 L p
1 g
F P
s
P
p
.002 w
.6587 .51128 m .67128 .46236 L .6855 .45812 L p
1 g
F P
s
P
p
.002 w
.68133 .40202 m .6855 .45812 L .67128 .46236 L p
1 g
F P
s
P
p
.002 w
.38987 .29826 m .34786 .34619 L .33766 .33666 L p
1 g
F P
s
P
p
.002 w
.33766 .33666 m .38123 .2869 L .38987 .29826 L p
1 g
F P
s
P
p
.002 w
.33777 .47093 m .35397 .52574 L .33845 .52571 L p
1 g
F P
s
P
p
.002 w
.33845 .52571 m .32094 .46687 L .33777 .47093 L p
1 g
F P
s
P
p
.004 w
.31637 .52527 m
.32894 .51878 L
s
P
p
.002 w
.50763 .25471 m .44529 .26655 L .43875 .25401 L p
1 g
F P
s
P
p
.002 w
.38123 .2869 m .43875 .25401 L .44529 .26655 L p
1 g
F P
s
P
p
.002 w
.44529 .26655 m .38987 .29826 L .38123 .2869 L p
1 g
F P
s
P
p
.002 w
.65895 .35029 m .62037 .30862 L .62423 .29275 L p
1 g
F P
s
P
p
.002 w
.56962 .26392 m .62423 .29275 L .62037 .30862 L p
1 g
F P
s
P
p
.002 w
.40403 .56395 m .44536 .59274 L .43342 .60361 L p
1 g
F P
s
P
p
.002 w
.43342 .60361 m .38717 .57154 L .40403 .56395 L p
1 g
F P
s
P
p
.002 w
.67128 .46236 m .66746 .41213 L .68133 .40202 L p
1 g
F P
s
P
p
.002 w
.65895 .35029 m .68133 .40202 L .66746 .41213 L p
1 g
F P
s
P
p
.002 w
.34078 .41303 m .33777 .47093 L .32094 .46687 L p
1 g
F P
s
P
p
.002 w
.32094 .46687 m .32406 .40468 L .34078 .41303 L p
1 g
F P
s
P
p
.002 w
.37446 .52293 m .40403 .56395 L .38717 .57154 L p
1 g
F P
s
P
p
.002 w
.38717 .57154 m .35397 .52574 L .37446 .52293 L p
1 g
F P
s
P
p
.002 w
.62037 .30862 m .56947 .28189 L .56962 .26392 L p
1 g
F P
s
P
p
.002 w
.50763 .25471 m .56962 .26392 L .56947 .28189 L p
1 g
F P
s
P
p
.002 w
.54353 .58636 m .58386 .57092 L .59178 .58591 L p
1 g
F P
s
P
p
.002 w
.59178 .58591 m .5444 .60409 L .54353 .58636 L p
1 g
F P
s
P
p
.002 w
.63123 .55389 m .59178 .58591 L .58386 .57092 L p
1 g
F P
s
P
p
.002 w
.58386 .57092 m .61742 .54367 L .63123 .55389 L p
1 g
F P
s
P
p
.002 w
.6587 .51128 m .63123 .55389 L .61742 .54367 L p
1 g
F P
s
P
p
.002 w
.50056 .58836 m .54353 .58636 L .5444 .60409 L p
1 g
F P
s
P
p
.002 w
.5444 .60409 m .49386 .60651 L .50056 .58836 L p
1 g
F P
s
P
p
.002 w
.61742 .54367 m .64075 .5074 L .6587 .51128 L p
1 g
F P
s
P
p
.002 w
.67128 .46236 m .6587 .51128 L .64075 .5074 L p
1 g
F P
s
P
p
.002 w
.66746 .41213 m .64733 .3659 L .65895 .35029 L p
1 g
F P
s
P
p
.002 w
.62037 .30862 m .65895 .35029 L .64733 .3659 L p
1 g
F P
s
P
p
.002 w
.36302 .35862 m .34078 .41303 L .32406 .40468 L p
1 g
F P
s
P
p
.002 w
.32406 .40468 m .34786 .34619 L .36302 .35862 L p
1 g
F P
s
P
p
.002 w
.45939 .57657 m .50056 .58836 L .49386 .60651 L p
1 g
F P
s
P
p
.002 w
.49386 .60651 m .44536 .59274 L .45939 .57657 L p
1 g
F P
s
P
p
.002 w
.56947 .28189 m .51175 .27342 L .50763 .25471 L p
1 g
F P
s
P
p
.002 w
.44529 .26655 m .50763 .25471 L .51175 .27342 L p
1 g
F P
s
P
p
.002 w
.36012 .47391 m .37446 .52293 L .35397 .52574 L p
1 g
F P
s
P
p
.004 w
.36744 .49892 m
.5 .43051 L
s
P
p
.002 w
.35397 .52574 m .33777 .47093 L .36012 .47391 L p
1 g
F P
s
P
p
.004 w
.35255 .5066 m
.35371 .506 L
s
P
p
.004 w
.32894 .51878 m
.34679 .50957 L
s
P
p
.004 w
.34679 .50957 m
.35255 .5066 L
s
P
p
.002 w
.64075 .5074 m .65137 .4658 L .67128 .46236 L p
1 g
F P
s
P
p
.002 w
.66746 .41213 m .67128 .46236 L .65137 .4658 L p
1 g
F P
s
P
p
.002 w
.40215 .31403 m .36302 .35862 L .34786 .34619 L p
1 g
F P
s
P
p
.002 w
.34786 .34619 m .38987 .29826 L .40215 .31403 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.51175 .27342 m .45373 .28449 L .44529 .26655 L p
1 g
F P
s
P
p
.002 w
.38987 .29826 m .44529 .26655 L .45373 .28449 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.45373 .28449 m .40215 .31403 L .38987 .29826 L p
1 g
F P
s
P
p
.002 w
.64733 .3659 m .61274 .32876 L .62037 .30862 L p
1 g
F P
s
P
p
.002 w
.56947 .28189 m .62037 .30862 L .61274 .32876 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.4244 .55205 m .45939 .57657 L .44536 .59274 L p
1 g
F P
s
P
p
.002 w
.44536 .59274 m .40403 .56395 L .4244 .55205 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.65137 .4658 m .64802 .42317 L .66746 .41213 L p
1 g
F P
s
P
p
.002 w
.64733 .3659 m .66746 .41213 L .64802 .42317 L p
1 g
F P
s
P
p
.002 w
.36294 .42221 m .36012 .47391 L .33777 .47093 L p
1 g
F P
s
P
p
.002 w
.33777 .47093 m .34078 .41303 L .36294 .42221 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.39946 .5172 m .4244 .55205 L .40403 .56395 L p
1 g
F P
s
P
p
.002 w
.40403 .56395 m .37446 .52293 L .39946 .5172 L p
1 g
F P
s
P
p
.002 w
.61274 .32876 m .56721 .305 L .56947 .28189 L p
1 g
F P
s
P
p
.002 w
.51175 .27342 m .56947 .28189 L .56721 .305 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5316 .57412 L p
1 g
F P
s
P
p
.54854 .56129 m .5316 .57412 L .53734 .57091 L 1 g
F
P
p
.54353 .58636 m .5272 .57659 L .5316 .57412 L 1 g
F
P
p
.002 w
.54181 .56842 m .54206 .57102 L p
.5316 .57412 L 1 g
F P
s
P
p
.002 w
.54206 .57102 m .54353 .58636 L p
.5316 .57412 L 1 g
F P
s
P
p
.002 w
.5316 .57412 m .53128 .57265 L p
.52401 .57638 L 1 g
F P
s
P
p
.54 .56943 m .53192 .57557 L .53871 .57066 L 1 g
F
P
p
.54854 .56129 m .53734 .57091 L .54 .56943 L 1 g
F
P
p
.53734 .57091 m .53192 .57557 L .54 .56943 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58027 L p
1 g
F P
s
P
p
.53128 .57265 m .51091 .58027 L .52401 .57638 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.54353 .58636 m .50056 .58836 L .50273 .58095 L p
1 g
F P
s
P
p
.002 w
.51091 .58027 m .51079 .57862 L p
.4999 .5808 L 1 g
F P
s
P
p
.002 w
.50273 .58095 m .50056 .58836 L p
.49449 .5805 L 1 g
F P
s
P
p
.4999 .5808 m .49653 .58147 L .50273 .58095 L 1 g
F
P
p
.4999 .5808 m .50273 .58095 L .51091 .58027 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58021 L p
1 g
F P
s
P
p
.002 w
.50056 .58836 m .46804 .57905 L p
.48909 .58021 L 1 g
F P
s
P
p
.49567 .58203 m .48909 .58021 L .49449 .5805 L 1 g
F
P
p
.50056 .58836 m .48909 .58021 L .49567 .58203 L 1 g
F
P
p
.002 w
.48909 .58021 m .48921 .57862 L p
.4809 .57794 L 1 g
F P
s
P
p
.51079 .57862 m .48909 .58021 L .4999 .5808 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46833 .57446 L p
1 g
F P
s
P
p
.48921 .57862 m .46833 .57446 L .4809 .57794 L 1 g
F
P
p
.49449 .5805 m .48722 .57969 L .47512 .55542 L 1 g
F
P
p
.002 w
.45939 .57657 m .46222 .57277 L p
.46833 .57446 L 1 g
F P
s
P
p
.47545 .57837 m .45939 .57657 L .46833 .57446 L 1 g
F
P
p
.002 w
.46833 .57446 m .46872 .57265 L p
.45964 .56902 L 1 g
F P
s
P
p
.002 w
.4631 .57158 m .45939 .57657 L p
.45656 .56674 L 1 g
F P
s
P
p
.002 w
.45939 .57657 m .4244 .55205 L .43078 .54767 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.45939 .57657 m .43078 .54767 L .45097 .56261 L 1 g
F
P
p
.45783 .57115 m .45097 .56261 L .45656 .56674 L 1 g
F
P
p
.45939 .57657 m .45097 .56261 L .45783 .57115 L 1 g
F
P
p
.002 w
.45097 .56261 m .45146 .56129 L p
.44635 .55685 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45097 .56261 L p
1 g
F P
s
P
p
.002 w
.45097 .56261 m .45002 .56518 L p
.45964 .56902 L 1 g
F P
s
P
p
.46872 .57265 m .45097 .56261 L .45964 .56902 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4385 .54707 L p
1 g
F P
s
P
p
.002 w
.43078 .54767 m .43607 .54404 L p
.4385 .54707 L 1 g
F P
s
P
p
.45097 .56261 m .44196 .55594 L .4385 .54707 L 1 g
F
P
p
.44196 .55594 m .43078 .54767 L .4385 .54707 L 1 g
F
P
p
.002 w
.4385 .54707 m .43925 .54566 L p
.43568 .5386 L 1 g
F P
s
P
p
.4244 .55205 m .42796 .5119 L .43273 .5284 L 1 g
F
P
p
.002 w
.43706 .54336 m .43189 .54691 L p
.43273 .5284 L 1 g
F P
s
P
p
.002 w
.43189 .54691 m .4244 .55205 L p
.43273 .5284 L 1 g
F P
s
P
p
.002 w
.43273 .5284 m .43346 .52734 L p
.43317 .51891 L 1 g
F P
s
P
p
.43568 .5386 m .43706 .54336 L .4385 .54707 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.45146 .56129 m .4385 .54707 L .44635 .55685 L 1 g
F
P
p
.45097 .56261 m .4385 .54707 L .44771 .53605 L 1 g
F
P
p
.002 w
.43607 .54404 m .43706 .54336 L p
.4385 .54707 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43177 .5298 L p
1 g
F P
s
P
p
.43925 .54566 m .43177 .5298 L .4336 .53447 L 1 g
F
P
p
.002 w
.43706 .54336 m .44771 .53605 L p
.4385 .54707 L 1 g
F P
s
P
p
.002 w
.43177 .5298 m .43146 .53025 L p
.4336 .53447 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43385 .50946 L p
1 g
F P
s
P
p
.002 w
.42825 .50864 m .43409 .50657 L p
.43385 .50946 L 1 g
F P
s
P
p
.002 w
.43331 .51576 m .43184 .51369 L p
.43385 .50946 L 1 g
F P
s
P
p
.002 w
.43184 .51369 m .42825 .50864 L p
.43385 .50946 L 1 g
F P
s
P
p
.002 w
.43385 .50946 m .43485 .50826 L p
.43814 .50057 L 1 g
F P
s
P
p
.002 w
.43543 .5061 m .42825 .50864 L p
.43786 .49592 L 1 g
F P
s
P
p
.43786 .49592 m .44511 .48631 L .44271 .49122 L 1 g
F
P
p
.43786 .49592 m .44271 .49122 L .43543 .5061 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43346 .52734 m .43385 .50946 L .43356 .51278 L 1 g
F
P
p
.43346 .52734 m .43358 .50977 L .43317 .51891 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.43331 .51576 m .43385 .50946 L .4599 .49746 L 1 g
F
P
p
.002 w
.43409 .50657 m .43543 .5061 L p
.43385 .50946 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44224 .49172 L p
1 g
F P
s
P
p
.43485 .50826 m .44224 .49172 L .43896 .49866 L 1 g
F
P
p
.43814 .50057 m .43543 .5061 L .43385 .50946 L 1 g
F
P
p
.002 w
.43543 .5061 m .4599 .49746 L p
.43385 .50946 L 1 g
F P
s
P
p
.002 w
.44224 .49172 m .44166 .49233 L p
.43896 .49866 L 1 g
F P
s
P
p
.002 w
.44271 .49122 m .44339 .4905 L p
.45045 .48373 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4599 .49746 m .43543 .5061 L p
.44603 .48802 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45757 .47683 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.45487 .47946 m .45757 .47683 L .49011 .4726 L 1 g
F
P
p
.002 w
.45757 .47683 m .45826 .47608 L p
.4679 .47185 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49011 .4726 m .46257 .47443 L p
.47755 .46718 L 1 g
F P
s
P
p
.002 w
.47755 .46718 m .47786 .46667 L p
.49157 .46527 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55359 .49163 m .54422 .49925 L .52751 .46974 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55359 .49163 m .5287 .4703 L p
.54233 .47673 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56605 .50933 L p
1 g
F P
s
P
p
.002 w
.57805 .51212 m .57035 .51838 L p
.56605 .50933 L 1 g
F P
s
P
p
.56588 .50749 m .56605 .50933 L .56502 .50716 L 1 g
F
P
p
.57805 .51212 m .56605 .50933 L .56588 .50749 L 1 g
F
P
p
.002 w
.56605 .50933 m .56515 .50826 L p
.56716 .52127 L 1 g
F P
s
P
p
.002 w
.56714 .52099 m .57805 .51212 L p
.56741 .5275 L 1 g
F P
s
P
p
.56716 .52127 m .56719 .52151 L .56714 .52099 L 1 g
F
P
p
.56716 .52127 m .56714 .52099 L .56605 .50933 L 1 g
F
P
p
.002 w
.57805 .51212 m .59955 .52964 L p
.56741 .5275 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56151 .54709 L p
1 g
F P
s
P
p
.002 w
.56511 .53667 m .5731 .55112 L p
.56185 .54611 L 1 g
F P
s
P
p
.56654 .52734 m .56151 .54709 L .56453 .53837 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5492 .56307 L p
1 g
F P
s
P
p
.54799 .56447 m .54862 .56374 L .5731 .55112 L 1 g
F
P
p
.56075 .54566 m .5492 .56307 L .551 .56098 L 1 g
F
P
p
.002 w
.55281 .55887 m .55744 .55711 L p
.5492 .56307 L 1 g
F P
s
P
p
.56075 .54566 m .551 .56098 L .55538 .55539 L 1 g
F
P
p
.002 w
.55744 .55711 m .5731 .55112 L p
.54862 .56374 L 1 g
F P
s
P
p
.5492 .56307 m .55744 .55711 L .54862 .56374 L 1 g
F
P
p
.551 .56098 m .54937 .56353 L .55281 .55887 L 1 g
F
P
p
.551 .56098 m .55281 .55887 L .55538 .55539 L 1 g
F
P
p
.54741 .56436 m .5492 .56307 L .54862 .56374 L 1 g
F
P
p
.002 w
.5731 .55112 m .58386 .57092 L p
.54799 .56447 L 1 g
F P
s
P
p
.54799 .56447 m .54741 .56436 L .54862 .56374 L 1 g
F
P
p
.002 w
.58386 .57092 m .54353 .58636 L .54181 .56842 L p
1 g
F P
s
P
p
.58386 .57092 m .54181 .56842 L .54741 .56436 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5492 .56307 L p
1 g
F P
s
P
p
.002 w
.5492 .56307 m .54854 .56129 L p
.53871 .57066 L 1 g
F P
s
P
p
.53871 .57066 m .5322 .57686 L .5492 .56307 L 1 g
F
P
p
.002 w
.54181 .56842 m .54132 .56327 L p
.54741 .56436 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54132 .56327 m .55281 .55887 L p
.54741 .56436 L 1 g
F P
s
P
p
.54741 .56436 m .55281 .55887 L .5492 .56307 L 1 g
F
P
p
.002 w
.5731 .55112 m .55281 .55887 L p
.56214 .54624 L 1 g
F P
s
P
p
.002 w
.54937 .56353 m .54998 .56518 L p
.55462 .55678 L 1 g
F P
s
P
p
.55538 .55539 m .55281 .55887 L .55462 .55678 L 1 g
F
P
p
.55281 .55887 m .54937 .56353 L .55462 .55678 L 1 g
F
P
p
.002 w
.5492 .56307 m .54937 .56353 L p
.551 .56098 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54132 .56327 m .53776 .53537 L p
.56214 .54624 L 1 g
F P
s
P
p
.002 w
.55281 .55887 m .54132 .56327 L p
.56214 .54624 L 1 g
F P
s
P
p
.002 w
.56151 .54709 m .56257 .5491 L p
.56453 .53837 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.59955 .52964 m .5731 .55112 L .56511 .53667 L p
1 g
F P
s
P
p
.59955 .52964 m .56777 .53613 L .5678 .52753 L 1 g
F
P
p
.56777 .53613 m .56511 .53667 L .56746 .52868 L 1 g
F
P
p
.56777 .53613 m .56746 .52868 L .5678 .52753 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56746 .52868 L p
1 g
F P
s
P
p
.56515 .50826 m .56746 .52868 L .56716 .52127 L 1 g
F
P
p
.002 w
.56746 .52868 m .56654 .52734 L p
.56438 .53916 L 1 g
F P
s
P
p
.002 w
.56511 .53667 m .55976 .52699 L p
.5678 .52753 L 1 g
F P
s
P
p
.002 w
.56746 .52868 m .56854 .53025 L p
.56716 .52127 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56746 .52868 L p
1 g
F P
s
P
p
.56438 .53916 m .56257 .5491 L .56746 .52868 L 1 g
F
P
p
.002 w
.53776 .53537 m .55976 .52699 L .56511 .53667 L p
1 g
F P
s
P
p
.56185 .54611 m .53776 .53537 L .56511 .53667 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55976 .52699 m .56714 .52099 L p
.56741 .5275 L 1 g
F P
s
P
p
.55661 .4905 m .56605 .50933 L .56203 .50087 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.57035 .51838 m .55976 .52699 L p
.56502 .50716 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56605 .50933 L p
1 g
F P
s
P
p
.56719 .52151 m .56854 .53025 L .56605 .50933 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.55661 .4905 m .56203 .50087 L .56032 .49726 L 1 g
F
P
p
.002 w
.55754 .49149 m .55661 .4905 L p
.56032 .49726 L 1 g
F P
s
P
p
.002 w
.59071 .49233 m .57805 .51212 L .56032 .49726 L p
1 g
F P
s
P
p
.002 w
.56032 .49726 m .55359 .49163 L p
.55764 .4917 L 1 g
F P
s
P
p
.59071 .49233 m .56032 .49726 L .55764 .4917 L 1 g
F
P
p
.002 w
.56032 .49726 m .57805 .51212 L p
.56502 .50716 L 1 g
F P
s
P
p
.56032 .49726 m .56713 .51061 L .55761 .49156 L 1 g
F
P
p
.56203 .50087 m .56228 .50134 L .56032 .49726 L 1 g
F
P
p
.56228 .50134 m .56713 .51061 L .56032 .49726 L 1 g
F
P
p
.002 w
.55761 .49156 m .55754 .49149 L p
.56032 .49726 L 1 g
F P
s
P
p
.002 w
.55359 .49163 m .55515 .48918 L p
.55754 .49149 L 1 g
F P
s
P
p
.55776 .4917 m .55764 .4917 L .55754 .49149 L 1 g
F
P
p
.55764 .4917 m .55359 .49163 L .55754 .49149 L 1 g
F
P
p
.002 w
.54422 .49925 m .55359 .49163 L .56032 .49726 L p
1 g
F P
s
P
p
.56502 .50716 m .54422 .49925 L .56032 .49726 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55761 .49156 L p
1 g
F P
s
P
p
.002 w
.56605 .50933 m .56713 .51061 L p
.56203 .50087 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55976 .52699 m .54422 .49925 L p
.56502 .50716 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55754 .49149 L p
1 g
F P
s
P
p
.002 w
.55754 .49149 m .55773 .49168 L p
.55618 .49017 L 1 g
F P
s
P
p
.54174 .47608 m .55754 .49149 L .55618 .49017 L 1 g
F
P
p
.002 w
.56005 .48148 m .59071 .49233 L p
.55776 .4917 L 1 g
F P
s
P
p
.54174 .47608 m .55773 .49168 L .55122 .48537 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55515 .48918 m .56005 .48148 L p
.55776 .4917 L 1 g
F P
s
P
p
.002 w
.55515 .48918 m .55359 .49163 L p
.54233 .47673 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54233 .47673 L p
1 g
F P
s
P
p
.002 w
.54233 .47673 m .54174 .47608 L p
.55122 .48537 L 1 g
F P
s
P
p
.55122 .48537 m .55834 .49233 L .54233 .47673 L 1 g
F
P
p
.002 w
.56005 .48148 m .55829 .48425 L p
.54164 .47605 L 1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52701 .46885 m .5389 .47339 L p
.54164 .47605 L 1 g
F P
s
P
p
.002 w
.5389 .47339 m .56005 .48148 L p
.54164 .47605 L 1 g
F P
s
P
p
.002 w
.55829 .48425 m .55515 .48918 L p
.54233 .47673 L 1 g
F P
s
P
p
.002 w
.55773 .49168 m .55834 .49233 L p
.55122 .48537 L 1 g
F P
s
P
p
.002 w
.54233 .47673 m .54236 .47676 L p
.54181 .47648 L 1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .54181 .47648 L 1 g
F
P
p
.52214 .46667 m .54236 .47676 L .54115 .47618 L 1 g
F
P
p
.52214 .46667 m .54242 .47682 L .53426 .47294 L 1 g
F
P
p
.002 w
.5287 .4703 m .55359 .49163 L p
.52751 .46974 L 1 g
F P
s
P
p
.002 w
.54422 .49925 m .53294 .50353 L .52713 .46956 L p
1 g
F P
s
P
p
.002 w
.52751 .46974 m .54422 .49925 L p
.52713 .46956 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .5225 .46727 L p
1 g
F P
s
P
p
.002 w
.53294 .50353 m .52096 .50401 L .52691 .46945 L p
1 g
F P
s
P
p
.52214 .46667 m .53487 .47326 L .52456 .46829 L 1 g
F
P
p
.53487 .47326 m .52691 .46945 L .52456 .46829 L 1 g
F
P
p
.002 w
.50957 .50062 m .49998 .49372 L .52655 .46928 L p
1 g
F P
s
P
p
.002 w
.52655 .46928 m .52701 .46885 L .52673 .46936 L p
1 g
F P
s
P
p
.002 w
.52673 .46936 m .50957 .50062 L p
.52655 .46928 L 1 g
F P
s
P
p
.002 w
.49998 .49372 m .49325 .48403 L .52631 .46916 L p
1 g
F P
s
P
p
.002 w
.52631 .46916 m .52701 .46885 L .52655 .46928 L p
1 g
F P
s
P
p
.002 w
.52655 .46928 m .49998 .49372 L p
.52631 .46916 L 1 g
F P
s
P
p
.52664 .46932 m .52655 .46928 L .52644 .46923 L 1 g
F
P
p
.52673 .46936 m .52668 .46934 L .52664 .46932 L 1 g
F
P
p
.52668 .46934 m .52655 .46928 L .52664 .46932 L 1 g
F
P
p
.002 w
.52691 .46945 m .52096 .50401 L p
.52673 .46936 L 1 g
F P
s
P
p
.52691 .46945 m .52681 .46941 L .52673 .46936 L 1 g
F
P
p
.52681 .46941 m .52655 .46928 L .52673 .46936 L 1 g
F
P
p
.002 w
.49325 .48403 m .49011 .4726 L .52591 .46896 L p
1 g
F P
s
P
p
.52691 .46945 m .52655 .46928 L .52456 .46829 L 1 g
F
P
p
.002 w
.52591 .46896 m .52701 .46885 L .52631 .46916 L p
1 g
F P
s
P
p
.002 w
.52631 .46916 m .49325 .48403 L p
.52591 .46896 L 1 g
F P
s
P
p
.52655 .46928 m .52644 .46923 L .52591 .46896 L 1 g
F
P
p
.52655 .46928 m .52591 .46896 L .52456 .46829 L 1 g
F
P
p
.002 w
.52096 .50401 m .50957 .50062 L .52673 .46936 L p
1 g
F P
s
P
p
.002 w
.52673 .46936 m .52701 .46885 L .52691 .46945 L p
1 g
F P
s
P
p
.002 w
.52691 .46945 m .52701 .46885 L .52713 .46956 L p
1 g
F P
s
P
p
.002 w
.52713 .46956 m .53294 .50353 L p
.52691 .46945 L 1 g
F P
s
P
p
.53487 .47326 m .54159 .47674 L .52655 .46928 L 1 g
F
P
p
.002 w
.5225 .46727 m .52214 .46667 L p
.52456 .46829 L 1 g
F P
s
P
p
.002 w
.52507 .46765 m .52701 .46885 L .52456 .46829 L p
1 g
F P
s
P
p
.002 w
.52456 .46829 m .51536 .46621 L p
.5225 .46727 L 1 g
F P
s
P
p
.5225 .46727 m .52507 .46765 L .52456 .46829 L 1 g
F
P
p
.49061 .46543 m .5 .46391 L .52456 .46829 L 1 g
F
P
p
.002 w
.51536 .46621 m .52456 .46829 L p
.5 .46391 L 1 g
F P
s
P
p
.49061 .46543 m .52456 .46829 L .52537 .4687 L 1 g
F
P
p
.002 w
.52701 .46885 m .49011 .4726 L .49061 .46543 L p
1 g
F P
s
P
p
.52456 .46829 m .54302 .47747 L .5225 .46727 L 1 g
F
P
p
.54159 .47674 m .54239 .47715 L .52456 .46829 L 1 g
F
P
p
.54239 .47715 m .54302 .47747 L .52456 .46829 L 1 g
F
P
p
.002 w
.5225 .46727 m .5225 .46727 L p
.52456 .46829 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.49564 .44952 m .52507 .46765 L p
.52201 .46703 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.49094 .46066 m .4941 .45316 L p
.52201 .46703 L 1 g
F P
s
P
p
.002 w
.4941 .45316 m .49564 .44952 L p
.52201 .46703 L 1 g
F P
s
P
p
.5 .4634 m .5225 .46727 L .52239 .46725 L 1 g
F
P
p
.5 .4634 m .5225 .46727 L .5119 .46569 L 1 g
F
P
p
.002 w
.51536 .46621 m .49094 .46066 L p
.52507 .46765 L 1 g
F P
s
P
p
.002 w
.5225 .46727 m .5225 .46727 L p
.52239 .46725 L 1 g
F P
s
P
p
.002 w
.5225 .46727 m .52282 .46778 L p
.5119 .46569 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .4634 L p
.5119 .46569 L 1 g
F P
s
P
p
.5119 .46569 m .52282 .46778 L .5 .46391 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46417 L p
1 g
F P
s
P
p
.002 w
.5 .46417 m .5 .46442 L p
.49243 .46519 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46417 L .49243 .46519 L 1 g
F
P
p
.4679 .47185 m .46257 .47443 L .45757 .47683 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47749 .46728 L p
1 g
F P
s
P
p
.002 w
.47749 .46728 m .47718 .46778 L p
.46849 .47159 L 1 g
F P
s
P
p
.45826 .47608 m .47749 .46728 L .46849 .47159 L 1 g
F
P
p
.002 w
.45363 .47503 m .45985 .47461 L p
.45757 .47683 L 1 g
F P
s
P
p
.44339 .4905 m .45757 .47683 L .45601 .47835 L 1 g
F
P
p
.44339 .4905 m .45745 .47696 L .45045 .48373 L 1 g
F
P
p
.002 w
.45487 .47946 m .45454 .47828 L p
.45757 .47683 L 1 g
F P
s
P
p
.002 w
.45454 .47828 m .45363 .47503 L p
.45757 .47683 L 1 g
F P
s
P
p
.002 w
.46257 .47443 m .45363 .47503 L p
.4722 .46789 L 1 g
F P
s
P
p
.4722 .46789 m .49093 .4607 L .47755 .46718 L 1 g
F
P
p
.4722 .46789 m .47755 .46718 L .46257 .47443 L 1 g
F
P
p
.002 w
.49094 .46066 m .50306 .46341 L p
.5 .46391 L 1 g
F P
s
P
p
.49157 .46527 m .49061 .46543 L .47755 .46718 L 1 g
F
P
p
.002 w
.49061 .46543 m .49081 .46253 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.49081 .46253 m .49094 .46066 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.50306 .46341 m .51536 .46621 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.52456 .46829 m .52701 .46885 L p
.52537 .4687 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5225 .46727 L p
1 g
F P
s
P
p
.002 w
.5287 .4703 m .52701 .46885 L p
.55829 .48425 L 1 g
F P
s
P
p
.002 w
.52751 .46974 m .52701 .46885 L .5287 .4703 L p
1 g
F P
s
P
p
.002 w
.54236 .47676 m .54242 .47682 L p
.54115 .47618 L 1 g
F P
s
P
p
.002 w
.54242 .47682 m .54302 .47747 L p
.53426 .47294 L 1 g
F P
s
P
p
.002 w
.52713 .46956 m .52701 .46885 L .52751 .46974 L p
1 g
F P
s
P
p
.49157 .46527 m .49243 .46519 L .49061 .46543 L 1 g
F
P
p
.002 w
.49093 .4607 m .49061 .46543 L p
.47755 .46718 L 1 g
F P
s
P
p
.002 w
.49061 .46543 m .49011 .4726 L p
.47755 .46718 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47755 .46718 L p
1 g
F P
s
P
p
.49243 .46519 m .5 .46442 L .47755 .46718 L 1 g
F
P
p
.4679 .47185 m .46849 .47159 L .46257 .47443 L 1 g
F
P
p
.002 w
.49094 .46066 m .49093 .4607 L p
.45363 .47503 L 1 g
F P
s
P
p
.002 w
.45985 .47461 m .46257 .47443 L p
.45757 .47683 L 1 g
F P
s
P
p
.002 w
.46257 .47443 m .49011 .4726 L p
.45757 .47683 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45757 .47683 L p
1 g
F P
s
P
p
.46849 .47159 m .47718 .46778 L .45757 .47683 L 1 g
F
P
p
.002 w
.45757 .47683 m .45745 .47696 L p
.45601 .47835 L 1 g
F P
s
P
p
.002 w
.4599 .49746 m .45487 .47946 L p
.49011 .4726 L 1 g
F P
s
P
p
.002 w
.45363 .47503 m .45487 .47946 L p
.44603 .48802 L 1 g
F P
s
P
p
.002 w
.45487 .47946 m .4599 .49746 L p
.44603 .48802 L 1 g
F P
s
P
p
.002 w
.45745 .47696 m .45698 .47747 L p
.45045 .48373 L 1 g
F P
s
P
p
.44511 .48631 m .45363 .47503 L .43543 .5061 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44271 .49122 L p
1 g
F P
s
P
p
.45045 .48373 m .45698 .47747 L .44271 .49122 L 1 g
F
P
p
.43814 .50057 m .43896 .49866 L .43543 .5061 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43385 .50946 L p
1 g
F P
s
P
p
.43896 .49866 m .44166 .49233 L .43385 .50946 L 1 g
F
P
p
.002 w
.43385 .50946 m .43358 .50977 L p
.43356 .51278 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44771 .53605 m .43331 .51576 L p
.4599 .49746 L 1 g
F P
s
P
p
.002 w
.44771 .53605 m .43706 .54336 L p
.43281 .52662 L 1 g
F P
s
P
p
.002 w
.42825 .50864 m .43331 .51576 L p
.43281 .52662 L 1 g
F P
s
P
p
.002 w
.43331 .51576 m .44771 .53605 L p
.43281 .52662 L 1 g
F P
s
P
p
.002 w
.43358 .50977 m .43287 .51061 L p
.43317 .51891 L 1 g
F P
s
P
p
.42796 .5119 m .42825 .50864 L .43706 .54336 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43273 .5284 L p
1 g
F P
s
P
p
.43317 .51891 m .43287 .51061 L .43273 .5284 L 1 g
F
P
p
.43568 .5386 m .4336 .53447 L .43706 .54336 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4385 .54707 L p
1 g
F P
s
P
p
.4336 .53447 m .43146 .53025 L .4385 .54707 L 1 g
F
P
p
.002 w
.4385 .54707 m .43743 .5491 L p
.44635 .55685 L 1 g
F P
s
P
p
.45656 .56674 m .45097 .56261 L .44771 .53605 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45097 .56261 L p
1 g
F P
s
P
p
.44635 .55685 m .43743 .5491 L .45097 .56261 L 1 g
F
P
p
.48722 .57969 m .46833 .57446 L .47512 .55542 L 1 g
F
P
p
.002 w
.46222 .57277 m .4631 .57158 L p
.46833 .57446 L 1 g
F P
s
P
p
.45964 .56902 m .4631 .57158 L .46833 .57446 L 1 g
F
P
p
.002 w
.4631 .57158 m .47512 .55542 L p
.46833 .57446 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46814 .57531 L p
1 g
F P
s
P
p
.002 w
.46814 .57531 m .46833 .57446 L p
.46406 .57229 L 1 g
F P
s
P
p
.46406 .57229 m .45002 .56518 L .46814 .57531 L 1 g
F
P
p
.45964 .56902 m .45525 .56727 L .4631 .57158 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44771 .53605 m .47512 .55542 L .4631 .57158 L p
1 g
F P
s
P
p
.45656 .56674 m .44771 .53605 L .4631 .57158 L 1 g
F
P
p
.45525 .56727 m .45002 .56518 L .46833 .57446 L 1 g
F
P
p
.48722 .57969 m .47545 .57837 L .46833 .57446 L 1 g
F
P
p
.002 w
.46833 .57446 m .4678 .57686 L p
.4809 .57794 L 1 g
F P
s
P
p
.002 w
.46804 .57905 m .45939 .57657 L p
.49449 .5805 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58021 L p
1 g
F P
s
P
p
.4809 .57794 m .4678 .57686 L .48909 .58021 L 1 g
F
P
p
.002 w
.48909 .58021 m .48889 .583 L p
.4999 .5808 L 1 g
F P
s
P
p
.002 w
.47512 .55542 m .50748 .56478 L .50273 .58095 L p
1 g
F P
s
P
p
.49449 .5805 m .47512 .55542 L .50273 .58095 L 1 g
F
P
p
.002 w
.50273 .58095 m .50748 .56478 L p
.5306 .57863 L 1 g
F P
s
P
p
.54353 .58636 m .50273 .58095 L .5306 .57863 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58027 L p
1 g
F P
s
P
p
.49653 .58147 m .48889 .583 L .51091 .58027 L 1 g
F
P
p
.002 w
.51091 .58027 m .51111 .583 L p
.52401 .57638 L 1 g
F P
s
P
p
.5316 .57412 m .50748 .56478 L .54181 .56842 L 1 g
F
P
p
.5272 .57659 m .52591 .57581 L .5316 .57412 L 1 g
F
P
p
.52591 .57581 m .50748 .56478 L .5316 .57412 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5316 .57412 L p
1 g
F P
s
P
p
.52401 .57638 m .51111 .583 L .5316 .57412 L 1 g
F
P
p
.002 w
.50748 .56478 m .54132 .56327 L .54181 .56842 L p
1 g
F P
s
P
p
.002 w
.5316 .57412 m .53192 .57557 L p
.53734 .57091 L 1 g
F P
s
P
p
.002 w
.53192 .57557 m .5322 .57686 L p
.53871 .57066 L 1 g
F P
s
P
p
.002 w
.61742 .54367 m .58386 .57092 L .5731 .55112 L p
1 g
F P
s
P
p
.002 w
.5731 .55112 m .59955 .52964 L .61742 .54367 L p
1 g
F P
s
P
p
.002 w
.64075 .5074 m .61742 .54367 L .59955 .52964 L p
1 g
F P
s
P
p
.002 w
.64802 .42317 m .63083 .38403 L .64733 .3659 L p
1 g
F P
s
P
p
.002 w
.61274 .32876 m .64733 .3659 L .63083 .38403 L p
1 g
F P
s
P
p
.002 w
.59955 .52964 m .61789 .50104 L .64075 .5074 L p
1 g
F P
s
P
p
.002 w
.65137 .4658 m .64075 .5074 L .61789 .50104 L p
1 g
F P
s
P
p
.002 w
.38288 .37367 m .36294 .42221 L .34078 .41303 L p
1 g
F P
s
P
p
.002 w
.34078 .41303 m .36302 .35862 L .38288 .37367 L p
1 g
F P
s
P
p
.002 w
.56721 .305 m .51565 .29756 L .51175 .27342 L p
1 g
F P
s
P
p
.002 w
.45373 .28449 m .51175 .27342 L .51565 .29756 L p
1 g
F P
s
P
p
.002 w
.38746 .47565 m .39946 .5172 L .37446 .52293 L p
1 g
F P
s
P
p
.002 w
.37446 .52293 m .36012 .47391 L .38746 .47565 L p
1 g
F P
s
P
p
.002 w
.61789 .50104 m .62618 .46829 L .65137 .4658 L p
1 g
F P
s
P
p
.002 w
.64802 .42317 m .65137 .4658 L .62618 .46829 L p
1 g
F P
s
P
p
.002 w
.41784 .33389 m .38288 .37367 L .36302 .35862 L p
1 g
F P
s
P
p
.002 w
.36302 .35862 m .40215 .31403 L .41784 .33389 L p
1 g
F P
s
P
p
.002 w
.51565 .29756 m .46388 .30752 L .45373 .28449 L p
1 g
F P
s
P
p
.002 w
.40215 .31403 m .45373 .28449 L .46388 .30752 L p
1 g
F P
s
P
p
.002 w
.46388 .30752 m .41784 .33389 L .40215 .31403 L p
1 g
F P
s
P
p
.002 w
.63083 .38403 m .60142 .35266 L .61274 .32876 L p
1 g
F P
s
P
p
.002 w
.56721 .305 m .61274 .32876 L .60142 .35266 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62618 .46829 m .62343 .43479 L .64802 .42317 L p
1 g
F P
s
P
p
.002 w
.63083 .38403 m .64802 .42317 L .62343 .43479 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.38998 .43193 m .38746 .47565 L .36012 .47391 L p
1 g
F P
s
P
p
.002 w
.36012 .47391 m .36294 .42221 L .38998 .43193 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4244 .55205 m .39946 .5172 L .42825 .50864 L p
1 g
F P
s
P
p
.002 w
.60142 .35266 m .56282 .33269 L .56721 .305 L p
1 g
F P
s
P
p
.002 w
.51565 .29756 m .56721 .305 L .56282 .33269 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.61789 .50104 m .59955 .52964 L .57805 .51212 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51436 .53636 m .53776 .53537 L .54132 .56327 L p
1 g
F P
s
P
p
.002 w
.54132 .56327 m .50748 .56478 L .51436 .53636 L p
1 g
F P
s
P
p
.002 w
.62343 .43479 m .60982 .40411 L .63083 .38403 L p
1 g
F P
s
P
p
.002 w
.60142 .35266 m .63083 .38403 L .60982 .40411 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57805 .51212 m .59071 .49233 L .61789 .50104 L p
1 g
F P
s
P
p
.002 w
.62618 .46829 m .61789 .50104 L .59071 .49233 L p
1 g
F P
s
P
p
.002 w
.40693 .39091 m .38998 .43193 L .36294 .42221 L p
1 g
F P
s
P
p
.002 w
.36294 .42221 m .38288 .37367 L .40693 .39091 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.49205 .52983 m .51436 .53636 L .50748 .56478 L p
1 g
F P
s
P
p
.002 w
.50748 .56478 m .47512 .55542 L .49205 .52983 L p
1 g
F P
s
P
p
.002 w
.56282 .33269 m .51919 .32651 L .51565 .29756 L p
1 g
F P
s
P
p
.002 w
.46388 .30752 m .51565 .29756 L .51919 .32651 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.41899 .47605 m .42825 .50864 L .39946 .5172 L p
1 g
F P
s
P
p
.002 w
.39946 .5172 m .38746 .47565 L .41899 .47605 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59071 .49233 m .59637 .46968 L .62618 .46829 L p
1 g
F P
s
P
p
.002 w
.62343 .43479 m .62618 .46829 L .59637 .46968 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43652 .35732 m .40693 .39091 L .38288 .37367 L p
1 g
F P
s
P
p
.002 w
.38288 .37367 m .41784 .33389 L .43652 .35732 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51919 .32651 m .47543 .335 L .46388 .30752 L p
1 g
F P
s
P
p
.002 w
.41784 .33389 m .46388 .30752 L .47543 .335 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.60982 .40411 m .58666 .37962 L .60142 .35266 L p
1 g
F P
s
P
p
.002 w
.56282 .33269 m .60142 .35266 L .58666 .37962 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.47321 .5164 m .49205 .52983 L .47512 .55542 L p
1 g
F P
s
P
p
.002 w
.47512 .55542 m .44771 .53605 L .47321 .5164 L p
1 g
F P
s
P
p
.002 w
.47543 .335 m .43652 .35732 L .41784 .33389 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59637 .46968 m .59439 .44657 L .62343 .43479 L p
1 g
F P
s
P
p
.002 w
.60982 .40411 m .62343 .43479 L .59439 .44657 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.42108 .44182 m .41899 .47605 L .38746 .47565 L p
1 g
F P
s
P
p
.002 w
.38746 .47565 m .38998 .43193 L .42108 .44182 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.4599 .49746 m .47321 .5164 L .44771 .53605 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58666 .37962 m .55637 .36409 L .56282 .33269 L p
1 g
F P
s
P
p
.002 w
.51919 .32651 m .56282 .33269 L .55637 .36409 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53294 .50353 m .54422 .49925 L .55976 .52699 L p
1 g
F P
s
P
p
.002 w
.55976 .52699 m .53776 .53537 L .53294 .50353 L p
1 g
F P
s
P
p
.002 w
.59439 .44657 m .58492 .42547 L .60982 .40411 L p
1 g
F P
s
P
p
.002 w
.58666 .37962 m .60982 .40411 L .58492 .42547 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52096 .50401 m .53294 .50353 L .53776 .53537 L p
1 g
F P
s
P
p
.002 w
.53776 .53537 m .51436 .53636 L .52096 .50401 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43442 .40978 m .42108 .44182 L .38998 .43193 L p
1 g
F P
s
P
p
.002 w
.38998 .43193 m .40693 .39091 L .43442 .40978 L p
1 g
F P
s
P
p
.002 w
.59637 .46968 m .59071 .49233 L .56005 .48148 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.50957 .50062 m .52096 .50401 L .51436 .53636 L p
1 g
F P
s
P
p
.002 w
.51436 .53636 m .49205 .52983 L .50957 .50062 L p
1 g
F P
s
P
p
.002 w
.42825 .50864 m .41899 .47605 L .45363 .47503 L p
1 g
F P
s
P
p
.002 w
.55637 .36409 m .52222 .35936 L .51919 .32651 L p
1 g
F P
s
P
p
.002 w
.47543 .335 m .51919 .32651 L .52222 .35936 L p
1 g
F P
s
P
p
.002 w
.56005 .48148 m .56291 .46988 L .59637 .46968 L p
1 g
F P
s
P
p
.002 w
.59439 .44657 m .59637 .46968 L .56291 .46988 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.45759 .38353 m .43442 .40978 L .40693 .39091 L p
1 g
F P
s
P
p
.002 w
.40693 .39091 m .43652 .35732 L .45759 .38353 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.58492 .42547 m .56891 .4087 L .58666 .37962 L p
1 g
F P
s
P
p
.002 w
.55637 .36409 m .58666 .37962 L .56891 .4087 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49998 .49372 m .50957 .50062 L .49205 .52983 L p
1 g
F P
s
P
p
.002 w
.49205 .52983 m .47321 .5164 L .49998 .49372 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52222 .35936 m .488 .36607 L .47543 .335 L p
1 g
F P
s
P
p
.002 w
.43652 .35732 m .47543 .335 L .488 .36607 L p
1 g
F P
s
P
p
.002 w
.488 .36607 m .45759 .38353 L .43652 .35732 L p
1 g
F P
s
P
p
.002 w
.56291 .46988 m .56185 .45807 L .59439 .44657 L p
1 g
F P
s
P
p
.002 w
.58492 .42547 m .59439 .44657 L .56185 .45807 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.45516 .45153 m .45363 .47503 L .41899 .47605 L p
1 g
F P
s
P
p
.002 w
.41899 .47605 m .42108 .44182 L .45516 .45153 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.49325 .48403 m .49998 .49372 L .47321 .5164 L p
1 g
F P
s
P
p
.002 w
.47321 .5164 m .4599 .49746 L .49325 .48403 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56891 .4087 m .54804 .39812 L .55637 .36409 L p
1 g
F P
s
P
p
.002 w
.52222 .35936 m .55637 .36409 L .54804 .39812 L p
1 g
F P
s
P
p
.002 w
.56185 .45807 m .55697 .44734 L .58492 .42547 L p
1 g
F P
s
P
p
.002 w
.56891 .4087 m .58492 .42547 L .55697 .44734 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46437 .42957 m .45516 .45153 L .42108 .44182 L p
1 g
F P
s
P
p
.002 w
.42108 .44182 m .43442 .40978 L .46437 .42957 L p
1 g
F P
s
P
p
.002 w
.56291 .46988 m .56005 .48148 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49011 .4726 m .49325 .48403 L .4599 .49746 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54804 .39812 m .52459 .39495 L .52222 .35936 L p
1 g
F P
s
P
p
.002 w
.488 .36607 m .52222 .35936 L .52459 .39495 L p
1 g
F P
s
P
p
.002 w
.56185 .45807 m .56291 .46988 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.55697 .44734 m .54877 .43883 L .56891 .4087 L p
1 g
F P
s
P
p
.002 w
.54804 .39812 m .56891 .4087 L .54877 .43883 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48028 .41159 m .46437 .42957 L .43442 .40978 L p
1 g
F P
s
P
p
.002 w
.43442 .40978 m .45759 .38353 L .48028 .41159 L p
1 g
F P
s
P
p
.002 w
.55697 .44734 m .56185 .45807 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.52459 .39495 m .50113 .3996 L .488 .36607 L p
1 g
F P
s
P
p
.002 w
.45759 .38353 m .488 .36607 L .50113 .3996 L p
1 g
F P
s
P
p
.002 w
.45363 .47503 m .45516 .45153 L .49094 .46066 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.50113 .3996 m .48028 .41159 L .45759 .38353 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.54877 .43883 m .55697 .44734 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54877 .43883 m .53813 .4335 L .54804 .39812 L p
1 g
F P
s
P
p
.002 w
.52459 .39495 m .54804 .39812 L .53813 .4335 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49564 .44952 m .49094 .46066 L .45516 .45153 L p
1 g
F P
s
P
p
.002 w
.45516 .45153 m .46437 .42957 L .49564 .44952 L p
1 g
F P
s
P
p
.002 w
.53813 .4335 m .54877 .43883 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.52621 .43193 m .53813 .4335 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.51431 .43432 m .52621 .43193 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.50373 .4404 m .51431 .43432 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50603 .43908 L
s
P
p
.002 w
.49564 .44952 m .50373 .4404 L .52701 .46885 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53813 .4335 m .52621 .43193 L .52459 .39495 L p
1 g
F P
s
P
p
.002 w
.50113 .3996 m .52459 .39495 L .52621 .43193 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50373 .4404 m .49564 .44952 L .46437 .42957 L p
1 g
F P
s
P
p
.002 w
.46437 .42957 m .48028 .41159 L .50373 .4404 L p
1 g
F P
s
P
p
.002 w
.52621 .43193 m .51431 .43432 L .50113 .3996 L p
1 g
F P
s
P
p
.002 w
.48028 .41159 m .50113 .3996 L .51431 .43432 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.51431 .43432 m .50373 .4404 L .48028 .41159 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.52701 .46885 m
.54374 .4926 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .26754 .55046 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .54374 .4926 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.11938)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.11938)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48989 .46284 m .51264 .44816 L .49367 .42682 L p
1 g
F P
s
P
p
.002 w
.49367 .42682 m .47815 .4368 L .48989 .46284 L p
1 g
F P
s
P
p
.002 w
.50543 .41257 m .49367 .42682 L .51264 .44816 L p
1 g
F P
s
P
p
.002 w
.47815 .4368 m .49367 .42682 L .47481 .40554 L p
1 g
F P
s
P
p
.002 w
.49367 .42682 m .50543 .41257 L .48078 .39829 L p
1 g
F P
s
P
p
.002 w
.48078 .39829 m .47481 .40554 L .49367 .42682 L p
1 g
F P
s
P
p
.002 w
.51264 .44816 m .52992 .42726 L .50543 .41257 L p
1 g
F P
s
P
p
.002 w
.51219 .39553 m .50543 .41257 L .52992 .42726 L p
1 g
F P
s
P
p
.002 w
.50543 .41257 m .51219 .39553 L .48419 .38963 L p
1 g
F P
s
P
p
.002 w
.48419 .38963 m .48078 .39829 L .50543 .41257 L p
1 g
F P
s
P
p
.002 w
.50194 .48824 m .53141 .46917 L .51264 .44816 L p
1 g
F P
s
P
p
.002 w
.51264 .44816 m .48989 .46284 L .50194 .48824 L p
1 g
F P
s
P
p
.002 w
.52992 .42726 m .51264 .44816 L .53141 .46917 L p
1 g
F P
s
P
p
.002 w
.46396 .46979 m .48989 .46284 L .47815 .4368 L p
1 g
F P
s
P
p
.002 w
.47815 .4368 m .46047 .44147 L .46396 .46979 L p
1 g
F P
s
P
p
.002 w
.46047 .44147 m .47815 .4368 L .46692 .4106 L p
1 g
F P
s
P
p
.002 w
.47481 .40554 m .46692 .4106 L .47815 .4368 L p
1 g
F P
s
P
p
.002 w
.53141 .46917 m .55381 .44212 L .52992 .42726 L p
1 g
F P
s
P
p
.002 w
.53993 .40229 m .52992 .42726 L .55381 .44212 L p
1 g
F P
s
P
p
.002 w
.52992 .42726 m .53993 .40229 L .51219 .39553 L p
1 g
F P
s
P
p
.002 w
.46836 .49736 m .50194 .48824 L .48989 .46284 L p
1 g
F P
s
P
p
.002 w
.48989 .46284 m .46396 .46979 L .46836 .49736 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .46692 .4106 L .47481 .40554 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .47481 .40554 L .48078 .39829 L closepath p
1 g
F P
s
P
p
.002 w
.51323 .37748 m .51219 .39553 L .53993 .40229 L p
1 g
F P
s
P
p
.002 w
.51219 .39553 m .51323 .37748 L .48467 .38048 L p
1 g
F P
s
P
p
.002 w
.48467 .38048 m .48419 .38963 L .51219 .39553 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .48078 .39829 L .48419 .38963 L closepath p
1 g
F P
s
P
p
.002 w
.46692 .4106 m .45794 .41294 L .46047 .44147 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .45794 .41294 L .46692 .4106 L closepath p
1 g
F P
s
P
p
.002 w
.43752 .4682 m .46396 .46979 L .46047 .44147 L p
1 g
F P
s
P
p
.002 w
.46047 .44147 m .44249 .4403 L .43752 .4682 L p
1 g
F P
s
P
p
.002 w
.44249 .4403 m .46047 .44147 L .45794 .41294 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .48419 .38963 L .48467 .38048 L closepath p
1 g
F P
s
P
p
.002 w
.45794 .41294 m .44883 .41229 L .44249 .4403 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .44883 .41229 L .45794 .41294 L closepath p
1 g
F P
s
P
p
.002 w
.55381 .44212 m .56689 .40978 L .53993 .40229 L p
1 g
F P
s
P
p
.002 w
.54158 .37577 m .53993 .40229 L .56689 .40978 L p
1 g
F P
s
P
p
.002 w
.53993 .40229 m .54158 .37577 L .51323 .37748 L p
1 g
F P
s
P
p
.002 w
.51409 .51252 m .54961 .48947 L .53141 .46917 L p
1 g
F P
s
P
p
.002 w
.53141 .46917 m .50194 .48824 L .51409 .51252 L p
1 g
F P
s
P
p
.002 w
.55381 .44212 m .53141 .46917 L .54961 .48947 L p
1 g
F P
s
P
p
.002 w
.48215 .37181 m .48467 .38048 L .51323 .37748 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .48467 .38048 L .48215 .37181 L closepath p
1 g
F P
s
P
p
.002 w
.43402 .49548 m .46836 .49736 L .46396 .46979 L p
1 g
F P
s
P
p
.002 w
.46396 .46979 m .43752 .4682 L .43402 .49548 L p
1 g
F P
s
P
p
.002 w
.4261 .43335 m .44249 .4403 L .44883 .41229 L p
1 g
F P
s
P
p
.002 w
.44883 .41229 m .44056 .40872 L .4261 .43335 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .44056 .40872 L .44883 .41229 L closepath p
1 g
F P
s
P
p
.002 w
.50837 .36032 m .51323 .37748 L .54158 .37577 L p
1 g
F P
s
P
p
.002 w
.51323 .37748 m .50837 .36032 L .48215 .37181 L p
1 g
F P
s
P
p
.002 w
.54961 .48947 m .57667 .45686 L .55381 .44212 L p
1 g
F P
s
P
p
.002 w
.56689 .40978 m .55381 .44212 L .57667 .45686 L p
1 g
F P
s
P
p
.002 w
.47359 .52367 m .51409 .51252 L .50194 .48824 L p
1 g
F P
s
P
p
.002 w
.50194 .48824 m .46836 .49736 L .47359 .52367 L p
1 g
F P
s
P
p
.002 w
.41332 .45813 m .43752 .4682 L .44249 .4403 L p
1 g
F P
s
P
p
.002 w
.44249 .4403 m .4261 .43335 L .41332 .45813 L p
1 g
F P
s
P
p
.002 w
.47689 .36455 m .48215 .37181 L .50837 .36032 L p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .48215 .37181 L .47689 .36455 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .42997 .39454 L .43404 .40259 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .43404 .40259 L .44056 .40872 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .47689 .36455 L .46944 .35952 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .46944 .35952 L .4606 .35726 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .4606 .35726 L .45133 .35805 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .45133 .35805 L .44266 .3618 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .44266 .3618 L .43553 .36812 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .43553 .36812 L .43075 .37631 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .43075 .37631 L .42883 .38545 L closepath p
1 g
F P
s
P
p
.002 w
.45643 .38469 m .42883 .38545 L .42997 .39454 L closepath p
1 g
F P
s
P
p
.002 w
.41309 .4213 m .4261 .43335 L .44056 .40872 L p
1 g
F P
s
P
p
.002 w
.44056 .40872 m .43404 .40259 L .41309 .4213 L p
1 g
F P
s
P
p
.002 w
.56689 .40978 m .5692 .37537 L .54158 .37577 L p
1 g
F P
s
P
p
.002 w
.53459 .35046 m .54158 .37577 L .5692 .37537 L p
1 g
F P
s
P
p
.002 w
.54158 .37577 m .53459 .35046 L .50837 .36032 L p
1 g
F P
s
P
p
.002 w
.50837 .36032 m .49806 .34589 L .47689 .36455 L p
1 g
F P
s
P
p
.002 w
.46944 .35952 m .47689 .36455 L .49806 .34589 L p
1 g
F P
s
P
p
.002 w
.57667 .45686 m .59256 .41787 L .56689 .40978 L p
1 g
F P
s
P
p
.002 w
.5692 .37537 m .56689 .40978 L .59256 .41787 L p
1 g
F P
s
P
p
.002 w
.49806 .34589 m .50837 .36032 L .53459 .35046 L p
1 g
F P
s
P
p
.002 w
.40492 .40539 m .41309 .4213 L .43404 .40259 L p
1 g
F P
s
P
p
.002 w
.43404 .40259 m .42997 .39454 L .40492 .40539 L p
1 g
F P
s
P
p
.002 w
.4025 .48259 m .43402 .49548 L .43752 .4682 L p
1 g
F P
s
P
p
.002 w
.43752 .4682 m .41332 .45813 L .4025 .48259 L p
1 g
F P
s
P
p
.002 w
.39401 .44049 m .41332 .45813 L .4261 .43335 L p
1 g
F P
s
P
p
.002 w
.4261 .43335 m .41309 .4213 L .39401 .44049 L p
1 g
F P
s
P
p
.002 w
.43211 .52161 m .47359 .52367 L .46836 .49736 L p
1 g
F P
s
P
p
.002 w
.46836 .49736 m .43402 .49548 L .43211 .52161 L p
1 g
F P
s
P
p
.002 w
.52611 .53522 m .5669 .50867 L .54961 .48947 L p
1 g
F P
s
P
p
.002 w
.54961 .48947 m .51409 .51252 L .52611 .53522 L p
1 g
F P
s
P
p
.002 w
.57667 .45686 m .54961 .48947 L .5669 .50867 L p
1 g
F P
s
P
p
.002 w
.49806 .34589 m .48335 .3358 L .46944 .35952 L p
1 g
F P
s
P
p
.002 w
.4606 .35726 m .46944 .35952 L .48335 .3358 L p
1 g
F P
s
P
p
.002 w
.40255 .38733 m .40492 .40539 L .42997 .39454 L p
1 g
F P
s
P
p
.002 w
.42997 .39454 m .42883 .38545 L .40255 .38733 L p
1 g
F P
s
P
p
.002 w
.5669 .50867 m .59804 .47121 L .57667 .45686 L p
1 g
F P
s
P
p
.002 w
.59256 .41787 m .57667 .45686 L .59804 .47121 L p
1 g
F P
s
P
p
.002 w
.48335 .3358 m .46581 .33122 L .4606 .35726 L p
1 g
F P
s
P
p
.002 w
.45133 .35805 m .4606 .35726 L .46581 .33122 L p
1 g
F P
s
P
p
.002 w
.47959 .54818 m .52611 .53522 L .51409 .51252 L p
1 g
F P
s
P
p
.002 w
.51409 .51252 m .47359 .52367 L .47959 .54818 L p
1 g
F P
s
P
p
.002 w
.4063 .36911 m .40255 .38733 L .42883 .38545 L p
1 g
F P
s
P
p
.002 w
.42883 .38545 m .43075 .37631 L .4063 .36911 L p
1 g
F P
s
P
p
.002 w
.53459 .35046 m .51954 .32908 L .49806 .34589 L p
1 g
F P
s
P
p
.002 w
.48335 .3358 m .49806 .34589 L .51954 .32908 L p
1 g
F P
s
P
p
.002 w
.5692 .37537 m .56031 .34244 L .53459 .35046 L p
1 g
F P
s
P
p
.002 w
.51954 .32908 m .53459 .35046 L .56031 .34244 L p
1 g
F P
s
P
p
.002 w
.46581 .33122 m .44735 .33271 L .45133 .35805 L p
1 g
F P
s
P
p
.002 w
.44266 .3618 m .45133 .35805 L .44735 .33271 L p
1 g
F P
s
P
p
.002 w
.38178 .41705 m .39401 .44049 L .41309 .4213 L p
1 g
F P
s
P
p
.002 w
.41309 .4213 m .40492 .40539 L .38178 .41705 L p
1 g
F P
s
P
p
.002 w
.41582 .35277 m .4063 .36911 L .43075 .37631 L p
1 g
F P
s
P
p
.002 w
.43075 .37631 m .43553 .36812 L .41582 .35277 L p
1 g
F P
s
P
p
.002 w
.59256 .41787 m .59555 .37634 L .5692 .37537 L p
1 g
F P
s
P
p
.002 w
.56031 .34244 m .5692 .37537 L .59555 .37634 L p
1 g
F P
s
P
p
.002 w
.44735 .33271 m .43003 .34016 L .44266 .3618 L p
1 g
F P
s
P
p
.002 w
.43553 .36812 m .44266 .3618 L .43003 .34016 L p
1 g
F P
s
P
p
.002 w
.43003 .34016 m .41582 .35277 L .43553 .36812 L p
1 g
F P
s
P
p
.002 w
.37721 .45979 m .4025 .48259 L .41332 .45813 L p
1 g
F P
s
P
p
.002 w
.41332 .45813 m .39401 .44049 L .37721 .45979 L p
1 g
F P
s
P
p
.002 w
.39389 .50625 m .43211 .52161 L .43402 .49548 L p
1 g
F P
s
P
p
.002 w
.43402 .49548 m .4025 .48259 L .39389 .50625 L p
1 g
F P
s
P
p
.002 w
.59804 .47121 m .61643 .42644 L .59256 .41787 L p
1 g
F P
s
P
p
.002 w
.59555 .37634 m .59256 .41787 L .61643 .42644 L p
1 g
F P
s
P
p
.002 w
.51954 .32908 m .49792 .31404 L .48335 .3358 L p
1 g
F P
s
P
p
.002 w
.46581 .33122 m .48335 .3358 L .49792 .31404 L p
1 g
F P
s
P
p
.002 w
.43185 .54604 m .47959 .54818 L .47359 .52367 L p
1 g
F P
s
P
p
.002 w
.47359 .52367 m .43211 .52161 L .43185 .54604 L p
1 g
F P
s
P
p
.002 w
.37813 .39033 m .38178 .41705 L .40492 .40539 L p
1 g
F P
s
P
p
.002 w
.40492 .40539 m .40255 .38733 L .37813 .39033 L p
1 g
F P
s
P
p
.002 w
.53776 .55583 m .58293 .52636 L .5669 .50867 L p
1 g
F P
s
P
p
.002 w
.5669 .50867 m .52611 .53522 L .53776 .55583 L p
1 g
F P
s
P
p
.002 w
.59804 .47121 m .5669 .50867 L .58293 .52636 L p
1 g
F P
s
P
p
.002 w
.56031 .34244 m .54092 .3145 L .51954 .32908 L p
1 g
F P
s
P
p
.002 w
.49792 .31404 m .51954 .32908 L .54092 .3145 L p
1 g
F P
s
P
p
.002 w
.49792 .31404 m .47199 .30711 L .46581 .33122 L p
1 g
F P
s
P
p
.002 w
.44735 .33271 m .46581 .33122 L .47199 .30711 L p
1 g
F P
s
P
p
.002 w
.58293 .52636 m .61745 .48488 L .59804 .47121 L p
1 g
F P
s
P
p
.002 w
.61643 .42644 m .59804 .47121 L .61745 .48488 L p
1 g
F P
s
P
p
.002 w
.36108 .42933 m .37721 .45979 L .39401 .44049 L p
1 g
F P
s
P
p
.002 w
.39401 .44049 m .38178 .41705 L .36108 .42933 L p
1 g
F P
s
P
p
.002 w
.38362 .36327 m .37813 .39033 L .40255 .38733 L p
1 g
F P
s
P
p
.002 w
.40255 .38733 m .4063 .36911 L .38362 .36327 L p
1 g
F P
s
P
p
.002 w
.59555 .37634 m .58504 .33646 L .56031 .34244 L p
1 g
F P
s
P
p
.002 w
.54092 .3145 m .56031 .34244 L .58504 .33646 L p
1 g
F P
s
P
p
.002 w
.48624 .57035 m .53776 .55583 L .52611 .53522 L p
1 g
F P
s
P
p
.002 w
.52611 .53522 m .47959 .54818 L .48624 .57035 L p
1 g
F P
s
P
p
.002 w
.61643 .42644 m .62008 .37868 L .59555 .37634 L p
1 g
F P
s
P
p
.002 w
.58504 .33646 m .59555 .37634 L .62008 .37868 L p
1 g
F P
s
P
p
.002 w
.3631 .47883 m .39389 .50625 L .4025 .48259 L p
1 g
F P
s
P
p
.002 w
.4025 .48259 m .37721 .45979 L .3631 .47883 L p
1 g
F P
s
P
p
.002 w
.47199 .30711 m .44459 .30922 L .44735 .33271 L p
1 g
F P
s
P
p
.002 w
.43003 .34016 m .44735 .33271 L .44459 .30922 L p
1 g
F P
s
P
p
.002 w
.39771 .33897 m .38362 .36327 L .4063 .36911 L p
1 g
F P
s
P
p
.002 w
.4063 .36911 m .41582 .35277 L .39771 .33897 L p
1 g
F P
s
P
p
.002 w
.38776 .52859 m .43185 .54604 L .43211 .52161 L p
1 g
F P
s
P
p
.002 w
.43211 .52161 m .39389 .50625 L .38776 .52859 L p
1 g
F P
s
P
p
.002 w
.44459 .30922 m .41885 .32024 L .43003 .34016 L p
1 g
F P
s
P
p
.002 w
.41582 .35277 m .43003 .34016 L .41885 .32024 L p
1 g
F P
s
P
p
.002 w
.41885 .32024 m .39771 .33897 L .41582 .35277 L p
1 g
F P
s
P
p
.002 w
.54092 .3145 m .51285 .29471 L .49792 .31404 L p
1 g
F P
s
P
p
.002 w
.47199 .30711 m .49792 .31404 L .51285 .29471 L p
1 g
F P
s
P
p
.002 w
.61745 .48488 m .63797 .43532 L .61643 .42644 L p
1 g
F P
s
P
p
.002 w
.62008 .37868 m .61643 .42644 L .63797 .43532 L p
1 g
F P
s
P
p
.002 w
.35616 .39442 m .36108 .42933 L .38178 .41705 L p
1 g
F P
s
P
p
.002 w
.38178 .41705 m .37813 .39033 L .35616 .39442 L p
1 g
F P
s
P
p
.002 w
.43332 .56819 m .48624 .57035 L .47959 .54818 L p
1 g
F P
s
P
p
.002 w
.47959 .54818 m .43185 .54604 L .43332 .56819 L p
1 g
F P
s
P
p
.002 w
.58504 .33646 m .56177 .30249 L .54092 .3145 L p
1 g
F P
s
P
p
.002 w
.51285 .29471 m .54092 .3145 L .56177 .30249 L p
1 g
F P
s
P
p
.002 w
.34335 .44198 m .3631 .47883 L .37721 .45979 L p
1 g
F P
s
P
p
.002 w
.37721 .45979 m .36108 .42933 L .34335 .44198 L p
1 g
F P
s
P
p
.002 w
.51285 .29471 m .47903 .28549 L .47199 .30711 L p
1 g
F P
s
P
p
.002 w
.44459 .30922 m .47199 .30711 L .47903 .28549 L p
1 g
F P
s
P
p
.002 w
.54879 .57385 m .5973 .54213 L .58293 .52636 L p
1 g
F P
s
P
p
.002 w
.58293 .52636 m .53776 .55583 L .54879 .57385 L p
1 g
F P
s
P
p
.002 w
.61745 .48488 m .58293 .52636 L .5973 .54213 L p
1 g
F P
s
P
p
.002 w
.62008 .37868 m .60823 .33271 L .58504 .33646 L p
1 g
F P
s
P
p
.002 w
.56177 .30249 m .58504 .33646 L .60823 .33271 L p
1 g
F P
s
P
p
.002 w
.36323 .35898 m .35616 .39442 L .37813 .39033 L p
1 g
F P
s
P
p
.002 w
.37813 .39033 m .38362 .36327 L .36323 .35898 L p
1 g
F P
s
P
p
.002 w
.5973 .54213 m .63445 .49756 L .61745 .48488 L p
1 g
F P
s
P
p
.002 w
.63797 .43532 m .61745 .48488 L .63445 .49756 L p
1 g
F P
s
P
p
.002 w
.3521 .49718 m .38776 .52859 L .39389 .50625 L p
1 g
F P
s
P
p
.002 w
.39389 .50625 m .3631 .47883 L .3521 .49718 L p
1 g
F P
s
P
p
.002 w
.63797 .43532 m .64222 .3824 L .62008 .37868 L p
1 g
F P
s
P
p
.002 w
.60823 .33271 m .62008 .37868 L .64222 .3824 L p
1 g
F P
s
P
p
.002 w
.49345 .5896 m .54879 .57385 L .53776 .55583 L p
1 g
F P
s
P
p
.002 w
.53776 .55583 m .48624 .57035 L .49345 .5896 L p
1 g
F P
s
P
p
.002 w
.47903 .28549 m .44317 .28813 L .44459 .30922 L p
1 g
F P
s
P
p
.002 w
.41885 .32024 m .44459 .30922 L .44317 .28813 L p
1 g
F P
s
P
p
.002 w
.38433 .54908 m .43332 .56819 L .43185 .54604 L p
1 g
F P
s
P
p
.002 w
.43185 .54604 m .38776 .52859 L .38433 .54908 L p
1 g
F P
s
P
p
.002 w
.38166 .32709 m .36323 .35898 L .38362 .36327 L p
1 g
F P
s
P
p
.002 w
.38362 .36327 m .39771 .33897 L .38166 .32709 L p
1 g
F P
s
P
p
.002 w
.56177 .30249 m .52787 .27832 L .51285 .29471 L p
1 g
F P
s
P
p
.002 w
.47903 .28549 m .51285 .29471 L .52787 .27832 L p
1 g
F P
s
P
p
.002 w
.44317 .28813 m .40939 .30252 L .41885 .32024 L p
1 g
F P
s
P
p
.002 w
.39771 .33897 m .41885 .32024 L .40939 .30252 L p
1 g
F P
s
P
p
.002 w
.40939 .30252 m .38166 .32709 L .39771 .33897 L p
1 g
F P
s
P
p
.002 w
.63445 .49756 m .65662 .44434 L .63797 .43532 L p
1 g
F P
s
P
p
.002 w
.64222 .3824 m .63797 .43532 L .65662 .44434 L p
1 g
F P
s
P
p
.002 w
.33719 .39958 m .34335 .44198 L .36108 .42933 L p
1 g
F P
s
P
p
.002 w
.36108 .42933 m .35616 .39442 L .33719 .39958 L p
1 g
F P
s
P
p
.002 w
.43656 .58749 m .49345 .5896 L .48624 .57035 L p
1 g
F P
s
P
p
.002 w
.48624 .57035 m .43332 .56819 L .43656 .58749 L p
1 g
F P
s
P
p
.002 w
.60823 .33271 m .58163 .29343 L .56177 .30249 L p
1 g
F P
s
P
p
.002 w
.52787 .27832 m .56177 .30249 L .58163 .29343 L p
1 g
F P
s
P
p
.002 w
.3291 .45475 m .3521 .49718 L .3631 .47883 L p
1 g
F P
s
P
p
.002 w
.3631 .47883 m .34335 .44198 L .3291 .45475 L p
1 g
F P
s
P
p
.002 w
.64222 .3824 m .62932 .33137 L .60823 .33271 L p
1 g
F P
s
P
p
.002 w
.58163 .29343 m .60823 .33271 L .62932 .33137 L p
1 g
F P
s
P
p
.002 w
.52787 .27832 m .48683 .26694 L .47903 .28549 L p
1 g
F P
s
P
p
.002 w
.44317 .28813 m .47903 .28549 L .48683 .26694 L p
1 g
F P
s
P
p
.002 w
.55893 .58878 m .60965 .55554 L .5973 .54213 L p
1 g
F P
s
P
p
.002 w
.5973 .54213 m .54879 .57385 L .55893 .58878 L p
1 g
F P
s
P
p
.002 w
.63445 .49756 m .5973 .54213 L .60965 .55554 L p
1 g
F P
s
P
p
.002 w
.34569 .35639 m .33719 .39958 L .35616 .39442 L p
1 g
F P
s
P
p
.002 w
.35616 .39442 m .36323 .35898 L .34569 .35639 L p
1 g
F P
s
P
p
.002 w
.3446 .5144 m .38433 .54908 L .38776 .52859 L p
1 g
F P
s
P
p
.002 w
.38776 .52859 m .3521 .49718 L .3446 .5144 L p
1 g
F P
s
P
p
.002 w
.65662 .44434 m .66138 .38748 L .64222 .3824 L p
1 g
F P
s
P
p
.002 w
.62932 .33137 m .64222 .3824 L .66138 .38748 L p
1 g
F P
s
P
p
.002 w
.60965 .55554 m .64854 .50894 L .63445 .49756 L p
1 g
F P
s
P
p
.002 w
.65662 .44434 m .63445 .49756 L .64854 .50894 L p
1 g
F P
s
P
p
.002 w
.50108 .60537 m .55893 .58878 L .54879 .57385 L p
1 g
F P
s
P
p
.002 w
.54879 .57385 m .49345 .5896 L .50108 .60537 L p
1 g
F P
s
P
p
.002 w
.38382 .56716 m .43656 .58749 L .43332 .56819 L p
1 g
F P
s
P
p
.002 w
.43332 .56819 m .38433 .54908 L .38382 .56716 L p
1 g
F P
s
P
p
.002 w
.48683 .26694 m .44317 .27003 L .44317 .28813 L p
1 g
F P
s
P
p
.002 w
.40939 .30252 m .44317 .28813 L .44317 .27003 L p
1 g
F P
s
P
p
.002 w
.36813 .31748 m .34569 .35639 L .36323 .35898 L p
1 g
F P
s
P
p
.002 w
.36323 .35898 m .38166 .32709 L .36813 .31748 L p
1 g
F P
s
P
p
.002 w
.58163 .29343 m .54265 .26534 L .52787 .27832 L p
1 g
F P
s
P
p
.002 w
.48683 .26694 m .52787 .27832 L .54265 .26534 L p
1 g
F P
s
P
p
.002 w
.44317 .27003 m .40196 .28751 L .40939 .30252 L p
1 g
F P
s
P
p
.002 w
.38166 .32709 m .40939 .30252 L .40196 .28751 L p
1 g
F P
s
P
p
.002 w
.32182 .40574 m .3291 .45475 L .34335 .44198 L p
1 g
F P
s
P
p
.002 w
.34335 .44198 m .33719 .39958 L .32182 .40574 L p
1 g
F P
s
P
p
.002 w
.40196 .28751 m .36813 .31748 L .38166 .32709 L p
1 g
F P
s
P
p
.002 w
.64854 .50894 m .67183 .45331 L .65662 .44434 L p
1 g
F P
s
P
p
.002 w
.66138 .38748 m .65662 .44434 L .67183 .45331 L p
1 g
F P
s
P
p
.002 w
.44159 .60334 m .50108 .60537 L .49345 .5896 L p
1 g
F P
s
P
p
.002 w
.49345 .5896 m .43656 .58749 L .44159 .60334 L p
1 g
F P
s
P
p
.002 w
.62932 .33137 m .60001 .28764 L .58163 .29343 L p
1 g
F P
s
P
p
.002 w
.54265 .26534 m .58163 .29343 L .60001 .28764 L p
1 g
F P
s
P
p
.002 w
.31887 .46734 m .3446 .5144 L .3521 .49718 L p
1 g
F P
s
P
p
.002 w
.3521 .49718 m .3291 .45475 L .31887 .46734 L p
1 g
F P
s
P
p
.002 w
.66138 .38748 m .64774 .33257 L .62932 .33137 L p
1 g
F P
s
P
p
.002 w
.60001 .28764 m .62932 .33137 L .64774 .33257 L p
1 g
F P
s
P
p
.002 w
.54265 .26534 m .49525 .25202 L .48683 .26694 L p
1 g
F P
s
P
p
.002 w
.44317 .27003 m .48683 .26694 L .49525 .25202 L p
1 g
F P
s
P
p
.002 w
.34096 .53002 m .38382 .56716 L .38433 .54908 L p
1 g
F P
s
P
p
.002 w
.38433 .54908 m .3446 .5144 L .34096 .53002 L p
1 g
F P
s
P
p
.002 w
.33157 .35567 m .32182 .40574 L .33719 .39958 L p
1 g
F P
s
P
p
.002 w
.33719 .39958 m .34569 .35639 L .33157 .35567 L p
1 g
F P
s
P
p
.002 w
.56789 .60009 m .61958 .56617 L .60965 .55554 L p
1 g
F P
s
P
p
.002 w
.60965 .55554 m .55893 .58878 L .56789 .60009 L p
1 g
F P
s
P
p
.002 w
.64854 .50894 m .60965 .55554 L .61958 .56617 L p
1 g
F P
s
P
p
.002 w
.67183 .45331 m .67698 .39387 L .66138 .38748 L p
1 g
F P
s
P
p
.002 w
.64774 .33257 m .66138 .38748 L .67698 .39387 L p
1 g
F P
s
P
p
.002 w
.61958 .56617 m .65924 .51867 L .64854 .50894 L p
1 g
F P
s
P
p
.002 w
.67183 .45331 m .64854 .50894 L .65924 .51867 L p
1 g
F P
s
P
p
.002 w
.50898 .6171 m .56789 .60009 L .55893 .58878 L p
1 g
F P
s
P
p
.002 w
.55893 .58878 m .50108 .60537 L .50898 .6171 L p
1 g
F P
s
P
p
.002 w
.3864 .58226 m .44159 .60334 L .43656 .58749 L p
1 g
F P
s
P
p
.002 w
.43656 .58749 m .38382 .56716 L .3864 .58226 L p
1 g
F P
s
P
p
.002 w
.49525 .25202 m .44467 .25548 L .44317 .27003 L p
1 g
F P
s
P
p
.002 w
.40196 .28751 m .44317 .27003 L .44467 .25548 L p
1 g
F P
s
P
p
.002 w
.60001 .28764 m .55683 .25627 L .54265 .26534 L p
1 g
F P
s
P
p
.002 w
.49525 .25202 m .54265 .26534 L .55683 .25627 L p
1 g
F P
s
P
p
.002 w
.35756 .31049 m .33157 .35567 L .34569 .35639 L p
1 g
F P
s
P
p
.002 w
.34569 .35639 m .36813 .31748 L .35756 .31049 L p
1 g
F P
s
P
p
.002 w
.31062 .41279 m .31887 .46734 L .3291 .45475 L p
1 g
F P
s
P
p
.002 w
.3291 .45475 m .32182 .40574 L .31062 .41279 L p
1 g
F P
s
P
p
.002 w
.65924 .51867 m .68307 .46202 L .67183 .45331 L p
1 g
F P
s
P
p
.002 w
.67698 .39387 m .67183 .45331 L .68307 .46202 L p
1 g
F P
s
P
p
.002 w
.44467 .25548 m .39684 .27571 L .40196 .28751 L p
1 g
F P
s
P
p
.002 w
.36813 .31748 m .40196 .28751 L .39684 .27571 L p
1 g
F P
s
P
p
.002 w
.39684 .27571 m .35756 .31049 L .36813 .31748 L p
1 g
F P
s
P
p
.002 w
.64774 .33257 m .6164 .28543 L .60001 .28764 L p
1 g
F P
s
P
p
.002 w
.55683 .25627 m .60001 .28764 L .6164 .28543 L p
1 g
F P
s
P
p
.002 w
.44839 .61516 m .50898 .6171 L .50108 .60537 L p
1 g
F P
s
P
p
.002 w
.50108 .60537 m .44159 .60334 L .44839 .61516 L p
1 g
F P
s
P
p
.002 w
.31312 .47943 m .34096 .53002 L .3446 .5144 L p
1 g
F P
s
P
p
.002 w
.3446 .5144 m .31887 .46734 L .31312 .47943 L p
1 g
F P
s
P
p
.002 w
.67698 .39387 m .6629 .33643 L .64774 .33257 L p
1 g
F P
s
P
p
.002 w
.6164 .28543 m .64774 .33257 L .6629 .33643 L p
1 g
F P
s
P
p
.002 w
.55683 .25627 m .50412 .2413 L .49525 .25202 L p
1 g
F P
s
P
p
.002 w
.44467 .25548 m .49525 .25202 L .50412 .2413 L p
1 g
F P
s
P
p
.002 w
.34149 .54355 m .3864 .58226 L .38382 .56716 L p
1 g
F P
s
P
p
.002 w
.38382 .56716 m .34096 .53002 L .34149 .54355 L p
1 g
F P
s
P
p
.002 w
.32141 .35694 m .31062 .41279 L .32182 .40574 L p
1 g
F P
s
P
p
.002 w
.32182 .40574 m .33157 .35567 L .32141 .35694 L p
1 g
F P
s
P
p
.002 w
.68307 .46202 m .68845 .40149 L .67698 .39387 L p
1 g
F P
s
P
p
.002 w
.6629 .33643 m .67698 .39387 L .68845 .40149 L p
1 g
F P
s
P
p
.002 w
.5754 .60729 m .6267 .57359 L .61958 .56617 L p
1 g
F P
s
P
p
.002 w
.61958 .56617 m .56789 .60009 L .5754 .60729 L p
1 g
F P
s
P
p
.002 w
.65924 .51867 m .61958 .56617 L .6267 .57359 L p
1 g
F P
s
P
p
.002 w
.6267 .57359 m .66611 .52644 L .65924 .51867 L p
1 g
F P
s
P
p
.002 w
.68307 .46202 m .65924 .51867 L .66611 .52644 L p
1 g
F P
s
P
p
.002 w
.39218 .59383 m .44839 .61516 L .44159 .60334 L p
1 g
F P
s
P
p
.002 w
.44159 .60334 m .3864 .58226 L .39218 .59383 L p
1 g
F P
s
P
p
.002 w
.51695 .62424 m .5754 .60729 L .56789 .60009 L p
1 g
F P
s
P
p
.002 w
.56789 .60009 m .50898 .6171 L .51695 .62424 L p
1 g
F P
s
P
p
.002 w
.6164 .28543 m .57003 .25153 L .55683 .25627 L p
1 g
F P
s
P
p
.002 w
.50412 .2413 m .55683 .25627 L .57003 .25153 L p
1 g
F P
s
P
p
.002 w
.50412 .2413 m .44772 .24506 L .44467 .25548 L p
1 g
F P
s
P
p
.002 w
.39684 .27571 m .44467 .25548 L .44772 .24506 L p
1 g
F P
s
P
p
.002 w
.35041 .30647 m .32141 .35694 L .33157 .35567 L p
1 g
F P
s
P
p
.002 w
.33157 .35567 m .35756 .31049 L .35041 .30647 L p
1 g
F P
s
P
p
.002 w
.30413 .42063 m .31312 .47943 L .31887 .46734 L p
1 g
F P
s
P
p
.002 w
.31887 .46734 m .31062 .41279 L .30413 .42063 L p
1 g
F P
s
P
p
.002 w
.66611 .52644 m .68981 .47023 L .68307 .46202 L p
1 g
F P
s
P
p
.002 w
.68845 .40149 m .68307 .46202 L .68981 .47023 L p
1 g
F P
s
P
p
.002 w
.6629 .33643 m .63029 .28706 L .6164 .28543 L p
1 g
F P
s
P
p
.002 w
.57003 .25153 m .6164 .28543 L .63029 .28706 L p
1 g
F P
s
P
p
.002 w
.44772 .24506 m .3943 .26761 L .39684 .27571 L p
1 g
F P
s
P
p
.002 w
.35756 .31049 m .39684 .27571 L .3943 .26761 L p
1 g
F P
s
P
p
.002 w
.3943 .26761 m .35041 .30647 L .35756 .31049 L p
1 g
F P
s
P
p
.002 w
.45689 .62241 m .51695 .62424 L .50898 .6171 L p
1 g
F P
s
P
p
.002 w
.50898 .6171 m .44839 .61516 L .45689 .62241 L p
1 g
F P
s
P
p
.002 w
.31228 .49068 m .34149 .54355 L .34096 .53002 L p
1 g
F P
s
P
p
.002 w
.34096 .53002 m .31312 .47943 L .31228 .49068 L p
1 g
F P
s
P
p
.002 w
.68845 .40149 m .67424 .343 L .6629 .33643 L p
1 g
F P
s
P
p
.002 w
.63029 .28706 m .6629 .33643 L .67424 .343 L p
1 g
F P
s
P
p
.002 w
.57003 .25153 m .51325 .23529 L .50412 .2413 L p
1 g
F P
s
P
p
.002 w
.44772 .24506 m .50412 .2413 L .51325 .23529 L p
1 g
F P
s
P
p
.002 w
.34644 .55451 m .39218 .59383 L .3864 .58226 L p
1 g
F P
s
P
p
.002 w
.3864 .58226 m .34149 .54355 L .34644 .55451 L p
1 g
F P
s
P
p
.002 w
.31575 .36029 m .30413 .42063 L .31062 .41279 L p
1 g
F P
s
P
p
.002 w
.31062 .41279 m .32141 .35694 L .31575 .36029 L p
1 g
F P
s
P
p
.002 w
.68981 .47023 m .69522 .41022 L .68845 .40149 L p
1 g
F P
s
P
p
.002 w
.67424 .343 m .68845 .40149 L .69522 .41022 L p
1 g
F P
s
P
p
.002 w
.58115 .60995 m .63066 .5774 L .6267 .57359 L p
1 g
F P
s
P
p
.002 w
.6267 .57359 m .5754 .60729 L .58115 .60995 L p
1 g
F P
s
P
p
.002 w
.66611 .52644 m .6267 .57359 L .63066 .5774 L p
1 g
F P
s
P
p
.002 w
.4012 .60133 m .45689 .62241 L .44839 .61516 L p
1 g
F P
s
P
p
.002 w
.44839 .61516 m .39218 .59383 L .4012 .60133 L p
1 g
F P
s
P
p
.002 w
.63066 .5774 m .6687 .5319 L .66611 .52644 L p
1 g
F P
s
P
p
.002 w
.68981 .47023 m .66611 .52644 L .6687 .5319 L p
1 g
F P
s
P
p
.002 w
.52479 .62632 m .58115 .60995 L .5754 .60729 L p
1 g
F P
s
P
p
.002 w
.5754 .60729 m .51695 .62424 L .52479 .62632 L p
1 g
F P
s
P
p
.002 w
.63029 .28706 m .58185 .25152 L .57003 .25153 L p
1 g
F P
s
P
p
.002 w
.51325 .23529 m .57003 .25153 L .58185 .25152 L p
1 g
F P
s
P
p
.002 w
.51325 .23529 m .45234 .2393 L .44772 .24506 L p
1 g
F P
s
P
p
.002 w
.3943 .26761 m .44772 .24506 L .45234 .2393 L p
1 g
F P
s
P
p
.002 w
.3471 .3057 m .31575 .36029 L .32141 .35694 L p
1 g
F P
s
P
p
.002 w
.32141 .35694 m .35041 .30647 L .3471 .3057 L p
1 g
F P
s
P
p
.002 w
.30283 .42908 m .31228 .49068 L .31312 .47943 L p
1 g
F P
s
P
p
.002 w
.31312 .47943 m .30413 .42063 L .30283 .42908 L p
1 g
F P
s
P
p
.002 w
.67424 .343 m .64114 .29272 L .63029 .28706 L p
1 g
F P
s
P
p
.002 w
.58185 .25152 m .63029 .28706 L .64114 .29272 L p
1 g
F P
s
P
p
.002 w
.6687 .5319 m .69159 .4777 L .68981 .47023 L p
1 g
F P
s
P
p
.002 w
.69522 .41022 m .68981 .47023 L .69159 .4777 L p
1 g
F P
s
P
p
.002 w
.45234 .2393 m .39458 .26366 L .3943 .26761 L p
1 g
F P
s
P
p
.002 w
.35041 .30647 m .3943 .26761 L .39458 .26366 L p
1 g
F P
s
P
p
.002 w
.39458 .26366 m .3471 .3057 L .35041 .30647 L p
1 g
F P
s
P
p
.002 w
.46695 .62457 m .52479 .62632 L .51695 .62424 L p
1 g
F P
s
P
p
.002 w
.51695 .62424 m .45689 .62241 L .46695 .62457 L p
1 g
F P
s
P
p
.002 w
.3167 .5007 m .34644 .55451 L .34149 .54355 L p
1 g
F P
s
P
p
.002 w
.34149 .54355 m .31228 .49068 L .3167 .5007 L p
1 g
F P
s
P
p
.002 w
.69522 .41022 m .68122 .35227 L .67424 .343 L p
1 g
F P
s
P
p
.002 w
.64114 .29272 m .67424 .343 L .68122 .35227 L p
1 g
F P
s
P
p
.002 w
.58185 .25152 m .52239 .23447 L .51325 .23529 L p
1 g
F P
s
P
p
.002 w
.45234 .2393 m .51325 .23529 L .52239 .23447 L p
1 g
F P
s
P
p
.004 w
.28345 .45626 m
.28929 .45556 L
s
P
p
.002 w
.35594 .56241 m .4012 .60133 L .39218 .59383 L p
1 g
F P
s
P
p
.002 w
.39218 .59383 m .34644 .55451 L .35594 .56241 L p
1 g
F P
s
P
p
.002 w
.31503 .36577 m .30283 .42908 L .30413 .42063 L p
1 g
F P
s
P
p
.002 w
.30413 .42063 m .31575 .36029 L .31503 .36577 L p
1 g
F P
s
P
p
.002 w
.69159 .4777 m .69683 .41988 L .69522 .41022 L p
1 g
F P
s
P
p
.002 w
.68122 .35227 m .69522 .41022 L .69683 .41988 L p
1 g
F P
s
P
p
.002 w
.58487 .60768 m .63112 .57727 L .63066 .5774 L p
1 g
F P
s
P
p
.002 w
.63066 .5774 m .58115 .60995 L .58487 .60768 L p
1 g
F P
s
P
p
.002 w
.6687 .5319 m .63066 .5774 L .63112 .57727 L p
1 g
F P
s
P
p
.002 w
.41341 .60429 m .46695 .62457 L .45689 .62241 L p
1 g
F P
s
P
p
.002 w
.45689 .62241 m .4012 .60133 L .41341 .60429 L p
1 g
F P
s
P
p
.002 w
.64114 .29272 m .59186 .25653 L .58185 .25152 L p
1 g
F P
s
P
p
.002 w
.52239 .23447 m .58185 .25152 L .59186 .25653 L p
1 g
F P
s
P
p
.002 w
.63112 .57727 m .66667 .53476 L .6687 .5319 L p
1 g
F P
s
P
p
.002 w
.69159 .4777 m .6687 .5319 L .66667 .53476 L p
1 g
F P
s
P
p
.002 w
.53228 .62295 m .58487 .60768 L .58115 .60995 L p
1 g
F P
s
P
p
.002 w
.58115 .60995 m .52479 .62632 L .53228 .62295 L p
1 g
F P
s
P
p
.002 w
.52239 .23447 m .45851 .23868 L .45234 .2393 L p
1 g
F P
s
P
p
.002 w
.39458 .26366 m .45234 .2393 L .45851 .23868 L p
1 g
F P
s
P
p
.002 w
.30711 .43793 m .3167 .5007 L .31228 .49068 L p
1 g
F P
s
P
p
.002 w
.31228 .49068 m .30283 .42908 L .30711 .43793 L p
1 g
F P
s
P
p
.002 w
.34796 .30844 m .31503 .36577 L .31575 .36029 L p
1 g
F P
s
P
p
.002 w
.31575 .36029 m .3471 .3057 L .34796 .30844 L p
1 g
F P
s
P
p
.002 w
.68122 .35227 m .64846 .3025 L .64114 .29272 L p
1 g
F P
s
P
p
.002 w
.59186 .25653 m .64114 .29272 L .64846 .3025 L p
1 g
F P
s
P
p
.002 w
.66667 .53476 m .68804 .48415 L .69159 .4777 L p
1 g
F P
s
P
p
.002 w
.69683 .41988 m .69159 .4777 L .68804 .48415 L p
1 g
F P
s
P
p
.002 w
.45851 .23868 m .39785 .26427 L .39458 .26366 L p
1 g
F P
s
P
p
.002 w
.3471 .3057 m .39458 .26366 L .39785 .26427 L p
1 g
F P
s
P
p
.002 w
.47838 .62128 m .53228 .62295 L .52479 .62632 L p
1 g
F P
s
P
p
.002 w
.52479 .62632 m .46695 .62457 L .47838 .62128 L p
1 g
F P
s
P
p
.002 w
.32656 .50912 m .35594 .56241 L .34644 .55451 L p
1 g
F P
s
P
p
.002 w
.34644 .55451 m .3167 .5007 L .32656 .50912 L p
1 g
F P
s
P
p
.002 w
.39785 .26427 m .34796 .30844 L .3471 .3057 L p
1 g
F P
s
P
p
.002 w
.69683 .41988 m .68335 .36414 L .68122 .35227 L p
1 g
F P
s
P
p
.002 w
.64846 .3025 m .68122 .35227 L .68335 .36414 L p
1 g
F P
s
P
p
.002 w
.36998 .56684 m .41341 .60429 L .4012 .60133 L p
1 g
F P
s
P
p
.002 w
.4012 .60133 m .35594 .56241 L .36998 .56684 L p
1 g
F P
s
P
p
.002 w
.59186 .25653 m .53129 .23919 L .52239 .23447 L p
1 g
F P
s
P
p
.002 w
.45851 .23868 m .52239 .23447 L .53129 .23919 L p
1 g
F P
s
P
p
.002 w
.3196 .37335 m .30711 .43793 L .30283 .42908 L p
1 g
F P
s
P
p
.002 w
.30283 .42908 m .31503 .36577 L .3196 .37335 L p
1 g
F P
s
P
p
.002 w
.68804 .48415 m .69289 .43026 L .69683 .41988 L p
1 g
F P
s
P
p
.002 w
.68335 .36414 m .69683 .41988 L .69289 .43026 L p
1 g
F P
s
P
p
.002 w
.42861 .60233 m .47838 .62128 L .46695 .62457 L p
1 g
F P
s
P
p
.002 w
.46695 .62457 m .41341 .60429 L .42861 .60233 L p
1 g
F P
s
P
p
.002 w
.58632 .60022 m .62786 .57293 L .63112 .57727 L p
1 g
F P
s
P
p
.002 w
.63112 .57727 m .58487 .60768 L .58632 .60022 L p
1 g
F P
s
P
p
.002 w
.66667 .53476 m .63112 .57727 L .62786 .57293 L p
1 g
F P
s
P
p
.002 w
.64846 .3025 m .59966 .26673 L .59186 .25653 L p
1 g
F P
s
P
p
.002 w
.53129 .23919 m .59186 .25653 L .59966 .26673 L p
1 g
F P
s
P
p
.002 w
.62786 .57293 m .65976 .53475 L .66667 .53476 L p
1 g
F P
s
P
p
.002 w
.68804 .48415 m .66667 .53476 L .65976 .53475 L p
1 g
F P
s
P
p
.002 w
.53915 .61387 m .58632 .60022 L .58487 .60768 L p
1 g
F P
s
P
p
.002 w
.58487 .60768 m .53228 .62295 L .53915 .61387 L p
1 g
F P
s
P
p
.002 w
.31717 .44693 m .32656 .50912 L .3167 .5007 L p
1 g
F P
s
P
p
.002 w
.3167 .5007 m .30711 .43793 L .31717 .44693 L p
1 g
F P
s
P
p
.002 w
.53129 .23919 m .46614 .24354 L .45851 .23868 L p
1 g
F P
s
P
p
.002 w
.39785 .26427 m .45851 .23868 L .46614 .24354 L p
1 g
F P
s
P
p
.002 w
.68335 .36414 m .65181 .31636 L .64846 .3025 L p
1 g
F P
s
P
p
.002 w
.59966 .26673 m .64846 .3025 L .65181 .31636 L p
1 g
F P
s
P
p
.002 w
.35327 .31483 m .3196 .37335 L .31503 .36577 L p
1 g
F P
s
P
p
.002 w
.31503 .36577 m .34796 .30844 L .35327 .31483 L p
1 g
F P
s
P
p
.002 w
.65976 .53475 m .6789 .48934 L .68804 .48415 L p
1 g
F P
s
P
p
.002 w
.69289 .43026 m .68804 .48415 L .6789 .48934 L p
1 g
F P
s
P
p
.002 w
.3419 .51558 m .36998 .56684 L .35594 .56241 L p
1 g
F P
s
P
p
.002 w
.35594 .56241 m .32656 .50912 L .3419 .51558 L p
1 g
F P
s
P
p
.002 w
.49091 .61229 m .53915 .61387 L .53228 .62295 L p
1 g
F P
s
P
p
.002 w
.53228 .62295 m .47838 .62128 L .49091 .61229 L p
1 g
F P
s
P
p
.002 w
.46614 .24354 m .40423 .2697 L .39785 .26427 L p
1 g
F P
s
P
p
.002 w
.34796 .30844 m .39785 .26427 L .40423 .2697 L p
1 g
F P
s
P
p
.002 w
.69289 .43026 m .68027 .37842 L .68335 .36414 L p
1 g
F P
s
P
p
.002 w
.65181 .31636 m .68335 .36414 L .68027 .37842 L p
1 g
F P
s
P
p
.002 w
.40423 .2697 m .35327 .31483 L .34796 .30844 L p
1 g
F P
s
P
p
.002 w
.38839 .56742 m .42861 .60233 L .41341 .60429 L p
1 g
F P
s
P
p
.002 w
.41341 .60429 m .36998 .56684 L .38839 .56742 L p
1 g
F P
s
P
p
.002 w
.59966 .26673 m .53965 .24966 L .53129 .23919 L p
1 g
F P
s
P
p
.002 w
.46614 .24354 m .53129 .23919 L .53965 .24966 L p
1 g
F P
s
P
p
.002 w
.32967 .38293 m .31717 .44693 L .30711 .43793 L p
1 g
F P
s
P
p
.002 w
.30711 .43793 m .3196 .37335 L .32967 .38293 L p
1 g
F P
s
P
p
.002 w
.6789 .48934 m .68317 .44108 L .69289 .43026 L p
1 g
F P
s
P
p
.002 w
.68027 .37842 m .69289 .43026 L .68317 .44108 L p
1 g
F P
s
P
p
.002 w
.44652 .59522 m .49091 .61229 L .47838 .62128 L p
1 g
F P
s
P
p
.002 w
.47838 .62128 m .42861 .60233 L .44652 .59522 L p
1 g
F P
s
P
p
.002 w
.65181 .31636 m .60486 .28212 L .59966 .26673 L p
1 g
F P
s
P
p
.002 w
.53965 .24966 m .59966 .26673 L .60486 .28212 L p
1 g
F P
s
P
p
.002 w
.58531 .58746 m .62071 .56423 L .62786 .57293 L p
1 g
F P
s
P
p
.002 w
.62786 .57293 m .58632 .60022 L .58531 .58746 L p
1 g
F P
s
P
p
.002 w
.65976 .53475 m .62786 .57293 L .62071 .56423 L p
1 g
F P
s
P
p
.002 w
.62071 .56423 m .64789 .53169 L .65976 .53475 L p
1 g
F P
s
P
p
.002 w
.6789 .48934 m .65976 .53475 L .64789 .53169 L p
1 g
F P
s
P
p
.002 w
.33306 .45581 m .3419 .51558 L .32656 .50912 L p
1 g
F P
s
P
p
.002 w
.32656 .50912 m .31717 .44693 L .33306 .45581 L p
1 g
F P
s
P
p
.002 w
.54514 .59902 m .58531 .58746 L .58632 .60022 L p
1 g
F P
s
P
p
.002 w
.58632 .60022 m .53915 .61387 L .54514 .59902 L p
1 g
F P
s
P
p
.002 w
.53965 .24966 m .47508 .25408 L .46614 .24354 L p
1 g
F P
s
P
p
.002 w
.40423 .2697 m .46614 .24354 L .47508 .25408 L p
1 g
F P
s
P
p
.002 w
.68027 .37842 m .65085 .33411 L .65181 .31636 L p
1 g
F P
s
P
p
.002 w
.60486 .28212 m .65181 .31636 L .65085 .33411 L p
1 g
F P
s
P
p
.002 w
.36313 .3249 m .32967 .38293 L .3196 .37335 L p
1 g
F P
s
P
p
.002 w
.3196 .37335 m .35327 .31483 L .36313 .3249 L p
1 g
F P
s
P
p
.002 w
.36252 .51975 m .38839 .56742 L .36998 .56684 L p
1 g
F P
s
P
p
.002 w
.36998 .56684 m .3419 .51558 L .36252 .51975 L p
1 g
F P
s
P
p
.002 w
.64789 .53169 m .66413 .49301 L .6789 .48934 L p
1 g
F P
s
P
p
.002 w
.68317 .44108 m .6789 .48934 L .66413 .49301 L p
1 g
F P
s
P
p
.002 w
.68317 .44108 m .67177 .39478 L .68027 .37842 L p
1 g
F P
s
P
p
.002 w
.65085 .33411 m .68027 .37842 L .67177 .39478 L p
1 g
F P
s
P
p
.002 w
.50419 .59756 m .54514 .59902 L .53915 .61387 L p
1 g
F P
s
P
p
.002 w
.53915 .61387 m .49091 .61229 L .50419 .59756 L p
1 g
F P
s
P
p
.002 w
.47508 .25408 m .41369 .28011 L .40423 .2697 L p
1 g
F P
s
P
p
.002 w
.35327 .31483 m .40423 .2697 L .41369 .28011 L p
1 g
F P
s
P
p
.002 w
.41369 .28011 m .36313 .3249 L .35327 .31483 L p
1 g
F P
s
P
p
.002 w
.41079 .56394 m .44652 .59522 L .42861 .60233 L p
1 g
F P
s
P
p
.002 w
.42861 .60233 m .38839 .56742 L .41079 .56394 L p
1 g
F P
s
P
p
.002 w
.60486 .28212 m .54717 .26589 L .53965 .24966 L p
1 g
F P
s
P
p
.002 w
.47508 .25408 m .53965 .24966 L .54717 .26589 L p
1 g
F P
s
P
p
.002 w
.34523 .39431 m .33306 .45581 L .31717 .44693 L p
1 g
F P
s
P
p
.004 w
.28929 .45556 m
.32232 .45163 L
s
P
p
.002 w
.31717 .44693 m .32967 .38293 L .34523 .39431 L p
1 g
F P
s
P
p
.002 w
.66413 .49301 m .66765 .452 L .68317 .44108 L p
1 g
F P
s
P
p
.002 w
.67177 .39478 m .68317 .44108 L .66765 .452 L p
1 g
F P
s
P
p
.002 w
.46665 .58293 m .50419 .59756 L .49091 .61229 L p
1 g
F P
s
P
p
.002 w
.49091 .61229 m .44652 .59522 L .46665 .58293 L p
1 g
F P
s
P
p
.002 w
.65085 .33411 m .60715 .30249 L .60486 .28212 L p
1 g
F P
s
P
p
.002 w
.54717 .26589 m .60486 .28212 L .60715 .30249 L p
1 g
F P
s
P
p
.002 w
.5817 .56952 m .60967 .5512 L .62071 .56423 L p
1 g
F P
s
P
p
.002 w
.62071 .56423 m .58531 .58746 L .5817 .56952 L p
1 g
F P
s
P
p
.002 w
.64789 .53169 m .62071 .56423 L .60967 .5512 L p
1 g
F P
s
P
p
.002 w
.35455 .46424 m .36252 .51975 L .3419 .51558 L p
1 g
F P
s
P
p
.002 w
.3419 .51558 m .33306 .45581 L .35455 .46424 L p
1 g
F P
s
P
p
.002 w
.60967 .5512 m .63112 .52549 L .64789 .53169 L p
1 g
F P
s
P
p
.002 w
.66413 .49301 m .64789 .53169 L .63112 .52549 L p
1 g
F P
s
P
p
.002 w
.67177 .39478 m .64536 .35538 L .65085 .33411 L p
1 g
F P
s
P
p
.002 w
.60715 .30249 m .65085 .33411 L .64536 .35538 L p
1 g
F P
s
P
p
.002 w
.55001 .57855 m .5817 .56952 L .58531 .58746 L p
1 g
F P
s
P
p
.002 w
.58531 .58746 m .54514 .59902 L .55001 .57855 L p
1 g
F P
s
P
p
.002 w
.54717 .26589 m .48512 .27031 L .47508 .25408 L p
1 g
F P
s
P
p
.002 w
.41369 .28011 m .47508 .25408 L .48512 .27031 L p
1 g
F P
s
P
p
.002 w
.37749 .33854 m .34523 .39431 L .32967 .38293 L p
1 g
F P
s
P
p
.002 w
.32967 .38293 m .36313 .3249 L .37749 .33854 L p
1 g
F P
s
P
p
.002 w
.38798 .52136 m .41079 .56394 L .38839 .56742 L p
1 g
F P
s
P
p
.002 w
.38839 .56742 m .36252 .51975 L .38798 .52136 L p
1 g
F P
s
P
p
.002 w
.63112 .52549 m .64387 .49495 L .66413 .49301 L p
1 g
F P
s
P
p
.002 w
.66765 .452 m .66413 .49301 L .64387 .49495 L p
1 g
F P
s
P
p
.002 w
.66765 .452 m .65782 .4128 L .67177 .39478 L p
1 g
F P
s
P
p
.002 w
.64536 .35538 m .67177 .39478 L .65782 .4128 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .5806 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .5806 L .51347 .58014 L 1 g
F
P
p
.50419 .59756 m .49704 .58309 L .51094 .5806 L 1 g
F
P
p
.002 w
.5162 .57965 m .51549 .58071 L p
.51094 .5806 L 1 g
F P
s
P
p
.002 w
.51549 .58071 m .50419 .59756 L p
.51094 .5806 L 1 g
F P
s
P
p
.002 w
.51094 .5806 m .51079 .57862 L p
.50204 .58037 L 1 g
F P
s
P
p
.53128 .57265 m .51347 .58014 L .51955 .57867 L 1 g
F
P
p
.51347 .58014 m .51098 .58119 L .5162 .57965 L 1 g
F
P
p
.51347 .58014 m .5162 .57965 L .51955 .57867 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58004 L p
1 g
F P
s
P
p
.49704 .58309 m .49562 .58021 L .51094 .5806 L 1 g
F
P
p
.51079 .57862 m .4891 .58004 L .50204 .58037 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.50419 .59756 m .46665 .58293 L .47452 .57667 L p
1 g
F P
s
P
p
.002 w
.4891 .58004 m .48921 .57862 L p
.47952 .57782 L 1 g
F P
s
P
p
.50419 .59756 m .47452 .57667 L .49636 .58172 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46835 .57436 L p
1 g
F P
s
P
p
.46665 .58293 m .46626 .57358 L .46835 .57436 L 1 g
F
P
p
.002 w
.47452 .57667 m .47328 .57766 L p
.46835 .57436 L 1 g
F P
s
P
p
.002 w
.47328 .57766 m .46665 .58293 L p
.46835 .57436 L 1 g
F P
s
P
p
.002 w
.46835 .57436 m .46872 .57265 L p
.46143 .56974 L 1 g
F P
s
P
p
.48921 .57862 m .46835 .57436 L .47707 .57762 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45093 .56272 L p
1 g
F P
s
P
p
.46872 .57265 m .45093 .56272 L .46143 .56974 L 1 g
F
P
p
.46835 .57436 m .46505 .54461 L .47452 .57667 L 1 g
F
P
p
.46626 .57358 m .46623 .57295 L .46835 .57436 L 1 g
F
P
p
.46623 .57295 m .46505 .54461 L .46835 .57436 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46665 .58293 m .43661 .5563 L .44301 .55367 L p
1 g
F P
s
P
p
.002 w
.45093 .56272 m .45146 .56129 L p
.44404 .55484 L 1 g
F P
s
P
p
.46665 .58293 m .44301 .55367 L .46655 .58057 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43852 .54704 L p
1 g
F P
s
P
p
.002 w
.44301 .55367 m .43661 .5563 L p
.43937 .5483 L 1 g
F P
s
P
p
.45146 .56129 m .43852 .54704 L .44348 .55435 L 1 g
F
P
p
.002 w
.43661 .5563 m .4176 .52023 L .42013 .51992 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42013 .51992 m .4298 .51877 L p
.43276 .52836 L 1 g
F P
s
P
p
.43852 .54704 m .43235 .53794 L .43276 .52836 L 1 g
F
P
p
.43235 .53794 m .42013 .51992 L .43276 .52836 L 1 g
F
P
p
.002 w
.43276 .52836 m .43346 .52734 L p
.43316 .51882 L 1 g
F P
s
P
p
.002 w
.43852 .54704 m .43925 .54566 L p
.43628 .53979 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43852 .54704 m .43276 .52836 L .45041 .5163 L 1 g
F
P
p
.002 w
.4298 .51877 m .43318 .51836 L p
.43276 .52836 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43414 .5091 L p
1 g
F P
s
P
p
.4176 .52023 m .43532 .4977 L .43414 .5091 L 1 g
F
P
p
.002 w
.43318 .51836 m .42952 .5188 L p
.43414 .5091 L 1 g
F P
s
P
p
.002 w
.42952 .5188 m .4176 .52023 L p
.43414 .5091 L 1 g
F P
s
P
p
.002 w
.43414 .5091 m .43485 .50826 L p
.43751 .50203 L 1 g
F P
s
P
p
.43346 .52734 m .43414 .5091 L .43352 .51508 L 1 g
F
P
p
.43346 .52734 m .43355 .50981 L .43316 .51882 L 1 g
F
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44263 .49131 L p
1 g
F P
s
P
p
.43485 .50826 m .44263 .49131 L .43751 .50203 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.43414 .5091 m .44273 .49121 L .43318 .51836 L 1 g
F
P
p
.44273 .49121 m .44392 .49006 L .43318 .51836 L 1 g
F
P
p
.43532 .4977 m .44614 .48395 L .43414 .5091 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48264 .48729 m .45013 .48406 L p
.4843 .46631 L 1 g
F P
s
P
p
.002 w
.48737 .46591 m .48264 .48729 L p
.4843 .46631 L 1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47673 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56611 .50941 L p
1 g
F P
s
P
p
.002 w
.57675 .51312 m .56999 .51752 L p
.56611 .50941 L 1 g
F P
s
P
p
.56519 .50023 m .56611 .50941 L .55779 .49199 L 1 g
F
P
p
.57675 .51312 m .56611 .50941 L .56519 .50023 L 1 g
F
P
p
.002 w
.56611 .50941 m .56515 .50826 L p
.56722 .5217 L 1 g
F P
s
P
p
.56722 .5217 m .56722 .52164 L .56611 .50941 L 1 g
F
P
p
.57549 .54671 m .56783 .53755 L .56749 .52873 L 1 g
F
P
p
.002 w
.56719 .52097 m .56857 .52526 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.56857 .52526 m .57549 .54671 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.56749 .52873 m .56654 .52734 L p
.56459 .53802 L 1 g
F P
s
P
p
.56722 .52164 m .56712 .51939 L .56611 .50941 L 1 g
F
P
p
.56723 .52174 m .56719 .52097 L .56722 .52164 L 1 g
F
P
p
.56719 .52097 m .56712 .51939 L .56722 .52164 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .54739 L p
1 g
F P
s
P
p
.56654 .52734 m .56167 .54739 L .56459 .53802 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55352 .5529 m .55548 .52277 L p
.56811 .53789 L 1 g
F P
s
P
p
.002 w
.57549 .54671 m .55896 .55137 L p
.56811 .53789 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56302 L p
1 g
F P
s
P
p
.56075 .54566 m .54918 .56302 L .55022 .56186 L 1 g
F
P
p
.55001 .57855 m .54353 .56933 L .54918 .56302 L 1 g
F
P
p
.002 w
.55267 .55913 m .55243 .56089 L p
.54918 .56302 L 1 g
F P
s
P
p
.002 w
.55243 .56089 m .55001 .57855 L p
.54918 .56302 L 1 g
F P
s
P
p
.002 w
.54918 .56302 m .54854 .56129 L p
.54131 .56818 L 1 g
F P
s
P
p
.56075 .54566 m .55022 .56186 L .55404 .55744 L 1 g
F
P
p
.55022 .56186 m .54929 .5633 L .55267 .55913 L 1 g
F
P
p
.55022 .56186 m .55267 .55913 L .55404 .55744 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53168 .5745 L p
1 g
F P
s
P
p
.54854 .56129 m .53168 .5745 L .54131 .56818 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.55001 .57855 m .54514 .59902 L p
.51955 .57867 L 1 g
F P
s
P
p
.002 w
.52351 .5775 m .55001 .57855 L p
.51955 .57867 L 1 g
F P
s
P
p
.002 w
.53168 .5745 m .53128 .57265 L p
.51955 .57867 L 1 g
F P
s
P
p
.54514 .59902 m .5162 .57965 L .51955 .57867 L 1 g
F
P
p
.51955 .57867 m .51752 .57971 L .52351 .5775 L 1 g
F
P
p
.51955 .57867 m .52351 .5775 L .53168 .5745 L 1 g
F
P
p
.002 w
.54514 .59902 m .50419 .59756 L .5162 .57965 L p
1 g
F P
s
P
p
.002 w
.5162 .57965 m .5178 .57728 L p
.51955 .57867 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.5178 .57728 m .53127 .55191 L p
.54397 .56997 L 1 g
F P
s
P
p
.002 w
.55001 .57855 m .52351 .5775 L p
.54397 .56997 L 1 g
F P
s
P
p
.002 w
.52351 .5775 m .5178 .57728 L p
.54397 .56997 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53168 .5745 L p
1 g
F P
s
P
p
.51752 .57971 m .51111 .583 L .53168 .5745 L 1 g
F
P
p
.002 w
.53168 .5745 m .5322 .57686 L p
.54131 .56818 L 1 g
F P
s
P
p
.54918 .56302 m .53127 .55191 L .55267 .55913 L 1 g
F
P
p
.54353 .56933 m .54227 .56755 L .54918 .56302 L 1 g
F
P
p
.54227 .56755 m .53127 .55191 L .54918 .56302 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56302 L p
1 g
F P
s
P
p
.54131 .56818 m .5322 .57686 L .54918 .56302 L 1 g
F
P
p
.002 w
.53127 .55191 m .55352 .5529 L .55267 .55913 L p
1 g
F P
s
P
p
.002 w
.54918 .56302 m .54929 .5633 L p
.55022 .56186 L 1 g
F P
s
P
p
.002 w
.5817 .56952 m .55001 .57855 L .55267 .55913 L p
1 g
F P
s
P
p
.56075 .54566 m .55404 .55744 L .55471 .55661 L 1 g
F
P
p
.5817 .56952 m .55267 .55913 L .55636 .55458 L 1 g
F
P
p
.002 w
.57549 .54671 m .5817 .56952 L p
.55636 .55458 L 1 g
F P
s
P
p
.002 w
.55896 .55137 m .57549 .54671 L p
.55636 .55458 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55267 .55913 m .55352 .5529 L p
.55636 .55458 L 1 g
F P
s
P
p
.55471 .55661 m .54984 .5648 L .55171 .56206 L 1 g
F
P
p
.55404 .55744 m .54984 .5648 L .55471 .55661 L 1 g
F
P
p
.002 w
.54929 .5633 m .54984 .5648 L p
.55404 .55744 L 1 g
F P
s
P
p
.002 w
.55352 .5529 m .55896 .55137 L p
.55636 .55458 L 1 g
F P
s
P
p
.002 w
.55896 .55137 m .55352 .5529 L p
.56811 .53789 L 1 g
F P
s
P
p
.002 w
.54984 .5648 m .54998 .56518 L p
.55171 .56206 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56257 .5491 L p
.56459 .53802 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56816 .5297 L p
1 g
F P
s
P
p
.56723 .52174 m .56816 .5297 L .56761 .5242 L 1 g
F
P
p
.56515 .50826 m .56732 .52368 L .56723 .52174 L 1 g
F
P
p
.56732 .52368 m .56816 .5297 L .56723 .52174 L 1 g
F
P
p
.002 w
.5949 .53402 m .57549 .54671 L .56719 .52097 L p
1 g
F P
s
P
p
.002 w
.56719 .52097 m .56676 .51963 L p
.56714 .51982 L 1 g
F P
s
P
p
.5949 .53402 m .56719 .52097 L .56714 .51982 L 1 g
F
P
p
.55661 .4905 m .56611 .50941 L .56208 .50097 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55757 .49152 m .55661 .4905 L p
.56208 .50097 L 1 g
F P
s
P
p
.002 w
.55932 .49321 m .57675 .51312 L p
.5561 .4901 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55757 .49152 L p
1 g
F P
s
P
p
.56208 .50097 m .56713 .51061 L .55757 .49152 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55757 .49152 L p
1 g
F P
s
P
p
.54174 .47608 m .55757 .49152 L .55632 .49031 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.5561 .4901 m .55575 .48913 L .55724 .49083 L p
1 g
F P
s
P
p
.002 w
.55724 .49083 m .55932 .49321 L p
.55757 .49152 L 1 g
F P
s
P
p
.55757 .49152 m .5561 .4901 L .55724 .49083 L 1 g
F
P
p
.56611 .50941 m .56676 .51963 L .55779 .49199 L 1 g
F
P
p
.002 w
.56999 .51752 m .56712 .51939 L p
.56611 .50941 L 1 g
F P
s
P
p
.002 w
.56712 .51939 m .56676 .51963 L p
.56611 .50941 L 1 g
F P
s
P
p
.002 w
.56816 .5297 m .56854 .53025 L p
.56761 .5242 L 1 g
F P
s
P
p
.56749 .52873 m .55548 .52277 L .56719 .52097 L 1 g
F
P
p
.56783 .53755 m .56558 .53485 L .56749 .52873 L 1 g
F
P
p
.56558 .53485 m .55548 .52277 L .56749 .52873 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56749 .52873 L p
1 g
F P
s
P
p
.56459 .53802 m .56257 .5491 L .56749 .52873 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55548 .52277 m .56676 .51963 L .56719 .52097 L p
1 g
F P
s
P
p
.56722 .5217 m .56723 .52174 L .56722 .52164 L 1 g
F
P
p
.002 w
.57675 .51312 m .5949 .53402 L p
.56714 .51982 L 1 g
F P
s
P
p
.002 w
.56712 .51939 m .57675 .51312 L p
.56714 .51982 L 1 g
F P
s
P
p
.56723 .52174 m .56761 .5242 L .56712 .51939 L 1 g
F
P
p
.002 w
.56676 .51963 m .56712 .51939 L p
.56714 .51982 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .50941 L p
1 g
F P
s
P
p
.56761 .5242 m .56854 .53025 L .56611 .50941 L 1 g
F
P
p
.002 w
.56611 .50941 m .56713 .51061 L p
.56208 .50097 L 1 g
F P
s
P
p
.002 w
.56676 .51963 m .5561 .4901 L p
.55779 .49199 L 1 g
F P
s
P
p
.002 w
.55757 .49152 m .55774 .4917 L p
.55632 .49031 L 1 g
F P
s
P
p
.54174 .47608 m .55633 .49032 L .5513 .48544 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .52277 m .54409 .52219 L .55558 .4896 L p
1 g
F P
s
P
p
.002 w
.55558 .4896 m .55575 .48913 L .55574 .48976 L p
1 g
F P
s
P
p
.002 w
.55574 .48976 m .55548 .52277 L p
.55558 .4896 L 1 g
F P
s
P
p
.002 w
.54409 .52219 m .53381 .51794 L .55547 .48949 L p
1 g
F P
s
P
p
.002 w
.55547 .48949 m .55575 .48913 L .55558 .4896 L p
1 g
F P
s
P
p
.002 w
.55558 .4896 m .54409 .52219 L p
.55547 .48949 L 1 g
F P
s
P
p
.002 w
.53381 .51794 m .52576 .51044 L .55537 .4894 L p
1 g
F P
s
P
p
.002 w
.55537 .4894 m .55575 .48913 L .55547 .48949 L p
1 g
F P
s
P
p
.002 w
.55547 .48949 m .53381 .51794 L p
.55537 .4894 L 1 g
F P
s
P
p
.002 w
.52576 .51044 m .52083 .50047 L .55526 .48929 L p
1 g
F P
s
P
p
.002 w
.55526 .48929 m .55575 .48913 L .55537 .4894 L p
1 g
F P
s
P
p
.002 w
.55537 .4894 m .52576 .51044 L p
.55526 .48929 L 1 g
F P
s
P
p
.55553 .48955 m .55774 .4917 L .55533 .48936 L 1 g
F
P
p
.55558 .4896 m .55566 .48968 L .55553 .48955 L 1 g
F
P
p
.55566 .48968 m .55774 .4917 L .55553 .48955 L 1 g
F
P
p
.55565 .48967 m .5557 .48972 L .55558 .4896 L 1 g
F
P
p
.5557 .48972 m .55774 .4917 L .55558 .4896 L 1 g
F
P
p
.55574 .48976 m .55577 .48979 L .55565 .48967 L 1 g
F
P
p
.55577 .48979 m .55774 .4917 L .55565 .48967 L 1 g
F
P
p
.55633 .49032 m .55637 .49037 L .55574 .48976 L 1 g
F
P
p
.55637 .49037 m .55774 .4917 L .55574 .48976 L 1 g
F
P
p
.002 w
.53723 .47432 m .55206 .48618 L p
.52704 .46952 L 1 g
F P
s
P
p
.002 w
.55206 .48618 m .53723 .47432 L p
.54234 .47673 L 1 g
F P
s
P
p
.53386 .47274 m .53723 .47432 L .54302 .47747 L 1 g
F
P
p
.002 w
.54234 .47673 m .54234 .47674 L p
.53723 .47432 L 1 g
F P
s
P
p
.002 w
.54234 .47674 m .54302 .47747 L p
.53723 .47432 L 1 g
F P
s
P
p
.002 w
.5222 .47763 m .52704 .46952 L p
.55206 .48618 L 1 g
F P
s
P
p
.52214 .46667 m .54234 .47673 L .53386 .47274 L 1 g
F
P
p
.002 w
.52704 .46952 m .5222 .47763 L p
.5219 .46716 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46725 L p
1 g
F P
s
P
p
.5219 .46696 m .52249 .46725 L .5219 .46716 L 1 g
F
P
p
.52249 .46725 m .52704 .46952 L .5219 .46716 L 1 g
F
P
p
.5 .4634 m .52249 .46725 L .51126 .46556 L 1 g
F
P
p
.002 w
.5222 .47763 m .49013 .46548 L p
.51992 .46687 L 1 g
F P
s
P
p
.51992 .46687 m .5219 .46696 L .5219 .46716 L 1 g
F
P
p
.51992 .46687 m .5219 .46716 L .5222 .47763 L 1 g
F
P
p
.002 w
.52249 .46725 m .52214 .46667 L p
.54227 .47709 L 1 g
F P
s
P
p
.49347 .46494 m .52839 .46726 L .49013 .46548 L 1 g
F
P
p
.002 w
.5 .46387 m .5 .4634 L p
.51126 .46556 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48767 .46455 m .49986 .44401 L .5202 .46058 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5202 .46058 m .52839 .46726 L p
.49347 .46494 L 1 g
F P
s
P
p
.45429 .48001 m .48373 .46638 L .45013 .48406 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46429 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46429 L .4952 .46491 L 1 g
F
P
p
.002 w
.47756 .46717 m .47786 .46667 L p
.49111 .46532 L 1 g
F P
s
P
p
.49111 .46532 m .49094 .46535 L .47756 .46717 L 1 g
F
P
p
.49124 .46531 m .48737 .46591 L .47756 .46717 L 1 g
F
P
p
.48373 .46638 m .48767 .46455 L .4843 .46631 L 1 g
F
P
p
.48373 .46638 m .4843 .46631 L .45013 .48406 L 1 g
F
P
p
.002 w
.5 .46429 m .5 .46442 L p
.4952 .46491 L 1 g
F P
s
P
p
.48767 .46455 m .5202 .46058 L .49347 .46494 L 1 g
F
P
p
.002 w
.49013 .46548 m .5222 .47763 L p
.48737 .46591 L 1 g
F P
s
P
p
.49124 .46531 m .4952 .46491 L .48795 .46584 L 1 g
F
P
p
.49013 .46548 m .48795 .46584 L .48737 .46591 L 1 g
F
P
p
.49124 .46531 m .48795 .46584 L .49013 .46548 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.51126 .46556 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.002 w
.52249 .46725 m .52282 .46778 L p
.51126 .46556 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46725 L p
1 g
F P
s
P
p
.54227 .47709 m .54302 .47747 L .52249 .46725 L 1 g
F
P
p
.002 w
.52839 .46726 m .52704 .46952 L p
.5219 .46696 L 1 g
F P
s
P
p
.002 w
.52704 .46952 m .52839 .46726 L .53723 .47432 L p
1 g
F P
s
P
p
.002 w
.52083 .50047 m .51959 .48912 L .55509 .48913 L p
1 g
F P
s
P
p
.002 w
.55509 .48913 m .55575 .48913 L .55526 .48929 L p
1 g
F P
s
P
p
.002 w
.55526 .48929 m .52083 .50047 L p
.55509 .48913 L 1 g
F P
s
P
p
.55633 .49032 m .55547 .4895 L .5513 .48544 L 1 g
F
P
p
.55547 .4895 m .55543 .48945 L .55521 .48924 L 1 g
F
P
p
.55547 .4895 m .55521 .48924 L .5513 .48544 L 1 g
F
P
p
.55543 .48945 m .55538 .4894 L .55476 .48881 L 1 g
F
P
p
.55543 .48945 m .55476 .48881 L .5513 .48544 L 1 g
F
P
p
.002 w
.51959 .48912 m .5222 .47763 L .55474 .48878 L p
1 g
F P
s
P
p
.002 w
.55474 .48878 m .55575 .48913 L .55509 .48913 L p
1 g
F P
s
P
p
.002 w
.55509 .48913 m .51959 .48912 L p
.55474 .48878 L 1 g
F P
s
P
p
.55538 .4894 m .55206 .48618 L .5513 .48544 L 1 g
F
P
p
.002 w
.55206 .48618 m .55575 .48913 L .55474 .48878 L p
1 g
F P
s
P
p
.002 w
.55474 .48878 m .5222 .47763 L p
.55206 .48618 L 1 g
F P
s
P
p
.55538 .4894 m .55533 .48936 L .55206 .48618 L 1 g
F
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56676 .51963 m .55548 .52277 L .55574 .48976 L p
1 g
F P
s
P
p
.002 w
.55574 .48976 m .55575 .48913 L .5561 .4901 L p
1 g
F P
s
P
p
.002 w
.5561 .4901 m .56676 .51963 L p
.55574 .48976 L 1 g
F P
s
P
p
.002 w
.55055 .4806 m .55575 .48913 L .55206 .48618 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54234 .47673 L p
1 g
F P
s
P
p
.002 w
.54234 .47673 m .54174 .47608 L p
.5513 .48544 L 1 g
F P
s
P
p
.5513 .48544 m .55834 .49233 L .54234 .47673 L 1 g
F
P
p
.002 w
.53723 .47432 m .52839 .46726 L p
.53943 .47391 L 1 g
F P
s
P
p
.53943 .47391 m .55055 .4806 L .54234 .47673 L 1 g
F
P
p
.53943 .47391 m .54234 .47673 L .53723 .47432 L 1 g
F
P
p
.54234 .47673 m .55055 .4806 L .55206 .48618 L 1 g
F
P
p
.002 w
.55774 .4917 m .55834 .49233 L p
.5513 .48544 L 1 g
F P
s
P
p
.002 w
.52839 .46726 m .53748 .45917 L .55055 .4806 L p
1 g
F P
s
P
p
.002 w
.49013 .46548 m .48767 .46455 L p
.49347 .46494 L 1 g
F P
s
P
p
.49111 .46532 m .49124 .46531 L .49094 .46535 L 1 g
F
P
p
.002 w
.48264 .48729 m .48737 .46591 L p
.5222 .47763 L 1 g
F P
s
P
p
.002 w
.48737 .46591 m .48767 .46455 L .49013 .46548 L p
1 g
F P
s
P
p
.002 w
.44634 .48369 m .45352 .45041 L .47539 .45946 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45429 .48001 m .45772 .47667 L .48767 .46455 L 1 g
F
P
p
.002 w
.48518 .46352 m .48767 .46455 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45772 .47667 L p
1 g
F P
s
P
p
.002 w
.45772 .47667 m .45826 .47608 L p
.46646 .47248 L 1 g
F P
s
P
p
.46646 .47248 m .47718 .46778 L .45772 .47667 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46717 L p
1 g
F P
s
P
p
.002 w
.47756 .46717 m .47718 .46778 L p
.46646 .47248 L 1 g
F P
s
P
p
.45826 .47608 m .47756 .46717 L .46646 .47248 L 1 g
F
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45703 .47742 L p
1 g
F P
s
P
p
.002 w
.45703 .47742 m .45698 .47747 L p
.45593 .47848 L 1 g
F P
s
P
p
.44339 .4905 m .45703 .47742 L .45593 .47848 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45041 .5163 m .43318 .51836 L p
.44392 .49006 L 1 g
F P
s
P
p
.002 w
.44263 .49131 m .44339 .4905 L p
.45119 .48303 L 1 g
F P
s
P
p
.45119 .48303 m .45068 .48352 L .44263 .49131 L 1 g
F
P
p
.45156 .48267 m .44679 .48729 L .44263 .49131 L 1 g
F
P
p
.002 w
.44634 .48369 m .44679 .48729 L p
.44392 .49006 L 1 g
F P
s
P
p
.002 w
.44679 .48729 m .45041 .5163 L p
.44392 .49006 L 1 g
F P
s
P
p
.44634 .48369 m .45077 .48 L .45429 .48001 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.45077 .48 m .47539 .45946 L .45772 .47667 L 1 g
F
P
p
.45077 .48 m .45772 .47667 L .45429 .48001 L 1 g
F
P
p
.002 w
.47539 .45946 m .48518 .46352 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.45013 .48406 m .48264 .48729 L p
.44679 .48729 L 1 g
F P
s
P
p
.45156 .48267 m .45593 .47848 L .4482 .48594 L 1 g
F
P
p
.45013 .48406 m .4482 .48594 L .44679 .48729 L 1 g
F
P
p
.45156 .48267 m .4482 .48594 L .45013 .48406 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46717 L p
1 g
F P
s
P
p
.4952 .46491 m .5 .46442 L .47756 .46717 L 1 g
F
P
p
.002 w
.48767 .46455 m .48737 .46591 L p
.4843 .46631 L 1 g
F P
s
P
p
.002 w
.45013 .48406 m .44634 .48369 L p
.45429 .48001 L 1 g
F P
s
P
p
.45119 .48303 m .45156 .48267 L .45068 .48352 L 1 g
F
P
p
.002 w
.45041 .5163 m .44679 .48729 L p
.48264 .48729 L 1 g
F P
s
P
p
.002 w
.44679 .48729 m .44634 .48369 L .45013 .48406 L p
1 g
F P
s
P
p
.44614 .48395 m .44634 .48369 L .43414 .5091 L 1 g
F
P
p
.002 w
.44263 .49131 m .44166 .49233 L p
.43751 .50203 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44263 .49131 L p
1 g
F P
s
P
p
.45593 .47848 m .45698 .47747 L .44263 .49131 L 1 g
F
P
p
.44273 .49121 m .44634 .48369 L .44392 .49006 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43414 .5091 L p
1 g
F P
s
P
p
.43751 .50203 m .44166 .49233 L .43414 .5091 L 1 g
F
P
p
.002 w
.43414 .5091 m .43355 .50981 L p
.43352 .51508 L 1 g
F P
s
P
p
.002 w
.43318 .51836 m .45041 .5163 L p
.43276 .52836 L 1 g
F P
s
P
p
.002 w
.43355 .50981 m .43287 .51061 L p
.43316 .51882 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43276 .52836 L p
1 g
F P
s
P
p
.43316 .51882 m .43287 .51061 L .43276 .52836 L 1 g
F
P
p
.43661 .5563 m .42013 .51992 L .43937 .5483 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43852 .54704 L p
1 g
F P
s
P
p
.43628 .53979 m .43146 .53025 L .43852 .54704 L 1 g
F
P
p
.43937 .5483 m .43852 .54704 L .45041 .5163 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4503 .56441 L p
1 g
F P
s
P
p
.002 w
.4503 .56441 m .45093 .56272 L p
.44529 .55703 L 1 g
F P
s
P
p
.44529 .55703 m .43743 .5491 L .4503 .56441 L 1 g
F
P
p
.002 w
.43852 .54704 m .43743 .5491 L p
.44348 .55435 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45041 .5163 m .46505 .54461 L .44301 .55367 L p
1 g
F P
s
P
p
.43937 .5483 m .45041 .5163 L .44301 .55367 L 1 g
F
P
p
.002 w
.44301 .55367 m .46505 .54461 L p
.46655 .58057 L 1 g
F P
s
P
p
.44404 .55484 m .43743 .5491 L .45093 .56272 L 1 g
F
P
p
.002 w
.45093 .56272 m .45002 .56518 L p
.46143 .56974 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46835 .57436 L p
1 g
F P
s
P
p
.46143 .56974 m .45002 .56518 L .46835 .57436 L 1 g
F
P
p
.002 w
.46835 .57436 m .4678 .57686 L p
.47707 .57762 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46505 .54461 m .48841 .56562 L .47452 .57667 L p
1 g
F P
s
P
p
.002 w
.47452 .57667 m .48841 .56562 L p
.49636 .58172 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58004 L p
1 g
F P
s
P
p
.47952 .57782 m .4678 .57686 L .4891 .58004 L 1 g
F
P
p
.002 w
.4891 .58004 m .48889 .583 L p
.50204 .58037 L 1 g
F P
s
P
p
.51094 .5806 m .48841 .56562 L .5162 .57965 L 1 g
F
P
p
.49562 .58021 m .48841 .56562 L .51094 .5806 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .5806 L p
1 g
F P
s
P
p
.50204 .58037 m .48889 .583 L .51094 .5806 L 1 g
F
P
p
.002 w
.48841 .56562 m .5178 .57728 L .5162 .57965 L p
1 g
F P
s
P
p
.002 w
.51094 .5806 m .51098 .58119 L p
.51347 .58014 L 1 g
F P
s
P
p
.002 w
.51098 .58119 m .51111 .583 L p
.51955 .57867 L 1 g
F P
s
P
p
.002 w
.5178 .57728 m .52351 .5775 L p
.51955 .57867 L 1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.48512 .27031 m .42612 .29545 L .41369 .28011 L p
1 g
F P
s
P
p
.002 w
.36313 .3249 m .41369 .28011 L .42612 .29545 L p
1 g
F P
s
P
p
.002 w
.43661 .5563 m .46665 .58293 L .44652 .59522 L p
1 g
F P
s
P
p
.002 w
.44652 .59522 m .41079 .56394 L .43661 .5563 L p
1 g
F P
s
P
p
.002 w
.42612 .29545 m .37749 .33854 L .36313 .3249 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.60715 .30249 m .55354 .28767 L .54717 .26589 L p
1 g
F P
s
P
p
.002 w
.48512 .27031 m .54717 .26589 L .55354 .28767 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53194 .4641 L
s
P
p
.002 w
.64387 .49495 m .64652 .46266 L .66765 .452 L p
1 g
F P
s
P
p
.002 w
.65782 .4128 m .66765 .452 L .64652 .46266 L p
1 g
F P
s
P
p
.002 w
.36604 .40719 m .35455 .46424 L .33306 .45581 L p
1 g
F P
s
P
p
.002 w
.33306 .45581 m .34523 .39431 L .36604 .40719 L p
1 g
F P
s
P
p
.004 w
.32232 .45163 m
.34213 .44928 L
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.64536 .35538 m .60628 .32743 L .60715 .30249 L p
1 g
F P
s
P
p
.002 w
.55354 .28767 m .60715 .30249 L .60628 .32743 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.38115 .47191 m .38798 .52136 L .36252 .51975 L p
1 g
F P
s
P
p
.002 w
.36252 .51975 m .35455 .46424 L .38115 .47191 L p
1 g
F P
s
P
p
.002 w
.65782 .4128 m .6353 .37961 L .64536 .35538 L p
1 g
F P
s
P
p
.002 w
.60628 .32743 m .64536 .35538 L .6353 .37961 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.57549 .54671 m .5949 .53402 L .60967 .5512 L p
1 g
F P
s
P
p
.002 w
.60967 .5512 m .5817 .56952 L .57549 .54671 L p
1 g
F P
s
P
p
.002 w
.63112 .52549 m .60967 .5512 L .5949 .53402 L p
1 g
F P
s
P
p
.002 w
.5949 .53402 m .60977 .51618 L .63112 .52549 L p
1 g
F P
s
P
p
.002 w
.64387 .49495 m .63112 .52549 L .60977 .51618 L p
1 g
F P
s
P
p
.002 w
.55354 .28767 m .49596 .29198 L .48512 .27031 L p
1 g
F P
s
P
p
.002 w
.42612 .29545 m .48512 .27031 L .49596 .29198 L p
1 g
F P
s
P
p
.002 w
.4176 .52023 m .43661 .5563 L .41079 .56394 L p
1 g
F P
s
P
p
.002 w
.41079 .56394 m .38798 .52136 L .4176 .52023 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.39608 .35546 m .36604 .40719 L .34523 .39431 L p
1 g
F P
s
P
p
.002 w
.34523 .39431 m .37749 .33854 L .39608 .35546 L p
1 g
F P
s
P
p
.002 w
.64652 .46266 m .63864 .43193 L .65782 .4128 L p
1 g
F P
s
P
p
.002 w
.6353 .37961 m .65782 .4128 L .63864 .43193 L p
1 g
F P
s
P
p
.002 w
.60977 .51618 m .61855 .495 L .64387 .49495 L p
1 g
F P
s
P
p
.002 w
.64652 .46266 m .64387 .49495 L .61855 .495 L p
1 g
F P
s
P
p
.002 w
.49596 .29198 m .44123 .31543 L .42612 .29545 L p
1 g
F P
s
P
p
.002 w
.37749 .33854 m .42612 .29545 L .44123 .31543 L p
1 g
F P
s
P
p
.002 w
.44123 .31543 m .39608 .35546 L .37749 .33854 L p
1 g
F P
s
P
p
.002 w
.60628 .32743 m .55849 .31448 L .55354 .28767 L p
1 g
F P
s
P
p
.002 w
.49596 .29198 m .55354 .28767 L .55849 .31448 L p
1 g
F P
s
P
p
.002 w
.61855 .495 m .62028 .47266 L .64652 .46266 L p
1 g
F P
s
P
p
.002 w
.63864 .43193 m .64652 .46266 L .62028 .47266 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39158 .42117 m .38115 .47191 L .35455 .46424 L p
1 g
F P
s
P
p
.004 w
.3869 .44396 m
.5 .43051 L
s
P
p
.002 w
.35455 .46424 m .36604 .40719 L .39158 .42117 L p
1 g
F P
s
P
p
.004 w
.34213 .44928 m
.35899 .44728 L
s
P
p
.004 w
.36441 .44663 m
.3655 .4465 L
s
P
p
.004 w
.35899 .44728 m
.36441 .44663 L
s
P
p
.002 w
.6353 .37961 m .60214 .35623 L .60628 .32743 L p
1 g
F P
s
P
p
.002 w
.55849 .31448 m .60628 .32743 L .60214 .35623 L p
1 g
F P
s
P
p
.002 w
.51107 .54374 m .53127 .55191 L .5178 .57728 L p
1 g
F P
s
P
p
.002 w
.5178 .57728 m .48841 .56562 L .51107 .54374 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.63864 .43193 m .62082 .40606 L .6353 .37961 L p
1 g
F P
s
P
p
.002 w
.60214 .35623 m .6353 .37961 L .62082 .40606 L p
1 g
F P
s
P
p
.002 w
.41209 .47848 m .4176 .52023 L .38798 .52136 L p
1 g
F P
s
P
p
.002 w
.38798 .52136 m .38115 .47191 L .41209 .47848 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60977 .51618 m .5949 .53402 L .57675 .51312 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57675 .51312 m .58438 .50394 L .60977 .51618 L p
1 g
F P
s
P
p
.002 w
.61855 .495 m .60977 .51618 L .58438 .50394 L p
1 g
F P
s
P
p
.002 w
.62028 .47266 m .6147 .45151 L .63864 .43193 L p
1 g
F P
s
P
p
.002 w
.62082 .40606 m .63864 .43193 L .6147 .45151 L p
1 g
F P
s
P
p
.002 w
.55849 .31448 m .50725 .31855 L .49596 .29198 L p
1 g
F P
s
P
p
.002 w
.44123 .31543 m .49596 .29198 L .50725 .31855 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41842 .37518 m .39158 .42117 L .36604 .40719 L p
1 g
F P
s
P
p
.002 w
.36604 .40719 m .39608 .35546 L .41842 .37518 L p
1 g
F P
s
P
p
.002 w
.49513 .52915 m .51107 .54374 L .48841 .56562 L p
1 g
F P
s
P
p
.002 w
.48841 .56562 m .46505 .54461 L .49513 .52915 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.58438 .50394 m .58885 .49306 L .61855 .495 L p
1 g
F P
s
P
p
.002 w
.62028 .47266 m .61855 .495 L .58885 .49306 L p
1 g
F P
s
P
p
.002 w
.54409 .52219 m .55548 .52277 L .55352 .5529 L p
1 g
F P
s
P
p
.002 w
.55352 .5529 m .53127 .55191 L .54409 .52219 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60214 .35623 m .56175 .34557 L .55849 .31448 L p
1 g
F P
s
P
p
.002 w
.50725 .31855 m .55849 .31448 L .56175 .34557 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.50725 .31855 m .45859 .33955 L .44123 .31543 L p
1 g
F P
s
P
p
.002 w
.39608 .35546 m .44123 .31543 L .45859 .33955 L p
1 g
F P
s
P
p
.002 w
.45859 .33955 m .41842 .37518 L .39608 .35546 L p
1 g
F P
s
P
p
.002 w
.58885 .49306 m .58968 .48161 L .62028 .47266 L p
1 g
F P
s
P
p
.002 w
.6147 .45151 m .62028 .47266 L .58968 .48161 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.62082 .40606 m .59476 .38798 L .60214 .35623 L p
1 g
F P
s
P
p
.002 w
.56175 .34557 m .60214 .35623 L .59476 .38798 L p
1 g
F P
s
P
p
.002 w
.42109 .43576 m .41209 .47848 L .38115 .47191 L p
1 g
F P
s
P
p
.002 w
.38115 .47191 m .39158 .42117 L .42109 .43576 L p
1 g
F P
s
P
p
.002 w
.53381 .51794 m .54409 .52219 L .53127 .55191 L p
1 g
F P
s
P
p
.002 w
.53127 .55191 m .51107 .54374 L .53381 .51794 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.6147 .45151 m .6023 .43382 L .62082 .40606 L p
1 g
F P
s
P
p
.002 w
.59476 .38798 m .62082 .40606 L .6023 .43382 L p
1 g
F P
s
P
p
.002 w
.4176 .52023 m .41209 .47848 L .44634 .48369 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.48526 .50964 m .49513 .52915 L .46505 .54461 L p
1 g
F P
s
P
p
.002 w
.46505 .54461 m .45041 .5163 L .48526 .50964 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58968 .48161 m .58675 .47083 L .6147 .45151 L p
1 g
F P
s
P
p
.002 w
.6023 .43382 m .6147 .45151 L .58675 .47083 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52576 .51044 m .53381 .51794 L .51107 .54374 L p
1 g
F P
s
P
p
.002 w
.51107 .54374 m .49513 .52915 L .52576 .51044 L p
1 g
F P
s
P
p
.002 w
.58438 .50394 m .57675 .51312 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.56175 .34557 m .51858 .34922 L .50725 .31855 L p
1 g
F P
s
P
p
.002 w
.45859 .33955 m .50725 .31855 L .51858 .34922 L p
1 g
F P
s
P
p
.002 w
.58885 .49306 m .58438 .50394 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.44379 .39706 m .42109 .43576 L .39158 .42117 L p
1 g
F P
s
P
p
.002 w
.39158 .42117 m .41842 .37518 L .44379 .39706 L p
1 g
F P
s
P
p
.002 w
.58968 .48161 m .58885 .49306 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59476 .38798 m .56316 .37989 L .56175 .34557 L p
1 g
F P
s
P
p
.002 w
.51858 .34922 m .56175 .34557 L .56316 .37989 L p
1 g
F P
s
P
p
.002 w
.6023 .43382 m .58431 .42157 L .59476 .38798 L p
1 g
F P
s
P
p
.002 w
.56316 .37989 m .59476 .38798 L .58431 .42157 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.58675 .47083 m .58968 .48161 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.58675 .47083 m .58035 .46187 L .6023 .43382 L p
1 g
F P
s
P
p
.002 w
.58431 .42157 m .6023 .43382 L .58035 .46187 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.45352 .45041 m .44634 .48369 L .41209 .47848 L p
1 g
F P
s
P
p
.002 w
.41209 .47848 m .42109 .43576 L .45352 .45041 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51858 .34922 m .47763 .36703 L .45859 .33955 L p
1 g
F P
s
P
p
.002 w
.41842 .37518 m .45859 .33955 L .47763 .36703 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48264 .48729 m .48526 .50964 L .45041 .5163 L p
1 g
F P
s
P
p
.002 w
.52083 .50047 m .52576 .51044 L .49513 .52915 L p
1 g
F P
s
P
p
.002 w
.49513 .52915 m .48526 .50964 L .52083 .50047 L p
1 g
F P
s
P
p
.002 w
.47763 .36703 m .44379 .39706 L .41842 .37518 L p
1 g
F P
s
P
p
.002 w
.58035 .46187 m .58675 .47083 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57114 .45572 m .58035 .46187 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.58035 .46187 m .57114 .45572 L .58431 .42157 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56261 .41619 m .58431 .42157 L .57114 .45572 L p
1 g
F P
s
P
p
.002 w
.58431 .42157 m .56261 .41619 L .56316 .37989 L p
1 g
F P
s
P
p
.002 w
.56316 .37989 m .5295 .38292 L .51858 .34922 L p
1 g
F P
s
P
p
.002 w
.47763 .36703 m .51858 .34922 L .5295 .38292 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.5295 .38292 m .56316 .37989 L .56261 .41619 L p
1 g
F P
s
P
p
.002 w
.56011 .45308 m .57114 .45572 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.54846 .45427 m .56011 .45308 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.53748 .45917 m .54846 .45427 L .55575 .48913 L closepath p
1 g
F P
s
P
p
.002 w
.51959 .48912 m .52083 .50047 L .48526 .50964 L p
1 g
F P
s
P
p
.002 w
.48526 .50964 m .48264 .48729 L .51959 .48912 L p
1 g
F P
s
P
p
.002 w
.47129 .4203 m .45352 .45041 L .42109 .43576 L p
1 g
F P
s
P
p
.002 w
.42109 .43576 m .44379 .39706 L .47129 .4203 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.004 w
.55575 .48913 m
.55754 .49101 L
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.57114 .45572 m .56011 .45308 L .56261 .41619 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.5295 .38292 m .49764 .3969 L .47763 .36703 L p
1 g
F P
s
P
p
.002 w
.44379 .39706 m .47763 .36703 L .49764 .3969 L p
1 g
F P
s
P
p
.002 w
.49764 .3969 m .47129 .4203 L .44379 .39706 L p
1 g
F P
s
P
p
.002 w
.5396 .4184 m .56261 .41619 L .56011 .45308 L p
1 g
F P
s
P
p
.002 w
.56261 .41619 m .5396 .4184 L .5295 .38292 L p
1 g
F P
s
P
p
.002 w
.56011 .45308 m .54846 .45427 L .5396 .4184 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.5222 .47763 m .51959 .48912 L .48264 .48729 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49764 .3969 m .5295 .38292 L .5396 .4184 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54846 .45427 m .53748 .45917 L .51786 .42803 L p
1 g
F P
s
P
p
.002 w
.51786 .42803 m .5396 .4184 L .54846 .45427 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49986 .44401 m .48767 .46455 L .45352 .45041 L p
1 g
F P
s
P
p
.002 w
.45352 .45041 m .47129 .4203 L .49986 .44401 L p
1 g
F P
s
P
p
.002 w
.53748 .45917 m .52839 .46726 L .49986 .44401 L p
1 g
F P
s
P
p
.002 w
.49986 .44401 m .51786 .42803 L .53748 .45917 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.5396 .4184 m .51786 .42803 L .49764 .3969 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47129 .4203 m .49764 .3969 L .51786 .42803 L p
1 g
F P
s
P
p
.002 w
.51786 .42803 m .49986 .44401 L .47129 .4203 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.55754 .49101 m
.5899 .52504 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28345 .45626 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .5899 .52504 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.124806)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.124806)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47606 .46808 m .50746 .45293 L .4915 .42925 L p
1 g
F P
s
P
p
.002 w
.4915 .42925 m .46718 .44092 L .47606 .46808 L p
1 g
F P
s
P
p
.002 w
.51161 .4111 m .4915 .42925 L .50746 .45293 L p
1 g
F P
s
P
p
.002 w
.46718 .44092 m .4915 .42925 L .47573 .40557 L p
1 g
F P
s
P
p
.002 w
.4915 .42925 m .51161 .4111 L .48947 .39315 L p
1 g
F P
s
P
p
.002 w
.48947 .39315 m .47573 .40557 L .4915 .42925 L p
1 g
F P
s
P
p
.002 w
.50746 .45293 m .53345 .42951 L .51161 .4111 L p
1 g
F P
s
P
p
.002 w
.52549 .38828 m .51161 .4111 L .53345 .42951 L p
1 g
F P
s
P
p
.002 w
.51161 .4111 m .52549 .38828 L .49889 .37752 L p
1 g
F P
s
P
p
.002 w
.49889 .37752 m .48947 .39315 L .51161 .4111 L p
1 g
F P
s
P
p
.002 w
.48558 .4945 m .52331 .47619 L .50746 .45293 L p
1 g
F P
s
P
p
.002 w
.50746 .45293 m .47606 .46808 L .48558 .4945 L p
1 g
F P
s
P
p
.002 w
.53345 .42951 m .50746 .45293 L .52331 .47619 L p
1 g
F P
s
P
p
.002 w
.52331 .47619 m .55461 .44804 L .53345 .42951 L p
1 g
F P
s
P
p
.002 w
.55151 .40007 m .53345 .42951 L .55461 .44804 L p
1 g
F P
s
P
p
.002 w
.53345 .42951 m .55151 .40007 L .52549 .38828 L p
1 g
F P
s
P
p
.002 w
.4423 .47341 m .47606 .46808 L .46718 .44092 L p
1 g
F P
s
P
p
.002 w
.46718 .44092 m .44105 .4449 L .4423 .47341 L p
1 g
F P
s
P
p
.002 w
.44105 .4449 m .46718 .44092 L .45909 .41351 L p
1 g
F P
s
P
p
.002 w
.47573 .40557 m .45909 .41351 L .46718 .44092 L p
1 g
F P
s
P
p
.002 w
.45909 .41351 m .47573 .40557 L .46044 .38232 L p
1 g
F P
s
P
p
.002 w
.47573 .40557 m .48947 .39315 L .46743 .37599 L p
1 g
F P
s
P
p
.002 w
.46743 .37599 m .46044 .38232 L .47573 .40557 L p
1 g
F P
s
P
p
.002 w
.48947 .39315 m .49889 .37752 L .47219 .36801 L p
1 g
F P
s
P
p
.002 w
.47219 .36801 m .46743 .37599 L .48947 .39315 L p
1 g
F P
s
P
p
.002 w
.45909 .41351 m .44124 .41613 L .44105 .4449 L p
1 g
F P
s
P
p
.002 w
.44124 .41613 m .45909 .41351 L .45195 .38635 L p
1 g
F P
s
P
p
.002 w
.46044 .38232 m .45195 .38635 L .45909 .41351 L p
1 g
F P
s
P
p
.002 w
.44497 .50112 m .48558 .4945 L .47606 .46808 L p
1 g
F P
s
P
p
.002 w
.47606 .46808 m .4423 .47341 L .44497 .50112 L p
1 g
F P
s
P
p
.002 w
.53166 .36302 m .52549 .38828 L .55151 .40007 L p
1 g
F P
s
P
p
.002 w
.52549 .38828 m .53166 .36302 L .50297 .36027 L p
1 g
F P
s
P
p
.002 w
.50297 .36027 m .49889 .37752 L .52549 .38828 L p
1 g
F P
s
P
p
.002 w
.49557 .51967 m .53877 .49859 L .52331 .47619 L p
1 g
F P
s
P
p
.002 w
.52331 .47619 m .48558 .4945 L .49557 .51967 L p
1 g
F P
s
P
p
.002 w
.55461 .44804 m .52331 .47619 L .53877 .49859 L p
1 g
F P
s
P
p
.002 w
.49889 .37752 m .50297 .36027 L .47421 .35923 L p
1 g
F P
s
P
p
.002 w
.47421 .35923 m .47219 .36801 L .49889 .37752 L p
1 g
F P
s
P
p
.002 w
.53877 .49859 m .57467 .46636 L .55461 .44804 L p
1 g
F P
s
P
p
.002 w
.57647 .4127 m .55461 .44804 L .57467 .46636 L p
1 g
F P
s
P
p
.002 w
.55461 .44804 m .57647 .4127 L .55151 .40007 L p
1 g
F P
s
P
p
.002 w
.55972 .36744 m .55151 .40007 L .57647 .4127 L p
1 g
F P
s
P
p
.002 w
.55151 .40007 m .55972 .36744 L .53166 .36302 L p
1 g
F P
s
P
p
.002 w
.41575 .44068 m .44105 .4449 L .44124 .41613 L p
1 g
F P
s
P
p
.002 w
.44124 .41613 m .42402 .41311 L .41575 .44068 L p
1 g
F P
s
P
p
.002 w
.42402 .41311 m .44124 .41613 L .44286 .38763 L p
1 g
F P
s
P
p
.002 w
.45195 .38635 m .44286 .38763 L .44124 .41613 L p
1 g
F P
s
P
p
.002 w
.40949 .4682 m .4423 .47341 L .44105 .4449 L p
1 g
F P
s
P
p
.002 w
.44105 .4449 m .41575 .44068 L .40949 .4682 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .45195 .38635 L .46044 .38232 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .46044 .38232 L .46743 .37599 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .46743 .37599 L .47219 .36801 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .44286 .38763 L .45195 .38635 L closepath p
1 g
F P
s
P
p
.002 w
.44904 .52751 m .49557 .51967 L .48558 .4945 L p
1 g
F P
s
P
p
.002 w
.48558 .4945 m .44497 .50112 L .44904 .52751 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .47219 .36801 L .47421 .35923 L closepath p
1 g
F P
s
P
p
.002 w
.50124 .34317 m .50297 .36027 L .53166 .36302 L p
1 g
F P
s
P
p
.002 w
.50297 .36027 m .50124 .34317 L .47325 .35057 L p
1 g
F P
s
P
p
.002 w
.47325 .35057 m .47421 .35923 L .50297 .36027 L p
1 g
F P
s
P
p
.002 w
.44286 .38763 m .43413 .38603 L .42402 .41311 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .43413 .38603 L .44286 .38763 L closepath p
1 g
F P
s
P
p
.002 w
.40539 .49515 m .44497 .50112 L .4423 .47341 L p
1 g
F P
s
P
p
.002 w
.4423 .47341 m .40949 .4682 L .40539 .49515 L p
1 g
F P
s
P
p
.002 w
.52935 .33789 m .53166 .36302 L .55972 .36744 L p
1 g
F P
s
P
p
.002 w
.53166 .36302 m .52935 .33789 L .50124 .34317 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .47421 .35923 L .47325 .35057 L closepath p
1 g
F P
s
P
p
.002 w
.39393 .42851 m .41575 .44068 L .42402 .41311 L p
1 g
F P
s
P
p
.002 w
.42402 .41311 m .40926 .40469 L .39393 .42851 L p
1 g
F P
s
P
p
.002 w
.40926 .40469 m .42402 .41311 L .43413 .38603 L p
1 g
F P
s
P
p
.002 w
.50586 .5431 m .55355 .51971 L .53877 .49859 L p
1 g
F P
s
P
p
.002 w
.53877 .49859 m .49557 .51967 L .50586 .5431 L p
1 g
F P
s
P
p
.002 w
.57467 .46636 m .53877 .49859 L .55355 .51971 L p
1 g
F P
s
P
p
.002 w
.57467 .46636 m .5999 .42594 L .57647 .4127 L p
1 g
F P
s
P
p
.002 w
.58663 .37346 m .57647 .4127 L .5999 .42594 L p
1 g
F P
s
P
p
.002 w
.57647 .4127 m .58663 .37346 L .55972 .36744 L p
1 g
F P
s
P
p
.002 w
.43413 .38603 m .4267 .38169 L .40926 .40469 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .4267 .38169 L .43413 .38603 L closepath p
1 g
F P
s
P
p
.002 w
.55355 .51971 m .59325 .48412 L .57467 .46636 L p
1 g
F P
s
P
p
.002 w
.5999 .42594 m .57467 .46636 L .59325 .48412 L p
1 g
F P
s
P
p
.002 w
.46939 .34296 m .47325 .35057 L .50124 .34317 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .47325 .35057 L .46939 .34296 L closepath p
1 g
F P
s
P
p
.002 w
.38103 .45269 m .40949 .4682 L .41575 .44068 L p
1 g
F P
s
P
p
.002 w
.41575 .44068 m .39393 .42851 L .38103 .45269 L p
1 g
F P
s
P
p
.002 w
.55702 .33484 m .55972 .36744 L .58663 .37346 L p
1 g
F P
s
P
p
.002 w
.55972 .36744 m .55702 .33484 L .52935 .33789 L p
1 g
F P
s
P
p
.002 w
.49378 .32806 m .50124 .34317 L .52935 .33789 L p
1 g
F P
s
P
p
.002 w
.50124 .34317 m .49378 .32806 L .46939 .34296 L p
1 g
F P
s
P
p
.002 w
.39859 .39167 m .40926 .40469 L .4267 .38169 L p
1 g
F P
s
P
p
.002 w
.4267 .38169 m .42137 .37505 L .39859 .39167 L p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .42137 .37505 L .4267 .38169 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .41916 .35788 L .41876 .36682 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .41876 .36682 L .42137 .37505 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .46939 .34296 L .46303 .33725 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .46303 .33725 L .45483 .33407 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .45483 .33407 L .44568 .33379 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .44568 .33379 L .4366 .33647 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .4366 .33647 L .4286 .34181 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .4286 .34181 L .42256 .34922 L closepath p
1 g
F P
s
P
p
.002 w
.44589 .35993 m .42256 .34922 L .41916 .35788 L closepath p
1 g
F P
s
P
p
.002 w
.45447 .552 m .50586 .5431 L .49557 .51967 L p
1 g
F P
s
P
p
.002 w
.49557 .51967 m .44904 .52751 L .45447 .552 L p
1 g
F P
s
P
p
.002 w
.40358 .52099 m .44904 .52751 L .44497 .50112 L p
1 g
F P
s
P
p
.002 w
.44497 .50112 m .40539 .49515 L .40358 .52099 L p
1 g
F P
s
P
p
.002 w
.46303 .33725 m .46939 .34296 L .49378 .32806 L p
1 g
F P
s
P
p
.002 w
.37801 .4095 m .39393 .42851 L .40926 .40469 L p
1 g
F P
s
P
p
.002 w
.40926 .40469 m .39859 .39167 L .37801 .4095 L p
1 g
F P
s
P
p
.002 w
.39324 .37539 m .39859 .39167 L .42137 .37505 L p
1 g
F P
s
P
p
.002 w
.42137 .37505 m .41876 .36682 L .39324 .37539 L p
1 g
F P
s
P
p
.002 w
.51859 .31554 m .52935 .33789 L .55702 .33484 L p
1 g
F P
s
P
p
.002 w
.52935 .33789 m .51859 .31554 L .49378 .32806 L p
1 g
F P
s
P
p
.002 w
.37089 .47676 m .40539 .49515 L .40949 .4682 L p
1 g
F P
s
P
p
.002 w
.40949 .4682 m .38103 .45269 L .37089 .47676 L p
1 g
F P
s
P
p
.002 w
.59325 .48412 m .62129 .43955 L .5999 .42594 L p
1 g
F P
s
P
p
.002 w
.61183 .381 m .5999 .42594 L .62129 .43955 L p
1 g
F P
s
P
p
.002 w
.5999 .42594 m .61183 .381 L .58663 .37346 L p
1 g
F P
s
P
p
.002 w
.49378 .32806 m .48128 .31661 L .46303 .33725 L p
1 g
F P
s
P
p
.002 w
.45483 .33407 m .46303 .33725 L .48128 .31661 L p
1 g
F P
s
P
p
.002 w
.48128 .31661 m .49378 .32806 L .51859 .31554 L p
1 g
F P
s
P
p
.002 w
.39391 .35761 m .39324 .37539 L .41876 .36682 L p
1 g
F P
s
P
p
.002 w
.41876 .36682 m .41916 .35788 L .39391 .35761 L p
1 g
F P
s
P
p
.002 w
.58372 .33413 m .58663 .37346 L .61183 .381 L p
1 g
F P
s
P
p
.002 w
.58663 .37346 m .58372 .33413 L .55702 .33484 L p
1 g
F P
s
P
p
.002 w
.51624 .56427 m .56734 .53909 L .55355 .51971 L p
1 g
F P
s
P
p
.002 w
.55355 .51971 m .50586 .5431 L .51624 .56427 L p
1 g
F P
s
P
p
.002 w
.59325 .48412 m .55355 .51971 L .56734 .53909 L p
1 g
F P
s
P
p
.002 w
.3601 .42819 m .38103 .45269 L .39393 .42851 L p
1 g
F P
s
P
p
.002 w
.39393 .42851 m .37801 .4095 L .3601 .42819 L p
1 g
F P
s
P
p
.002 w
.48128 .31661 m .46504 .31016 L .45483 .33407 L p
1 g
F P
s
P
p
.002 w
.44568 .33379 m .45483 .33407 L .46504 .31016 L p
1 g
F P
s
P
p
.002 w
.56734 .53909 m .60994 .50096 L .59325 .48412 L p
1 g
F P
s
P
p
.002 w
.62129 .43955 m .59325 .48412 L .60994 .50096 L p
1 g
F P
s
P
p
.002 w
.36989 .38553 m .37801 .4095 L .39859 .39167 L p
1 g
F P
s
P
p
.002 w
.39859 .39167 m .39324 .37539 L .36989 .38553 L p
1 g
F P
s
P
p
.002 w
.40062 .34031 m .39391 .35761 L .41916 .35788 L p
1 g
F P
s
P
p
.002 w
.41916 .35788 m .42256 .34922 L .40062 .34031 L p
1 g
F P
s
P
p
.002 w
.40418 .54514 m .45447 .552 L .44904 .52751 L p
1 g
F P
s
P
p
.002 w
.44904 .52751 m .40358 .52099 L .40418 .54514 L p
1 g
F P
s
P
p
.002 w
.46504 .31016 m .44682 .3095 L .44568 .33379 L p
1 g
F P
s
P
p
.002 w
.4366 .33647 m .44568 .33379 L .44682 .3095 L p
1 g
F P
s
P
p
.002 w
.54335 .30568 m .55702 .33484 L .58372 .33413 L p
1 g
F P
s
P
p
.002 w
.55702 .33484 m .54335 .30568 L .51859 .31554 L p
1 g
F P
s
P
p
.002 w
.41265 .32546 m .40062 .34031 L .42256 .34922 L p
1 g
F P
s
P
p
.002 w
.42256 .34922 m .4286 .34181 L .41265 .32546 L p
1 g
F P
s
P
p
.002 w
.4612 .57405 m .51624 .56427 L .50586 .5431 L p
1 g
F P
s
P
p
.002 w
.50586 .5431 m .45447 .552 L .4612 .57405 L p
1 g
F P
s
P
p
.002 w
.44682 .3095 m .42867 .31478 L .4366 .33647 L p
1 g
F P
s
P
p
.002 w
.4286 .34181 m .4366 .33647 L .42867 .31478 L p
1 g
F P
s
P
p
.002 w
.42867 .31478 m .41265 .32546 L .4286 .34181 L p
1 g
F P
s
P
p
.002 w
.3638 .50021 m .40358 .52099 L .40539 .49515 L p
1 g
F P
s
P
p
.002 w
.40539 .49515 m .37089 .47676 L .3638 .50021 L p
1 g
F P
s
P
p
.002 w
.51859 .31554 m .50033 .29847 L .48128 .31661 L p
1 g
F P
s
P
p
.002 w
.46504 .31016 m .48128 .31661 L .50033 .29847 L p
1 g
F P
s
P
p
.002 w
.50033 .29847 m .51859 .31554 L .54335 .30568 L p
1 g
F P
s
P
p
.002 w
.37071 .35918 m .36989 .38553 L .39324 .37539 L p
1 g
F P
s
P
p
.002 w
.39324 .37539 m .39391 .35761 L .37071 .35918 L p
1 g
F P
s
P
p
.002 w
.34534 .44739 m .37089 .47676 L .38103 .45269 L p
1 g
F P
s
P
p
.002 w
.38103 .45269 m .3601 .42819 L .34534 .44739 L p
1 g
F P
s
P
p
.002 w
.60994 .50096 m .64016 .45327 L .62129 .43955 L p
1 g
F P
s
P
p
.002 w
.63478 .38996 m .62129 .43955 L .64016 .45327 L p
1 g
F P
s
P
p
.002 w
.62129 .43955 m .63478 .38996 L .61183 .381 L p
1 g
F P
s
P
p
.002 w
.60886 .33584 m .61183 .381 L .63478 .38996 L p
1 g
F P
s
P
p
.002 w
.61183 .381 m .60886 .33584 L .58372 .33413 L p
1 g
F P
s
P
p
.002 w
.34928 .39706 m .3601 .42819 L .37801 .4095 L p
1 g
F P
s
P
p
.002 w
.37801 .4095 m .36989 .38553 L .34928 .39706 L p
1 g
F P
s
P
p
.002 w
.50033 .29847 m .47638 .28873 L .46504 .31016 L p
1 g
F P
s
P
p
.002 w
.44682 .3095 m .46504 .31016 L .47638 .28873 L p
1 g
F P
s
P
p
.002 w
.56754 .29878 m .58372 .33413 L .60886 .33584 L p
1 g
F P
s
P
p
.002 w
.58372 .33413 m .56754 .29878 L .54335 .30568 L p
1 g
F P
s
P
p
.002 w
.52652 .58265 m .57981 .55627 L .56734 .53909 L p
1 g
F P
s
P
p
.002 w
.56734 .53909 m .51624 .56427 L .52652 .58265 L p
1 g
F P
s
P
p
.002 w
.60994 .50096 m .56734 .53909 L .57981 .55627 L p
1 g
F P
s
P
p
.002 w
.38057 .33343 m .37071 .35918 L .39391 .35761 L p
1 g
F P
s
P
p
.002 w
.39391 .35761 m .40062 .34031 L .38057 .33343 L p
1 g
F P
s
P
p
.002 w
.40726 .56702 m .4612 .57405 L .45447 .552 L p
1 g
F P
s
P
p
.002 w
.45447 .552 m .40418 .54514 L .40726 .56702 L p
1 g
F P
s
P
p
.002 w
.57981 .55627 m .62431 .5165 L .60994 .50096 L p
1 g
F P
s
P
p
.002 w
.64016 .45327 m .60994 .50096 L .62431 .5165 L p
1 g
F P
s
P
p
.002 w
.54335 .30568 m .51979 .28326 L .50033 .29847 L p
1 g
F P
s
P
p
.002 w
.47638 .28873 m .50033 .29847 L .51979 .28326 L p
1 g
F P
s
P
p
.002 w
.51979 .28326 m .54335 .30568 L .56754 .29878 L p
1 g
F P
s
P
p
.002 w
.47638 .28873 m .44935 .28761 L .44682 .3095 L p
1 g
F P
s
P
p
.002 w
.42867 .31478 m .44682 .3095 L .44935 .28761 L p
1 g
F P
s
P
p
.002 w
.36003 .52251 m .40418 .54514 L .40358 .52099 L p
1 g
F P
s
P
p
.002 w
.40358 .52099 m .3638 .50021 L .36003 .52251 L p
1 g
F P
s
P
p
.002 w
.39845 .31129 m .38057 .33343 L .40062 .34031 L p
1 g
F P
s
P
p
.002 w
.40062 .34031 m .41265 .32546 L .39845 .31129 L p
1 g
F P
s
P
p
.002 w
.46912 .59307 m .52652 .58265 L .51624 .56427 L p
1 g
F P
s
P
p
.002 w
.51624 .56427 m .4612 .57405 L .46912 .59307 L p
1 g
F P
s
P
p
.002 w
.44935 .28761 m .42232 .2954 L .42867 .31478 L p
1 g
F P
s
P
p
.002 w
.41265 .32546 m .42867 .31478 L .42232 .2954 L p
1 g
F P
s
P
p
.002 w
.42232 .2954 m .39845 .31129 L .41265 .32546 L p
1 g
F P
s
P
p
.002 w
.33417 .4667 m .3638 .50021 L .37089 .47676 L p
1 g
F P
s
P
p
.002 w
.37089 .47676 m .34534 .44739 L .33417 .4667 L p
1 g
F P
s
P
p
.002 w
.35014 .36263 m .34928 .39706 L .36989 .38553 L p
1 g
F P
s
P
p
.002 w
.36989 .38553 m .37071 .35918 L .35014 .36263 L p
1 g
F P
s
P
p
.002 w
.33196 .4098 m .34534 .44739 L .3601 .42819 L p
1 g
F P
s
P
p
.002 w
.3601 .42819 m .34928 .39706 L .33196 .4098 L p
1 g
F P
s
P
p
.002 w
.64016 .45327 m .6549 .4002 L .63478 .38996 L p
1 g
F P
s
P
p
.002 w
.63186 .34002 m .63478 .38996 L .6549 .4002 L p
1 g
F P
s
P
p
.002 w
.63478 .38996 m .63186 .34002 L .60886 .33584 L p
1 g
F P
s
P
p
.002 w
.62431 .5165 m .65599 .46682 L .64016 .45327 L p
1 g
F P
s
P
p
.002 w
.6549 .4002 m .64016 .45327 L .65599 .46682 L p
1 g
F P
s
P
p
.002 w
.51979 .28326 m .48864 .27033 L .47638 .28873 L p
1 g
F P
s
P
p
.002 w
.44935 .28761 m .47638 .28873 L .48864 .27033 L p
1 g
F P
s
P
p
.002 w
.59062 .29508 m .60886 .33584 L .63186 .34002 L p
1 g
F P
s
P
p
.002 w
.60886 .33584 m .59062 .29508 L .56754 .29878 L p
1 g
F P
s
P
p
.002 w
.36294 .32883 m .35014 .36263 L .37071 .35918 L p
1 g
F P
s
P
p
.002 w
.37071 .35918 m .38057 .33343 L .36294 .32883 L p
1 g
F P
s
P
p
.002 w
.53927 .27143 m .56754 .29878 L .59062 .29508 L p
1 g
F P
s
P
p
.002 w
.56754 .29878 m .53927 .27143 L .51979 .28326 L p
1 g
F P
s
P
p
.002 w
.48864 .27033 m .51979 .28326 L .53927 .27143 L p
1 g
F P
s
P
p
.002 w
.41287 .58603 m .46912 .59307 L .4612 .57405 L p
1 g
F P
s
P
p
.002 w
.4612 .57405 m .40726 .56702 L .41287 .58603 L p
1 g
F P
s
P
p
.002 w
.53645 .5977 m .59064 .57078 L .57981 .55627 L p
1 g
F P
s
P
p
.002 w
.57981 .55627 m .52652 .58265 L .53645 .5977 L p
1 g
F P
s
P
p
.002 w
.62431 .5165 m .57981 .55627 L .59064 .57078 L p
1 g
F P
s
P
p
.002 w
.35982 .54309 m .40726 .56702 L .40418 .54514 L p
1 g
F P
s
P
p
.002 w
.40418 .54514 m .36003 .52251 L .35982 .54309 L p
1 g
F P
s
P
p
.002 w
.59064 .57078 m .63595 .53033 L .62431 .5165 L p
1 g
F P
s
P
p
.002 w
.65599 .46682 m .62431 .5165 L .63595 .53033 L p
1 g
F P
s
P
p
.002 w
.48864 .27033 m .45327 .26871 L .44935 .28761 L p
1 g
F P
s
P
p
.002 w
.42232 .2954 m .44935 .28761 L .45327 .26871 L p
1 g
F P
s
P
p
.002 w
.327 .48567 m .36003 .52251 L .3638 .50021 L p
1 g
F P
s
P
p
.002 w
.3638 .50021 m .33417 .4667 L .327 .48567 L p
1 g
F P
s
P
p
.002 w
.38639 .29972 m .36294 .32883 L .38057 .33343 L p
1 g
F P
s
P
p
.002 w
.38057 .33343 m .39845 .31129 L .38639 .29972 L p
1 g
F P
s
P
p
.002 w
.3328 .36798 m .33196 .4098 L .34928 .39706 L p
1 g
F P
s
P
p
.002 w
.34928 .39706 m .35014 .36263 L .3328 .36798 L p
1 g
F P
s
P
p
.002 w
.47814 .60848 m .53645 .5977 L .52652 .58265 L p
1 g
F P
s
P
p
.002 w
.52652 .58265 m .46912 .59307 L .47814 .60848 L p
1 g
F P
s
P
p
.002 w
.31848 .42351 m .33417 .4667 L .34534 .44739 L p
1 g
F P
s
P
p
.002 w
.34534 .44739 m .33196 .4098 L .31848 .42351 L p
1 g
F P
s
P
p
.002 w
.45327 .26871 m .41776 .27885 L .42232 .2954 L p
1 g
F P
s
P
p
.002 w
.39845 .31129 m .42232 .2954 L .41776 .27885 L p
1 g
F P
s
P
p
.002 w
.41776 .27885 m .38639 .29972 L .39845 .31129 L p
1 g
F P
s
P
p
.002 w
.65599 .46682 m .67163 .41155 L .6549 .4002 L p
1 g
F P
s
P
p
.002 w
.65212 .34668 m .6549 .4002 L .67163 .41155 L p
1 g
F P
s
P
p
.002 w
.6549 .4002 m .65212 .34668 L .63186 .34002 L p
1 g
F P
s
P
p
.002 w
.61203 .29481 m .63186 .34002 L .65212 .34668 L p
1 g
F P
s
P
p
.002 w
.63186 .34002 m .61203 .29481 L .59062 .29508 L p
1 g
F P
s
P
p
.002 w
.63595 .53033 m .6683 .47988 L .65599 .46682 L p
1 g
F P
s
P
p
.002 w
.67163 .41155 m .65599 .46682 L .6683 .47988 L p
1 g
F P
s
P
p
.002 w
.53927 .27143 m .50159 .25552 L .48864 .27033 L p
1 g
F P
s
P
p
.002 w
.45327 .26871 m .48864 .27033 L .50159 .25552 L p
1 g
F P
s
P
p
.002 w
.55833 .26339 m .59062 .29508 L .61203 .29481 L p
1 g
F P
s
P
p
.002 w
.59062 .29508 m .55833 .26339 L .53927 .27143 L p
1 g
F P
s
P
p
.002 w
.50159 .25552 m .53927 .27143 L .55833 .26339 L p
1 g
F P
s
P
p
.002 w
.34827 .32676 m .3328 .36798 L .35014 .36263 L p
1 g
F P
s
P
p
.002 w
.35014 .36263 m .36294 .32883 L .34827 .32676 L p
1 g
F P
s
P
p
.002 w
.36334 .56138 m .41287 .58603 L .40726 .56702 L p
1 g
F P
s
P
p
.002 w
.40726 .56702 m .35982 .54309 L .36334 .56138 L p
1 g
F P
s
P
p
.002 w
.421 .60157 m .47814 .60848 L .46912 .59307 L p
1 g
F P
s
P
p
.002 w
.46912 .59307 m .41287 .58603 L .421 .60157 L p
1 g
F P
s
P
p
.002 w
.54579 .6089 m .59949 .58215 L .59064 .57078 L p
1 g
F P
s
P
p
.002 w
.59064 .57078 m .53645 .5977 L .54579 .6089 L p
1 g
F P
s
P
p
.002 w
.63595 .53033 m .59064 .57078 L .59949 .58215 L p
1 g
F P
s
P
p
.002 w
.32422 .50382 m .35982 .54309 L .36003 .52251 L p
1 g
F P
s
P
p
.002 w
.36003 .52251 m .327 .48567 L .32422 .50382 L p
1 g
F P
s
P
p
.002 w
.50159 .25552 m .45856 .25338 L .45327 .26871 L p
1 g
F P
s
P
p
.002 w
.41776 .27885 m .45327 .26871 L .45856 .25338 L p
1 g
F P
s
P
p
.002 w
.59949 .58215 m .64445 .54205 L .63595 .53033 L p
1 g
F P
s
P
p
.002 w
.6683 .47988 m .63595 .53033 L .64445 .54205 L p
1 g
F P
s
P
p
.002 w
.31927 .3752 m .31848 .42351 L .33196 .4098 L p
1 g
F P
s
P
p
.002 w
.33196 .4098 m .3328 .36798 L .31927 .3752 L p
1 g
F P
s
P
p
.002 w
.30939 .4379 m .327 .48567 L .33417 .4667 L p
1 g
F P
s
P
p
.002 w
.33417 .4667 m .31848 .42351 L .30939 .4379 L p
1 g
F P
s
P
p
.002 w
.37687 .29117 m .34827 .32676 L .36294 .32883 L p
1 g
F P
s
P
p
.002 w
.36294 .32883 m .38639 .29972 L .37687 .29117 L p
1 g
F P
s
P
p
.002 w
.48807 .61972 m .54579 .6089 L .53645 .5977 L p
1 g
F P
s
P
p
.002 w
.53645 .5977 m .47814 .60848 L .48807 .61972 L p
1 g
F P
s
P
p
.002 w
.45856 .25338 m .41521 .26568 L .41776 .27885 L p
1 g
F P
s
P
p
.002 w
.38639 .29972 m .41776 .27885 L .41521 .26568 L p
1 g
F P
s
P
p
.002 w
.6683 .47988 m .6844 .4238 L .67163 .41155 L p
1 g
F P
s
P
p
.002 w
.66904 .35578 m .67163 .41155 L .6844 .4238 L p
1 g
F P
s
P
p
.002 w
.67163 .41155 m .66904 .35578 L .65212 .34668 L p
1 g
F P
s
P
p
.002 w
.41521 .26568 m .37687 .29117 L .38639 .29972 L p
1 g
F P
s
P
p
.002 w
.63119 .29813 m .65212 .34668 L .66904 .35578 L p
1 g
F P
s
P
p
.002 w
.65212 .34668 m .63119 .29813 L .61203 .29481 L p
1 g
F P
s
P
p
.002 w
.55833 .26339 m .51497 .24483 L .50159 .25552 L p
1 g
F P
s
P
p
.002 w
.45856 .25338 m .50159 .25552 L .51497 .24483 L p
1 g
F P
s
P
p
.002 w
.64445 .54205 m .6766 .49212 L .6683 .47988 L p
1 g
F P
s
P
p
.002 w
.6844 .4238 m .6683 .47988 L .6766 .49212 L p
1 g
F P
s
P
p
.002 w
.5765 .25952 m .61203 .29481 L .63119 .29813 L p
1 g
F P
s
P
p
.002 w
.61203 .29481 m .5765 .25952 L .55833 .26339 L p
1 g
F P
s
P
p
.002 w
.51497 .24483 m .55833 .26339 L .5765 .25952 L p
1 g
F P
s
P
p
.002 w
.37071 .57678 m .421 .60157 L .41287 .58603 L p
1 g
F P
s
P
p
.002 w
.41287 .58603 m .36334 .56138 L .37071 .57678 L p
1 g
F P
s
P
p
.002 w
.33711 .32739 m .31927 .3752 L .3328 .36798 L p
1 g
F P
s
P
p
.002 w
.3328 .36798 m .34827 .32676 L .33711 .32739 L p
1 g
F P
s
P
p
.002 w
.43159 .61305 m .48807 .61972 L .47814 .60848 L p
1 g
F P
s
P
p
.002 w
.47814 .60848 m .421 .60157 L .43159 .61305 L p
1 g
F P
s
P
p
.002 w
.32613 .52065 m .36334 .56138 L .35982 .54309 L p
1 g
F P
s
P
p
.002 w
.35982 .54309 m .32422 .50382 L .32613 .52065 L p
1 g
F P
s
P
p
.002 w
.55428 .61574 m .60603 .58991 L .59949 .58215 L p
1 g
F P
s
P
p
.002 w
.59949 .58215 m .54579 .6089 L .55428 .61574 L p
1 g
F P
s
P
p
.002 w
.64445 .54205 m .59949 .58215 L .60603 .58991 L p
1 g
F P
s
P
p
.002 w
.30516 .45265 m .32422 .50382 L .327 .48567 L p
1 g
F P
s
P
p
.002 w
.327 .48567 m .30939 .4379 L .30516 .45265 L p
1 g
F P
s
P
p
.002 w
.31012 .38421 m .30939 .4379 L .31848 .42351 L p
1 g
F P
s
P
p
.002 w
.31848 .42351 m .31927 .3752 L .31012 .38421 L p
1 g
F P
s
P
p
.002 w
.51497 .24483 m .46517 .24222 L .45856 .25338 L p
1 g
F P
s
P
p
.002 w
.41521 .26568 m .45856 .25338 L .46517 .24222 L p
1 g
F P
s
P
p
.002 w
.60603 .58991 m .6494 .55125 L .64445 .54205 L p
1 g
F P
s
P
p
.002 w
.6766 .49212 m .64445 .54205 L .6494 .55125 L p
1 g
F P
s
P
p
.002 w
.37029 .28604 m .33711 .32739 L .34827 .32676 L p
1 g
F P
s
P
p
.002 w
.34827 .32676 m .37687 .29117 L .37029 .28604 L p
1 g
F P
s
P
p
.002 w
.49874 .62624 m .55428 .61574 L .54579 .6089 L p
1 g
F P
s
P
p
.002 w
.54579 .6089 m .48807 .61972 L .49874 .62624 L p
1 g
F P
s
P
p
.002 w
.6766 .49212 m .69268 .43669 L .6844 .4238 L p
1 g
F P
s
P
p
.002 w
.682 .36723 m .6844 .4238 L .69268 .43669 L p
1 g
F P
s
P
p
.002 w
.6844 .4238 m .682 .36723 L .66904 .35578 L p
1 g
F P
s
P
p
.002 w
.64748 .30515 m .66904 .35578 L .682 .36723 L p
1 g
F P
s
P
p
.002 w
.66904 .35578 m .64748 .30515 L .63119 .29813 L p
1 g
F P
s
P
p
.002 w
.46517 .24222 m .41485 .25643 L .41521 .26568 L p
1 g
F P
s
P
p
.002 w
.37687 .29117 m .41521 .26568 L .41485 .25643 L p
1 g
F P
s
P
p
.002 w
.41485 .25643 m .37029 .28604 L .37687 .29117 L p
1 g
F P
s
P
p
.002 w
.5765 .25952 m .52845 .23875 L .51497 .24483 L p
1 g
F P
s
P
p
.002 w
.46517 .24222 m .51497 .24483 L .52845 .23875 L p
1 g
F P
s
P
p
.002 w
.59326 .26014 m .63119 .29813 L .64748 .30515 L p
1 g
F P
s
P
p
.002 w
.63119 .29813 m .59326 .26014 L .5765 .25952 L p
1 g
F P
s
P
p
.002 w
.6494 .55125 m .68044 .50319 L .6766 .49212 L p
1 g
F P
s
P
p
.002 w
.69268 .43669 m .6766 .49212 L .68044 .50319 L p
1 g
F P
s
P
p
.002 w
.52845 .23875 m .5765 .25952 L .59326 .26014 L p
1 g
F P
s
P
p
.002 w
.38195 .58871 m .43159 .61305 L .421 .60157 L p
1 g
F P
s
P
p
.002 w
.421 .60157 m .37071 .57678 L .38195 .58871 L p
1 g
F P
s
P
p
.002 w
.32995 .3309 m .31012 .38421 L .31927 .3752 L p
1 g
F P
s
P
p
.002 w
.31927 .3752 m .33711 .32739 L .32995 .3309 L p
1 g
F P
s
P
p
.002 w
.33296 .53562 m .37071 .57678 L .36334 .56138 L p
1 g
F P
s
P
p
.002 w
.36334 .56138 m .32613 .52065 L .33296 .53562 L p
1 g
F P
s
P
p
.002 w
.44449 .61992 m .49874 .62624 L .48807 .61972 L p
1 g
F P
s
P
p
.002 w
.48807 .61972 m .43159 .61305 L .44449 .61992 L p
1 g
F P
s
P
p
.002 w
.30619 .46736 m .32613 .52065 L .32422 .50382 L p
1 g
F P
s
P
p
.002 w
.32422 .50382 m .30516 .45265 L .30619 .46736 L p
1 g
F P
s
P
p
.002 w
.30587 .39489 m .30516 .45265 L .30939 .4379 L p
1 g
F P
s
P
p
.002 w
.30939 .4379 m .31012 .38421 L .30587 .39489 L p
1 g
F P
s
P
p
.002 w
.56164 .61777 m .60995 .59363 L .60603 .58991 L p
1 g
F P
s
P
p
.002 w
.60603 .58991 m .55428 .61574 L .56164 .61777 L p
1 g
F P
s
P
p
.002 w
.6494 .55125 m .60603 .58991 L .60995 .59363 L p
1 g
F P
s
P
p
.002 w
.52845 .23875 m .47301 .23575 L .46517 .24222 L p
1 g
F P
s
P
p
.002 w
.41485 .25643 m .46517 .24222 L .47301 .23575 L p
1 g
F P
s
P
p
.002 w
.60995 .59363 m .65046 .55753 L .6494 .55125 L p
1 g
F P
s
P
p
.002 w
.68044 .50319 m .6494 .55125 L .65046 .55753 L p
1 g
F P
s
P
p
.002 w
.69268 .43669 m .69046 .38085 L .682 .36723 L p
1 g
F P
s
P
p
.002 w
.66032 .31589 m .682 .36723 L .69046 .38085 L p
1 g
F P
s
P
p
.002 w
.682 .36723 m .66032 .31589 L .64748 .30515 L p
1 g
F P
s
P
p
.002 w
.68044 .50319 m .69599 .44993 L .69268 .43669 L p
1 g
F P
s
P
p
.002 w
.69046 .38085 m .69268 .43669 L .69599 .44993 L p
1 g
F P
s
P
p
.002 w
.36701 .28469 m .32995 .3309 L .33711 .32739 L p
1 g
F P
s
P
p
.002 w
.33711 .32739 m .37029 .28604 L .36701 .28469 L p
1 g
F P
s
P
p
.002 w
.50988 .62758 m .56164 .61777 L .55428 .61574 L p
1 g
F P
s
P
p
.002 w
.55428 .61574 m .49874 .62624 L .50988 .62758 L p
1 g
F P
s
P
p
.002 w
.60809 .26549 m .64748 .30515 L .66032 .31589 L p
1 g
F P
s
P
p
.002 w
.64748 .30515 m .60809 .26549 L .59326 .26014 L p
1 g
F P
s
P
p
.002 w
.47301 .23575 m .41683 .25159 L .41485 .25643 L p
1 g
F P
s
P
p
.002 w
.37029 .28604 m .41485 .25643 L .41683 .25159 L p
1 g
F P
s
P
p
.002 w
.59326 .26014 m .54168 .23772 L .52845 .23875 L p
1 g
F P
s
P
p
.002 w
.47301 .23575 m .52845 .23875 L .54168 .23772 L p
1 g
F P
s
P
p
.002 w
.41683 .25159 m .36701 .28469 L .37029 .28604 L p
1 g
F P
s
P
p
.002 w
.54168 .23772 m .59326 .26014 L .60809 .26549 L p
1 g
F P
s
P
p
.002 w
.65046 .55753 m .67944 .51271 L .68044 .50319 L p
1 g
F P
s
P
p
.002 w
.69599 .44993 m .68044 .50319 L .67944 .51271 L p
1 g
F P
s
P
p
.002 w
.39696 .59662 m .44449 .61992 L .43159 .61305 L p
1 g
F P
s
P
p
.002 w
.43159 .61305 m .38195 .58871 L .39696 .59662 L p
1 g
F P
s
P
p
.002 w
.34478 .54817 m .38195 .58871 L .37071 .57678 L p
1 g
F P
s
P
p
.002 w
.37071 .57678 m .33296 .53562 L .34478 .54817 L p
1 g
F P
s
P
p
.002 w
.32727 .33736 m .30587 .39489 L .31012 .38421 L p
1 g
F P
s
P
p
.002 w
.31012 .38421 m .32995 .3309 L .32727 .33736 L p
1 g
F P
s
P
p
.002 w
.45948 .62172 m .50988 .62758 L .49874 .62624 L p
1 g
F P
s
P
p
.002 w
.49874 .62624 m .44449 .61992 L .45948 .62172 L p
1 g
F P
s
P
p
.002 w
.31278 .4816 m .33296 .53562 L .32613 .52065 L p
1 g
F P
s
P
p
.002 w
.32613 .52065 m .30619 .46736 L .31278 .4816 L p
1 g
F P
s
P
p
.002 w
.30696 .40702 m .30619 .46736 L .30516 .45265 L p
1 g
F P
s
P
p
.002 w
.30516 .45265 m .30587 .39489 L .30696 .40702 L p
1 g
F P
s
P
p
.002 w
.54168 .23772 m .48195 .23447 L .47301 .23575 L p
1 g
F P
s
P
p
.002 w
.41683 .25159 m .47301 .23575 L .48195 .23447 L p
1 g
F P
s
P
p
.002 w
.65046 .55753 m .60995 .59363 L .61095 .59293 L p
1 g
F P
s
P
p
.002 w
.56758 .61461 m .61095 .59293 L .60995 .59363 L p
1 g
F P
s
P
p
.002 w
.60995 .59363 m .56164 .61777 L .56758 .61461 L p
1 g
F P
s
P
p
.002 w
.69599 .44993 m .69392 .39639 L .69046 .38085 L p
1 g
F P
s
P
p
.002 w
.69046 .38085 m .66915 .33026 L .66032 .31589 L p
1 g
F P
s
P
p
.002 w
.66915 .33026 m .69046 .38085 L .69392 .39639 L p
1 g
F P
s
P
p
.002 w
.61095 .59293 m .64734 .56051 L .65046 .55753 L p
1 g
F P
s
P
p
.002 w
.67944 .51271 m .65046 .55753 L .64734 .56051 L p
1 g
F P
s
P
p
.002 w
.67944 .51271 m .69393 .46316 L .69599 .44993 L p
1 g
F P
s
P
p
.002 w
.69392 .39639 m .69599 .44993 L .69393 .46316 L p
1 g
F P
s
P
p
.002 w
.36735 .2874 m .32727 .33736 L .32995 .3309 L p
1 g
F P
s
P
p
.002 w
.32995 .3309 m .36701 .28469 L .36735 .2874 L p
1 g
F P
s
P
p
.002 w
.66032 .31589 m .62046 .2757 L .60809 .26549 L p
1 g
F P
s
P
p
.002 w
.62046 .2757 m .66032 .31589 L .66915 .33026 L p
1 g
F P
s
P
p
.002 w
.5212 .62338 m .56758 .61461 L .56164 .61777 L p
1 g
F P
s
P
p
.002 w
.56164 .61777 m .50988 .62758 L .5212 .62338 L p
1 g
F P
s
P
p
.002 w
.60809 .26549 m .55428 .24209 L .54168 .23772 L p
1 g
F P
s
P
p
.002 w
.48195 .23447 m .54168 .23772 L .55428 .24209 L p
1 g
F P
s
P
p
.002 w
.55428 .24209 m .60809 .26549 L .62046 .2757 L p
1 g
F P
s
P
p
.002 w
.48195 .23447 m .42124 .25159 L .41683 .25159 L p
1 g
F P
s
P
p
.002 w
.36701 .28469 m .41683 .25159 L .42124 .25159 L p
1 g
F P
s
P
p
.002 w
.42124 .25159 m .36735 .2874 L .36701 .28469 L p
1 g
F P
s
P
p
.002 w
.64734 .56051 m .67333 .52031 L .67944 .51271 L p
1 g
F P
s
P
p
.002 w
.69393 .46316 m .67944 .51271 L .67333 .52031 L p
1 g
F P
s
P
p
.002 w
.41551 .60006 m .45948 .62172 L .44449 .61992 L p
1 g
F P
s
P
p
.002 w
.44449 .61992 m .39696 .59662 L .41551 .60006 L p
1 g
F P
s
P
p
.002 w
.36153 .5578 m .39696 .59662 L .38195 .58871 L p
1 g
F P
s
P
p
.002 w
.38195 .58871 m .34478 .54817 L .36153 .5578 L p
1 g
F P
s
P
p
.002 w
.32944 .34678 m .30696 .40702 L .30587 .39489 L p
1 g
F P
s
P
p
.002 w
.30587 .39489 m .32727 .33736 L .32944 .34678 L p
1 g
F P
s
P
p
.002 w
.32504 .49492 m .34478 .54817 L .33296 .53562 L p
1 g
F P
s
P
p
.002 w
.33296 .53562 m .31278 .4816 L .32504 .49492 L p
1 g
F P
s
P
p
.002 w
.47622 .61807 m .5212 .62338 L .50988 .62758 L p
1 g
F P
s
P
p
.002 w
.50988 .62758 m .45948 .62172 L .47622 .61807 L p
1 g
F P
s
P
p
.002 w
.31368 .42033 m .31278 .4816 L .30619 .46736 L p
1 g
F P
s
P
p
.002 w
.30619 .46736 m .30696 .40702 L .31368 .42033 L p
1 g
F P
s
P
p
.002 w
.69393 .46316 m .69197 .41351 L .69392 .39639 L p
1 g
F P
s
P
p
.002 w
.67348 .34804 m .69392 .39639 L .69197 .41351 L p
1 g
F P
s
P
p
.002 w
.69392 .39639 m .67348 .34804 L .66915 .33026 L p
1 g
F P
s
P
p
.002 w
.55428 .24209 m .49178 .23873 L .48195 .23447 L p
1 g
F P
s
P
p
.002 w
.42124 .25159 m .48195 .23447 L .49178 .23873 L p
1 g
F P
s
P
p
.002 w
.57183 .60601 m .60881 .58755 L .61095 .59293 L p
1 g
F P
s
P
p
.002 w
.61095 .59293 m .56758 .61461 L .57183 .60601 L p
1 g
F P
s
P
p
.002 w
.64734 .56051 m .61095 .59293 L .60881 .58755 L p
1 g
F P
s
P
p
.002 w
.67333 .52031 m .68624 .47598 L .69393 .46316 L p
1 g
F P
s
P
p
.002 w
.69197 .41351 m .69393 .46316 L .68624 .47598 L p
1 g
F P
s
P
p
.002 w
.62984 .29075 m .66915 .33026 L .67348 .34804 L p
1 g
F P
s
P
p
.002 w
.66915 .33026 m .62984 .29075 L .62046 .2757 L p
1 g
F P
s
P
p
.002 w
.60881 .58755 m .63984 .55989 L .64734 .56051 L p
1 g
F P
s
P
p
.002 w
.67333 .52031 m .64734 .56051 L .63984 .55989 L p
1 g
F P
s
P
p
.002 w
.37154 .29437 m .32944 .34678 L .32727 .33736 L p
1 g
F P
s
P
p
.002 w
.32727 .33736 m .36735 .2874 L .37154 .29437 L p
1 g
F P
s
P
p
.002 w
.56584 .25204 m .62046 .2757 L .62984 .29075 L p
1 g
F P
s
P
p
.002 w
.62046 .2757 m .56584 .25204 L .55428 .24209 L p
1 g
F P
s
P
p
.002 w
.53238 .61342 m .57183 .60601 L .56758 .61461 L p
1 g
F P
s
P
p
.002 w
.56758 .61461 m .5212 .62338 L .53238 .61342 L p
1 g
F P
s
P
p
.002 w
.49178 .23873 m .55428 .24209 L .56584 .25204 L p
1 g
F P
s
P
p
.002 w
.49178 .23873 m .42812 .25675 L .42124 .25159 L p
1 g
F P
s
P
p
.002 w
.36735 .2874 m .42124 .25159 L .42812 .25675 L p
1 g
F P
s
P
p
.002 w
.38293 .56404 m .41551 .60006 L .39696 .59662 L p
1 g
F P
s
P
p
.002 w
.39696 .59662 m .36153 .5578 L .38293 .56404 L p
1 g
F P
s
P
p
.002 w
.43718 .59865 m .47622 .61807 L .45948 .62172 L p
1 g
F P
s
P
p
.002 w
.45948 .62172 m .41551 .60006 L .43718 .59865 L p
1 g
F P
s
P
p
.002 w
.63984 .55989 m .66194 .52563 L .67333 .52031 L p
1 g
F P
s
P
p
.002 w
.68624 .47598 m .67333 .52031 L .66194 .52563 L p
1 g
F P
s
P
p
.002 w
.42812 .25675 m .37154 .29437 L .36735 .2874 L p
1 g
F P
s
P
p
.002 w
.3429 .50682 m .36153 .5578 L .34478 .54817 L p
1 g
F P
s
P
p
.002 w
.34478 .54817 m .32504 .49492 L .3429 .50682 L p
1 g
F P
s
P
p
.002 w
.3367 .35905 m .31368 .42033 L .30696 .40702 L p
1 g
F P
s
P
p
.002 w
.30696 .40702 m .32944 .34678 L .3367 .35905 L p
1 g
F P
s
P
p
.002 w
.32616 .43445 m .32504 .49492 L .31278 .4816 L p
1 g
F P
s
P
p
.002 w
.31278 .4816 m .31368 .42033 L .32616 .43445 L p
1 g
F P
s
P
p
.002 w
.49428 .60879 m .53238 .61342 L .5212 .62338 L p
1 g
F P
s
P
p
.002 w
.5212 .62338 m .47622 .61807 L .49428 .60879 L p
1 g
F P
s
P
p
.002 w
.68624 .47598 m .68436 .43177 L .69197 .41351 L p
1 g
F P
s
P
p
.002 w
.67292 .36887 m .69197 .41351 L .68436 .43177 L p
1 g
F P
s
P
p
.002 w
.69197 .41351 m .67292 .36887 L .67348 .34804 L p
1 g
F P
s
P
p
.002 w
.63578 .31043 m .67348 .34804 L .67292 .36887 L p
1 g
F P
s
P
p
.002 w
.67348 .34804 m .63578 .31043 L .62984 .29075 L p
1 g
F P
s
P
p
.002 w
.56584 .25204 m .50226 .24878 L .49178 .23873 L p
1 g
F P
s
P
p
.002 w
.42812 .25675 m .49178 .23873 L .50226 .24878 L p
1 g
F P
s
P
p
.002 w
.66194 .52563 m .67282 .48799 L .68624 .47598 L p
1 g
F P
s
P
p
.002 w
.68436 .43177 m .68624 .47598 L .67282 .48799 L p
1 g
F P
s
P
p
.002 w
.57415 .5919 m .6034 .57734 L .60881 .58755 L p
1 g
F P
s
P
p
.002 w
.60881 .58755 m .57183 .60601 L .57415 .5919 L p
1 g
F P
s
P
p
.002 w
.63984 .55989 m .60881 .58755 L .6034 .57734 L p
1 g
F P
s
P
p
.002 w
.57591 .2676 m .62984 .29075 L .63578 .31043 L p
1 g
F P
s
P
p
.002 w
.62984 .29075 m .57591 .2676 L .56584 .25204 L p
1 g
F P
s
P
p
.002 w
.6034 .57734 m .62794 .55545 L .63984 .55989 L p
1 g
F P
s
P
p
.002 w
.66194 .52563 m .63984 .55989 L .62794 .55545 L p
1 g
F P
s
P
p
.002 w
.50226 .24878 m .56584 .25204 L .57591 .2676 L p
1 g
F P
s
P
p
.002 w
.3797 .30565 m .3367 .35905 L .32944 .34678 L p
1 g
F P
s
P
p
.002 w
.32944 .34678 m .37154 .29437 L .3797 .30565 L p
1 g
F P
s
P
p
.002 w
.54303 .59766 m .57415 .5919 L .57183 .60601 L p
1 g
F P
s
P
p
.002 w
.57183 .60601 m .53238 .61342 L .54303 .59766 L p
1 g
F P
s
P
p
.002 w
.40851 .5665 m .43718 .59865 L .41551 .60006 L p
1 g
F P
s
P
p
.002 w
.41551 .60006 m .38293 .56404 L .40851 .5665 L p
1 g
F P
s
P
p
.002 w
.46144 .5922 m .49428 .60879 L .47622 .61807 L p
1 g
F P
s
P
p
.002 w
.47622 .61807 m .43718 .59865 L .46144 .5922 L p
1 g
F P
s
P
p
.002 w
.36605 .51683 m .38293 .56404 L .36153 .5578 L p
1 g
F P
s
P
p
.002 w
.36153 .5578 m .3429 .50682 L .36605 .51683 L p
1 g
F P
s
P
p
.002 w
.50226 .24878 m .43741 .26725 L .42812 .25675 L p
1 g
F P
s
P
p
.002 w
.37154 .29437 m .42812 .25675 L .43741 .26725 L p
1 g
F P
s
P
p
.002 w
.62794 .55545 m .64534 .52837 L .66194 .52563 L p
1 g
F P
s
P
p
.002 w
.67282 .48799 m .66194 .52563 L .64534 .52837 L p
1 g
F P
s
P
p
.002 w
.43741 .26725 m .3797 .30565 L .37154 .29437 L p
1 g
F P
s
P
p
.002 w
.34912 .37393 m .32616 .43445 L .31368 .42033 L p
1 g
F P
s
P
p
.002 w
.31368 .42033 m .3367 .35905 L .34912 .37393 L p
1 g
F P
s
P
p
.002 w
.34429 .44896 m .3429 .50682 L .32504 .49492 L p
1 g
F P
s
P
p
.002 w
.32504 .49492 m .32616 .43445 L .34429 .44896 L p
1 g
F P
s
P
p
.002 w
.51313 .59388 m .54303 .59766 L .53238 .61342 L p
1 g
F P
s
P
p
.002 w
.53238 .61342 m .49428 .60879 L .51313 .59388 L p
1 g
F P
s
P
p
.002 w
.67282 .48799 m .67105 .45062 L .68436 .43177 L p
1 g
F P
s
P
p
.002 w
.66723 .39222 m .68436 .43177 L .67105 .45062 L p
1 g
F P
s
P
p
.002 w
.68436 .43177 m .66723 .39222 L .67292 .36887 L p
1 g
F P
s
P
p
.002 w
.63789 .33434 m .67292 .36887 L .66723 .39222 L p
1 g
F P
s
P
p
.002 w
.67292 .36887 m .63789 .33434 L .63578 .31043 L p
1 g
F P
s
P
p
.002 w
.64534 .52837 m .65378 .49872 L .67282 .48799 L p
1 g
F P
s
P
p
.002 w
.67105 .45062 m .67282 .48799 L .65378 .49872 L p
1 g
F P
s
P
p
.002 w
.57591 .2676 m .51308 .26461 L .50226 .24878 L p
1 g
F P
s
P
p
.002 w
.43741 .26725 m .50226 .24878 L .51308 .26461 L p
1 g
F P
s
P
p
.002 w
.58408 .28857 m .63578 .31043 L .63789 .33434 L p
1 g
F P
s
P
p
.002 w
.63578 .31043 m .58408 .28857 L .57591 .2676 L p
1 g
F P
s
P
p
.002 w
.51308 .26461 m .57591 .2676 L .58408 .28857 L p
1 g
F P
s
P
p
.002 w
.57435 .57242 m .59469 .56233 L .6034 .57734 L p
1 g
F P
s
P
p
.002 w
.6034 .57734 m .57415 .5919 L .57435 .57242 L p
1 g
F P
s
P
p
.002 w
.62794 .55545 m .6034 .57734 L .59469 .56233 L p
1 g
F P
s
P
p
.002 w
.43756 .56492 m .46144 .5922 L .43718 .59865 L p
1 g
F P
s
P
p
.002 w
.43718 .59865 m .40851 .5665 L .43756 .56492 L p
1 g
F P
s
P
p
.002 w
.59469 .56233 m .61173 .54711 L .62794 .55545 L p
1 g
F P
s
P
p
.002 w
.64534 .52837 m .62794 .55545 L .61173 .54711 L p
1 g
F P
s
P
p
.002 w
.51313 .59388 m .49428 .60879 L p
.48765 .58112 L 1 g
F P
s
P
p
.48765 .58112 m .48759 .58086 L .48814 .58114 L 1 g
F
P
p
.48765 .58112 m .48814 .58114 L .51313 .59388 L 1 g
F
P
p
.002 w
.48809 .58097 m .48844 .58115 L p
.48759 .58086 L 1 g
F P
s
P
p
.002 w
.48844 .58115 m .51313 .59388 L p
.48814 .58114 L 1 g
F P
s
P
p
.48759 .58086 m .48844 .58115 L .48814 .58114 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48902 .58113 L p
1 g
F P
s
P
p
.51079 .57862 m .48902 .58113 L .48963 .58111 L 1 g
F
P
p
.002 w
.51313 .59388 m .48844 .58115 L p
.48902 .58113 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58031 L p
1 g
F P
s
P
p
.51357 .58538 m .5 .58303 L .51384 .5802 L 1 g
F
P
p
.5 .58303 m .51092 .58031 L .51384 .5802 L 1 g
F
P
p
.53128 .57265 m .51092 .58031 L .52148 .57768 L 1 g
F
P
p
.48921 .57862 m .47881 .57777 L .48809 .58097 L 1 g
F
P
p
.46144 .5922 m .4659 .57317 L .46841 .57406 L 1 g
F
P
p
.002 w
.48732 .5808 m .48258 .58289 L p
.46841 .57406 L 1 g
F P
s
P
p
.002 w
.48258 .58289 m .46144 .5922 L p
.46841 .57406 L 1 g
F P
s
P
p
.002 w
.46841 .57406 m .46872 .57265 L p
.46154 .56978 L 1 g
F P
s
P
p
.47881 .57777 m .48732 .5808 L .48809 .58097 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56309 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56309 L .46154 .56978 L 1 g
F
P
p
.46841 .57406 m .46917 .55921 L .48732 .5808 L 1 g
F
P
p
.4659 .57317 m .46604 .57258 L .46841 .57406 L 1 g
F
P
p
.46604 .57258 m .46917 .55921 L .46841 .57406 L 1 g
F
P
p
.002 w
.46144 .5922 m .43756 .56492 L .45034 .56261 L p
1 g
F P
s
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44564 .55627 L 1 g
F P
s
P
p
.002 w
.45034 .56261 m .43756 .56492 L p
.44449 .55472 L 1 g
F P
s
P
p
.002 w
.43756 .56492 m .42567 .5295 L .42583 .52951 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.43756 .56492 m .42583 .52951 L .43864 .54681 L 1 g
F
P
p
.44245 .55773 m .43864 .54681 L .44449 .55472 L 1 g
F
P
p
.43756 .56492 m .43864 .54681 L .44245 .55773 L 1 g
F
P
p
.002 w
.43864 .54681 m .43925 .54566 L p
.43598 .53919 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .54681 L p
1 g
F P
s
P
p
.002 w
.43864 .54681 m .43743 .5491 L p
.44557 .55617 L 1 g
F P
s
P
p
.45146 .56129 m .43864 .54681 L .44557 .55617 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43247 .52879 L p
1 g
F P
s
P
p
.43925 .54566 m .43247 .52879 L .43265 .52954 L 1 g
F
P
p
.42567 .5295 m .43151 .52486 L .43247 .52879 L 1 g
F
P
p
.002 w
.43274 .52991 m .43237 .52989 L p
.43247 .52879 L 1 g
F P
s
P
p
.002 w
.43237 .52989 m .42567 .5295 L p
.43247 .52879 L 1 g
F P
s
P
p
.002 w
.43247 .52879 m .43346 .52734 L p
.43321 .52022 L 1 g
F P
s
P
p
.43925 .54566 m .43265 .52954 L .43598 .53919 L 1 g
F
P
p
.43265 .52954 m .43239 .5289 L .43274 .52991 L 1 g
F
P
p
.43265 .52954 m .43274 .52991 L .43598 .53919 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43418 .50905 L p
1 g
F P
s
P
p
.43346 .52734 m .43418 .50905 L .43321 .52022 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.42567 .5295 m .4258 .52681 L p
.46211 .50056 L 1 g
F P
s
P
p
.002 w
.4258 .52681 m .42764 .48968 L .44129 .49399 L p
1 g
F P
s
P
p
.002 w
.43418 .50905 m .43485 .50826 L p
.43768 .50165 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44265 .49128 L p
1 g
F P
s
P
p
.42764 .48968 m .4477 .48125 L .44265 .49128 L 1 g
F
P
p
.002 w
.44129 .49399 m .44022 .49365 L p
.44265 .49128 L 1 g
F P
s
P
p
.002 w
.44022 .49365 m .42764 .48968 L p
.44265 .49128 L 1 g
F P
s
P
p
.002 w
.44265 .49128 m .44166 .49233 L p
.43904 .49847 L 1 g
F P
s
P
p
.43485 .50826 m .44265 .49128 L .43904 .49847 L 1 g
F
P
p
.002 w
.44265 .49128 m .44339 .4905 L p
.44872 .4854 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44265 .49128 m .47483 .46985 L .44129 .49399 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45783 .47655 L p
1 g
F P
s
P
p
.44339 .4905 m .45783 .47655 L .44872 .4854 L 1 g
F
P
p
.4477 .48125 m .45703 .47733 L .44265 .49128 L 1 g
F
P
p
.45703 .47733 m .47483 .46985 L .44265 .49128 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47372 .46914 m .47483 .46985 L p
.44834 .48098 L 1 g
F P
s
P
p
.002 w
.47483 .46985 m .47658 .46774 L p
.52195 .47023 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47749 .46728 L p
1 g
F P
s
P
p
.45826 .47608 m .47749 .46728 L .47727 .46739 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47658 .46774 m .47749 .46728 L .52195 .47023 L 1 g
F
P
p
.002 w
.47749 .46728 m .47786 .46667 L p
.48831 .46561 L 1 g
F P
s
P
p
.47749 .46728 m .5 .4638 L .52195 .47023 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52251 .46728 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5423 .47669 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56611 .50941 L p
1 g
F P
s
P
p
.002 w
.56748 .50108 m .56779 .51292 L p
.56611 .50941 L 1 g
F P
s
P
p
.55757 .49152 m .56503 .49872 L .56611 .50941 L 1 g
F
P
p
.56503 .49872 m .56748 .50108 L .56611 .50941 L 1 g
F
P
p
.002 w
.56611 .50941 m .56515 .50826 L p
.56721 .52165 L 1 g
F P
s
P
p
.56721 .52165 m .56721 .52162 L .56611 .50941 L 1 g
F
P
p
.56722 .52166 m .56719 .52107 L .56611 .50941 L 1 g
F
P
p
.56719 .52107 m .56713 .51975 L .56611 .50941 L 1 g
F
P
p
.56713 .51975 m .56711 .51952 L .56611 .50941 L 1 g
F
P
p
.56712 .5196 m .56708 .51907 L .56611 .50941 L 1 g
F
P
p
.002 w
.56705 .51873 m .56795 .51916 L .56708 .51907 L p
1 g
F P
s
P
p
.56708 .51907 m .56707 .51892 L .56706 .51882 L 1 g
F
P
p
.56708 .51907 m .56706 .51882 L .56611 .50941 L 1 g
F
P
p
.56707 .51892 m .56701 .5183 L .56611 .50941 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56716 .5205 m .56795 .51916 L .56725 .52238 L p
1 g
F P
s
P
p
.002 w
.57229 .54796 m .56833 .54866 L p
.56805 .52696 L 1 g
F P
s
P
p
.002 w
.56795 .51916 m .56877 .5246 L p
.56805 .52696 L 1 g
F P
s
P
p
.002 w
.56877 .5246 m .57229 .54796 L p
.56805 .52696 L 1 g
F P
s
P
p
.002 w
.56751 .52875 m .56654 .52734 L p
.56444 .53883 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56751 .52875 L p
1 g
F P
s
P
p
.002 w
.56725 .52238 m .56795 .51916 L p
.56833 .54866 L 1 g
F P
s
P
p
.002 w
.56751 .52875 m .56854 .53025 L p
.56722 .52166 L 1 g
F P
s
P
p
.56515 .50826 m .56751 .52875 L .56722 .52166 L 1 g
F
P
p
.002 w
.56833 .54866 m .5612 .54992 L .56153 .5484 L p
1 g
F P
s
P
p
.002 w
.56153 .5484 m .56167 .54775 L p
.56173 .54775 L 1 g
F P
s
P
p
.56833 .54866 m .56153 .5484 L .56173 .54775 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56177 .54759 L p
1 g
F P
s
P
p
.56654 .52734 m .56177 .54759 L .56444 .53883 L 1 g
F
P
p
.56833 .54866 m .56167 .54775 L .5679 .53834 L 1 g
F
P
p
.002 w
.5612 .54992 m .5603 .54979 L p
.56162 .54783 L 1 g
F P
s
P
p
.002 w
.56178 .54759 m .56075 .54566 L p
.55501 .55607 L 1 g
F P
s
P
p
.002 w
.5612 .54992 m .55277 .57634 L p
.55154 .56018 L 1 g
F P
s
P
p
.002 w
.5603 .54979 m .5612 .54992 L p
.55154 .56018 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55277 .57634 m .54303 .59766 L p
.53259 .57456 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53179 .57501 L p
1 g
F P
s
P
p
.54854 .56129 m .53179 .57501 L .53297 .57435 L 1 g
F
P
p
.002 w
.53391 .57382 m .55277 .57634 L p
.53259 .57456 L 1 g
F P
s
P
p
.54854 .56129 m .53297 .57435 L .5397 .56972 L 1 g
F
P
p
.54303 .59766 m .52974 .57615 L .53179 .57501 L 1 g
F
P
p
.53266 .57473 m .53179 .57501 L .53259 .57456 L 1 g
F
P
p
.54303 .59766 m .53179 .57501 L .53266 .57473 L 1 g
F
P
p
.002 w
.54303 .59766 m .51313 .59388 L .52974 .57615 L p
1 g
F P
s
P
p
.002 w
.53179 .57501 m .53128 .57265 L p
.52148 .57768 L 1 g
F P
s
P
p
.002 w
.53039 .57546 m .51313 .59388 L p
.51387 .57957 L 1 g
F P
s
P
p
.52148 .57768 m .51815 .57938 L .53039 .57546 L 1 g
F
P
p
.52148 .57768 m .53039 .57546 L .53179 .57501 L 1 g
F
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51466 .56435 m .53215 .57359 L .53039 .57546 L p
1 g
F P
s
P
p
.51387 .57957 m .51466 .56435 L .53039 .57546 L 1 g
F
P
p
.002 w
.52974 .57615 m .53215 .57359 L p
.53259 .57456 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53179 .57501 L p
1 g
F P
s
P
p
.51815 .57938 m .51111 .583 L .53179 .57501 L 1 g
F
P
p
.53297 .57435 m .53186 .57528 L .53391 .57382 L 1 g
F
P
p
.53297 .57435 m .53391 .57382 L .5397 .56972 L 1 g
F
P
p
.002 w
.53215 .57359 m .53391 .57382 L p
.53259 .57456 L 1 g
F P
s
P
p
.002 w
.53179 .57501 m .53186 .57528 L p
.53297 .57435 L 1 g
F P
s
P
p
.002 w
.53943 .57456 m .53391 .57382 L p
.54917 .56299 L 1 g
F P
s
P
p
.002 w
.53186 .57528 m .5322 .57686 L p
.5397 .56972 L 1 g
F P
s
P
p
.002 w
.55277 .57634 m .53943 .57456 L p
.54917 .56299 L 1 g
F P
s
P
p
.55277 .57634 m .54917 .56299 L .55163 .56125 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54917 .56299 L p
1 g
F P
s
P
p
.002 w
.54917 .56299 m .54854 .56129 L p
.5397 .56972 L 1 g
F P
s
P
p
.5397 .56972 m .5322 .57686 L .54917 .56299 L 1 g
F
P
p
.55163 .56125 m .54917 .56299 L .55154 .56018 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54998 .56518 L p
1 g
F P
s
P
p
.54917 .56299 m .53215 .57359 L .55154 .56018 L 1 g
F
P
p
.002 w
.53391 .57382 m .53215 .57359 L p
.54917 .56299 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53215 .57359 m .55066 .54842 L p
.55154 .56018 L 1 g
F P
s
P
p
.55501 .55607 m .5603 .54979 L .56178 .54759 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56725 .52238 m .56167 .54775 L p
.56716 .5205 L 1 g
F P
s
P
p
.002 w
.56167 .54775 m .5612 .54992 L p
.56162 .54783 L 1 g
F P
s
P
p
.56162 .54783 m .56716 .5205 L .56167 .54775 L 1 g
F
P
p
.002 w
.5612 .54992 m .57229 .54796 L .57435 .57242 L p
1 g
F P
s
P
p
.002 w
.57435 .57242 m .55277 .57634 L .5612 .54992 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56192 .54787 L p
1 g
F P
s
P
p
.002 w
.56192 .54787 m .56178 .54759 L p
.56031 .54977 L 1 g
F P
s
P
p
.56031 .54977 m .54998 .56518 L .56192 .54787 L 1 g
F
P
p
.55501 .55607 m .55009 .56498 L .5603 .54979 L 1 g
F
P
p
.002 w
.55066 .54842 m .5603 .54979 L p
.55154 .56018 L 1 g
F P
s
P
p
.55009 .56498 m .54998 .56518 L .56178 .54759 L 1 g
F
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55066 .54842 m .56716 .5205 L p
.56162 .54783 L 1 g
F P
s
P
p
.002 w
.5603 .54979 m .55066 .54842 L p
.56162 .54783 L 1 g
F P
s
P
p
.002 w
.56167 .54775 m .56725 .52238 L p
.5679 .53834 L 1 g
F P
s
P
p
.002 w
.56177 .54759 m .56257 .5491 L p
.56444 .53883 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .55092 .56398 L p
.55144 .56909 L 1 g
F P
s
P
p
.002 w
.55092 .56398 m .54998 .56518 L .55004 .56532 L p
1 g
F P
s
P
p
.002 w
.55004 .56532 m .55144 .56909 L p
.55092 .56398 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56751 .52875 L p
1 g
F P
s
P
p
.56444 .53883 m .56257 .5491 L .56751 .52875 L 1 g
F
P
p
.002 w
.53364 .51557 m .53817 .50507 L .56705 .51873 L p
1 g
F P
s
P
p
.002 w
.56708 .51907 m .53364 .51557 L p
.56705 .51873 L 1 g
F P
s
P
p
.56705 .51874 m .56682 .51634 L .56611 .50941 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53817 .50507 m .54586 .49593 L .567 .51815 L p
1 g
F P
s
P
p
.002 w
.567 .51815 m .56795 .51916 L .56705 .51873 L p
1 g
F P
s
P
p
.002 w
.56705 .51873 m .53817 .50507 L p
.567 .51815 L 1 g
F P
s
P
p
.56707 .51892 m .56705 .51874 L .56701 .5183 L 1 g
F
P
p
.002 w
.56682 .51634 m .56795 .51916 L .567 .51815 L p
1 g
F P
s
P
p
.56705 .51874 m .56703 .51851 L .56682 .51634 L 1 g
F
P
p
.55661 .4905 m .56611 .50941 L .56209 .50099 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55757 .49152 L p
1 g
F P
s
P
p
.002 w
.55757 .49152 m .55661 .4905 L p
.56209 .50099 L 1 g
F P
s
P
p
.56209 .50099 m .56713 .51061 L .55757 .49152 L 1 g
F
P
p
.002 w
.54174 .47608 m .55628 .49018 L p
.55633 .49031 L 1 g
F P
s
P
p
.002 w
.55628 .49018 m .55661 .4905 L p
.55633 .49031 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .55757 .49152 L p
.55633 .49031 L 1 g
F P
s
P
p
.54174 .47608 m .55757 .49152 L .55634 .49033 L 1 g
F
P
p
.002 w
.55634 .49033 m .56682 .51634 L p
.55544 .48947 L 1 g
F P
s
P
p
.55633 .49032 m .55634 .49033 L .55633 .49032 L 1 g
F
P
p
.54174 .47608 m .55634 .49033 L .55633 .49032 L 1 g
F
P
p
.002 w
.54586 .49593 m .55544 .48947 L p
.56682 .51634 L 1 g
F P
s
P
p
.002 w
.56795 .51916 m .55634 .49033 L p
.55757 .49152 L 1 g
F P
s
P
p
.54174 .47608 m .55633 .49032 L .55106 .48521 L 1 g
F
P
p
.002 w
.56779 .51292 m .56795 .51916 L p
.55757 .49152 L 1 g
F P
s
P
p
.55633 .49032 m .55774 .4917 L .5555 .48952 L 1 g
F
P
p
.55633 .49032 m .5555 .48952 L .55106 .48521 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55544 .48947 m .55587 .48918 L .55634 .49033 L p
1 g
F P
s
P
p
.002 w
.55634 .49033 m .55587 .48918 L p
.557 .49034 L 1 g
F P
s
P
p
.557 .49034 m .56748 .50108 L .55757 .49152 L 1 g
F
P
p
.557 .49034 m .55757 .49152 L .55634 .49033 L 1 g
F
P
p
.002 w
.567 .51815 m .54586 .49593 L p
.56682 .51634 L 1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5356 .53596 m .53276 .52626 L .5671 .51933 L p
1 g
F P
s
P
p
.002 w
.5671 .51933 m .56795 .51916 L .56712 .5196 L p
1 g
F P
s
P
p
.002 w
.56712 .5196 m .5356 .53596 L p
.5671 .51933 L 1 g
F P
s
P
p
.002 w
.56712 .5196 m .56795 .51916 L .56714 .51993 L p
1 g
F P
s
P
p
.56713 .51975 m .56712 .5196 L .56711 .51952 L 1 g
F
P
p
.56712 .5196 m .56709 .51909 L .56703 .51851 L 1 g
F
P
p
.002 w
.53276 .52626 m .53364 .51557 L .56708 .51907 L p
1 g
F P
s
P
p
.002 w
.56708 .51907 m .56795 .51916 L .5671 .51933 L p
1 g
F P
s
P
p
.002 w
.5671 .51933 m .53276 .52626 L p
.56708 .51907 L 1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5418 .54361 m .5356 .53596 L .56712 .5196 L p
1 g
F P
s
P
p
.002 w
.56714 .51993 m .5418 .54361 L p
.56712 .5196 L 1 g
F P
s
P
p
.56714 .51993 m .56712 .51936 L .56709 .51909 L 1 g
F
P
p
.56719 .52107 m .56717 .5205 L .56714 .51993 L 1 g
F
P
p
.002 w
.56714 .51993 m .56795 .51916 L .56716 .5205 L p
1 g
F P
s
P
p
.56717 .5205 m .56712 .51936 L .56714 .51993 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55066 .54842 m .5418 .54361 L .56714 .51993 L p
1 g
F P
s
P
p
.002 w
.56716 .5205 m .55066 .54842 L p
.56714 .51993 L 1 g
F P
s
P
p
.56721 .52165 m .56722 .52166 L .56721 .52162 L 1 g
F
P
p
.56722 .52166 m .56762 .52428 L .56712 .51936 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .50941 L p
1 g
F P
s
P
p
.56762 .52428 m .56854 .53025 L .56611 .50941 L 1 g
F
P
p
.002 w
.56611 .50941 m .56713 .51061 L p
.56209 .50099 L 1 g
F P
s
P
p
.002 w
.55757 .49152 m .55774 .4917 L p
.55633 .49032 L 1 g
F P
s
P
p
.002 w
.55587 .48918 m .56707 .48557 L .56748 .50108 L p
1 g
F P
s
P
p
.002 w
.55256 .48154 m .55587 .48918 L p
.55354 .48762 L 1 g
F P
s
P
p
.52471 .46837 m .5423 .47669 L .55354 .48762 L 1 g
F
P
p
.002 w
.52195 .47023 m .52471 .46837 L p
.55354 .48762 L 1 g
F P
s
P
p
.52195 .47023 m .55354 .48762 L .55416 .48822 L 1 g
F
P
p
.002 w
.55587 .48918 m .54586 .49593 L .52195 .47023 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5423 .47669 L p
1 g
F P
s
P
p
.002 w
.5423 .47669 m .54174 .47608 L p
.55106 .48521 L 1 g
F P
s
P
p
.55106 .48521 m .55834 .49233 L .5423 .47669 L 1 g
F
P
p
.55416 .48822 m .55354 .48762 L .55587 .48918 L 1 g
F
P
p
.5423 .47669 m .55256 .48154 L .55354 .48762 L 1 g
F
P
p
.002 w
.55774 .4917 m .55834 .49233 L p
.55106 .48521 L 1 g
F P
s
P
p
.002 w
.5423 .47669 m .54302 .47747 L p
.53301 .4723 L 1 g
F P
s
P
p
.52214 .46667 m .5423 .47669 L .53301 .4723 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52195 .47023 m .51876 .46675 L p
.52251 .46728 L 1 g
F P
s
P
p
.002 w
.52251 .46728 m .52214 .46667 L p
.54105 .47646 L 1 g
F P
s
P
p
.002 w
.52567 .46773 m .52471 .46837 L p
.52251 .46728 L 1 g
F P
s
P
p
.002 w
.52471 .46837 m .52195 .47023 L p
.52251 .46728 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52251 .46728 L p
1 g
F P
s
P
p
.54105 .47646 m .54302 .47747 L .52251 .46728 L 1 g
F
P
p
.002 w
.52471 .46837 m .54184 .45685 L .55256 .48154 L p
1 g
F P
s
P
p
.002 w
.52251 .46728 m .52255 .46734 L p
.52082 .46704 L 1 g
F P
s
P
p
.5 .4634 m .52251 .46728 L .52082 .46704 L 1 g
F
P
p
.002 w
.54184 .45685 m .52567 .46773 L p
.49711 .44304 L 1 g
F P
s
P
p
.5 .4634 m .52255 .46734 L .51135 .46558 L 1 g
F
P
p
.002 w
.51876 .46675 m .49711 .44304 L p
.52567 .46773 L 1 g
F P
s
P
p
.002 w
.51876 .46675 m .52195 .47023 L p
.5 .4638 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4638 L p
1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .4634 L p
.51135 .46558 L 1 g
F P
s
P
p
.51135 .46558 m .52282 .46778 L .5 .4638 L 1 g
F
P
p
.002 w
.50616 .45295 m .51408 .46162 L p
.5 .4638 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .46442 L p
.48831 .46561 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .48831 .46561 L 1 g
F
P
p
.47749 .46728 m .48818 .46194 L .5 .4638 L 1 g
F
P
p
.48818 .46194 m .50616 .45295 L .5 .4638 L 1 g
F
P
p
.002 w
.51408 .46162 m .51876 .46675 L p
.5 .4638 L 1 g
F P
s
P
p
.002 w
.52255 .46734 m .52282 .46778 L p
.51135 .46558 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47749 .46728 L p
1 g
F P
s
P
p
.48831 .46561 m .5 .46442 L .47749 .46728 L 1 g
F
P
p
.45826 .47608 m .47748 .4673 L .47059 .47067 L 1 g
F
P
p
.002 w
.47658 .46774 m .49711 .44304 L .50616 .45295 L p
1 g
F P
s
P
p
.002 w
.47749 .46728 m .47748 .4673 L p
.47727 .46739 L 1 g
F P
s
P
p
.002 w
.47658 .46774 m .47483 .46985 L .47372 .46914 L p
1 g
F P
s
P
p
.002 w
.47748 .4673 m .47718 .46778 L p
.47059 .47067 L 1 g
F P
s
P
p
.002 w
.49711 .44304 m .47658 .46774 L p
.44372 .45004 L 1 g
F P
s
P
p
.002 w
.47372 .46914 m .44372 .45004 L p
.47658 .46774 L 1 g
F P
s
P
p
.002 w
.42764 .48968 m .44372 .45004 L .47372 .46914 L p
1 g
F P
s
P
p
.002 w
.45783 .47655 m .45826 .47608 L p
.46796 .47183 L 1 g
F P
s
P
p
.42764 .48968 m .47372 .46914 L .44834 .48098 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45783 .47655 L p
1 g
F P
s
P
p
.46796 .47183 m .47718 .46778 L .45783 .47655 L 1 g
F
P
p
.002 w
.45783 .47655 m .45698 .47747 L p
.44872 .4854 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44265 .49128 L p
1 g
F P
s
P
p
.44872 .4854 m .45698 .47747 L .44265 .49128 L 1 g
F
P
p
.002 w
.47483 .46985 m .46211 .50056 L .44129 .49399 L p
1 g
F P
s
P
p
.002 w
.44129 .49399 m .46211 .50056 L p
.4258 .52681 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43418 .50905 L p
1 g
F P
s
P
p
.43768 .50165 m .44166 .49233 L .43418 .50905 L 1 g
F
P
p
.002 w
.43418 .50905 m .43287 .51061 L p
.43321 .52022 L 1 g
F P
s
P
p
.43247 .52879 m .46211 .50056 L .43274 .52991 L 1 g
F
P
p
.43151 .52486 m .4329 .52375 L .43247 .52879 L 1 g
F
P
p
.4329 .52375 m .46211 .50056 L .43247 .52879 L 1 g
F
P
p
.002 w
.42583 .52951 m .43274 .52991 L p
.43864 .54681 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43247 .52879 L p
1 g
F P
s
P
p
.43321 .52022 m .43287 .51061 L .43247 .52879 L 1 g
F
P
p
.002 w
.46211 .50056 m .46025 .53152 L .43274 .52991 L p
1 g
F P
s
P
p
.002 w
.43247 .52879 m .43239 .5289 L p
.43265 .52954 L 1 g
F P
s
P
p
.002 w
.43239 .5289 m .43146 .53025 L p
.43598 .53919 L 1 g
F P
s
P
p
.44449 .55472 m .43864 .54681 L .46025 .53152 L 1 g
F
P
p
.002 w
.43274 .52991 m .46025 .53152 L p
.43864 .54681 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43864 .54681 L p
1 g
F P
s
P
p
.43598 .53919 m .43146 .53025 L .43864 .54681 L 1 g
F
P
p
.002 w
.43743 .5491 m .43763 .54935 L p
.44564 .55627 L 1 g
F P
s
P
p
.45146 .56129 m .44557 .55617 L .44564 .55627 L 1 g
F
P
p
.44557 .55617 m .43743 .5491 L .44564 .55627 L 1 g
F
P
p
.44564 .55627 m .43763 .54935 L .45034 .56261 L 1 g
F
P
p
.44564 .55627 m .45034 .56261 L .45079 .56309 L 1 g
F
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.46025 .53152 m .46917 .55921 L .45034 .56261 L p
1 g
F P
s
P
p
.44449 .55472 m .46025 .53152 L .45034 .56261 L 1 g
F
P
p
.002 w
.45034 .56261 m .46917 .55921 L p
.46483 .57773 L 1 g
F P
s
P
p
.46144 .5922 m .45034 .56261 L .46483 .57773 L 1 g
F
P
p
.002 w
.43763 .54935 m .45002 .56518 L .45079 .56309 L p
1 g
F P
s
P
p
.002 w
.45079 .56309 m .45002 .56518 L p
.46154 .56978 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46841 .57406 L p
1 g
F P
s
P
p
.46154 .56978 m .45002 .56518 L .46841 .57406 L 1 g
F
P
p
.47881 .57777 m .47107 .57713 L .48732 .5808 L 1 g
F
P
p
.002 w
.46917 .55921 m .48755 .58069 L .48732 .5808 L p
1 g
F P
s
P
p
.002 w
.48902 .58113 m .48921 .57862 L p
.48809 .58097 L 1 g
F P
s
P
p
.5 .58303 m .48902 .58113 L .51092 .58031 L 1 g
F
P
p
.51313 .59388 m .48902 .58113 L .51357 .58538 L 1 g
F
P
p
.50036 .58071 m .48902 .58118 L .4963 .58152 L 1 g
F
P
p
.51079 .57862 m .48963 .58111 L .50036 .58071 L 1 g
F
P
p
.48963 .58111 m .48902 .58118 L .50036 .58071 L 1 g
F
P
p
.002 w
.51105 .5822 m .51079 .57862 L p
.4963 .58152 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48755 .58069 m .51466 .56435 L p
.51384 .5802 L 1 g
F P
s
P
p
.48902 .58113 m .48755 .58069 L .51384 .5802 L 1 g
F
P
p
.002 w
.48844 .58115 m .48809 .58097 L p
.48902 .58113 L 1 g
F P
s
P
p
.002 w
.48809 .58097 m .48755 .58069 L p
.48902 .58113 L 1 g
F P
s
P
p
.002 w
.49428 .60879 m .46144 .5922 L .48755 .58069 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .48902 .58118 L p
.48741 .58085 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .47287 .57834 L p
.48741 .58085 L 1 g
F P
s
P
p
.002 w
.47287 .57834 m .48889 .583 L p
.48741 .58085 L 1 g
F P
s
P
p
.002 w
.51092 .58031 m .51111 .583 L p
.52148 .57768 L 1 g
F P
s
P
p
.002 w
.48902 .58118 m .48902 .58113 L p
.48809 .58097 L 1 g
F P
s
P
p
.002 w
.48902 .58113 m .48902 .58118 L p
.48963 .58111 L 1 g
F P
s
P
p
.002 w
.48902 .58118 m .48889 .583 L p
.4963 .58152 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51105 .5822 L p
1 g
F P
s
P
p
.4963 .58152 m .48889 .583 L .51105 .5822 L 1 g
F
P
p
.47107 .57713 m .4678 .57686 L .48902 .58118 L 1 g
F
P
p
.002 w
.48755 .58069 m .48809 .58097 L p
.48759 .58086 L 1 g
F P
s
P
p
.002 w
.39179 .32112 m .34912 .37393 L .3367 .35905 L p
1 g
F P
s
P
p
.002 w
.3367 .35905 m .3797 .30565 L .39179 .32112 L p
1 g
F P
s
P
p
.002 w
.55277 .57634 m .57435 .57242 L .57415 .5919 L p
1 g
F P
s
P
p
.002 w
.57415 .5919 m .54303 .59766 L .55277 .57634 L p
1 g
F P
s
P
p
.002 w
.39391 .52452 m .40851 .5665 L .38293 .56404 L p
1 g
F P
s
P
p
.002 w
.38293 .56404 m .36605 .51683 L .39391 .52452 L p
1 g
F P
s
P
p
.002 w
.61173 .54711 m .62376 .52829 L .64534 .52837 L p
1 g
F P
s
P
p
.002 w
.65378 .49872 m .64534 .52837 L .62376 .52829 L p
1 g
F P
s
P
p
.002 w
.51308 .26461 m .44894 .28306 L .43741 .26725 L p
1 g
F P
s
P
p
.002 w
.3797 .30565 m .43741 .26725 L .44894 .28306 L p
1 g
F P
s
P
p
.002 w
.36771 .46336 m .36605 .51683 L .3429 .50682 L p
1 g
F P
s
P
p
.002 w
.3429 .50682 m .34429 .44896 L .36771 .46336 L p
1 g
F P
s
P
p
.002 w
.36655 .39104 m .34429 .44896 L .32616 .43445 L p
1 g
F P
s
P
p
.002 w
.32616 .43445 m .34912 .37393 L .36655 .39104 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.44894 .28306 m .39179 .32112 L .3797 .30565 L p
1 g
F P
s
P
p
.002 w
.65378 .49872 m .6522 .46946 L .67105 .45062 L p
1 g
F P
s
P
p
.002 w
.65635 .41742 m .67105 .45062 L .6522 .46946 L p
1 g
F P
s
P
p
.002 w
.67105 .45062 m .65635 .41742 L .66723 .39222 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.63592 .36187 m .66723 .39222 L .65635 .41742 L p
1 g
F P
s
P
p
.002 w
.66723 .39222 m .63592 .36187 L .63789 .33434 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51348 .44809 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.62376 .52829 m .62949 .50775 L .65378 .49872 L p
1 g
F P
s
P
p
.002 w
.6522 .46946 m .65378 .49872 L .62949 .50775 L p
1 g
F P
s
P
p
.002 w
.58998 .3145 m .63789 .33434 L .63592 .36187 L p
1 g
F P
s
P
p
.002 w
.63789 .33434 m .58998 .3145 L .58408 .28857 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.58408 .28857 m .52389 .28601 L .51308 .26461 L p
1 g
F P
s
P
p
.002 w
.44894 .28306 m .51308 .26461 L .52389 .28601 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52389 .28601 m .58408 .28857 L .58998 .3145 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.42567 .5295 m .43756 .56492 L .40851 .5665 L p
1 g
F P
s
P
p
.002 w
.40851 .5665 m .39391 .52452 L .42567 .5295 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.57229 .54796 m .58278 .54278 L .59469 .56233 L p
1 g
F P
s
P
p
.002 w
.59469 .56233 m .57435 .57242 L .57229 .54796 L p
1 g
F P
s
P
p
.002 w
.61173 .54711 m .59469 .56233 L .58278 .54278 L p
1 g
F P
s
P
p
.004 w
.59642 .5563 m
.6089 .57258 L
s
P
p
.002 w
.58278 .54278 m .59156 .53493 L .61173 .54711 L p
1 g
F P
s
P
p
.002 w
.62376 .52829 m .61173 .54711 L .59156 .53493 L p
1 g
F P
s
P
p
.002 w
.4076 .34046 m .36655 .39104 L .34912 .37393 L p
1 g
F P
s
P
p
.002 w
.34912 .37393 m .39179 .32112 L .4076 .34046 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.3958 .47711 m .39391 .52452 L .36605 .51683 L p
1 g
F P
s
P
p
.002 w
.36605 .51683 m .36771 .46336 L .3958 .47711 L p
1 g
F P
s
P
p
.002 w
.59156 .53493 m .59771 .52522 L .62376 .52829 L p
1 g
F P
s
P
p
.002 w
.62949 .50775 m .62376 .52829 L .59771 .52522 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.62949 .50775 m .62823 .48761 L .6522 .46946 L p
1 g
F P
s
P
p
.002 w
.64046 .44366 m .6522 .46946 L .62823 .48761 L p
1 g
F P
s
P
p
.002 w
.6522 .46946 m .64046 .44366 L .65635 .41742 L p
1 g
F P
s
P
p
.002 w
.62976 .39217 m .65635 .41742 L .64046 .44366 L p
1 g
F P
s
P
p
.002 w
.65635 .41742 m .62976 .39217 L .63592 .36187 L p
1 g
F P
s
P
p
.002 w
.3886 .40988 m .36771 .46336 L .34429 .44896 L p
1 g
F P
s
P
p
.002 w
.34429 .44896 m .36655 .39104 L .3886 .40988 L p
1 g
F P
s
P
p
.002 w
.52389 .28601 m .46242 .30391 L .44894 .28306 L p
1 g
F P
s
P
p
.002 w
.39179 .32112 m .44894 .28306 L .46242 .30391 L p
1 g
F P
s
P
p
.002 w
.46242 .30391 m .4076 .34046 L .39179 .32112 L p
1 g
F P
s
P
p
.002 w
.59328 .34465 m .63592 .36187 L .62976 .39217 L p
1 g
F P
s
P
p
.002 w
.63592 .36187 m .59328 .34465 L .58998 .3145 L p
1 g
F P
s
P
p
.002 w
.59771 .52522 m .60058 .51468 L .62949 .50775 L p
1 g
F P
s
P
p
.002 w
.62823 .48761 m .62949 .50775 L .60058 .51468 L p
1 g
F P
s
P
p
.002 w
.50225 .54946 m .51466 .56435 L .48755 .58069 L p
1 g
F P
s
P
p
.002 w
.48755 .58069 m .46917 .55921 L .50225 .54946 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.53428 .31248 m .58998 .3145 L .59328 .34465 L p
1 g
F P
s
P
p
.002 w
.58998 .3145 m .53428 .31248 L .52389 .28601 L p
1 g
F P
s
P
p
.002 w
.5418 .54361 m .55066 .54842 L .53215 .57359 L p
1 g
F P
s
P
p
.002 w
.53215 .57359 m .51466 .56435 L .5418 .54361 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46242 .30391 m .52389 .28601 L .53428 .31248 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.42764 .48968 m .42567 .5295 L .39391 .52452 L p
1 g
F P
s
P
p
.002 w
.39391 .52452 m .3958 .47711 L .42764 .48968 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.62823 .48761 m .61997 .47001 L .64046 .44366 L p
1 g
F P
s
P
p
.002 w
.61951 .42424 m .64046 .44366 L .61997 .47001 L p
1 g
F P
s
P
p
.002 w
.64046 .44366 m .61951 .42424 L .62976 .39217 L p
1 g
F P
s
P
p
.002 w
.60058 .51468 m .59983 .5044 L .62823 .48761 L p
1 g
F P
s
P
p
.002 w
.61997 .47001 m .62823 .48761 L .59983 .5044 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.58278 .54278 m .57229 .54796 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.59156 .53493 m .58278 .54278 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.42672 .36315 m .3886 .40988 L .36655 .39104 L p
1 g
F P
s
P
p
.002 w
.36655 .39104 m .4076 .34046 L .42672 .36315 L p
1 g
F P
s
P
p
.002 w
.59771 .52522 m .59156 .53493 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41462 .42979 m .3958 .47711 L .36771 .46336 L p
1 g
F P
s
P
p
.002 w
.36771 .46336 m .3886 .40988 L .41462 .42979 L p
1 g
F P
s
P
p
.002 w
.60058 .51468 m .59771 .52522 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.59378 .37808 m .62976 .39217 L .61951 .42424 L p
1 g
F P
s
P
p
.002 w
.62976 .39217 m .59378 .37808 L .59328 .34465 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5356 .53596 m .5418 .54361 L .51466 .56435 L p
1 g
F P
s
P
p
.002 w
.51466 .56435 m .50225 .54946 L .5356 .53596 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.4964 .53044 m .50225 .54946 L .46917 .55921 L p
1 g
F P
s
P
p
.002 w
.46917 .55921 m .46025 .53152 L .4964 .53044 L p
1 g
F P
s
P
p
.002 w
.53428 .31248 m .47746 .32926 L .46242 .30391 L p
1 g
F P
s
P
p
.002 w
.4076 .34046 m .46242 .30391 L .47746 .32926 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59983 .5044 m .60058 .51468 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.47746 .32926 m .42672 .36315 L .4076 .34046 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.54387 .34323 m .59328 .34465 L .59378 .37808 L p
1 g
F P
s
P
p
.002 w
.59328 .34465 m .54387 .34323 L .53428 .31248 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59983 .5044 m .59551 .4955 L .61997 .47001 L p
1 g
F P
s
P
p
.002 w
.60544 .45691 m .61997 .47001 L .59551 .4955 L p
1 g
F P
s
P
p
.002 w
.61997 .47001 m .60544 .45691 L .61951 .42424 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.59551 .4955 m .59983 .5044 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.47746 .32926 m .53428 .31248 L .54387 .34323 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59137 .41359 m .61951 .42424 L .60544 .45691 L p
1 g
F P
s
P
p
.002 w
.61951 .42424 m .59137 .41359 L .59378 .37808 L p
1 g
F P
s
P
p
.002 w
.53276 .52626 m .5356 .53596 L .50225 .54946 L p
1 g
F P
s
P
p
.002 w
.50225 .54946 m .4964 .53044 L .53276 .52626 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.58804 .48895 m .59551 .4955 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.57821 .48551 m .58804 .48895 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.56707 .48557 m .57821 .48551 L .56795 .51916 L closepath p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59551 .4955 m .58804 .48895 L .60544 .45691 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44372 .45004 m .42764 .48968 L .3958 .47711 L p
1 g
F P
s
P
p
.002 w
.3958 .47711 m .41462 .42979 L .44372 .45004 L p
1 g
F P
s
P
p
.002 w
.44856 .38844 m .41462 .42979 L .3886 .40988 L p
1 g
F P
s
P
p
.004 w
.43304 .40735 m
.5 .43051 L
s
P
p
.002 w
.3886 .40988 m .42672 .36315 L .44856 .38844 L p
1 g
F P
s
P
p
.004 w
.40062 .39614 m
.4079 .39866 L
s
P
p
.004 w
.35132 .37908 m
.40062 .39614 L
s
P
p
.004 w
.4079 .39866 m
.40865 .39892 L
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.58612 .44986 m .60544 .45691 L .58804 .48895 L p
1 g
F P
s
P
p
.002 w
.60544 .45691 m .58612 .44986 L .59137 .41359 L p
1 g
F P
s
P
p
.002 w
.4979 .5093 m .4964 .53044 L .46025 .53152 L p
1 g
F P
s
P
p
.002 w
.46025 .53152 m .46211 .50056 L .4979 .5093 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.55226 .37723 m .59378 .37808 L .59137 .41359 L p
1 g
F P
s
P
p
.002 w
.59378 .37808 m .55226 .37723 L .54387 .34323 L p
1 g
F P
s
P
p
.002 w
.58804 .48895 m .57821 .48551 L .58612 .44986 L p
1 g
F P
s
P
p
.002 w
.54387 .34323 m .49353 .35834 L .47746 .32926 L p
1 g
F P
s
P
p
.002 w
.42672 .36315 m .47746 .32926 L .49353 .35834 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53364 .51557 m .53276 .52626 L .4964 .53044 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4964 .53044 m .4979 .5093 L .53364 .51557 L p
1 g
F P
s
P
p
.002 w
.49353 .35834 m .44856 .38844 L .42672 .36315 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49353 .35834 m .54387 .34323 L .55226 .37723 L p
1 g
F P
s
P
p
.002 w
.57821 .48551 m .56707 .48557 L .56409 .44981 L p
1 g
F P
s
P
p
.002 w
.56409 .44981 m .58612 .44986 L .57821 .48551 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.55909 .41322 m .59137 .41359 L .58612 .44986 L p
1 g
F P
s
P
p
.002 w
.59137 .41359 m .55909 .41322 L .55226 .37723 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.53817 .50507 m .53364 .51557 L .4979 .5093 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.58612 .44986 m .56409 .44981 L .55909 .41322 L p
1 g
F P
s
P
p
.002 w
.56707 .48557 m .55587 .48918 L .54184 .45685 L p
1 g
F P
s
P
p
.002 w
.54184 .45685 m .56409 .44981 L .56707 .48557 L p
1 g
F P
s
P
p
.002 w
.47232 .41542 m .44372 .45004 L .41462 .42979 L p
1 g
F P
s
P
p
.002 w
.41462 .42979 m .44856 .38844 L .47232 .41542 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.54586 .49593 m .53817 .50507 L .50672 .48843 L p
1 g
F P
s
P
p
.002 w
.4979 .5093 m .50672 .48843 L .53817 .50507 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.50672 .48843 m .52195 .47023 L .54586 .49593 L p
1 g
F P
s
P
p
.002 w
.50672 .48843 m .4979 .5093 L .46211 .50056 L p
1 g
F P
s
P
p
.002 w
.46211 .50056 m .47483 .46985 L .50672 .48843 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51005 .39012 m .55226 .37723 L .55909 .41322 L p
1 g
F P
s
P
p
.002 w
.55226 .37723 m .51005 .39012 L .49353 .35834 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.44856 .38844 m .49353 .35834 L .51005 .39012 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.56409 .44981 m .54184 .45685 L .52637 .42339 L p
1 g
F P
s
P
p
.002 w
.52637 .42339 m .55909 .41322 L .56409 .44981 L p
1 g
F P
s
P
p
.002 w
.51005 .39012 m .47232 .41542 L .44856 .38844 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.55909 .41322 m .52637 .42339 L .51005 .39012 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.44372 .45004 m .47232 .41542 L .49711 .44304 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52195 .47023 m .50672 .48843 L .47483 .46985 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49711 .44304 m .52637 .42339 L .54184 .45685 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.47232 .41542 m .51005 .39012 L .52637 .42339 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52637 .42339 m .49711 .44304 L .47232 .41542 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59049 .54856 m
.59642 .5563 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .35132 .37908 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .6089 .57258 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.130233)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.130233)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46716 .47124 m .50705 .45892 L .49515 .43302 L p
1 g
F P
s
P
p
.002 w
.49515 .43302 m .46189 .44319 L .46716 .47124 L p
1 g
F P
s
P
p
.002 w
.52476 .41449 m .49515 .43302 L .50705 .45892 L p
1 g
F P
s
P
p
.002 w
.46189 .44319 m .49515 .43302 L .48336 .40705 L p
1 g
F P
s
P
p
.002 w
.49515 .43302 m .52476 .41449 L .50632 .39265 L p
1 g
F P
s
P
p
.002 w
.50632 .39265 m .48336 .40705 L .49515 .43302 L p
1 g
F P
s
P
p
.002 w
.48336 .40705 m .45754 .41489 L .46189 .44319 L p
1 g
F P
s
P
p
.002 w
.45754 .41489 m .48336 .40705 L .47191 .3815 L p
1 g
F P
s
P
p
.002 w
.48336 .40705 m .50632 .39265 L .48763 .3716 L p
1 g
F P
s
P
p
.002 w
.48763 .3716 m .47191 .3815 L .48336 .40705 L p
1 g
F P
s
P
p
.002 w
.47328 .4985 m .51886 .4843 L .50705 .45892 L p
1 g
F P
s
P
p
.002 w
.50705 .45892 m .46716 .47124 L .47328 .4985 L p
1 g
F P
s
P
p
.002 w
.54261 .43673 m .50705 .45892 L .51886 .4843 L p
1 g
F P
s
P
p
.002 w
.50705 .45892 m .54261 .43673 L .52476 .41449 L p
1 g
F P
s
P
p
.002 w
.54788 .38933 m .52476 .41449 L .54261 .43673 L p
1 g
F P
s
P
p
.002 w
.52476 .41449 m .54788 .38933 L .52415 .37305 L p
1 g
F P
s
P
p
.002 w
.52415 .37305 m .50632 .39265 L .52476 .41449 L p
1 g
F P
s
P
p
.002 w
.50632 .39265 m .52415 .37305 L .49976 .35813 L p
1 g
F P
s
P
p
.002 w
.49976 .35813 m .48763 .3716 L .50632 .39265 L p
1 g
F P
s
P
p
.002 w
.42661 .47243 m .46716 .47124 L .46189 .44319 L p
1 g
F P
s
P
p
.002 w
.46189 .44319 m .42811 .44397 L .42661 .47243 L p
1 g
F P
s
P
p
.002 w
.42811 .44397 m .46189 .44319 L .45754 .41489 L p
1 g
F P
s
P
p
.002 w
.51886 .4843 m .55956 .45898 L .54261 .43673 L p
1 g
F P
s
P
p
.002 w
.57053 .40667 m .54261 .43673 L .55956 .45898 L p
1 g
F P
s
P
p
.002 w
.54261 .43673 m .57053 .40667 L .54788 .38933 L p
1 g
F P
s
P
p
.002 w
.45754 .41489 m .43136 .41532 L .42811 .44397 L p
1 g
F P
s
P
p
.002 w
.43136 .41532 m .45754 .41489 L .4542 .38682 L p
1 g
F P
s
P
p
.002 w
.47191 .3815 m .4542 .38682 L .45754 .41489 L p
1 g
F P
s
P
p
.002 w
.42689 .50015 m .47328 .4985 L .46716 .47124 L p
1 g
F P
s
P
p
.002 w
.46716 .47124 m .42661 .47243 L .42689 .50015 L p
1 g
F P
s
P
p
.002 w
.4542 .38682 m .47191 .3815 L .46099 .35682 L p
1 g
F P
s
P
p
.002 w
.47191 .3815 m .48763 .3716 L .46902 .35176 L p
1 g
F P
s
P
p
.002 w
.46902 .35176 m .46099 .35682 L .47191 .3815 L p
1 g
F P
s
P
p
.002 w
.48014 .52446 m .53036 .50869 L .51886 .4843 L p
1 g
F P
s
P
p
.002 w
.51886 .4843 m .47328 .4985 L .48014 .52446 L p
1 g
F P
s
P
p
.002 w
.55956 .45898 m .51886 .4843 L .53036 .50869 L p
1 g
F P
s
P
p
.002 w
.48763 .3716 m .49976 .35813 L .47517 .34485 L p
1 g
F P
s
P
p
.002 w
.47517 .34485 m .46902 .35176 L .48763 .3716 L p
1 g
F P
s
P
p
.002 w
.53499 .35014 m .52415 .37305 L .54788 .38933 L p
1 g
F P
s
P
p
.002 w
.52415 .37305 m .53499 .35014 L .50703 .34241 L p
1 g
F P
s
P
p
.002 w
.50703 .34241 m .49976 .35813 L .52415 .37305 L p
1 g
F P
s
P
p
.002 w
.56216 .35986 m .54788 .38933 L .57053 .40667 L p
1 g
F P
s
P
p
.002 w
.54788 .38933 m .56216 .35986 L .53499 .35014 L p
1 g
F P
s
P
p
.002 w
.4542 .38682 m .43629 .38701 L .43136 .41532 L p
1 g
F P
s
P
p
.002 w
.43629 .38701 m .4542 .38682 L .45195 .35952 L p
1 g
F P
s
P
p
.002 w
.46099 .35682 m .45195 .35952 L .4542 .38682 L p
1 g
F P
s
P
p
.002 w
.53036 .50869 m .57526 .48083 L .55956 .45898 L p
1 g
F P
s
P
p
.002 w
.59167 .42475 m .55956 .45898 L .57526 .48083 L p
1 g
F P
s
P
p
.002 w
.55956 .45898 m .59167 .42475 L .57053 .40667 L p
1 g
F P
s
P
p
.002 w
.39712 .43507 m .42811 .44397 L .43136 .41532 L p
1 g
F P
s
P
p
.002 w
.43136 .41532 m .40746 .40819 L .39712 .43507 L p
1 g
F P
s
P
p
.002 w
.40746 .40819 m .43136 .41532 L .43629 .38701 L p
1 g
F P
s
P
p
.002 w
.49976 .35813 m .50703 .34241 L .4788 .33683 L p
1 g
F P
s
P
p
.002 w
.4788 .33683 m .47517 .34485 L .49976 .35813 L p
1 g
F P
s
P
p
.002 w
.42899 .52658 m .48014 .52446 L .47328 .4985 L p
1 g
F P
s
P
p
.002 w
.47328 .4985 m .42689 .50015 L .42899 .52658 L p
1 g
F P
s
P
p
.002 w
.38923 .46208 m .42661 .47243 L .42811 .44397 L p
1 g
F P
s
P
p
.002 w
.42811 .44397 m .39712 .43507 L .38923 .46208 L p
1 g
F P
s
P
p
.002 w
.58801 .37139 m .57053 .40667 L .59167 .42475 L p
1 g
F P
s
P
p
.002 w
.57053 .40667 m .58801 .37139 L .56216 .35986 L p
1 g
F P
s
P
p
.002 w
.43629 .38701 m .42002 .38198 L .40746 .40819 L p
1 g
F P
s
P
p
.002 w
.42002 .38198 m .43629 .38701 L .44282 .35955 L p
1 g
F P
s
P
p
.002 w
.45195 .35952 m .44282 .35955 L .43629 .38701 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .45195 .35952 L .46099 .35682 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .46099 .35682 L .46902 .35176 L closepath p
1 g
F P
s
P
p
.002 w
.48763 .54859 m .54132 .5316 L .53036 .50869 L p
1 g
F P
s
P
p
.002 w
.53036 .50869 m .48014 .52446 L .48763 .54859 L p
1 g
F P
s
P
p
.002 w
.57526 .48083 m .53036 .50869 L .54132 .5316 L p
1 g
F P
s
P
p
.002 w
.384 .48871 m .42689 .50015 L .42661 .47243 L p
1 g
F P
s
P
p
.002 w
.42661 .47243 m .38923 .46208 L .384 .48871 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .46902 .35176 L .47517 .34485 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .44282 .35955 L .45195 .35952 L closepath p
1 g
F P
s
P
p
.002 w
.5376 .32618 m .53499 .35014 L .56216 .35986 L p
1 g
F P
s
P
p
.002 w
.53499 .35014 m .5376 .32618 L .50861 .32606 L p
1 g
F P
s
P
p
.002 w
.50861 .32606 m .50703 .34241 L .53499 .35014 L p
1 g
F P
s
P
p
.002 w
.50703 .34241 m .50861 .32606 L .4795 .32852 L p
1 g
F P
s
P
p
.002 w
.4795 .32852 m .4788 .33683 L .50703 .34241 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .47517 .34485 L .4788 .33683 L closepath p
1 g
F P
s
P
p
.002 w
.54132 .5316 m .5894 .50184 L .57526 .48083 L p
1 g
F P
s
P
p
.002 w
.61085 .44325 m .57526 .48083 L .5894 .50184 L p
1 g
F P
s
P
p
.002 w
.57526 .48083 m .61085 .44325 L .59167 .42475 L p
1 g
F P
s
P
p
.002 w
.44282 .35955 m .43457 .35692 L .42002 .38198 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .43457 .35692 L .44282 .35955 L closepath p
1 g
F P
s
P
p
.002 w
.61201 .38455 m .59167 .42475 L .61085 .44325 L p
1 g
F P
s
P
p
.002 w
.59167 .42475 m .61201 .38455 L .58801 .37139 L p
1 g
F P
s
P
p
.002 w
.38834 .39404 m .40746 .40819 L .42002 .38198 L p
1 g
F P
s
P
p
.002 w
.42002 .38198 m .40712 .37217 L .38834 .39404 L p
1 g
F P
s
P
p
.002 w
.40712 .37217 m .42002 .38198 L .43457 .35692 L p
1 g
F P
s
P
p
.002 w
.5659 .32889 m .56216 .35986 L .58801 .37139 L p
1 g
F P
s
P
p
.002 w
.56216 .35986 m .5659 .32889 L .5376 .32618 L p
1 g
F P
s
P
p
.002 w
.37214 .41706 m .39712 .43507 L .40746 .40819 L p
1 g
F P
s
P
p
.002 w
.40746 .40819 m .38834 .39404 L .37214 .41706 L p
1 g
F P
s
P
p
.002 w
.43293 .55116 m .48763 .54859 L .48014 .52446 L p
1 g
F P
s
P
p
.002 w
.48014 .52446 m .42899 .52658 L .43293 .55116 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .4788 .33683 L .4795 .32852 L closepath p
1 g
F P
s
P
p
.002 w
.43457 .35692 m .4281 .35186 L .40712 .37217 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .4281 .35186 L .43457 .35692 L closepath p
1 g
F P
s
P
p
.002 w
.3816 .51439 m .42899 .52658 L .42689 .50015 L p
1 g
F P
s
P
p
.002 w
.42689 .50015 m .384 .48871 L .3816 .51439 L p
1 g
F P
s
P
p
.002 w
.35891 .44077 m .38923 .46208 L .39712 .43507 L p
1 g
F P
s
P
p
.002 w
.39712 .43507 m .37214 .41706 L .35891 .44077 L p
1 g
F P
s
P
p
.002 w
.47716 .32082 m .4795 .32852 L .50861 .32606 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .4795 .32852 L .47716 .32082 L closepath p
1 g
F P
s
P
p
.002 w
.5042 .31079 m .50861 .32606 L .5376 .32618 L p
1 g
F P
s
P
p
.002 w
.50861 .32606 m .5042 .31079 L .47716 .32082 L p
1 g
F P
s
P
p
.002 w
.59294 .33418 m .58801 .37139 L .61201 .38455 L p
1 g
F P
s
P
p
.002 w
.58801 .37139 m .59294 .33418 L .5659 .32889 L p
1 g
F P
s
P
p
.002 w
.39904 .35853 m .40712 .37217 L .4281 .35186 L p
1 g
F P
s
P
p
.002 w
.4281 .35186 m .42411 .3449 L .39904 .35853 L p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .42411 .3449 L .4281 .35186 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .43007 .32061 L .42512 .32837 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .42512 .32837 L .42307 .33678 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .42307 .33678 L .42411 .3449 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .47716 .32082 L .47201 .31457 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .47201 .31457 L .46457 .31048 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .46457 .31048 L .45565 .30901 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .45565 .30901 L .44624 .31035 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .44624 .31035 L .43738 .31437 L closepath p
1 g
F P
s
P
p
.002 w
.45084 .3335 m .43738 .31437 L .43007 .32061 L closepath p
1 g
F P
s
P
p
.002 w
.49561 .57036 m .55151 .55253 L .54132 .5316 L p
1 g
F P
s
P
p
.002 w
.54132 .5316 m .48763 .54859 L .49561 .57036 L p
1 g
F P
s
P
p
.002 w
.5894 .50184 m .54132 .5316 L .55151 .55253 L p
1 g
F P
s
P
p
.002 w
.37618 .37414 m .38834 .39404 L .40712 .37217 L p
1 g
F P
s
P
p
.002 w
.40712 .37217 m .39904 .35853 L .37618 .37414 L p
1 g
F P
s
P
p
.002 w
.53144 .30365 m .5376 .32618 L .5659 .32889 L p
1 g
F P
s
P
p
.002 w
.5376 .32618 m .53144 .30365 L .5042 .31079 L p
1 g
F P
s
P
p
.002 w
.5894 .50184 m .62766 .46182 L .61085 .44325 L p
1 g
F P
s
P
p
.002 w
.63364 .39911 m .61085 .44325 L .62766 .46182 L p
1 g
F P
s
P
p
.002 w
.61085 .44325 m .63364 .39911 L .61201 .38455 L p
1 g
F P
s
P
p
.002 w
.47201 .31457 m .47716 .32082 L .5042 .31079 L p
1 g
F P
s
P
p
.002 w
.55151 .55253 m .60165 .52159 L .5894 .50184 L p
1 g
F P
s
P
p
.002 w
.62766 .46182 m .5894 .50184 L .60165 .52159 L p
1 g
F P
s
P
p
.002 w
.39678 .34246 m .39904 .35853 L .42411 .3449 L p
1 g
F P
s
P
p
.002 w
.42411 .3449 m .42307 .33678 L .39678 .34246 L p
1 g
F P
s
P
p
.002 w
.34901 .46471 m .384 .48871 L .38923 .46208 L p
1 g
F P
s
P
p
.002 w
.38923 .46208 m .35891 .44077 L .34901 .46471 L p
1 g
F P
s
P
p
.002 w
.35604 .39147 m .37214 .41706 L .38834 .39404 L p
1 g
F P
s
P
p
.002 w
.38834 .39404 m .37618 .37414 L .35604 .39147 L p
1 g
F P
s
P
p
.002 w
.43868 .57332 m .49561 .57036 L .48763 .54859 L p
1 g
F P
s
P
p
.002 w
.48763 .54859 m .43293 .55116 L .43868 .57332 L p
1 g
F P
s
P
p
.002 w
.5042 .31079 m .49417 .29829 L .47201 .31457 L p
1 g
F P
s
P
p
.002 w
.46457 .31048 m .47201 .31457 L .49417 .29829 L p
1 g
F P
s
P
p
.002 w
.38217 .53855 m .43293 .55116 L .42899 .52658 L p
1 g
F P
s
P
p
.002 w
.42899 .52658 m .3816 .51439 L .38217 .53855 L p
1 g
F P
s
P
p
.002 w
.49417 .29829 m .5042 .31079 L .53144 .30365 L p
1 g
F P
s
P
p
.002 w
.61812 .34202 m .61201 .38455 L .63364 .39911 L p
1 g
F P
s
P
p
.002 w
.61201 .38455 m .61812 .34202 L .59294 .33418 L p
1 g
F P
s
P
p
.002 w
.5583 .29959 m .5659 .32889 L .59294 .33418 L p
1 g
F P
s
P
p
.002 w
.5659 .32889 m .5583 .29959 L .53144 .30365 L p
1 g
F P
s
P
p
.002 w
.40071 .3257 m .39678 .34246 L .42307 .33678 L p
1 g
F P
s
P
p
.002 w
.42307 .33678 m .42512 .32837 L .40071 .3257 L p
1 g
F P
s
P
p
.002 w
.37256 .35049 m .37618 .37414 L .39904 .35853 L p
1 g
F P
s
P
p
.002 w
.39904 .35853 m .39678 .34246 L .37256 .35049 L p
1 g
F P
s
P
p
.002 w
.49417 .29829 m .47948 .29 L .46457 .31048 L p
1 g
F P
s
P
p
.002 w
.45565 .30901 m .46457 .31048 L .47948 .29 L p
1 g
F P
s
P
p
.002 w
.4105 .31016 m .40071 .3257 L .42512 .32837 L p
1 g
F P
s
P
p
.002 w
.42512 .32837 m .43007 .32061 L .4105 .31016 L p
1 g
F P
s
P
p
.002 w
.33915 .41019 m .35891 .44077 L .37214 .41706 L p
1 g
F P
s
P
p
.002 w
.37214 .41706 m .35604 .39147 L .33915 .41019 L p
1 g
F P
s
P
p
.002 w
.47948 .29 m .46172 .28696 L .45565 .30901 L p
1 g
F P
s
P
p
.002 w
.44624 .31035 m .45565 .30901 L .46172 .28696 L p
1 g
F P
s
P
p
.002 w
.34276 .48834 m .3816 .51439 L .384 .48871 L p
1 g
F P
s
P
p
.002 w
.384 .48871 m .34901 .46471 L .34276 .48834 L p
1 g
F P
s
P
p
.002 w
.42511 .29763 m .4105 .31016 L .43007 .32061 L p
1 g
F P
s
P
p
.002 w
.43007 .32061 m .43738 .31437 L .42511 .29763 L p
1 g
F P
s
P
p
.002 w
.51688 .28505 m .53144 .30365 L .5583 .29959 L p
1 g
F P
s
P
p
.002 w
.53144 .30365 m .51688 .28505 L .49417 .29829 L p
1 g
F P
s
P
p
.002 w
.60165 .52159 m .64166 .48007 L .62766 .46182 L p
1 g
F P
s
P
p
.002 w
.65237 .41481 m .62766 .46182 L .64166 .48007 L p
1 g
F P
s
P
p
.002 w
.62766 .46182 m .65237 .41481 L .63364 .39911 L p
1 g
F P
s
P
p
.002 w
.46172 .28696 m .44287 .28958 L .44624 .31035 L p
1 g
F P
s
P
p
.002 w
.43738 .31437 m .44624 .31035 L .44287 .28958 L p
1 g
F P
s
P
p
.002 w
.44287 .28958 m .42511 .29763 L .43738 .31437 L p
1 g
F P
s
P
p
.002 w
.47948 .29 m .49417 .29829 L .51688 .28505 L p
1 g
F P
s
P
p
.002 w
.50395 .5892 m .5607 .57099 L .55151 .55253 L p
1 g
F P
s
P
p
.002 w
.55151 .55253 m .49561 .57036 L .50395 .5892 L p
1 g
F P
s
P
p
.002 w
.60165 .52159 m .55151 .55253 L .5607 .57099 L p
1 g
F P
s
P
p
.002 w
.58423 .2988 m .59294 .33418 L .61812 .34202 L p
1 g
F P
s
P
p
.002 w
.59294 .33418 m .58423 .2988 L .5583 .29959 L p
1 g
F P
s
P
p
.002 w
.37817 .32565 m .37256 .35049 L .39678 .34246 L p
1 g
F P
s
P
p
.002 w
.39678 .34246 m .40071 .3257 L .37817 .32565 L p
1 g
F P
s
P
p
.002 w
.35102 .36079 m .35604 .39147 L .37618 .37414 L p
1 g
F P
s
P
p
.002 w
.37618 .37414 m .37256 .35049 L .35102 .36079 L p
1 g
F P
s
P
p
.002 w
.5607 .57099 m .61167 .5396 L .60165 .52159 L p
1 g
F P
s
P
p
.002 w
.64166 .48007 m .60165 .52159 L .61167 .5396 L p
1 g
F P
s
P
p
.002 w
.64085 .3523 m .63364 .39911 L .65237 .41481 L p
1 g
F P
s
P
p
.002 w
.63364 .39911 m .64085 .3523 L .61812 .34202 L p
1 g
F P
s
P
p
.002 w
.38583 .56058 m .43868 .57332 L .43293 .55116 L p
1 g
F P
s
P
p
.002 w
.43293 .55116 m .38217 .53855 L .38583 .56058 L p
1 g
F P
s
P
p
.002 w
.4462 .59245 m .50395 .5892 L .49561 .57036 L p
1 g
F P
s
P
p
.002 w
.49561 .57036 m .43868 .57332 L .4462 .59245 L p
1 g
F P
s
P
p
.002 w
.32601 .42992 m .34901 .46471 L .35891 .44077 L p
1 g
F P
s
P
p
.002 w
.35891 .44077 m .33915 .41019 L .32601 .42992 L p
1 g
F P
s
P
p
.002 w
.51688 .28505 m .49529 .2726 L .47948 .29 L p
1 g
F P
s
P
p
.002 w
.46172 .28696 m .47948 .29 L .49529 .2726 L p
1 g
F P
s
P
p
.002 w
.53969 .27523 m .5583 .29959 L .58423 .2988 L p
1 g
F P
s
P
p
.002 w
.5583 .29959 m .53969 .27523 L .51688 .28505 L p
1 g
F P
s
P
p
.002 w
.39262 .30247 m .37817 .32565 L .40071 .3257 L p
1 g
F P
s
P
p
.002 w
.40071 .3257 m .4105 .31016 L .39262 .30247 L p
1 g
F P
s
P
p
.002 w
.34047 .51113 m .38217 .53855 L .3816 .51439 L p
1 g
F P
s
P
p
.002 w
.3816 .51439 m .34276 .48834 L .34047 .51113 L p
1 g
F P
s
P
p
.002 w
.49529 .2726 m .51688 .28505 L .53969 .27523 L p
1 g
F P
s
P
p
.002 w
.6086 .30139 m .61812 .34202 L .64085 .3523 L p
1 g
F P
s
P
p
.002 w
.61812 .34202 m .6086 .30139 L .58423 .2988 L p
1 g
F P
s
P
p
.002 w
.49529 .2726 m .46895 .26793 L .46172 .28696 L p
1 g
F P
s
P
p
.002 w
.44287 .28958 m .46172 .28696 L .46895 .26793 L p
1 g
F P
s
P
p
.002 w
.33274 .37321 m .33915 .41019 L .35604 .39147 L p
1 g
F P
s
P
p
.002 w
.35604 .39147 m .35102 .36079 L .33274 .37321 L p
1 g
F P
s
P
p
.002 w
.41436 .28375 m .39262 .30247 L .4105 .31016 L p
1 g
F P
s
P
p
.002 w
.4105 .31016 m .42511 .29763 L .41436 .28375 L p
1 g
F P
s
P
p
.002 w
.61167 .5396 m .65244 .4976 L .64166 .48007 L p
1 g
F P
s
P
p
.002 w
.66769 .43135 m .64166 .48007 L .65244 .4976 L p
1 g
F P
s
P
p
.002 w
.64166 .48007 m .66769 .43135 L .65237 .41481 L p
1 g
F P
s
P
p
.002 w
.35811 .32833 m .35102 .36079 L .37256 .35049 L p
1 g
F P
s
P
p
.002 w
.37256 .35049 m .37817 .32565 L .35811 .32833 L p
1 g
F P
s
P
p
.002 w
.46895 .26793 m .44086 .27176 L .44287 .28958 L p
1 g
F P
s
P
p
.002 w
.42511 .29763 m .44287 .28958 L .44086 .27176 L p
1 g
F P
s
P
p
.002 w
.44086 .27176 m .41436 .28375 L .42511 .29763 L p
1 g
F P
s
P
p
.002 w
.51247 .60455 m .56863 .58644 L .5607 .57099 L p
1 g
F P
s
P
p
.002 w
.5607 .57099 m .50395 .5892 L .51247 .60455 L p
1 g
F P
s
P
p
.002 w
.61167 .5396 m .5607 .57099 L .56863 .58644 L p
1 g
F P
s
P
p
.002 w
.66053 .3649 m .65237 .41481 L .66769 .43135 L p
1 g
F P
s
P
p
.002 w
.65237 .41481 m .66053 .3649 L .64085 .3523 L p
1 g
F P
s
P
p
.002 w
.31707 .45026 m .34276 .48834 L .34901 .46471 L p
1 g
F P
s
P
p
.002 w
.34901 .46471 m .32601 .42992 L .31707 .45026 L p
1 g
F P
s
P
p
.002 w
.39261 .57988 m .4462 .59245 L .43868 .57332 L p
1 g
F P
s
P
p
.002 w
.43868 .57332 m .38583 .56058 L .39261 .57988 L p
1 g
F P
s
P
p
.002 w
.56863 .58644 m .61913 .5554 L .61167 .5396 L p
1 g
F P
s
P
p
.002 w
.65244 .4976 m .61167 .5396 L .61913 .5554 L p
1 g
F P
s
P
p
.002 w
.56208 .26918 m .58423 .2988 L .6086 .30139 L p
1 g
F P
s
P
p
.002 w
.58423 .2988 m .56208 .26918 L .53969 .27523 L p
1 g
F P
s
P
p
.002 w
.53969 .27523 m .5117 .25878 L .49529 .2726 L p
1 g
F P
s
P
p
.002 w
.46895 .26793 m .49529 .2726 L .5117 .25878 L p
1 g
F P
s
P
p
.002 w
.4554 .60798 m .51247 .60455 L .50395 .5892 L p
1 g
F P
s
P
p
.002 w
.50395 .5892 m .4462 .59245 L .4554 .60798 L p
1 g
F P
s
P
p
.002 w
.34235 .53247 m .38583 .56058 L .38217 .53855 L p
1 g
F P
s
P
p
.002 w
.38217 .53855 m .34047 .51113 L .34235 .53247 L p
1 g
F P
s
P
p
.002 w
.5117 .25878 m .53969 .27523 L .56208 .26918 L p
1 g
F P
s
P
p
.002 w
.37692 .29788 m .35811 .32833 L .37817 .32565 L p
1 g
F P
s
P
p
.002 w
.37817 .32565 m .39262 .30247 L .37692 .29788 L p
1 g
F P
s
P
p
.002 w
.63081 .30744 m .64085 .3523 L .66053 .3649 L p
1 g
F P
s
P
p
.002 w
.64085 .3523 m .63081 .30744 L .6086 .30139 L p
1 g
F P
s
P
p
.002 w
.31831 .38755 m .32601 .42992 L .33915 .41019 L p
1 g
F P
s
P
p
.002 w
.33915 .41019 m .33274 .37321 L .31831 .38755 L p
1 g
F P
s
P
p
.002 w
.3411 .33381 m .33274 .37321 L .35102 .36079 L p
1 g
F P
s
P
p
.002 w
.35102 .36079 m .35811 .32833 L .3411 .33381 L p
1 g
F P
s
P
p
.002 w
.5117 .25878 m .47725 .2525 L .46895 .26793 L p
1 g
F P
s
P
p
.002 w
.44086 .27176 m .46895 .26793 L .47725 .2525 L p
1 g
F P
s
P
p
.002 w
.61913 .5554 m .65958 .51398 L .65244 .4976 L p
1 g
F P
s
P
p
.002 w
.67909 .44838 m .65244 .4976 L .65958 .51398 L p
1 g
F P
s
P
p
.002 w
.65244 .4976 m .67909 .44838 L .66769 .43135 L p
1 g
F P
s
P
p
.002 w
.40546 .27322 m .37692 .29788 L .39262 .30247 L p
1 g
F P
s
P
p
.002 w
.39262 .30247 m .41436 .28375 L .40546 .27322 L p
1 g
F P
s
P
p
.002 w
.31276 .47073 m .34047 .51113 L .34276 .48834 L p
1 g
F P
s
P
p
.002 w
.34276 .48834 m .31707 .45026 L .31276 .47073 L p
1 g
F P
s
P
p
.002 w
.67655 .37961 m .66769 .43135 L .67909 .44838 L p
1 g
F P
s
P
p
.002 w
.66769 .43135 m .67655 .37961 L .66053 .3649 L p
1 g
F P
s
P
p
.002 w
.58352 .26721 m .6086 .30139 L .63081 .30744 L p
1 g
F P
s
P
p
.002 w
.6086 .30139 m .58352 .26721 L .56208 .26918 L p
1 g
F P
s
P
p
.002 w
.47725 .2525 m .44034 .25745 L .44086 .27176 L p
1 g
F P
s
P
p
.002 w
.41436 .28375 m .44086 .27176 L .44034 .25745 L p
1 g
F P
s
P
p
.002 w
.44034 .25745 m .40546 .27322 L .41436 .28375 L p
1 g
F P
s
P
p
.002 w
.52098 .61587 m .57505 .59836 L .56863 .58644 L p
1 g
F P
s
P
p
.002 w
.56863 .58644 m .51247 .60455 L .52098 .61587 L p
1 g
F P
s
P
p
.002 w
.61913 .5554 m .56863 .58644 L .57505 .59836 L p
1 g
F P
s
P
p
.002 w
.40252 .59584 m .4554 .60798 L .4462 .59245 L p
1 g
F P
s
P
p
.002 w
.4462 .59245 m .39261 .57988 L .40252 .59584 L p
1 g
F P
s
P
p
.002 w
.56208 .26918 m .52834 .24904 L .5117 .25878 L p
1 g
F P
s
P
p
.002 w
.47725 .2525 m .5117 .25878 L .52834 .24904 L p
1 g
F P
s
P
p
.002 w
.57505 .59836 m .62372 .56849 L .61913 .5554 L p
1 g
F P
s
P
p
.002 w
.65958 .51398 m .61913 .5554 L .62372 .56849 L p
1 g
F P
s
P
p
.002 w
.52834 .24904 m .56208 .26918 L .58352 .26721 L p
1 g
F P
s
P
p
.002 w
.34856 .55177 m .39261 .57988 L .38583 .56058 L p
1 g
F P
s
P
p
.002 w
.38583 .56058 m .34235 .53247 L .34856 .55177 L p
1 g
F P
s
P
p
.002 w
.65022 .31697 m .66053 .3649 L .67655 .37961 L p
1 g
F P
s
P
p
.002 w
.66053 .3649 m .65022 .31697 L .63081 .30744 L p
1 g
F P
s
P
p
.002 w
.3083 .40356 m .31707 .45026 L .32601 .42992 L p
1 g
F P
s
P
p
.002 w
.32601 .42992 m .31831 .38755 L .3083 .40356 L p
1 g
F P
s
P
p
.002 w
.46614 .61931 m .52098 .61587 L .51247 .60455 L p
1 g
F P
s
P
p
.002 w
.51247 .60455 m .4554 .60798 L .46614 .61931 L p
1 g
F P
s
P
p
.002 w
.3639 .29667 m .3411 .33381 L .35811 .32833 L p
1 g
F P
s
P
p
.002 w
.35811 .32833 m .37692 .29788 L .3639 .29667 L p
1 g
F P
s
P
p
.002 w
.32776 .34212 m .31831 .38755 L .33274 .37321 L p
1 g
F P
s
P
p
.002 w
.33274 .37321 m .3411 .33381 L .32776 .34212 L p
1 g
F P
s
P
p
.002 w
.31342 .49079 m .34235 .53247 L .34047 .51113 L p
1 g
F P
s
P
p
.002 w
.34047 .51113 m .31276 .47073 L .31342 .49079 L p
1 g
F P
s
P
p
.002 w
.52834 .24904 m .48648 .24125 L .47725 .2525 L p
1 g
F P
s
P
p
.002 w
.44034 .25745 m .47725 .2525 L .48648 .24125 L p
1 g
F P
s
P
p
.002 w
.60343 .26955 m .63081 .30744 L .65022 .31697 L p
1 g
F P
s
P
p
.002 w
.63081 .30744 m .60343 .26955 L .58352 .26721 L p
1 g
F P
s
P
p
.002 w
.65958 .51398 m .68609 .46554 L .67909 .44838 L p
1 g
F P
s
P
p
.002 w
.68837 .39617 m .67909 .44838 L .68609 .46554 L p
1 g
F P
s
P
p
.002 w
.67909 .44838 m .68837 .39617 L .67655 .37961 L p
1 g
F P
s
P
p
.002 w
.62372 .56849 m .66272 .52874 L .65958 .51398 L p
1 g
F P
s
P
p
.002 w
.68609 .46554 m .65958 .51398 L .66272 .52874 L p
1 g
F P
s
P
p
.002 w
.39875 .2665 m .3639 .29667 L .37692 .29788 L p
1 g
F P
s
P
p
.002 w
.37692 .29788 m .40546 .27322 L .39875 .2665 L p
1 g
F P
s
P
p
.002 w
.41547 .60784 m .46614 .61931 L .4554 .60798 L p
1 g
F P
s
P
p
.002 w
.4554 .60798 m .40252 .59584 L .41547 .60784 L p
1 g
F P
s
P
p
.002 w
.48648 .24125 m .44141 .24722 L .44034 .25745 L p
1 g
F P
s
P
p
.002 w
.40546 .27322 m .44034 .25745 L .44141 .24722 L p
1 g
F P
s
P
p
.002 w
.54482 .24383 m .58352 .26721 L .60343 .26955 L p
1 g
F P
s
P
p
.002 w
.58352 .26721 m .54482 .24383 L .52834 .24904 L p
1 g
F P
s
P
p
.002 w
.44141 .24722 m .39875 .2665 L .40546 .27322 L p
1 g
F P
s
P
p
.002 w
.48648 .24125 m .52834 .24904 L .54482 .24383 L p
1 g
F P
s
P
p
.002 w
.6662 .32988 m .67655 .37961 L .68837 .39617 L p
1 g
F P
s
P
p
.002 w
.67655 .37961 m .6662 .32988 L .65022 .31697 L p
1 g
F P
s
P
p
.002 w
.52928 .62263 m .57972 .60625 L .57505 .59836 L p
1 g
F P
s
P
p
.002 w
.57505 .59836 m .52098 .61587 L .52928 .62263 L p
1 g
F P
s
P
p
.002 w
.62372 .56849 m .57505 .59836 L .57972 .60625 L p
1 g
F P
s
P
p
.002 w
.35917 .5684 m .40252 .59584 L .39261 .57988 L p
1 g
F P
s
P
p
.002 w
.39261 .57988 m .34856 .55177 L .35917 .5684 L p
1 g
F P
s
P
p
.002 w
.3032 .42089 m .31276 .47073 L .31707 .45026 L p
1 g
F P
s
P
p
.002 w
.31707 .45026 m .3083 .40356 L .3032 .42089 L p
1 g
F P
s
P
p
.002 w
.57972 .60625 m .62515 .57839 L .62372 .56849 L p
1 g
F P
s
P
p
.002 w
.66272 .52874 m .62372 .56849 L .62515 .57839 L p
1 g
F P
s
P
p
.002 w
.35407 .29907 m .32776 .34212 L .3411 .33381 L p
1 g
F P
s
P
p
.002 w
.3411 .33381 m .3639 .29667 L .35407 .29907 L p
1 g
F P
s
P
p
.002 w
.47823 .62591 m .52928 .62263 L .52098 .61587 L p
1 g
F P
s
P
p
.002 w
.52098 .61587 m .46614 .61931 L .47823 .62591 L p
1 g
F P
s
P
p
.002 w
.31864 .35319 m .3083 .40356 L .31831 .38755 L p
1 g
F P
s
P
p
.002 w
.31831 .38755 m .32776 .34212 L .31864 .35319 L p
1 g
F P
s
P
p
.002 w
.3193 .50988 m .34856 .55177 L .34235 .53247 L p
1 g
F P
s
P
p
.002 w
.34235 .53247 m .31342 .49079 L .3193 .50988 L p
1 g
F P
s
P
p
.002 w
.62121 .27639 m .65022 .31697 L .6662 .32988 L p
1 g
F P
s
P
p
.002 w
.65022 .31697 m .62121 .27639 L .60343 .26955 L p
1 g
F P
s
P
p
.002 w
.66272 .52874 m .68829 .48237 L .68609 .46554 L p
1 g
F P
s
P
p
.002 w
.69544 .41425 m .68609 .46554 L .68829 .48237 L p
1 g
F P
s
P
p
.002 w
.68609 .46554 m .69544 .41425 L .68837 .39617 L p
1 g
F P
s
P
p
.002 w
.54482 .24383 m .49645 .2347 L .48648 .24125 L p
1 g
F P
s
P
p
.002 w
.44141 .24722 m .48648 .24125 L .49645 .2347 L p
1 g
F P
s
P
p
.002 w
.62515 .57839 m .66154 .5414 L .66272 .52874 L p
1 g
F P
s
P
p
.002 w
.68829 .48237 m .66272 .52874 L .66154 .5414 L p
1 g
F P
s
P
p
.002 w
.39453 .264 m .35407 .29907 L .3639 .29667 L p
1 g
F P
s
P
p
.002 w
.3639 .29667 m .39875 .2665 L .39453 .264 L p
1 g
F P
s
P
p
.002 w
.5607 .24354 m .60343 .26955 L .62121 .27639 L p
1 g
F P
s
P
p
.002 w
.60343 .26955 m .5607 .24354 L .54482 .24383 L p
1 g
F P
s
P
p
.002 w
.67814 .34602 m .68837 .39617 L .69544 .41425 L p
1 g
F P
s
P
p
.002 w
.68837 .39617 m .67814 .34602 L .6662 .32988 L p
1 g
F P
s
P
p
.002 w
.30343 .43913 m .31342 .49079 L .31276 .47073 L p
1 g
F P
s
P
p
.002 w
.31276 .47073 m .3032 .42089 L .30343 .43913 L p
1 g
F P
s
P
p
.002 w
.43126 .61535 m .47823 .62591 L .46614 .61931 L p
1 g
F P
s
P
p
.002 w
.46614 .61931 m .41547 .60784 L .43126 .61535 L p
1 g
F P
s
P
p
.002 w
.37409 .58175 m .41547 .60784 L .40252 .59584 L p
1 g
F P
s
P
p
.002 w
.40252 .59584 m .35917 .5684 L .37409 .58175 L p
1 g
F P
s
P
p
.002 w
.49645 .2347 m .54482 .24383 L .5607 .24354 L p
1 g
F P
s
P
p
.002 w
.49645 .2347 m .44413 .2416 L .44141 .24722 L p
1 g
F P
s
P
p
.002 w
.39875 .2665 m .44141 .24722 L .44413 .2416 L p
1 g
F P
s
P
p
.002 w
.44413 .2416 m .39453 .264 L .39875 .2665 L p
1 g
F P
s
P
p
.002 w
.53712 .62435 m .58238 .60964 L .57972 .60625 L p
1 g
F P
s
P
p
.002 w
.57972 .60625 m .52928 .62263 L .53712 .62435 L p
1 g
F P
s
P
p
.002 w
.62515 .57839 m .57972 .60625 L .58238 .60964 L p
1 g
F P
s
P
p
.002 w
.31425 .36688 m .3032 .42089 L .3083 .40356 L p
1 g
F P
s
P
p
.002 w
.3083 .40356 m .31864 .35319 L .31425 .36688 L p
1 g
F P
s
P
p
.002 w
.34791 .30525 m .31864 .35319 L .32776 .34212 L p
1 g
F P
s
P
p
.002 w
.32776 .34212 m .35407 .29907 L .34791 .30525 L p
1 g
F P
s
P
p
.002 w
.58238 .60964 m .62318 .58462 L .62515 .57839 L p
1 g
F P
s
P
p
.002 w
.66154 .5414 m .62515 .57839 L .62318 .58462 L p
1 g
F P
s
P
p
.002 w
.33049 .52739 m .35917 .5684 L .34856 .55177 L p
1 g
F P
s
P
p
.002 w
.34856 .55177 m .3193 .50988 L .33049 .52739 L p
1 g
F P
s
P
p
.002 w
.63626 .28775 m .6662 .32988 L .67814 .34602 L p
1 g
F P
s
P
p
.002 w
.6662 .32988 m .63626 .28775 L .62121 .27639 L p
1 g
F P
s
P
p
.002 w
.49143 .62732 m .53712 .62435 L .52928 .62263 L p
1 g
F P
s
P
p
.002 w
.52928 .62263 m .47823 .62591 L .49143 .62732 L p
1 g
F P
s
P
p
.002 w
.66154 .5414 m .68534 .4984 L .68829 .48237 L p
1 g
F P
s
P
p
.002 w
.69733 .43342 m .68829 .48237 L .68534 .4984 L p
1 g
F P
s
P
p
.002 w
.68829 .48237 m .69733 .43342 L .69544 .41425 L p
1 g
F P
s
P
p
.002 w
.5607 .24354 m .50694 .23334 L .49645 .2347 L p
1 g
F P
s
P
p
.002 w
.44413 .2416 m .49645 .2347 L .50694 .23334 L p
1 g
F P
s
P
p
.002 w
.62318 .58462 m .65581 .5515 L .66154 .5414 L p
1 g
F P
s
P
p
.002 w
.68534 .4984 m .66154 .5414 L .65581 .5515 L p
1 g
F P
s
P
p
.002 w
.30928 .4578 m .3193 .50988 L .31342 .49079 L p
1 g
F P
s
P
p
.002 w
.31342 .49079 m .30343 .43913 L .30928 .4578 L p
1 g
F P
s
P
p
.002 w
.62121 .27639 m .5755 .24847 L .5607 .24354 L p
1 g
F P
s
P
p
.002 w
.5755 .24847 m .62121 .27639 L .63626 .28775 L p
1 g
F P
s
P
p
.002 w
.69544 .41425 m .68551 .3651 L .67814 .34602 L p
1 g
F P
s
P
p
.002 w
.68551 .3651 m .69544 .41425 L .69733 .43342 L p
1 g
F P
s
P
p
.002 w
.39309 .26609 m .34791 .30525 L .35407 .29907 L p
1 g
F P
s
P
p
.002 w
.35407 .29907 m .39453 .264 L .39309 .26609 L p
1 g
F P
s
P
p
.002 w
.39313 .59125 m .43126 .61535 L .41547 .60784 L p
1 g
F P
s
P
p
.002 w
.41547 .60784 m .37409 .58175 L .39313 .59125 L p
1 g
F P
s
P
p
.002 w
.50694 .23334 m .5607 .24354 L .5755 .24847 L p
1 g
F P
s
P
p
.002 w
.4496 .61788 m .49143 .62732 L .47823 .62591 L p
1 g
F P
s
P
p
.002 w
.47823 .62591 m .43126 .61535 L .4496 .61788 L p
1 g
F P
s
P
p
.002 w
.50694 .23334 m .44855 .24104 L .44413 .2416 L p
1 g
F P
s
P
p
.002 w
.39453 .264 m .44413 .2416 L .44855 .24104 L p
1 g
F P
s
P
p
.002 w
.31502 .38294 m .30343 .43913 L .3032 .42089 L p
1 g
F P
s
P
p
.002 w
.3032 .42089 m .31425 .36688 L .31502 .38294 L p
1 g
F P
s
P
p
.002 w
.34694 .54271 m .37409 .58175 L .35917 .5684 L p
1 g
F P
s
P
p
.002 w
.35917 .5684 m .33049 .52739 L .34694 .54271 L p
1 g
F P
s
P
p
.002 w
.44855 .24104 m .39309 .26609 L .39453 .264 L p
1 g
F P
s
P
p
.002 w
.34582 .31528 m .31425 .36688 L .31864 .35319 L p
1 g
F P
s
P
p
.002 w
.31864 .35319 m .34791 .30525 L .34582 .31528 L p
1 g
F P
s
P
p
.002 w
.54424 .62067 m .58285 .60812 L .58238 .60964 L p
1 g
F P
s
P
p
.002 w
.58238 .60964 m .53712 .62435 L .54424 .62067 L p
1 g
F P
s
P
p
.002 w
.62318 .58462 m .58238 .60964 L .58285 .60812 L p
1 g
F P
s
P
p
.002 w
.67814 .34602 m .64799 .30358 L .63626 .28775 L p
1 g
F P
s
P
p
.002 w
.64799 .30358 m .67814 .34602 L .68551 .3651 L p
1 g
F P
s
P
p
.002 w
.58285 .60812 m .61765 .58678 L .62318 .58462 L p
1 g
F P
s
P
p
.002 w
.65581 .5515 m .62318 .58462 L .61765 .58678 L p
1 g
F P
s
P
p
.002 w
.50541 .62316 m .54424 .62067 L .53712 .62435 L p
1 g
F P
s
P
p
.002 w
.53712 .62435 m .49143 .62732 L .50541 .62316 L p
1 g
F P
s
P
p
.002 w
.65581 .5515 m .67705 .51314 L .68534 .4984 L p
1 g
F P
s
P
p
.002 w
.68534 .4984 m .69369 .4532 L .69733 .43342 L p
1 g
F P
s
P
p
.002 w
.69369 .4532 m .68534 .4984 L .67705 .51314 L p
1 g
F P
s
P
p
.002 w
.32087 .47633 m .33049 .52739 L .3193 .50988 L p
1 g
F P
s
P
p
.002 w
.3193 .50988 m .30928 .4578 L .32087 .47633 L p
1 g
F P
s
P
p
.002 w
.58873 .25877 m .63626 .28775 L .64799 .30358 L p
1 g
F P
s
P
p
.002 w
.63626 .28775 m .58873 .25877 L .5755 .24847 L p
1 g
F P
s
P
p
.002 w
.68783 .38669 m .69733 .43342 L .69369 .4532 L p
1 g
F P
s
P
p
.002 w
.69733 .43342 m .68783 .38669 L .68551 .3651 L p
1 g
F P
s
P
p
.002 w
.5755 .24847 m .51767 .23754 L .50694 .23334 L p
1 g
F P
s
P
p
.002 w
.44855 .24104 m .50694 .23334 L .51767 .23754 L p
1 g
F P
s
P
p
.002 w
.61765 .58678 m .64541 .55858 L .65581 .5515 L p
1 g
F P
s
P
p
.002 w
.67705 .51314 m .65581 .5515 L .64541 .55858 L p
1 g
F P
s
P
p
.002 w
.41591 .59641 m .4496 .61788 L .43126 .61535 L p
1 g
F P
s
P
p
.002 w
.43126 .61535 m .39313 .59125 L .41591 .59641 L p
1 g
F P
s
P
p
.002 w
.51767 .23754 m .5755 .24847 L .58873 .25877 L p
1 g
F P
s
P
p
.002 w
.39467 .273 m .34582 .31528 L .34791 .30525 L p
1 g
F P
s
P
p
.002 w
.34791 .30525 m .39309 .26609 L .39467 .273 L p
1 g
F P
s
P
p
.002 w
.47006 .61509 m .50541 .62316 L .49143 .62732 L p
1 g
F P
s
P
p
.002 w
.49143 .62732 m .4496 .61788 L .47006 .61509 L p
1 g
F P
s
P
p
.002 w
.36839 .55525 m .39313 .59125 L .37409 .58175 L p
1 g
F P
s
P
p
.002 w
.37409 .58175 m .34694 .54271 L .36839 .55525 L p
1 g
F P
s
P
p
.002 w
.32121 .401 m .30928 .4578 L .30343 .43913 L p
1 g
F P
s
P
p
.002 w
.30343 .43913 m .31502 .38294 L .32121 .401 L p
1 g
F P
s
P
p
.002 w
.65588 .32361 m .68551 .3651 L .68783 .38669 L p
1 g
F P
s
P
p
.002 w
.68551 .3651 m .65588 .32361 L .64799 .30358 L p
1 g
F P
s
P
p
.002 w
.34814 .32908 m .31502 .38294 L .31425 .36688 L p
1 g
F P
s
P
p
.002 w
.31425 .36688 m .34582 .31528 L .34814 .32908 L p
1 g
F P
s
P
p
.002 w
.51767 .23754 m .45464 .2459 L .44855 .24104 L p
1 g
F P
s
P
p
.002 w
.39309 .26609 m .44855 .24104 L .45464 .2459 L p
1 g
F P
s
P
p
.002 w
.45464 .2459 m .39467 .273 L .39309 .26609 L p
1 g
F P
s
P
p
.002 w
.5504 .61133 m .58094 .60142 L .58285 .60812 L p
1 g
F P
s
P
p
.002 w
.58285 .60812 m .54424 .62067 L .5504 .61133 L p
1 g
F P
s
P
p
.002 w
.61765 .58678 m .58285 .60812 L .58094 .60142 L p
1 g
F P
s
P
p
.002 w
.58094 .60142 m .60848 .58453 L .61765 .58678 L p
1 g
F P
s
P
p
.002 w
.64541 .55858 m .61765 .58678 L .60848 .58453 L p
1 g
F P
s
P
p
.002 w
.64541 .55858 m .66334 .52605 L .67705 .51314 L p
1 g
F P
s
P
p
.002 w
.68435 .47302 m .67705 .51314 L .66334 .52605 L p
1 g
F P
s
P
p
.002 w
.67705 .51314 m .68435 .47302 L .69369 .4532 L p
1 g
F P
s
P
p
.002 w
.33813 .49412 m .34694 .54271 L .33049 .52739 L p
1 g
F P
s
P
p
.002 w
.33049 .52739 m .32087 .47633 L .33813 .49412 L p
1 g
F P
s
P
p
.002 w
.51978 .61323 m .5504 .61133 L .54424 .62067 L p
1 g
F P
s
P
p
.002 w
.54424 .62067 m .50541 .62316 L .51978 .61323 L p
1 g
F P
s
P
p
.002 w
.68479 .41027 m .69369 .4532 L .68435 .47302 L p
1 g
F P
s
P
p
.002 w
.69369 .4532 m .68479 .41027 L .68783 .38669 L p
1 g
F P
s
P
p
.002 w
.59988 .27445 m .64799 .30358 L .65588 .32361 L p
1 g
F P
s
P
p
.002 w
.64799 .30358 m .59988 .27445 L .58873 .25877 L p
1 g
F P
s
P
p
.002 w
.44186 .59686 m .47006 .61509 L .4496 .61788 L p
1 g
F P
s
P
p
.002 w
.4496 .61788 m .41591 .59641 L .44186 .59686 L p
1 g
F P
s
P
p
.002 w
.58873 .25877 m .52833 .2475 L .51767 .23754 L p
1 g
F P
s
P
p
.002 w
.45464 .2459 m .51767 .23754 L .52833 .2475 L p
1 g
F P
s
P
p
.002 w
.60848 .58453 m .63036 .56223 L .64541 .55858 L p
1 g
F P
s
P
p
.002 w
.66334 .52605 m .64541 .55858 L .63036 .56223 L p
1 g
F P
s
P
p
.002 w
.52833 .2475 m .58873 .25877 L .59988 .27445 L p
1 g
F P
s
P
p
.002 w
.39435 .56445 m .41591 .59641 L .39313 .59125 L p
1 g
F P
s
P
p
.002 w
.39313 .59125 m .36839 .55525 L .39435 .56445 L p
1 g
F P
s
P
p
.002 w
.65946 .34744 m .68783 .38669 L .68479 .41027 L p
1 g
F P
s
P
p
.002 w
.68783 .38669 m .65946 .34744 L .65588 .32361 L p
1 g
F P
s
P
p
.002 w
.49209 .60677 m .51978 .61323 L .50541 .62316 L p
1 g
F P
s
P
p
.002 w
.50541 .62316 m .47006 .61509 L .49209 .60677 L p
1 g
F P
s
P
p
.002 w
.33294 .42058 m .32087 .47633 L .30928 .4578 L p
1 g
F P
s
P
p
.002 w
.30928 .4578 m .32121 .401 L .33294 .42058 L p
1 g
F P
s
P
p
.002 w
.39941 .28483 m .34814 .32908 L .34582 .31528 L p
1 g
F P
s
P
p
.002 w
.34582 .31528 m .39467 .273 L .39941 .28483 L p
1 g
F P
s
P
p
.002 w
.35506 .34643 m .32121 .401 L .31502 .38294 L p
1 g
F P
s
P
p
.002 w
.31502 .38294 m .34814 .32908 L .35506 .34643 L p
1 g
F P
s
P
p
.002 w
.52833 .2475 m .46232 .25638 L .45464 .2459 L p
1 g
F P
s
P
p
.002 w
.39467 .273 m .45464 .2459 L .46232 .25638 L p
1 g
F P
s
P
p
.002 w
.36072 .51052 m .36839 .55525 L .34694 .54271 L p
1 g
F P
s
P
p
.002 w
.34694 .54271 m .33813 .49412 L .36072 .51052 L p
1 g
F P
s
P
p
.002 w
.46232 .25638 m .39941 .28483 L .39467 .273 L p
1 g
F P
s
P
p
.002 w
.63036 .56223 m .64435 .53662 L .66334 .52605 L p
1 g
F P
s
P
p
.002 w
.66932 .49224 m .66334 .52605 L .64435 .53662 L p
1 g
F P
s
P
p
.002 w
.66334 .52605 m .66932 .49224 L .68435 .47302 L p
1 g
F P
s
P
p
.002 w
.67622 .43516 m .68435 .47302 L .66932 .49224 L p
1 g
F P
s
P
p
.002 w
.68435 .47302 m .67622 .43516 L .68479 .41027 L p
1 g
F P
s
P
p
.002 w
.55532 .59628 m .57658 .58942 L .58094 .60142 L p
1 g
F P
s
P
p
.002 w
.58094 .60142 m .5504 .61133 L .55532 .59628 L p
1 g
F P
s
P
p
.002 w
.60848 .58453 m .58094 .60142 L .57658 .58942 L p
1 g
F P
s
P
p
.004 w
.58554 .59931 m
.59642 .62078 L
s
P
p
.002 w
.60848 .29529 m .65588 .32361 L .65946 .34744 L p
1 g
F P
s
P
p
.002 w
.65588 .32361 m .60848 .29529 L .59988 .27445 L p
1 g
F P
s
P
p
.002 w
.57658 .58942 m .59574 .57765 L .60848 .58453 L p
1 g
F P
s
P
p
.002 w
.63036 .56223 m .60848 .58453 L .59574 .57765 L p
1 g
F P
s
P
p
.002 w
.53409 .59753 m .55532 .59628 L .5504 .61133 L p
1 g
F P
s
P
p
.002 w
.5504 .61133 m .51978 .61323 L .53409 .59753 L p
1 g
F P
s
P
p
.002 w
.47025 .59236 m .49209 .60677 L .47006 .61509 L p
1 g
F P
s
P
p
.002 w
.47006 .61509 m .44186 .59686 L .47025 .59236 L p
1 g
F P
s
P
p
.002 w
.42412 .56988 m .44186 .59686 L .41591 .59641 L p
1 g
F P
s
P
p
.002 w
.41591 .59641 m .39435 .56445 L .42412 .56988 L p
1 g
F P
s
P
p
.002 w
.65842 .37445 m .68479 .41027 L .67622 .43516 L p
1 g
F P
s
P
p
.002 w
.68479 .41027 m .65842 .37445 L .65946 .34744 L p
1 g
F P
s
P
p
.002 w
.59574 .57765 m .61089 .56213 L .63036 .56223 L p
1 g
F P
s
P
p
.002 w
.64435 .53662 m .63036 .56223 L .61089 .56213 L p
1 g
F P
s
P
p
.002 w
.53857 .26327 m .59988 .27445 L .60848 .29529 L p
1 g
F P
s
P
p
.002 w
.59988 .27445 m .53857 .26327 L .52833 .2475 L p
1 g
F P
s
P
p
.002 w
.46232 .25638 m .52833 .2475 L .53857 .26327 L p
1 g
F P
s
P
p
.002 w
.35007 .44107 m .33813 .49412 L .32087 .47633 L p
1 g
F P
s
P
p
.002 w
.32087 .47633 m .33294 .42058 L .35007 .44107 L p
1 g
F P
s
P
p
.002 w
.51504 .59295 m .53409 .59753 L .51978 .61323 L p
1 g
F P
s
P
p
.002 w
.51978 .61323 m .49209 .60677 L .51504 .59295 L p
1 g
F P
s
P
p
.002 w
.40735 .30149 m .35506 .34643 L .34814 .32908 L p
1 g
F P
s
P
p
.002 w
.34814 .32908 m .39941 .28483 L .40735 .30149 L p
1 g
F P
s
P
p
.002 w
.38807 .52491 m .39435 .56445 L .36839 .55525 L p
1 g
F P
s
P
p
.002 w
.36839 .55525 m .36072 .51052 L .38807 .52491 L p
1 g
F P
s
P
p
.002 w
.3666 .36694 m .33294 .42058 L .32121 .401 L p
1 g
F P
s
P
p
.002 w
.32121 .401 m .35506 .34643 L .3666 .36694 L p
1 g
F P
s
P
p
.002 w
.64435 .53662 m .64881 .51019 L .66932 .49224 L p
1 g
F P
s
P
p
.002 w
.66218 .46058 m .66932 .49224 L .64881 .51019 L p
1 g
F P
s
P
p
.002 w
.66932 .49224 m .66218 .46058 L .67622 .43516 L p
1 g
F P
s
P
p
.002 w
.61411 .32084 m .65946 .34744 L .65842 .37445 L p
1 g
F P
s
P
p
.002 w
.65946 .34744 m .61411 .32084 L .60848 .29529 L p
1 g
F P
s
P
p
.002 w
.61089 .56213 m .62045 .54439 L .64435 .53662 L p
1 g
F P
s
P
p
.002 w
.64881 .51019 m .64435 .53662 L .62045 .54439 L p
1 g
F P
s
P
p
.002 w
.53857 .26327 m .47142 .27248 L .46232 .25638 L p
1 g
F P
s
P
p
.002 w
.39941 .28483 m .46232 .25638 L .47142 .27248 L p
1 g
F P
s
P
p
.002 w
.47142 .27248 m .40735 .30149 L .39941 .28483 L p
1 g
F P
s
P
p
.002 w
.50019 .58289 m .51504 .59295 L .49209 .60677 L p
1 g
F P
s
P
p
.002 w
.49209 .60677 m .47025 .59236 L .50019 .58289 L p
1 g
F P
s
P
p
.002 w
.55878 .5757 m .56975 .57217 L .57658 .58942 L p
1 g
F P
s
P
p
.002 w
.57658 .58942 m .55532 .59628 L .55878 .5757 L p
1 g
F P
s
P
p
.002 w
.59574 .57765 m .57658 .58942 L .56975 .57217 L p
1 g
F P
s
P
p
.002 w
.65259 .40383 m .67622 .43516 L .66218 .46058 L p
1 g
F P
s
P
p
.002 w
.67622 .43516 m .65259 .40383 L .65842 .37445 L p
1 g
F P
s
P
p
.002 w
.45678 .57121 m .47025 .59236 L .44186 .59686 L p
1 g
F P
s
P
p
.002 w
.44186 .59686 m .42412 .56988 L .45678 .57121 L p
1 g
F P
s
P
p
.002 w
.56975 .57217 m .57964 .56609 L .59574 .57765 L p
1 g
F P
s
P
p
.002 w
.61089 .56213 m .59574 .57765 L .57964 .56609 L p
1 g
F P
s
P
p
.002 w
.54786 .57629 m .55878 .5757 L .55532 .59628 L p
1 g
F P
s
P
p
.002 w
.55532 .59628 m .53409 .59753 L .54786 .57629 L p
1 g
F P
s
P
p
.002 w
.37222 .46178 m .36072 .51052 L .33813 .49412 L p
1 g
F P
s
P
p
.002 w
.33813 .49412 m .35007 .44107 L .37222 .46178 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.54801 .28462 m .60848 .29529 L .61411 .32084 L p
1 g
F P
s
P
p
.002 w
.60848 .29529 m .54801 .28462 L .53857 .26327 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.57964 .56609 m .58741 .55807 L .61089 .56213 L p
1 g
F P
s
P
p
.002 w
.62045 .54439 m .61089 .56213 L .58741 .55807 L p
1 g
F P
s
P
p
.002 w
.47142 .27248 m .53857 .26327 L .54801 .28462 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.41936 .53669 m .42412 .56988 L .39435 .56445 L p
1 g
F P
s
P
p
.002 w
.39435 .56445 m .38807 .52491 L .41936 .53669 L p
1 g
F P
s
P
p
.002 w
.53813 .57386 m .54786 .57629 L .53409 .59753 L p
1 g
F P
s
P
p
.002 w
.53409 .59753 m .51504 .59295 L .53813 .57386 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.62045 .54439 m .62333 .52622 L .64881 .51019 L p
1 g
F P
s
P
p
.002 w
.64295 .48567 m .64881 .51019 L .62333 .52622 L p
1 g
F P
s
P
p
.002 w
.64881 .51019 m .64295 .48567 L .66218 .46058 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.61643 .35041 m .65842 .37445 L .65259 .40383 L p
1 g
F P
s
P
p
.002 w
.65842 .37445 m .61643 .35041 L .61411 .32084 L p
1 g
F P
s
P
p
.002 w
.41839 .32266 m .3666 .36694 L .35506 .34643 L p
1 g
F P
s
P
p
.002 w
.35506 .34643 m .40735 .30149 L .41839 .32266 L p
1 g
F P
s
P
p
.002 w
.38257 .39002 m .35007 .44107 L .33294 .42058 L p
1 g
F P
s
P
p
.002 w
.33294 .42058 m .3666 .36694 L .38257 .39002 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.54719 .52363 L
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.58741 .55807 m .59224 .54895 L .62045 .54439 L p
1 g
F P
s
P
p
.002 w
.62333 .52622 m .62045 .54439 L .59224 .54895 L p
1 g
F P
s
P
p
.002 w
.64203 .43464 m .66218 .46058 L .64295 .48567 L p
1 g
F P
s
P
p
.002 w
.66218 .46058 m .64203 .43464 L .65259 .40383 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4987 .58336 m .47025 .59236 L p
.48111 .5799 L 1 g
F P
s
P
p
.48111 .5799 m .48228 .57856 L .48907 .58054 L 1 g
F
P
p
.48111 .5799 m .48907 .58054 L .4987 .58336 L 1 g
F
P
p
.51079 .57862 m .49768 .58124 L .49926 .58137 L 1 g
F
P
p
.51079 .57862 m .49926 .58137 L .50077 .58131 L 1 g
F
P
p
.002 w
.50382 .58119 m .50019 .58289 L p
.50215 .58126 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51079 .57862 L p
.50077 .58131 L 1 g
F P
s
P
p
.002 w
.50019 .58289 m .49926 .58137 L p
.50215 .58126 L 1 g
F P
s
P
p
.50077 .58131 m .50025 .58145 L .50382 .58119 L 1 g
F
P
p
.50077 .58131 m .50382 .58119 L .51094 .58068 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.50019 .58289 m .4987 .58336 L p
.49765 .58124 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58054 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58054 L .49768 .58124 L 1 g
F
P
p
.002 w
.49124 .56829 m .49926 .58137 L p
.49765 .58124 L 1 g
F P
s
P
p
.002 w
.49926 .58137 m .50019 .58289 L p
.49765 .58124 L 1 g
F P
s
P
p
.002 w
.48907 .58054 m .48921 .57862 L p
.47985 .57785 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46832 .57448 L p
1 g
F P
s
P
p
.47025 .59236 m .45706 .57119 L .46832 .57448 L 1 g
F
P
p
.48015 .581 m .46832 .57448 L .48228 .57856 L 1 g
F
P
p
.47025 .59236 m .46832 .57448 L .48015 .581 L 1 g
F
P
p
.002 w
.46832 .57448 m .46872 .57265 L p
.45786 .56831 L 1 g
F P
s
P
p
.45786 .56831 m .45913 .56915 L .46832 .57448 L 1 g
F
P
p
.002 w
.46164 .5708 m .45678 .57121 L p
.45958 .56944 L 1 g
F P
s
P
p
.002 w
.45678 .57121 m .45628 .56727 L p
.45958 .56944 L 1 g
F P
s
P
p
.45732 .56809 m .45863 .56914 L .46164 .5708 L 1 g
F
P
p
.45913 .56915 m .46164 .5708 L .46832 .57448 L 1 g
F
P
p
.45732 .56809 m .46164 .5708 L .45913 .56915 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45678 .57121 m .42412 .56988 L p
.44143 .55546 L 1 g
F P
s
P
p
.44143 .55546 m .45084 .56295 L .45678 .57121 L 1 g
F
P
p
.002 w
.45628 .56727 m .4567 .57057 L p
.45084 .56295 L 1 g
F P
s
P
p
.002 w
.4567 .57057 m .45678 .57121 L p
.45084 .56295 L 1 g
F P
s
P
p
.002 w
.45084 .56295 m .45146 .56129 L p
.44578 .55635 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45084 .56295 L p
1 g
F P
s
P
p
.002 w
.45084 .56295 m .45002 .56518 L p
.45732 .56809 L 1 g
F P
s
P
p
.46872 .57265 m .45084 .56295 L .45732 .56809 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43856 .54696 L p
1 g
F P
s
P
p
.44143 .55546 m .44366 .5536 L .45084 .56295 L 1 g
F
P
p
.45146 .56129 m .43856 .54696 L .44578 .55635 L 1 g
F
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.42412 .56988 m .41936 .53669 L .43628 .541 L p
1 g
F P
s
P
p
.002 w
.43856 .54696 m .43925 .54566 L p
.43555 .53833 L 1 g
F P
s
P
p
.002 w
.43628 .541 m .41936 .53669 L p
.43334 .53034 L 1 g
F P
s
P
p
.43555 .53833 m .43438 .53603 L .43628 .541 L 1 g
F
P
p
.43555 .53833 m .43628 .541 L .43856 .54696 L 1 g
F
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43279 .52832 L p
1 g
F P
s
P
p
.002 w
.41936 .53669 m .42704 .50748 L p
.43279 .52832 L 1 g
F P
s
P
p
.43264 .53066 m .43279 .52832 L .43334 .53034 L 1 g
F
P
p
.41936 .53669 m .43279 .52832 L .43264 .53066 L 1 g
F
P
p
.002 w
.43279 .52832 m .43346 .52734 L p
.43324 .52114 L 1 g
F P
s
P
p
.43925 .54566 m .43279 .52832 L .43555 .53833 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43401 .50926 L p
1 g
F P
s
P
p
.43346 .52734 m .43401 .50926 L .43324 .52114 L 1 g
F
P
p
.43334 .53034 m .43286 .5272 L .46123 .51765 L 1 g
F
P
p
.002 w
.42879 .50083 m .43436 .50372 L p
.43401 .50926 L 1 g
F P
s
P
p
.43107 .51565 m .42879 .50083 L .43401 .50926 L 1 g
F
P
p
.002 w
.43401 .50926 m .43485 .50826 L p
.43817 .50051 L 1 g
F P
s
P
p
.002 w
.43613 .50464 m .42879 .50083 L p
.43896 .4989 L 1 g
F P
s
P
p
.002 w
.42879 .50083 m .45189 .46652 L .45399 .46841 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.42879 .50083 m .45399 .46841 L .44278 .49115 L 1 g
F
P
p
.43377 .49988 m .44278 .49115 L .43896 .4989 L 1 g
F
P
p
.42879 .50083 m .44278 .49115 L .43377 .49988 L 1 g
F
P
p
.43286 .5272 m .43401 .50926 L .46123 .51765 L 1 g
F
P
p
.002 w
.43436 .50372 m .43613 .50464 L p
.43401 .50926 L 1 g
F P
s
P
p
.002 w
.44325 .49079 m .44187 .49213 L p
.43485 .50826 L 1 g
F P
s
P
p
.43485 .50826 m .44187 .49213 L .44009 .49602 L 1 g
F
P
p
.43817 .50051 m .43613 .50464 L .43401 .50926 L 1 g
F
P
p
.002 w
.43613 .50464 m .46123 .51765 L p
.43401 .50926 L 1 g
F P
s
P
p
.002 w
.44187 .49213 m .44166 .49233 L p
.44009 .49602 L 1 g
F P
s
P
p
.002 w
.44334 .49061 m .44339 .4905 L p
.44278 .49115 L 1 g
F P
s
P
p
.002 w
.44278 .49115 m .44339 .4905 L p
.44863 .48548 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.43896 .4989 m .44278 .49115 L .47938 .49122 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45771 .47668 L p
1 g
F P
s
P
p
.44339 .4905 m .45771 .47668 L .44863 .48548 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45771 .47668 m .45826 .47608 L p
.46671 .47237 L 1 g
F P
s
P
p
.47612 .46777 m .50603 .46932 L .46133 .47501 L 1 g
F
P
p
.46671 .47237 m .47242 .46987 L .46133 .47501 L 1 g
F
P
p
.46671 .47237 m .46133 .47501 L .45771 .47668 L 1 g
F
P
p
.002 w
.50603 .46932 m .47938 .49122 L .46133 .47501 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.44278 .49115 m .45771 .47668 L .47938 .49122 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47765 .46702 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47612 .46777 m .47765 .46702 L .50603 .46932 L 1 g
F
P
p
.002 w
.47765 .46702 m .47786 .46667 L p
.48627 .46582 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46715 L p
1 g
F P
s
P
p
.002 w
.50603 .46932 m .5134 .46595 L p
.54721 .48917 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47672 L p
1 g
F P
s
P
p
.52243 .46715 m .53785 .47457 L .54721 .48917 L 1 g
F
P
p
.52214 .46667 m .54233 .47672 L .53145 .47149 L 1 g
F
P
p
.002 w
.54444 .47878 m .54721 .48917 L p
.53785 .47457 L 1 g
F P
s
P
p
.53409 .4687 m .54233 .47672 L .53785 .47457 L 1 g
F
P
p
.54233 .47672 m .54444 .47878 L .53785 .47457 L 1 g
F
P
p
.5134 .46595 m .52243 .46715 L .54721 .48917 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46715 L p
1 g
F P
s
P
p
.002 w
.52243 .46715 m .52214 .46667 L p
.53145 .47149 L 1 g
F P
s
P
p
.53145 .47149 m .54302 .47747 L .52243 .46715 L 1 g
F
P
p
.002 w
.54233 .47672 m .54302 .47747 L p
.53145 .47149 L 1 g
F P
s
P
p
.52243 .46715 m .53409 .4687 L .53785 .47457 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56611 .5094 L p
1 g
F P
s
P
p
.55661 .4905 m .56611 .5094 L .56178 .5004 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56751 .52875 L p
1 g
F P
s
P
p
.002 w
.57681 .52042 m .56784 .53675 L p
.56751 .52875 L 1 g
F P
s
P
p
.002 w
.56712 .51939 m .57026 .51972 L p
.56751 .52875 L 1 g
F P
s
P
p
.002 w
.57026 .51972 m .57681 .52042 L p
.56751 .52875 L 1 g
F P
s
P
p
.002 w
.56751 .52875 m .56654 .52734 L p
.56445 .53879 L 1 g
F P
s
P
p
.56515 .50826 m .56751 .52875 L .56727 .52315 L 1 g
F
P
p
.56756 .52388 m .56822 .52979 L .56771 .52487 L 1 g
F
P
p
.56515 .50826 m .56796 .52793 L .56756 .52388 L 1 g
F
P
p
.56796 .52793 m .56822 .52979 L .56756 .52388 L 1 g
F
P
p
.002 w
.57681 .52042 m .56712 .51939 L p
.56989 .48523 L 1 g
F P
s
P
p
.002 w
.56667 .51487 m .56989 .48523 L p
.56712 .51939 L 1 g
F P
s
P
p
.002 w
.5681 .50168 m .56705 .51137 L p
.56499 .49868 L 1 g
F P
s
P
p
.002 w
.56705 .51137 m .56667 .51487 L p
.56611 .5094 L 1 g
F P
s
P
p
.56499 .49868 m .56705 .51137 L .56611 .5094 L 1 g
F
P
p
.002 w
.55747 .49141 m .55661 .4905 L p
.56178 .5004 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .5094 L p
1 g
F P
s
P
p
.002 w
.56611 .5094 m .56515 .50826 L p
.56771 .52487 L 1 g
F P
s
P
p
.56771 .52487 m .56854 .53025 L .56611 .5094 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.55394 .488 m .56499 .49868 L .56619 .51929 L 1 g
F
P
p
.002 w
.56667 .51487 m .56619 .51929 L p
.56499 .49868 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55747 .49141 L p
1 g
F P
s
P
p
.56178 .5004 m .56713 .51061 L .55747 .49141 L 1 g
F
P
p
.002 w
.56712 .51939 m .56619 .51929 L .56667 .51487 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56177 .54758 L p
1 g
F P
s
P
p
.002 w
.56784 .53675 m .56244 .54658 L p
.5629 .54386 L 1 g
F P
s
P
p
.56751 .52875 m .56784 .53675 L .5629 .54386 L 1 g
F
P
p
.002 w
.56244 .54658 m .56055 .55001 L p
.56074 .54913 L 1 g
F P
s
P
p
.56654 .52734 m .56177 .54758 L .56445 .53879 L 1 g
F
P
p
.002 w
.56177 .54758 m .56075 .54566 L p
.55516 .55599 L 1 g
F P
s
P
p
.002 w
.54786 .57629 m .53988 .5743 L p
.5497 .56276 L 1 g
F P
s
P
p
.002 w
.56055 .55001 m .5569 .55757 L p
.5497 .56276 L 1 g
F P
s
P
p
.002 w
.5569 .55757 m .54786 .57629 L p
.5497 .56276 L 1 g
F P
s
P
p
.002 w
.54922 .56311 m .54854 .56129 L p
.53883 .57054 L 1 g
F P
s
P
p
.002 w
.54618 .5653 m .53813 .57386 L .53614 .57247 L p
1 g
F P
s
P
p
.53883 .57054 m .5386 .57077 L .54618 .5653 L 1 g
F
P
p
.53883 .57054 m .54618 .5653 L .54922 .56311 L 1 g
F
P
p
.002 w
.5597 .55054 m .56055 .55001 L .55696 .55383 L p
1 g
F P
s
P
p
.002 w
.55696 .55383 m .56055 .55001 L p
.53988 .5743 L 1 g
F P
s
P
p
.55516 .55599 m .5597 .55055 L .56177 .54758 L 1 g
F
P
p
.002 w
.55998 .55019 m .56055 .55001 L .5597 .55054 L p
1 g
F P
s
P
p
.5597 .55055 m .55988 .55033 L .55993 .55026 L 1 g
F
P
p
.5597 .55055 m .55993 .55026 L .56177 .54758 L 1 g
F
P
p
.55988 .55033 m .56005 .55011 L .56177 .54758 L 1 g
F
P
p
.55999 .5502 m .56027 .54983 L .56177 .54758 L 1 g
F
P
p
.002 w
.56035 .54971 m .56055 .55001 L .56027 .54983 L p
1 g
F P
s
P
p
.56027 .54983 m .56031 .54977 L .56033 .54974 L 1 g
F
P
p
.56027 .54983 m .56033 .54974 L .56177 .54758 L 1 g
F
P
p
.002 w
.54998 .56518 m .55063 .56435 L p
.56075 .54566 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53477 .53373 m .54392 .52633 L .56035 .54971 L p
1 g
F P
s
P
p
.002 w
.56027 .54983 m .53477 .53373 L p
.56035 .54971 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.54392 .52633 m .5548 .52133 L .56046 .54955 L p
1 g
F P
s
P
p
.002 w
.56046 .54955 m .56055 .55001 L .56035 .54971 L p
1 g
F P
s
P
p
.002 w
.56035 .54971 m .54392 .52633 L p
.56046 .54955 L 1 g
F P
s
P
p
.56031 .54977 m .56035 .54972 L .56043 .5496 L 1 g
F
P
p
.56031 .54977 m .56043 .5496 L .56177 .54758 L 1 g
F
P
p
.002 w
.5607 .54919 m .56055 .55001 L .56046 .54955 L p
1 g
F P
s
P
p
.56035 .54972 m .5604 .54965 L .5607 .54919 L 1 g
F
P
p
.56035 .54972 m .5607 .54919 L .56177 .54758 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5548 .52133 m .56619 .51929 L .5607 .54919 L p
1 g
F P
s
P
p
.002 w
.56046 .54955 m .5548 .52133 L p
.5607 .54919 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52625 .56114 m .52545 .55217 L .56011 .55003 L p
1 g
F P
s
P
p
.002 w
.56011 .55003 m .56055 .55001 L .55998 .55019 L p
1 g
F P
s
P
p
.002 w
.55998 .55019 m .52625 .56114 L p
.56011 .55003 L 1 g
F P
s
P
p
.002 w
.52545 .55217 m .52838 .54268 L .56019 .54992 L p
1 g
F P
s
P
p
.002 w
.56019 .54992 m .56055 .55001 L .56011 .55003 L p
1 g
F P
s
P
p
.002 w
.56011 .55003 m .52545 .55217 L p
.56019 .54992 L 1 g
F P
s
P
p
.55988 .55033 m .55999 .5502 L .56005 .55011 L 1 g
F
P
p
.55999 .5502 m .5602 .54994 L .5604 .54965 L 1 g
F
P
p
.002 w
.52838 .54268 m .53477 .53373 L .56027 .54983 L p
1 g
F P
s
P
p
.002 w
.56027 .54983 m .56055 .55001 L .56019 .54992 L p
1 g
F P
s
P
p
.002 w
.56019 .54992 m .52838 .54268 L p
.56027 .54983 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53066 .56864 m .52625 .56114 L .55998 .55019 L p
1 g
F P
s
P
p
.002 w
.5597 .55054 m .53066 .56864 L p
.55998 .55019 L 1 g
F P
s
P
p
.55928 .55105 m .55063 .56435 L .5602 .54994 L 1 g
F
P
p
.55696 .55383 m .55684 .55402 L .55928 .55105 L 1 g
F
P
p
.55684 .55402 m .55063 .56435 L .55928 .55105 L 1 g
F
P
p
.55516 .55599 m .55515 .55601 L .55696 .55383 L 1 g
F
P
p
.55515 .55601 m .55063 .56435 L .55696 .55383 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53175 .57482 L p
1 g
F P
s
P
p
.002 w
.53813 .57386 m .51504 .59295 L p
.524 .57899 L 1 g
F P
s
P
p
.524 .57899 m .53175 .57482 L .53813 .57386 L 1 g
F
P
p
.002 w
.53614 .57247 m .53729 .57327 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.53729 .57327 m .53813 .57386 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.53175 .57482 m .53128 .57265 L p
.52131 .57776 L 1 g
F P
s
P
p
.54854 .56129 m .53175 .57482 L .53769 .57163 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53066 .56864 m .53614 .57247 L p
.53175 .57482 L 1 g
F P
s
P
p
.524 .57899 m .52556 .57657 L .53175 .57482 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58068 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58068 L .52131 .57776 L 1 g
F
P
p
.52556 .57657 m .53066 .56864 L .53175 .57482 L 1 g
F
P
p
.002 w
.50382 .58119 m .53066 .56864 L p
.5235 .57978 L 1 g
F P
s
P
p
.51504 .59295 m .50382 .58119 L .5235 .57978 L 1 g
F
P
p
.002 w
.51094 .58068 m .51111 .583 L p
.52131 .57776 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53175 .57482 L p
1 g
F P
s
P
p
.52131 .57776 m .51111 .583 L .53175 .57482 L 1 g
F
P
p
.002 w
.53175 .57482 m .5322 .57686 L p
.53769 .57163 L 1 g
F P
s
P
p
.002 w
.53066 .56864 m .5597 .55054 L p
.54618 .5653 L 1 g
F P
s
P
p
.002 w
.55696 .55383 m .54618 .5653 L p
.5597 .55054 L 1 g
F P
s
P
p
.002 w
.53614 .57247 m .53066 .56864 L p
.54618 .5653 L 1 g
F P
s
P
p
.002 w
.53988 .5743 m .53813 .57386 L .55696 .55383 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54922 .56311 L p
1 g
F P
s
P
p
.5386 .57077 m .5322 .57686 L .54922 .56311 L 1 g
F
P
p
.56712 .51939 m .56244 .54658 L .56074 .54913 L 1 g
F
P
p
.002 w
.59127 .53124 m .59359 .53967 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.58548 .52456 m .59127 .53124 L .56113 .54965 L p
1 g
F P
s
P
p
.002 w
.56113 .54965 m .56055 .55001 L .56124 .54931 L p
1 g
F P
s
P
p
.002 w
.56124 .54931 m .58548 .52456 L p
.56113 .54965 L 1 g
F P
s
P
p
.002 w
.56177 .54758 m .56178 .5476 L p
.56445 .53879 L 1 g
F P
s
P
p
.002 w
.58548 .52456 m .56124 .54931 L p
.56244 .54658 L 1 g
F P
s
P
p
.002 w
.56244 .54658 m .57681 .52042 L .57905 .52149 L p
1 g
F P
s
P
p
.002 w
.57905 .52149 m .58548 .52456 L p
.56244 .54658 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56755 .52882 L p
1 g
F P
s
P
p
.002 w
.56755 .52882 m .56751 .52875 L p
.56725 .5298 L 1 g
F P
s
P
p
.56725 .5298 m .56257 .5491 L .56755 .52882 L 1 g
F
P
p
.002 w
.56124 .54931 m .56055 .55001 L .56163 .54805 L p
1 g
F P
s
P
p
.002 w
.56163 .54805 m .56244 .54658 L p
.56124 .54931 L 1 g
F P
s
P
p
.002 w
.56055 .55001 m .56619 .51929 L .56712 .51939 L p
1 g
F P
s
P
p
.002 w
.55063 .56435 m .5509 .564 L p
.56177 .54758 L 1 g
F P
s
P
p
.002 w
.56975 .57217 m .55878 .5757 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.57964 .56609 m .56975 .57217 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.58741 .55807 m .57964 .56609 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.55878 .5757 m .54786 .57629 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.59224 .54895 m .58741 .55807 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.59359 .53967 m .59224 .54895 L .56055 .55001 L closepath p
1 g
F P
s
P
p
.002 w
.5509 .564 m .56257 .5491 L .56177 .54759 L p
1 g
F P
s
P
p
.002 w
.56177 .54759 m .56177 .54758 L p
.5509 .564 L 1 g
F P
s
P
p
.002 w
.56178 .5476 m .56257 .5491 L p
.56428 .53971 L 1 g
F P
s
P
p
.56445 .53879 m .56178 .5476 L .56428 .53971 L 1 g
F
P
p
.56712 .51939 m .56751 .52875 L .5629 .54386 L 1 g
F
P
p
.56445 .53879 m .56257 .5491 L .56751 .52875 L 1 g
F
P
p
.002 w
.56751 .52875 m .56822 .52979 L p
.56727 .52315 L 1 g
F P
s
P
p
.002 w
.56822 .52979 m .56854 .53025 L p
.56771 .52487 L 1 g
F P
s
P
p
.002 w
.56611 .5094 m .56713 .51061 L p
.56178 .5004 L 1 g
F P
s
P
p
.002 w
.56989 .48523 m .5681 .50168 L p
.55747 .49141 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55747 .49141 L p
1 g
F P
s
P
p
.54174 .47608 m .55747 .49141 L .55394 .488 L 1 g
F
P
p
.002 w
.55394 .488 m .54721 .48917 L .54444 .47878 L p
1 g
F P
s
P
p
.55301 .4871 m .55394 .488 L .55342 .4875 L 1 g
F
P
p
.54174 .47608 m .55394 .488 L .55301 .4871 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56989 .48523 m .55394 .488 L p
.53803 .45468 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54721 .48917 m .55394 .488 L p
.56619 .51929 L 1 g
F P
s
P
p
.54174 .47608 m .55807 .49205 L .55422 .4883 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54444 .47878 m .53803 .45468 L p
.55394 .488 L 1 g
F P
s
P
p
.002 w
.55394 .488 m .55568 .4877 L p
.55747 .49141 L 1 g
F P
s
P
p
.002 w
.55568 .4877 m .56989 .48523 L p
.55747 .49141 L 1 g
F P
s
P
p
.002 w
.55747 .49141 m .55807 .49205 L p
.55342 .4875 L 1 g
F P
s
P
p
.002 w
.54204 .46976 m .54444 .47878 L p
.53409 .4687 L 1 g
F P
s
P
p
.002 w
.55807 .49205 m .55834 .49233 L p
.55422 .4883 L 1 g
F P
s
P
p
.5 .4634 m .52243 .46715 L .513 .4659 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.53803 .45468 m .5134 .46595 L p
.4862 .43807 L 1 g
F P
s
P
p
.002 w
.5134 .46595 m .50603 .46932 L .5029 .46439 L p
1 g
F P
s
P
p
.47765 .46702 m .5 .46389 L .50603 .46932 L 1 g
F
P
p
.002 w
.52282 .46778 m .52109 .46753 L p
.5 .4634 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.52109 .46753 L 1 g
F P
s
P
p
.002 w
.50237 .46356 m .5029 .46439 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.5029 .46439 m .50603 .46932 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.52109 .46753 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5029 .46439 m .4862 .43807 L p
.5134 .46595 L 1 g
F P
s
P
p
.513 .4659 m .5134 .46595 L .52282 .46778 L 1 g
F
P
p
.002 w
.52243 .46715 m .52253 .46731 L p
.5134 .46595 L 1 g
F P
s
P
p
.002 w
.52253 .46731 m .52282 .46778 L p
.5134 .46595 L 1 g
F P
s
P
p
.002 w
.5134 .46595 m .53803 .45468 L .54204 .46976 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.48627 .46582 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .48627 .46582 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.45189 .46652 m .4982 .45697 L .47765 .46702 L 1 g
F
P
p
.45826 .47608 m .47765 .46702 L .46791 .47179 L 1 g
F
P
p
.47333 .46763 m .47765 .46702 L .47612 .46777 L 1 g
F
P
p
.45189 .46652 m .47765 .46702 L .47333 .46763 L 1 g
F
P
p
.002 w
.4982 .45697 m .50237 .46356 L p
.47765 .46702 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47765 .46702 L p
1 g
F P
s
P
p
.48627 .46582 m .5 .46442 L .47765 .46702 L 1 g
F
P
p
.002 w
.47765 .46702 m .47728 .46762 L p
.46791 .47179 L 1 g
F P
s
P
p
.002 w
.45189 .46652 m .4862 .43807 L .4982 .45697 L p
1 g
F P
s
P
p
.45826 .47608 m .47728 .46762 L .47242 .46987 L 1 g
F
P
p
.002 w
.46035 .47412 m .46133 .47501 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.46133 .47501 m .47938 .49122 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.47728 .46762 m .47718 .46778 L p
.47242 .46987 L 1 g
F P
s
P
p
.002 w
.46133 .47501 m .45189 .46652 L p
.47612 .46777 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45771 .47668 L p
1 g
F P
s
P
p
.47242 .46987 m .47718 .46778 L .45771 .47668 L 1 g
F
P
p
.002 w
.45399 .46841 m .46035 .47412 L p
.45771 .47668 L 1 g
F P
s
P
p
.44278 .49115 m .4476 .48136 L .45771 .47668 L 1 g
F
P
p
.4476 .48136 m .45399 .46841 L .45771 .47668 L 1 g
F
P
p
.002 w
.45771 .47668 m .45698 .47747 L p
.44863 .48548 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44278 .49115 L p
1 g
F P
s
P
p
.44863 .48548 m .45698 .47747 L .44278 .49115 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43362 .50972 L p
1 g
F P
s
P
p
.002 w
.43362 .50972 m .43401 .50926 L p
.43575 .50541 L 1 g
F P
s
P
p
.43575 .50541 m .44166 .49233 L .43362 .50972 L 1 g
F
P
p
.43817 .50051 m .44009 .49602 L .43613 .50464 L 1 g
F
P
p
.002 w
.47938 .49122 m .46123 .51765 L .43613 .50464 L p
1 g
F P
s
P
p
.43896 .4989 m .47938 .49122 L .43613 .50464 L 1 g
F
P
p
.44009 .49602 m .44166 .49233 L .43401 .50926 L 1 g
F
P
p
.43286 .5272 m .43107 .51565 L .43401 .50926 L 1 g
F
P
p
.002 w
.43401 .50926 m .43287 .51061 L p
.43324 .52114 L 1 g
F P
s
P
p
.002 w
.42704 .50748 m .42879 .50083 L p
.43334 .53034 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43279 .52832 L p
1 g
F P
s
P
p
.43324 .52114 m .43287 .51061 L .43279 .52832 L 1 g
F
P
p
.002 w
.43279 .52832 m .43146 .53025 L p
.43555 .53833 L 1 g
F P
s
P
p
.002 w
.46123 .51765 m .45352 .54539 L .43628 .541 L p
1 g
F P
s
P
p
.43334 .53034 m .46123 .51765 L .43628 .541 L 1 g
F
P
p
.002 w
.43628 .541 m .45352 .54539 L p
.44172 .55522 L 1 g
F P
s
P
p
.42412 .56988 m .43628 .541 L .44172 .55522 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43856 .54696 L p
1 g
F P
s
P
p
.43438 .53603 m .43146 .53025 L .43856 .54696 L 1 g
F
P
p
.002 w
.43856 .54696 m .43743 .5491 L p
.44578 .55635 L 1 g
F P
s
P
p
.002 w
.45352 .54539 m .45628 .56727 L p
.45084 .56295 L 1 g
F P
s
P
p
.44366 .5536 m .45352 .54539 L .45084 .56295 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45084 .56295 L p
1 g
F P
s
P
p
.44578 .55635 m .43743 .5491 L .45084 .56295 L 1 g
F
P
p
.002 w
.45352 .54539 m .48932 .55061 L p
.45958 .56944 L 1 g
F P
s
P
p
.002 w
.45628 .56727 m .45352 .54539 L p
.45958 .56944 L 1 g
F P
s
P
p
.002 w
.48932 .55061 m .49124 .56829 L .46164 .5708 L p
1 g
F P
s
P
p
.45958 .56944 m .48932 .55061 L .46164 .5708 L 1 g
F
P
p
.45786 .56831 m .45732 .56809 L .45913 .56915 L 1 g
F
P
p
.45732 .56809 m .45519 .56724 L .45863 .56914 L 1 g
F
P
p
.48921 .57862 m .46832 .57448 L .47985 .57785 L 1 g
F
P
p
.002 w
.45706 .57119 m .49124 .56829 L p
.48228 .57856 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46832 .57448 L p
1 g
F P
s
P
p
.45519 .56724 m .45002 .56518 L .46832 .57448 L 1 g
F
P
p
.002 w
.46832 .57448 m .4678 .57686 L p
.47985 .57785 L 1 g
F P
s
P
p
.002 w
.47025 .59236 m .45678 .57121 L .45706 .57119 L p
1 g
F P
s
P
p
.48228 .57856 m .49124 .56829 L .4987 .58336 L 1 g
F
P
p
.002 w
.48907 .58054 m .48889 .583 L p
.49768 .58124 L 1 g
F P
s
P
p
.002 w
.49124 .56829 m .52625 .56114 L p
.50215 .58126 L 1 g
F P
s
P
p
.002 w
.49926 .58137 m .49124 .56829 L p
.50215 .58126 L 1 g
F P
s
P
p
.002 w
.52625 .56114 m .53066 .56864 L .50382 .58119 L p
1 g
F P
s
P
p
.50215 .58126 m .52625 .56114 L .50382 .58119 L 1 g
F
P
p
.50077 .58131 m .49926 .58137 L .50025 .58145 L 1 g
F
P
p
.002 w
.51504 .59295 m .50019 .58289 L .50382 .58119 L p
1 g
F P
s
P
p
.002 w
.51106 .58232 m .51094 .58068 L p
.50025 .58145 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58232 L p
1 g
F P
s
P
p
.49768 .58124 m .48889 .583 L .51106 .58232 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58054 L p
1 g
F P
s
P
p
.47985 .57785 m .4678 .57686 L .48907 .58054 L 1 g
F
P
p
.002 w
.39875 .48196 m .38807 .52491 L .36072 .51052 L p
1 g
F P
s
P
p
.002 w
.36072 .51052 m .37222 .46178 L .39875 .48196 L p
1 g
F P
s
P
p
.002 w
.54801 .28462 m .48173 .29395 L .47142 .27248 L p
1 g
F P
s
P
p
.002 w
.40735 .30149 m .47142 .27248 L .48173 .29395 L p
1 g
F P
s
P
p
.002 w
.48173 .29395 m .41839 .32266 L .40735 .30149 L p
1 g
F P
s
P
p
.002 w
.55628 .31107 m .61411 .32084 L .61643 .35041 L p
1 g
F P
s
P
p
.002 w
.61411 .32084 m .55628 .31107 L .54801 .28462 L p
1 g
F P
s
P
p
.002 w
.59224 .54895 m .59359 .53967 L .62333 .52622 L p
1 g
F P
s
P
p
.002 w
.61906 .50952 m .62333 .52622 L .59359 .53967 L p
1 g
F P
s
P
p
.002 w
.62333 .52622 m .61906 .50952 L .64295 .48567 L p
1 g
F P
s
P
p
.002 w
.61524 .38307 m .65259 .40383 L .64203 .43464 L p
1 g
F P
s
P
p
.002 w
.65259 .40383 m .61524 .38307 L .61643 .35041 L p
1 g
F P
s
P
p
.002 w
.48173 .29395 m .54801 .28462 L .55628 .31107 L p
1 g
F P
s
P
p
.002 w
.62697 .46579 m .64295 .48567 L .61906 .50952 L p
1 g
F P
s
P
p
.002 w
.64295 .48567 m .62697 .46579 L .64203 .43464 L p
1 g
F P
s
P
p
.002 w
.40257 .41492 m .37222 .46178 L .35007 .44107 L p
1 g
F P
s
P
p
.002 w
.35007 .44107 m .38257 .39002 L .40257 .41492 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.43228 .34781 m .38257 .39002 L .3666 .36694 L p
1 g
F P
s
P
p
.002 w
.3666 .36694 m .41839 .32266 L .43228 .34781 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.42879 .50083 m .41936 .53669 L .38807 .52491 L p
1 g
F P
s
P
p
.002 w
.38807 .52491 m .39875 .48196 L .42879 .50083 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59359 .53967 m .59127 .53124 L .61906 .50952 L p
1 g
F P
s
P
p
.002 w
.6079 .49614 m .61906 .50952 L .59127 .53124 L p
1 g
F P
s
P
p
.002 w
.61906 .50952 m .6079 .49614 L .62697 .46579 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.61048 .41769 m .64203 .43464 L .62697 .46579 L p
1 g
F P
s
P
p
.002 w
.64203 .43464 m .61048 .41769 L .61524 .38307 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.56303 .34186 m .61643 .35041 L .61524 .38307 L p
1 g
F P
s
P
p
.002 w
.61643 .35041 m .56303 .34186 L .55628 .31107 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52545 .55217 m .52625 .56114 L .49124 .56829 L p
1 g
F P
s
P
p
.002 w
.49124 .56829 m .48932 .55061 L .52545 .55217 L p
1 g
F P
s
P
p
.002 w
.55628 .31107 m .4929 .32028 L .48173 .29395 L p
1 g
F P
s
P
p
.002 w
.41839 .32266 m .48173 .29395 L .4929 .32028 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59127 .53124 m .58548 .52456 L .6079 .49614 L p
1 g
F P
s
P
p
.002 w
.4929 .32028 m .43228 .34781 L .41839 .32266 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.4929 .32028 m .55628 .31107 L .56303 .34186 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60228 .45301 m .62697 .46579 L .6079 .49614 L p
1 g
F P
s
P
p
.002 w
.62697 .46579 m .60228 .45301 L .61048 .41769 L p
1 g
F P
s
P
p
.002 w
.42595 .44075 m .39875 .48196 L .37222 .46178 L p
1 g
F P
s
P
p
.002 w
.37222 .46178 m .40257 .41492 L .42595 .44075 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.58548 .52456 m .57681 .52042 L .59091 .48769 L p
1 g
F P
s
P
p
.002 w
.59091 .48769 m .6079 .49614 L .58548 .52456 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.6079 .49614 m .59091 .48769 L .60228 .45301 L p
1 g
F P
s
P
p
.002 w
.56794 .37598 m .61524 .38307 L .61048 .41769 L p
1 g
F P
s
P
p
.002 w
.61524 .38307 m .56794 .37598 L .56303 .34186 L p
1 g
F P
s
P
p
.002 w
.52838 .54268 m .52545 .55217 L .48932 .55061 L p
1 g
F P
s
P
p
.002 w
.44861 .37612 m .40257 .41492 L .38257 .39002 L p
1 g
F P
s
P
p
.002 w
.38257 .39002 m .43228 .34781 L .44861 .37612 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.49486 .53177 m .48932 .55061 L .45352 .54539 L p
1 g
F P
s
P
p
.002 w
.45352 .54539 m .46123 .51765 L .49486 .53177 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.48932 .55061 m .49486 .53177 L .52838 .54268 L p
1 g
F P
s
P
p
.002 w
.56989 .48523 m .59091 .48769 L .57681 .52042 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53477 .53373 m .52838 .54268 L .49486 .53177 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45189 .46652 m .42879 .50083 L .39875 .48196 L p
1 g
F P
s
P
p
.002 w
.39875 .48196 m .42595 .44075 L .45189 .46652 L p
1 g
F P
s
P
p
.002 w
.57079 .41217 m .61048 .41769 L .60228 .45301 L p
1 g
F P
s
P
p
.002 w
.61048 .41769 m .57079 .41217 L .56794 .37598 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56619 .51929 m .5548 .52133 L .54721 .48917 L p
1 g
F P
s
P
p
.002 w
.56303 .34186 m .50456 .35066 L .4929 .32028 L p
1 g
F P
s
P
p
.002 w
.43228 .34781 m .4929 .32028 L .50456 .35066 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.49486 .53177 m .50737 .51391 L .53477 .53373 L p
1 g
F P
s
P
p
.002 w
.54392 .52633 m .53477 .53373 L .50737 .51391 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.50456 .35066 m .56303 .34186 L .56794 .37598 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59091 .48769 m .56989 .48523 L .57145 .44907 L p
1 g
F P
s
P
p
.002 w
.57145 .44907 m .60228 .45301 L .59091 .48769 L p
1 g
F P
s
P
p
.002 w
.50456 .35066 m .44861 .37612 L .43228 .34781 L p
1 g
F P
s
P
p
.002 w
.5548 .52133 m .54392 .52633 L .52552 .49912 L p
1 g
F P
s
P
p
.002 w
.52552 .49912 m .54721 .48917 L .5548 .52133 L p
1 g
F P
s
P
p
.002 w
.50737 .51391 m .52552 .49912 L .54392 .52633 L p
1 g
F P
s
P
p
.002 w
.60228 .45301 m .57145 .44907 L .57079 .41217 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.50737 .51391 m .49486 .53177 L .46123 .51765 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46681 .40659 m .42595 .44075 L .40257 .41492 L p
1 g
F P
s
P
p
.002 w
.40257 .41492 m .44861 .37612 L .46681 .40659 L p
1 g
F P
s
P
p
.002 w
.46123 .51765 m .47938 .49122 L .50737 .51391 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.53803 .45468 m .57145 .44907 L .56989 .48523 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.51627 .38404 m .56794 .37598 L .57079 .41217 L p
1 g
F P
s
P
p
.002 w
.56794 .37598 m .51627 .38404 L .50456 .35066 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52552 .49912 m .50737 .51391 L .47938 .49122 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.44861 .37612 m .50456 .35066 L .51627 .38404 L p
1 g
F P
s
P
p
.004 w
.47262 .37482 m
.47285 .37528 L
s
P
p
.004 w
.47477 .37918 m
.5 .43051 L
s
P
p
.004 w
.4715 .37253 m
.47262 .37482 L
s
P
p
.004 w
.45555 .34008 m
.4715 .37253 L
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54721 .48917 m .52552 .49912 L .50603 .46932 L p
1 g
F P
s
P
p
.002 w
.51627 .38404 m .46681 .40659 L .44861 .37612 L p
1 g
F P
s
P
p
.002 w
.4862 .43807 m .45189 .46652 L .42595 .44075 L p
1 g
F P
s
P
p
.002 w
.42595 .44075 m .46681 .40659 L .4862 .43807 L p
1 g
F P
s
P
p
.002 w
.57145 .44907 m .53803 .45468 L .52758 .41918 L p
1 g
F P
s
P
p
.002 w
.52758 .41918 m .57079 .41217 L .57145 .44907 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.47938 .49122 m .50603 .46932 L .52552 .49912 L p
1 g
F P
s
P
p
.002 w
.57079 .41217 m .52758 .41918 L .51627 .38404 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46681 .40659 m .51627 .38404 L .52758 .41918 L p
1 g
F P
s
P
p
.002 w
.4862 .43807 m .52758 .41918 L .53803 .45468 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52758 .41918 m .4862 .43807 L .46681 .40659 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.58129 .59094 m
.58554 .59931 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .45555 .34008 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .59642 .62078 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.135659)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.135659)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46095 .47767 m .50825 .47202 L .50155 .4445 L p
1 g
F P
s
P
p
.002 w
.50155 .4445 m .4601 .44935 L .46095 .47767 L p
1 g
F P
s
P
p
.002 w
.54068 .42984 m .50155 .4445 L .50825 .47202 L p
1 g
F P
s
P
p
.002 w
.4601 .44935 m .50155 .4445 L .49482 .41673 L p
1 g
F P
s
P
p
.002 w
.50155 .4445 m .54068 .42984 L .52747 .40443 L p
1 g
F P
s
P
p
.002 w
.52747 .40443 m .49482 .41673 L .50155 .4445 L p
1 g
F P
s
P
p
.002 w
.49482 .41673 m .46022 .4207 L .4601 .44935 L p
1 g
F P
s
P
p
.002 w
.46022 .4207 m .49482 .41673 L .48821 .3892 L p
1 g
F P
s
P
p
.002 w
.49482 .41673 m .52747 .40443 L .51355 .3796 L p
1 g
F P
s
P
p
.002 w
.51355 .3796 m .48821 .3892 L .49482 .41673 L p
1 g
F P
s
P
p
.002 w
.55507 .3849 m .52747 .40443 L .54068 .42984 L p
1 g
F P
s
P
p
.002 w
.52747 .40443 m .55507 .3849 L .53489 .3643 L p
1 g
F P
s
P
p
.002 w
.53489 .3643 m .51355 .3796 L .52747 .40443 L p
1 g
F P
s
P
p
.002 w
.50825 .47202 m .55296 .45537 L .54068 .42984 L p
1 g
F P
s
P
p
.002 w
.57393 .40663 m .54068 .42984 L .55296 .45537 L p
1 g
F P
s
P
p
.002 w
.54068 .42984 m .57393 .40663 L .55507 .3849 L p
1 g
F P
s
P
p
.002 w
.4201 .44386 m .4601 .44935 L .46022 .4207 L p
1 g
F P
s
P
p
.002 w
.46022 .4207 m .4269 .4159 L .4201 .44386 L p
1 g
F P
s
P
p
.002 w
.4269 .4159 m .46022 .4207 L .46131 .39223 L p
1 g
F P
s
P
p
.002 w
.48821 .3892 m .46131 .39223 L .46022 .4207 L p
1 g
F P
s
P
p
.002 w
.46276 .50512 m .51482 .49878 L .50825 .47202 L p
1 g
F P
s
P
p
.002 w
.50825 .47202 m .46095 .47767 L .46276 .50512 L p
1 g
F P
s
P
p
.002 w
.55296 .45537 m .50825 .47202 L .51482 .49878 L p
1 g
F P
s
P
p
.002 w
.46131 .39223 m .48821 .3892 L .48181 .36242 L p
1 g
F P
s
P
p
.002 w
.48821 .3892 m .51355 .3796 L .4992 .35579 L p
1 g
F P
s
P
p
.002 w
.4992 .35579 m .48181 .36242 L .48821 .3892 L p
1 g
F P
s
P
p
.002 w
.41521 .47169 m .46095 .47767 L .4601 .44935 L p
1 g
F P
s
P
p
.002 w
.4601 .44935 m .4201 .44386 L .41521 .47169 L p
1 g
F P
s
P
p
.002 w
.51355 .3796 m .53489 .3643 L .51375 .34522 L p
1 g
F P
s
P
p
.002 w
.51375 .34522 m .4992 .35579 L .51355 .3796 L p
1 g
F P
s
P
p
.002 w
.46131 .39223 m .43547 .38833 L .4269 .4159 L p
1 g
F P
s
P
p
.002 w
.43547 .38833 m .46131 .39223 L .46335 .36445 L p
1 g
F P
s
P
p
.002 w
.48181 .36242 m .46335 .36445 L .46131 .39223 L p
1 g
F P
s
P
p
.002 w
.51482 .49878 m .56408 .48055 L .55296 .45537 L p
1 g
F P
s
P
p
.002 w
.59111 .42909 m .55296 .45537 L .56408 .48055 L p
1 g
F P
s
P
p
.002 w
.55296 .45537 m .59111 .42909 L .57393 .40663 L p
1 g
F P
s
P
p
.002 w
.41236 .49886 m .46276 .50512 L .46095 .47767 L p
1 g
F P
s
P
p
.002 w
.46095 .47767 m .41521 .47169 L .41236 .49886 L p
1 g
F P
s
P
p
.002 w
.46552 .53118 m .52113 .52429 L .51482 .49878 L p
1 g
F P
s
P
p
.002 w
.51482 .49878 m .46276 .50512 L .46552 .53118 L p
1 g
F P
s
P
p
.002 w
.56408 .48055 m .51482 .49878 L .52113 .52429 L p
1 g
F P
s
P
p
.002 w
.46335 .36445 m .48181 .36242 L .47576 .33689 L p
1 g
F P
s
P
p
.002 w
.48181 .36242 m .4992 .35579 L .48465 .33348 L p
1 g
F P
s
P
p
.002 w
.48465 .33348 m .47576 .33689 L .48181 .36242 L p
1 g
F P
s
P
p
.002 w
.57489 .35985 m .55507 .3849 L .57393 .40663 L p
1 g
F P
s
P
p
.002 w
.55507 .3849 m .57489 .35985 L .55003 .34473 L p
1 g
F P
s
P
p
.002 w
.55003 .34473 m .53489 .3643 L .55507 .3849 L p
1 g
F P
s
P
p
.002 w
.38532 .42825 m .4201 .44386 L .4269 .4159 L p
1 g
F P
s
P
p
.002 w
.4269 .4159 m .39808 .40258 L .38532 .42825 L p
1 g
F P
s
P
p
.002 w
.39808 .40258 m .4269 .4159 L .43547 .38833 L p
1 g
F P
s
P
p
.002 w
.4992 .35579 m .51375 .34522 L .49205 .32804 L p
1 g
F P
s
P
p
.002 w
.49205 .32804 m .48465 .33348 L .4992 .35579 L p
1 g
F P
s
P
p
.002 w
.53489 .3643 m .55003 .34473 L .52396 .33174 L p
1 g
F P
s
P
p
.002 w
.52396 .33174 m .51375 .34522 L .53489 .3643 L p
1 g
F P
s
P
p
.002 w
.46335 .36445 m .44566 .36167 L .43547 .38833 L p
1 g
F P
s
P
p
.002 w
.44566 .36167 m .46335 .36445 L .46632 .33791 L p
1 g
F P
s
P
p
.002 w
.47576 .33689 m .46632 .33791 L .46335 .36445 L p
1 g
F P
s
P
p
.002 w
.43547 .38833 m .41326 .37777 L .39808 .40258 L p
1 g
F P
s
P
p
.002 w
.41326 .37777 m .43547 .38833 L .44566 .36167 L p
1 g
F P
s
P
p
.002 w
.59804 .3768 m .57393 .40663 L .59111 .42909 L p
1 g
F P
s
P
p
.002 w
.57393 .40663 m .59804 .3768 L .57489 .35985 L p
1 g
F P
s
P
p
.002 w
.37528 .45427 m .41521 .47169 L .4201 .44386 L p
1 g
F P
s
P
p
.002 w
.4201 .44386 m .38532 .42825 L .37528 .45427 L p
1 g
F P
s
P
p
.002 w
.52113 .52429 m .57379 .5049 L .56408 .48055 L p
1 g
F P
s
P
p
.002 w
.60624 .45186 m .56408 .48055 L .57379 .5049 L p
1 g
F P
s
P
p
.002 w
.56408 .48055 m .60624 .45186 L .59111 .42909 L p
1 g
F P
s
P
p
.002 w
.41164 .52482 m .46552 .53118 L .46276 .50512 L p
1 g
F P
s
P
p
.002 w
.46276 .50512 m .41236 .49886 L .41164 .52482 L p
1 g
F P
s
P
p
.002 w
.51375 .34522 m .52396 .33174 L .49717 .32113 L p
1 g
F P
s
P
p
.002 w
.49717 .32113 m .49205 .32804 L .51375 .34522 L p
1 g
F P
s
P
p
.002 w
.44566 .36167 m .43057 .35429 L .41326 .37777 L p
1 g
F P
s
P
p
.002 w
.43057 .35429 m .44566 .36167 L .4573 .33643 L p
1 g
F P
s
P
p
.002 w
.46632 .33791 m .4573 .33643 L .44566 .36167 L p
1 g
F P
s
P
p
.002 w
.619 .39528 m .59111 .42909 L .60624 .45186 L p
1 g
F P
s
P
p
.002 w
.59111 .42909 m .619 .39528 L .59804 .3768 L p
1 g
F P
s
P
p
.002 w
.36821 .48013 m .41236 .49886 L .41521 .47169 L p
1 g
F P
s
P
p
.002 w
.41521 .47169 m .37528 .45427 L .36821 .48013 L p
1 g
F P
s
P
p
.002 w
.4692 .5553 m .52704 .54801 L .52113 .52429 L p
1 g
F P
s
P
p
.002 w
.52113 .52429 m .46552 .53118 L .4692 .5553 L p
1 g
F P
s
P
p
.002 w
.57379 .5049 m .52113 .52429 L .52704 .54801 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .46632 .33791 L .47576 .33689 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .47576 .33689 L .48465 .33348 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .48465 .33348 L .49205 .32804 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .4573 .33643 L .46632 .33791 L closepath p
1 g
F P
s
P
p
.002 w
.55728 .32277 m .55003 .34473 L .57489 .35985 L p
1 g
F P
s
P
p
.002 w
.55003 .34473 m .55728 .32277 L .52869 .31669 L p
1 g
F P
s
P
p
.002 w
.52869 .31669 m .52396 .33174 L .55003 .34473 L p
1 g
F P
s
P
p
.002 w
.37681 .38178 m .39808 .40258 L .41326 .37777 L p
1 g
F P
s
P
p
.002 w
.41326 .37777 m .39705 .36145 L .37681 .38178 L p
1 g
F P
s
P
p
.002 w
.39705 .36145 m .41326 .37777 L .43057 .35429 L p
1 g
F P
s
P
p
.002 w
.52396 .33174 m .52869 .31669 L .49946 .31346 L p
1 g
F P
s
P
p
.002 w
.49946 .31346 m .49717 .32113 L .52396 .33174 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .49205 .32804 L .49717 .32113 L closepath p
1 g
F P
s
P
p
.002 w
.58466 .33158 m .57489 .35985 L .59804 .3768 L p
1 g
F P
s
P
p
.002 w
.57489 .35985 m .58466 .33158 L .55728 .32277 L p
1 g
F P
s
P
p
.002 w
.43057 .35429 m .41968 .343 L .39705 .36145 L p
1 g
F P
s
P
p
.002 w
.41968 .343 m .43057 .35429 L .44966 .33259 L p
1 g
F P
s
P
p
.002 w
.4573 .33643 m .44966 .33259 L .43057 .35429 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .44966 .33259 L .4573 .33643 L closepath p
1 g
F P
s
P
p
.002 w
.52704 .54801 m .58187 .52793 L .57379 .5049 L p
1 g
F P
s
P
p
.002 w
.619 .47451 m .57379 .5049 L .58187 .52793 L p
1 g
F P
s
P
p
.002 w
.57379 .5049 m .619 .47451 L .60624 .45186 L p
1 g
F P
s
P
p
.002 w
.35942 .40362 m .38532 .42825 L .39808 .40258 L p
1 g
F P
s
P
p
.002 w
.39808 .40258 m .37681 .38178 L .35942 .40362 L p
1 g
F P
s
P
p
.002 w
.41315 .549 m .4692 .5553 L .46552 .53118 L p
1 g
F P
s
P
p
.002 w
.46552 .53118 m .41164 .52482 L .41315 .549 L p
1 g
F P
s
P
p
.002 w
.63732 .41495 m .60624 .45186 L .619 .47451 L p
1 g
F P
s
P
p
.002 w
.60624 .45186 m .63732 .41495 L .619 .39528 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .49717 .32113 L .49946 .31346 L closepath p
1 g
F P
s
P
p
.002 w
.44966 .33259 m .44422 .32678 L .41968 .343 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .44422 .32678 L .44966 .33259 L closepath p
1 g
F P
s
P
p
.002 w
.36435 .50527 m .41164 .52482 L .41236 .49886 L p
1 g
F P
s
P
p
.002 w
.41236 .49886 m .36821 .48013 L .36435 .50527 L p
1 g
F P
s
P
p
.002 w
.61025 .343 m .59804 .3768 L .619 .39528 L p
1 g
F P
s
P
p
.002 w
.59804 .3768 m .61025 .343 L .58466 .33158 L p
1 g
F P
s
P
p
.002 w
.3453 .42652 m .37528 .45427 L .38532 .42825 L p
1 g
F P
s
P
p
.002 w
.38532 .42825 m .35942 .40362 L .3453 .42652 L p
1 g
F P
s
P
p
.002 w
.49863 .30585 m .49946 .31346 L .52869 .31669 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .49946 .31346 L .49863 .30585 L closepath p
1 g
F P
s
P
p
.002 w
.5273 .30164 m .52869 .31669 L .55728 .32277 L p
1 g
F P
s
P
p
.002 w
.52869 .31669 m .5273 .30164 L .49863 .30585 L p
1 g
F P
s
P
p
.002 w
.41426 .3289 m .41968 .343 L .44422 .32678 L p
1 g
F P
s
P
p
.002 w
.44422 .32678 m .4416 .3196 L .41426 .3289 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .4416 .3196 L .44422 .32678 L closepath p
1 g
F P
s
P
p
.002 w
.38876 .34088 m .39705 .36145 L .41968 .343 L p
1 g
F P
s
P
p
.002 w
.41968 .343 m .41426 .3289 L .38876 .34088 L p
1 g
F P
s
P
p
.002 w
.47376 .57691 m .53244 .56941 L .52704 .54801 L p
1 g
F P
s
P
p
.002 w
.52704 .54801 m .4692 .5553 L .47376 .57691 L p
1 g
F P
s
P
p
.002 w
.58187 .52793 m .52704 .54801 L .53244 .56941 L p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .44572 .30427 L .4421 .31181 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .4421 .31181 L .4416 .3196 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .46052 .29316 L .45209 .2978 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .45209 .2978 L .44572 .30427 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .49863 .30585 L .49474 .29912 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .49474 .29912 L .48817 .29403 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .48817 .29403 L .47963 .29117 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .47963 .29117 L .47005 .29086 L closepath p
1 g
F P
s
P
p
.002 w
.47019 .31313 m .47005 .29086 L .46052 .29316 L closepath p
1 g
F P
s
P
p
.002 w
.55561 .30063 m .55728 .32277 L .58466 .33158 L p
1 g
F P
s
P
p
.002 w
.55728 .32277 m .55561 .30063 L .5273 .30164 L p
1 g
F P
s
P
p
.002 w
.36567 .35534 m .37681 .38178 L .39705 .36145 L p
1 g
F P
s
P
p
.002 w
.39705 .36145 m .38876 .34088 L .36567 .35534 L p
1 g
F P
s
P
p
.002 w
.63348 .35684 m .619 .39528 L .63732 .41495 L p
1 g
F P
s
P
p
.002 w
.619 .39528 m .63348 .35684 L .61025 .343 L p
1 g
F P
s
P
p
.002 w
.49474 .29912 m .49863 .30585 L .5273 .30164 L p
1 g
F P
s
P
p
.002 w
.41503 .31348 m .41426 .3289 L .4416 .3196 L p
1 g
F P
s
P
p
.002 w
.4416 .3196 m .4421 .31181 L .41503 .31348 L p
1 g
F P
s
P
p
.002 w
.58187 .52793 m .62905 .49658 L .619 .47451 L p
1 g
F P
s
P
p
.002 w
.65252 .43543 m .619 .47451 L .62905 .49658 L p
1 g
F P
s
P
p
.002 w
.619 .47451 m .65252 .43543 L .63732 .41495 L p
1 g
F P
s
P
p
.002 w
.33487 .45002 m .36821 .48013 L .37528 .45427 L p
1 g
F P
s
P
p
.002 w
.37528 .45427 m .3453 .42652 L .33487 .45002 L p
1 g
F P
s
P
p
.002 w
.53244 .56941 m .5881 .54912 L .58187 .52793 L p
1 g
F P
s
P
p
.002 w
.62905 .49658 m .58187 .52793 L .5881 .54912 L p
1 g
F P
s
P
p
.002 w
.41693 .57081 m .47376 .57691 L .4692 .5553 L p
1 g
F P
s
P
p
.002 w
.4692 .5553 m .41315 .549 L .41693 .57081 L p
1 g
F P
s
P
p
.002 w
.3639 .52913 m .41315 .549 L .41164 .52482 L p
1 g
F P
s
P
p
.002 w
.41164 .52482 m .36435 .50527 L .3639 .52913 L p
1 g
F P
s
P
p
.002 w
.58294 .30291 m .58466 .33158 L .61025 .343 L p
1 g
F P
s
P
p
.002 w
.58466 .33158 m .58294 .30291 L .55561 .30063 L p
1 g
F P
s
P
p
.002 w
.5273 .30164 m .5198 .28822 L .49474 .29912 L p
1 g
F P
s
P
p
.002 w
.48817 .29403 m .49474 .29912 L .5198 .28822 L p
1 g
F P
s
P
p
.002 w
.5198 .28822 m .5273 .30164 L .55561 .30063 L p
1 g
F P
s
P
p
.002 w
.42207 .29841 m .41503 .31348 L .4421 .31181 L p
1 g
F P
s
P
p
.002 w
.4421 .31181 m .44572 .30427 L .42207 .29841 L p
1 g
F P
s
P
p
.002 w
.34556 .37203 m .35942 .40362 L .37681 .38178 L p
1 g
F P
s
P
p
.002 w
.37681 .38178 m .36567 .35534 L .34556 .37203 L p
1 g
F P
s
P
p
.002 w
.38958 .31817 m .38876 .34088 L .41426 .3289 L p
1 g
F P
s
P
p
.002 w
.41426 .3289 m .41503 .31348 L .38958 .31817 L p
1 g
F P
s
P
p
.002 w
.5198 .28822 m .50687 .27797 L .48817 .29403 L p
1 g
F P
s
P
p
.002 w
.47963 .29117 m .48817 .29403 L .50687 .27797 L p
1 g
F P
s
P
p
.002 w
.4347 .28543 m .42207 .29841 L .44572 .30427 L p
1 g
F P
s
P
p
.002 w
.44572 .30427 m .45209 .2978 L .4347 .28543 L p
1 g
F P
s
P
p
.002 w
.65375 .37287 m .63732 .41495 L .65252 .43543 L p
1 g
F P
s
P
p
.002 w
.63732 .41495 m .65375 .37287 L .63348 .35684 L p
1 g
F P
s
P
p
.002 w
.60869 .30851 m .61025 .343 L .63348 .35684 L p
1 g
F P
s
P
p
.002 w
.61025 .343 m .60869 .30851 L .58294 .30291 L p
1 g
F P
s
P
p
.002 w
.32848 .47361 m .36435 .50527 L .36821 .48013 L p
1 g
F P
s
P
p
.002 w
.36821 .48013 m .33487 .45002 L .32848 .47361 L p
1 g
F P
s
P
p
.002 w
.50687 .27797 m .48986 .27214 L .47963 .29117 L p
1 g
F P
s
P
p
.002 w
.47005 .29086 m .47963 .29117 L .48986 .27214 L p
1 g
F P
s
P
p
.002 w
.45155 .27607 m .4347 .28543 L .45209 .2978 L p
1 g
F P
s
P
p
.002 w
.45209 .2978 m .46052 .29316 L .45155 .27607 L p
1 g
F P
s
P
p
.002 w
.54485 .28073 m .55561 .30063 L .58294 .30291 L p
1 g
F P
s
P
p
.002 w
.55561 .30063 m .54485 .28073 L .5198 .28822 L p
1 g
F P
s
P
p
.002 w
.47915 .59545 m .53717 .58794 L .53244 .56941 L p
1 g
F P
s
P
p
.002 w
.53244 .56941 m .47376 .57691 L .47915 .59545 L p
1 g
F P
s
P
p
.002 w
.5881 .54912 m .53244 .56941 L .53717 .58794 L p
1 g
F P
s
P
p
.002 w
.48986 .27214 m .47068 .27146 L .47005 .29086 L p
1 g
F P
s
P
p
.002 w
.46052 .29316 m .47005 .29086 L .47068 .27146 L p
1 g
F P
s
P
p
.002 w
.36636 .32588 m .36567 .35534 L .38876 .34088 L p
1 g
F P
s
P
p
.002 w
.38876 .34088 m .38958 .31817 L .36636 .32588 L p
1 g
F P
s
P
p
.002 w
.47068 .27146 m .45155 .27607 L .46052 .29316 L p
1 g
F P
s
P
p
.002 w
.329 .39065 m .3453 .42652 L .35942 .40362 L p
1 g
F P
s
P
p
.002 w
.35942 .40362 m .34556 .37203 L .329 .39065 L p
1 g
F P
s
P
p
.002 w
.50687 .27797 m .5198 .28822 L .54485 .28073 L p
1 g
F P
s
P
p
.002 w
.39977 .2958 m .38958 .31817 L .41503 .31348 L p
1 g
F P
s
P
p
.002 w
.41503 .31348 m .42207 .29841 L .39977 .2958 L p
1 g
F P
s
P
p
.002 w
.5881 .54912 m .63607 .51757 L .62905 .49658 L p
1 g
F P
s
P
p
.002 w
.66418 .45629 m .62905 .49658 L .63607 .51757 L p
1 g
F P
s
P
p
.002 w
.62905 .49658 m .66418 .45629 L .65252 .43543 L p
1 g
F P
s
P
p
.002 w
.367 .55109 m .41693 .57081 L .41315 .549 L p
1 g
F P
s
P
p
.002 w
.41315 .549 m .3639 .52913 L .367 .55109 L p
1 g
F P
s
P
p
.002 w
.53717 .58794 m .59226 .56793 L .5881 .54912 L p
1 g
F P
s
P
p
.002 w
.63607 .51757 m .5881 .54912 L .59226 .56793 L p
1 g
F P
s
P
p
.002 w
.42301 .58966 m .47915 .59545 L .47376 .57691 L p
1 g
F P
s
P
p
.002 w
.47376 .57691 m .41693 .57081 L .42301 .58966 L p
1 g
F P
s
P
p
.002 w
.56934 .27694 m .58294 .30291 L .60869 .30851 L p
1 g
F P
s
P
p
.002 w
.58294 .30291 m .56934 .27694 L .54485 .28073 L p
1 g
F P
s
P
p
.002 w
.63221 .31743 m .63348 .35684 L .65375 .37287 L p
1 g
F P
s
P
p
.002 w
.63348 .35684 m .63221 .31743 L .60869 .30851 L p
1 g
F P
s
P
p
.002 w
.67053 .3908 m .65252 .43543 L .66418 .45629 L p
1 g
F P
s
P
p
.002 w
.65252 .43543 m .67053 .3908 L .65375 .37287 L p
1 g
F P
s
P
p
.002 w
.54485 .28073 m .5259 .26541 L .50687 .27797 L p
1 g
F P
s
P
p
.002 w
.48986 .27214 m .50687 .27797 L .5259 .26541 L p
1 g
F P
s
P
p
.002 w
.41843 .27642 m .39977 .2958 L .42207 .29841 L p
1 g
F P
s
P
p
.002 w
.42207 .29841 m .4347 .28543 L .41843 .27642 L p
1 g
F P
s
P
p
.002 w
.346 .33656 m .34556 .37203 L .36567 .35534 L p
1 g
F P
s
P
p
.002 w
.36567 .35534 m .36636 .32588 L .346 .33656 L p
1 g
F P
s
P
p
.002 w
.31651 .41084 m .33487 .45002 L .3453 .42652 L p
1 g
F P
s
P
p
.002 w
.3453 .42652 m .329 .39065 L .31651 .41084 L p
1 g
F P
s
P
p
.002 w
.32647 .49672 m .3639 .52913 L .36435 .50527 L p
1 g
F P
s
P
p
.002 w
.36435 .50527 m .32848 .47361 L .32647 .49672 L p
1 g
F P
s
P
p
.002 w
.5259 .26541 m .54485 .28073 L .56934 .27694 L p
1 g
F P
s
P
p
.002 w
.37939 .29665 m .36636 .32588 L .38958 .31817 L p
1 g
F P
s
P
p
.002 w
.38958 .31817 m .39977 .2958 L .37939 .29665 L p
1 g
F P
s
P
p
.002 w
.5259 .26541 m .5007 .25661 L .48986 .27214 L p
1 g
F P
s
P
p
.002 w
.47068 .27146 m .48986 .27214 L .5007 .25661 L p
1 g
F P
s
P
p
.002 w
.44353 .26241 m .41843 .27642 L .4347 .28543 L p
1 g
F P
s
P
p
.002 w
.4347 .28543 m .45155 .27607 L .44353 .26241 L p
1 g
F P
s
P
p
.002 w
.59226 .56793 m .63976 .53697 L .63607 .51757 L p
1 g
F P
s
P
p
.002 w
.67187 .47709 m .63607 .51757 L .63976 .53697 L p
1 g
F P
s
P
p
.002 w
.63607 .51757 m .67187 .47709 L .66418 .45629 L p
1 g
F P
s
P
p
.002 w
.5007 .25661 m .4721 .25553 L .47068 .27146 L p
1 g
F P
s
P
p
.002 w
.45155 .27607 m .47068 .27146 L .4721 .25553 L p
1 g
F P
s
P
p
.002 w
.48528 .61032 m .54111 .60302 L .53717 .58794 L p
1 g
F P
s
P
p
.002 w
.53717 .58794 m .47915 .59545 L .48528 .61032 L p
1 g
F P
s
P
p
.002 w
.59226 .56793 m .53717 .58794 L .54111 .60302 L p
1 g
F P
s
P
p
.002 w
.4721 .25553 m .44353 .26241 L .45155 .27607 L p
1 g
F P
s
P
p
.002 w
.37375 .57055 m .42301 .58966 L .41693 .57081 L p
1 g
F P
s
P
p
.002 w
.41693 .57081 m .367 .55109 L .37375 .57055 L p
1 g
F P
s
P
p
.002 w
.59268 .27707 m .60869 .30851 L .63221 .31743 L p
1 g
F P
s
P
p
.002 w
.60869 .30851 m .59268 .27707 L .56934 .27694 L p
1 g
F P
s
P
p
.002 w
.65288 .32956 m .65375 .37287 L .67053 .3908 L p
1 g
F P
s
P
p
.002 w
.65375 .37287 m .65288 .32956 L .63221 .31743 L p
1 g
F P
s
P
p
.002 w
.32912 .35007 m .329 .39065 L .34556 .37203 L p
1 g
F P
s
P
p
.002 w
.34556 .37203 m .346 .33656 L .32912 .35007 L p
1 g
F P
s
P
p
.002 w
.54111 .60302 m .59415 .58382 L .59226 .56793 L p
1 g
F P
s
P
p
.002 w
.63976 .53697 m .59226 .56793 L .59415 .58382 L p
1 g
F P
s
P
p
.002 w
.68326 .41029 m .66418 .45629 L .67187 .47709 L p
1 g
F P
s
P
p
.002 w
.66418 .45629 m .68326 .41029 L .67053 .3908 L p
1 g
F P
s
P
p
.002 w
.43135 .60494 m .48528 .61032 L .47915 .59545 L p
1 g
F P
s
P
p
.002 w
.47915 .59545 m .42301 .58966 L .43135 .60494 L p
1 g
F P
s
P
p
.002 w
.30857 .43216 m .32848 .47361 L .33487 .45002 L p
1 g
F P
s
P
p
.002 w
.33487 .45002 m .31651 .41084 L .30857 .43216 L p
1 g
F P
s
P
p
.002 w
.56934 .27694 m .54484 .25679 L .5259 .26541 L p
1 g
F P
s
P
p
.002 w
.5007 .25661 m .5259 .26541 L .54484 .25679 L p
1 g
F P
s
P
p
.002 w
.40372 .27117 m .37939 .29665 L .39977 .2958 L p
1 g
F P
s
P
p
.002 w
.39977 .2958 m .41843 .27642 L .40372 .27117 L p
1 g
F P
s
P
p
.002 w
.32907 .51876 m .367 .55109 L .3639 .52913 L p
1 g
F P
s
P
p
.002 w
.3639 .52913 m .32647 .49672 L .32907 .51876 L p
1 g
F P
s
P
p
.002 w
.54484 .25679 m .56934 .27694 L .59268 .27707 L p
1 g
F P
s
P
p
.002 w
.36154 .30111 m .346 .33656 L .36636 .32588 L p
1 g
F P
s
P
p
.002 w
.36636 .32588 m .37939 .29665 L .36154 .30111 L p
1 g
F P
s
P
p
.002 w
.54484 .25679 m .51191 .24512 L .5007 .25661 L p
1 g
F P
s
P
p
.002 w
.4721 .25553 m .5007 .25661 L .51191 .24512 L p
1 g
F P
s
P
p
.002 w
.61426 .28129 m .63221 .31743 L .65288 .32956 L p
1 g
F P
s
P
p
.002 w
.63221 .31743 m .61426 .28129 L .59268 .27707 L p
1 g
F P
s
P
p
.002 w
.43669 .25269 m .40372 .27117 L .41843 .27642 L p
1 g
F P
s
P
p
.002 w
.41843 .27642 m .44353 .26241 L .43669 .25269 L p
1 g
F P
s
P
p
.002 w
.67005 .34476 m .67053 .3908 L .68326 .41029 L p
1 g
F P
s
P
p
.002 w
.67053 .3908 m .67005 .34476 L .65288 .32956 L p
1 g
F P
s
P
p
.002 w
.31632 .36622 m .31651 .41084 L .329 .39065 L p
1 g
F P
s
P
p
.002 w
.329 .39065 m .32912 .35007 L .31632 .36622 L p
1 g
F P
s
P
p
.002 w
.59415 .58382 m .63987 .55422 L .63976 .53697 L p
1 g
F P
s
P
p
.002 w
.67524 .49733 m .63976 .53697 L .63987 .55422 L p
1 g
F P
s
P
p
.002 w
.63976 .53697 m .67524 .49733 L .67187 .47709 L p
1 g
F P
s
P
p
.002 w
.38417 .58687 m .43135 .60494 L .42301 .58966 L p
1 g
F P
s
P
p
.002 w
.42301 .58966 m .37375 .57055 L .38417 .58687 L p
1 g
F P
s
P
p
.002 w
.30561 .4541 m .32647 .49672 L .32848 .47361 L p
1 g
F P
s
P
p
.002 w
.32848 .47361 m .30857 .43216 L .30561 .4541 L p
1 g
F P
s
P
p
.002 w
.51191 .24512 m .47432 .24363 L .4721 .25553 L p
1 g
F P
s
P
p
.002 w
.44353 .26241 m .4721 .25553 L .47432 .24363 L p
1 g
F P
s
P
p
.002 w
.47432 .24363 m .43669 .25269 L .44353 .26241 L p
1 g
F P
s
P
p
.002 w
.49204 .62095 m .5441 .6141 L .54111 .60302 L p
1 g
F P
s
P
p
.002 w
.54111 .60302 m .48528 .61032 L .49204 .62095 L p
1 g
F P
s
P
p
.002 w
.59415 .58382 m .54111 .60302 L .5441 .6141 L p
1 g
F P
s
P
p
.002 w
.69146 .43091 m .67187 .47709 L .67524 .49733 L p
1 g
F P
s
P
p
.002 w
.67187 .47709 m .69146 .43091 L .68326 .41029 L p
1 g
F P
s
P
p
.002 w
.56324 .25251 m .59268 .27707 L .61426 .28129 L p
1 g
F P
s
P
p
.002 w
.59268 .27707 m .56324 .25251 L .54484 .25679 L p
1 g
F P
s
P
p
.002 w
.51191 .24512 m .54484 .25679 L .56324 .25251 L p
1 g
F P
s
P
p
.002 w
.33643 .5391 m .37375 .57055 L .367 .55109 L p
1 g
F P
s
P
p
.002 w
.367 .55109 m .32907 .51876 L .33643 .5391 L p
1 g
F P
s
P
p
.002 w
.5441 .6141 m .59359 .59623 L .59415 .58382 L p
1 g
F P
s
P
p
.002 w
.63987 .55422 m .59415 .58382 L .59359 .59623 L p
1 g
F P
s
P
p
.002 w
.39104 .27002 m .36154 .30111 L .37939 .29665 L p
1 g
F P
s
P
p
.002 w
.37939 .29665 m .40372 .27117 L .39104 .27002 L p
1 g
F P
s
P
p
.002 w
.34679 .30925 m .32912 .35007 L .346 .33656 L p
1 g
F P
s
P
p
.002 w
.346 .33656 m .36154 .30111 L .34679 .30925 L p
1 g
F P
s
P
p
.002 w
.44187 .61607 m .49204 .62095 L .48528 .61032 L p
1 g
F P
s
P
p
.002 w
.48528 .61032 m .43135 .60494 L .44187 .61607 L p
1 g
F P
s
P
p
.002 w
.63346 .2897 m .65288 .32956 L .67005 .34476 L p
1 g
F P
s
P
p
.002 w
.65288 .32956 m .63346 .2897 L .61426 .28129 L p
1 g
F P
s
P
p
.002 w
.68314 .36277 m .68326 .41029 L .69146 .43091 L p
1 g
F P
s
P
p
.002 w
.68326 .41029 m .68314 .36277 L .67005 .34476 L p
1 g
F P
s
P
p
.002 w
.30815 .3847 m .30857 .43216 L .31651 .41084 L p
1 g
F P
s
P
p
.002 w
.31651 .41084 m .31632 .36622 L .30815 .3847 L p
1 g
F P
s
P
p
.002 w
.30795 .4761 m .32907 .51876 L .32647 .49672 L p
1 g
F P
s
P
p
.002 w
.32647 .49672 m .30561 .4541 L .30795 .4761 L p
1 g
F P
s
P
p
.002 w
.56324 .25251 m .52324 .23819 L .51191 .24512 L p
1 g
F P
s
P
p
.002 w
.47432 .24363 m .51191 .24512 L .52324 .23819 L p
1 g
F P
s
P
p
.002 w
.43129 .2474 m .39104 .27002 L .40372 .27117 L p
1 g
F P
s
P
p
.002 w
.40372 .27117 m .43669 .25269 L .43129 .2474 L p
1 g
F P
s
P
p
.002 w
.59359 .59623 m .63619 .56879 L .63987 .55422 L p
1 g
F P
s
P
p
.002 w
.67398 .51645 m .63987 .55422 L .63619 .56879 L p
1 g
F P
s
P
p
.002 w
.63987 .55422 m .67398 .51645 L .67524 .49733 L p
1 g
F P
s
P
p
.002 w
.39816 .59947 m .44187 .61607 L .43135 .60494 L p
1 g
F P
s
P
p
.002 w
.43135 .60494 m .38417 .58687 L .39816 .59947 L p
1 g
F P
s
P
p
.002 w
.6947 .45219 m .67524 .49733 L .67398 .51645 L p
1 g
F P
s
P
p
.002 w
.67524 .49733 m .6947 .45219 L .69146 .43091 L p
1 g
F P
s
P
p
.002 w
.58059 .25292 m .61426 .28129 L .63346 .2897 L p
1 g
F P
s
P
p
.002 w
.61426 .28129 m .58059 .25292 L .56324 .25251 L p
1 g
F P
s
P
p
.002 w
.34859 .55709 m .38417 .58687 L .37375 .57055 L p
1 g
F P
s
P
p
.002 w
.37375 .57055 m .33643 .5391 L .34859 .55709 L p
1 g
F P
s
P
p
.002 w
.52324 .23819 m .47734 .23632 L .47432 .24363 L p
1 g
F P
s
P
p
.002 w
.43669 .25269 m .47432 .24363 L .47734 .23632 L p
1 g
F P
s
P
p
.002 w
.47734 .23632 m .43129 .2474 L .43669 .25269 L p
1 g
F P
s
P
p
.002 w
.49931 .62682 m .54602 .62064 L .5441 .6141 L p
1 g
F P
s
P
p
.002 w
.5441 .6141 m .49204 .62095 L .49931 .62682 L p
1 g
F P
s
P
p
.002 w
.59359 .59623 m .5441 .6141 L .54602 .62064 L p
1 g
F P
s
P
p
.002 w
.33572 .32108 m .31632 .36622 L .32912 .35007 L p
1 g
F P
s
P
p
.002 w
.32912 .35007 m .34679 .30925 L .33572 .32108 L p
1 g
F P
s
P
p
.002 w
.52324 .23819 m .56324 .25251 L .58059 .25292 L p
1 g
F P
s
P
p
.002 w
.38083 .27326 m .34679 .30925 L .36154 .30111 L p
1 g
F P
s
P
p
.002 w
.36154 .30111 m .39104 .27002 L .38083 .27326 L p
1 g
F P
s
P
p
.002 w
.54602 .62064 m .59044 .60463 L .59359 .59623 L p
1 g
F P
s
P
p
.002 w
.63619 .56879 m .59359 .59623 L .59044 .60463 L p
1 g
F P
s
P
p
.002 w
.64962 .30226 m .67005 .34476 L .68314 .36277 L p
1 g
F P
s
P
p
.002 w
.67005 .34476 m .64962 .30226 L .63346 .2897 L p
1 g
F P
s
P
p
.002 w
.45441 .62251 m .49931 .62682 L .49204 .62095 L p
1 g
F P
s
P
p
.002 w
.49204 .62095 m .44187 .61607 L .45441 .62251 L p
1 g
F P
s
P
p
.002 w
.30509 .40512 m .30561 .4541 L .30857 .43216 L p
1 g
F P
s
P
p
.002 w
.30857 .43216 m .30815 .3847 L .30509 .40512 L p
1 g
F P
s
P
p
.002 w
.69158 .38324 m .69146 .43091 L .6947 .45219 L p
1 g
F P
s
P
p
.002 w
.69146 .43091 m .69158 .38324 L .68314 .36277 L p
1 g
F P
s
P
p
.002 w
.31578 .49754 m .33643 .5391 L .32907 .51876 L p
1 g
F P
s
P
p
.002 w
.32907 .51876 m .30795 .4761 L .31578 .49754 L p
1 g
F P
s
P
p
.002 w
.58059 .25292 m .5344 .23629 L .52324 .23819 L p
1 g
F P
s
P
p
.002 w
.47734 .23632 m .52324 .23819 L .5344 .23629 L p
1 g
F P
s
P
p
.002 w
.42757 .24698 m .38083 .27326 L .39104 .27002 L p
1 g
F P
s
P
p
.002 w
.39104 .27002 m .43129 .2474 L .42757 .24698 L p
1 g
F P
s
P
p
.002 w
.59636 .25826 m .63346 .2897 L .64962 .30226 L p
1 g
F P
s
P
p
.002 w
.63346 .2897 m .59636 .25826 L .58059 .25292 L p
1 g
F P
s
P
p
.002 w
.63619 .56879 m .66788 .53389 L .67398 .51645 L p
1 g
F P
s
P
p
.002 w
.69263 .47358 m .67398 .51645 L .66788 .53389 L p
1 g
F P
s
P
p
.002 w
.67398 .51645 m .69263 .47358 L .6947 .45219 L p
1 g
F P
s
P
p
.002 w
.59044 .60463 m .6286 .58011 L .63619 .56879 L p
1 g
F P
s
P
p
.002 w
.66788 .53389 m .63619 .56879 L .6286 .58011 L p
1 g
F P
s
P
p
.002 w
.41552 .60776 m .45441 .62251 L .44187 .61607 L p
1 g
F P
s
P
p
.002 w
.44187 .61607 m .39816 .59947 L .41552 .60776 L p
1 g
F P
s
P
p
.002 w
.36543 .57209 m .39816 .59947 L .38417 .58687 L p
1 g
F P
s
P
p
.002 w
.38417 .58687 m .34859 .55709 L .36543 .57209 L p
1 g
F P
s
P
p
.002 w
.32888 .33646 m .30815 .3847 L .31632 .36622 L p
1 g
F P
s
P
p
.002 w
.31632 .36622 m .33572 .32108 L .32888 .33646 L p
1 g
F P
s
P
p
.002 w
.5344 .23629 m .58059 .25292 L .59636 .25826 L p
1 g
F P
s
P
p
.002 w
.68314 .36277 m .66216 .31886 L .64962 .30226 L p
1 g
F P
s
P
p
.002 w
.66216 .31886 m .68314 .36277 L .69158 .38324 L p
1 g
F P
s
P
p
.002 w
.37356 .28108 m .33572 .32108 L .34679 .30925 L p
1 g
F P
s
P
p
.002 w
.34679 .30925 m .38083 .27326 L .37356 .28108 L p
1 g
F P
s
P
p
.002 w
.5344 .23629 m .48111 .2341 L .47734 .23632 L p
1 g
F P
s
P
p
.002 w
.43129 .2474 m .47734 .23632 L .48111 .2341 L p
1 g
F P
s
P
p
.002 w
.48111 .2341 m .42757 .24698 L .43129 .2474 L p
1 g
F P
s
P
p
.002 w
.50691 .62745 m .54675 .62218 L .54602 .62064 L p
1 g
F P
s
P
p
.002 w
.54602 .62064 m .49931 .62682 L .50691 .62745 L p
1 g
F P
s
P
p
.002 w
.59044 .60463 m .54602 .62064 L .54675 .62218 L p
1 g
F P
s
P
p
.004 w
.55095 .63112 m
.55735 .65631 L
s
P
p
.002 w
.30749 .42695 m .30795 .4761 L .30561 .4541 L p
1 g
F P
s
P
p
.002 w
.30561 .4541 m .30509 .40512 L .30749 .42695 L p
1 g
F P
s
P
p
.002 w
.6947 .45219 m .6949 .40569 L .69158 .38324 L p
1 g
F P
s
P
p
.002 w
.6949 .40569 m .6947 .45219 L .69263 .47358 L p
1 g
F P
s
P
p
.002 w
.54675 .62218 m .58463 .60853 L .59044 .60463 L p
1 g
F P
s
P
p
.002 w
.6286 .58011 m .59044 .60463 L .58463 .60853 L p
1 g
F P
s
P
p
.002 w
.46875 .62379 m .50691 .62745 L .49931 .62682 L p
1 g
F P
s
P
p
.002 w
.49931 .62682 m .45441 .62251 L .46875 .62379 L p
1 g
F P
s
P
p
.002 w
.32912 .51773 m .34859 .55709 L .33643 .5391 L p
1 g
F P
s
P
p
.002 w
.33643 .5391 m .31578 .49754 L .32912 .51773 L p
1 g
F P
s
P
p
.002 w
.64962 .30226 m .61001 .26867 L .59636 .25826 L p
1 g
F P
s
P
p
.002 w
.61001 .26867 m .64962 .30226 L .66216 .31886 L p
1 g
F P
s
P
p
.002 w
.6286 .58011 m .65684 .54907 L .66788 .53389 L p
1 g
F P
s
P
p
.002 w
.66788 .53389 m .68507 .49446 L .69263 .47358 L p
1 g
F P
s
P
p
.002 w
.68507 .49446 m .66788 .53389 L .65684 .54907 L p
1 g
F P
s
P
p
.002 w
.32671 .35513 m .30509 .40512 L .30815 .3847 L p
1 g
F P
s
P
p
.002 w
.30815 .3847 m .32888 .33646 L .32671 .35513 L p
1 g
F P
s
P
p
.002 w
.59636 .25826 m .54506 .23979 L .5344 .23629 L p
1 g
F P
s
P
p
.002 w
.48111 .2341 m .5344 .23629 L .54506 .23979 L p
1 g
F P
s
P
p
.002 w
.38668 .5835 m .41552 .60776 L .39816 .59947 L p
1 g
F P
s
P
p
.002 w
.39816 .59947 m .36543 .57209 L .38668 .5835 L p
1 g
F P
s
P
p
.002 w
.58463 .60853 m .61708 .58768 L .6286 .58011 L p
1 g
F P
s
P
p
.002 w
.65684 .54907 m .6286 .58011 L .61708 .58768 L p
1 g
F P
s
P
p
.002 w
.42575 .25177 m .37356 .28108 L .38083 .27326 L p
1 g
F P
s
P
p
.002 w
.38083 .27326 m .42757 .24698 L .42575 .25177 L p
1 g
F P
s
P
p
.002 w
.6705 .3392 m .69158 .38324 L .6949 .40569 L p
1 g
F P
s
P
p
.002 w
.69158 .38324 m .6705 .3392 L .66216 .31886 L p
1 g
F P
s
P
p
.002 w
.43592 .61128 m .46875 .62379 L .45441 .62251 L p
1 g
F P
s
P
p
.002 w
.45441 .62251 m .41552 .60776 L .43592 .61128 L p
1 g
F P
s
P
p
.002 w
.54506 .23979 m .59636 .25826 L .61001 .26867 L p
1 g
F P
s
P
p
.002 w
.31555 .4496 m .31578 .49754 L .30795 .4761 L p
1 g
F P
s
P
p
.002 w
.30795 .4761 m .30749 .42695 L .31555 .4496 L p
1 g
F P
s
P
p
.002 w
.36963 .29353 m .32888 .33646 L .33572 .32108 L p
1 g
F P
s
P
p
.002 w
.33572 .32108 m .37356 .28108 L .36963 .29353 L p
1 g
F P
s
P
p
.002 w
.69278 .42957 m .69263 .47358 L .68507 .49446 L p
1 g
F P
s
P
p
.002 w
.69263 .47358 m .69278 .42957 L .6949 .40569 L p
1 g
F P
s
P
p
.002 w
.34783 .53599 m .36543 .57209 L .34859 .55709 L p
1 g
F P
s
P
p
.002 w
.34859 .55709 m .32912 .51773 L .34783 .53599 L p
1 g
F P
s
P
p
.002 w
.54506 .23979 m .4856 .23737 L .48111 .2341 L p
1 g
F P
s
P
p
.002 w
.42757 .24698 m .48111 .2341 L .4856 .23737 L p
1 g
F P
s
P
p
.002 w
.4856 .23737 m .42575 .25177 L .42757 .24698 L p
1 g
F P
s
P
p
.002 w
.51464 .62249 m .54617 .61833 L .54675 .62218 L p
1 g
F P
s
P
p
.002 w
.54675 .62218 m .50691 .62745 L .51464 .62249 L p
1 g
F P
s
P
p
.002 w
.58463 .60853 m .54675 .62218 L .54617 .61833 L p
1 g
F P
s
P
p
.002 w
.54617 .61833 m .57616 .60751 L .58463 .60853 L p
1 g
F P
s
P
p
.002 w
.61708 .58768 m .58463 .60853 L .57616 .60751 L p
1 g
F P
s
P
p
.002 w
.48456 .61956 m .51464 .62249 L .50691 .62745 L p
1 g
F P
s
P
p
.002 w
.50691 .62745 m .46875 .62379 L .48456 .61956 L p
1 g
F P
s
P
p
.002 w
.62102 .28413 m .66216 .31886 L .6705 .3392 L p
1 g
F P
s
P
p
.002 w
.66216 .31886 m .62102 .28413 L .61001 .26867 L p
1 g
F P
s
P
p
.002 w
.61708 .58768 m .64091 .56141 L .65684 .54907 L p
1 g
F P
s
P
p
.002 w
.67195 .51419 m .65684 .54907 L .64091 .56141 L p
1 g
F P
s
P
p
.002 w
.65684 .54907 m .67195 .51419 L .68507 .49446 L p
1 g
F P
s
P
p
.002 w
.32955 .37667 m .30749 .42695 L .30509 .40512 L p
1 g
F P
s
P
p
.002 w
.30509 .40512 m .32671 .35513 L .32955 .37667 L p
1 g
F P
s
P
p
.002 w
.67418 .36285 m .6949 .40569 L .69278 .42957 L p
1 g
F P
s
P
p
.002 w
.6949 .40569 m .67418 .36285 L .6705 .3392 L p
1 g
F P
s
P
p
.002 w
.41186 .5908 m .43592 .61128 L .41552 .60776 L p
1 g
F P
s
P
p
.002 w
.41552 .60776 m .38668 .5835 L .41186 .5908 L p
1 g
F P
s
P
p
.002 w
.32928 .47237 m .32912 .51773 L .31578 .49754 L p
1 g
F P
s
P
p
.002 w
.31578 .49754 m .31555 .4496 L .32928 .47237 L p
1 g
F P
s
P
p
.002 w
.57616 .60751 m .60174 .59103 L .61708 .58768 L p
1 g
F P
s
P
p
.002 w
.64091 .56141 m .61708 .58768 L .60174 .59103 L p
1 g
F P
s
P
p
.002 w
.61001 .26867 m .55487 .24891 L .54506 .23979 L p
1 g
F P
s
P
p
.002 w
.4856 .23737 m .54506 .23979 L .55487 .24891 L p
1 g
F P
s
P
p
.002 w
.685 .4542 m .68507 .49446 L .67195 .51419 L p
1 g
F P
s
P
p
.002 w
.68507 .49446 m .685 .4542 L .69278 .42957 L p
1 g
F P
s
P
p
.002 w
.45887 .60966 m .48456 .61956 L .46875 .62379 L p
1 g
F P
s
P
p
.002 w
.46875 .62379 m .43592 .61128 L .45887 .60966 L p
1 g
F P
s
P
p
.002 w
.426 .26197 m .36963 .29353 L .37356 .28108 L p
1 g
F P
s
P
p
.002 w
.37356 .28108 m .42575 .25177 L .426 .26197 L p
1 g
F P
s
P
p
.002 w
.55487 .24891 m .61001 .26867 L .62102 .28413 L p
1 g
F P
s
P
p
.002 w
.3715 .55164 m .38668 .5835 L .36543 .57209 L p
1 g
F P
s
P
p
.002 w
.36543 .57209 m .34783 .53599 L .3715 .55164 L p
1 g
F P
s
P
p
.002 w
.36937 .3105 m .32671 .35513 L .32888 .33646 L p
1 g
F P
s
P
p
.002 w
.32888 .33646 m .36963 .29353 L .36937 .3105 L p
1 g
F P
s
P
p
.002 w
.55487 .24891 m .49069 .24639 L .4856 .23737 L p
1 g
F P
s
P
p
.002 w
.42575 .25177 m .4856 .23737 L .49069 .24639 L p
1 g
F P
s
P
p
.002 w
.49069 .24639 m .426 .26197 L .42575 .25177 L p
1 g
F P
s
P
p
.002 w
.62888 .30441 m .6705 .3392 L .67418 .36285 L p
1 g
F P
s
P
p
.002 w
.6705 .3392 m .62888 .30441 L .62102 .28413 L p
1 g
F P
s
P
p
.002 w
.52227 .61172 m .54423 .60884 L .54617 .61833 L p
1 g
F P
s
P
p
.002 w
.54617 .61833 m .51464 .62249 L .52227 .61172 L p
1 g
F P
s
P
p
.002 w
.57616 .60751 m .54617 .61833 L .54423 .60884 L p
1 g
F P
s
P
p
.002 w
.67286 .3892 m .69278 .42957 L .685 .4542 L p
1 g
F P
s
P
p
.002 w
.69278 .42957 m .67286 .3892 L .67418 .36285 L p
1 g
F P
s
P
p
.002 w
.54423 .60884 m .5651 .60129 L .57616 .60751 L p
1 g
F P
s
P
p
.002 w
.60174 .59103 m .57616 .60751 L .5651 .60129 L p
1 g
F P
s
P
p
.002 w
.33754 .40053 m .31555 .4496 L .30749 .42695 L p
1 g
F P
s
P
p
.002 w
.30749 .42695 m .32955 .37667 L .33754 .40053 L p
1 g
F P
s
P
p
.002 w
.50142 .60963 m .52227 .61172 L .51464 .62249 L p
1 g
F P
s
P
p
.002 w
.51464 .62249 m .48456 .61956 L .50142 .60963 L p
1 g
F P
s
P
p
.002 w
.60174 .59103 m .62034 .57037 L .64091 .56141 L p
1 g
F P
s
P
p
.002 w
.65343 .53208 m .64091 .56141 L .62034 .57037 L p
1 g
F P
s
P
p
.002 w
.64091 .56141 m .65343 .53208 L .67195 .51419 L p
1 g
F P
s
P
p
.002 w
.34845 .4945 m .34783 .53599 L .32912 .51773 L p
1 g
F P
s
P
p
.002 w
.32912 .51773 m .32928 .47237 L .34845 .4945 L p
1 g
F P
s
P
p
.002 w
.44032 .59357 m .45887 .60966 L .43592 .61128 L p
1 g
F P
s
P
p
.002 w
.43592 .61128 m .41186 .5908 L .44032 .59357 L p
1 g
F P
s
P
p
.002 w
.67159 .4788 m .67195 .51419 L .65343 .53208 L p
1 g
F P
s
P
p
.002 w
.67195 .51419 m .67159 .4788 L .685 .4542 L p
1 g
F P
s
P
p
.002 w
.39955 .56407 m .41186 .5908 L .38668 .5835 L p
1 g
F P
s
P
p
.002 w
.38668 .5835 m .3715 .55164 L .39955 .56407 L p
1 g
F P
s
P
p
.002 w
.5651 .60129 m .58282 .58982 L .60174 .59103 L p
1 g
F P
s
P
p
.002 w
.62034 .57037 m .60174 .59103 L .58282 .58982 L p
1 g
F P
s
P
p
.002 w
.56346 .26373 m .62102 .28413 L .62888 .30441 L p
1 g
F P
s
P
p
.002 w
.62102 .28413 m .56346 .26373 L .55487 .24891 L p
1 g
F P
s
P
p
.002 w
.49069 .24639 m .55487 .24891 L .56346 .26373 L p
1 g
F P
s
P
p
.002 w
.48377 .6027 m .50142 .60963 L .48456 .61956 L p
1 g
F P
s
P
p
.002 w
.48456 .61956 m .45887 .60966 L .48377 .6027 L p
1 g
F P
s
P
p
.002 w
.42846 .27758 m .36937 .3105 L .36963 .29353 L p
1 g
F P
s
P
p
.002 w
.36963 .29353 m .426 .26197 L .42846 .27758 L p
1 g
F P
s
P
p
.002 w
.373 .33169 m .32955 .37667 L .32671 .35513 L p
1 g
F P
s
P
p
.002 w
.32671 .35513 m .36937 .3105 L .373 .33169 L p
1 g
F P
s
P
p
.002 w
.63317 .32911 m .67418 .36285 L .67286 .3892 L p
1 g
F P
s
P
p
.002 w
.67418 .36285 m .63317 .32911 L .62888 .30441 L p
1 g
F P
s
P
p
.002 w
.66637 .41747 m .685 .4542 L .67159 .4788 L p
1 g
F P
s
P
p
.002 w
.685 .4542 m .66637 .41747 L .67286 .3892 L p
1 g
F P
s
P
p
.002 w
.35066 .42597 m .32928 .47237 L .31555 .4496 L p
1 g
F P
s
P
p
.002 w
.31555 .4496 m .33754 .40053 L .35066 .42597 L p
1 g
F P
s
P
p
.002 w
.37261 .51519 m .3715 .55164 L .34783 .53599 L p
1 g
F P
s
P
p
.002 w
.34783 .53599 m .34845 .4945 L .37261 .51519 L p
1 g
F P
s
P
p
.002 w
.58282 .58982 m .59556 .5755 L .62034 .57037 L p
1 g
F P
s
P
p
.002 w
.62989 .54748 m .62034 .57037 L .59556 .5755 L p
1 g
F P
s
P
p
.002 w
.62034 .57037 m .62989 .54748 L .65343 .53208 L p
1 g
F P
s
P
p
.002 w
.56346 .26373 m .49627 .26125 L .49069 .24639 L p
1 g
F P
s
P
p
.002 w
.426 .26197 m .49069 .24639 L .49627 .26125 L p
1 g
F P
s
P
p
.002 w
.49627 .26125 m .42846 .27758 L .426 .26197 L p
1 g
F P
s
P
p
.002 w
.65277 .50257 m .65343 .53208 L .62989 .54748 L p
1 g
F P
s
P
p
.002 w
.65343 .53208 m .65277 .50257 L .67159 .4788 L p
1 g
F P
s
P
p
.002 w
.47122 .59154 m .48377 .6027 L .45887 .60966 L p
1 g
F P
s
P
p
.002 w
.45887 .60966 m .44032 .59357 L .47122 .59154 L p
1 g
F P
s
P
p
.002 w
.52955 .59514 m .54089 .59367 L .54423 .60884 L p
1 g
F P
s
P
p
.002 w
.54423 .60884 m .52227 .61172 L .52955 .59514 L p
1 g
F P
s
P
p
.002 w
.5651 .60129 m .54423 .60884 L .54089 .59367 L p
1 g
F P
s
P
p
.002 w
.43114 .57272 m .44032 .59357 L .41186 .5908 L p
1 g
F P
s
P
p
.002 w
.41186 .5908 m .39955 .56407 L .43114 .57272 L p
1 g
F P
s
P
p
.002 w
.54089 .59367 m .55167 .58976 L .5651 .60129 L p
1 g
F P
s
P
p
.002 w
.58282 .58982 m .5651 .60129 L .55167 .58976 L p
1 g
F P
s
P
p
.002 w
.51882 .59402 m .52955 .59514 L .52227 .61172 L p
1 g
F P
s
P
p
.002 w
.52227 .61172 m .50142 .60963 L .51882 .59402 L p
1 g
F P
s
P
p
.002 w
.57047 .28407 m .62888 .30441 L .63317 .32911 L p
1 g
F P
s
P
p
.002 w
.62888 .30441 m .57047 .28407 L .56346 .26373 L p
1 g
F P
s
P
p
.002 w
.55167 .58976 m .56077 .58381 L .58282 .58982 L p
1 g
F P
s
P
p
.002 w
.59556 .5755 m .58282 .58982 L .56077 .58381 L p
1 g
F P
s
P
p
.002 w
.50983 .5904 m .51882 .59402 L .50142 .60963 L p
1 g
F P
s
P
p
.002 w
.50142 .60963 m .48377 .6027 L .50983 .5904 L p
1 g
F P
s
P
p
.002 w
.3806 .35657 m .33754 .40053 L .32955 .37667 L p
1 g
F P
s
P
p
.002 w
.32955 .37667 m .373 .33169 L .3806 .35657 L p
1 g
F P
s
P
p
.002 w
.49627 .26125 m .56346 .26373 L .57047 .28407 L p
1 g
F P
s
P
p
.002 w
.65474 .44678 m .67159 .4788 L .65277 .50257 L p
1 g
F P
s
P
p
.002 w
.67159 .4788 m .65474 .44678 L .66637 .41747 L p
1 g
F P
s
P
p
.002 w
.63357 .35756 m .67286 .3892 L .66637 .41747 L p
1 g
F P
s
P
p
.002 w
.67286 .3892 m .63357 .35756 L .63317 .32911 L p
1 g
F P
s
P
p
.002 w
.43317 .2984 m .373 .33169 L .36937 .3105 L p
1 g
F P
s
P
p
.002 w
.36937 .3105 m .42846 .27758 L .43317 .2984 L p
1 g
F P
s
P
p
.002 w
.40102 .53366 m .39955 .56407 L .3715 .55164 L p
1 g
F P
s
P
p
.002 w
.3715 .55164 m .37261 .51519 L .40102 .53366 L p
1 g
F P
s
P
p
.002 w
.36864 .45215 m .34845 .4945 L .32928 .47237 L p
1 g
F P
s
P
p
.002 w
.32928 .47237 m .35066 .42597 L .36864 .45215 L p
1 g
F P
s
P
p
.002 w
.59556 .5755 m .60191 .55976 L .62989 .54748 L p
1 g
F P
s
P
p
.002 w
.62901 .52464 m .62989 .54748 L .60191 .55976 L p
1 g
F P
s
P
p
.002 w
.62989 .54748 m .62901 .52464 L .65277 .50257 L p
1 g
F P
s
P
p
.002 w
.56077 .58381 m .56723 .57644 L .59556 .5755 L p
1 g
F P
s
P
p
.002 w
.60191 .55976 m .59556 .5755 L .56723 .57644 L p
1 g
F P
s
P
p
.002 w
.46524 .57722 m .47122 .59154 L .44032 .59357 L p
1 g
F P
s
P
p
.002 w
.44032 .59357 m .43114 .57272 L .46524 .57722 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50354 .58464 m .50983 .5904 L .48377 .6027 L p
1 g
F P
s
P
p
.002 w
.48377 .6027 m .47122 .59154 L .50354 .58464 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52823 .54165 L
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.57047 .28407 m .50218 .28177 L .49627 .26125 L p
1 g
F P
s
P
p
.002 w
.42846 .27758 m .49627 .26125 L .50218 .28177 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63823 .4761 m .65277 .50257 L .62901 .52464 L p
1 g
F P
s
P
p
.002 w
.65277 .50257 m .63823 .4761 L .65474 .44678 L p
1 g
F P
s
P
p
.002 w
.50218 .28177 m .43317 .2984 L .42846 .27758 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.54089 .59367 m .52955 .59514 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.55167 .58976 m .54089 .59367 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.56077 .58381 m .55167 .58976 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.57558 .30951 m .63317 .32911 L .63357 .35756 L p
1 g
F P
s
P
p
.002 w
.63317 .32911 m .57558 .30951 L .57047 .28407 L p
1 g
F P
s
P
p
.002 w
.52955 .59514 m .51882 .59402 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.43276 .5492 m .43114 .57272 L .39955 .56407 L p
1 g
F P
s
P
p
.002 w
.39955 .56407 m .40102 .53366 L .43276 .5492 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.62993 .38891 m .66637 .41747 L .65474 .44678 L p
1 g
F P
s
P
p
.002 w
.66637 .41747 m .62993 .38891 L .63357 .35756 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.39208 .3844 m .35066 .42597 L .33754 .40053 L p
1 g
F P
s
P
p
.002 w
.33754 .40053 m .3806 .35657 L .39208 .3844 L p
1 g
F P
s
P
p
.002 w
.56723 .57644 m .56077 .58381 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.56723 .57644 m .57034 .5684 L .60191 .55976 L p
1 g
F P
s
P
p
.002 w
.60102 .54422 m .60191 .55976 L .57034 .5684 L p
1 g
F P
s
P
p
.002 w
.60191 .55976 m .60102 .54422 L .62901 .52464 L p
1 g
F P
s
P
p
.002 w
.51882 .59402 m .50983 .5904 L .53445 .57414 L p
1 g
F P
s
P
p
.002 w
.50983 .5904 m .50354 .58464 L .51506 .58053 L p
1 g
F P
s
P
p
.002 w
.50354 .58464 m .47122 .59154 L p
.49334 .58087 L 1 g
F P
s
P
p
.002 w
.50227 .58139 m .50354 .58464 L p
.49334 .58087 L 1 g
F P
s
P
p
.002 w
.51506 .58053 m .50354 .58464 L .50293 .58308 L p
1 g
F P
s
P
p
.002 w
.50293 .58308 m .50227 .58139 L p
.51095 .58081 L 1 g
F P
s
P
p
.50293 .58308 m .51095 .58081 L .51506 .58053 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58081 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58081 L .52082 .57801 L 1 g
F
P
p
.002 w
.51095 .58081 m .51079 .57862 L p
.49424 .58193 L 1 g
F P
s
P
p
.002 w
.52709 .57624 m .51506 .58053 L p
.51331 .58014 L 1 g
F P
s
P
p
.002 w
.53177 .57491 m .53128 .57265 L p
.52076 .57805 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53619 .57299 m .53445 .57414 L p
.53177 .57491 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53177 .57491 L p
1 g
F P
s
P
p
.54854 .56129 m .53177 .57491 L .53182 .57488 L 1 g
F
P
p
.002 w
.53359 .57392 m .53619 .57299 L p
.53177 .57491 L 1 g
F P
s
P
p
.54854 .56129 m .53182 .57488 L .53531 .57298 L 1 g
F
P
p
.002 w
.53542 .57291 m .53619 .57299 L .53502 .57314 L p
1 g
F P
s
P
p
.53538 .57294 m .53531 .57298 L .53538 .57294 L 1 g
F
P
p
.54854 .56129 m .53531 .57298 L .53538 .57294 L 1 g
F
P
p
.54854 .56129 m .53538 .57294 L .5355 .57287 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.50068 .57732 m .5016 .56922 L .53542 .57291 L p
1 g
F P
s
P
p
.53182 .57488 m .53359 .57392 L .53591 .57265 L 1 g
F
P
p
.54854 .56129 m .53549 .57288 L .53561 .5728 L 1 g
F
P
p
.002 w
.53619 .57299 m .53752 .5715 L p
.54757 .56508 L 1 g
F P
s
P
p
.002 w
.56537 .55372 m .54684 .56596 L p
.54757 .56508 L 1 g
F P
s
P
p
.002 w
.54684 .56596 m .53619 .57299 L p
.54757 .56508 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54922 .56311 L p
1 g
F P
s
P
p
.56075 .54566 m .54922 .56311 L .55488 .5563 L 1 g
F
P
p
.54854 .56129 m .53559 .57282 L .53598 .57257 L 1 g
F
P
p
.002 w
.53619 .57243 m .53619 .57299 L .53598 .57257 L p
1 g
F P
s
P
p
.53609 .5725 m .53598 .57257 L .53608 .57251 L 1 g
F
P
p
.54854 .56129 m .53598 .57257 L .53609 .5725 L 1 g
F
P
p
.54854 .56129 m .53608 .57251 L .53639 .57229 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52452 .54901 m .53609 .54619 L .53619 .57243 L p
1 g
F P
s
P
p
.002 w
.53598 .57257 m .52452 .54901 L p
.53619 .57243 L 1 g
F P
s
P
p
.54854 .56129 m .53633 .57235 L .53878 .57059 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53609 .54619 m .54759 .5461 L .53653 .5722 L p
1 g
F P
s
P
p
.002 w
.53653 .5722 m .53619 .57299 L .53619 .57243 L p
1 g
F P
s
P
p
.002 w
.53619 .57243 m .53609 .54619 L p
.53653 .5722 L 1 g
F P
s
P
p
.53639 .57229 m .53608 .57251 L .53633 .57235 L 1 g
F
P
p
.53878 .57059 m .53633 .57235 L .53817 .57117 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56376 .55267 m .56537 .55372 L p
.54757 .56508 L 1 g
F P
s
P
p
.54922 .56311 m .54757 .56508 L .53752 .5715 L 1 g
F
P
p
.56376 .55267 m .54757 .56508 L .54922 .56311 L 1 g
F
P
p
.56075 .54566 m .55488 .5563 L .55997 .55019 L 1 g
F
P
p
.002 w
.56537 .55372 m .56075 .55069 L p
.57537 .52697 L 1 g
F P
s
P
p
.002 w
.56075 .55069 m .55997 .55019 L p
.56174 .54753 L 1 g
F P
s
P
p
.57537 .52697 m .56075 .55069 L .56174 .54753 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56174 .54753 L p
1 g
F P
s
P
p
.56654 .52734 m .56174 .54753 L .56424 .53955 L 1 g
F
P
p
.002 w
.57048 .51844 m .57782 .52042 L .56776 .53459 L p
1 g
F P
s
P
p
.002 w
.56776 .53459 m .56424 .53955 L p
.56745 .52867 L 1 g
F P
s
P
p
.57048 .51844 m .56776 .53459 L .56745 .52867 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56745 .52867 L p
1 g
F P
s
P
p
.56515 .50826 m .56745 .52867 L .56704 .52053 L 1 g
F
P
p
.56654 .52734 m .56424 .53955 L .56443 .53888 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.57782 .52042 m .57537 .52697 L .56365 .54141 L 1 g
F
P
p
.002 w
.55772 .54871 m .56424 .53955 L p
.56365 .54141 L 1 g
F P
s
P
p
.002 w
.56424 .53955 m .57782 .52042 L p
.56365 .54141 L 1 g
F P
s
P
p
.002 w
.56174 .54753 m .56075 .54566 L p
.55997 .55019 L 1 g
F P
s
P
p
.002 w
.55997 .55019 m .55772 .54871 L p
.57537 .52697 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56758 .52885 L p
1 g
F P
s
P
p
.002 w
.56758 .52885 m .56654 .52734 L p
.56442 .53896 L 1 g
F P
s
P
p
.56442 .53896 m .56257 .5491 L .56758 .52885 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56515 .50826 m .56704 .52053 L .56689 .51747 L 1 g
F
P
p
.002 w
.56406 .4899 m .56633 .48083 L p
.56679 .51088 L 1 g
F P
s
P
p
.56679 .51088 m .56689 .51747 L .56605 .50933 L 1 g
F
P
p
.56679 .51088 m .56605 .50933 L .56406 .4899 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56605 .50933 L p
1 g
F P
s
P
p
.002 w
.57782 .52042 m .57037 .51841 L p
.56633 .48083 L 1 g
F P
s
P
p
.002 w
.57037 .51841 m .56689 .51747 L p
.56679 .51088 L 1 g
F P
s
P
p
.56633 .48083 m .57037 .51841 L .56679 .51088 L 1 g
F
P
p
.55661 .4905 m .56202 .50086 L .56156 .49989 L 1 g
F
P
p
.002 w
.5522 .4808 m .56633 .48083 L .56247 .49625 L p
1 g
F P
s
P
p
.002 w
.56247 .49625 m .56156 .49989 L p
.55734 .49128 L 1 g
F P
s
P
p
.5522 .4808 m .56247 .49625 L .55734 .49128 L 1 g
F
P
p
.002 w
.55734 .49128 m .55661 .4905 L p
.56156 .49989 L 1 g
F P
s
P
p
.55661 .4905 m .56605 .50933 L .56202 .50086 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55734 .49128 L p
1 g
F P
s
P
p
.002 w
.5576 .49155 m .55734 .49128 L p
.56156 .49989 L 1 g
F P
s
P
p
.54174 .47608 m .55734 .49128 L .54995 .48412 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53253 .48076 m .54651 .48078 L p
.55778 .51502 L 1 g
F P
s
P
p
.54174 .47608 m .54995 .48412 L .54651 .48078 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54651 .48078 m .53253 .48076 L .53168 .47168 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .4767 L p
1 g
F P
s
P
p
.52214 .46667 m .54231 .4767 L .53331 .47245 L 1 g
F
P
p
.54231 .4767 m .54651 .48078 L .53168 .47168 L 1 g
F
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53168 .47168 m .53253 .48076 L p
.51121 .46542 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46708 L p
1 g
F P
s
P
p
.5 .4634 m .52239 .46708 L .50822 .46498 L 1 g
F
P
p
.49389 .45297 m .52239 .46708 L .51121 .46542 L 1 g
F
P
p
.52239 .46708 m .53168 .47168 L .51121 .46542 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48494 .45514 m .49389 .45297 L p
.51121 .46542 L 1 g
F P
s
P
p
.50132 .46396 m .51121 .46542 L .53253 .48076 L 1 g
F
P
p
.002 w
.5 .46376 m .5 .4634 L p
.50822 .46498 L 1 g
F P
s
P
p
.48494 .45514 m .51121 .46542 L .50132 .46396 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.53253 .48076 m .49841 .48903 L .48908 .46556 L p
1 g
F P
s
P
p
.47786 .46667 m .48958 .46548 L .48908 .46556 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48908 .46556 m .49841 .48903 L p
.46446 .47341 L 1 g
F P
s
P
p
.002 w
.45775 .47664 m .45826 .47608 L p
.46568 .47282 L 1 g
F P
s
P
p
.47761 .46709 m .48908 .46556 L .46446 .47341 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47761 .46709 L p
1 g
F P
s
P
p
.002 w
.47761 .46709 m .47718 .46778 L p
.46568 .47282 L 1 g
F P
s
P
p
.45826 .47608 m .47761 .46709 L .46568 .47282 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.44591 .47554 m .45676 .46987 L p
.46446 .47341 L 1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.45617 .47818 m .46446 .47341 L .49841 .48903 L 1 g
F
P
p
.45775 .47664 m .46446 .47341 L .45617 .47818 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43409 .50916 m .43485 .50826 L p
.43737 .50237 L 1 g
F P
s
P
p
.43015 .50335 m .44279 .49114 L .43679 .50358 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44279 .49114 L p
1 g
F P
s
P
p
.002 w
.44279 .49114 m .44166 .49233 L p
.43737 .50237 L 1 g
F P
s
P
p
.43485 .50826 m .44279 .49114 L .43737 .50237 L 1 g
F
P
p
.41688 .50291 m .44502 .48652 L .43015 .50335 L 1 g
F
P
p
.44591 .47554 m .46061 .47386 L .45511 .47791 L 1 g
F
P
p
.46061 .47386 m .46446 .47341 L .45775 .47664 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45775 .47664 L p
1 g
F P
s
P
p
.46061 .47386 m .45775 .47664 L .45511 .47791 L 1 g
F
P
p
.44339 .4905 m .45775 .47664 L .45359 .48069 L 1 g
F
P
p
.002 w
.49841 .48903 m .46818 .50463 L .45145 .48277 L p
1 g
F P
s
P
p
.45617 .47818 m .49841 .48903 L .45145 .48277 L 1 g
F
P
p
.44339 .4905 m .45739 .47704 L .45057 .48362 L 1 g
F
P
p
.002 w
.45145 .48277 m .44591 .47554 L p
.45617 .47818 L 1 g
F P
s
P
p
.002 w
.45145 .48277 m .46818 .50463 L p
.43679 .50358 L 1 g
F P
s
P
p
.44279 .49114 m .45145 .48277 L .43679 .50358 L 1 g
F
P
p
.002 w
.45739 .47704 m .45698 .47747 L p
.45099 .48322 L 1 g
F P
s
P
p
.45057 .48362 m .45145 .48277 L .45099 .48322 L 1 g
F
P
p
.45145 .48277 m .45739 .47704 L .45099 .48322 L 1 g
F
P
p
.002 w
.45775 .47664 m .45739 .47704 L p
.45359 .48069 L 1 g
F P
s
P
p
.002 w
.44279 .49114 m .44339 .4905 L p
.45057 .48362 L 1 g
F P
s
P
p
.44502 .48652 m .45145 .48277 L .44279 .49114 L 1 g
F
P
p
.44502 .48652 m .44279 .49114 L .43015 .50335 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43336 .51597 m .41688 .50291 L p
.4347 .50351 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43369 .50965 L p
1 g
F P
s
P
p
.002 w
.40102 .53366 m .41688 .50291 L .43336 .51597 L p
1 g
F P
s
P
p
.40102 .53366 m .43336 .51597 L .43275 .52788 L 1 g
F
P
p
.002 w
.43369 .50965 m .43287 .51061 L p
.43318 .5194 L 1 g
F P
s
P
p
.43346 .52734 m .43369 .50965 L .43318 .5194 L 1 g
F
P
p
.002 w
.43168 .54867 m .40102 .53366 L p
.43258 .52791 L 1 g
F P
s
P
p
.43258 .52791 m .43275 .52788 L .43272 .52842 L 1 g
F
P
p
.43258 .52791 m .43272 .52842 L .43168 .54867 L 1 g
F
P
p
.43925 .54566 m .43543 .53811 L .43656 .54213 L 1 g
F
P
p
.002 w
.43276 .5492 m .43568 .54377 L p
.43879 .54864 L 1 g
F P
s
P
p
.002 w
.43568 .54377 m .43656 .54213 L p
.43835 .54736 L 1 g
F P
s
P
p
.43568 .54377 m .43835 .54736 L .43879 .54864 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43835 .54736 L p
1 g
F P
s
P
p
.45146 .56129 m .43835 .54736 L .44221 .55254 L 1 g
F
P
p
.43114 .57272 m .44061 .55545 L .4532 .56558 L 1 g
F
P
p
.44061 .55545 m .44221 .55254 L .45088 .56284 L 1 g
F
P
p
.44061 .55545 m .45088 .56284 L .4532 .56558 L 1 g
F
P
p
.46872 .57265 m .45931 .56889 L .46559 .57341 L 1 g
F
P
p
.002 w
.46524 .57722 m .46552 .57412 L p
.47033 .5761 L 1 g
F P
s
P
p
.002 w
.46552 .57412 m .46559 .57341 L p
.46823 .57491 L 1 g
F P
s
P
p
.46552 .57412 m .46823 .57491 L .47033 .5761 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46823 .57491 L p
1 g
F P
s
P
p
.48921 .57862 m .46823 .57491 L .47631 .57725 L 1 g
F
P
p
.47122 .59154 m .47539 .57982 L .49216 .58143 L 1 g
F
P
p
.47539 .57982 m .47631 .57725 L .48906 .58062 L 1 g
F
P
p
.47539 .57982 m .48906 .58062 L .49216 .58143 L 1 g
F
P
p
.49279 .58222 m .48889 .583 L .5042 .5815 L 1 g
F
P
p
.50309 .58144 m .5042 .5815 L .51096 .58084 L 1 g
F
P
p
.49279 .58222 m .5042 .5815 L .50309 .58144 L 1 g
F
P
p
.478 .5777 m .47631 .57725 L .47778 .57768 L 1 g
F
P
p
.48921 .57862 m .47631 .57725 L .478 .5777 L 1 g
F
P
p
.002 w
.47122 .59154 m .46524 .57722 L .47631 .57725 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.47631 .57725 m .46524 .57722 L p
.47147 .57585 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58095 L p
1 g
F P
s
P
p
.002 w
.48904 .58095 m .48921 .57862 L p
.47778 .57768 L 1 g
F P
s
P
p
.47778 .57768 m .4678 .57686 L .48904 .58095 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.5016 .56922 m .50068 .57732 L .47631 .57725 L p
1 g
F P
s
P
p
.47147 .57585 m .5016 .56922 L .47631 .57725 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58062 L p
1 g
F P
s
P
p
.49216 .58143 m .48906 .58062 L .49334 .58087 L 1 g
F
P
p
.002 w
.48906 .58062 m .48889 .583 L p
.49814 .58115 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58062 L .49814 .58115 L 1 g
F
P
p
.002 w
.47631 .57725 m .50068 .57732 L p
.49334 .58087 L 1 g
F P
s
P
p
.48906 .58062 m .47631 .57725 L .49334 .58087 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.4667 .5612 m .5016 .56922 L p
.47033 .5761 L 1 g
F P
s
P
p
.002 w
.46823 .57491 m .46872 .57265 L p
.46559 .57341 L 1 g
F P
s
P
p
.002 w
.46524 .57722 m .43114 .57272 L p
.45423 .56524 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45088 .56284 L p
1 g
F P
s
P
p
.46872 .57265 m .45088 .56284 L .45931 .56889 L 1 g
F
P
p
.002 w
.4667 .5612 m .46559 .57341 L p
.45423 .56524 L 1 g
F P
s
P
p
.002 w
.46559 .57341 m .46524 .57722 L p
.45423 .56524 L 1 g
F P
s
P
p
.45146 .56129 m .44221 .55254 L .44444 .55519 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43114 .57272 m .43276 .5492 L .44221 .55254 L p
1 g
F P
s
P
p
.002 w
.44221 .55254 m .43276 .5492 L p
.43927 .54859 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45055 .56375 L p
1 g
F P
s
P
p
.002 w
.45055 .56375 m .45146 .56129 L p
.4437 .55455 L 1 g
F P
s
P
p
.4437 .55455 m .43743 .5491 L .45055 .56375 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.47564 .54524 m .4667 .5612 L .44221 .55254 L p
1 g
F P
s
P
p
.43927 .54859 m .47564 .54524 L .44221 .55254 L 1 g
F
P
p
.002 w
.44221 .55254 m .4667 .5612 L p
.4532 .56558 L 1 g
F P
s
P
p
.002 w
.45088 .56284 m .45002 .56518 L p
.45931 .56889 L 1 g
F P
s
P
p
.002 w
.46559 .57341 m .4667 .5612 L p
.47033 .5761 L 1 g
F P
s
P
p
.002 w
.46823 .57491 m .4678 .57686 L p
.47778 .57768 L 1 g
F P
s
P
p
.002 w
.46815 .57525 m .46823 .57491 L p
.46559 .57341 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46815 .57525 L p
1 g
F P
s
P
p
.45931 .56889 m .45002 .56518 L .46815 .57525 L 1 g
F
P
p
.44444 .55519 m .44221 .55254 L .4437 .55455 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44547 .52556 m .47564 .54524 L p
.43879 .54864 L 1 g
F P
s
P
p
.002 w
.43835 .54736 m .43925 .54566 L p
.43656 .54213 L 1 g
F P
s
P
p
.002 w
.43276 .5492 m .43168 .54867 L p
.43625 .54102 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43272 .52842 L p
1 g
F P
s
P
p
.43925 .54566 m .43272 .52842 L .43543 .53811 L 1 g
F
P
p
.002 w
.44547 .52556 m .43656 .54213 L p
.43625 .54102 L 1 g
F P
s
P
p
.002 w
.43656 .54213 m .43276 .5492 L p
.43625 .54102 L 1 g
F P
s
P
p
.002 w
.43272 .52842 m .43346 .52734 L p
.43318 .5194 L 1 g
F P
s
P
p
.43275 .52788 m .44547 .52556 L .43168 .54867 L 1 g
F
P
p
.002 w
.43272 .52842 m .43146 .53025 L p
.43543 .53811 L 1 g
F P
s
P
p
.002 w
.43656 .54213 m .44547 .52556 L p
.43879 .54864 L 1 g
F P
s
P
p
.002 w
.43835 .54736 m .43743 .5491 L p
.4437 .55455 L 1 g
F P
s
P
p
.002 w
.43814 .54776 m .43835 .54736 L p
.43656 .54213 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43814 .54776 L p
1 g
F P
s
P
p
.43543 .53811 m .43146 .53025 L .43814 .54776 L 1 g
F
P
p
.002 w
.43189 .52962 m .43272 .52842 L p
.43314 .51805 L 1 g
F P
s
P
p
.43318 .5194 m .43314 .51805 L .43272 .52842 L 1 g
F
P
p
.002 w
.43336 .51597 m .44547 .52556 L p
.43275 .52788 L 1 g
F P
s
P
p
.002 w
.46818 .50463 m .44547 .52556 L .43336 .51597 L p
1 g
F P
s
P
p
.4347 .50351 m .46818 .50463 L .43336 .51597 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43189 .52962 L p
1 g
F P
s
P
p
.43314 .51805 m .43287 .51061 L .43189 .52962 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43409 .50916 L p
1 g
F P
s
P
p
.43737 .50237 m .44166 .49233 L .43409 .50916 L 1 g
F
P
p
.002 w
.41688 .50291 m .44591 .47554 L .45145 .48277 L p
1 g
F P
s
P
p
.002 w
.44207 .49191 m .44279 .49114 L p
.45099 .48322 L 1 g
F P
s
P
p
.45057 .48362 m .45099 .48322 L .44279 .49114 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44207 .49191 L p
1 g
F P
s
P
p
.45099 .48322 m .45698 .47747 L .44207 .49191 L 1 g
F
P
p
.45511 .47791 m .45775 .47664 L .45617 .47818 L 1 g
F
P
p
.45676 .46987 m .47761 .46709 L .46446 .47341 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45775 .47664 L p
1 g
F P
s
P
p
.46568 .47282 m .47718 .46778 L .45775 .47664 L 1 g
F
P
p
.002 w
.47737 .46749 m .47761 .46709 L p
.48908 .46556 L 1 g
F P
s
P
p
.002 w
.47761 .46709 m .47786 .46667 L p
.48908 .46556 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.50073 .46364 m .53253 .48076 L .48908 .46556 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.45676 .46987 m .48494 .45514 L .48908 .46556 L p
1 g
F P
s
P
p
.002 w
.48908 .46556 m .48494 .45514 L p
.50073 .46364 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47737 .46749 L p
1 g
F P
s
P
p
.48958 .46548 m .5 .46442 L .47737 .46749 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46376 L p
1 g
F P
s
P
p
.50822 .46498 m .52282 .46778 L .5 .46376 L 1 g
F
P
p
.002 w
.52239 .46708 m .52282 .46778 L p
.50822 .46498 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52239 .46708 L p
1 g
F P
s
P
p
.002 w
.52239 .46708 m .52214 .46667 L p
.53502 .47333 L 1 g
F P
s
P
p
.53502 .47333 m .54302 .47747 L .52239 .46708 L 1 g
F
P
p
.002 w
.49389 .45297 m .52914 .44443 L .53168 .47168 L p
1 g
F P
s
P
p
.002 w
.53168 .47168 m .53114 .46583 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.54231 .4767 m .54302 .47747 L p
.53331 .47245 L 1 g
F P
s
P
p
.002 w
.54246 .47686 m .54231 .4767 L p
.54651 .48078 L 1 g
F P
s
P
p
.002 w
.54231 .4767 m .54174 .47608 L p
.54651 .48078 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.56633 .48083 m .54651 .48078 L p
.52914 .44443 L 1 g
F P
s
P
p
.002 w
.53114 .46583 m .52914 .44443 L p
.54651 .48078 L 1 g
F P
s
P
p
.002 w
.54651 .48078 m .5522 .4808 L p
.55327 .48733 L 1 g
F P
s
P
p
.54651 .48078 m .55327 .48733 L .55778 .51502 L 1 g
F
P
p
.002 w
.56156 .49989 m .55778 .51502 L p
.5522 .4808 L 1 g
F P
s
P
p
.002 w
.56689 .51747 m .55778 .51502 L .56156 .49989 L p
1 g
F P
s
P
p
.002 w
.56156 .49989 m .56406 .4899 L p
.56605 .50933 L 1 g
F P
s
P
p
.002 w
.56605 .50933 m .56515 .50826 L p
.56689 .51747 L 1 g
F P
s
P
p
.56605 .50933 m .56689 .51747 L .56156 .49989 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .5576 .49155 L p
1 g
F P
s
P
p
.56202 .50086 m .56713 .51061 L .5576 .49155 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54246 .47686 L p
1 g
F P
s
P
p
.54995 .48412 m .55834 .49233 L .54246 .47686 L 1 g
F
P
p
.002 w
.55734 .49128 m .55834 .49233 L p
.54995 .48412 L 1 g
F P
s
P
p
.002 w
.56605 .50933 m .56713 .51061 L p
.56202 .50086 L 1 g
F P
s
P
p
.002 w
.5665 .50987 m .56605 .50933 L p
.56689 .51747 L 1 g
F P
s
P
p
.002 w
.55778 .51502 m .56689 .51747 L p
.55772 .54871 L 1 g
F P
s
P
p
.002 w
.56689 .51747 m .57048 .51844 L p
.56732 .52596 L 1 g
F P
s
P
p
.56689 .51747 m .56732 .52596 L .55772 .54871 L 1 g
F
P
p
.002 w
.56424 .53955 m .55772 .54871 L p
.57048 .51844 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5665 .50987 L p
1 g
F P
s
P
p
.56704 .52053 m .56854 .53025 L .5665 .50987 L 1 g
F
P
p
.002 w
.56745 .52867 m .56854 .53025 L p
.56704 .52053 L 1 g
F P
s
P
p
.56443 .53888 m .56424 .53955 L .56442 .53896 L 1 g
F
P
p
.002 w
.56174 .54753 m .56257 .5491 L p
.56442 .53896 L 1 g
F P
s
P
p
.002 w
.56191 .54786 m .56174 .54753 L p
.55997 .55019 L 1 g
F P
s
P
p
.002 w
.5355 .57383 m .51882 .59402 L p
.53445 .57414 L 1 g
F P
s
P
p
.002 w
.57034 .5684 m .56723 .57644 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.56971 .56054 m .57034 .5684 L .53619 .57299 L closepath p
1 g
F P
s
P
p
.002 w
.56537 .55372 m .56971 .56054 L .54305 .57045 L p
1 g
F P
s
P
p
.002 w
.54305 .57045 m .53619 .57299 L .54684 .56596 L p
1 g
F P
s
P
p
.002 w
.54684 .56596 m .56537 .55372 L p
.54305 .57045 L 1 g
F P
s
P
p
.002 w
.54922 .56311 m .54854 .56129 L p
.53878 .57059 L 1 g
F P
s
P
p
.002 w
.53752 .5715 m .55772 .54871 L .56376 .55267 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .562 .54801 L p
1 g
F P
s
P
p
.002 w
.562 .54801 m .56191 .54786 L p
.56096 .54924 L 1 g
F P
s
P
p
.56096 .54924 m .54998 .56518 L .562 .54801 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54922 .56311 L p
1 g
F P
s
P
p
.002 w
.53445 .57414 m .53619 .57299 L .5355 .57383 L p
1 g
F P
s
P
p
.53878 .57059 m .5322 .57686 L .54922 .56311 L 1 g
F
P
p
.55488 .5563 m .54998 .56518 L .56191 .54786 L 1 g
F
P
p
.002 w
.54922 .56311 m .54998 .56518 L p
.55488 .5563 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54759 .5461 m .55772 .54871 L .53752 .5715 L p
1 g
F P
s
P
p
.002 w
.53752 .5715 m .53619 .57299 L .53653 .5722 L p
1 g
F P
s
P
p
.002 w
.53653 .5722 m .54759 .5461 L p
.53752 .5715 L 1 g
F P
s
P
p
.53817 .57117 m .53619 .57244 L .53758 .57174 L 1 g
F
P
p
.002 w
.53598 .57257 m .53619 .57299 L .53582 .57268 L p
1 g
F P
s
P
p
.53619 .57244 m .53559 .57282 L .53584 .57268 L 1 g
F
P
p
.53619 .57244 m .53584 .57268 L .53758 .57174 L 1 g
F
P
p
.53592 .57264 m .53591 .57265 L .53758 .57174 L 1 g
F
P
p
.53182 .57488 m .53591 .57265 L .53592 .57264 L 1 g
F
P
p
.002 w
.53502 .57314 m .50068 .57732 L p
.53542 .57291 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.5016 .56922 m .50626 .56122 L .53565 .57278 L p
1 g
F P
s
P
p
.002 w
.53565 .57278 m .53619 .57299 L .53542 .57291 L p
1 g
F P
s
P
p
.002 w
.53542 .57291 m .5016 .56922 L p
.53565 .57278 L 1 g
F P
s
P
p
.5355 .57287 m .53538 .57294 L .53549 .57288 L 1 g
F
P
p
.53561 .5728 m .53549 .57288 L .53559 .57282 L 1 g
F
P
p
.002 w
.50626 .56122 m .51419 .55421 L .53582 .57268 L p
1 g
F P
s
P
p
.002 w
.53582 .57268 m .53619 .57299 L .53565 .57278 L p
1 g
F P
s
P
p
.002 w
.53565 .57278 m .50626 .56122 L p
.53582 .57268 L 1 g
F P
s
P
p
.002 w
.51419 .55421 m .52452 .54901 L .53598 .57257 L p
1 g
F P
s
P
p
.002 w
.53582 .57268 m .51419 .55421 L p
.53598 .57257 L 1 g
F P
s
P
p
.53182 .57488 m .53177 .57492 L .53359 .57392 L 1 g
F
P
p
.002 w
.53445 .57414 m .50983 .5904 L p
.52278 .57977 L 1 g
F P
s
P
p
.52278 .57977 m .52709 .57624 L .53177 .57491 L 1 g
F
P
p
.52278 .57977 m .53177 .57491 L .53445 .57414 L 1 g
F
P
p
.002 w
.52709 .57624 m .53359 .57392 L p
.53177 .57491 L 1 g
F P
s
P
p
.002 w
.53177 .57491 m .53177 .57492 L p
.53182 .57488 L 1 g
F P
s
P
p
.002 w
.53502 .57314 m .53619 .57299 L .53359 .57392 L p
1 g
F P
s
P
p
.002 w
.53177 .57492 m .5322 .57686 L p
.53758 .57174 L 1 g
F P
s
P
p
.002 w
.50068 .57732 m .53502 .57314 L p
.52709 .57624 L 1 g
F P
s
P
p
.002 w
.53359 .57392 m .52709 .57624 L p
.53502 .57314 L 1 g
F P
s
P
p
.51331 .58014 m .50068 .57732 L .52709 .57624 L 1 g
F
P
p
.002 w
.51506 .58053 m .52709 .57624 L p
.52255 .57997 L 1 g
F P
s
P
p
.002 w
.53178 .57493 m .53177 .57492 L p
.52017 .57835 L 1 g
F P
s
P
p
.002 w
.53177 .57492 m .53177 .57491 L p
.53102 .57513 L 1 g
F P
s
P
p
.53102 .57513 m .52017 .57835 L .53177 .57492 L 1 g
F
P
p
.002 w
.50227 .58139 m .50068 .57732 L p
.51506 .58053 L 1 g
F P
s
P
p
.50983 .5904 m .51506 .58053 L .52255 .57997 L 1 g
F
P
p
.002 w
.51095 .58081 m .51111 .583 L p
.52082 .57801 L 1 g
F P
s
P
p
.002 w
.51096 .58084 m .51095 .58081 L p
.49279 .58222 L 1 g
F P
s
P
p
.49424 .58193 m .49279 .58222 L .51095 .58081 L 1 g
F
P
p
.002 w
.50068 .57732 m .50227 .58139 L p
.49334 .58087 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51103 .5819 L p
1 g
F P
s
P
p
.002 w
.51103 .5819 m .51096 .58084 L p
.5042 .5815 L 1 g
F P
s
P
p
.5042 .5815 m .48889 .583 L .51103 .5819 L 1 g
F
P
p
.52076 .57805 m .52017 .57835 L .53177 .57491 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53178 .57493 L p
1 g
F P
s
P
p
.52017 .57835 m .51111 .583 L .53178 .57493 L 1 g
F
P
p
.002 w
.39096 .47812 m .37261 .51519 L .34845 .4945 L p
1 g
F P
s
P
p
.002 w
.34845 .4945 m .36864 .45215 L .39096 .47812 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.50218 .28177 m .57047 .28407 L .57558 .30951 L p
1 g
F P
s
P
p
.002 w
.44008 .32395 m .3806 .35657 L .373 .33169 L p
1 g
F P
s
P
p
.002 w
.373 .33169 m .43317 .2984 L .44008 .32395 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.61733 .50438 m .62901 .52464 L .60102 .54422 L p
1 g
F P
s
P
p
.002 w
.62901 .52464 m .61733 .50438 L .63823 .4761 L p
1 g
F P
s
P
p
.002 w
.62224 .42209 m .65474 .44678 L .63823 .4761 L p
1 g
F P
s
P
p
.002 w
.65474 .44678 m .62224 .42209 L .62993 .38891 L p
1 g
F P
s
P
p
.002 w
.57034 .5684 m .56971 .56054 L .60102 .54422 L p
1 g
F P
s
P
p
.002 w
.41688 .50291 m .40102 .53366 L .37261 .51519 L p
1 g
F P
s
P
p
.002 w
.37261 .51519 m .39096 .47812 L .41688 .50291 L p
1 g
F P
s
P
p
.002 w
.57851 .33936 m .63357 .35756 L .62993 .38891 L p
1 g
F P
s
P
p
.002 w
.63357 .35756 m .57851 .33936 L .57558 .30951 L p
1 g
F P
s
P
p
.002 w
.59275 .53057 m .60102 .54422 L .56971 .56054 L p
1 g
F P
s
P
p
.002 w
.60102 .54422 m .59275 .53057 L .61733 .50438 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40714 .41424 m .36864 .45215 L .35066 .42597 L p
1 g
F P
s
P
p
.002 w
.35066 .42597 m .39208 .3844 L .40714 .41424 L p
1 g
F P
s
P
p
.002 w
.57558 .30951 m .50821 .30751 L .50218 .28177 L p
1 g
F P
s
P
p
.002 w
.43317 .2984 m .50218 .28177 L .50821 .30751 L p
1 g
F P
s
P
p
.002 w
.50821 .30751 m .44008 .32395 L .43317 .2984 L p
1 g
F P
s
P
p
.002 w
.56971 .56054 m .56537 .55372 L .59275 .53057 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.004 w
.53726 .5772 m
.53732 .57743 L
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61071 .45591 m .63823 .4761 L .61733 .50438 L p
1 g
F P
s
P
p
.002 w
.63823 .4761 m .61071 .45591 L .62224 .42209 L p
1 g
F P
s
P
p
.002 w
.50821 .30751 m .57558 .30951 L .57851 .33936 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.44904 .35348 m .39208 .3844 L .3806 .35657 L p
1 g
F P
s
P
p
.002 w
.3806 .35657 m .44008 .32395 L .44904 .35348 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57782 .52042 m .59275 .53057 L .56537 .55372 L p
1 g
F P
s
P
p
.002 w
.50626 .56122 m .5016 .56922 L .4667 .5612 L p
1 g
F P
s
P
p
.002 w
.59572 .4891 m .61733 .50438 L .59275 .53057 L p
1 g
F P
s
P
p
.002 w
.61733 .50438 m .59572 .4891 L .61071 .45591 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59275 .53057 m .57782 .52042 L .59572 .4891 L p
1 g
F P
s
P
p
.002 w
.57908 .37267 m .62993 .38891 L .62224 .42209 L p
1 g
F P
s
P
p
.002 w
.62993 .38891 m .57908 .37267 L .57851 .33936 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4667 .5612 m .47564 .54524 L .50626 .56122 L p
1 g
F P
s
P
p
.002 w
.4253 .44502 m .39096 .47812 L .36864 .45215 L p
1 g
F P
s
P
p
.002 w
.36864 .45215 m .40714 .41424 L .4253 .44502 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.55772 .54871 m .54759 .5461 L .55778 .51502 L p
1 g
F P
s
P
p
.002 w
.51419 .55421 m .50626 .56122 L .47564 .54524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.54759 .5461 m .53609 .54619 L .53486 .5151 L p
1 g
F P
s
P
p
.002 w
.53486 .5151 m .55778 .51502 L .54759 .5461 L p
1 g
F P
s
P
p
.002 w
.52452 .54901 m .51419 .55421 L .49123 .53118 L p
1 g
F P
s
P
p
.002 w
.47564 .54524 m .49123 .53118 L .51419 .55421 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.57851 .33936 m .51415 .33776 L .50821 .30751 L p
1 g
F P
s
P
p
.002 w
.44008 .32395 m .50821 .30751 L .51415 .33776 L p
1 g
F P
s
P
p
.002 w
.57719 .40825 m .62224 .42209 L .61071 .45591 L p
1 g
F P
s
P
p
.002 w
.62224 .42209 m .57719 .40825 L .57908 .37267 L p
1 g
F P
s
P
p
.002 w
.51415 .33776 m .44904 .35348 L .44008 .32395 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.53609 .54619 m .52452 .54901 L .51177 .52071 L p
1 g
F P
s
P
p
.002 w
.51177 .52071 m .53486 .5151 L .53609 .54619 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.49123 .53118 m .51177 .52071 L .52452 .54901 L p
1 g
F P
s
P
p
.002 w
.51415 .33776 m .57851 .33936 L .57908 .37267 L p
1 g
F P
s
P
p
.002 w
.44591 .47554 m .41688 .50291 L .39096 .47812 L p
1 g
F P
s
P
p
.002 w
.39096 .47812 m .4253 .44502 L .44591 .47554 L p
1 g
F P
s
P
p
.002 w
.56633 .48083 m .59572 .4891 L .57782 .52042 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45976 .38601 m .40714 .41424 L .39208 .3844 L p
1 g
F P
s
P
p
.002 w
.39208 .3844 m .44904 .35348 L .45976 .38601 L p
1 g
F P
s
P
p
.002 w
.49123 .53118 m .47564 .54524 L .44547 .52556 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57289 .44478 m .61071 .45591 L .59572 .4891 L p
1 g
F P
s
P
p
.002 w
.61071 .45591 m .57289 .44478 L .57719 .40825 L p
1 g
F P
s
P
p
.002 w
.59572 .4891 m .56633 .48083 L .57289 .44478 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.44547 .52556 m .46818 .50463 L .49123 .53118 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55778 .51502 m .53486 .5151 L .53253 .48076 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.51177 .52071 m .49123 .53118 L .46818 .50463 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51977 .37151 m .57908 .37267 L .57719 .40825 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53948 .38412 L
s
P
p
.002 w
.57908 .37267 m .51977 .37151 L .51415 .33776 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47188 .42034 m .4253 .44502 L .40714 .41424 L p
1 g
F P
s
P
p
.002 w
.40714 .41424 m .45976 .38601 L .47188 .42034 L p
1 g
F P
s
P
p
.002 w
.44904 .35348 m .51415 .33776 L .51977 .37151 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.51977 .37151 m .45976 .38601 L .44904 .35348 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.53486 .5151 m .51177 .52071 L .49841 .48903 L p
1 g
F P
s
P
p
.002 w
.49841 .48903 m .53253 .48076 L .53486 .5151 L p
1 g
F P
s
P
p
.002 w
.46818 .50463 m .49841 .48903 L .51177 .52071 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52914 .44443 m .57289 .44478 L .56633 .48083 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52483 .40753 m .57719 .40825 L .57289 .44478 L p
1 g
F P
s
P
p
.002 w
.57719 .40825 m .52483 .40753 L .51977 .37151 L p
1 g
F P
s
P
p
.004 w
.54553 .37701 m
.56845 .35009 L
s
P
p
.004 w
.54182 .38137 m
.54553 .37701 L
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.48494 .45514 m .44591 .47554 L .4253 .44502 L p
1 g
F P
s
P
p
.002 w
.4253 .44502 m .47188 .42034 L .48494 .45514 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.57289 .44478 m .52914 .44443 L .52483 .40753 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.54841 .6211 m
.55095 .63112 L
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.45976 .38601 m .51977 .37151 L .52483 .40753 L p
1 g
F P
s
P
p
.002 w
.52483 .40753 m .47188 .42034 L .45976 .38601 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47188 .42034 m .52483 .40753 L .52914 .44443 L p
1 g
F P
s
P
p
.002 w
.52914 .44443 m .48494 .45514 L .47188 .42034 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .56845 .35009 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .55735 .65631 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.141085)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.141085)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4564 .46321 m .5039 .46732 L .50312 .43892 L p
1 g
F P
s
P
p
.002 w
.50312 .43892 m .46149 .43524 L .4564 .46321 L p
1 g
F P
s
P
p
.002 w
.54435 .4328 m .50312 .43892 L .5039 .46732 L p
1 g
F P
s
P
p
.002 w
.46149 .43524 m .50312 .43892 L .50226 .41037 L p
1 g
F P
s
P
p
.002 w
.50312 .43892 m .54435 .4328 L .53668 .40518 L p
1 g
F P
s
P
p
.002 w
.53668 .40518 m .50226 .41037 L .50312 .43892 L p
1 g
F P
s
P
p
.002 w
.50226 .41037 m .4675 .40723 L .46149 .43524 L p
1 g
F P
s
P
p
.002 w
.4675 .40723 m .50226 .41037 L .50135 .38218 L p
1 g
F P
s
P
p
.002 w
.50226 .41037 m .53668 .40518 L .5281 .37808 L p
1 g
F P
s
P
p
.002 w
.5281 .37808 m .50135 .38218 L .50226 .41037 L p
1 g
F P
s
P
p
.002 w
.45232 .49064 m .50459 .49506 L .5039 .46732 L p
1 g
F P
s
P
p
.002 w
.5039 .46732 m .4564 .46321 L .45232 .49064 L p
1 g
F P
s
P
p
.002 w
.55096 .46046 m .5039 .46732 L .50459 .49506 L p
1 g
F P
s
P
p
.002 w
.5039 .46732 m .55096 .46046 L .54435 .4328 L p
1 g
F P
s
P
p
.002 w
.41262 .4484 m .4564 .46321 L .46149 .43524 L p
1 g
F P
s
P
p
.002 w
.46149 .43524 m .42322 .42202 L .41262 .4484 L p
1 g
F P
s
P
p
.002 w
.42322 .42202 m .46149 .43524 L .4675 .40723 L p
1 g
F P
s
P
p
.002 w
.4675 .40723 m .43564 .396 L .42322 .42202 L p
1 g
F P
s
P
p
.002 w
.43564 .396 m .4675 .40723 L .47432 .37969 L p
1 g
F P
s
P
p
.002 w
.50135 .38218 m .47432 .37969 L .4675 .40723 L p
1 g
F P
s
P
p
.002 w
.58145 .41734 m .54435 .4328 L .55096 .46046 L p
1 g
F P
s
P
p
.002 w
.54435 .4328 m .58145 .41734 L .56755 .39206 L p
1 g
F P
s
P
p
.002 w
.56755 .39206 m .53668 .40518 L .54435 .4328 L p
1 g
F P
s
P
p
.002 w
.53668 .40518 m .56755 .39206 L .55199 .36772 L p
1 g
F P
s
P
p
.002 w
.55199 .36772 m .5281 .37808 L .53668 .40518 L p
1 g
F P
s
P
p
.002 w
.47432 .37969 m .50135 .38218 L .50039 .35487 L p
1 g
F P
s
P
p
.002 w
.50135 .38218 m .5281 .37808 L .51875 .35201 L p
1 g
F P
s
P
p
.002 w
.51875 .35201 m .50039 .35487 L .50135 .38218 L p
1 g
F P
s
P
p
.002 w
.40405 .47463 m .45232 .49064 L .4564 .46321 L p
1 g
F P
s
P
p
.002 w
.4564 .46321 m .41262 .4484 L .40405 .47463 L p
1 g
F P
s
P
p
.002 w
.47432 .37969 m .44964 .37081 L .43564 .396 L p
1 g
F P
s
P
p
.002 w
.44964 .37081 m .47432 .37969 L .48183 .35313 L p
1 g
F P
s
P
p
.002 w
.50039 .35487 m .48183 .35313 L .47432 .37969 L p
1 g
F P
s
P
p
.002 w
.50459 .49506 m .55639 .48764 L .55096 .46046 L p
1 g
F P
s
P
p
.002 w
.59345 .4431 m .55096 .46046 L .55639 .48764 L p
1 g
F P
s
P
p
.002 w
.55096 .46046 m .59345 .4431 L .58145 .41734 L p
1 g
F P
s
P
p
.002 w
.5281 .37808 m .55199 .36772 L .53508 .3448 L p
1 g
F P
s
P
p
.002 w
.53508 .3448 m .51875 .35201 L .5281 .37808 L p
1 g
F P
s
P
p
.002 w
.44936 .51699 m .50518 .52161 L .50459 .49506 L p
1 g
F P
s
P
p
.002 w
.50459 .49506 m .45232 .49064 L .44936 .51699 L p
1 g
F P
s
P
p
.002 w
.55639 .48764 m .50459 .49506 L .50518 .52161 L p
1 g
F P
s
P
p
.002 w
.39196 .40023 m .42322 .42202 L .43564 .396 L p
1 g
F P
s
P
p
.002 w
.43564 .396 m .40979 .37756 L .39196 .40023 L p
1 g
F P
s
P
p
.002 w
.40979 .37756 m .43564 .396 L .44964 .37081 L p
1 g
F P
s
P
p
.002 w
.48183 .35313 m .50039 .35487 L .49941 .32896 L p
1 g
F P
s
P
p
.002 w
.50039 .35487 m .51875 .35201 L .5088 .32747 L p
1 g
F P
s
P
p
.002 w
.5088 .32747 m .49941 .32896 L .50039 .35487 L p
1 g
F P
s
P
p
.002 w
.39772 .5002 m .44936 .51699 L .45232 .49064 L p
1 g
F P
s
P
p
.002 w
.45232 .49064 m .40405 .47463 L .39772 .5002 L p
1 g
F P
s
P
p
.002 w
.37664 .42388 m .41262 .4484 L .42322 .42202 L p
1 g
F P
s
P
p
.002 w
.42322 .42202 m .39196 .40023 L .37664 .42388 L p
1 g
F P
s
P
p
.002 w
.5918 .37208 m .56755 .39206 L .58145 .41734 L p
1 g
F P
s
P
p
.002 w
.56755 .39206 m .5918 .37208 L .57061 .35203 L p
1 g
F P
s
P
p
.002 w
.57061 .35203 m .55199 .36772 L .56755 .39206 L p
1 g
F P
s
P
p
.002 w
.44964 .37081 m .42976 .3563 L .40979 .37756 L p
1 g
F P
s
P
p
.002 w
.42976 .3563 m .44964 .37081 L .46495 .34693 L p
1 g
F P
s
P
p
.002 w
.48183 .35313 m .46495 .34693 L .44964 .37081 L p
1 g
F P
s
P
p
.002 w
.46495 .34693 m .48183 .35313 L .48991 .32805 L p
1 g
F P
s
P
p
.002 w
.49941 .32896 m .48991 .32805 L .48183 .35313 L p
1 g
F P
s
P
p
.002 w
.50518 .52161 m .56052 .51382 L .55639 .48764 L p
1 g
F P
s
P
p
.002 w
.60327 .46885 m .55639 .48764 L .56052 .51382 L p
1 g
F P
s
P
p
.002 w
.55639 .48764 m .60327 .46885 L .59345 .4431 L p
1 g
F P
s
P
p
.002 w
.51875 .35201 m .53508 .3448 L .51711 .32374 L p
1 g
F P
s
P
p
.002 w
.51711 .32374 m .5088 .32747 L .51875 .35201 L p
1 g
F P
s
P
p
.002 w
.55199 .36772 m .57061 .35203 L .54768 .33393 L p
1 g
F P
s
P
p
.002 w
.54768 .33393 m .53508 .3448 L .55199 .36772 L p
1 g
F P
s
P
p
.002 w
.61085 .39369 m .58145 .41734 L .59345 .4431 L p
1 g
F P
s
P
p
.002 w
.58145 .41734 m .61085 .39369 L .5918 .37208 L p
1 g
F P
s
P
p
.002 w
.36419 .44806 m .40405 .47463 L .41262 .4484 L p
1 g
F P
s
P
p
.002 w
.41262 .4484 m .37664 .42388 L .36419 .44806 L p
1 g
F P
s
P
p
.002 w
.46495 .34693 m .45146 .33686 L .42976 .3563 L p
1 g
F P
s
P
p
.002 w
.45146 .33686 m .46495 .34693 L .48131 .32483 L p
1 g
F P
s
P
p
.002 w
.48991 .32805 m .48131 .32483 L .46495 .34693 L p
1 g
F P
s
P
p
.002 w
.44759 .54174 m .50566 .54645 L .50518 .52161 L p
1 g
F P
s
P
p
.002 w
.50518 .52161 m .44936 .51699 L .44759 .54174 L p
1 g
F P
s
P
p
.002 w
.56052 .51382 m .50518 .52161 L .50566 .54645 L p
1 g
F P
s
P
p
.002 w
.53508 .3448 m .54768 .33393 L .52346 .31813 L p
1 g
F P
s
P
p
.002 w
.52346 .31813 m .51711 .32374 L .53508 .3448 L p
1 g
F P
s
P
p
.002 w
.62732 .41646 m .59345 .4431 L .60327 .46885 L p
1 g
F P
s
P
p
.002 w
.59345 .4431 m .62732 .41646 L .61085 .39369 L p
1 g
F P
s
P
p
.002 w
.39384 .52458 m .44759 .54174 L .44936 .51699 L p
1 g
F P
s
P
p
.002 w
.44936 .51699 m .39772 .5002 L .39384 .52458 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .48991 .32805 L .49941 .32896 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .49941 .32896 L .5088 .32747 L closepath p
1 g
F P
s
P
p
.002 w
.39272 .35348 m .40979 .37756 L .42976 .3563 L p
1 g
F P
s
P
p
.002 w
.42976 .3563 m .41683 .33747 L .39272 .35348 L p
1 g
F P
s
P
p
.002 w
.41683 .33747 m .42976 .3563 L .45146 .33686 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .48131 .32483 L .48991 .32805 L closepath p
1 g
F P
s
P
p
.002 w
.50566 .54645 m .56322 .53847 L .56052 .51382 L p
1 g
F P
s
P
p
.002 w
.61069 .49408 m .56052 .51382 L .56322 .53847 L p
1 g
F P
s
P
p
.002 w
.56052 .51382 m .61069 .49408 L .60327 .46885 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .5088 .32747 L .51711 .32374 L closepath p
1 g
F P
s
P
p
.002 w
.37104 .37161 m .39196 .40023 L .40979 .37756 L p
1 g
F P
s
P
p
.002 w
.40979 .37756 m .39272 .35348 L .37104 .37161 L p
1 g
F P
s
P
p
.002 w
.45146 .33686 m .44284 .32389 L .41683 .33747 L p
1 g
F P
s
P
p
.002 w
.44284 .32389 m .45146 .33686 L .4745 .31964 L p
1 g
F P
s
P
p
.002 w
.48131 .32483 m .4745 .31964 L .45146 .33686 L p
1 g
F P
s
P
p
.002 w
.5819 .33243 m .57061 .35203 L .5918 .37208 L p
1 g
F P
s
P
p
.002 w
.57061 .35203 m .5819 .33243 L .55517 .32044 L p
1 g
F P
s
P
p
.002 w
.55517 .32044 m .54768 .33393 L .57061 .35203 L p
1 g
F P
s
P
p
.002 w
.35494 .47227 m .39772 .5002 L .40405 .47463 L p
1 g
F P
s
P
p
.002 w
.40405 .47463 m .36419 .44806 L .35494 .47227 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .4745 .31964 L .48131 .32483 L closepath p
1 g
F P
s
P
p
.002 w
.54768 .33393 m .55517 .32044 L .52715 .31124 L p
1 g
F P
s
P
p
.002 w
.52715 .31124 m .52346 .31813 L .54768 .33393 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .51711 .32374 L .52346 .31813 L closepath p
1 g
F P
s
P
p
.002 w
.60679 .34698 m .5918 .37208 L .61085 .39369 L p
1 g
F P
s
P
p
.002 w
.5918 .37208 m .60679 .34698 L .5819 .33243 L p
1 g
F P
s
P
p
.002 w
.64085 .43995 m .60327 .46885 L .61069 .49408 L p
1 g
F P
s
P
p
.002 w
.60327 .46885 m .64085 .43995 L .62732 .41646 L p
1 g
F P
s
P
p
.002 w
.35229 .39154 m .37664 .42388 L .39196 .40023 L p
1 g
F P
s
P
p
.002 w
.39196 .40023 m .37104 .37161 L .35229 .39154 L p
1 g
F P
s
P
p
.002 w
.4745 .31964 m .47022 .31299 L .44284 .32389 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .47022 .31299 L .4745 .31964 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .52346 .31813 L .52715 .31124 L closepath p
1 g
F P
s
P
p
.002 w
.44711 .56433 m .506 .56902 L .50566 .54645 L p
1 g
F P
s
P
p
.002 w
.50566 .54645 m .44759 .54174 L .44711 .56433 L p
1 g
F P
s
P
p
.002 w
.56322 .53847 m .50566 .54645 L .506 .56902 L p
1 g
F P
s
P
p
.002 w
.6293 .36382 m .61085 .39369 L .62732 .41646 L p
1 g
F P
s
P
p
.002 w
.61085 .39369 m .6293 .36382 L .60679 .34698 L p
1 g
F P
s
P
p
.002 w
.41246 .31616 m .41683 .33747 L .44284 .32389 L p
1 g
F P
s
P
p
.002 w
.44284 .32389 m .44011 .30932 L .41246 .31616 L p
1 g
F P
s
P
p
.002 w
.44011 .30932 m .44284 .32389 L .47022 .31299 L p
1 g
F P
s
P
p
.002 w
.47022 .31299 m .46897 .30559 L .44011 .30932 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .46897 .30559 L .47022 .31299 L closepath p
1 g
F P
s
P
p
.002 w
.52776 .30377 m .52715 .31124 L .55517 .32044 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .52715 .31124 L .52776 .30377 L closepath p
1 g
F P
s
P
p
.002 w
.39257 .54722 m .44711 .56433 L .44759 .54174 L p
1 g
F P
s
P
p
.002 w
.44759 .54174 m .39384 .52458 L .39257 .54722 L p
1 g
F P
s
P
p
.002 w
.55663 .30573 m .55517 .32044 L .5819 .33243 L p
1 g
F P
s
P
p
.002 w
.55517 .32044 m .55663 .30573 L .52776 .30377 L p
1 g
F P
s
P
p
.002 w
.33697 .41286 m .36419 .44806 L .37664 .42388 L p
1 g
F P
s
P
p
.002 w
.37664 .42388 m .35229 .39154 L .33697 .41286 L p
1 g
F P
s
P
p
.002 w
.34921 .496 m .39384 .52458 L .39772 .5002 L p
1 g
F P
s
P
p
.002 w
.39772 .5002 m .35494 .47227 L .34921 .496 L p
1 g
F P
s
P
p
.002 w
.38661 .32602 m .39272 .35348 L .41683 .33747 L p
1 g
F P
s
P
p
.002 w
.41683 .33747 m .41246 .31616 L .38661 .32602 L p
1 g
F P
s
P
p
.002 w
.506 .56902 m .56439 .56105 L .56322 .53847 L p
1 g
F P
s
P
p
.002 w
.61547 .51828 m .56322 .53847 L .56439 .56105 L p
1 g
F P
s
P
p
.002 w
.56322 .53847 m .61547 .51828 L .61069 .49408 L p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .50237 .28369 L .49254 .284 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .49254 .284 L .48337 .28678 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .48337 .28678 L .47589 .29171 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .47589 .29171 L .47091 .29822 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .47091 .29822 L .46897 .30559 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .52776 .30377 L .52518 .29654 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .52518 .29654 L .51965 .29035 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .51965 .29035 L .51176 .28589 L closepath p
1 g
F P
s
P
p
.002 w
.49842 .30499 m .51176 .28589 L .50237 .28369 L closepath p
1 g
F P
s
P
p
.002 w
.65107 .46367 m .61069 .49408 L .61547 .51828 L p
1 g
F P
s
P
p
.002 w
.61069 .49408 m .65107 .46367 L .64085 .43995 L p
1 g
F P
s
P
p
.002 w
.58442 .31087 m .5819 .33243 L .60679 .34698 L p
1 g
F P
s
P
p
.002 w
.5819 .33243 m .58442 .31087 L .55663 .30573 L p
1 g
F P
s
P
p
.002 w
.64888 .38265 m .62732 .41646 L .64085 .43995 L p
1 g
F P
s
P
p
.002 w
.62732 .41646 m .64888 .38265 L .6293 .36382 L p
1 g
F P
s
P
p
.002 w
.44373 .2947 m .44011 .30932 L .46897 .30559 L p
1 g
F P
s
P
p
.002 w
.46897 .30559 m .47091 .29822 L .44373 .2947 L p
1 g
F P
s
P
p
.002 w
.52518 .29654 m .52776 .30377 L .55663 .30573 L p
1 g
F P
s
P
p
.002 w
.36319 .33875 m .37104 .37161 L .39272 .35348 L p
1 g
F P
s
P
p
.002 w
.39272 .35348 m .38661 .32602 L .36319 .33875 L p
1 g
F P
s
P
p
.002 w
.41745 .29459 m .41246 .31616 L .44011 .30932 L p
1 g
F P
s
P
p
.002 w
.44011 .30932 m .44373 .2947 L .41745 .29459 L p
1 g
F P
s
P
p
.002 w
.45345 .28166 m .44373 .2947 L .47091 .29822 L p
1 g
F P
s
P
p
.002 w
.47091 .29822 m .47589 .29171 L .45345 .28166 L p
1 g
F P
s
P
p
.002 w
.61051 .31915 m .60679 .34698 L .6293 .36382 L p
1 g
F P
s
P
p
.002 w
.60679 .34698 m .61051 .31915 L .58442 .31087 L p
1 g
F P
s
P
p
.002 w
.55663 .30573 m .55175 .29135 L .52518 .29654 L p
1 g
F P
s
P
p
.002 w
.51965 .29035 m .52518 .29654 L .55175 .29135 L p
1 g
F P
s
P
p
.002 w
.32552 .43516 m .35494 .47227 L .36419 .44806 L p
1 g
F P
s
P
p
.002 w
.36419 .44806 m .33697 .41286 L .32552 .43516 L p
1 g
F P
s
P
p
.002 w
.55175 .29135 m .55663 .30573 L .58442 .31087 L p
1 g
F P
s
P
p
.002 w
.44797 .58419 m .5062 .58875 L .506 .56902 L p
1 g
F P
s
P
p
.002 w
.506 .56902 m .44711 .56433 L .44797 .58419 L p
1 g
F P
s
P
p
.002 w
.56439 .56105 m .506 .56902 L .5062 .58875 L p
1 g
F P
s
P
p
.002 w
.4683 .27172 m .45345 .28166 L .47589 .29171 L p
1 g
F P
s
P
p
.002 w
.47589 .29171 m .48337 .28678 L .4683 .27172 L p
1 g
F P
s
P
p
.002 w
.66503 .40311 m .64085 .43995 L .65107 .46367 L p
1 g
F P
s
P
p
.002 w
.64085 .43995 m .66503 .40311 L .64888 .38265 L p
1 g
F P
s
P
p
.002 w
.55175 .29135 m .5409 .27893 L .51965 .29035 L p
1 g
F P
s
P
p
.002 w
.51176 .28589 m .51965 .29035 L .5409 .27893 L p
1 g
F P
s
P
p
.002 w
.3428 .35417 m .35229 .39154 L .37104 .37161 L p
1 g
F P
s
P
p
.002 w
.37104 .37161 m .36319 .33875 L .3428 .35417 L p
1 g
F P
s
P
p
.002 w
.34724 .51868 m .39257 .54722 L .39384 .52458 L p
1 g
F P
s
P
p
.002 w
.39384 .52458 m .34921 .496 L .34724 .51868 L p
1 g
F P
s
P
p
.002 w
.39405 .56752 m .44797 .58419 L .44711 .56433 L p
1 g
F P
s
P
p
.002 w
.44711 .56433 m .39257 .54722 L .39405 .56752 L p
1 g
F P
s
P
p
.002 w
.39268 .29799 m .38661 .32602 L .41246 .31616 L p
1 g
F P
s
P
p
.002 w
.41246 .31616 m .41745 .29459 L .39268 .29799 L p
1 g
F P
s
P
p
.002 w
.48666 .26609 m .4683 .27172 L .48337 .28678 L p
1 g
F P
s
P
p
.002 w
.48337 .28678 m .49254 .284 L .48666 .26609 L p
1 g
F P
s
P
p
.002 w
.56439 .56105 m .61742 .54087 L .61547 .51828 L p
1 g
F P
s
P
p
.002 w
.65764 .48712 m .61547 .51828 L .61742 .54087 L p
1 g
F P
s
P
p
.002 w
.61547 .51828 m .65764 .48712 L .65107 .46367 L p
1 g
F P
s
P
p
.002 w
.5409 .27893 m .5252 .26994 L .51176 .28589 L p
1 g
F P
s
P
p
.002 w
.50237 .28369 m .51176 .28589 L .5252 .26994 L p
1 g
F P
s
P
p
.002 w
.63427 .33047 m .6293 .36382 L .64888 .38265 L p
1 g
F P
s
P
p
.002 w
.6293 .36382 m .63427 .33047 L .61051 .31915 L p
1 g
F P
s
P
p
.002 w
.5062 .58875 m .56394 .58097 L .56439 .56105 L p
1 g
F P
s
P
p
.002 w
.61742 .54087 m .56439 .56105 L .56394 .58097 L p
1 g
F P
s
P
p
.002 w
.57754 .28962 m .58442 .31087 L .61051 .31915 L p
1 g
F P
s
P
p
.002 w
.58442 .31087 m .57754 .28962 L .55175 .29135 L p
1 g
F P
s
P
p
.002 w
.50639 .26547 m .48666 .26609 L .49254 .284 L p
1 g
F P
s
P
p
.002 w
.49254 .284 m .50237 .28369 L .50639 .26547 L p
1 g
F P
s
P
p
.002 w
.5252 .26994 m .50639 .26547 L .50237 .28369 L p
1 g
F P
s
P
p
.002 w
.4316 .27519 m .41745 .29459 L .44373 .2947 L p
1 g
F P
s
P
p
.002 w
.44373 .2947 m .45345 .28166 L .4316 .27519 L p
1 g
F P
s
P
p
.002 w
.5409 .27893 m .55175 .29135 L .57754 .28962 L p
1 g
F P
s
P
p
.002 w
.31838 .45794 m .34921 .496 L .35494 .47227 L p
1 g
F P
s
P
p
.002 w
.35494 .47227 m .32552 .43516 L .31838 .45794 L p
1 g
F P
s
P
p
.002 w
.32603 .372 m .33697 .41286 L .35229 .39154 L p
1 g
F P
s
P
p
.002 w
.35229 .39154 m .3428 .35417 L .32603 .372 L p
1 g
F P
s
P
p
.002 w
.37007 .30497 m .36319 .33875 L .38661 .32602 L p
1 g
F P
s
P
p
.002 w
.38661 .32602 m .39268 .29799 L .37007 .30497 L p
1 g
F P
s
P
p
.002 w
.67726 .42479 m .65107 .46367 L .65764 .48712 L p
1 g
F P
s
P
p
.002 w
.65107 .46367 m .67726 .42479 L .66503 .40311 L p
1 g
F P
s
P
p
.002 w
.45356 .2603 m .4316 .27519 L .45345 .28166 L p
1 g
F P
s
P
p
.002 w
.45345 .28166 m .4683 .27172 L .45356 .2603 L p
1 g
F P
s
P
p
.002 w
.65509 .34468 m .64888 .38265 L .66503 .40311 L p
1 g
F P
s
P
p
.002 w
.64888 .38265 m .65509 .34468 L .63427 .33047 L p
1 g
F P
s
P
p
.002 w
.60196 .29151 m .61051 .31915 L .63427 .33047 L p
1 g
F P
s
P
p
.002 w
.61051 .31915 m .60196 .29151 L .57754 .28962 L p
1 g
F P
s
P
p
.002 w
.57754 .28962 m .56169 .27112 L .5409 .27893 L p
1 g
F P
s
P
p
.002 w
.5252 .26994 m .5409 .27893 L .56169 .27112 L p
1 g
F P
s
P
p
.002 w
.45021 .60073 m .50625 .60506 L .5062 .58875 L p
1 g
F P
s
P
p
.002 w
.5062 .58875 m .44797 .58419 L .45021 .60073 L p
1 g
F P
s
P
p
.002 w
.56394 .58097 m .5062 .58875 L .50625 .60506 L p
1 g
F P
s
P
p
.002 w
.34928 .53973 m .39405 .56752 L .39257 .54722 L p
1 g
F P
s
P
p
.002 w
.39257 .54722 m .34724 .51868 L .34928 .53973 L p
1 g
F P
s
P
p
.002 w
.41086 .2726 m .39268 .29799 L .41745 .29459 L p
1 g
F P
s
P
p
.002 w
.41745 .29459 m .4316 .27519 L .41086 .2726 L p
1 g
F P
s
P
p
.002 w
.56169 .27112 m .57754 .28962 L .60196 .29151 L p
1 g
F P
s
P
p
.002 w
.56394 .58097 m .61637 .5613 L .61742 .54087 L p
1 g
F P
s
P
p
.002 w
.66025 .50975 m .61742 .54087 L .61637 .5613 L p
1 g
F P
s
P
p
.002 w
.61742 .54087 m .66025 .50975 L .65764 .48712 L p
1 g
F P
s
P
p
.002 w
.48091 .25184 m .45356 .2603 L .4683 .27172 L p
1 g
F P
s
P
p
.002 w
.4683 .27172 m .48666 .26609 L .48091 .25184 L p
1 g
F P
s
P
p
.002 w
.39839 .5849 m .45021 .60073 L .44797 .58419 L p
1 g
F P
s
P
p
.002 w
.44797 .58419 m .39405 .56752 L .39839 .5849 L p
1 g
F P
s
P
p
.002 w
.56169 .27112 m .53844 .25764 L .5252 .26994 L p
1 g
F P
s
P
p
.002 w
.50639 .26547 m .5252 .26994 L .53844 .25764 L p
1 g
F P
s
P
p
.002 w
.50625 .60506 m .5618 .59765 L .56394 .58097 L p
1 g
F P
s
P
p
.002 w
.61637 .5613 m .56394 .58097 L .5618 .59765 L p
1 g
F P
s
P
p
.002 w
.31344 .39191 m .32552 .43516 L .33697 .41286 L p
1 g
F P
s
P
p
.002 w
.33697 .41286 m .32603 .372 L .31344 .39191 L p
1 g
F P
s
P
p
.002 w
.31589 .48065 m .34724 .51868 L .34921 .496 L p
1 g
F P
s
P
p
.002 w
.34921 .496 m .31838 .45794 L .31589 .48065 L p
1 g
F P
s
P
p
.002 w
.35026 .31551 m .3428 .35417 L .36319 .33875 L p
1 g
F P
s
P
p
.002 w
.36319 .33875 m .37007 .30497 L .35026 .31551 L p
1 g
F P
s
P
p
.002 w
.51039 .25091 m .48091 .25184 L .48666 .26609 L p
1 g
F P
s
P
p
.002 w
.48666 .26609 m .50639 .26547 L .51039 .25091 L p
1 g
F P
s
P
p
.002 w
.53844 .25764 m .51039 .25091 L .50639 .26547 L p
1 g
F P
s
P
p
.002 w
.67236 .36155 m .66503 .40311 L .67726 .42479 L p
1 g
F P
s
P
p
.002 w
.66503 .40311 m .67236 .36155 L .65509 .34468 L p
1 g
F P
s
P
p
.002 w
.62438 .29711 m .63427 .33047 L .65509 .34468 L p
1 g
F P
s
P
p
.002 w
.63427 .33047 m .62438 .29711 L .60196 .29151 L p
1 g
F P
s
P
p
.002 w
.68513 .44722 m .65764 .48712 L .66025 .50975 L p
1 g
F P
s
P
p
.002 w
.65764 .48712 m .68513 .44722 L .67726 .42479 L p
1 g
F P
s
P
p
.002 w
.43951 .253 m .41086 .2726 L .4316 .27519 L p
1 g
F P
s
P
p
.002 w
.4316 .27519 m .45356 .2603 L .43951 .253 L p
1 g
F P
s
P
p
.002 w
.39181 .27415 m .37007 .30497 L .39268 .29799 L p
1 g
F P
s
P
p
.002 w
.39268 .29799 m .41086 .2726 L .39181 .27415 L p
1 g
F P
s
P
p
.002 w
.60196 .29151 m .58153 .26726 L .56169 .27112 L p
1 g
F P
s
P
p
.002 w
.53844 .25764 m .56169 .27112 L .58153 .26726 L p
1 g
F P
s
P
p
.002 w
.58153 .26726 m .60196 .29151 L .62438 .29711 L p
1 g
F P
s
P
p
.002 w
.35545 .55854 m .39839 .5849 L .39405 .56752 L p
1 g
F P
s
P
p
.002 w
.39405 .56752 m .34928 .53973 L .35545 .55854 L p
1 g
F P
s
P
p
.002 w
.30555 .41347 m .31838 .45794 L .32552 .43516 L p
1 g
F P
s
P
p
.002 w
.32552 .43516 m .31344 .39191 L .30555 .41347 L p
1 g
F P
s
P
p
.002 w
.45388 .61338 m .50613 .61737 L .50625 .60506 L p
1 g
F P
s
P
p
.002 w
.50625 .60506 m .45021 .60073 L .45388 .61338 L p
1 g
F P
s
P
p
.002 w
.5618 .59765 m .50625 .60506 L .50613 .61737 L p
1 g
F P
s
P
p
.002 w
.33387 .32951 m .32603 .372 L .3428 .35417 L p
1 g
F P
s
P
p
.002 w
.3428 .35417 m .35026 .31551 L .33387 .32951 L p
1 g
F P
s
P
p
.002 w
.5618 .59765 m .61219 .57896 L .61637 .5613 L p
1 g
F P
s
P
p
.002 w
.65869 .53097 m .61637 .5613 L .61219 .57896 L p
1 g
F P
s
P
p
.002 w
.61637 .5613 m .65869 .53097 L .66025 .50975 L p
1 g
F P
s
P
p
.002 w
.31835 .50271 m .34928 .53973 L .34724 .51868 L p
1 g
F P
s
P
p
.002 w
.34724 .51868 m .31589 .48065 L .31835 .50271 L p
1 g
F P
s
P
p
.002 w
.47544 .24181 m .43951 .253 L .45356 .2603 L p
1 g
F P
s
P
p
.002 w
.45356 .2603 m .48091 .25184 L .47544 .24181 L p
1 g
F P
s
P
p
.002 w
.58153 .26726 m .55115 .24949 L .53844 .25764 L p
1 g
F P
s
P
p
.002 w
.51039 .25091 m .53844 .25764 L .55115 .24949 L p
1 g
F P
s
P
p
.002 w
.64416 .30646 m .65509 .34468 L .67236 .36155 L p
1 g
F P
s
P
p
.002 w
.65509 .34468 m .64416 .30646 L .62438 .29711 L p
1 g
F P
s
P
p
.002 w
.40563 .59878 m .45388 .61338 L .45021 .60073 L p
1 g
F P
s
P
p
.002 w
.45021 .60073 m .39839 .5849 L .40563 .59878 L p
1 g
F P
s
P
p
.002 w
.68549 .38076 m .67726 .42479 L .68513 .44722 L p
1 g
F P
s
P
p
.002 w
.67726 .42479 m .68549 .38076 L .67236 .36155 L p
1 g
F P
s
P
p
.002 w
.50613 .61737 m .55793 .61052 L .5618 .59765 L p
1 g
F P
s
P
p
.002 w
.61219 .57896 m .5618 .59765 L .55793 .61052 L p
1 g
F P
s
P
p
.002 w
.68824 .46986 m .66025 .50975 L .65869 .53097 L p
1 g
F P
s
P
p
.002 w
.66025 .50975 m .68824 .46986 L .68513 .44722 L p
1 g
F P
s
P
p
.002 w
.51428 .24058 m .47544 .24181 L .48091 .25184 L p
1 g
F P
s
P
p
.002 w
.48091 .25184 m .51039 .25091 L .51428 .24058 L p
1 g
F P
s
P
p
.002 w
.55115 .24949 m .51428 .24058 L .51039 .25091 L p
1 g
F P
s
P
p
.002 w
.37502 .28003 m .35026 .31551 L .37007 .30497 L p
1 g
F P
s
P
p
.002 w
.37007 .30497 m .39181 .27415 L .37502 .28003 L p
1 g
F P
s
P
p
.002 w
.42655 .25023 m .39181 .27415 L .41086 .2726 L p
1 g
F P
s
P
p
.002 w
.41086 .2726 m .43951 .253 L .42655 .25023 L p
1 g
F P
s
P
p
.002 w
.59987 .26765 m .62438 .29711 L .64416 .30646 L p
1 g
F P
s
P
p
.002 w
.62438 .29711 m .59987 .26765 L .58153 .26726 L p
1 g
F P
s
P
p
.002 w
.55115 .24949 m .58153 .26726 L .59987 .26765 L p
1 g
F P
s
P
p
.002 w
.32152 .34676 m .31344 .39191 L .32603 .372 L p
1 g
F P
s
P
p
.002 w
.32603 .372 m .33387 .32951 L .32152 .34676 L p
1 g
F P
s
P
p
.002 w
.30279 .43618 m .31589 .48065 L .31838 .45794 L p
1 g
F P
s
P
p
.002 w
.31838 .45794 m .30555 .41347 L .30279 .43618 L p
1 g
F P
s
P
p
.002 w
.36581 .57451 m .40563 .59878 L .39839 .5849 L p
1 g
F P
s
P
p
.002 w
.39839 .5849 m .35545 .55854 L .36581 .57451 L p
1 g
F P
s
P
p
.002 w
.66066 .31949 m .67236 .36155 L .68549 .38076 L p
1 g
F P
s
P
p
.002 w
.67236 .36155 m .66066 .31949 L .64416 .30646 L p
1 g
F P
s
P
p
.002 w
.69395 .40193 m .68513 .44722 L .68824 .46986 L p
1 g
F P
s
P
p
.002 w
.68513 .44722 m .69395 .40193 L .68549 .38076 L p
1 g
F P
s
P
p
.002 w
.55793 .61052 m .60482 .59327 L .61219 .57896 L p
1 g
F P
s
P
p
.002 w
.65277 .55019 m .61219 .57896 L .60482 .59327 L p
1 g
F P
s
P
p
.002 w
.61219 .57896 m .65277 .55019 L .65869 .53097 L p
1 g
F P
s
P
p
.002 w
.32592 .52349 m .35545 .55854 L .34928 .53973 L p
1 g
F P
s
P
p
.002 w
.34928 .53973 m .31835 .50271 L .32592 .52349 L p
1 g
F P
s
P
p
.002 w
.45895 .62157 m .50585 .62513 L .50613 .61737 L p
1 g
F P
s
P
p
.002 w
.50613 .61737 m .45388 .61338 L .45895 .62157 L p
1 g
F P
s
P
p
.002 w
.55793 .61052 m .50613 .61737 L .50585 .62513 L p
1 g
F P
s
P
p
.002 w
.47042 .23651 m .42655 .25023 L .43951 .253 L p
1 g
F P
s
P
p
.002 w
.43951 .253 m .47544 .24181 L .47042 .23651 L p
1 g
F P
s
P
p
.002 w
.6863 .49214 m .65869 .53097 L .65277 .55019 L p
1 g
F P
s
P
p
.002 w
.65869 .53097 m .6863 .49214 L .68824 .46986 L p
1 g
F P
s
P
p
.002 w
.59987 .26765 m .56298 .24593 L .55115 .24949 L p
1 g
F P
s
P
p
.002 w
.51428 .24058 m .55115 .24949 L .56298 .24593 L p
1 g
F P
s
P
p
.002 w
.41576 .60857 m .45895 .62157 L .45388 .61338 L p
1 g
F P
s
P
p
.002 w
.45388 .61338 m .40563 .59878 L .41576 .60857 L p
1 g
F P
s
P
p
.002 w
.36107 .2903 m .33387 .32951 L .35026 .31551 L p
1 g
F P
s
P
p
.002 w
.35026 .31551 m .37502 .28003 L .36107 .2903 L p
1 g
F P
s
P
p
.002 w
.50585 .62513 m .55232 .61902 L .55793 .61052 L p
1 g
F P
s
P
p
.002 w
.60482 .59327 m .55793 .61052 L .55232 .61902 L p
1 g
F P
s
P
p
.002 w
.41509 .25233 m .37502 .28003 L .39181 .27415 L p
1 g
F P
s
P
p
.002 w
.39181 .27415 m .42655 .25023 L .41509 .25233 L p
1 g
F P
s
P
p
.002 w
.61616 .2725 m .64416 .30646 L .66066 .31949 L p
1 g
F P
s
P
p
.002 w
.64416 .30646 m .61616 .2725 L .59987 .26765 L p
1 g
F P
s
P
p
.002 w
.51794 .235 m .47042 .23651 L .47544 .24181 L p
1 g
F P
s
P
p
.002 w
.47544 .24181 m .51428 .24058 L .51794 .235 L p
1 g
F P
s
P
p
.002 w
.56298 .24593 m .51794 .235 L .51428 .24058 L p
1 g
F P
s
P
p
.002 w
.31376 .36694 m .30555 .41347 L .31344 .39191 L p
1 g
F P
s
P
p
.002 w
.31344 .39191 m .32152 .34676 L .31376 .36694 L p
1 g
F P
s
P
p
.002 w
.30548 .45945 m .31835 .50271 L .31589 .48065 L p
1 g
F P
s
P
p
.002 w
.31589 .48065 m .30279 .43618 L .30548 .45945 L p
1 g
F P
s
P
p
.002 w
.56298 .24593 m .59987 .26765 L .61616 .2725 L p
1 g
F P
s
P
p
.002 w
.67327 .33604 m .68549 .38076 L .69395 .40193 L p
1 g
F P
s
P
p
.002 w
.68549 .38076 m .67327 .33604 L .66066 .31949 L p
1 g
F P
s
P
p
.002 w
.6973 .42455 m .68824 .46986 L .6863 .49214 L p
1 g
F P
s
P
p
.002 w
.68824 .46986 m .6973 .42455 L .69395 .40193 L p
1 g
F P
s
P
p
.002 w
.3803 .58701 m .41576 .60857 L .40563 .59878 L p
1 g
F P
s
P
p
.002 w
.40563 .59878 m .36581 .57451 L .3803 .58701 L p
1 g
F P
s
P
p
.002 w
.33863 .54232 m .36581 .57451 L .35545 .55854 L p
1 g
F P
s
P
p
.002 w
.35545 .55854 m .32592 .52349 L .33863 .54232 L p
1 g
F P
s
P
p
.002 w
.55232 .61902 m .59428 .60366 L .60482 .59327 L p
1 g
F P
s
P
p
.002 w
.64243 .56678 m .60482 .59327 L .59428 .60366 L p
1 g
F P
s
P
p
.002 w
.60482 .59327 m .64243 .56678 L .65277 .55019 L p
1 g
F P
s
P
p
.002 w
.67912 .51342 m .65277 .55019 L .64243 .56678 L p
1 g
F P
s
P
p
.002 w
.65277 .55019 m .67912 .51342 L .6863 .49214 L p
1 g
F P
s
P
p
.002 w
.35052 .30493 m .32152 .34676 L .33387 .32951 L p
1 g
F P
s
P
p
.002 w
.33387 .32951 m .36107 .2903 L .35052 .30493 L p
1 g
F P
s
P
p
.002 w
.466 .2364 m .41509 .25233 L .42655 .25023 L p
1 g
F P
s
P
p
.002 w
.42655 .25023 m .47042 .23651 L .466 .2364 L p
1 g
F P
s
P
p
.002 w
.46538 .6248 m .50538 .62783 L .50585 .62513 L p
1 g
F P
s
P
p
.002 w
.50585 .62513 m .45895 .62157 L .46538 .6248 L p
1 g
F P
s
P
p
.002 w
.55232 .61902 m .50585 .62513 L .50538 .62783 L p
1 g
F P
s
P
p
.002 w
.61616 .2725 m .57356 .24734 L .56298 .24593 L p
1 g
F P
s
P
p
.002 w
.51794 .235 m .56298 .24593 L .57356 .24734 L p
1 g
F P
s
P
p
.002 w
.31104 .38959 m .30279 .43618 L .30555 .41347 L p
1 g
F P
s
P
p
.002 w
.30555 .41347 m .31376 .36694 L .31104 .38959 L p
1 g
F P
s
P
p
.002 w
.66066 .31949 m .62984 .28195 L .61616 .2725 L p
1 g
F P
s
P
p
.002 w
.62984 .28195 m .66066 .31949 L .67327 .33604 L p
1 g
F P
s
P
p
.002 w
.42866 .61375 m .46538 .6248 L .45895 .62157 L p
1 g
F P
s
P
p
.002 w
.45895 .62157 m .41576 .60857 L .42866 .61375 L p
1 g
F P
s
P
p
.002 w
.3138 .4826 m .32592 .52349 L .31835 .50271 L p
1 g
F P
s
P
p
.002 w
.31835 .50271 m .30548 .45945 L .3138 .4826 L p
1 g
F P
s
P
p
.002 w
.40555 .25957 m .36107 .2903 L .37502 .28003 L p
1 g
F P
s
P
p
.002 w
.37502 .28003 m .41509 .25233 L .40555 .25957 L p
1 g
F P
s
P
p
.002 w
.50538 .62783 m .54501 .62262 L .55232 .61902 L p
1 g
F P
s
P
p
.002 w
.59428 .60366 m .55232 .61902 L .54501 .62262 L p
1 g
F P
s
P
p
.004 w
.50269 .64351 m
.50302 .67012 L
s
P
p
.002 w
.69395 .40193 m .68144 .35581 L .67327 .33604 L p
1 g
F P
s
P
p
.002 w
.68144 .35581 m .69395 .40193 L .6973 .42455 L p
1 g
F P
s
P
p
.002 w
.57356 .24734 m .61616 .2725 L .62984 .28195 L p
1 g
F P
s
P
p
.002 w
.6863 .49214 m .69519 .44806 L .6973 .42455 L p
1 g
F P
s
P
p
.002 w
.69519 .44806 m .6863 .49214 L .67912 .51342 L p
1 g
F P
s
P
p
.002 w
.52126 .23465 m .466 .2364 L .47042 .23651 L p
1 g
F P
s
P
p
.002 w
.47042 .23651 m .51794 .235 L .52126 .23465 L p
1 g
F P
s
P
p
.002 w
.57356 .24734 m .52126 .23465 L .51794 .235 L p
1 g
F P
s
P
p
.002 w
.35635 .55856 m .3803 .58701 L .36581 .57451 L p
1 g
F P
s
P
p
.002 w
.36581 .57451 m .33863 .54232 L .35635 .55856 L p
1 g
F P
s
P
p
.002 w
.39872 .59552 m .42866 .61375 L .41576 .60857 L p
1 g
F P
s
P
p
.002 w
.41576 .60857 m .3803 .58701 L .39872 .59552 L p
1 g
F P
s
P
p
.002 w
.59428 .60366 m .62773 .58014 L .64243 .56678 L p
1 g
F P
s
P
p
.002 w
.64243 .56678 m .66664 .53304 L .67912 .51342 L p
1 g
F P
s
P
p
.002 w
.66664 .53304 m .64243 .56678 L .62773 .58014 L p
1 g
F P
s
P
p
.002 w
.54501 .62262 m .58066 .60958 L .59428 .60366 L p
1 g
F P
s
P
p
.002 w
.62773 .58014 m .59428 .60366 L .58066 .60958 L p
1 g
F P
s
P
p
.002 w
.3439 .32372 m .31376 .36694 L .32152 .34676 L p
1 g
F P
s
P
p
.002 w
.32152 .34676 m .35052 .30493 L .3439 .32372 L p
1 g
F P
s
P
p
.002 w
.31371 .41415 m .30548 .45945 L .30279 .43618 L p
1 g
F P
s
P
p
.002 w
.30279 .43618 m .31104 .38959 L .31371 .41415 L p
1 g
F P
s
P
p
.002 w
.64035 .29597 m .67327 .33604 L .68144 .35581 L p
1 g
F P
s
P
p
.002 w
.67327 .33604 m .64035 .29597 L .62984 .28195 L p
1 g
F P
s
P
p
.002 w
.32773 .50493 m .33863 .54232 L .32592 .52349 L p
1 g
F P
s
P
p
.002 w
.32592 .52349 m .3138 .4826 L .32773 .50493 L p
1 g
F P
s
P
p
.002 w
.46235 .24184 m .40555 .25957 L .41509 .25233 L p
1 g
F P
s
P
p
.002 w
.41509 .25233 m .466 .2364 L .46235 .24184 L p
1 g
F P
s
P
p
.002 w
.47308 .62264 m .50474 .62505 L .50538 .62783 L p
1 g
F P
s
P
p
.002 w
.50538 .62783 m .46538 .6248 L .47308 .62264 L p
1 g
F P
s
P
p
.002 w
.54501 .62262 m .50538 .62783 L .50474 .62505 L p
1 g
F P
s
P
p
.002 w
.68468 .37839 m .6973 .42455 L .69519 .44806 L p
1 g
F P
s
P
p
.002 w
.6973 .42455 m .68468 .37839 L .68144 .35581 L p
1 g
F P
s
P
p
.002 w
.62984 .28195 m .5825 .25401 L .57356 .24734 L p
1 g
F P
s
P
p
.002 w
.52126 .23465 m .57356 .24734 L .5825 .25401 L p
1 g
F P
s
P
p
.002 w
.39835 .27204 m .35052 .30493 L .36107 .2903 L p
1 g
F P
s
P
p
.002 w
.36107 .2903 m .40555 .25957 L .39835 .27204 L p
1 g
F P
s
P
p
.002 w
.68743 .47179 m .67912 .51342 L .66664 .53304 L p
1 g
F P
s
P
p
.002 w
.67912 .51342 m .68743 .47179 L .69519 .44806 L p
1 g
F P
s
P
p
.002 w
.44412 .6139 m .47308 .62264 L .46538 .6248 L p
1 g
F P
s
P
p
.002 w
.46538 .6248 m .42866 .61375 L .44412 .6139 L p
1 g
F P
s
P
p
.002 w
.50474 .62505 m .53611 .62092 L .54501 .62262 L p
1 g
F P
s
P
p
.002 w
.58066 .60958 m .54501 .62262 L .53611 .62092 L p
1 g
F P
s
P
p
.002 w
.5825 .25401 m .62984 .28195 L .64035 .29597 L p
1 g
F P
s
P
p
.002 w
.52412 .23988 m .46235 .24184 L .466 .2364 L p
1 g
F P
s
P
p
.002 w
.466 .2364 m .52126 .23465 L .52412 .23988 L p
1 g
F P
s
P
p
.002 w
.37877 .57157 m .39872 .59552 L .3803 .58701 L p
1 g
F P
s
P
p
.002 w
.3803 .58701 m .35635 .55856 L .37877 .57157 L p
1 g
F P
s
P
p
.002 w
.5825 .25401 m .52412 .23988 L .52126 .23465 L p
1 g
F P
s
P
p
.002 w
.34161 .34628 m .31104 .38959 L .31376 .36694 L p
1 g
F P
s
P
p
.002 w
.31376 .36694 m .3439 .32372 L .34161 .34628 L p
1 g
F P
s
P
p
.002 w
.58066 .60958 m .60887 .5897 L .62773 .58014 L p
1 g
F P
s
P
p
.002 w
.64901 .55034 m .62773 .58014 L .60887 .5897 L p
1 g
F P
s
P
p
.002 w
.62773 .58014 m .64901 .55034 L .66664 .53304 L p
1 g
F P
s
P
p
.002 w
.32192 .4399 m .3138 .4826 L .30548 .45945 L p
1 g
F P
s
P
p
.002 w
.30548 .45945 m .31371 .41415 L .32192 .4399 L p
1 g
F P
s
P
p
.002 w
.4207 .59954 m .44412 .6139 L .42866 .61375 L p
1 g
F P
s
P
p
.002 w
.42866 .61375 m .39872 .59552 L .4207 .59954 L p
1 g
F P
s
P
p
.002 w
.53611 .62092 m .5642 .61061 L .58066 .60958 L p
1 g
F P
s
P
p
.002 w
.60887 .5897 m .58066 .60958 L .5642 .61061 L p
1 g
F P
s
P
p
.002 w
.34708 .52568 m .35635 .55856 L .33863 .54232 L p
1 g
F P
s
P
p
.002 w
.33863 .54232 m .32773 .50493 L .34708 .52568 L p
1 g
F P
s
P
p
.002 w
.6472 .3144 m .68144 .35581 L .68468 .37839 L p
1 g
F P
s
P
p
.002 w
.68144 .35581 m .6472 .3144 L .64035 .29597 L p
1 g
F P
s
P
p
.002 w
.68267 .40318 m .69519 .44806 L .68743 .47179 L p
1 g
F P
s
P
p
.002 w
.69519 .44806 m .68267 .40318 L .68468 .37839 L p
1 g
F P
s
P
p
.002 w
.67401 .49499 m .66664 .53304 L .64901 .55034 L p
1 g
F P
s
P
p
.002 w
.66664 .53304 m .67401 .49499 L .68743 .47179 L p
1 g
F P
s
P
p
.002 w
.45965 .25301 m .39835 .27204 L .40555 .25957 L p
1 g
F P
s
P
p
.002 w
.40555 .25957 m .46235 .24184 L .45965 .25301 L p
1 g
F P
s
P
p
.002 w
.39385 .28965 m .3439 .32372 L .35052 .30493 L p
1 g
F P
s
P
p
.002 w
.35052 .30493 m .39835 .27204 L .39385 .28965 L p
1 g
F P
s
P
p
.002 w
.64035 .29597 m .58943 .26606 L .5825 .25401 L p
1 g
F P
s
P
p
.002 w
.52412 .23988 m .5825 .25401 L .58943 .26606 L p
1 g
F P
s
P
p
.002 w
.48189 .61482 m .50394 .61651 L .50474 .62505 L p
1 g
F P
s
P
p
.002 w
.50474 .62505 m .47308 .62264 L .48189 .61482 L p
1 g
F P
s
P
p
.002 w
.53611 .62092 m .50474 .62505 L .50394 .61651 L p
1 g
F P
s
P
p
.002 w
.58943 .26606 m .64035 .29597 L .6472 .3144 L p
1 g
F P
s
P
p
.002 w
.46181 .60871 m .48189 .61482 L .47308 .62264 L p
1 g
F P
s
P
p
.002 w
.47308 .62264 m .44412 .6139 L .46181 .60871 L p
1 g
F P
s
P
p
.002 w
.50394 .61651 m .52578 .61362 L .53611 .62092 L p
1 g
F P
s
P
p
.002 w
.5642 .61061 m .53611 .62092 L .52578 .61362 L p
1 g
F P
s
P
p
.002 w
.40535 .5808 m .4207 .59954 L .39872 .59552 L p
1 g
F P
s
P
p
.002 w
.39872 .59552 m .37877 .57157 L .40535 .5808 L p
1 g
F P
s
P
p
.002 w
.33562 .46603 m .32773 .50493 L .3138 .4826 L p
1 g
F P
s
P
p
.002 w
.3138 .4826 m .32192 .4399 L .33562 .46603 L p
1 g
F P
s
P
p
.002 w
.34396 .37206 m .31371 .41415 L .31104 .38959 L p
1 g
F P
s
P
p
.002 w
.31104 .38959 m .34161 .34628 L .34396 .37206 L p
1 g
F P
s
P
p
.002 w
.5642 .61061 m .58622 .59497 L .60887 .5897 L p
1 g
F P
s
P
p
.002 w
.62653 .56465 m .60887 .5897 L .58622 .59497 L p
1 g
F P
s
P
p
.002 w
.60887 .5897 m .62653 .56465 L .64901 .55034 L p
1 g
F P
s
P
p
.002 w
.3714 .54409 m .37877 .57157 L .35635 .55856 L p
1 g
F P
s
P
p
.002 w
.35635 .55856 m .34708 .52568 L .3714 .54409 L p
1 g
F P
s
P
p
.002 w
.5264 .25091 m .45965 .25301 L .46235 .24184 L p
1 g
F P
s
P
p
.002 w
.46235 .24184 m .52412 .23988 L .5264 .25091 L p
1 g
F P
s
P
p
.002 w
.58943 .26606 m .5264 .25091 L .52412 .23988 L p
1 g
F P
s
P
p
.002 w
.67522 .4295 m .68743 .47179 L .67401 .49499 L p
1 g
F P
s
P
p
.002 w
.68743 .47179 m .67522 .4295 L .68267 .40318 L p
1 g
F P
s
P
p
.002 w
.64996 .33689 m .68468 .37839 L .68267 .40318 L p
1 g
F P
s
P
p
.002 w
.68468 .37839 m .64996 .33689 L .6472 .3144 L p
1 g
F P
s
P
p
.002 w
.44572 .59872 m .46181 .60871 L .44412 .6139 L p
1 g
F P
s
P
p
.002 w
.44412 .6139 m .4207 .59954 L .44572 .59872 L p
1 g
F P
s
P
p
.002 w
.65514 .51691 m .64901 .55034 L .62653 .56465 L p
1 g
F P
s
P
p
.002 w
.64901 .55034 m .65514 .51691 L .67401 .49499 L p
1 g
F P
s
P
p
.002 w
.52578 .61362 m .54524 .60641 L .5642 .61061 L p
1 g
F P
s
P
p
.002 w
.58622 .59497 m .5642 .61061 L .54524 .60641 L p
1 g
F P
s
P
p
.002 w
.39236 .31211 m .34161 .34628 L .3439 .32372 L p
1 g
F P
s
P
p
.002 w
.3439 .32372 m .39385 .28965 L .39236 .31211 L p
1 g
F P
s
P
p
.002 w
.45804 .26991 m .39385 .28965 L .39835 .27204 L p
1 g
F P
s
P
p
.002 w
.39835 .27204 m .45965 .25301 L .45804 .26991 L p
1 g
F P
s
P
p
.002 w
.35454 .49166 m .34708 .52568 L .32773 .50493 L p
1 g
F P
s
P
p
.002 w
.32773 .50493 m .33562 .46603 L .35454 .49166 L p
1 g
F P
s
P
p
.002 w
.59399 .28343 m .6472 .3144 L .64996 .33689 L p
1 g
F P
s
P
p
.002 w
.6472 .3144 m .59399 .28343 L .58943 .26606 L p
1 g
F P
s
P
p
.002 w
.5264 .25091 m .58943 .26606 L .59399 .28343 L p
1 g
F P
s
P
p
.002 w
.35106 .40032 m .32192 .4399 L .31371 .41415 L p
1 g
F P
s
P
p
.002 w
.31371 .41415 m .34396 .37206 L .35106 .40032 L p
1 g
F P
s
P
p
.002 w
.43538 .58579 m .44572 .59872 L .4207 .59954 L p
1 g
F P
s
P
p
.002 w
.4207 .59954 m .40535 .5808 L .43538 .58579 L p
1 g
F P
s
P
p
.002 w
.4916 .60123 m .50299 .60211 L .50394 .61651 L p
1 g
F P
s
P
p
.002 w
.50394 .61651 m .48189 .61482 L .4916 .60123 L p
1 g
F P
s
P
p
.002 w
.52578 .61362 m .50394 .61651 L .50299 .60211 L p
1 g
F P
s
P
p
.002 w
.40001 .55947 m .40535 .5808 L .37877 .57157 L p
1 g
F P
s
P
p
.002 w
.37877 .57157 m .3714 .54409 L .40001 .55947 L p
1 g
F P
s
P
p
.002 w
.54524 .60641 m .56033 .59556 L .58622 .59497 L p
1 g
F P
s
P
p
.002 w
.59974 .57539 m .58622 .59497 L .56033 .59556 L p
1 g
F P
s
P
p
.002 w
.58622 .59497 m .59974 .57539 L .62653 .56465 L p
1 g
F P
s
P
p
.002 w
.66236 .45651 m .67401 .49499 L .65514 .51691 L p
1 g
F P
s
P
p
.002 w
.67401 .49499 m .66236 .45651 L .67522 .4295 L p
1 g
F P
s
P
p
.002 w
.48126 .59804 m .4916 .60123 L .48189 .61482 L p
1 g
F P
s
P
p
.002 w
.48189 .61482 m .46181 .60871 L .48126 .59804 L p
1 g
F P
s
P
p
.002 w
.50299 .60211 m .51427 .6006 L .52578 .61362 L p
1 g
F P
s
P
p
.002 w
.54524 .60641 m .52578 .61362 L .51427 .6006 L p
1 g
F P
s
P
p
.002 w
.64834 .36288 m .68267 .40318 L .67522 .4295 L p
1 g
F P
s
P
p
.002 w
.68267 .40318 m .64834 .36288 L .64996 .33689 L p
1 g
F P
s
P
p
.002 w
.63124 .53675 m .62653 .56465 L .59974 .57539 L p
1 g
F P
s
P
p
.002 w
.62653 .56465 m .63124 .53675 L .65514 .51691 L p
1 g
F P
s
P
p
.002 w
.47308 .59287 m .48126 .59804 L .46181 .60871 L p
1 g
F P
s
P
p
.002 w
.46181 .60871 m .44572 .59872 L .47308 .59287 L p
1 g
F P
s
P
p
.002 w
.52799 .26772 m .45804 .26991 L .45965 .25301 L p
1 g
F P
s
P
p
.002 w
.45965 .25301 m .5264 .25091 L .52799 .26772 L p
1 g
F P
s
P
p
.002 w
.51427 .6006 m .52427 .59686 L .54524 .60641 L p
1 g
F P
s
P
p
.002 w
.56033 .59556 m .54524 .60641 L .52427 .59686 L p
1 g
F P
s
P
p
.002 w
.59399 .28343 m .52799 .26772 L .5264 .25091 L p
1 g
F P
s
P
p
.002 w
.37816 .51587 m .3714 .54409 L .34708 .52568 L p
1 g
F P
s
P
p
.002 w
.34708 .52568 m .35454 .49166 L .37816 .51587 L p
1 g
F P
s
P
p
.002 w
.39409 .33888 m .34396 .37206 L .34161 .34628 L p
1 g
F P
s
P
p
.002 w
.34161 .34628 m .39236 .31211 L .39409 .33888 L p
1 g
F P
s
P
p
.002 w
.36286 .43012 m .33562 .46603 L .32192 .4399 L p
1 g
F P
s
P
p
.002 w
.32192 .4399 m .35106 .40032 L .36286 .43012 L p
1 g
F P
s
P
p
.002 w
.43204 .57121 m .43538 .58579 L .40535 .5808 L p
1 g
F P
s
P
p
.002 w
.40535 .5808 m .40001 .55947 L .43204 .57121 L p
1 g
F P
s
P
p
.002 w
.64436 .4833 m .65514 .51691 L .63124 .53675 L p
1 g
F P
s
P
p
.002 w
.65514 .51691 m .64436 .4833 L .66236 .45651 L p
1 g
F P
s
P
p
.002 w
.5959 .30584 m .64996 .33689 L .64834 .36288 L p
1 g
F P
s
P
p
.002 w
.64996 .33689 m .5959 .30584 L .59399 .28343 L p
1 g
F P
s
P
p
.002 w
.46793 .58623 m .47308 .59287 L .44572 .59872 L p
1 g
F P
s
P
p
.002 w
.44572 .59872 m .43538 .58579 L .46793 .58623 L p
1 g
F P
s
P
p
.002 w
.45763 .2923 m .39236 .31211 L .39385 .28965 L p
1 g
F P
s
P
p
.002 w
.39385 .28965 m .45804 .26991 L .45763 .2923 L p
1 g
F P
s
P
p
.002 w
.56033 .59556 m .56939 .58207 L .59974 .57539 L p
1 g
F P
s
P
p
.002 w
.603 .55377 m .59974 .57539 L .56939 .58207 L p
1 g
F P
s
P
p
.002 w
.59974 .57539 m .603 .55377 L .63124 .53675 L p
1 g
F P
s
P
p
.002 w
.52427 .59686 m .53193 .59124 L .56033 .59556 L p
1 g
F P
s
P
p
.002 w
.56939 .58207 m .56033 .59556 L .53193 .59124 L p
1 g
F P
s
P
p
.002 w
.6422 .39162 m .67522 .4295 L .66236 .45651 L p
1 g
F P
s
P
p
.002 w
.67522 .4295 m .6422 .39162 L .64834 .36288 L p
1 g
F P
s
P
p
.002 w
.52799 .26772 m .59399 .28343 L .5959 .30584 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50149 .54865 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.50299 .60211 m .4916 .60123 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.51427 .6006 m .50299 .60211 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.40572 .53776 m .40001 .55947 L .3714 .54409 L p
1 g
F P
s
P
p
.002 w
.3714 .54409 m .37816 .51587 L .40572 .53776 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.4916 .60123 m .48126 .59804 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.52427 .59686 m .51427 .6006 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.62171 .50891 m .63124 .53675 L .603 .55377 L p
1 g
F P
s
P
p
.002 w
.63124 .53675 m .62171 .50891 L .64436 .4833 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.48126 .59804 m .47308 .59287 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.46641 .57882 m .46793 .58623 L .43538 .58579 L p
1 g
F P
s
P
p
.002 w
.43538 .58579 m .43204 .57121 L .46641 .57882 L p
1 g
F P
s
P
p
.002 w
.37904 .46043 m .35454 .49166 L .33562 .46603 L p
1 g
F P
s
P
p
.002 w
.33562 .46603 m .36286 .43012 L .37904 .46043 L p
1 g
F P
s
P
p
.002 w
.53193 .59124 m .52427 .59686 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.53193 .59124 m .53641 .58433 L .56939 .58207 L p
1 g
F P
s
P
p
.002 w
.57129 .56732 m .56939 .58207 L .53641 .58433 L p
1 g
F P
s
P
p
.002 w
.56939 .58207 m .57129 .56732 L .603 .55377 L p
1 g
F P
s
P
p
.002 w
.39912 .36916 m .35106 .40032 L .34396 .37206 L p
1 g
F P
s
P
p
.002 w
.34396 .37206 m .39409 .33888 L .39912 .36916 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52879 .29009 m .45763 .2923 L .45804 .26991 L p
1 g
F P
s
P
p
.002 w
.45804 .26991 m .52799 .26772 L .52879 .29009 L p
1 g
F P
s
P
p
.002 w
.5959 .30584 m .52879 .29009 L .52799 .26772 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47308 .59287 m .46793 .58623 L .50191 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.63158 .42219 m .66236 .45651 L .64436 .4833 L p
1 g
F P
s
P
p
.002 w
.66236 .45651 m .63158 .42219 L .6422 .39162 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.53641 .58433 m .50578 .58226 L p
.51649 .58041 L 1 g
F P
s
P
p
.002 w
.51095 .58081 m .51079 .57862 L p
.49782 .58121 L 1 g
F P
s
P
p
.49782 .58121 m .49792 .58122 L .51095 .58081 L 1 g
F
P
p
.002 w
.49981 .58132 m .50191 .58199 L .48976 .58091 L p
1 g
F P
s
P
p
.002 w
.48976 .58091 m .48521 .5805 L p
.48905 .58072 L 1 g
F P
s
P
p
.48905 .58072 m .49981 .58132 L .48976 .58091 L 1 g
F
P
p
.002 w
.48905 .58072 m .48921 .57862 L p
.47783 .57769 L 1 g
F P
s
P
p
.49792 .58122 m .49981 .58132 L .51095 .58081 L 1 g
F
P
p
.002 w
.50094 .58138 m .50191 .58199 L .49981 .58132 L p
1 g
F P
s
P
p
.49981 .58132 m .50053 .58136 L .50058 .58136 L 1 g
F
P
p
.49981 .58132 m .50058 .58136 L .51095 .58081 L 1 g
F
P
p
.50053 .58136 m .50103 .58138 L .51095 .58081 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46793 .58623 m .46653 .57943 L p
.49082 .58119 L 1 g
F P
s
P
p
.002 w
.50191 .58199 m .49645 .58267 L p
.49082 .58119 L 1 g
F P
s
P
p
.002 w
.49645 .58267 m .46793 .58623 L p
.49082 .58119 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58072 L p
1 g
F P
s
P
p
.002 w
.48521 .5805 m .50191 .58199 L p
.46653 .57943 L 1 g
F P
s
P
p
.002 w
.48905 .58072 m .48889 .583 L p
.49782 .58121 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58072 L .49782 .58121 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46819 .57508 L p
1 g
F P
s
P
p
.002 w
.46641 .57882 m .46763 .57493 L p
.46819 .57508 L 1 g
F P
s
P
p
.47667 .57959 m .46819 .57508 L .48803 .58044 L 1 g
F
P
p
.46641 .57882 m .46819 .57508 L .47667 .57959 L 1 g
F
P
p
.002 w
.46641 .57882 m .43204 .57121 L p
.46273 .57139 L 1 g
F P
s
P
p
.46872 .57265 m .45886 .56871 L .45979 .56936 L 1 g
F
P
p
.002 w
.46767 .57481 m .46641 .57882 L p
.46273 .57139 L 1 g
F P
s
P
p
.002 w
.46819 .57508 m .46872 .57265 L p
.45979 .56936 L 1 g
F P
s
P
p
.45801 .57136 m .45097 .56325 L .46273 .57139 L 1 g
F
P
p
.43204 .57121 m .45091 .56328 L .45801 .57136 L 1 g
F
P
p
.45091 .56328 m .45097 .56325 L .45801 .57136 L 1 g
F
P
p
.002 w
.43204 .57121 m .43628 .5565 L .45097 .56325 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56312 L p
1 g
F P
s
P
p
.002 w
.45097 .56325 m .45084 .5632 L p
.45089 .5632 L 1 g
F P
s
P
p
.002 w
.45084 .5632 m .43628 .5565 L p
.4473 .5589 L 1 g
F P
s
P
p
.46872 .57265 m .45078 .56312 L .4583 .56849 L 1 g
F
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44377 .55461 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43837 .54731 L p
1 g
F P
s
P
p
.43455 .54157 m .43837 .54731 L .43628 .5565 L 1 g
F
P
p
.002 w
.44095 .55119 m .43995 .55233 L p
.43837 .54731 L 1 g
F P
s
P
p
.002 w
.43995 .55233 m .43628 .5565 L p
.43837 .54731 L 1 g
F P
s
P
p
.002 w
.43837 .54731 m .43925 .54566 L p
.43556 .53837 L 1 g
F P
s
P
p
.45146 .56129 m .43837 .54731 L .44095 .55119 L 1 g
F
P
p
.002 w
.43628 .5565 m .44095 .55119 L p
.4473 .5589 L 1 g
F P
s
P
p
.44377 .55461 m .44095 .55119 L .44249 .5535 L 1 g
F
P
p
.45146 .56129 m .44095 .55119 L .44377 .55461 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44786 .54333 m .47472 .56486 L p
.4473 .5589 L 1 g
F P
s
P
p
.002 w
.44095 .55119 m .44786 .54333 L p
.4473 .5589 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44786 .54333 m .44095 .55119 L p
.43837 .54731 L 1 g
F P
s
P
p
.43455 .54157 m .43666 .54185 L .43837 .54731 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43253 .5287 L p
1 g
F P
s
P
p
.43925 .54566 m .43253 .5287 L .43556 .53837 L 1 g
F
P
p
.43666 .54185 m .44786 .54333 L .43837 .54731 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.40572 .53776 m .42233 .51812 L .43254 .5282 L p
1 g
F P
s
P
p
.002 w
.43253 .5287 m .43346 .52734 L p
.43317 .51913 L 1 g
F P
s
P
p
.002 w
.43254 .5282 m .42233 .51812 L p
.43298 .52184 L 1 g
F P
s
P
p
.43317 .51913 m .43254 .5282 L .43253 .5287 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42233 .51812 m .43371 .51149 L p
.43298 .52184 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43395 .50933 L p
1 g
F P
s
P
p
.43505 .49952 m .43395 .50933 L .42233 .51812 L 1 g
F
P
p
.002 w
.43371 .51149 m .4326 .51214 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.4326 .51214 m .42233 .51812 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43801 .50086 L 1 g
F P
s
P
p
.43346 .52734 m .43395 .50933 L .4331 .51696 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44832 .50298 m .43371 .51149 L p
.43395 .50933 L 1 g
F P
s
P
p
.43505 .49952 m .43826 .50035 L .43395 .50933 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44257 .49138 L p
1 g
F P
s
P
p
.43485 .50826 m .44257 .49138 L .43801 .50086 L 1 g
F
P
p
.43826 .50035 m .44832 .50298 L .43395 .50933 L 1 g
F
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.3991 .49014 m .43243 .47016 L .44266 .49129 L p
1 g
F P
s
P
p
.002 w
.44266 .49129 m .44832 .50298 L p
.43432 .49933 L 1 g
F P
s
P
p
.3991 .49014 m .44266 .49129 L .43432 .49933 L 1 g
F
P
p
.002 w
.44257 .49138 m .44166 .49233 L p
.43801 .50086 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.48079 .49431 m .44832 .50298 L .44266 .49129 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.45355 .48071 m .48079 .49431 L .44266 .49129 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45786 .47652 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45355 .48071 m .45786 .47652 L .48079 .49431 L 1 g
F
P
p
.002 w
.45786 .47652 m .45826 .47608 L p
.46585 .47275 L 1 g
F P
s
P
p
.002 w
.47607 .46794 m .48079 .49431 L p
.45786 .47652 L 1 g
F P
s
P
p
.002 w
.51584 .4933 m .48079 .49431 L .47607 .46794 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .47654 .4677 L 1 g
F
P
p
.45826 .47608 m .4775 .46726 L .46585 .47275 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.48724 .46572 L 1 g
F P
s
P
p
.47754 .4672 m .51584 .4933 L .47607 .46794 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46376 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46376 L .48724 .46572 L 1 g
F
P
p
.48197 .465 m .48351 .46629 L .47754 .4672 L 1 g
F
P
p
.48351 .46629 m .51584 .4933 L .47754 .4672 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.52244 .46717 m .54912 .50009 L .51881 .46671 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54215 .47653 L p
1 g
F P
s
P
p
.52214 .46667 m .54215 .47653 L .53041 .47095 L 1 g
F
P
p
.52856 .47007 m .54912 .50009 L .52244 .46717 L 1 g
F
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.53041 .47095 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.51985 .45736 m .52315 .45805 L p
.54912 .50009 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5661 .50939 L p
1 g
F P
s
P
p
.55661 .4905 m .5661 .50939 L .56586 .50888 L 1 g
F
P
p
.002 w
.57659 .51372 m .57103 .51993 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56557 .50825 m .56603 .50848 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56603 .50848 m .57659 .51372 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.5661 .50939 m .56515 .50826 L p
.56686 .51932 L 1 g
F P
s
P
p
.55661 .4905 m .56586 .50888 L .56148 .49982 L 1 g
F
P
p
.56586 .50888 m .56615 .50945 L .56557 .50825 L 1 g
F
P
p
.56586 .50888 m .56557 .50825 L .56148 .49982 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5674 .52859 L p
1 g
F P
s
P
p
.56515 .50826 m .5674 .52859 L .56732 .52667 L 1 g
F
P
p
.57659 .51372 m .56801 .54428 L .5674 .52859 L 1 g
F
P
p
.002 w
.56723 .52418 m .56948 .52166 L p
.5674 .52859 L 1 g
F P
s
P
p
.002 w
.56948 .52166 m .57659 .51372 L p
.5674 .52859 L 1 g
F P
s
P
p
.002 w
.5674 .52859 m .56654 .52734 L p
.56463 .53779 L 1 g
F P
s
P
p
.56515 .50826 m .56732 .52667 L .56686 .51932 L 1 g
F
P
p
.56732 .52667 m .56758 .52886 L .56723 .52418 L 1 g
F
P
p
.56732 .52667 m .56723 .52418 L .56686 .51932 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5492 .56307 L p
1 g
F P
s
P
p
.5656 .55287 m .53818 .57602 L .5492 .56307 L 1 g
F
P
p
.002 w
.55151 .56036 m .55734 .55727 L p
.5492 .56307 L 1 g
F P
s
P
p
.002 w
.55734 .55727 m .5656 .55287 L p
.5492 .56307 L 1 g
F P
s
P
p
.002 w
.5492 .56307 m .54854 .56129 L p
.53912 .57027 L 1 g
F P
s
P
p
.56075 .54566 m .5492 .56307 L .55151 .56036 L 1 g
F
P
p
.002 w
.56107 .54848 m .5656 .55287 L .55151 .56036 L p
1 g
F P
s
P
p
.55511 .55589 m .55151 .56036 L .55472 .55658 L 1 g
F
P
p
.56075 .54566 m .55151 .56036 L .55511 .55589 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .55155 .56318 L p
.56075 .54566 L 1 g
F P
s
P
p
.002 w
.5656 .55287 m .56134 .54873 L p
.56631 .54039 L 1 g
F P
s
P
p
.002 w
.56134 .54873 m .56107 .54848 L p
.56172 .54748 L 1 g
F P
s
P
p
.56631 .54039 m .56134 .54873 L .56172 .54748 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56172 .54748 L p
1 g
F P
s
P
p
.56654 .52734 m .56172 .54748 L .56463 .53779 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55272 .54037 m .56723 .52418 L p
.56631 .54039 L 1 g
F P
s
P
p
.002 w
.56172 .54748 m .56075 .54566 L p
.55155 .56318 L 1 g
F P
s
P
p
.002 w
.56107 .54848 m .55272 .54037 L p
.56631 .54039 L 1 g
F P
s
P
p
.002 w
.56172 .54748 m .56257 .5491 L p
.56463 .53779 L 1 g
F P
s
P
p
.002 w
.55155 .56318 m .56257 .5491 L .56172 .54748 L p
1 g
F P
s
P
p
.002 w
.55272 .54037 m .56107 .54848 L p
.53414 .5696 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53177 .5749 L p
1 g
F P
s
P
p
.002 w
.5372 .57685 m .52495 .57863 L p
.53177 .5749 L 1 g
F P
s
P
p
.002 w
.53551 .57285 m .53588 .57373 L p
.53177 .5749 L 1 g
F P
s
P
p
.002 w
.53588 .57373 m .5372 .57685 L p
.53177 .5749 L 1 g
F P
s
P
p
.002 w
.53177 .5749 m .53128 .57265 L p
.52085 .578 L 1 g
F P
s
P
p
.54854 .56129 m .53177 .5749 L .53388 .57374 L 1 g
F
P
p
.54854 .56129 m .53189 .57543 L .53912 .57027 L 1 g
F
P
p
.50094 .58139 m .50188 .5814 L .51095 .58081 L 1 g
F
P
p
.002 w
.50233 .58139 m .50191 .58199 L .50202 .5814 L p
1 g
F P
s
P
p
.50188 .5814 m .50202 .58141 L .50217 .5814 L 1 g
F
P
p
.50188 .5814 m .50217 .5814 L .51095 .58081 L 1 g
F
P
p
.50202 .58141 m .50256 .58138 L .51095 .58081 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.50669 .55672 m .51801 .55891 L .50233 .58139 L p
1 g
F P
s
P
p
.002 w
.50202 .5814 m .50669 .55672 L p
.50233 .58139 L 1 g
F P
s
P
p
.50217 .58141 m .5036 .58132 L .51095 .58081 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51801 .55891 m .52751 .56338 L .50277 .58137 L p
1 g
F P
s
P
p
.002 w
.50277 .58137 m .50191 .58199 L .50233 .58139 L p
1 g
F P
s
P
p
.002 w
.50233 .58139 m .51801 .55891 L p
.50277 .58137 L 1 g
F P
s
P
p
.50202 .58141 m .50217 .58141 L .50256 .58138 L 1 g
F
P
p
.50217 .58141 m .50233 .58141 L .5036 .58132 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52751 .56338 m .53414 .5696 L .50367 .58132 L p
1 g
F P
s
P
p
.002 w
.50367 .58132 m .50191 .58199 L .50277 .58137 L p
1 g
F P
s
P
p
.002 w
.50277 .58137 m .52751 .56338 L p
.50367 .58132 L 1 g
F P
s
P
p
.50233 .58141 m .50914 .58094 L .51095 .58081 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58081 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58081 L .51144 .58067 L 1 g
F
P
p
.002 w
.52495 .57863 m .51196 .58053 L p
.53177 .5749 L 1 g
F P
s
P
p
.002 w
.51196 .58053 m .5372 .57685 L p
.50578 .58226 L 1 g
F P
s
P
p
.52085 .578 m .51096 .58087 L .51998 .57845 L 1 g
F
P
p
.53128 .57265 m .51142 .58068 L .52085 .578 L 1 g
F
P
p
.51142 .58068 m .51096 .58087 L .52085 .578 L 1 g
F
P
p
.53551 .57285 m .53177 .5749 L .50914 .58094 L 1 g
F
P
p
.002 w
.51196 .58053 m .50914 .58094 L p
.53177 .5749 L 1 g
F P
s
P
p
.002 w
.50914 .58094 m .50191 .58199 L p
.50464 .58125 L 1 g
F P
s
P
p
.53551 .57285 m .50914 .58094 L .50464 .58125 L 1 g
F
P
p
.002 w
.53414 .5696 m .53551 .57285 L p
.50464 .58125 L 1 g
F P
s
P
p
.002 w
.50191 .58199 m .50367 .58132 L p
.50464 .58125 L 1 g
F P
s
P
p
.002 w
.50367 .58132 m .53414 .5696 L p
.50464 .58125 L 1 g
F P
s
P
p
.002 w
.50142 .5814 m .50191 .58199 L .50094 .58138 L p
1 g
F P
s
P
p
.002 w
.50174 .5814 m .50191 .58199 L .50142 .5814 L p
1 g
F P
s
P
p
.002 w
.50202 .5814 m .50191 .58199 L .50174 .5814 L p
1 g
F P
s
P
p
.002 w
.50578 .58226 m .50191 .58199 L .50914 .58094 L p
1 g
F P
s
P
p
.002 w
.50914 .58094 m .51196 .58053 L p
.51095 .58081 L 1 g
F P
s
P
p
.51095 .58081 m .50578 .58226 L .50914 .58094 L 1 g
F
P
p
.002 w
.53641 .58433 m .53193 .59124 L .50417 .58269 L p
1 g
F P
s
P
p
.002 w
.50417 .58269 m .50191 .58199 L .50578 .58226 L p
1 g
F P
s
P
p
.002 w
.50578 .58226 m .53641 .58433 L p
.50417 .58269 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58081 L p
1 g
F P
s
P
p
.002 w
.51095 .58081 m .51095 .58081 L p
.5108 .58082 L 1 g
F P
s
P
p
.5108 .58082 m .48889 .583 L .51095 .58081 L 1 g
F
P
p
.50233 .58141 m .50252 .58141 L .50914 .58094 L 1 g
F
P
p
.002 w
.5372 .57685 m .53698 .57895 L p
.51649 .58041 L 1 g
F P
s
P
p
.002 w
.53698 .57895 m .53641 .58433 L p
.51649 .58041 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53177 .5749 L p
1 g
F P
s
P
p
.52085 .578 m .51111 .583 L .53177 .5749 L 1 g
F
P
p
.002 w
.53177 .5749 m .53189 .57543 L p
.53388 .57374 L 1 g
F P
s
P
p
.002 w
.53414 .5696 m .55151 .56036 L p
.54908 .56316 L 1 g
F P
s
P
p
.002 w
.5372 .57685 m .53551 .57285 L p
.54908 .56316 L 1 g
F P
s
P
p
.002 w
.53551 .57285 m .53414 .5696 L p
.54908 .56316 L 1 g
F P
s
P
p
.002 w
.53189 .57543 m .5322 .57686 L p
.53912 .57027 L 1 g
F P
s
P
p
.002 w
.55151 .56036 m .53414 .5696 L p
.56107 .54848 L 1 g
F P
s
P
p
.53818 .57602 m .5372 .57685 L .55151 .56036 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5492 .56307 L p
1 g
F P
s
P
p
.53912 .57027 m .5322 .57686 L .5492 .56307 L 1 g
F
P
p
.002 w
.5492 .56307 m .54998 .56518 L p
.55472 .55658 L 1 g
F P
s
P
p
.56801 .54428 m .5656 .55287 L .56723 .52418 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5674 .52859 L p
1 g
F P
s
P
p
.56463 .53779 m .56257 .5491 L .5674 .52859 L 1 g
F
P
p
.002 w
.5674 .52859 m .56758 .52886 L p
.56732 .52667 L 1 g
F P
s
P
p
.002 w
.57103 .51993 m .56723 .52418 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56758 .52886 m .56854 .53025 L p
.56686 .51932 L 1 g
F P
s
P
p
.56557 .50825 m .5661 .50939 L .55272 .54037 L 1 g
F
P
p
.002 w
.56723 .52418 m .55272 .54037 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5661 .50939 L p
1 g
F P
s
P
p
.56686 .51932 m .56854 .53025 L .5661 .50939 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54912 .50009 m .56557 .50825 L p
.55272 .54037 L 1 g
F P
s
P
p
.002 w
.5661 .50939 m .56615 .50945 L p
.56586 .50888 L 1 g
F P
s
P
p
.002 w
.57659 .51372 m .56557 .50825 L p
.55795 .49254 L 1 g
F P
s
P
p
.002 w
.56615 .50945 m .56713 .51061 L p
.56148 .49982 L 1 g
F P
s
P
p
.002 w
.55734 .49128 m .55661 .4905 L p
.56148 .49982 L 1 g
F P
s
P
p
.57505 .50838 m .57659 .51372 L .55403 .48808 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55734 .49128 L p
1 g
F P
s
P
p
.56148 .49982 m .56713 .51061 L .55734 .49128 L 1 g
F
P
p
.56291 .46637 m .57505 .50838 L .55734 .49128 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55734 .49128 L p
1 g
F P
s
P
p
.54174 .47608 m .55734 .49128 L .55515 .48916 L 1 g
F
P
p
.54174 .47608 m .5576 .49155 L .54891 .4831 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55403 .48808 m .55484 .48611 L p
.55734 .49128 L 1 g
F P
s
P
p
.002 w
.55484 .48611 m .56291 .46637 L p
.55734 .49128 L 1 g
F P
s
P
p
.002 w
.54912 .50009 m .55403 .48808 L p
.55795 .49254 L 1 g
F P
s
P
p
.002 w
.56557 .50825 m .54912 .50009 L p
.55795 .49254 L 1 g
F P
s
P
p
.002 w
.55734 .49128 m .5576 .49155 L p
.55515 .48916 L 1 g
F P
s
P
p
.002 w
.55403 .48808 m .54912 .50009 L p
.52315 .45805 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52315 .45805 m .56291 .46637 L .55403 .48808 L p
1 g
F P
s
P
p
.002 w
.5576 .49155 m .55834 .49233 L p
.54891 .4831 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46717 L p
1 g
F P
s
P
p
.53041 .47095 m .54302 .47747 L .52244 .46717 L 1 g
F
P
p
.51985 .45736 m .52696 .46773 L .52244 .46717 L 1 g
F
P
p
.5 .4634 m .52244 .46717 L .52003 .46687 L 1 g
F
P
p
.5 .4634 m .52252 .46729 L .51017 .46536 L 1 g
F
P
p
.002 w
.51881 .46671 m .51894 .46551 L p
.52244 .46717 L 1 g
F P
s
P
p
.002 w
.51894 .46551 m .51985 .45736 L p
.52244 .46717 L 1 g
F P
s
P
p
.52696 .46773 m .52856 .47007 L .52244 .46717 L 1 g
F
P
p
.002 w
.54215 .47653 m .54302 .47747 L p
.53041 .47095 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52252 .46729 L p
.52003 .46687 L 1 g
F P
s
P
p
.002 w
.54912 .50009 m .51584 .4933 L .51881 .46671 L p
1 g
F P
s
P
p
.002 w
.47441 .45868 m .51985 .45736 L .51881 .46671 L p
1 g
F P
s
P
p
.002 w
.51881 .46671 m .51584 .4933 L p
.47597 .45998 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.47441 .45868 m .51881 .46671 L .47597 .45998 L 1 g
F
P
p
.002 w
.52252 .46729 m .52282 .46778 L p
.51017 .46536 L 1 g
F P
s
P
p
.002 w
.5 .46376 m .5 .46442 L p
.48724 .46572 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47754 .4672 L p
1 g
F P
s
P
p
.48724 .46572 m .5 .46442 L .47754 .4672 L 1 g
F
P
p
.47441 .45868 m .48197 .465 L .47754 .4672 L 1 g
F
P
p
.002 w
.47607 .46794 m .47598 .46744 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47598 .46744 m .47441 .45868 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .4775 .46726 L p
.47654 .4677 L 1 g
F P
s
P
p
.002 w
.4775 .46726 m .47718 .46778 L p
.46585 .47275 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.43243 .47016 m .47468 .46018 L .45786 .47652 L 1 g
F
P
p
.44339 .4905 m .45786 .47652 L .44897 .48515 L 1 g
F
P
p
.45132 .4796 m .45786 .47652 L .45355 .48071 L 1 g
F
P
p
.43243 .47016 m .45786 .47652 L .45132 .4796 L 1 g
F
P
p
.002 w
.47468 .46018 m .47607 .46794 L p
.45786 .47652 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45786 .47652 L p
1 g
F P
s
P
p
.46585 .47275 m .47718 .46778 L .45786 .47652 L 1 g
F
P
p
.002 w
.45786 .47652 m .45698 .47747 L p
.44897 .48515 L 1 g
F P
s
P
p
.002 w
.43243 .47016 m .47441 .45868 L .47468 .46018 L p
1 g
F P
s
P
p
.002 w
.44266 .49129 m .43243 .47016 L p
.45355 .48071 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .44257 .49138 L p
.44265 .49129 L 1 g
F P
s
P
p
.44265 .49129 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.44257 .49138 m .44339 .4905 L p
.4564 .47803 L 1 g
F P
s
P
p
.4564 .47803 m .45698 .47747 L .44257 .49138 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43801 .50086 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.002 w
.43395 .50933 m .43287 .51061 L p
.4331 .51696 L 1 g
F P
s
P
p
.002 w
.42233 .51812 m .3991 .49014 L p
.43505 .49952 L 1 g
F P
s
P
p
.002 w
.44832 .50298 m .46565 .53325 L p
.43298 .52184 L 1 g
F P
s
P
p
.002 w
.43371 .51149 m .44832 .50298 L p
.43298 .52184 L 1 g
F P
s
P
p
.40572 .53776 m .43254 .5282 L .43215 .54125 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52873 L p
1 g
F P
s
P
p
.002 w
.4325 .52873 m .43253 .5287 L p
.43253 .52831 L 1 g
F P
s
P
p
.43253 .52831 m .43287 .51061 L .4325 .52873 L 1 g
F
P
p
.43317 .51913 m .43298 .51357 L .43254 .5282 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.46565 .53325 m .44786 .54333 L .43254 .5282 L p
1 g
F P
s
P
p
.43298 .52184 m .46565 .53325 L .43254 .5282 L 1 g
F
P
p
.002 w
.43254 .5282 m .44786 .54333 L p
.43215 .54125 L 1 g
F P
s
P
p
.43298 .51357 m .43287 .51061 L .43253 .5287 L 1 g
F
P
p
.002 w
.43253 .5287 m .43146 .53025 L p
.43556 .53837 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43837 .54731 L p
1 g
F P
s
P
p
.43556 .53837 m .43146 .53025 L .43837 .54731 L 1 g
F
P
p
.002 w
.43837 .54731 m .43743 .5491 L p
.44249 .5535 L 1 g
F P
s
P
p
.002 w
.43628 .5565 m .40572 .53776 L p
.43455 .54157 L 1 g
F P
s
P
p
.4473 .5589 m .47472 .56486 L .45084 .5632 L 1 g
F
P
p
.002 w
.45078 .56312 m .45002 .56518 L p
.4583 .56849 L 1 g
F P
s
P
p
.002 w
.47472 .56486 m .46874 .57142 L .45097 .56325 L p
1 g
F P
s
P
p
.45089 .5632 m .47472 .56486 L .45097 .56325 L 1 g
F
P
p
.002 w
.45078 .56312 m .45078 .56312 L p
.44182 .55291 L 1 g
F P
s
P
p
.44377 .55461 m .44182 .55291 L .45078 .56312 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.44182 .55291 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.45979 .56936 m .452 .56648 L .46767 .57481 L 1 g
F
P
p
.45979 .56936 m .46767 .57481 L .46819 .57508 L 1 g
F
P
p
.002 w
.45097 .56325 m .46874 .57142 L p
.46273 .57139 L 1 g
F P
s
P
p
.002 w
.46874 .57142 m .46767 .57481 L p
.46273 .57139 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .452 .56648 L p
.45979 .56936 L 1 g
F P
s
P
p
.45886 .56871 m .45002 .56518 L .45979 .56936 L 1 g
F
P
p
.48921 .57862 m .46819 .57508 L .47783 .57769 L 1 g
F
P
p
.002 w
.46763 .57493 m .46874 .57142 L p
.48803 .58044 L 1 g
F P
s
P
p
.002 w
.452 .56648 m .4678 .57686 L .46819 .57508 L p
1 g
F P
s
P
p
.002 w
.46819 .57508 m .4678 .57686 L p
.47783 .57769 L 1 g
F P
s
P
p
.002 w
.46874 .57142 m .49981 .58132 L p
.48803 .58044 L 1 g
F P
s
P
p
.002 w
.48521 .5805 m .46641 .57882 L p
.49981 .58132 L 1 g
F P
s
P
p
.002 w
.46653 .57943 m .46641 .57882 L .48521 .5805 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58072 L p
1 g
F P
s
P
p
.002 w
.48905 .58072 m .48905 .58072 L p
.489 .58071 L 1 g
F P
s
P
p
.489 .58071 m .4678 .57686 L .48905 .58072 L 1 g
F
P
p
.002 w
.46874 .57142 m .47472 .56486 L .50094 .58138 L p
1 g
F P
s
P
p
.002 w
.49981 .58132 m .46874 .57142 L p
.50094 .58138 L 1 g
F P
s
P
p
.002 w
.47472 .56486 m .48375 .55987 L .50142 .5814 L p
1 g
F P
s
P
p
.002 w
.50094 .58138 m .47472 .56486 L p
.50142 .5814 L 1 g
F P
s
P
p
.50053 .58136 m .50094 .58139 L .50103 .58138 L 1 g
F
P
p
.50094 .58139 m .50202 .58145 L .50252 .58141 L 1 g
F
P
p
.002 w
.48375 .55987 m .49482 .55705 L .50174 .5814 L p
1 g
F P
s
P
p
.002 w
.50142 .5814 m .48375 .55987 L p
.50174 .5814 L 1 g
F P
s
P
p
.002 w
.49482 .55705 m .50669 .55672 L .50202 .5814 L p
1 g
F P
s
P
p
.002 w
.50174 .5814 m .49482 .55705 L p
.50202 .5814 L 1 g
F P
s
P
p
.50117 .5814 m .50188 .58146 L .50202 .58145 L 1 g
F
P
p
.49777 .58122 m .50094 .5814 L .50117 .5814 L 1 g
F
P
p
.50094 .5814 m .50188 .58146 L .50117 .5814 L 1 g
F
P
p
.49777 .58122 m .50202 .58145 L .49792 .58122 L 1 g
F
P
p
.47783 .57769 m .4678 .57686 L .48905 .58072 L 1 g
F
P
p
.49782 .58121 m .49777 .58122 L .49792 .58122 L 1 g
F
P
p
.49777 .58122 m .49363 .58205 L .50188 .58146 L 1 g
F
P
p
.49363 .58205 m .48889 .583 L .51095 .58081 L 1 g
F
P
p
.002 w
.51095 .58081 m .51096 .58087 L p
.51144 .58067 L 1 g
F P
s
P
p
.002 w
.51096 .58087 m .51111 .583 L p
.51998 .57845 L 1 g
F P
s
P
p
.002 w
.43628 .5565 m .43204 .57121 L .40001 .55947 L p
1 g
F P
s
P
p
.002 w
.40001 .55947 m .40572 .53776 L .43628 .5565 L p
1 g
F P
s
P
p
.002 w
.59496 .33274 m .64834 .36288 L .6422 .39162 L p
1 g
F P
s
P
p
.002 w
.64834 .36288 m .59496 .33274 L .5959 .30584 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.59515 .5324 m .603 .55377 L .57129 .56732 L p
1 g
F P
s
P
p
.002 w
.603 .55377 m .59515 .5324 L .62171 .50891 L p
1 g
F P
s
P
p
.002 w
.45852 .31963 m .39409 .33888 L .39236 .31211 L p
1 g
F P
s
P
p
.002 w
.39236 .31211 m .45763 .2923 L .45852 .31963 L p
1 g
F P
s
P
p
.002 w
.53641 .58433 m .5372 .57685 L .57129 .56732 L p
1 g
F P
s
P
p
.002 w
.3991 .49014 m .37816 .51587 L .35454 .49166 L p
1 g
F P
s
P
p
.002 w
.35454 .49166 m .37904 .46043 L .3991 .49014 L p
1 g
F P
s
P
p
.002 w
.52879 .29009 m .5959 .30584 L .59496 .33274 L p
1 g
F P
s
P
p
.002 w
.5656 .55287 m .57129 .56732 L .5372 .57685 L p
1 g
F P
s
P
p
.002 w
.57129 .56732 m .5656 .55287 L .59515 .5324 L p
1 g
F P
s
P
p
.002 w
.61676 .4535 m .64436 .4833 L .62171 .50891 L p
1 g
F P
s
P
p
.002 w
.64436 .4833 m .61676 .4535 L .63158 .42219 L p
1 g
F P
s
P
p
.002 w
.40736 .40195 m .36286 .43012 L .35106 .40032 L p
1 g
F P
s
P
p
.002 w
.35106 .40032 m .39912 .36916 L .40736 .40195 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42233 .51812 m .40572 .53776 L .37816 .51587 L p
1 g
F P
s
P
p
.002 w
.37816 .51587 m .3991 .49014 L .42233 .51812 L p
1 g
F P
s
P
p
.002 w
.59107 .36336 m .6422 .39162 L .63158 .42219 L p
1 g
F P
s
P
p
.002 w
.6422 .39162 m .59107 .36336 L .59496 .33274 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59821 .4844 m .62171 .50891 L .59515 .5324 L p
1 g
F P
s
P
p
.002 w
.62171 .50891 m .59821 .4844 L .61676 .4535 L p
1 g
F P
s
P
p
.002 w
.52873 .31747 m .45852 .31963 L .45763 .2923 L p
1 g
F P
s
P
p
.002 w
.45763 .2923 m .52879 .29009 L .52873 .31747 L p
1 g
F P
s
P
p
.002 w
.59496 .33274 m .52873 .31747 L .52879 .29009 L p
1 g
F P
s
P
p
.002 w
.53414 .5696 m .52751 .56338 L .55272 .54037 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46071 .35111 m .39912 .36916 L .39409 .33888 L p
1 g
F P
s
P
p
.002 w
.39409 .33888 m .45852 .31963 L .46071 .35111 L p
1 g
F P
s
P
p
.002 w
.57659 .51372 m .59515 .5324 L .5656 .55287 L p
1 g
F P
s
P
p
.002 w
.59515 .5324 m .57659 .51372 L .59821 .4844 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.4186 .43605 m .37904 .46043 L .36286 .43012 L p
1 g
F P
s
P
p
.002 w
.36286 .43012 m .40736 .40195 L .4186 .43605 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.48375 .55987 m .47472 .56486 L .44786 .54333 L p
1 g
F P
s
P
p
.002 w
.52873 .31747 m .59496 .33274 L .59107 .36336 L p
1 g
F P
s
P
p
.002 w
.52751 .56338 m .51801 .55891 L .53395 .53131 L p
1 g
F P
s
P
p
.002 w
.53395 .53131 m .55272 .54037 L .52751 .56338 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.58429 .39667 m .63158 .42219 L .61676 .4535 L p
1 g
F P
s
P
p
.002 w
.63158 .42219 m .58429 .39667 L .59107 .36336 L p
1 g
F P
s
P
p
.002 w
.49482 .55705 m .48375 .55987 L .46565 .53325 L p
1 g
F P
s
P
p
.002 w
.44786 .54333 m .46565 .53325 L .48375 .55987 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51801 .55891 m .50669 .55672 L .51139 .52683 L p
1 g
F P
s
P
p
.002 w
.51139 .52683 m .53395 .53131 L .51801 .55891 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.50669 .55672 m .49482 .55705 L .48769 .5275 L p
1 g
F P
s
P
p
.002 w
.46565 .53325 m .48769 .5275 L .49482 .55705 L p
1 g
F P
s
P
p
.002 w
.48769 .5275 m .51139 .52683 L .50669 .55672 L p
1 g
F P
s
P
p
.002 w
.43243 .47016 m .3991 .49014 L .37904 .46043 L p
1 g
F P
s
P
p
.002 w
.37904 .46043 m .4186 .43605 L .43243 .47016 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55272 .54037 m .53395 .53131 L .54912 .50009 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.004 w
.50232 .61431 m
.50232 .61446 L
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57479 .43145 m .61676 .4535 L .59821 .4844 L p
1 g
F P
s
P
p
.002 w
.61676 .4535 m .57479 .43145 L .58429 .39667 L p
1 g
F P
s
P
p
.004 w
.59841 .41473 m
.59922 .4146 L
s
P
p
.004 w
.5 .43051 m
.57848 .41793 L
s
P
p
.004 w
.59922 .4146 m
.61025 .41284 L
s
P
p
.004 w
.61025 .41284 m
.66007 .40485 L
s
P
p
.002 w
.52777 .34907 m .46071 .35111 L .45852 .31963 L p
1 g
F P
s
P
p
.002 w
.45852 .31963 m .52873 .31747 L .52777 .34907 L p
1 g
F P
s
P
p
.002 w
.46417 .38565 m .40736 .40195 L .39912 .36916 L p
1 g
F P
s
P
p
.002 w
.39912 .36916 m .46071 .35111 L .46417 .38565 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59107 .36336 m .52777 .34907 L .52873 .31747 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52777 .34907 m .59107 .36336 L .58429 .39667 L p
1 g
F P
s
P
p
.002 w
.56291 .46637 m .59821 .4844 L .57659 .51372 L p
1 g
F P
s
P
p
.002 w
.59821 .4844 m .56291 .46637 L .57479 .43145 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.48769 .5275 m .46565 .53325 L .44832 .50298 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53395 .53131 m .51139 .52683 L .51584 .4933 L p
1 g
F P
s
P
p
.002 w
.51584 .4933 m .54912 .50009 L .53395 .53131 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51139 .52683 m .48769 .5275 L .48079 .49431 L p
1 g
F P
s
P
p
.002 w
.44832 .50298 m .48079 .49431 L .48769 .5275 L p
1 g
F P
s
P
p
.002 w
.48079 .49431 m .51584 .4933 L .51139 .52683 L p
1 g
F P
s
P
p
.002 w
.4688 .42198 m .4186 .43605 L .40736 .40195 L p
1 g
F P
s
P
p
.002 w
.40736 .40195 m .46417 .38565 L .4688 .42198 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.50255 .63276 m
.50269 .64351 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.52593 .3838 m .58429 .39667 L .57479 .43145 L p
1 g
F P
s
P
p
.002 w
.58429 .39667 m .52593 .3838 L .52777 .34907 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52593 .3838 m .46417 .38565 L .46071 .35111 L p
1 g
F P
s
P
p
.002 w
.46071 .35111 m .52777 .34907 L .52593 .3838 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47441 .45868 m .43243 .47016 L .4186 .43605 L p
1 g
F P
s
P
p
.002 w
.4186 .43605 m .4688 .42198 L .47441 .45868 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52326 .42037 m .57479 .43145 L .56291 .46637 L p
1 g
F P
s
P
p
.002 w
.57479 .43145 m .52326 .42037 L .52593 .3838 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.56291 .46637 m .51985 .45736 L .52326 .42037 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52326 .42037 m .4688 .42198 L .46417 .38565 L p
1 g
F P
s
P
p
.002 w
.46417 .38565 m .52593 .3838 L .52326 .42037 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51985 .45736 m .47441 .45868 L .4688 .42198 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.4688 .42198 m .52326 .42037 L .51985 .45736 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .66007 .40485 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .50302 .67012 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.146512)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.146512)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45405 .45855 m .49974 .47256 L .50494 .4447 L p
1 g
F P
s
P
p
.002 w
.50494 .4447 m .46493 .43237 L .45405 .45855 L p
1 g
F P
s
P
p
.002 w
.54647 .4471 m .50494 .4447 L .49974 .47256 L p
1 g
F P
s
P
p
.002 w
.46493 .43237 m .50494 .4447 L .51 .41657 L p
1 g
F P
s
P
p
.002 w
.50494 .4447 m .54647 .4471 L .54468 .41848 L p
1 g
F P
s
P
p
.002 w
.54468 .41848 m .51 .41657 L .50494 .4447 L p
1 g
F P
s
P
p
.002 w
.51 .41657 m .47662 .40624 L .46493 .43237 L p
1 g
F P
s
P
p
.002 w
.47662 .40624 m .51 .41657 L .51485 .38869 L p
1 g
F P
s
P
p
.002 w
.51 .41657 m .54468 .41848 L .54179 .3901 L p
1 g
F P
s
P
p
.002 w
.54179 .3901 m .51485 .38869 L .51 .41657 L p
1 g
F P
s
P
p
.002 w
.43008 .41119 m .46493 .43237 L .47662 .40624 L p
1 g
F P
s
P
p
.002 w
.47662 .40624 m .44765 .38841 L .43008 .41119 L p
1 g
F P
s
P
p
.002 w
.44765 .38841 m .47662 .40624 L .48891 .38063 L p
1 g
F P
s
P
p
.002 w
.51485 .38869 m .48891 .38063 L .47662 .40624 L p
1 g
F P
s
P
p
.002 w
.41412 .43458 m .45405 .45855 L .46493 .43237 L p
1 g
F P
s
P
p
.002 w
.46493 .43237 m .43008 .41119 L .41412 .43458 L p
1 g
F P
s
P
p
.002 w
.44419 .4843 m .4945 .49965 L .49974 .47256 L p
1 g
F P
s
P
p
.002 w
.49974 .47256 m .45405 .45855 L .44419 .4843 L p
1 g
F P
s
P
p
.002 w
.54715 .47544 m .49974 .47256 L .4945 .49965 L p
1 g
F P
s
P
p
.002 w
.49974 .47256 m .54715 .47544 L .54647 .4471 L p
1 g
F P
s
P
p
.002 w
.48891 .38063 m .51485 .38869 L .51937 .36156 L p
1 g
F P
s
P
p
.002 w
.51485 .38869 m .54179 .3901 L .53787 .36247 L p
1 g
F P
s
P
p
.002 w
.53787 .36247 m .51937 .36156 L .51485 .38869 L p
1 g
F P
s
P
p
.002 w
.57739 .41169 m .54468 .41848 L .54647 .4471 L p
1 g
F P
s
P
p
.002 w
.54468 .41848 m .57739 .41169 L .56714 .38464 L p
1 g
F P
s
P
p
.002 w
.56714 .38464 m .54179 .3901 L .54468 .41848 L p
1 g
F P
s
P
p
.002 w
.58576 .43925 m .54647 .4471 L .54715 .47544 L p
1 g
F P
s
P
p
.002 w
.54647 .4471 m .58576 .43925 L .57739 .41169 L p
1 g
F P
s
P
p
.002 w
.48891 .38063 m .46649 .36665 L .44765 .38841 L p
1 g
F P
s
P
p
.002 w
.46649 .36665 m .48891 .38063 L .50157 .356 L p
1 g
F P
s
P
p
.002 w
.51937 .36156 m .50157 .356 L .48891 .38063 L p
1 g
F P
s
P
p
.002 w
.40008 .45815 m .44419 .4843 L .45405 .45855 L p
1 g
F P
s
P
p
.002 w
.45405 .45855 m .41412 .43458 L .40008 .45815 L p
1 g
F P
s
P
p
.002 w
.54179 .3901 m .56714 .38464 L .5552 .35861 L p
1 g
F P
s
P
p
.002 w
.5552 .35861 m .53787 .36247 L .54179 .3901 L p
1 g
F P
s
P
p
.002 w
.4945 .49965 m .54667 .50298 L .54715 .47544 L p
1 g
F P
s
P
p
.002 w
.59209 .46679 m .54715 .47544 L .54667 .50298 L p
1 g
F P
s
P
p
.002 w
.54715 .47544 m .59209 .46679 L .58576 .43925 L p
1 g
F P
s
P
p
.002 w
.40375 .3829 m .43008 .41119 L .44765 .38841 L p
1 g
F P
s
P
p
.002 w
.44765 .38841 m .42595 .36462 L .40375 .3829 L p
1 g
F P
s
P
p
.002 w
.42595 .36462 m .44765 .38841 L .46649 .36665 L p
1 g
F P
s
P
p
.002 w
.43554 .50913 m .48931 .52546 L .4945 .49965 L p
1 g
F P
s
P
p
.002 w
.4945 .49965 m .44419 .4843 L .43554 .50913 L p
1 g
F P
s
P
p
.002 w
.54667 .50298 m .4945 .49965 L .48931 .52546 L p
1 g
F P
s
P
p
.002 w
.50157 .356 m .51937 .36156 L .5235 .33569 L p
1 g
F P
s
P
p
.002 w
.51937 .36156 m .53787 .36247 L .53295 .33613 L p
1 g
F P
s
P
p
.002 w
.53295 .33613 m .5235 .33569 L .51937 .36156 L p
1 g
F P
s
P
p
.002 w
.46649 .36665 m .44986 .34805 L .42595 .36462 L p
1 g
F P
s
P
p
.002 w
.44986 .34805 m .46649 .36665 L .48626 .34633 L p
1 g
F P
s
P
p
.002 w
.50157 .356 m .48626 .34633 L .46649 .36665 L p
1 g
F P
s
P
p
.002 w
.38371 .40255 m .41412 .43458 L .43008 .41119 L p
1 g
F P
s
P
p
.002 w
.43008 .41119 m .40375 .3829 L .38371 .40255 L p
1 g
F P
s
P
p
.002 w
.48626 .34633 m .50157 .356 L .51439 .33283 L p
1 g
F P
s
P
p
.002 w
.5235 .33569 m .51439 .33283 L .50157 .356 L p
1 g
F P
s
P
p
.002 w
.38829 .48144 m .43554 .50913 L .44419 .4843 L p
1 g
F P
s
P
p
.002 w
.44419 .4843 m .40008 .45815 L .38829 .48144 L p
1 g
F P
s
P
p
.002 w
.53787 .36247 m .5552 .35861 L .54178 .3341 L p
1 g
F P
s
P
p
.002 w
.54178 .3341 m .53295 .33613 L .53787 .36247 L p
1 g
F P
s
P
p
.002 w
.60493 .39664 m .57739 .41169 L .58576 .43925 L p
1 g
F P
s
P
p
.002 w
.57739 .41169 m .60493 .39664 L .58833 .37274 L p
1 g
F P
s
P
p
.002 w
.58833 .37274 m .56714 .38464 L .57739 .41169 L p
1 g
F P
s
P
p
.002 w
.56714 .38464 m .58833 .37274 L .56958 .35031 L p
1 g
F P
s
P
p
.002 w
.56958 .35031 m .5552 .35861 L .56714 .38464 L p
1 g
F P
s
P
p
.002 w
.48626 .34633 m .47502 .3335 L .44986 .34805 L p
1 g
F P
s
P
p
.002 w
.47502 .3335 m .48626 .34633 L .5066 .32786 L p
1 g
F P
s
P
p
.002 w
.51439 .33283 m .5066 .32786 L .48626 .34633 L p
1 g
F P
s
P
p
.002 w
.36628 .4232 m .40008 .45815 L .41412 .43458 L p
1 g
F P
s
P
p
.002 w
.41412 .43458 m .38371 .40255 L .36628 .4232 L p
1 g
F P
s
P
p
.002 w
.48931 .52546 m .54504 .52917 L .54667 .50298 L p
1 g
F P
s
P
p
.002 w
.59622 .4938 m .54667 .50298 L .54504 .52917 L p
1 g
F P
s
P
p
.002 w
.54667 .50298 m .59622 .4938 L .59209 .46679 L p
1 g
F P
s
P
p
.002 w
.61904 .42155 m .58576 .43925 L .59209 .46679 L p
1 g
F P
s
P
p
.002 w
.58576 .43925 m .61904 .42155 L .60493 .39664 L p
1 g
F P
s
P
p
.002 w
.5552 .35861 m .56958 .35031 L .54905 .32979 L p
1 g
F P
s
P
p
.002 w
.54905 .32979 m .54178 .3341 L .5552 .35861 L p
1 g
F P
s
P
p
.002 w
.42832 .53253 m .48428 .54947 L .48931 .52546 L p
1 g
F P
s
P
p
.002 w
.48931 .52546 m .43554 .50913 L .42832 .53253 L p
1 g
F P
s
P
p
.002 w
.54504 .52917 m .48931 .52546 L .48428 .54947 L p
1 g
F P
s
P
p
.002 w
.41391 .33704 m .42595 .36462 L .44986 .34805 L p
1 g
F P
s
P
p
.002 w
.44986 .34805 m .44084 .32659 L .41391 .33704 L p
1 g
F P
s
P
p
.002 w
.44084 .32659 m .44986 .34805 L .47502 .3335 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .51439 .33283 L .5235 .33569 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .5235 .33569 L .53295 .33613 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .5066 .32786 L .51439 .33283 L closepath p
1 g
F P
s
P
p
.002 w
.63035 .447 m .59209 .46679 L .59622 .4938 L p
1 g
F P
s
P
p
.002 w
.59209 .46679 m .63035 .447 L .61904 .42155 L p
1 g
F P
s
P
p
.002 w
.38883 .34997 m .40375 .3829 L .42595 .36462 L p
1 g
F P
s
P
p
.002 w
.42595 .36462 m .41391 .33704 L .38883 .34997 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .53295 .33613 L .54178 .3341 L closepath p
1 g
F P
s
P
p
.002 w
.47502 .3335 m .46907 .31878 L .44084 .32659 L p
1 g
F P
s
P
p
.002 w
.46907 .31878 m .47502 .3335 L .50094 .32127 L p
1 g
F P
s
P
p
.002 w
.5066 .32786 m .50094 .32127 L .47502 .3335 L p
1 g
F P
s
P
p
.002 w
.37905 .50398 m .42832 .53253 L .43554 .50913 L p
1 g
F P
s
P
p
.002 w
.43554 .50913 m .38829 .48144 L .37905 .50398 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .50094 .32127 L .5066 .32786 L closepath p
1 g
F P
s
P
p
.002 w
.35189 .44446 m .38829 .48144 L .40008 .45815 L p
1 g
F P
s
P
p
.002 w
.40008 .45815 m .36628 .4232 L .35189 .44446 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .54178 .3341 L .54905 .32979 L closepath p
1 g
F P
s
P
p
.002 w
.60308 .35541 m .58833 .37274 L .60493 .39664 L p
1 g
F P
s
P
p
.002 w
.58833 .37274 m .60308 .35541 L .57945 .33835 L p
1 g
F P
s
P
p
.002 w
.57945 .33835 m .56958 .35031 L .58833 .37274 L p
1 g
F P
s
P
p
.002 w
.56958 .35031 m .57945 .33835 L .55396 .32365 L p
1 g
F P
s
P
p
.002 w
.55396 .32365 m .54905 .32979 L .56958 .35031 L p
1 g
F P
s
P
p
.002 w
.36617 .36514 m .38371 .40255 L .40375 .3829 L p
1 g
F P
s
P
p
.002 w
.40375 .3829 m .38883 .34997 L .36617 .36514 L p
1 g
F P
s
P
p
.002 w
.48428 .54947 m .54224 .55347 L .54504 .52917 L p
1 g
F P
s
P
p
.002 w
.59801 .51972 m .54504 .52917 L .54224 .55347 L p
1 g
F P
s
P
p
.002 w
.54504 .52917 m .59801 .51972 L .59622 .4938 L p
1 g
F P
s
P
p
.002 w
.50094 .32127 m .49802 .31375 L .46907 .31878 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .49802 .31375 L .50094 .32127 L closepath p
1 g
F P
s
P
p
.002 w
.62434 .37453 m .60493 .39664 L .61904 .42155 L p
1 g
F P
s
P
p
.002 w
.60493 .39664 m .62434 .37453 L .60308 .35541 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .54905 .32979 L .55396 .32365 L closepath p
1 g
F P
s
P
p
.002 w
.63856 .47246 m .59622 .4938 L .59801 .51972 L p
1 g
F P
s
P
p
.002 w
.59622 .4938 m .63856 .47246 L .63035 .447 L p
1 g
F P
s
P
p
.002 w
.44063 .30441 m .44084 .32659 L .46907 .31878 L p
1 g
F P
s
P
p
.002 w
.46907 .31878 m .46918 .30367 L .44063 .30441 L p
1 g
F P
s
P
p
.002 w
.46918 .30367 m .46907 .31878 L .49802 .31375 L p
1 g
F P
s
P
p
.002 w
.49802 .31375 m .4982 .3061 L .46918 .30367 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .4982 .3061 L .49802 .31375 L closepath p
1 g
F P
s
P
p
.002 w
.64275 .39533 m .61904 .42155 L .63035 .447 L p
1 g
F P
s
P
p
.002 w
.61904 .42155 m .64275 .39533 L .62434 .37453 L p
1 g
F P
s
P
p
.002 w
.41319 .30836 m .41391 .33704 L .44084 .32659 L p
1 g
F P
s
P
p
.002 w
.44084 .32659 m .44063 .30441 L .41319 .30836 L p
1 g
F P
s
P
p
.002 w
.34649 .38229 m .36628 .4232 L .38371 .40255 L p
1 g
F P
s
P
p
.002 w
.38371 .40255 m .36617 .36514 L .34649 .38229 L p
1 g
F P
s
P
p
.002 w
.55597 .31631 m .55396 .32365 L .57945 .33835 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .55396 .32365 L .55597 .31631 L closepath p
1 g
F P
s
P
p
.002 w
.42271 .55399 m .47951 .57111 L .48428 .54947 L p
1 g
F P
s
P
p
.002 w
.48428 .54947 m .42832 .53253 L .42271 .55399 L p
1 g
F P
s
P
p
.002 w
.54224 .55347 m .48428 .54947 L .47951 .57111 L p
1 g
F P
s
P
p
.002 w
.58366 .32392 m .57945 .33835 L .60308 .35541 L p
1 g
F P
s
P
p
.002 w
.57945 .33835 m .58366 .32392 L .55597 .31631 L p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .5437 .29517 L .53495 .29105 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .53495 .29105 L .52529 .28935 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .52529 .28935 L .51581 .29026 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .51581 .29026 L .50758 .29365 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .50758 .29365 L .5015 .29914 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .5015 .29914 L .4982 .3061 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .55597 .31631 L .55481 .30856 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .55481 .30856 L .55057 .30124 L closepath p
1 g
F P
s
P
p
.002 w
.52712 .31161 m .55057 .30124 L .5437 .29517 L closepath p
1 g
F P
s
P
p
.002 w
.34095 .46589 m .37905 .50398 L .38829 .48144 L p
1 g
F P
s
P
p
.002 w
.38829 .48144 m .35189 .44446 L .34095 .46589 L p
1 g
F P
s
P
p
.002 w
.47547 .28981 m .46918 .30367 L .4982 .3061 L p
1 g
F P
s
P
p
.002 w
.4982 .3061 m .5015 .29914 L .47547 .28981 L p
1 g
F P
s
P
p
.002 w
.37264 .52527 m .42271 .55399 L .42832 .53253 L p
1 g
F P
s
P
p
.002 w
.42832 .53253 m .37905 .50398 L .37264 .52527 L p
1 g
F P
s
P
p
.002 w
.38745 .31551 m .38883 .34997 L .41391 .33704 L p
1 g
F P
s
P
p
.002 w
.41391 .33704 m .41319 .30836 L .38745 .31551 L p
1 g
F P
s
P
p
.002 w
.55481 .30856 m .55597 .31631 L .58366 .32392 L p
1 g
F P
s
P
p
.002 w
.6096 .33432 m .60308 .35541 L .62434 .37453 L p
1 g
F P
s
P
p
.002 w
.60308 .35541 m .6096 .33432 L .58366 .32392 L p
1 g
F P
s
P
p
.002 w
.47951 .57111 m .5383 .57531 L .54224 .55347 L p
1 g
F P
s
P
p
.002 w
.59736 .54398 m .54224 .55347 L .5383 .57531 L p
1 g
F P
s
P
p
.002 w
.54224 .55347 m .59736 .54398 L .59801 .51972 L p
1 g
F P
s
P
p
.002 w
.44959 .2839 m .44063 .30441 L .46918 .30367 L p
1 g
F P
s
P
p
.002 w
.46918 .30367 m .47547 .28981 L .44959 .2839 L p
1 g
F P
s
P
p
.002 w
.48742 .27878 m .47547 .28981 L .5015 .29914 L p
1 g
F P
s
P
p
.002 w
.5015 .29914 m .50758 .29365 L .48742 .27878 L p
1 g
F P
s
P
p
.002 w
.65785 .41741 m .63035 .447 L .63856 .47246 L p
1 g
F P
s
P
p
.002 w
.63035 .447 m .65785 .41741 L .64275 .39533 L p
1 g
F P
s
P
p
.002 w
.6434 .49741 m .59801 .51972 L .59736 .54398 L p
1 g
F P
s
P
p
.002 w
.59801 .51972 m .6434 .49741 L .63856 .47246 L p
1 g
F P
s
P
p
.002 w
.58366 .32392 m .58158 .30853 L .55481 .30856 L p
1 g
F P
s
P
p
.002 w
.55057 .30124 m .55481 .30856 L .58158 .30853 L p
1 g
F P
s
P
p
.002 w
.33032 .40112 m .35189 .44446 L .36628 .4232 L p
1 g
F P
s
P
p
.002 w
.36628 .4232 m .34649 .38229 L .33032 .40112 L p
1 g
F P
s
P
p
.002 w
.58158 .30853 m .58366 .32392 L .6096 .33432 L p
1 g
F P
s
P
p
.002 w
.63319 .34737 m .62434 .37453 L .64275 .39533 L p
1 g
F P
s
P
p
.002 w
.62434 .37453 m .63319 .34737 L .6096 .33432 L p
1 g
F P
s
P
p
.002 w
.50378 .27189 m .48742 .27878 L .50758 .29365 L p
1 g
F P
s
P
p
.002 w
.50758 .29365 m .51581 .29026 L .50378 .27189 L p
1 g
F P
s
P
p
.002 w
.36405 .32582 m .36617 .36514 L .38883 .34997 L p
1 g
F P
s
P
p
.002 w
.38883 .34997 m .38745 .31551 L .36405 .32582 L p
1 g
F P
s
P
p
.002 w
.58158 .30853 m .57331 .2939 L .55057 .30124 L p
1 g
F P
s
P
p
.002 w
.5437 .29517 m .55057 .30124 L .57331 .2939 L p
1 g
F P
s
P
p
.002 w
.42442 .28163 m .41319 .30836 L .44063 .30441 L p
1 g
F P
s
P
p
.002 w
.44063 .30441 m .44959 .2839 L .42442 .28163 L p
1 g
F P
s
P
p
.002 w
.52275 .27001 m .50378 .27189 L .51581 .29026 L p
1 g
F P
s
P
p
.002 w
.51581 .29026 m .52529 .28935 L .52275 .27001 L p
1 g
F P
s
P
p
.002 w
.33384 .48701 m .37264 .52527 L .37905 .50398 L p
1 g
F P
s
P
p
.002 w
.37905 .50398 m .34095 .46589 L .33384 .48701 L p
1 g
F P
s
P
p
.002 w
.41891 .57296 m .47511 .58985 L .47951 .57111 L p
1 g
F P
s
P
p
.002 w
.47951 .57111 m .42271 .55399 L .41891 .57296 L p
1 g
F P
s
P
p
.002 w
.5383 .57531 m .47951 .57111 L .47511 .58985 L p
1 g
F P
s
P
p
.002 w
.53495 .29105 m .5437 .29517 L .55966 .28171 L p
1 g
F P
s
P
p
.002 w
.57331 .2939 m .55966 .28171 L .5437 .29517 L p
1 g
F P
s
P
p
.002 w
.46705 .26743 m .44959 .2839 L .47547 .28981 L p
1 g
F P
s
P
p
.002 w
.47547 .28981 m .48742 .27878 L .46705 .26743 L p
1 g
F P
s
P
p
.002 w
.54213 .27342 m .52275 .27001 L .52529 .28935 L p
1 g
F P
s
P
p
.002 w
.52529 .28935 m .53495 .29105 L .54213 .27342 L p
1 g
F P
s
P
p
.002 w
.55966 .28171 m .54213 .27342 L .53495 .29105 L p
1 g
F P
s
P
p
.002 w
.66919 .44032 m .63856 .47246 L .6434 .49741 L p
1 g
F P
s
P
p
.002 w
.63856 .47246 m .66919 .44032 L .65785 .41741 L p
1 g
F P
s
P
p
.002 w
.36934 .54477 m .41891 .57296 L .42271 .55399 L p
1 g
F P
s
P
p
.002 w
.42271 .55399 m .37264 .52527 L .36934 .54477 L p
1 g
F P
s
P
p
.002 w
.60685 .31164 m .6096 .33432 L .63319 .34737 L p
1 g
F P
s
P
p
.002 w
.6096 .33432 m .60685 .31164 L .58158 .30853 L p
1 g
F P
s
P
p
.002 w
.57331 .2939 m .58158 .30853 L .60685 .31164 L p
1 g
F P
s
P
p
.002 w
.65386 .36284 m .64275 .39533 L .65785 .41741 L p
1 g
F P
s
P
p
.002 w
.64275 .39533 m .65386 .36284 L .63319 .34737 L p
1 g
F P
s
P
p
.002 w
.31817 .42123 m .34095 .46589 L .35189 .44446 L p
1 g
F P
s
P
p
.002 w
.35189 .44446 m .33032 .40112 L .31817 .42123 L p
1 g
F P
s
P
p
.002 w
.34363 .33914 m .34649 .38229 L .36617 .36514 L p
1 g
F P
s
P
p
.002 w
.36617 .36514 m .36405 .32582 L .34363 .33914 L p
1 g
F P
s
P
p
.002 w
.5383 .57531 m .59418 .566 L .59736 .54398 L p
1 g
F P
s
P
p
.002 w
.64465 .52126 m .59736 .54398 L .59418 .566 L p
1 g
F P
s
P
p
.002 w
.59736 .54398 m .64465 .52126 L .6434 .49741 L p
1 g
F P
s
P
p
.002 w
.47511 .58985 m .53324 .59411 L .5383 .57531 L p
1 g
F P
s
P
p
.002 w
.59418 .566 m .5383 .57531 L .53324 .59411 L p
1 g
F P
s
P
p
.002 w
.40057 .2832 m .38745 .31551 L .41319 .30836 L p
1 g
F P
s
P
p
.002 w
.41319 .30836 m .42442 .28163 L .40057 .2832 L p
1 g
F P
s
P
p
.002 w
.49126 .25706 m .46705 .26743 L .48742 .27878 L p
1 g
F P
s
P
p
.002 w
.48742 .27878 m .50378 .27189 L .49126 .25706 L p
1 g
F P
s
P
p
.002 w
.60685 .31164 m .59481 .28989 L .57331 .2939 L p
1 g
F P
s
P
p
.002 w
.55966 .28171 m .57331 .2939 L .59481 .28989 L p
1 g
F P
s
P
p
.002 w
.44693 .26001 m .42442 .28163 L .44959 .2839 L p
1 g
F P
s
P
p
.002 w
.44959 .2839 m .46705 .26743 L .44693 .26001 L p
1 g
F P
s
P
p
.002 w
.62999 .3179 m .63319 .34737 L .65386 .36284 L p
1 g
F P
s
P
p
.002 w
.63319 .34737 m .62999 .3179 L .60685 .31164 L p
1 g
F P
s
P
p
.002 w
.67639 .46357 m .6434 .49741 L .64465 .52126 L p
1 g
F P
s
P
p
.002 w
.6434 .49741 m .67639 .46357 L .66919 .44032 L p
1 g
F P
s
P
p
.002 w
.67102 .38048 m .65785 .41741 L .66919 .44032 L p
1 g
F P
s
P
p
.002 w
.65785 .41741 m .67102 .38048 L .65386 .36284 L p
1 g
F P
s
P
p
.002 w
.51952 .25417 m .49126 .25706 L .50378 .27189 L p
1 g
F P
s
P
p
.002 w
.50378 .27189 m .52275 .27001 L .51952 .25417 L p
1 g
F P
s
P
p
.002 w
.33091 .50731 m .36934 .54477 L .37264 .52527 L p
1 g
F P
s
P
p
.002 w
.37264 .52527 m .33384 .48701 L .33091 .50731 L p
1 g
F P
s
P
p
.002 w
.59481 .28989 m .60685 .31164 L .62999 .3179 L p
1 g
F P
s
P
p
.002 w
.54213 .27342 m .55966 .28171 L .5746 .27167 L p
1 g
F P
s
P
p
.002 w
.59481 .28989 m .5746 .27167 L .55966 .28171 L p
1 g
F P
s
P
p
.002 w
.3268 .35528 m .33032 .40112 L .34649 .38229 L p
1 g
F P
s
P
p
.002 w
.34649 .38229 m .34363 .33914 L .3268 .35528 L p
1 g
F P
s
P
p
.002 w
.37866 .28873 m .36405 .32582 L .38745 .31551 L p
1 g
F P
s
P
p
.002 w
.38745 .31551 m .40057 .2832 L .37866 .28873 L p
1 g
F P
s
P
p
.002 w
.4171 .58888 m .4712 .60509 L .47511 .58985 L p
1 g
F P
s
P
p
.002 w
.47511 .58985 m .41891 .57296 L .4171 .58888 L p
1 g
F P
s
P
p
.002 w
.53324 .59411 m .47511 .58985 L .4712 .60509 L p
1 g
F P
s
P
p
.002 w
.54847 .25924 m .51952 .25417 L .52275 .27001 L p
1 g
F P
s
P
p
.002 w
.52275 .27001 m .54213 .27342 L .54847 .25924 L p
1 g
F P
s
P
p
.002 w
.5746 .27167 m .54847 .25924 L .54213 .27342 L p
1 g
F P
s
P
p
.002 w
.31053 .4422 m .33384 .48701 L .34095 .46589 L p
1 g
F P
s
P
p
.002 w
.34095 .46589 m .31817 .42123 L .31053 .4422 L p
1 g
F P
s
P
p
.002 w
.36939 .56193 m .4171 .58888 L .41891 .57296 L p
1 g
F P
s
P
p
.002 w
.41891 .57296 m .36934 .54477 L .36939 .56193 L p
1 g
F P
s
P
p
.002 w
.53324 .59411 m .58844 .58518 L .59418 .566 L p
1 g
F P
s
P
p
.002 w
.64212 .54342 m .59418 .566 L .58844 .58518 L p
1 g
F P
s
P
p
.002 w
.59418 .566 m .64212 .54342 L .64465 .52126 L p
1 g
F P
s
P
p
.002 w
.47852 .24628 m .44693 .26001 L .46705 .26743 L p
1 g
F P
s
P
p
.002 w
.46705 .26743 m .49126 .25706 L .47852 .24628 L p
1 g
F P
s
P
p
.002 w
.4712 .60509 m .52712 .60929 L .53324 .59411 L p
1 g
F P
s
P
p
.002 w
.58844 .58518 m .53324 .59411 L .52712 .60929 L p
1 g
F P
s
P
p
.002 w
.42755 .25688 m .40057 .2832 L .42442 .28163 L p
1 g
F P
s
P
p
.002 w
.42442 .28163 m .44693 .26001 L .42755 .25688 L p
1 g
F P
s
P
p
.002 w
.65037 .32732 m .65386 .36284 L .67102 .38048 L p
1 g
F P
s
P
p
.002 w
.65386 .36284 m .65037 .32732 L .62999 .3179 L p
1 g
F P
s
P
p
.002 w
.68411 .39994 m .66919 .44032 L .67639 .46357 L p
1 g
F P
s
P
p
.002 w
.66919 .44032 m .68411 .39994 L .67102 .38048 L p
1 g
F P
s
P
p
.002 w
.62999 .3179 m .61451 .28945 L .59481 .28989 L p
1 g
F P
s
P
p
.002 w
.5746 .27167 m .59481 .28989 L .61451 .28945 L p
1 g
F P
s
P
p
.002 w
.6791 .4866 m .64465 .52126 L .64212 .54342 L p
1 g
F P
s
P
p
.002 w
.64465 .52126 m .6791 .4866 L .67639 .46357 L p
1 g
F P
s
P
p
.002 w
.35932 .29826 m .34363 .33914 L .36405 .32582 L p
1 g
F P
s
P
p
.002 w
.36405 .32582 m .37866 .28873 L .35932 .29826 L p
1 g
F P
s
P
p
.002 w
.61451 .28945 m .62999 .3179 L .65037 .32732 L p
1 g
F P
s
P
p
.002 w
.31415 .37395 m .31817 .42123 L .33032 .40112 L p
1 g
F P
s
P
p
.002 w
.33032 .40112 m .3268 .35528 L .31415 .37395 L p
1 g
F P
s
P
p
.002 w
.33244 .52624 m .36939 .56193 L .36934 .54477 L p
1 g
F P
s
P
p
.002 w
.36934 .54477 m .33091 .50731 L .33244 .52624 L p
1 g
F P
s
P
p
.002 w
.51565 .24242 m .47852 .24628 L .49126 .25706 L p
1 g
F P
s
P
p
.002 w
.49126 .25706 m .51952 .25417 L .51565 .24242 L p
1 g
F P
s
P
p
.002 w
.61451 .28945 m .58812 .26548 L .5746 .27167 L p
1 g
F P
s
P
p
.002 w
.54847 .25924 m .5746 .27167 L .58812 .26548 L p
1 g
F P
s
P
p
.002 w
.30779 .46352 m .33091 .50731 L .33384 .48701 L p
1 g
F P
s
P
p
.002 w
.33384 .48701 m .31053 .4422 L .30779 .46352 L p
1 g
F P
s
P
p
.002 w
.41744 .6012 m .46791 .61629 L .4712 .60509 L p
1 g
F P
s
P
p
.002 w
.4712 .60509 m .4171 .58888 L .41744 .6012 L p
1 g
F P
s
P
p
.002 w
.52712 .60929 m .4712 .60509 L .46791 .61629 L p
1 g
F P
s
P
p
.002 w
.55377 .24908 m .51565 .24242 L .51952 .25417 L p
1 g
F P
s
P
p
.002 w
.51952 .25417 m .54847 .25924 L .55377 .24908 L p
1 g
F P
s
P
p
.002 w
.40944 .25836 m .37866 .28873 L .40057 .2832 L p
1 g
F P
s
P
p
.002 w
.40057 .2832 m .42755 .25688 L .40944 .25836 L p
1 g
F P
s
P
p
.002 w
.58812 .26548 m .55377 .24908 L .54847 .25924 L p
1 g
F P
s
P
p
.002 w
.52712 .60929 m .58013 .60091 L .58844 .58518 L p
1 g
F P
s
P
p
.002 w
.63572 .56327 m .58844 .58518 L .58013 .60091 L p
1 g
F P
s
P
p
.002 w
.58844 .58518 m .63572 .56327 L .64212 .54342 L p
1 g
F P
s
P
p
.002 w
.66738 .33981 m .67102 .38048 L .68411 .39994 L p
1 g
F P
s
P
p
.002 w
.67102 .38048 m .66738 .33981 L .65037 .32732 L p
1 g
F P
s
P
p
.002 w
.46587 .24007 m .42755 .25688 L .44693 .26001 L p
1 g
F P
s
P
p
.002 w
.44693 .26001 m .47852 .24628 L .46587 .24007 L p
1 g
F P
s
P
p
.002 w
.37297 .5762 m .41744 .6012 L .4171 .58888 L p
1 g
F P
s
P
p
.002 w
.4171 .58888 m .36939 .56193 L .37297 .5762 L p
1 g
F P
s
P
p
.002 w
.69263 .42081 m .67639 .46357 L .6791 .4866 L p
1 g
F P
s
P
p
.002 w
.67639 .46357 m .69263 .42081 L .68411 .39994 L p
1 g
F P
s
P
p
.002 w
.46791 .61629 m .52004 .62027 L .52712 .60929 L p
1 g
F P
s
P
p
.002 w
.58013 .60091 m .52712 .60929 L .52004 .62027 L p
1 g
F P
s
P
p
.002 w
.34321 .31174 m .3268 .35528 L .34363 .33914 L p
1 g
F P
s
P
p
.002 w
.34363 .33914 m .35932 .29826 L .34321 .31174 L p
1 g
F P
s
P
p
.002 w
.67705 .50882 m .64212 .54342 L .63572 .56327 L p
1 g
F P
s
P
p
.002 w
.64212 .54342 m .67705 .50882 L .6791 .4866 L p
1 g
F P
s
P
p
.002 w
.65037 .32732 m .63184 .29278 L .61451 .28945 L p
1 g
F P
s
P
p
.002 w
.58812 .26548 m .61451 .28945 L .63184 .29278 L p
1 g
F P
s
P
p
.002 w
.30621 .39478 m .31053 .4422 L .31817 .42123 L p
1 g
F P
s
P
p
.002 w
.31817 .42123 m .31415 .37395 L .30621 .39478 L p
1 g
F P
s
P
p
.002 w
.63184 .29278 m .65037 .32732 L .66738 .33981 L p
1 g
F P
s
P
p
.002 w
.33863 .54323 m .37297 .5762 L .36939 .56193 L p
1 g
F P
s
P
p
.002 w
.36939 .56193 m .33244 .52624 L .33863 .54323 L p
1 g
F P
s
P
p
.002 w
.51118 .23529 m .46587 .24007 L .47852 .24628 L p
1 g
F P
s
P
p
.002 w
.47852 .24628 m .51565 .24242 L .51118 .23529 L p
1 g
F P
s
P
p
.002 w
.31027 .48464 m .33244 .52624 L .33091 .50731 L p
1 g
F P
s
P
p
.002 w
.33091 .50731 m .30779 .46352 L .31027 .48464 L p
1 g
F P
s
P
p
.002 w
.39317 .26465 m .35932 .29826 L .37866 .28873 L p
1 g
F P
s
P
p
.002 w
.37866 .28873 m .40944 .25836 L .39317 .26465 L p
1 g
F P
s
P
p
.002 w
.6804 .35519 m .68411 .39994 L .69263 .42081 L p
1 g
F P
s
P
p
.002 w
.68411 .39994 m .6804 .35519 L .66738 .33981 L p
1 g
F P
s
P
p
.002 w
.63184 .29278 m .59979 .26351 L .58812 .26548 L p
1 g
F P
s
P
p
.002 w
.55377 .24908 m .58812 .26548 L .59979 .26351 L p
1 g
F P
s
P
p
.002 w
.69615 .44262 m .6791 .4866 L .67705 .50882 L p
1 g
F P
s
P
p
.002 w
.6791 .4866 m .69615 .44262 L .69263 .42081 L p
1 g
F P
s
P
p
.002 w
.45364 .23886 m .40944 .25836 L .42755 .25688 L p
1 g
F P
s
P
p
.002 w
.42755 .25688 m .46587 .24007 L .45364 .23886 L p
1 g
F P
s
P
p
.002 w
.52004 .62027 m .56934 .61261 L .58013 .60091 L p
1 g
F P
s
P
p
.002 w
.62539 .58018 m .58013 .60091 L .56934 .61261 L p
1 g
F P
s
P
p
.002 w
.58013 .60091 m .62539 .58018 L .63572 .56327 L p
1 g
F P
s
P
p
.002 w
.42004 .60937 m .46535 .6229 L .46791 .61629 L p
1 g
F P
s
P
p
.002 w
.46791 .61629 m .41744 .6012 L .42004 .60937 L p
1 g
F P
s
P
p
.002 w
.52004 .62027 m .46791 .61629 L .46535 .6229 L p
1 g
F P
s
P
p
.002 w
.55782 .24344 m .51118 .23529 L .51565 .24242 L p
1 g
F P
s
P
p
.002 w
.51565 .24242 m .55377 .24908 L .55782 .24344 L p
1 g
F P
s
P
p
.002 w
.33093 .329 m .31415 .37395 L .3268 .35528 L p
1 g
F P
s
P
p
.002 w
.3268 .35528 m .34321 .31174 L .33093 .329 L p
1 g
F P
s
P
p
.002 w
.59979 .26351 m .55782 .24344 L .55377 .24908 L p
1 g
F P
s
P
p
.002 w
.38019 .58704 m .42004 .60937 L .41744 .6012 L p
1 g
F P
s
P
p
.002 w
.41744 .6012 m .37297 .5762 L .38019 .58704 L p
1 g
F P
s
P
p
.002 w
.30344 .41728 m .30779 .46352 L .31053 .4422 L p
1 g
F P
s
P
p
.002 w
.31053 .4422 m .30621 .39478 L .30344 .41728 L p
1 g
F P
s
P
p
.002 w
.67007 .52961 m .63572 .56327 L .62539 .58018 L p
1 g
F P
s
P
p
.002 w
.63572 .56327 m .67007 .52961 L .67705 .50882 L p
1 g
F P
s
P
p
.002 w
.64623 .3 m .66738 .33981 L .6804 .35519 L p
1 g
F P
s
P
p
.002 w
.66738 .33981 m .64623 .3 L .63184 .29278 L p
1 g
F P
s
P
p
.002 w
.59979 .26351 m .63184 .29278 L .64623 .3 L p
1 g
F P
s
P
p
.002 w
.46535 .6229 m .51211 .62651 L .52004 .62027 L p
1 g
F P
s
P
p
.002 w
.56934 .61261 m .52004 .62027 L .51211 .62651 L p
1 g
F P
s
P
p
.002 w
.68888 .37319 m .69263 .42081 L .69615 .44262 L p
1 g
F P
s
P
p
.002 w
.69263 .42081 m .68888 .37319 L .6804 .35519 L p
1 g
F P
s
P
p
.002 w
.31817 .50496 m .33863 .54323 L .33244 .52624 L p
1 g
F P
s
P
p
.002 w
.33244 .52624 m .31027 .48464 L .31817 .50496 L p
1 g
F P
s
P
p
.002 w
.37929 .27584 m .34321 .31174 L .35932 .29826 L p
1 g
F P
s
P
p
.002 w
.35932 .29826 m .39317 .26465 L .37929 .27584 L p
1 g
F P
s
P
p
.002 w
.34957 .55769 m .38019 .58704 L .37297 .5762 L p
1 g
F P
s
P
p
.002 w
.37297 .5762 m .33863 .54323 L .34957 .55769 L p
1 g
F P
s
P
p
.002 w
.50621 .23329 m .45364 .23886 L .46587 .24007 L p
1 g
F P
s
P
p
.002 w
.46587 .24007 m .51118 .23529 L .50621 .23329 L p
1 g
F P
s
P
p
.002 w
.69431 .4648 m .67705 .50882 L .67007 .52961 L p
1 g
F P
s
P
p
.002 w
.67705 .50882 m .69431 .4648 L .69615 .44262 L p
1 g
F P
s
P
p
.002 w
.32303 .34971 m .30621 .39478 L .31415 .37395 L p
1 g
F P
s
P
p
.002 w
.31415 .37395 m .33093 .329 L .32303 .34971 L p
1 g
F P
s
P
p
.002 w
.44221 .243 m .39317 .26465 L .40944 .25836 L p
1 g
F P
s
P
p
.002 w
.40944 .25836 m .45364 .23886 L .44221 .243 L p
1 g
F P
s
P
p
.002 w
.64623 .3 m .60919 .26609 L .59979 .26351 L p
1 g
F P
s
P
p
.002 w
.55782 .24344 m .59979 .26351 L .60919 .26609 L p
1 g
F P
s
P
p
.002 w
.51211 .62651 m .55619 .61971 L .56934 .61261 L p
1 g
F P
s
P
p
.002 w
.61123 .59355 m .56934 .61261 L .55619 .61971 L p
1 g
F P
s
P
p
.002 w
.56934 .61261 m .61123 .59355 L .62539 .58018 L p
1 g
F P
s
P
p
.002 w
.30617 .44088 m .31027 .48464 L .30779 .46352 L p
1 g
F P
s
P
p
.002 w
.30779 .46352 m .30344 .41728 L .30617 .44088 L p
1 g
F P
s
P
p
.002 w
.62539 .58018 m .65811 .54831 L .67007 .52961 L p
1 g
F P
s
P
p
.002 w
.65811 .54831 m .62539 .58018 L .61123 .59355 L p
1 g
F P
s
P
p
.002 w
.42499 .61291 m .46364 .62445 L .46535 .6229 L p
1 g
F P
s
P
p
.002 w
.46535 .6229 m .42004 .60937 L .42499 .61291 L p
1 g
F P
s
P
p
.002 w
.51211 .62651 m .46535 .6229 L .46364 .62445 L p
1 g
F P
s
P
p
.002 w
.6804 .35519 m .6571 .31113 L .64623 .3 L p
1 g
F P
s
P
p
.002 w
.6571 .31113 m .6804 .35519 L .68888 .37319 L p
1 g
F P
s
P
p
.002 w
.56045 .24276 m .50621 .23329 L .51118 .23529 L p
1 g
F P
s
P
p
.002 w
.51118 .23529 m .55782 .24344 L .56045 .24276 L p
1 g
F P
s
P
p
.004 w
.4479 .6589 m
.45371 .63344 L
s
P
p
.002 w
.60919 .26609 m .56045 .24276 L .55782 .24344 L p
1 g
F P
s
P
p
.002 w
.39108 .59391 m .42499 .61291 L .42004 .60937 L p
1 g
F P
s
P
p
.002 w
.42004 .60937 m .38019 .58704 L .39108 .59391 L p
1 g
F P
s
P
p
.002 w
.60919 .26609 m .64623 .3 L .6571 .31113 L p
1 g
F P
s
P
p
.002 w
.46364 .62445 m .50351 .62753 L .51211 .62651 L p
1 g
F P
s
P
p
.002 w
.55619 .61971 m .51211 .62651 L .50351 .62753 L p
1 g
F P
s
P
p
.002 w
.69615 .44262 m .69232 .39345 L .68888 .37319 L p
1 g
F P
s
P
p
.002 w
.69232 .39345 m .69615 .44262 L .69431 .4648 L p
1 g
F P
s
P
p
.002 w
.36836 .29189 m .33093 .329 L .34321 .31174 L p
1 g
F P
s
P
p
.002 w
.34321 .31174 m .37929 .27584 L .36836 .29189 L p
1 g
F P
s
P
p
.002 w
.67007 .52961 m .68691 .48672 L .69431 .4648 L p
1 g
F P
s
P
p
.002 w
.68691 .48672 m .67007 .52961 L .65811 .54831 L p
1 g
F P
s
P
p
.002 w
.33152 .52381 m .34957 .55769 L .33863 .54323 L p
1 g
F P
s
P
p
.002 w
.33863 .54323 m .31817 .50496 L .33152 .52381 L p
1 g
F P
s
P
p
.002 w
.31998 .37343 m .30344 .41728 L .30621 .39478 L p
1 g
F P
s
P
p
.002 w
.30621 .39478 m .32303 .34971 L .31998 .37343 L p
1 g
F P
s
P
p
.002 w
.3652 .56906 m .39108 .59391 L .38019 .58704 L p
1 g
F P
s
P
p
.002 w
.38019 .58704 m .34957 .55769 L .3652 .56906 L p
1 g
F P
s
P
p
.002 w
.50084 .23682 m .44221 .243 L .45364 .23886 L p
1 g
F P
s
P
p
.002 w
.45364 .23886 m .50621 .23329 L .50084 .23682 L p
1 g
F P
s
P
p
.002 w
.43197 .25269 m .37929 .27584 L .39317 .26465 L p
1 g
F P
s
P
p
.002 w
.39317 .26465 m .44221 .243 L .43197 .25269 L p
1 g
F P
s
P
p
.002 w
.31458 .46489 m .31817 .50496 L .31027 .48464 L p
1 g
F P
s
P
p
.002 w
.31027 .48464 m .30617 .44088 L .31458 .46489 L p
1 g
F P
s
P
p
.002 w
.55619 .61971 m .59343 .60279 L .61123 .59355 L p
1 g
F P
s
P
p
.002 w
.64127 .56427 m .61123 .59355 L .59343 .60279 L p
1 g
F P
s
P
p
.002 w
.61123 .59355 m .64127 .56427 L .65811 .54831 L p
1 g
F P
s
P
p
.002 w
.50351 .62753 m .54094 .62176 L .55619 .61971 L p
1 g
F P
s
P
p
.002 w
.59343 .60279 m .55619 .61971 L .54094 .62176 L p
1 g
F P
s
P
p
.002 w
.6571 .31113 m .61591 .27344 L .60919 .26609 L p
1 g
F P
s
P
p
.002 w
.56045 .24276 m .60919 .26609 L .61591 .27344 L p
1 g
F P
s
P
p
.002 w
.66394 .32609 m .68888 .37319 L .69232 .39345 L p
1 g
F P
s
P
p
.002 w
.68888 .37319 m .66394 .32609 L .6571 .31113 L p
1 g
F P
s
P
p
.002 w
.43229 .6114 m .46289 .62054 L .46364 .62445 L p
1 g
F P
s
P
p
.002 w
.46364 .62445 m .42499 .61291 L .43229 .6114 L p
1 g
F P
s
P
p
.002 w
.50351 .62753 m .46364 .62445 L .46289 .62054 L p
1 g
F P
s
P
p
.002 w
.56146 .24741 m .50084 .23682 L .50621 .23329 L p
1 g
F P
s
P
p
.002 w
.50621 .23329 m .56045 .24276 L .56146 .24741 L p
1 g
F P
s
P
p
.002 w
.61591 .27344 m .6571 .31113 L .66394 .32609 L p
1 g
F P
s
P
p
.002 w
.69037 .41546 m .69431 .4648 L .68691 .48672 L p
1 g
F P
s
P
p
.004 w
.69325 .48316 m
.70928 .48753 L
s
P
p
.002 w
.69431 .4648 m .69037 .41546 L .69232 .39345 L p
1 g
F P
s
P
p
.002 w
.61591 .27344 m .56146 .24741 L .56045 .24276 L p
1 g
F P
s
P
p
.002 w
.40554 .59638 m .43229 .6114 L .42499 .61291 L p
1 g
F P
s
P
p
.002 w
.42499 .61291 m .39108 .59391 L .40554 .59638 L p
1 g
F P
s
P
p
.002 w
.36088 .31254 m .32303 .34971 L .33093 .329 L p
1 g
F P
s
P
p
.002 w
.33093 .329 m .36836 .29189 L .36088 .31254 L p
1 g
F P
s
P
p
.002 w
.67392 .50772 m .65811 .54831 L .64127 .56427 L p
1 g
F P
s
P
p
.002 w
.65811 .54831 m .67392 .50772 L .68691 .48672 L p
1 g
F P
s
P
p
.002 w
.46289 .62054 m .49443 .62297 L .50351 .62753 L p
1 g
F P
s
P
p
.002 w
.54094 .62176 m .50351 .62753 L .49443 .62297 L p
1 g
F P
s
P
p
.002 w
.32209 .39952 m .30617 .44088 L .30344 .41728 L p
1 g
F P
s
P
p
.002 w
.30344 .41728 m .31998 .37343 L .32209 .39952 L p
1 g
F P
s
P
p
.002 w
.35018 .54055 m .3652 .56906 L .34957 .55769 L p
1 g
F P
s
P
p
.002 w
.34957 .55769 m .33152 .52381 L .35018 .54055 L p
1 g
F P
s
P
p
.002 w
.32863 .48856 m .33152 .52381 L .31817 .50496 L p
1 g
F P
s
P
p
.002 w
.31817 .50496 m .31458 .46489 L .32863 .48856 L p
1 g
F P
s
P
p
.002 w
.38529 .57682 m .40554 .59638 L .39108 .59391 L p
1 g
F P
s
P
p
.002 w
.39108 .59391 m .3652 .56906 L .38529 .57682 L p
1 g
F P
s
P
p
.002 w
.49522 .24612 m .43197 .25269 L .44221 .243 L p
1 g
F P
s
P
p
.002 w
.44221 .243 m .50084 .23682 L .49522 .24612 L p
1 g
F P
s
P
p
.002 w
.42332 .26797 m .36836 .29189 L .37929 .27584 L p
1 g
F P
s
P
p
.002 w
.37929 .27584 m .43197 .25269 L .42332 .26797 L p
1 g
F P
s
P
p
.002 w
.54094 .62176 m .57234 .60742 L .59343 .60279 L p
1 g
F P
s
P
p
.002 w
.61984 .57688 m .59343 .60279 L .57234 .60742 L p
1 g
F P
s
P
p
.002 w
.59343 .60279 m .61984 .57688 L .64127 .56427 L p
1 g
F P
s
P
p
.002 w
.6663 .34464 m .69232 .39345 L .69037 .41546 L p
1 g
F P
s
P
p
.002 w
.69232 .39345 m .6663 .34464 L .66394 .32609 L p
1 g
F P
s
P
p
.002 w
.49443 .62297 m .52392 .61837 L .54094 .62176 L p
1 g
F P
s
P
p
.002 w
.57234 .60742 m .54094 .62176 L .52392 .61837 L p
1 g
F P
s
P
p
.002 w
.66394 .32609 m .61955 .28563 L .61591 .27344 L p
1 g
F P
s
P
p
.002 w
.56146 .24741 m .61591 .27344 L .61955 .28563 L p
1 g
F P
s
P
p
.002 w
.6828 .43863 m .68691 .48672 L .67392 .50772 L p
1 g
F P
s
P
p
.002 w
.68691 .48672 m .6828 .43863 L .69037 .41546 L p
1 g
F P
s
P
p
.002 w
.65548 .52707 m .64127 .56427 L .61984 .57688 L p
1 g
F P
s
P
p
.002 w
.64127 .56427 m .65548 .52707 L .67392 .50772 L p
1 g
F P
s
P
p
.002 w
.35728 .33736 m .31998 .37343 L .32303 .34971 L p
1 g
F P
s
P
p
.002 w
.32303 .34971 m .36088 .31254 L .35728 .33736 L p
1 g
F P
s
P
p
.002 w
.61955 .28563 m .66394 .32609 L .6663 .34464 L p
1 g
F P
s
P
p
.002 w
.32953 .42724 m .31458 .46489 L .30617 .44088 L p
1 g
F P
s
P
p
.002 w
.30617 .44088 m .32209 .39952 L .32953 .42724 L p
1 g
F P
s
P
p
.002 w
.56073 .25759 m .49522 .24612 L .50084 .23682 L p
1 g
F P
s
P
p
.002 w
.50084 .23682 m .56146 .24741 L .56073 .25759 L p
1 g
F P
s
P
p
.002 w
.44188 .60457 m .46319 .61094 L .46289 .62054 L p
1 g
F P
s
P
p
.002 w
.46289 .62054 m .43229 .6114 L .44188 .60457 L p
1 g
F P
s
P
p
.002 w
.49443 .62297 m .46289 .62054 L .46319 .61094 L p
1 g
F P
s
P
p
.002 w
.37376 .55453 m .38529 .57682 L .3652 .56906 L p
1 g
F P
s
P
p
.002 w
.3652 .56906 m .35018 .54055 L .37376 .55453 L p
1 g
F P
s
P
p
.002 w
.42333 .59409 m .44188 .60457 L .43229 .6114 L p
1 g
F P
s
P
p
.002 w
.43229 .6114 m .40554 .59638 L .42333 .59409 L p
1 g
F P
s
P
p
.002 w
.61955 .28563 m .56073 .25759 L .56146 .24741 L p
1 g
F P
s
P
p
.002 w
.3481 .51111 m .35018 .54055 L .33152 .52381 L p
1 g
F P
s
P
p
.002 w
.33152 .52381 m .32863 .48856 L .3481 .51111 L p
1 g
F P
s
P
p
.002 w
.46319 .61094 m .48514 .61261 L .49443 .62297 L p
1 g
F P
s
P
p
.002 w
.52392 .61837 m .49443 .62297 L .48514 .61261 L p
1 g
F P
s
P
p
.002 w
.41663 .28865 m .36088 .31254 L .36836 .29189 L p
1 g
F P
s
P
p
.002 w
.36836 .29189 m .42332 .26797 L .41663 .28865 L p
1 g
F P
s
P
p
.002 w
.52392 .61837 m .54843 .60705 L .57234 .60742 L p
1 g
F P
s
P
p
.002 w
.5943 .58557 m .57234 .60742 L .54843 .60705 L p
1 g
F P
s
P
p
.002 w
.57234 .60742 m .5943 .58557 L .61984 .57688 L p
1 g
F P
s
P
p
.002 w
.66385 .36637 m .69037 .41546 L .6828 .43863 L p
1 g
F P
s
P
p
.002 w
.69037 .41546 m .66385 .36637 L .6663 .34464 L p
1 g
F P
s
P
p
.002 w
.40943 .58052 m .42333 .59409 L .40554 .59638 L p
1 g
F P
s
P
p
.002 w
.40554 .59638 m .38529 .57682 L .40943 .58052 L p
1 g
F P
s
P
p
.002 w
.4895 .26127 m .42332 .26797 L .43197 .25269 L p
1 g
F P
s
P
p
.002 w
.43197 .25269 m .49522 .24612 L .4895 .26127 L p
1 g
F P
s
P
p
.002 w
.66962 .46224 m .67392 .50772 L .65548 .52707 L p
1 g
F P
s
P
p
.002 w
.67392 .50772 m .66962 .46224 L .6828 .43863 L p
1 g
F P
s
P
p
.004 w
.67823 .47907 m
.69325 .48316 L
s
P
p
.002 w
.48514 .61261 m .50557 .60936 L .52392 .61837 L p
1 g
F P
s
P
p
.002 w
.54843 .60705 m .52392 .61837 L .50557 .60936 L p
1 g
F P
s
P
p
.002 w
.63198 .54409 m .61984 .57688 L .5943 .58557 L p
1 g
F P
s
P
p
.002 w
.61984 .57688 m .63198 .54409 L .65548 .52707 L p
1 g
F P
s
P
p
.002 w
.35785 .36568 m .32209 .39952 L .31998 .37343 L p
1 g
F P
s
P
p
.002 w
.31998 .37343 m .35728 .33736 L .35785 .36568 L p
1 g
F P
s
P
p
.002 w
.34224 .4557 m .32863 .48856 L .31458 .46489 L p
1 g
F P
s
P
p
.002 w
.31458 .46489 m .32953 .42724 L .34224 .4557 L p
1 g
F P
s
P
p
.002 w
.6663 .34464 m .61983 .30257 L .61955 .28563 L p
1 g
F P
s
P
p
.002 w
.56073 .25759 m .61955 .28563 L .61983 .30257 L p
1 g
F P
s
P
p
.002 w
.61983 .30257 m .6663 .34464 L .66385 .36637 L p
1 g
F P
s
P
p
.002 w
.40169 .56518 m .40943 .58052 L .38529 .57682 L p
1 g
F P
s
P
p
.002 w
.38529 .57682 m .37376 .55453 L .40169 .56518 L p
1 g
F P
s
P
p
.002 w
.3725 .53172 m .37376 .55453 L .35018 .54055 L p
1 g
F P
s
P
p
.002 w
.35018 .54055 m .3481 .51111 L .3725 .53172 L p
1 g
F P
s
P
p
.002 w
.55817 .27333 m .4895 .26127 L .49522 .24612 L p
1 g
F P
s
P
p
.002 w
.49522 .24612 m .56073 .25759 L .55817 .27333 L p
1 g
F P
s
P
p
.002 w
.45358 .59229 m .46459 .59559 L .46319 .61094 L p
1 g
F P
s
P
p
.002 w
.46319 .61094 m .44188 .60457 L .45358 .59229 L p
1 g
F P
s
P
p
.002 w
.48514 .61261 m .46319 .61094 L .46459 .59559 L p
1 g
F P
s
P
p
.002 w
.44404 .58686 m .45358 .59229 L .44188 .60457 L p
1 g
F P
s
P
p
.002 w
.44188 .60457 m .42333 .59409 L .44404 .58686 L p
1 g
F P
s
P
p
.002 w
.61983 .30257 m .55817 .27333 L .56073 .25759 L p
1 g
F P
s
P
p
.002 w
.50557 .60936 m .52238 .60145 L .54843 .60705 L p
1 g
F P
s
P
p
.002 w
.56531 .58991 m .54843 .60705 L .52238 .60145 L p
1 g
F P
s
P
p
.002 w
.54843 .60705 m .56531 .58991 L .5943 .58557 L p
1 g
F P
s
P
p
.002 w
.65103 .48551 m .65548 .52707 L .63198 .54409 L p
1 g
F P
s
P
p
.002 w
.65548 .52707 m .65103 .48551 L .66962 .46224 L p
1 g
F P
s
P
p
.002 w
.65643 .39074 m .6828 .43863 L .66962 .46224 L p
1 g
F P
s
P
p
.002 w
.6828 .43863 m .65643 .39074 L .66385 .36637 L p
1 g
F P
s
P
p
.002 w
.46459 .59559 m .47593 .59643 L .48514 .61261 L p
1 g
F P
s
P
p
.002 w
.50557 .60936 m .48514 .61261 L .47593 .59643 L p
1 g
F P
s
P
p
.002 w
.41225 .31429 m .35728 .33736 L .36088 .31254 L p
1 g
F P
s
P
p
.002 w
.36088 .31254 m .41663 .28865 L .41225 .31429 L p
1 g
F P
s
P
p
.002 w
.60402 .5581 m .5943 .58557 L .56531 .58991 L p
1 g
F P
s
P
p
.002 w
.5943 .58557 m .60402 .5581 L .63198 .54409 L p
1 g
F P
s
P
p
.002 w
.35993 .48391 m .3481 .51111 L .32863 .48856 L p
1 g
F P
s
P
p
.002 w
.32863 .48856 m .34224 .4557 L .35993 .48391 L p
1 g
F P
s
P
p
.002 w
.43697 .57986 m .44404 .58686 L .42333 .59409 L p
1 g
F P
s
P
p
.002 w
.42333 .59409 m .40943 .58052 L .43697 .57986 L p
1 g
F P
s
P
p
.002 w
.36274 .39664 m .32953 .42724 L .32209 .39952 L p
1 g
F P
s
P
p
.002 w
.32209 .39952 m .35785 .36568 L .36274 .39664 L p
1 g
F P
s
P
p
.002 w
.48389 .28209 m .41663 .28865 L .42332 .26797 L p
1 g
F P
s
P
p
.002 w
.42332 .26797 m .4895 .26127 L .48389 .28209 L p
1 g
F P
s
P
p
.002 w
.47593 .59643 m .48642 .59472 L .50557 .60936 L p
1 g
F P
s
P
p
.002 w
.52238 .60145 m .50557 .60936 L .48642 .59472 L p
1 g
F P
s
P
p
.002 w
.40112 .54963 m .40169 .56518 L .37376 .55453 L p
1 g
F P
s
P
p
.002 w
.37376 .55453 m .3725 .53172 L .40112 .54963 L p
1 g
F P
s
P
p
.002 w
.61653 .32397 m .66385 .36637 L .65643 .39074 L p
1 g
F P
s
P
p
.002 w
.66385 .36637 m .61653 .32397 L .61983 .30257 L p
1 g
F P
s
P
p
.002 w
.55817 .27333 m .61983 .30257 L .61653 .32397 L p
1 g
F P
s
P
p
.002 w
.43315 .57201 m .43697 .57986 L .40943 .58052 L p
1 g
F P
s
P
p
.002 w
.40943 .58052 m .40169 .56518 L .43315 .57201 L p
1 g
F P
s
P
p
.002 w
.62749 .50761 m .63198 .54409 L .60402 .5581 L p
1 g
F P
s
P
p
.002 w
.63198 .54409 m .62749 .50761 L .65103 .48551 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.64406 .41699 m .66962 .46224 L .65103 .48551 L p
1 g
F P
s
P
p
.002 w
.66962 .46224 m .64406 .41699 L .65643 .39074 L p
1 g
F P
s
P
p
.002 w
.48642 .59472 m .49497 .5906 L .52238 .60145 L p
1 g
F P
s
P
p
.002 w
.53375 .58959 m .52238 .60145 L .49497 .5906 L p
1 g
F P
s
P
p
.002 w
.52238 .60145 m .53375 .58959 L .56531 .58991 L p
1 g
F P
s
P
p
.002 w
.57246 .56853 m .56531 .58991 L .53375 .58959 L p
1 g
F P
s
P
p
.002 w
.56531 .58991 m .57246 .56853 L .60402 .5581 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.47427 .54331 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.38209 .51086 m .3725 .53172 L .3481 .51111 L p
1 g
F P
s
P
p
.002 w
.3481 .51111 m .35993 .48391 L .38209 .51086 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37192 .4292 m .34224 .4557 L .32953 .42724 L p
1 g
F P
s
P
p
.002 w
.32953 .42724 m .36274 .39664 L .37192 .4292 L p
1 g
F P
s
P
p
.002 w
.41043 .34419 m .35785 .36568 L .35728 .33736 L p
1 g
F P
s
P
p
.002 w
.35728 .33736 m .41225 .31429 L .41043 .34419 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.55376 .2944 m .48389 .28209 L .4895 .26127 L p
1 g
F P
s
P
p
.002 w
.4895 .26127 m .55817 .27333 L .55376 .2944 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.46459 .59559 m .45358 .59229 L .46711 .57468 L closepath p
1 g
F P
s
P
p
.002 w
.47593 .59643 m .46459 .59559 L .4671 .5748 L p
1 g
F P
s
P
p
.002 w
.46717 .57482 m .47593 .59643 L p
.4671 .5748 L 1 g
F P
s
P
p
.002 w
.48642 .59472 m .47593 .59643 L .46717 .57482 L p
1 g
F P
s
P
p
.002 w
.46717 .57482 m .46711 .57468 L .46728 .57486 L p
1 g
F P
s
P
p
.002 w
.46728 .57486 m .48642 .59472 L p
.46717 .57482 L 1 g
F P
s
P
p
.002 w
.50063 .58449 m .49497 .5906 L .47633 .57995 L p
1 g
F P
s
P
p
.50063 .58449 m .47633 .57995 L .48724 .58062 L 1 g
F
P
p
.002 w
.43302 .56413 m .43666 .55708 L .45437 .56732 L p
1 g
F P
s
P
p
.002 w
.45437 .56732 m .46711 .57468 L .45843 .57199 L p
1 g
F P
s
P
p
.002 w
.45843 .57199 m .43302 .56413 L p
.45437 .56732 L 1 g
F P
s
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.4428 .55376 L 1 g
F P
s
P
p
.002 w
.46711 .57468 m .45437 .56732 L p
.45218 .56409 L 1 g
F P
s
P
p
.002 w
.46656 .57414 m .46711 .57468 L p
.45218 .56409 L 1 g
F P
s
P
p
.002 w
.45437 .56732 m .43666 .55708 L .43928 .55507 L p
1 g
F P
s
P
p
.002 w
.43928 .55507 m .44208 .55292 L p
.45078 .56311 L 1 g
F P
s
P
p
.43928 .55507 m .45078 .56311 L .45437 .56732 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56311 L p
1 g
F P
s
P
p
.46872 .57265 m .45078 .56311 L .4587 .56865 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43832 .54741 L p
1 g
F P
s
P
p
.002 w
.43666 .55708 m .40797 .53555 L p
.43901 .54953 L 1 g
F P
s
P
p
.43901 .54953 m .4401 .55002 L .43955 .55116 L 1 g
F
P
p
.43901 .54953 m .43955 .55116 L .43666 .55708 L 1 g
F
P
p
.002 w
.43832 .54741 m .43925 .54566 L p
.43534 .53793 L 1 g
F P
s
P
p
.002 w
.43701 .54339 m .42172 .52457 L p
.43411 .53389 L 1 g
F P
s
P
p
.43534 .53793 m .43503 .53732 L .43701 .54339 L 1 g
F
P
p
.43534 .53793 m .43701 .54339 L .43832 .54741 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43252 .52871 L p
1 g
F P
s
P
p
.002 w
.42172 .52457 m .43036 .52164 L p
.43252 .52871 L 1 g
F P
s
P
p
.43235 .53257 m .43252 .52871 L .43411 .53389 L 1 g
F
P
p
.42172 .52457 m .43252 .52871 L .43235 .53257 L 1 g
F
P
p
.002 w
.43252 .52871 m .43346 .52734 L p
.43313 .51801 L 1 g
F P
s
P
p
.002 w
.43287 .52079 m .42172 .52457 L p
.43356 .51354 L 1 g
F P
s
P
p
.43313 .51801 m .43307 .51623 L .43287 .52079 L 1 g
F
P
p
.43313 .51801 m .43287 .52079 L .43252 .52871 L 1 g
F
P
p
.002 w
.42172 .52457 m .40194 .49438 L p
.43356 .51354 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43925 .54566 m .43252 .52871 L .43534 .53793 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43252 .52871 m .44097 .51804 L .43411 .53389 L 1 g
F
P
p
.002 w
.43036 .52164 m .43287 .52079 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43396 .50932 L p
1 g
F P
s
P
p
.40194 .49438 m .43491 .49928 L .43396 .50932 L 1 g
F
P
p
.43232 .5128 m .43396 .50932 L .43356 .51354 L 1 g
F
P
p
.40194 .49438 m .43396 .50932 L .43232 .5128 L 1 g
F
P
p
.002 w
.43396 .50932 m .43485 .50826 L p
.43817 .50051 L 1 g
F P
s
P
p
.002 w
.43645 .50403 m .43011 .48443 L p
.44091 .49487 L 1 g
F P
s
P
p
.43817 .50051 m .43875 .49915 L .43645 .50403 L 1 g
F
P
p
.43817 .50051 m .43645 .50403 L .43396 .50932 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43346 .52734 m .43396 .50932 L .43338 .51541 L 1 g
F
P
p
.43356 .51354 m .43396 .50932 L .44097 .51804 L 1 g
F
P
p
.002 w
.43491 .49928 m .43645 .50403 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44267 .49127 L p
1 g
F P
s
P
p
.002 w
.43011 .48443 m .44649 .48343 L p
.44267 .49127 L 1 g
F P
s
P
p
.43993 .49392 m .44267 .49127 L .44091 .49487 L 1 g
F
P
p
.43011 .48443 m .44267 .49127 L .43993 .49392 L 1 g
F
P
p
.002 w
.44267 .49127 m .44225 .49171 L p
.43998 .49677 L 1 g
F P
s
P
p
.43485 .50826 m .44267 .49127 L .43998 .49677 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44267 .49127 m .44339 .4905 L p
.4506 .48359 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44267 .49127 m .46346 .48239 L .44091 .49487 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45768 .47671 L p
1 g
F P
s
P
p
.002 w
.46346 .48239 m .45106 .48315 L p
.45707 .47731 L 1 g
F P
s
P
p
.44339 .4905 m .45768 .47671 L .45448 .47983 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.42134 .44887 m .46447 .44595 L .46378 .47079 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45707 .47731 m .45768 .47671 L .46346 .48239 L 1 g
F
P
p
.002 w
.46369 .4739 m .46346 .48239 L p
.45768 .47671 L 1 g
F P
s
P
p
.002 w
.49795 .48867 m .46346 .48239 L .46369 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47764 .46704 m .49795 .48867 L .46369 .4739 L 1 g
F
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48581 .46586 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .48581 .46586 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52238 .46706 L p
1 g
F P
s
P
p
.51411 .46593 m .52933 .50252 L .50569 .46478 L 1 g
F
P
p
.5 .4634 m .52238 .46706 L .51195 .46563 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.58108 .49785 m .56669 .51067 L p
.56601 .50912 L 1 g
F P
s
P
p
.002 w
.56603 .50931 m .56515 .50826 L p
.56666 .51803 L 1 g
F P
s
P
p
.002 w
.56863 .54507 m .56828 .54452 L p
.56749 .5277 L 1 g
F P
s
P
p
.56669 .51067 m .56762 .5272 L .56749 .5277 L 1 g
F
P
p
.56762 .5272 m .56863 .54507 L .56749 .5277 L 1 g
F
P
p
.002 w
.56729 .52844 m .56654 .52734 L p
.56434 .53937 L 1 g
F P
s
P
p
.002 w
.56863 .54507 m .56145 .54807 L p
.56167 .5474 L 1 g
F P
s
P
p
.002 w
.56455 .53876 m .56616 .54125 L p
.56167 .5474 L 1 g
F P
s
P
p
.002 w
.56616 .54125 m .56863 .54507 L p
.56167 .5474 L 1 g
F P
s
P
p
.002 w
.56167 .5474 m .56075 .54566 L p
.55571 .5548 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5617 .54746 L p
1 g
F P
s
P
p
.002 w
.56145 .54807 m .56863 .54507 L p
.55868 .55488 L 1 g
F P
s
P
p
.002 w
.5617 .54746 m .56257 .5491 L p
.56381 .5423 L 1 g
F P
s
P
p
.56654 .52734 m .5617 .54746 L .56322 .54375 L 1 g
F
P
p
.56654 .52734 m .56322 .54375 L .56426 .53985 L 1 g
F
P
p
.56666 .51803 m .56623 .51108 L .56603 .50931 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56623 .51108 m .56669 .51067 L p
.56828 .54452 L 1 g
F P
s
P
p
.57365 .52604 m .56863 .54507 L .56669 .51067 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5538 .52215 m .56623 .51108 L p
.56729 .52844 L 1 g
F P
s
P
p
.002 w
.56828 .54452 m .56455 .53876 L p
.56729 .52844 L 1 g
F P
s
P
p
.56434 .53937 m .56455 .53876 L .56729 .52844 L 1 g
F
P
p
.002 w
.56455 .53876 m .5538 .52215 L p
.56729 .52844 L 1 g
F P
s
P
p
.56426 .53985 m .56322 .54375 L .56381 .5423 L 1 g
F
P
p
.002 w
.56107 .54823 m .56145 .54807 L p
.55497 .55852 L 1 g
F P
s
P
p
.55868 .55488 m .55497 .55852 L .56145 .54807 L 1 g
F
P
p
.55497 .55852 m .54321 .57011 L .54912 .56286 L 1 g
F
P
p
.55497 .55852 m .54912 .56286 L .56107 .54823 L 1 g
F
P
p
.002 w
.54912 .56286 m .54854 .56129 L p
.53904 .57035 L 1 g
F P
s
P
p
.55571 .5548 m .56107 .54823 L .56167 .5474 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53175 .57482 L p
1 g
F P
s
P
p
.54854 .56129 m .53175 .57482 L .53198 .57469 L 1 g
F
P
p
.002 w
.53831 .57493 m .53082 .57537 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.53765 .57138 m .53794 .57295 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.53794 .57295 m .53831 .57493 L p
.53175 .57482 L 1 g
F P
s
P
p
.002 w
.53175 .57482 m .53128 .57265 L p
.52116 .57784 L 1 g
F P
s
P
p
.002 w
.50063 .58449 m .50091 .58352 L p
.51135 .58068 L 1 g
F P
s
P
p
.53082 .57537 m .51386 .58049 L .51135 .58068 L 1 g
F
P
p
.51386 .58049 m .50063 .58449 L .51135 .58068 L 1 g
F
P
p
.51079 .57862 m .49789 .5812 L .50105 .58137 L 1 g
F
P
p
.002 w
.50063 .58449 m .48746 .58063 L p
.48905 .58072 L 1 g
F P
s
P
p
.002 w
.50152 .5814 m .50081 .58388 L p
.48905 .58072 L 1 g
F P
s
P
p
.002 w
.50081 .58388 m .50063 .58449 L p
.48905 .58072 L 1 g
F P
s
P
p
.002 w
.48905 .58072 m .48921 .57862 L p
.47775 .57768 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51079 .57862 L p
.50105 .58137 L 1 g
F P
s
P
p
.50105 .58137 m .50076 .58145 L .50152 .5814 L 1 g
F
P
p
.50105 .58137 m .50152 .5814 L .51095 .58071 L 1 g
F
P
p
.002 w
.46772 .57486 m .46711 .57468 L p
.46754 .57476 L 1 g
F P
s
P
p
.002 w
.46818 .5751 m .46872 .57265 L p
.46002 .56961 L 1 g
F P
s
P
p
.46002 .56961 m .45969 .56949 L .46319 .5718 L 1 g
F
P
p
.46002 .56961 m .46319 .5718 L .46818 .5751 L 1 g
F
P
p
.45969 .56949 m .4642 .57255 L .46818 .5751 L 1 g
F
P
p
.45914 .5693 m .46496 .57311 L .46818 .5751 L 1 g
F
P
p
.45835 .56902 m .46707 .57449 L .46818 .5751 L 1 g
F
P
p
.46872 .57265 m .4587 .56865 L .46014 .56965 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44373 .55165 m .45348 .54847 L .46698 .57443 L p
1 g
F P
s
P
p
.002 w
.46698 .57443 m .46711 .57468 L .46656 .57414 L p
1 g
F P
s
P
p
.002 w
.46656 .57414 m .44373 .55165 L p
.46698 .57443 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45348 .54847 m .46484 .54791 L .4671 .57451 L p
1 g
F P
s
P
p
.002 w
.4671 .57451 m .46711 .57468 L .46698 .57443 L p
1 g
F P
s
P
p
.002 w
.46698 .57443 m .45348 .54847 L p
.4671 .57451 L 1 g
F P
s
P
p
.45969 .56949 m .45914 .5693 L .4642 .57255 L 1 g
F
P
p
.45914 .5693 m .45835 .56902 L .46496 .57311 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46818 .5751 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48723 .55468 m .49573 .56123 L .46726 .57461 L p
1 g
F P
s
P
p
.002 w
.46726 .57461 m .46711 .57468 L .46721 .57458 L p
1 g
F P
s
P
p
.002 w
.46721 .57458 m .48723 .55468 L p
.46726 .57461 L 1 g
F P
s
P
p
.4548 .56778 m .46721 .57458 L .46727 .57461 L 1 g
F
P
p
.4667 .57429 m .46727 .57462 L .46818 .5751 L 1 g
F
P
p
.4548 .56778 m .46727 .57462 L .4667 .57429 L 1 g
F
P
p
.45368 .56739 m .46772 .57486 L .46818 .5751 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49573 .56123 m .50109 .56897 L .46732 .57464 L p
1 g
F P
s
P
p
.002 w
.46732 .57464 m .46711 .57468 L .46726 .57461 L p
1 g
F P
s
P
p
.002 w
.46726 .57461 m .49573 .56123 L p
.46732 .57464 L 1 g
F P
s
P
p
.002 w
.46484 .54791 m .47653 .55006 L .46716 .57455 L p
1 g
F P
s
P
p
.002 w
.46716 .57455 m .46711 .57468 L .4671 .57451 L p
1 g
F P
s
P
p
.002 w
.4671 .57451 m .46484 .54791 L p
.46716 .57455 L 1 g
F P
s
P
p
.002 w
.47653 .55006 m .48723 .55468 L .46721 .57458 L p
1 g
F P
s
P
p
.002 w
.46721 .57458 m .46711 .57468 L .46716 .57455 L p
1 g
F P
s
P
p
.002 w
.46716 .57455 m .47653 .55006 L p
.46721 .57458 L 1 g
F P
s
P
p
.45835 .56902 m .4548 .56778 L .46707 .57449 L 1 g
F
P
p
.4548 .56778 m .45368 .56739 L .46721 .57458 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50109 .56897 m .50277 .57701 L .46742 .5747 L p
1 g
F P
s
P
p
.002 w
.46742 .5747 m .46711 .57468 L .46732 .57464 L p
1 g
F P
s
P
p
.002 w
.46732 .57464 m .50109 .56897 L p
.46742 .5747 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58073 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58073 L .4976 .58126 L 1 g
F
P
p
.48921 .57862 m .46818 .5751 L .46836 .57515 L 1 g
F
P
p
.002 w
.48746 .58063 m .47293 .57638 L p
.48905 .58072 L 1 g
F P
s
P
p
.002 w
.47293 .57638 m .48746 .58063 L p
.46823 .57513 L 1 g
F P
s
P
p
.48724 .58062 m .46755 .57493 L .48746 .58063 L 1 g
F
P
p
.002 w
.47633 .57995 m .46755 .57493 L p
.48724 .58062 L 1 g
F P
s
P
p
.47775 .57768 m .46818 .57512 L .47661 .57759 L 1 g
F
P
p
.48921 .57862 m .46832 .57514 L .47775 .57768 L 1 g
F
P
p
.46823 .57513 m .46818 .5751 L .47293 .57638 L 1 g
F
P
p
.46832 .57514 m .46818 .57512 L .47775 .57768 L 1 g
F
P
p
.50152 .5814 m .48905 .58072 L .46772 .57486 L 1 g
F
P
p
.002 w
.47293 .57638 m .46772 .57486 L p
.48905 .58072 L 1 g
F P
s
P
p
.002 w
.50277 .57701 m .50152 .5814 L p
.46754 .57476 L 1 g
F P
s
P
p
.002 w
.46711 .57468 m .46742 .5747 L p
.46754 .57476 L 1 g
F P
s
P
p
.002 w
.46742 .5747 m .50277 .57701 L p
.46754 .57476 L 1 g
F P
s
P
p
.45368 .56739 m .45305 .56717 L .46772 .57486 L 1 g
F
P
p
.46823 .57513 m .46755 .57493 L .46818 .5751 L 1 g
F
P
p
.002 w
.46755 .57493 m .46711 .57468 L .47293 .57638 L p
1 g
F P
s
P
p
.002 w
.4671 .5748 m .46711 .57468 L .46717 .57482 L p
1 g
F P
s
P
p
.002 w
.45358 .59229 m .44404 .58686 L .46711 .57468 L closepath p
1 g
F P
s
P
p
.002 w
.44404 .58686 m .43697 .57986 L .46711 .57468 L closepath p
1 g
F P
s
P
p
.002 w
.49497 .5906 m .48642 .59472 L .46711 .57468 L closepath p
1 g
F P
s
P
p
.002 w
.43697 .57986 m .43315 .57201 L .46711 .57468 L closepath p
1 g
F P
s
P
p
.002 w
.43315 .57201 m .43302 .56413 L .46711 .57468 L closepath p
1 g
F P
s
P
p
.002 w
.45305 .56717 m .4678 .57686 L .46818 .57511 L p
1 g
F P
s
P
p
.002 w
.46818 .57511 m .46818 .5751 L p
.46772 .57486 L 1 g
F P
s
P
p
.46772 .57486 m .45305 .56717 L .46818 .57511 L 1 g
F
P
p
.50152 .5814 m .46772 .57486 L .46754 .57476 L 1 g
F
P
p
.002 w
.48746 .58063 m .50063 .58449 L p
.48724 .58062 L 1 g
F P
s
P
p
.002 w
.48899 .58163 m .48905 .58072 L p
.47581 .57752 L 1 g
F P
s
P
p
.47775 .57768 m .47581 .57752 L .48905 .58072 L 1 g
F
P
p
.50105 .58137 m .4976 .58126 L .50076 .58145 L 1 g
F
P
p
.49789 .5812 m .4976 .58126 L .50105 .58137 L 1 g
F
P
p
.52116 .57784 m .52974 .57543 L .53175 .57482 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52974 .57543 m .53082 .57537 L p
.50091 .58352 L 1 g
F P
s
P
p
.5256 .57816 m .50063 .58449 L .53082 .57537 L 1 g
F
P
p
.002 w
.53831 .57493 m .53375 .58959 L .50063 .58449 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.50277 .57701 m .52974 .57543 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.50091 .58352 m .50152 .5814 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.50152 .5814 m .50277 .57701 L p
.51095 .58071 L 1 g
F P
s
P
p
.50076 .58145 m .48889 .583 L .51105 .58208 L 1 g
F
P
p
.4976 .58126 m .49423 .58193 L .50076 .58145 L 1 g
F
P
p
.49423 .58193 m .48889 .583 L .50076 .58145 L 1 g
F
P
p
.002 w
.51105 .58208 m .51095 .58071 L p
.50076 .58145 L 1 g
F P
s
P
p
.52116 .57784 m .52025 .57831 L .52974 .57543 L 1 g
F
P
p
.53517 .57283 m .53176 .57487 L .53449 .57341 L 1 g
F
P
p
.54854 .56129 m .53198 .57469 L .53517 .57283 L 1 g
F
P
p
.53198 .57469 m .53176 .57487 L .53517 .57283 L 1 g
F
P
p
.002 w
.53082 .57537 m .53831 .57493 L p
.5256 .57816 L 1 g
F P
s
P
p
.54854 .56129 m .53193 .57562 L .53904 .57035 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53082 .57537 m .50277 .57701 L p
.53765 .57138 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53175 .57482 L p
1 g
F P
s
P
p
.52025 .57831 m .51111 .583 L .53175 .57482 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53535 .55899 m .53765 .57138 L p
.50277 .57701 L 1 g
F P
s
P
p
.002 w
.53175 .57482 m .53176 .57487 L p
.53198 .57469 L 1 g
F P
s
P
p
.002 w
.53176 .57487 m .53193 .57562 L p
.53449 .57341 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54912 .56286 L p
1 g
F P
s
P
p
.002 w
.56863 .54507 m .57246 .56853 L .53944 .57472 L p
1 g
F P
s
P
p
.56863 .54507 m .53944 .57472 L .54321 .57011 L 1 g
F
P
p
.002 w
.54912 .56286 m .54998 .56518 L p
.55571 .5548 L 1 g
F P
s
P
p
.56075 .54566 m .54912 .56286 L .55571 .5548 L 1 g
F
P
p
.002 w
.53944 .57472 m .53831 .57493 L p
.54321 .57011 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53535 .55899 m .56107 .54823 L p
.54769 .56392 L 1 g
F P
s
P
p
.002 w
.53831 .57493 m .53765 .57138 L p
.54769 .56392 L 1 g
F P
s
P
p
.002 w
.53765 .57138 m .53535 .55899 L p
.54769 .56392 L 1 g
F P
s
P
p
.002 w
.53193 .57562 m .5322 .57686 L p
.53904 .57035 L 1 g
F P
s
P
p
.54321 .57011 m .53831 .57493 L .56107 .54823 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54912 .56286 L p
1 g
F P
s
P
p
.53904 .57035 m .5322 .57686 L .54912 .56286 L 1 g
F
P
p
.55571 .5548 m .5539 .55807 L .56107 .54823 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56145 .54807 m .53535 .55899 L p
.56455 .53876 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56167 .5474 L p
1 g
F P
s
P
p
.5539 .55807 m .54998 .56518 L .56167 .5474 L 1 g
F
P
p
.56434 .53937 m .56426 .53985 L .56455 .53876 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5538 .52215 m .56455 .53876 L p
.53535 .55899 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56729 .52844 L p
1 g
F P
s
P
p
.56426 .53985 m .56257 .5491 L .56729 .52844 L 1 g
F
P
p
.56666 .51803 m .56806 .52712 L .56623 .51108 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56603 .50931 L p
1 g
F P
s
P
p
.55661 .4905 m .56603 .50931 L .56486 .5069 L 1 g
F
P
p
.54972 .47216 m .55874 .49261 L .55008 .47652 L 1 g
F
P
p
.55874 .49261 m .56669 .51067 L .55717 .4911 L 1 g
F
P
p
.55874 .49261 m .55717 .4911 L .55008 .47652 L 1 g
F
P
p
.55661 .4905 m .56613 .50943 L .56373 .50411 L 1 g
F
P
p
.002 w
.54972 .47216 m .56304 .48307 L p
.56601 .50912 L 1 g
F P
s
P
p
.002 w
.56304 .48307 m .58108 .49785 L p
.56601 .50912 L 1 g
F P
s
P
p
.002 w
.56669 .51067 m .58108 .49785 L p
.57365 .52604 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55717 .4911 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56669 .51067 m .5538 .52215 L p
.55076 .4849 L 1 g
F P
s
P
p
.54174 .47608 m .55717 .4911 L .54992 .48409 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55008 .47652 m .55717 .4911 L .55076 .4849 L 1 g
F
P
p
.55717 .4911 m .56669 .51067 L .55076 .4849 L 1 g
F
P
p
.002 w
.5538 .52215 m .52933 .50252 L .54494 .47927 L p
1 g
F P
s
P
p
.54174 .47608 m .54992 .48409 L .54937 .48355 L 1 g
F
P
p
.55076 .4849 m .5538 .52215 L .54494 .47927 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54494 .47927 m .52933 .50252 L p
.53443 .4729 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47672 L p
1 g
F P
s
P
p
.52214 .46667 m .54233 .47672 L .53041 .47095 L 1 g
F
P
p
.535 .46958 m .54233 .47672 L .53443 .4729 L 1 g
F
P
p
.54233 .47672 m .54494 .47927 L .53443 .4729 L 1 g
F
P
p
.51411 .46593 m .52339 .46755 L .52933 .50252 L 1 g
F
P
p
.002 w
.52238 .46706 m .52214 .46667 L p
.53041 .47095 L 1 g
F P
s
P
p
.52339 .46755 m .535 .46958 L .53443 .4729 L 1 g
F
P
p
.52339 .46755 m .53443 .4729 L .52933 .50252 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54537 .47021 m .54972 .47216 L p
.51411 .46593 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52238 .46706 L p
1 g
F P
s
P
p
.53041 .47095 m .54302 .47747 L .52238 .46706 L 1 g
F
P
p
.002 w
.54233 .47672 m .54302 .47747 L p
.53041 .47095 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54494 .47927 m .54972 .47216 L p
.55076 .4849 L 1 g
F P
s
P
p
.54937 .48355 m .55817 .49216 L .55552 .48958 L 1 g
F
P
p
.54992 .48409 m .55817 .49216 L .54937 .48355 L 1 g
F
P
p
.002 w
.55717 .4911 m .55817 .49216 L p
.54992 .48409 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56603 .50931 L p
1 g
F P
s
P
p
.56806 .52712 m .56854 .53025 L .56603 .50931 L 1 g
F
P
p
.002 w
.56603 .50931 m .56613 .50943 L p
.56486 .5069 L 1 g
F P
s
P
p
.002 w
.56613 .50943 m .56713 .51061 L p
.56373 .50411 L 1 g
F P
s
P
p
.002 w
.55817 .49216 m .55834 .49233 L p
.55552 .48958 L 1 g
F P
s
P
p
.002 w
.54972 .47216 m .54494 .47927 L p
.535 .46958 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.50917 .45404 m .54537 .47021 L p
.51411 .46593 L 1 g
F P
s
P
p
.51078 .46547 m .52273 .46764 L .51755 .46677 L 1 g
F
P
p
.5 .4634 m .51195 .46563 L .51078 .46547 L 1 g
F
P
p
.51195 .46563 m .52273 .46764 L .51078 .46547 L 1 g
F
P
p
.002 w
.52238 .46706 m .52273 .46764 L p
.51195 .46563 L 1 g
F P
s
P
p
.002 w
.52933 .50252 m .49795 .48867 L .50569 .46478 L p
1 g
F P
s
P
p
.002 w
.50569 .46478 m .49795 .48867 L p
.4752 .45964 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50569 .46478 m .50917 .45404 L p
.51411 .46593 L 1 g
F P
s
P
p
.002 w
.46447 .44595 m .50917 .45404 L .50569 .46478 L p
1 g
F P
s
P
p
.46447 .44595 m .50569 .46478 L .4752 .45964 L 1 g
F
P
p
.002 w
.52273 .46764 m .52282 .46778 L p
.51755 .46677 L 1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .46442 L p
.48581 .46586 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47735 .46751 L p
1 g
F P
s
P
p
.002 w
.47735 .46751 m .47718 .46778 L p
.47065 .47065 L 1 g
F P
s
P
p
.45826 .47608 m .47735 .46751 L .47065 .47065 L 1 g
F
P
p
.002 w
.45768 .47671 m .45826 .47608 L p
.45839 .47602 L 1 g
F P
s
P
p
.45839 .47602 m .47065 .47065 L .45768 .47671 L 1 g
F
P
p
.42134 .44887 m .46378 .47079 L .45768 .47671 L 1 g
F
P
p
.45682 .47711 m .45768 .47671 L .45707 .47731 L 1 g
F
P
p
.42134 .44887 m .45768 .47671 L .45682 .47711 L 1 g
F
P
p
.46447 .44595 m .48006 .46585 L .47764 .46704 L 1 g
F
P
p
.002 w
.46369 .4739 m .46383 .46903 L p
.47764 .46704 L 1 g
F P
s
P
p
.002 w
.46383 .46903 m .46447 .44595 L p
.47764 .46704 L 1 g
F P
s
P
p
.48006 .46585 m .48065 .4666 L .47764 .46704 L 1 g
F
P
p
.48065 .4666 m .49795 .48867 L .47764 .46704 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48581 .46586 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45744 .47698 L p
1 g
F P
s
P
p
.002 w
.45744 .47698 m .45768 .47671 L p
.46197 .47475 L 1 g
F P
s
P
p
.46197 .47475 m .47718 .46778 L .45744 .47698 L 1 g
F
P
p
.47065 .47065 m .47718 .46778 L .45768 .47671 L 1 g
F
P
p
.002 w
.46378 .47079 m .46369 .4739 L p
.45768 .47671 L 1 g
F P
s
P
p
.002 w
.45106 .48315 m .46346 .48239 L p
.44267 .49127 L 1 g
F P
s
P
p
.002 w
.45746 .47695 m .45698 .47747 L p
.45074 .48345 L 1 g
F P
s
P
p
.4506 .48359 m .45106 .48315 L .45074 .48345 L 1 g
F
P
p
.45106 .48315 m .45746 .47695 L .45074 .48345 L 1 g
F
P
p
.002 w
.45768 .47671 m .45746 .47695 L p
.45448 .47983 L 1 g
F P
s
P
p
.002 w
.43011 .48443 m .42134 .44887 L p
.45707 .47731 L 1 g
F P
s
P
p
.44339 .4905 m .45746 .47695 L .4506 .48359 L 1 g
F
P
p
.002 w
.45106 .48315 m .43011 .48443 L p
.45707 .47731 L 1 g
F P
s
P
p
.002 w
.44649 .48343 m .45106 .48315 L p
.44267 .49127 L 1 g
F P
s
P
p
.002 w
.44225 .49171 m .44166 .49233 L p
.43875 .49915 L 1 g
F P
s
P
p
.43485 .50826 m .44225 .49171 L .43875 .49915 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44267 .49127 L p
1 g
F P
s
P
p
.4506 .48359 m .45698 .47747 L .44267 .49127 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.46346 .48239 m .46359 .5168 L p
.44091 .49487 L 1 g
F P
s
P
p
.002 w
.43645 .50403 m .44097 .51804 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.46359 .5168 m .44097 .51804 L .43645 .50403 L p
1 g
F P
s
P
p
.44091 .49487 m .46359 .5168 L .43645 .50403 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43396 .50932 L p
1 g
F P
s
P
p
.43875 .49915 m .44166 .49233 L .43396 .50932 L 1 g
F
P
p
.002 w
.43396 .50932 m .43334 .51005 L p
.43338 .51541 L 1 g
F P
s
P
p
.002 w
.40194 .49438 m .43011 .48443 L .43491 .49928 L p
1 g
F P
s
P
p
.43346 .52734 m .43334 .51005 L .43307 .51623 L 1 g
F
P
p
.002 w
.43287 .52079 m .44097 .51804 L p
.43252 .52871 L 1 g
F P
s
P
p
.002 w
.43334 .51005 m .43287 .51061 L p
.43307 .51623 L 1 g
F P
s
P
p
.002 w
.44097 .51804 m .43287 .52079 L p
.43356 .51354 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43252 .52871 L p
1 g
F P
s
P
p
.43307 .51623 m .43287 .51061 L .43252 .52871 L 1 g
F
P
p
.002 w
.43252 .52871 m .43146 .53025 L p
.43534 .53793 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44097 .51804 m .45348 .54847 L p
.43411 .53389 L 1 g
F P
s
P
p
.002 w
.45348 .54847 m .44373 .55165 L .43701 .54339 L p
1 g
F P
s
P
p
.43411 .53389 m .45348 .54847 L .43701 .54339 L 1 g
F
P
p
.45146 .56129 m .43832 .54741 L .44244 .55345 L 1 g
F
P
p
.002 w
.40797 .53555 m .42172 .52457 L .44373 .55165 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43832 .54741 L p
1 g
F P
s
P
p
.43503 .53732 m .43146 .53025 L .43832 .54741 L 1 g
F
P
p
.002 w
.44208 .55292 m .43666 .55708 L p
.4401 .55002 L 1 g
F P
s
P
p
.002 w
.43832 .54741 m .43743 .5491 L p
.44244 .55345 L 1 g
F P
s
P
p
.002 w
.44373 .55165 m .44208 .55292 L p
.4401 .55002 L 1 g
F P
s
P
p
.002 w
.44208 .55292 m .44373 .55165 L p
.45437 .56732 L 1 g
F P
s
P
p
.002 w
.45078 .56311 m .45002 .56518 L p
.4587 .56865 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .45305 .56717 L p
.46014 .56965 L 1 g
F P
s
P
p
.4587 .56865 m .45002 .56518 L .46014 .56965 L 1 g
F
P
p
.002 w
.44373 .55165 m .46656 .57414 L p
.45218 .56409 L 1 g
F P
s
P
p
.002 w
.45076 .56316 m .45078 .56311 L p
.442 .55307 L 1 g
F P
s
P
p
.4428 .55376 m .442 .55307 L .45078 .56311 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45076 .56316 L p
1 g
F P
s
P
p
.442 .55307 m .43743 .5491 L .45076 .56316 L 1 g
F
P
p
.002 w
.48905 .58073 m .48889 .583 L p
.4976 .58126 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51105 .58208 L p
1 g
F P
s
P
p
.002 w
.46818 .5751 m .46818 .57512 L p
.46836 .57515 L 1 g
F P
s
P
p
.002 w
.46818 .57512 m .4678 .57686 L p
.47661 .57759 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58163 L p
1 g
F P
s
P
p
.47581 .57752 m .4678 .57686 L .48899 .58163 L 1 g
F
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.61653 .32397 m .55376 .2944 L .55817 .27333 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.43302 .56413 m .43315 .57201 L .40169 .56518 L p
1 g
F P
s
P
p
.002 w
.40169 .56518 m .40112 .54963 L .43302 .56413 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.59971 .52772 m .60402 .5581 L .57246 .56853 L p
1 g
F P
s
P
p
.002 w
.60402 .5581 m .59971 .52772 L .62749 .50761 L p
1 g
F P
s
P
p
.002 w
.47859 .30813 m .41225 .31429 L .41663 .28865 L p
1 g
F P
s
P
p
.002 w
.41663 .28865 m .48389 .28209 L .47859 .30813 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.40797 .53555 m .40112 .54963 L .3725 .53172 L p
1 g
F P
s
P
p
.002 w
.3725 .53172 m .38209 .51086 L .40797 .53555 L p
1 g
F P
s
P
p
.002 w
.49497 .5906 m .50063 .58449 L .53375 .58959 L p
1 g
F P
s
P
p
.002 w
.53375 .58959 m .53831 .57493 L .57246 .56853 L p
1 g
F P
s
P
p
.002 w
.60957 .34931 m .65643 .39074 L .64406 .41699 L p
1 g
F P
s
P
p
.002 w
.65643 .39074 m .60957 .34931 L .61653 .32397 L p
1 g
F P
s
P
p
.002 w
.62702 .44425 m .65103 .48551 L .62749 .50761 L p
1 g
F P
s
P
p
.002 w
.65103 .48551 m .62702 .44425 L .64406 .41699 L p
1 g
F P
s
P
p
.004 w
.6453 .4701 m
.67823 .47907 L
s
P
p
.004 w
.63099 .4662 m
.6453 .4701 L
s
P
p
.004 w
.62994 .46591 m
.63099 .4662 L
s
P
p
.002 w
.38513 .46219 m .35993 .48391 L .34224 .4557 L p
1 g
F P
s
P
p
.002 w
.34224 .4557 m .37192 .4292 L .38513 .46219 L p
1 g
F P
s
P
p
.002 w
.55376 .2944 m .61653 .32397 L .60957 .34931 L p
1 g
F P
s
P
p
.002 w
.41133 .3774 m .36274 .39664 L .35785 .36568 L p
1 g
F P
s
P
p
.002 w
.35785 .36568 m .41043 .34419 L .41133 .3774 L p
1 g
F P
s
P
p
.002 w
.57246 .56853 m .56863 .54507 L .59971 .52772 L p
1 g
F P
s
P
p
.002 w
.43666 .55708 m .43302 .56413 L .40112 .54963 L p
1 g
F P
s
P
p
.002 w
.40112 .54963 m .40797 .53555 L .43666 .55708 L p
1 g
F P
s
P
p
.002 w
.40194 .49438 m .38209 .51086 L .35993 .48391 L p
1 g
F P
s
P
p
.002 w
.35993 .48391 m .38513 .46219 L .40194 .49438 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.54755 .32034 m .47859 .30813 L .48389 .28209 L p
1 g
F P
s
P
p
.002 w
.48389 .28209 m .55376 .2944 L .54755 .32034 L p
1 g
F P
s
P
p
.002 w
.60579 .47155 m .62749 .50761 L .59971 .52772 L p
1 g
F P
s
P
p
.002 w
.62749 .50761 m .60579 .47155 L .62702 .44425 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.61363 .46147 L
s
P
p
.002 w
.50277 .57701 m .50109 .56897 L .53535 .55899 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.60957 .34931 m .54755 .32034 L .55376 .2944 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.47381 .33866 m .41043 .34419 L .41225 .31429 L p
1 g
F P
s
P
p
.002 w
.41225 .31429 m .47859 .30813 L .47381 .33866 L p
1 g
F P
s
P
p
.002 w
.59906 .37784 m .64406 .41699 L .62702 .44425 L p
1 g
F P
s
P
p
.002 w
.64406 .41699 m .59906 .37784 L .60957 .34931 L p
1 g
F P
s
P
p
.002 w
.42172 .52457 m .40797 .53555 L .38209 .51086 L p
1 g
F P
s
P
p
.002 w
.38209 .51086 m .40194 .49438 L .42172 .52457 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.415 .41273 m .37192 .4292 L .36274 .39664 L p
1 g
F P
s
P
p
.002 w
.36274 .39664 m .41133 .3774 L .415 .41273 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58108 .49785 m .59971 .52772 L .56863 .54507 L p
1 g
F P
s
P
p
.002 w
.59971 .52772 m .58108 .49785 L .60579 .47155 L p
1 g
F P
s
P
p
.002 w
.50109 .56897 m .49573 .56123 L .52499 .54353 L p
1 g
F P
s
P
p
.002 w
.52499 .54353 m .53535 .55899 L .50109 .56897 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.54755 .32034 m .60957 .34931 L .59906 .37784 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53535 .55899 m .52499 .54353 L .5538 .52215 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.49573 .56123 m .48723 .55468 L .50823 .53036 L p
1 g
F P
s
P
p
.002 w
.50823 .53036 m .52499 .54353 L .49573 .56123 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42134 .44887 m .38513 .46219 L .37192 .4292 L p
1 g
F P
s
P
p
.002 w
.37192 .4292 m .415 .41273 L .42134 .44887 L p
1 g
F P
s
P
p
.002 w
.58526 .40859 m .62702 .44425 L .60579 .47155 L p
1 g
F P
s
P
p
.002 w
.62702 .44425 m .58526 .40859 L .59906 .37784 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46484 .54791 m .45348 .54847 L .44097 .51804 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48723 .55468 m .47653 .55006 L .48693 .52107 L p
1 g
F P
s
P
p
.002 w
.48693 .52107 m .50823 .53036 L .48723 .55468 L p
1 g
F P
s
P
p
.002 w
.46975 .37266 m .41133 .3774 L .41043 .34419 L p
1 g
F P
s
P
p
.002 w
.41043 .34419 m .47381 .33866 L .46975 .37266 L p
1 g
F P
s
P
p
.002 w
.5397 .35038 m .47381 .33866 L .47859 .30813 L p
1 g
F P
s
P
p
.002 w
.47859 .30813 m .54755 .32034 L .5397 .35038 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.47653 .55006 m .46484 .54791 L .46359 .5168 L p
1 g
F P
s
P
p
.002 w
.44097 .51804 m .46359 .5168 L .46484 .54791 L p
1 g
F P
s
P
p
.002 w
.46359 .5168 m .48693 .52107 L .47653 .55006 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59906 .37784 m .5397 .35038 L .54755 .32034 L p
1 g
F P
s
P
p
.002 w
.43011 .48443 m .40194 .49438 L .38513 .46219 L p
1 g
F P
s
P
p
.002 w
.38513 .46219 m .42134 .44887 L .43011 .48443 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.52499 .54353 m .50823 .53036 L .52933 .50252 L p
1 g
F P
s
P
p
.002 w
.52933 .50252 m .5538 .52215 L .52499 .54353 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56861 .44043 m .60579 .47155 L .58108 .49785 L p
1 g
F P
s
P
p
.002 w
.60579 .47155 m .56861 .44043 L .58526 .40859 L p
1 g
F P
s
P
p
.002 w
.5397 .35038 m .59906 .37784 L .58526 .40859 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.58108 .49785 m .54972 .47216 L .56861 .44043 L p
1 g
F P
s
P
p
.002 w
.46659 .40889 m .415 .41273 L .41133 .3774 L p
1 g
F P
s
P
p
.002 w
.41133 .3774 m .46975 .37266 L .46659 .40889 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50823 .53036 m .48693 .52107 L .49795 .48867 L p
1 g
F P
s
P
p
.002 w
.49795 .48867 m .52933 .50252 L .50823 .53036 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53046 .38352 m .46975 .37266 L .47381 .33866 L p
1 g
F P
s
P
p
.002 w
.47381 .33866 m .5397 .35038 L .53046 .38352 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.48693 .52107 m .46359 .5168 L .46346 .48239 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46346 .48239 m .49795 .48867 L .48693 .52107 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.58526 .40859 m .53046 .38352 L .5397 .35038 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53046 .38352 m .58526 .40859 L .56861 .44043 L p
1 g
F P
s
P
p
.002 w
.46447 .44595 m .42134 .44887 L .415 .41273 L p
1 g
F P
s
P
p
.002 w
.415 .41273 m .46659 .40889 L .46447 .44595 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.004 w
.45371 .63344 m
.45589 .62387 L
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52015 .41853 m .56861 .44043 L .54972 .47216 L p
1 g
F P
s
P
p
.002 w
.56861 .44043 m .52015 .41853 L .53046 .38352 L p
1 g
F P
s
P
p
.002 w
.52015 .41853 m .46659 .40889 L .46975 .37266 L p
1 g
F P
s
P
p
.002 w
.46975 .37266 m .53046 .38352 L .52015 .41853 L p
1 g
F P
s
P
p
.002 w
.54972 .47216 m .50917 .45404 L .52015 .41853 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.50917 .45404 m .46447 .44595 L .46659 .40889 L p
1 g
F P
s
P
p
.002 w
.46659 .40889 m .52015 .41853 L .50917 .45404 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .70928 .48753 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4479 .6589 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.151938)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.151938)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46321 .4396 m .50006 .45963 L .51047 .43307 L p
1 g
F P
s
P
p
.002 w
.51047 .43307 m .47976 .41635 L .46321 .4396 L p
1 g
F P
s
P
p
.002 w
.54417 .44124 m .51047 .43307 L .50006 .45963 L p
1 g
F P
s
P
p
.002 w
.47976 .41635 m .51047 .43307 L .52062 .40644 L p
1 g
F P
s
P
p
.002 w
.51047 .43307 m .54417 .44124 L .54679 .4127 L p
1 g
F P
s
P
p
.002 w
.54679 .4127 m .52062 .40644 L .51047 .43307 L p
1 g
F P
s
P
p
.002 w
.43332 .41127 m .46321 .4396 L .47976 .41635 L p
1 g
F P
s
P
p
.002 w
.47976 .41635 m .45496 .39263 L .43332 .41127 L p
1 g
F P
s
P
p
.002 w
.45496 .39263 m .47976 .41635 L .49679 .39344 L p
1 g
F P
s
P
p
.002 w
.52062 .40644 m .49679 .39344 L .47976 .41635 L p
1 g
F P
s
P
p
.002 w
.44745 .46278 m .4896 .48565 L .50006 .45963 L p
1 g
F P
s
P
p
.002 w
.50006 .45963 m .46321 .4396 L .44745 .46278 L p
1 g
F P
s
P
p
.002 w
.54048 .46957 m .50006 .45963 L .4896 .48565 L p
1 g
F P
s
P
p
.002 w
.50006 .45963 m .54048 .46957 L .54417 .44124 L p
1 g
F P
s
P
p
.002 w
.49679 .39344 m .52062 .40644 L .53033 .38021 L p
1 g
F P
s
P
p
.002 w
.52062 .40644 m .54679 .4127 L .54828 .38445 L p
1 g
F P
s
P
p
.002 w
.54828 .38445 m .53033 .38021 L .52062 .40644 L p
1 g
F P
s
P
p
.002 w
.49679 .39344 m .47765 .37495 L .45496 .39263 L p
1 g
F P
s
P
p
.002 w
.47765 .37495 m .49679 .39344 L .51401 .37129 L p
1 g
F P
s
P
p
.002 w
.53033 .38021 m .51401 .37129 L .49679 .39344 L p
1 g
F P
s
P
p
.002 w
.41312 .43054 m .44745 .46278 L .46321 .4396 L p
1 g
F P
s
P
p
.002 w
.46321 .4396 m .43332 .41127 L .41312 .43054 L p
1 g
F P
s
P
p
.002 w
.57768 .43999 m .54417 .44124 L .54048 .46957 L p
1 g
F P
s
P
p
.002 w
.54417 .44124 m .57768 .43999 L .57274 .41154 L p
1 g
F P
s
P
p
.002 w
.57274 .41154 m .54679 .4127 L .54417 .44124 L p
1 g
F P
s
P
p
.002 w
.54679 .4127 m .57274 .41154 L .56603 .38353 L p
1 g
F P
s
P
p
.002 w
.56603 .38353 m .54828 .38445 L .54679 .4127 L p
1 g
F P
s
P
p
.002 w
.43278 .48546 m .47926 .51064 L .4896 .48565 L p
1 g
F P
s
P
p
.002 w
.4896 .48565 m .44745 .46278 L .43278 .48546 L p
1 g
F P
s
P
p
.002 w
.53577 .49715 m .4896 .48565 L .47926 .51064 L p
1 g
F P
s
P
p
.002 w
.4896 .48565 m .53577 .49715 L .54048 .46957 L p
1 g
F P
s
P
p
.002 w
.58073 .46834 m .54048 .46957 L .53577 .49715 L p
1 g
F P
s
P
p
.002 w
.54048 .46957 m .58073 .46834 L .57768 .43999 L p
1 g
F P
s
P
p
.002 w
.51401 .37129 m .53033 .38021 L .53944 .35488 L p
1 g
F P
s
P
p
.002 w
.53033 .38021 m .54828 .38445 L .5486 .35702 L p
1 g
F P
s
P
p
.002 w
.5486 .35702 m .53944 .35488 L .53033 .38021 L p
1 g
F P
s
P
p
.002 w
.41333 .37714 m .43332 .41127 L .45496 .39263 L p
1 g
F P
s
P
p
.002 w
.45496 .39263 m .43857 .36409 L .41333 .37714 L p
1 g
F P
s
P
p
.002 w
.43857 .36409 m .45496 .39263 L .47765 .37495 L p
1 g
F P
s
P
p
.002 w
.47765 .37495 m .46514 .35275 L .43857 .36409 L p
1 g
F P
s
P
p
.002 w
.46514 .35275 m .47765 .37495 L .50096 .35857 L p
1 g
F P
s
P
p
.002 w
.51401 .37129 m .50096 .35857 L .47765 .37495 L p
1 g
F P
s
P
p
.002 w
.50096 .35857 m .51401 .37129 L .5311 .35032 L p
1 g
F P
s
P
p
.002 w
.53944 .35488 m .5311 .35032 L .51401 .37129 L p
1 g
F P
s
P
p
.002 w
.39477 .45009 m .43278 .48546 L .44745 .46278 L p
1 g
F P
s
P
p
.002 w
.44745 .46278 m .41312 .43054 L .39477 .45009 L p
1 g
F P
s
P
p
.002 w
.54828 .38445 m .56603 .38353 L .55765 .35649 L p
1 g
F P
s
P
p
.002 w
.55765 .35649 m .5486 .35702 L .54828 .38445 L p
1 g
F P
s
P
p
.002 w
.38992 .39168 m .41312 .43054 L .43332 .41127 L p
1 g
F P
s
P
p
.002 w
.43332 .41127 m .41333 .37714 L .38992 .39168 L p
1 g
F P
s
P
p
.002 w
.50096 .35857 m .49254 .34332 L .46514 .35275 L p
1 g
F P
s
P
p
.002 w
.49254 .34332 m .50096 .35857 L .52447 .3438 L p
1 g
F P
s
P
p
.002 w
.5311 .35032 m .52447 .3438 L .50096 .35857 L p
1 g
F P
s
P
p
.002 w
.59588 .40295 m .57274 .41154 L .57768 .43999 L p
1 g
F P
s
P
p
.002 w
.57274 .41154 m .59588 .40295 L .58176 .3775 L p
1 g
F P
s
P
p
.002 w
.58176 .3775 m .56603 .38353 L .57274 .41154 L p
1 g
F P
s
P
p
.002 w
.47926 .51064 m .53012 .52347 L .53577 .49715 L p
1 g
F P
s
P
p
.002 w
.58183 .49606 m .53577 .49715 L .53012 .52347 L p
1 g
F P
s
P
p
.002 w
.53577 .49715 m .58183 .49606 L .58073 .46834 L p
1 g
F P
s
P
p
.002 w
.60771 .4292 m .57768 .43999 L .58073 .46834 L p
1 g
F P
s
P
p
.002 w
.57768 .43999 m .60771 .4292 L .59588 .40295 L p
1 g
F P
s
P
p
.002 w
.56603 .38353 m .58176 .3775 L .5656 .35334 L p
1 g
F P
s
P
p
.002 w
.5656 .35334 m .55765 .35649 L .56603 .38353 L p
1 g
F P
s
P
p
.002 w
.4195 .5072 m .46924 .5341 L .47926 .51064 L p
1 g
F P
s
P
p
.002 w
.47926 .51064 m .43278 .48546 L .4195 .5072 L p
1 g
F P
s
P
p
.002 w
.53012 .52347 m .47926 .51064 L .46924 .5341 L p
1 g
F P
s
P
p
.002 w
.43245 .33343 m .43857 .36409 L .46514 .35275 L p
1 g
F P
s
P
p
.002 w
.46514 .35275 m .46069 .32899 L .43245 .33343 L p
1 g
F P
s
P
p
.002 w
.46069 .32899 m .46514 .35275 L .49254 .34332 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .5311 .35032 L .53944 .35488 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .53944 .35488 L .5486 .35702 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .52447 .3438 L .5311 .35032 L closepath p
1 g
F P
s
P
p
.002 w
.37868 .46954 m .4195 .5072 L .43278 .48546 L p
1 g
F P
s
P
p
.002 w
.43278 .48546 m .39477 .45009 L .37868 .46954 L p
1 g
F P
s
P
p
.002 w
.36887 .40745 m .39477 .45009 L .41312 .43054 L p
1 g
F P
s
P
p
.002 w
.41312 .43054 m .38992 .39168 L .36887 .40745 L p
1 g
F P
s
P
p
.002 w
.49254 .34332 m .4897 .32709 L .46069 .32899 L p
1 g
F P
s
P
p
.002 w
.4897 .32709 m .49254 .34332 L .52025 .336 L p
1 g
F P
s
P
p
.002 w
.52447 .3438 m .52025 .336 L .49254 .34332 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .5486 .35702 L .55765 .35649 L closepath p
1 g
F P
s
P
p
.002 w
.61698 .45575 m .58073 .46834 L .58183 .49606 L p
1 g
F P
s
P
p
.002 w
.58073 .46834 m .61698 .45575 L .60771 .4292 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .52025 .336 L .52447 .3438 L closepath p
1 g
F P
s
P
p
.002 w
.40554 .34035 m .41333 .37714 L .43857 .36409 L p
1 g
F P
s
P
p
.002 w
.43857 .36409 m .43245 .33343 L .40554 .34035 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .55765 .35649 L .5656 .35334 L closepath p
1 g
F P
s
P
p
.002 w
.52025 .336 m .51891 .32774 L .4897 .32709 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .51891 .32774 L .52025 .336 L closepath p
1 g
F P
s
P
p
.002 w
.59377 .36689 m .58176 .3775 L .59588 .40295 L p
1 g
F P
s
P
p
.002 w
.58176 .3775 m .59377 .36689 L .57162 .34788 L p
1 g
F P
s
P
p
.002 w
.57162 .34788 m .5656 .35334 L .58176 .3775 L p
1 g
F P
s
P
p
.002 w
.46924 .5341 m .52361 .54798 L .53012 .52347 L p
1 g
F P
s
P
p
.002 w
.58091 .5226 m .53012 .52347 L .52361 .54798 L p
1 g
F P
s
P
p
.002 w
.53012 .52347 m .58091 .5226 L .58183 .49606 L p
1 g
F P
s
P
p
.002 w
.61374 .3876 m .59588 .40295 L .60771 .4292 L p
1 g
F P
s
P
p
.002 w
.59588 .40295 m .61374 .3876 L .59377 .36689 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .5656 .35334 L .57162 .34788 L closepath p
1 g
F P
s
P
p
.002 w
.38055 .34966 m .38992 .39168 L .41333 .37714 L p
1 g
F P
s
P
p
.002 w
.41333 .37714 m .40554 .34035 L .38055 .34966 L p
1 g
F P
s
P
p
.002 w
.465 .30612 m .46069 .32899 L .4897 .32709 L p
1 g
F P
s
P
p
.002 w
.4897 .32709 m .49285 .31156 L .465 .30612 L p
1 g
F P
s
P
p
.002 w
.49285 .31156 m .4897 .32709 L .51891 .32774 L p
1 g
F P
s
P
p
.002 w
.51891 .32774 m .52061 .3199 L .49285 .31156 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .52061 .3199 L .51891 .32774 L closepath p
1 g
F P
s
P
p
.002 w
.62345 .48206 m .58183 .49606 L .58091 .5226 L p
1 g
F P
s
P
p
.002 w
.58183 .49606 m .62345 .48206 L .61698 .45575 L p
1 g
F P
s
P
p
.002 w
.35067 .42416 m .37868 .46954 L .39477 .45009 L p
1 g
F P
s
P
p
.002 w
.39477 .45009 m .36887 .40745 L .35067 .42416 L p
1 g
F P
s
P
p
.002 w
.63108 .40964 m .60771 .4292 L .61698 .45575 L p
1 g
F P
s
P
p
.002 w
.60771 .4292 m .63108 .40964 L .61374 .3876 L p
1 g
F P
s
P
p
.002 w
.40791 .52755 m .45976 .55554 L .46924 .5341 L p
1 g
F P
s
P
p
.002 w
.46924 .5341 m .4195 .5072 L .40791 .52755 L p
1 g
F P
s
P
p
.002 w
.52361 .54798 m .46924 .5341 L .45976 .55554 L p
1 g
F P
s
P
p
.002 w
.43763 .30372 m .43245 .33343 L .46069 .32899 L p
1 g
F P
s
P
p
.002 w
.46069 .32899 m .465 .30612 L .43763 .30372 L p
1 g
F P
s
P
p
.002 w
.57503 .34067 m .57162 .34788 L .59377 .36689 L p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .57162 .34788 L .57503 .34067 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .57273 .32419 L .56721 .31674 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .56721 .31674 L .55948 .31095 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .55948 .31095 L .55039 .3075 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .55039 .3075 L .54096 .30675 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .54096 .30675 L .53225 .30877 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .53225 .30877 L .52522 .31334 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .52522 .31334 L .52061 .3199 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .57503 .34067 L .57542 .33247 L closepath p
1 g
F P
s
P
p
.002 w
.54773 .33094 m .57542 .33247 L .57273 .32419 L closepath p
1 g
F P
s
P
p
.002 w
.36526 .48849 m .40791 .52755 L .4195 .5072 L p
1 g
F P
s
P
p
.002 w
.4195 .5072 m .37868 .46954 L .36526 .48849 L p
1 g
F P
s
P
p
.002 w
.50178 .29844 m .49285 .31156 L .52061 .3199 L p
1 g
F P
s
P
p
.002 w
.52061 .3199 m .52522 .31334 L .50178 .29844 L p
1 g
F P
s
P
p
.002 w
.60071 .35273 m .59377 .36689 L .61374 .3876 L p
1 g
F P
s
P
p
.002 w
.59377 .36689 m .60071 .35273 L .57503 .34067 L p
1 g
F P
s
P
p
.002 w
.35807 .36125 m .36887 .40745 L .38992 .39168 L p
1 g
F P
s
P
p
.002 w
.38992 .39168 m .38055 .34966 L .35807 .36125 L p
1 g
F P
s
P
p
.002 w
.57542 .33247 m .57503 .34067 L .60071 .35273 L p
1 g
F P
s
P
p
.002 w
.41132 .30452 m .40554 .34035 L .43245 .33343 L p
1 g
F P
s
P
p
.002 w
.43245 .33343 m .43763 .30372 L .41132 .30452 L p
1 g
F P
s
P
p
.002 w
.4779 .28663 m .465 .30612 L .49285 .31156 L p
1 g
F P
s
P
p
.002 w
.49285 .31156 m .50178 .29844 L .4779 .28663 L p
1 g
F P
s
P
p
.002 w
.6454 .43256 m .61698 .45575 L .62345 .48206 L p
1 g
F P
s
P
p
.002 w
.61698 .45575 m .6454 .43256 L .63108 .40964 L p
1 g
F P
s
P
p
.002 w
.45976 .55554 m .51635 .57014 L .52361 .54798 L p
1 g
F P
s
P
p
.002 w
.57793 .54738 m .52361 .54798 L .51635 .57014 L p
1 g
F P
s
P
p
.002 w
.52361 .54798 m .57793 .54738 L .58091 .5226 L p
1 g
F P
s
P
p
.002 w
.51565 .28924 m .50178 .29844 L .52522 .31334 L p
1 g
F P
s
P
p
.002 w
.52522 .31334 m .53225 .30877 L .51565 .28924 L p
1 g
F P
s
P
p
.002 w
.62423 .36692 m .61374 .3876 L .63108 .40964 L p
1 g
F P
s
P
p
.002 w
.61374 .3876 m .62423 .36692 L .60071 .35273 L p
1 g
F P
s
P
p
.002 w
.62693 .5076 m .58091 .5226 L .57793 .54738 L p
1 g
F P
s
P
p
.002 w
.58091 .5226 m .62693 .5076 L .62345 .48206 L p
1 g
F P
s
P
p
.002 w
.60071 .35273 m .60169 .3365 L .57542 .33247 L p
1 g
F P
s
P
p
.002 w
.57273 .32419 m .57542 .33247 L .60169 .3365 L p
1 g
F P
s
P
p
.002 w
.53297 .28507 m .51565 .28924 L .53225 .30877 L p
1 g
F P
s
P
p
.002 w
.53225 .30877 m .54096 .30675 L .53297 .28507 L p
1 g
F P
s
P
p
.002 w
.60169 .3365 m .60071 .35273 L .62423 .36692 L p
1 g
F P
s
P
p
.002 w
.33582 .44148 m .36526 .48849 L .37868 .46954 L p
1 g
F P
s
P
p
.002 w
.37868 .46954 m .35067 .42416 L .33582 .44148 L p
1 g
F P
s
P
p
.002 w
.56721 .31674 m .57273 .32419 L .59647 .31997 L p
1 g
F P
s
P
p
.002 w
.60169 .3365 m .59647 .31997 L .57273 .32419 L p
1 g
F P
s
P
p
.002 w
.45405 .27824 m .43763 .30372 L .465 .30612 L p
1 g
F P
s
P
p
.002 w
.465 .30612 m .4779 .28663 L .45405 .27824 L p
1 g
F P
s
P
p
.002 w
.55183 .2865 m .53297 .28507 L .54096 .30675 L p
1 g
F P
s
P
p
.002 w
.54096 .30675 m .55039 .3075 L .55183 .2865 L p
1 g
F P
s
P
p
.002 w
.38669 .30858 m .38055 .34966 L .40554 .34035 L p
1 g
F P
s
P
p
.002 w
.40554 .34035 m .41132 .30452 L .38669 .30858 L p
1 g
F P
s
P
p
.002 w
.39833 .54603 m .45101 .57444 L .45976 .55554 L p
1 g
F P
s
P
p
.002 w
.45976 .55554 m .40791 .52755 L .39833 .54603 L p
1 g
F P
s
P
p
.002 w
.51635 .57014 m .45976 .55554 L .45101 .57444 L p
1 g
F P
s
P
p
.002 w
.49823 .27283 m .4779 .28663 L .50178 .29844 L p
1 g
F P
s
P
p
.002 w
.50178 .29844 m .51565 .28924 L .49823 .27283 L p
1 g
F P
s
P
p
.002 w
.59647 .31997 m .58553 .30503 L .56721 .31674 L p
1 g
F P
s
P
p
.002 w
.55948 .31095 m .56721 .31674 L .58553 .30503 L p
1 g
F P
s
P
p
.002 w
.64503 .38301 m .63108 .40964 L .6454 .43256 L p
1 g
F P
s
P
p
.002 w
.63108 .40964 m .64503 .38301 L .62423 .36692 L p
1 g
F P
s
P
p
.002 w
.57006 .29342 m .55183 .2865 L .55039 .3075 L p
1 g
F P
s
P
p
.002 w
.55039 .3075 m .55948 .31095 L .57006 .29342 L p
1 g
F P
s
P
p
.002 w
.33868 .37494 m .35067 .42416 L .36887 .40745 L p
1 g
F P
s
P
p
.002 w
.36887 .40745 m .35807 .36125 L .33868 .37494 L p
1 g
F P
s
P
p
.002 w
.58553 .30503 m .57006 .29342 L .55948 .31095 L p
1 g
F P
s
P
p
.002 w
.3549 .50652 m .39833 .54603 L .40791 .52755 L p
1 g
F P
s
P
p
.002 w
.40791 .52755 m .36526 .48849 L .3549 .50652 L p
1 g
F P
s
P
p
.002 w
.65629 .45591 m .62345 .48206 L .62693 .5076 L p
1 g
F P
s
P
p
.002 w
.62345 .48206 m .65629 .45591 L .6454 .43256 L p
1 g
F P
s
P
p
.002 w
.62423 .36692 m .62594 .34301 L .60169 .3365 L p
1 g
F P
s
P
p
.002 w
.59647 .31997 m .60169 .3365 L .62594 .34301 L p
1 g
F P
s
P
p
.002 w
.62594 .34301 m .62423 .36692 L .64503 .38301 L p
1 g
F P
s
P
p
.002 w
.51635 .57014 m .57288 .56983 L .57793 .54738 L p
1 g
F P
s
P
p
.002 w
.62723 .53178 m .57793 .54738 L .57288 .56983 L p
1 g
F P
s
P
p
.002 w
.57793 .54738 m .62723 .53178 L .62693 .5076 L p
1 g
F P
s
P
p
.002 w
.45101 .57444 m .50845 .58939 L .51635 .57014 L p
1 g
F P
s
P
p
.002 w
.57288 .56983 m .51635 .57014 L .50845 .58939 L p
1 g
F P
s
P
p
.002 w
.43077 .27358 m .41132 .30452 L .43763 .30372 L p
1 g
F P
s
P
p
.002 w
.43763 .30372 m .45405 .27824 L .43077 .27358 L p
1 g
F P
s
P
p
.002 w
.5239 .26649 m .49823 .27283 L .51565 .28924 L p
1 g
F P
s
P
p
.002 w
.51565 .28924 m .53297 .28507 L .5239 .26649 L p
1 g
F P
s
P
p
.002 w
.36435 .31594 m .35807 .36125 L .38055 .34966 L p
1 g
F P
s
P
p
.002 w
.38055 .34966 m .38669 .30858 L .36435 .31594 L p
1 g
F P
s
P
p
.002 w
.66258 .40069 m .6454 .43256 L .65629 .45591 L p
1 g
F P
s
P
p
.002 w
.6454 .43256 m .66258 .40069 L .64503 .38301 L p
1 g
F P
s
P
p
.002 w
.48036 .26004 m .45405 .27824 L .4779 .28663 L p
1 g
F P
s
P
p
.002 w
.4779 .28663 m .49823 .27283 L .48036 .26004 L p
1 g
F P
s
P
p
.002 w
.3248 .45905 m .3549 .50652 L .36526 .48849 L p
1 g
F P
s
P
p
.002 w
.36526 .48849 m .33582 .44148 L .3248 .45905 L p
1 g
F P
s
P
p
.002 w
.62594 .34301 m .6184 .31848 L .59647 .31997 L p
1 g
F P
s
P
p
.002 w
.58553 .30503 m .59647 .31997 L .6184 .31848 L p
1 g
F P
s
P
p
.002 w
.6634 .47918 m .62693 .5076 L .62723 .53178 L p
1 g
F P
s
P
p
.002 w
.62693 .5076 m .6634 .47918 L .65629 .45591 L p
1 g
F P
s
P
p
.002 w
.55199 .26853 m .5239 .26649 L .53297 .28507 L p
1 g
F P
s
P
p
.002 w
.53297 .28507 m .55183 .2865 L .55199 .26853 L p
1 g
F P
s
P
p
.002 w
.32297 .39049 m .33582 .44148 L .35067 .42416 L p
1 g
F P
s
P
p
.002 w
.35067 .42416 m .33868 .37494 L .32297 .39049 L p
1 g
F P
s
P
p
.002 w
.6184 .31848 m .60223 .29619 L .58553 .30503 L p
1 g
F P
s
P
p
.002 w
.57006 .29342 m .58553 .30503 L .60223 .29619 L p
1 g
F P
s
P
p
.002 w
.39106 .56214 m .44324 .59025 L .45101 .57444 L p
1 g
F P
s
P
p
.002 w
.45101 .57444 m .39833 .54603 L .39106 .56214 L p
1 g
F P
s
P
p
.002 w
.50845 .58939 m .45101 .57444 L .44324 .59025 L p
1 g
F P
s
P
p
.002 w
.64758 .35195 m .64503 .38301 L .66258 .40069 L p
1 g
F P
s
P
p
.002 w
.64503 .38301 m .64758 .35195 L .62594 .34301 L p
1 g
F P
s
P
p
.002 w
.57919 .27883 m .55199 .26853 L .55183 .2865 L p
1 g
F P
s
P
p
.002 w
.55183 .2865 m .57006 .29342 L .57919 .27883 L p
1 g
F P
s
P
p
.002 w
.6184 .31848 m .62594 .34301 L .64758 .35195 L p
1 g
F P
s
P
p
.002 w
.34799 .52318 m .39106 .56214 L .39833 .54603 L p
1 g
F P
s
P
p
.002 w
.39833 .54603 m .3549 .50652 L .34799 .52318 L p
1 g
F P
s
P
p
.002 w
.60223 .29619 m .57919 .27883 L .57006 .29342 L p
1 g
F P
s
P
p
.002 w
.40863 .27293 m .38669 .30858 L .41132 .30452 L p
1 g
F P
s
P
p
.002 w
.41132 .30452 m .43077 .27358 L .40863 .27293 L p
1 g
F P
s
P
p
.002 w
.50845 .58939 m .56578 .58935 L .57288 .56983 L p
1 g
F P
s
P
p
.002 w
.62422 .55401 m .57288 .56983 L .56578 .58935 L p
1 g
F P
s
P
p
.002 w
.57288 .56983 m .62422 .55401 L .62723 .53178 L p
1 g
F P
s
P
p
.002 w
.51388 .25157 m .48036 .26004 L .49823 .27283 L p
1 g
F P
s
P
p
.002 w
.49823 .27283 m .5239 .26649 L .51388 .25157 L p
1 g
F P
s
P
p
.002 w
.34495 .32657 m .33868 .37494 L .35807 .36125 L p
1 g
F P
s
P
p
.002 w
.35807 .36125 m .36435 .31594 L .34495 .32657 L p
1 g
F P
s
P
p
.002 w
.67636 .41963 m .65629 .45591 L .6634 .47918 L p
1 g
F P
s
P
p
.002 w
.65629 .45591 m .67636 .41963 L .66258 .40069 L p
1 g
F P
s
P
p
.002 w
.46243 .25134 m .43077 .27358 L .45405 .27824 L p
1 g
F P
s
P
p
.002 w
.45405 .27824 m .48036 .26004 L .46243 .25134 L p
1 g
F P
s
P
p
.002 w
.44324 .59025 m .50006 .60516 L .50845 .58939 L p
1 g
F P
s
P
p
.002 w
.56578 .58935 m .50845 .58939 L .50006 .60516 L p
1 g
F P
s
P
p
.002 w
.66642 .50183 m .62723 .53178 L .62422 .55401 L p
1 g
F P
s
P
p
.002 w
.62723 .53178 m .66642 .50183 L .6634 .47918 L p
1 g
F P
s
P
p
.002 w
.64758 .35195 m .63795 .31986 L .6184 .31848 L p
1 g
F P
s
P
p
.002 w
.60223 .29619 m .6184 .31848 L .63795 .31986 L p
1 g
F P
s
P
p
.002 w
.31807 .47647 m .34799 .52318 L .3549 .50652 L p
1 g
F P
s
P
p
.002 w
.3549 .50652 m .3248 .45905 L .31807 .47647 L p
1 g
F P
s
P
p
.002 w
.31149 .40762 m .3248 .45905 L .33582 .44148 L p
1 g
F P
s
P
p
.002 w
.33582 .44148 m .32297 .39049 L .31149 .40762 L p
1 g
F P
s
P
p
.002 w
.666 .36322 m .66258 .40069 L .67636 .41963 L p
1 g
F P
s
P
p
.002 w
.66258 .40069 m .666 .36322 L .64758 .35195 L p
1 g
F P
s
P
p
.002 w
.55077 .25415 m .51388 .25157 L .5239 .26649 L p
1 g
F P
s
P
p
.002 w
.5239 .26649 m .55199 .26853 L .55077 .25415 L p
1 g
F P
s
P
p
.002 w
.38822 .27647 m .36435 .31594 L .38669 .30858 L p
1 g
F P
s
P
p
.002 w
.38669 .30858 m .40863 .27293 L .38822 .27647 L p
1 g
F P
s
P
p
.002 w
.63795 .31986 m .64758 .35195 L .666 .36322 L p
1 g
F P
s
P
p
.002 w
.63795 .31986 m .61685 .29056 L .60223 .29619 L p
1 g
F P
s
P
p
.002 w
.57919 .27883 m .60223 .29619 L .61685 .29056 L p
1 g
F P
s
P
p
.002 w
.38639 .57539 m .43666 .60244 L .44324 .59025 L p
1 g
F P
s
P
p
.002 w
.44324 .59025 m .39106 .56214 L .38639 .57539 L p
1 g
F P
s
P
p
.002 w
.50006 .60516 m .44324 .59025 L .43666 .60244 L p
1 g
F P
s
P
p
.002 w
.58657 .26769 m .55077 .25415 L .55199 .26853 L p
1 g
F P
s
P
p
.002 w
.55199 .26853 m .57919 .27883 L .58657 .26769 L p
1 g
F P
s
P
p
.002 w
.68588 .43943 m .6634 .47918 L .66642 .50183 L p
1 g
F P
s
P
p
.002 w
.6634 .47918 m .68588 .43943 L .67636 .41963 L p
1 g
F P
s
P
p
.002 w
.32911 .34035 m .32297 .39049 L .33868 .37494 L p
1 g
F P
s
P
p
.002 w
.33868 .37494 m .34495 .32657 L .32911 .34035 L p
1 g
F P
s
P
p
.002 w
.34487 .53799 m .38639 .57539 L .39106 .56214 L p
1 g
F P
s
P
p
.002 w
.39106 .56214 m .34799 .52318 L .34487 .53799 L p
1 g
F P
s
P
p
.002 w
.61685 .29056 m .58657 .26769 L .57919 .27883 L p
1 g
F P
s
P
p
.002 w
.44487 .24714 m .40863 .27293 L .43077 .27358 L p
1 g
F P
s
P
p
.002 w
.43077 .27358 m .46243 .25134 L .44487 .24714 L p
1 g
F P
s
P
p
.002 w
.50311 .24087 m .46243 .25134 L .48036 .26004 L p
1 g
F P
s
P
p
.002 w
.48036 .26004 m .51388 .25157 L .50311 .24087 L p
1 g
F P
s
P
p
.002 w
.50006 .60516 m .5567 .60534 L .56578 .58935 L p
1 g
F P
s
P
p
.002 w
.61782 .57368 m .56578 .58935 L .5567 .60534 L p
1 g
F P
s
P
p
.002 w
.56578 .58935 m .61782 .57368 L .62422 .55401 L p
1 g
F P
s
P
p
.002 w
.43666 .60244 m .49135 .61688 L .50006 .60516 L p
1 g
F P
s
P
p
.002 w
.5567 .60534 m .50006 .60516 L .49135 .61688 L p
1 g
F P
s
P
p
.002 w
.66509 .52328 m .62422 .55401 L .61782 .57368 L p
1 g
F P
s
P
p
.002 w
.62422 .55401 m .66509 .52328 L .66642 .50183 L p
1 g
F P
s
P
p
.002 w
.68061 .37665 m .67636 .41963 L .68588 .43943 L p
1 g
F P
s
P
p
.002 w
.67636 .41963 m .68061 .37665 L .666 .36322 L p
1 g
F P
s
P
p
.002 w
.666 .36322 m .65453 .32424 L .63795 .31986 L p
1 g
F P
s
P
p
.002 w
.61685 .29056 m .63795 .31986 L .65453 .32424 L p
1 g
F P
s
P
p
.002 w
.30474 .42596 m .31807 .47647 L .3248 .45905 L p
1 g
F P
s
P
p
.002 w
.3248 .45905 m .31149 .40762 L .30474 .42596 L p
1 g
F P
s
P
p
.002 w
.37016 .28433 m .34495 .32657 L .36435 .31594 L p
1 g
F P
s
P
p
.002 w
.36435 .31594 m .38822 .27647 L .37016 .28433 L p
1 g
F P
s
P
p
.002 w
.31603 .49328 m .34487 .53799 L .34799 .52318 L p
1 g
F P
s
P
p
.002 w
.34799 .52318 m .31807 .47647 L .31603 .49328 L p
1 g
F P
s
P
p
.002 w
.65453 .32424 m .666 .36322 L .68061 .37665 L p
1 g
F P
s
P
p
.002 w
.54814 .24394 m .50311 .24087 L .51388 .25157 L p
1 g
F P
s
P
p
.002 w
.51388 .25157 m .55077 .25415 L .54814 .24394 L p
1 g
F P
s
P
p
.002 w
.69069 .45963 m .66642 .50183 L .66509 .52328 L p
1 g
F P
s
P
p
.002 w
.66642 .50183 m .69069 .45963 L .68588 .43943 L p
1 g
F P
s
P
p
.002 w
.31743 .35707 m .31149 .40762 L .32297 .39049 L p
1 g
F P
s
P
p
.002 w
.32297 .39049 m .32911 .34035 L .31743 .35707 L p
1 g
F P
s
P
p
.002 w
.42816 .24781 m .38822 .27647 L .40863 .27293 L p
1 g
F P
s
P
p
.002 w
.40863 .27293 m .44487 .24714 L .42816 .24781 L p
1 g
F P
s
P
p
.002 w
.65453 .32424 m .62891 .28847 L .61685 .29056 L p
1 g
F P
s
P
p
.002 w
.58657 .26769 m .61685 .29056 L .62891 .28847 L p
1 g
F P
s
P
p
.002 w
.49183 .23492 m .44487 .24714 L .46243 .25134 L p
1 g
F P
s
P
p
.002 w
.46243 .25134 m .50311 .24087 L .49183 .23492 L p
1 g
F P
s
P
p
.002 w
.3846 .58527 m .43153 .61051 L .43666 .60244 L p
1 g
F P
s
P
p
.002 w
.43666 .60244 m .38639 .57539 L .3846 .58527 L p
1 g
F P
s
P
p
.002 w
.49135 .61688 m .43666 .60244 L .43153 .61051 L p
1 g
F P
s
P
p
.002 w
.59193 .26048 m .54814 .24394 L .55077 .25415 L p
1 g
F P
s
P
p
.002 w
.55077 .25415 m .58657 .26769 L .59193 .26048 L p
1 g
F P
s
P
p
.002 w
.49135 .61688 m .54576 .61722 L .5567 .60534 L p
1 g
F P
s
P
p
.002 w
.60803 .59016 m .5567 .60534 L .54576 .61722 L p
1 g
F P
s
P
p
.002 w
.5567 .60534 m .60803 .59016 L .61782 .57368 L p
1 g
F P
s
P
p
.002 w
.34585 .55047 m .3846 .58527 L .38639 .57539 L p
1 g
F P
s
P
p
.002 w
.38639 .57539 m .34487 .53799 L .34585 .55047 L p
1 g
F P
s
P
p
.002 w
.62891 .28847 m .59193 .26048 L .58657 .26769 L p
1 g
F P
s
P
p
.002 w
.65922 .54292 m .61782 .57368 L .60803 .59016 L p
1 g
F P
s
P
p
.002 w
.61782 .57368 m .65922 .54292 L .66509 .52328 L p
1 g
F P
s
P
p
.002 w
.69082 .39203 m .68588 .43943 L .69069 .45963 L p
1 g
F P
s
P
p
.002 w
.68588 .43943 m .69082 .39203 L .68061 .37665 L p
1 g
F P
s
P
p
.002 w
.43153 .61051 m .48252 .62403 L .49135 .61688 L p
1 g
F P
s
P
p
.002 w
.54576 .61722 m .49135 .61688 L .48252 .62403 L p
1 g
F P
s
P
p
.002 w
.35506 .29652 m .32911 .34035 L .34495 .32657 L p
1 g
F P
s
P
p
.002 w
.34495 .32657 m .37016 .28433 L .35506 .29652 L p
1 g
F P
s
P
p
.002 w
.68061 .37665 m .66755 .33167 L .65453 .32424 L p
1 g
F P
s
P
p
.002 w
.62891 .28847 m .65453 .32424 L .66755 .33167 L p
1 g
F P
s
P
p
.002 w
.30316 .44508 m .31603 .49328 L .31807 .47647 L p
1 g
F P
s
P
p
.002 w
.31807 .47647 m .30474 .42596 L .30316 .44508 L p
1 g
F P
s
P
p
.002 w
.66755 .33167 m .68061 .37665 L .69082 .39203 L p
1 g
F P
s
P
p
.002 w
.31899 .50901 m .34585 .55047 L .34487 .53799 L p
1 g
F P
s
P
p
.002 w
.34487 .53799 m .31603 .49328 L .31899 .50901 L p
1 g
F P
s
P
p
.002 w
.69043 .47973 m .66509 .52328 L .65922 .54292 L p
1 g
F P
s
P
p
.002 w
.66509 .52328 m .69043 .47973 L .69069 .45963 L p
1 g
F P
s
P
p
.002 w
.54407 .23844 m .49183 .23492 L .50311 .24087 L p
1 g
F P
s
P
p
.002 w
.50311 .24087 m .54814 .24394 L .54407 .23844 L p
1 g
F P
s
P
p
.002 w
.31044 .37643 m .30474 .42596 L .31149 .40762 L p
1 g
F P
s
P
p
.002 w
.31149 .40762 m .31743 .35707 L .31044 .37643 L p
1 g
F P
s
P
p
.002 w
.41282 .25359 m .37016 .28433 L .38822 .27647 L p
1 g
F P
s
P
p
.002 w
.38822 .27647 m .42816 .24781 L .41282 .25359 L p
1 g
F P
s
P
p
.002 w
.48031 .23418 m .42816 .24781 L .44487 .24714 L p
1 g
F P
s
P
p
.002 w
.44487 .24714 m .49183 .23492 L .48031 .23418 L p
1 g
F P
s
P
p
.002 w
.66755 .33167 m .63793 .29019 L .62891 .28847 L p
1 g
F P
s
P
p
.002 w
.59193 .26048 m .62891 .28847 L .63793 .29019 L p
1 g
F P
s
P
p
.002 w
.48252 .62403 m .53313 .62443 L .54576 .61722 L p
1 g
F P
s
P
p
.002 w
.59491 .60285 m .54576 .61722 L .53313 .62443 L p
1 g
F P
s
P
p
.002 w
.54576 .61722 m .59491 .60285 L .60803 .59016 L p
1 g
F P
s
P
p
.002 w
.38591 .59131 m .42805 .61397 L .43153 .61051 L p
1 g
F P
s
P
p
.002 w
.43153 .61051 m .3846 .58527 L .38591 .59131 L p
1 g
F P
s
P
p
.002 w
.48252 .62403 m .43153 .61051 L .42805 .61397 L p
1 g
F P
s
P
p
.002 w
.59498 .25766 m .54407 .23844 L .54814 .24394 L p
1 g
F P
s
P
p
.002 w
.54814 .24394 m .59193 .26048 L .59498 .25766 L p
1 g
F P
s
P
p
.002 w
.64875 .56014 m .60803 .59016 L .59491 .60285 L p
1 g
F P
s
P
p
.002 w
.60803 .59016 m .64875 .56014 L .65922 .54292 L p
1 g
F P
s
P
p
.002 w
.69614 .40903 m .69069 .45963 L .69043 .47973 L p
1 g
F P
s
P
p
.002 w
.69069 .45963 m .69614 .40903 L .69082 .39203 L p
1 g
F P
s
P
p
.002 w
.35116 .56014 m .38591 .59131 L .3846 .58527 L p
1 g
F P
s
P
p
.002 w
.3846 .58527 m .34585 .55047 L .35116 .56014 L p
1 g
F P
s
P
p
.002 w
.34351 .31294 m .31743 .35707 L .32911 .34035 L p
1 g
F P
s
P
p
.002 w
.32911 .34035 m .35506 .29652 L .34351 .31294 L p
1 g
F P
s
P
p
.002 w
.63793 .29019 m .59498 .25766 L .59193 .26048 L p
1 g
F P
s
P
p
.002 w
.42805 .61397 m .47381 .62612 L .48252 .62403 L p
1 g
F P
s
P
p
.002 w
.53313 .62443 m .48252 .62403 L .47381 .62612 L p
1 g
F P
s
P
p
.002 w
.30708 .46448 m .31899 .50901 L .31603 .49328 L p
1 g
F P
s
P
p
.002 w
.31603 .49328 m .30316 .44508 L .30708 .46448 L p
1 g
F P
s
P
p
.002 w
.69082 .39203 m .67645 .34214 L .66755 .33167 L p
1 g
F P
s
P
p
.002 w
.63793 .29019 m .66755 .33167 L .67645 .34214 L p
1 g
F P
s
P
p
.002 w
.67645 .34214 m .69082 .39203 L .69614 .40903 L p
1 g
F P
s
P
p
.002 w
.65922 .54292 m .68484 .49916 L .69043 .47973 L p
1 g
F P
s
P
p
.002 w
.68484 .49916 m .65922 .54292 L .64875 .56014 L p
1 g
F P
s
P
p
.002 w
.3086 .39799 m .30316 .44508 L .30474 .42596 L p
1 g
F P
s
P
p
.002 w
.30474 .42596 m .31044 .37643 L .3086 .39799 L p
1 g
F P
s
P
p
.002 w
.32717 .52313 m .35116 .56014 L .34585 .55047 L p
1 g
F P
s
P
p
.002 w
.34585 .55047 m .31899 .50901 L .32717 .52313 L p
1 g
F P
s
P
p
.002 w
.39936 .26464 m .35506 .29652 L .37016 .28433 L p
1 g
F P
s
P
p
.002 w
.37016 .28433 m .41282 .25359 L .39936 .26464 L p
1 g
F P
s
P
p
.002 w
.53858 .2381 m .48031 .23418 L .49183 .23492 L p
1 g
F P
s
P
p
.002 w
.49183 .23492 m .54407 .23844 L .53858 .2381 L p
1 g
F P
s
P
p
.002 w
.46886 .23898 m .41282 .25359 L .42816 .24781 L p
1 g
F P
s
P
p
.002 w
.42816 .24781 m .48031 .23418 L .46886 .23898 L p
1 g
F P
s
P
p
.002 w
.69043 .47973 m .69613 .42728 L .69614 .40903 L p
1 g
F P
s
P
p
.002 w
.69613 .42728 m .69043 .47973 L .68484 .49916 L p
1 g
F P
s
P
p
.002 w
.47381 .62612 m .51907 .62651 L .53313 .62443 L p
1 g
F P
s
P
p
.002 w
.53313 .62443 m .57866 .61119 L .59491 .60285 L p
1 g
F P
s
P
p
.002 w
.57866 .61119 m .53313 .62443 L .51907 .62651 L p
1 g
F P
s
P
p
.002 w
.59491 .60285 m .63372 .57431 L .64875 .56014 L p
1 g
F P
s
P
p
.002 w
.63372 .57431 m .59491 .60285 L .57866 .61119 L p
1 g
F P
s
P
p
.002 w
.67645 .34214 m .64348 .29593 L .63793 .29019 L p
1 g
F P
s
P
p
.002 w
.59498 .25766 m .63793 .29019 L .64348 .29593 L p
1 g
F P
s
P
p
.002 w
.33605 .3333 m .31044 .37643 L .31743 .35707 L p
1 g
F P
s
P
p
.002 w
.31743 .35707 m .34351 .31294 L .33605 .3333 L p
1 g
F P
s
P
p
.002 w
.39049 .59308 m .42645 .61241 L .42805 .61397 L p
1 g
F P
s
P
p
.002 w
.42805 .61397 m .38591 .59131 L .39049 .59308 L p
1 g
F P
s
P
p
.002 w
.47381 .62612 m .42805 .61397 L .42645 .61241 L p
1 g
F P
s
P
p
.002 w
.59549 .25959 m .53858 .2381 L .54407 .23844 L p
1 g
F P
s
P
p
.002 w
.54407 .23844 m .59498 .25766 L .59549 .25959 L p
1 g
F P
s
P
p
.002 w
.36091 .56653 m .39049 .59308 L .38591 .59131 L p
1 g
F P
s
P
p
.002 w
.38591 .59131 m .35116 .56014 L .36091 .56653 L p
1 g
F P
s
P
p
.002 w
.64348 .29593 m .59549 .25959 L .59498 .25766 L p
1 g
F P
s
P
p
.002 w
.31668 .48358 m .32717 .52313 L .31899 .50901 L p
1 g
F P
s
P
p
.002 w
.31899 .50901 m .30708 .46448 L .31668 .48358 L p
1 g
F P
s
P
p
.002 w
.67381 .51731 m .64875 .56014 L .63372 .57431 L p
1 g
F P
s
P
p
.002 w
.64875 .56014 m .67381 .51731 L .68484 .49916 L p
1 g
F P
s
P
p
.004 w
.67884 .55536 m
.7091 .57648 L
s
P
p
.002 w
.69614 .40903 m .68073 .35552 L .67645 .34214 L p
1 g
F P
s
P
p
.002 w
.68073 .35552 m .69614 .40903 L .69613 .42728 L p
1 g
F P
s
P
p
.002 w
.64348 .29593 m .67645 .34214 L .68073 .35552 L p
1 g
F P
s
P
p
.002 w
.42645 .61241 m .46545 .62277 L .47381 .62612 L p
1 g
F P
s
P
p
.002 w
.51907 .62651 m .47381 .62612 L .46545 .62277 L p
1 g
F P
s
P
p
.002 w
.31223 .4212 m .30708 .46448 L .30316 .44508 L p
1 g
F P
s
P
p
.002 w
.30316 .44508 m .3086 .39799 L .31223 .4212 L p
1 g
F P
s
P
p
.002 w
.38832 .28089 m .34351 .31294 L .35506 .29652 L p
1 g
F P
s
P
p
.002 w
.35506 .29652 m .39936 .26464 L .38832 .28089 L p
1 g
F P
s
P
p
.002 w
.34063 .53513 m .36091 .56653 L .35116 .56014 L p
1 g
F P
s
P
p
.002 w
.35116 .56014 m .32717 .52313 L .34063 .53513 L p
1 g
F P
s
P
p
.002 w
.53174 .24327 m .46886 .23898 L .48031 .23418 L p
1 g
F P
s
P
p
.002 w
.48031 .23418 m .53858 .2381 L .53174 .24327 L p
1 g
F P
s
P
p
.002 w
.45786 .24953 m .39936 .26464 L .41282 .25359 L p
1 g
F P
s
P
p
.002 w
.41282 .25359 m .46886 .23898 L .45786 .24953 L p
1 g
F P
s
P
p
.002 w
.69049 .44628 m .68484 .49916 L .67381 .51731 L p
1 g
F P
s
P
p
.002 w
.68484 .49916 m .69049 .44628 L .69613 .42728 L p
1 g
F P
s
P
p
.002 w
.33312 .35716 m .3086 .39799 L .31044 .37643 L p
1 g
F P
s
P
p
.002 w
.31044 .37643 m .33605 .3333 L .33312 .35716 L p
1 g
F P
s
P
p
.002 w
.51907 .62651 m .55957 .61469 L .57866 .61119 L p
1 g
F P
s
P
p
.002 w
.61436 .58485 m .57866 .61119 L .55957 .61469 L p
1 g
F P
s
P
p
.002 w
.57866 .61119 m .61436 .58485 L .63372 .57431 L p
1 g
F P
s
P
p
.002 w
.46545 .62277 m .5039 .62307 L .51907 .62651 L p
1 g
F P
s
P
p
.002 w
.55957 .61469 m .51907 .62651 L .5039 .62307 L p
1 g
F P
s
P
p
.002 w
.68073 .35552 m .64516 .30577 L .64348 .29593 L p
1 g
F P
s
P
p
.002 w
.59549 .25959 m .64348 .29593 L .64516 .30577 L p
1 g
F P
s
P
p
.002 w
.65739 .53357 m .63372 .57431 L .61436 .58485 L p
1 g
F P
s
P
p
.002 w
.63372 .57431 m .65739 .53357 L .67381 .51731 L p
1 g
F P
s
P
p
.002 w
.59326 .26653 m .53174 .24327 L .53858 .2381 L p
1 g
F P
s
P
p
.002 w
.53858 .2381 m .59549 .25959 L .59326 .26653 L p
1 g
F P
s
P
p
.002 w
.39843 .59025 m .42689 .60556 L .42645 .61241 L p
1 g
F P
s
P
p
.002 w
.42645 .61241 m .39049 .59308 L .39843 .59025 L p
1 g
F P
s
P
p
.002 w
.46545 .62277 m .42645 .61241 L .42689 .60556 L p
1 g
F P
s
P
p
.002 w
.67998 .3716 m .69613 .42728 L .69049 .44628 L p
1 g
F P
s
P
p
.002 w
.69613 .42728 m .67998 .3716 L .68073 .35552 L p
1 g
F P
s
P
p
.002 w
.33193 .50178 m .34063 .53513 L .32717 .52313 L p
1 g
F P
s
P
p
.002 w
.32717 .52313 m .31668 .48358 L .33193 .50178 L p
1 g
F P
s
P
p
.002 w
.37509 .56925 m .39843 .59025 L .39049 .59308 L p
1 g
F P
s
P
p
.002 w
.39049 .59308 m .36091 .56653 L .37509 .56925 L p
1 g
F P
s
P
p
.002 w
.32146 .44539 m .31668 .48358 L .30708 .46448 L p
1 g
F P
s
P
p
.002 w
.30708 .46448 m .31223 .4212 L .32146 .44539 L p
1 g
F P
s
P
p
.002 w
.64516 .30577 m .59326 .26653 L .59549 .25959 L p
1 g
F P
s
P
p
.002 w
.38018 .30211 m .33605 .3333 L .34351 .31294 L p
1 g
F P
s
P
p
.002 w
.34351 .31294 m .38832 .28089 L .38018 .30211 L p
1 g
F P
s
P
p
.002 w
.64516 .30577 m .68073 .35552 L .67998 .3716 L p
1 g
F P
s
P
p
.002 w
.42689 .60556 m .45774 .61373 L .46545 .62277 L p
1 g
F P
s
P
p
.002 w
.5039 .62307 m .46545 .62277 L .45774 .61373 L p
1 g
F P
s
P
p
.002 w
.35923 .54452 m .37509 .56925 L .36091 .56653 L p
1 g
F P
s
P
p
.002 w
.36091 .56653 m .34063 .53513 L .35923 .54452 L p
1 g
F P
s
P
p
.002 w
.67911 .46549 m .67381 .51731 L .65739 .53357 L p
1 g
F P
s
P
p
.002 w
.67381 .51731 m .67911 .46549 L .69049 .44628 L p
1 g
F P
s
P
p
.002 w
.33505 .38391 m .31223 .4212 L .3086 .39799 L p
1 g
F P
s
P
p
.002 w
.3086 .39799 m .33312 .35716 L .33505 .38391 L p
1 g
F P
s
P
p
.002 w
.52368 .25416 m .45786 .24953 L .46886 .23898 L p
1 g
F P
s
P
p
.002 w
.46886 .23898 m .53174 .24327 L .52368 .25416 L p
1 g
F P
s
P
p
.002 w
.44767 .26583 m .38832 .28089 L .39936 .26464 L p
1 g
F P
s
P
p
.002 w
.39936 .26464 m .45786 .24953 L .44767 .26583 L p
1 g
F P
s
P
p
.002 w
.5039 .62307 m .53807 .61299 L .55957 .61469 L p
1 g
F P
s
P
p
.002 w
.59105 .59126 m .55957 .61469 L .53807 .61299 L p
1 g
F P
s
P
p
.002 w
.55957 .61469 m .59105 .59126 L .61436 .58485 L p
1 g
F P
s
P
p
.002 w
.45774 .61373 m .48803 .61389 L .5039 .62307 L p
1 g
F P
s
P
p
.002 w
.53807 .61299 m .5039 .62307 L .48803 .61389 L p
1 g
F P
s
P
p
.002 w
.63585 .54731 m .61436 .58485 L .59105 .59126 L p
1 g
F P
s
P
p
.002 w
.61436 .58485 m .63585 .54731 L .65739 .53357 L p
1 g
F P
s
P
p
.002 w
.67998 .3716 m .64266 .31966 L .64516 .30577 L p
1 g
F P
s
P
p
.002 w
.59326 .26653 m .64516 .30577 L .64266 .31966 L p
1 g
F P
s
P
p
.002 w
.67393 .39001 m .69049 .44628 L .67911 .46549 L p
1 g
F P
s
P
p
.002 w
.69049 .44628 m .67393 .39001 L .67998 .3716 L p
1 g
F P
s
P
p
.002 w
.33625 .46981 m .33193 .50178 L .31668 .48358 L p
1 g
F P
s
P
p
.002 w
.31668 .48358 m .32146 .44539 L .33625 .46981 L p
1 g
F P
s
P
p
.002 w
.35262 .51842 m .35923 .54452 L .34063 .53513 L p
1 g
F P
s
P
p
.002 w
.34063 .53513 m .33193 .50178 L .35262 .51842 L p
1 g
F P
s
P
p
.002 w
.37536 .32784 m .33312 .35716 L .33605 .3333 L p
1 g
F P
s
P
p
.002 w
.33605 .3333 m .38018 .30211 L .37536 .32784 L p
1 g
F P
s
P
p
.002 w
.5882 .27859 m .52368 .25416 L .53174 .24327 L p
1 g
F P
s
P
p
.002 w
.53174 .24327 m .59326 .26653 L .5882 .27859 L p
1 g
F P
s
P
p
.002 w
.40969 .58261 m .4295 .59327 L .42689 .60556 L p
1 g
F P
s
P
p
.002 w
.42689 .60556 m .39843 .59025 L .40969 .58261 L p
1 g
F P
s
P
p
.002 w
.45774 .61373 m .42689 .60556 L .4295 .59327 L p
1 g
F P
s
P
p
.002 w
.64266 .31966 m .67998 .3716 L .67393 .39001 L p
1 g
F P
s
P
p
.002 w
.39351 .56799 m .40969 .58261 L .39843 .59025 L p
1 g
F P
s
P
p
.002 w
.39843 .59025 m .37509 .56925 L .39351 .56799 L p
1 g
F P
s
P
p
.002 w
.64266 .31966 m .5882 .27859 L .59326 .26653 L p
1 g
F P
s
P
p
.002 w
.66206 .48428 m .65739 .53357 L .63585 .54731 L p
1 g
F P
s
P
p
.002 w
.65739 .53357 m .66206 .48428 L .67911 .46549 L p
1 g
F P
s
P
p
.002 w
.4295 .59327 m .45096 .59892 L .45774 .61373 L p
1 g
F P
s
P
p
.002 w
.48803 .61389 m .45774 .61373 L .45096 .59892 L p
1 g
F P
s
P
p
.002 w
.34196 .41276 m .32146 .44539 L .31223 .4212 L p
1 g
F P
s
P
p
.002 w
.31223 .4212 m .33505 .38391 L .34196 .41276 L p
1 g
F P
s
P
p
.002 w
.4387 .28765 m .38018 .30211 L .38832 .28089 L p
1 g
F P
s
P
p
.002 w
.38832 .28089 m .44767 .26583 L .4387 .28765 L p
1 g
F P
s
P
p
.002 w
.38263 .55084 m .39351 .56799 L .37509 .56925 L p
1 g
F P
s
P
p
.002 w
.37509 .56925 m .35923 .54452 L .38263 .55084 L p
1 g
F P
s
P
p
.002 w
.48803 .61389 m .51475 .60586 L .53807 .61299 L p
1 g
F P
s
P
p
.002 w
.56436 .59312 m .53807 .61299 L .51475 .60586 L p
1 g
F P
s
P
p
.002 w
.53807 .61299 m .56436 .59312 L .59105 .59126 L p
1 g
F P
s
P
p
.002 w
.51459 .27075 m .44767 .26583 L .45786 .24953 L p
1 g
F P
s
P
p
.002 w
.45786 .24953 m .52368 .25416 L .51459 .27075 L p
1 g
F P
s
P
p
.002 w
.60967 .55798 m .59105 .59126 L .56436 .59312 L p
1 g
F P
s
P
p
.002 w
.59105 .59126 m .60967 .55798 L .63585 .54731 L p
1 g
F P
s
P
p
.002 w
.45096 .59892 m .47195 .59896 L .48803 .61389 L p
1 g
F P
s
P
p
.002 w
.51475 .60586 m .48803 .61389 L .47195 .59896 L p
1 g
F P
s
P
p
.002 w
.35628 .49362 m .35262 .51842 L .33193 .50178 L p
1 g
F P
s
P
p
.002 w
.33193 .50178 m .33625 .46981 L .35628 .49362 L p
1 g
F P
s
P
p
.002 w
.66248 .41028 m .67911 .46549 L .66206 .48428 L p
1 g
F P
s
P
p
.002 w
.67911 .46549 m .66248 .41028 L .67393 .39001 L p
1 g
F P
s
P
p
.002 w
.37417 .35737 m .33505 .38391 L .33312 .35716 L p
1 g
F P
s
P
p
.002 w
.33312 .35716 m .37536 .32784 L .37417 .35737 L p
1 g
F P
s
P
p
.002 w
.37826 .53287 m .38263 .55084 L .35923 .54452 L p
1 g
F P
s
P
p
.002 w
.35923 .54452 m .35262 .51842 L .37826 .53287 L p
1 g
F P
s
P
p
.002 w
.67393 .39001 m .63582 .3374 L .64266 .31966 L p
1 g
F P
s
P
p
.002 w
.5882 .27859 m .64266 .31966 L .63582 .3374 L p
1 g
F P
s
P
p
.002 w
.35378 .44275 m .33625 .46981 L .32146 .44539 L p
1 g
F P
s
P
p
.002 w
.32146 .44539 m .34196 .41276 L .35378 .44275 L p
1 g
F P
s
P
p
.002 w
.63967 .50199 m .63585 .54731 L .60967 .55798 L p
1 g
F P
s
P
p
.002 w
.63585 .54731 m .63967 .50199 L .66206 .48428 L p
1 g
F P
s
P
p
.004 w
.64647 .53276 m
.6586 .54123 L
s
P
p
.004 w
.6586 .54123 m
.67884 .55536 L
s
P
p
.002 w
.63582 .3374 m .67393 .39001 L .66248 .41028 L p
1 g
F P
s
P
p
.002 w
.58029 .29568 m .51459 .27075 L .52368 .25416 L p
1 g
F P
s
P
p
.002 w
.52368 .25416 m .5882 .27859 L .58029 .29568 L p
1 g
F P
s
P
p
.002 w
.42409 .57012 m .43432 .57563 L .4295 .59327 L p
1 g
F P
s
P
p
.002 w
.4295 .59327 m .40969 .58261 L .42409 .57012 L p
1 g
F P
s
P
p
.002 w
.45096 .59892 m .4295 .59327 L .43432 .57563 L p
1 g
F P
s
P
p
.002 w
.41578 .56256 m .42409 .57012 L .40969 .58261 L p
1 g
F P
s
P
p
.002 w
.40969 .58261 m .39351 .56799 L .41578 .56256 L p
1 g
F P
s
P
p
.002 w
.47195 .59896 m .4903 .59329 L .51475 .60586 L p
1 g
F P
s
P
p
.002 w
.53506 .59018 m .51475 .60586 L .4903 .59329 L p
1 g
F P
s
P
p
.002 w
.51475 .60586 m .53506 .59018 L .56436 .59312 L p
1 g
F P
s
P
p
.002 w
.63582 .3374 m .58029 .29568 L .5882 .27859 L p
1 g
F P
s
P
p
.002 w
.43131 .31447 m .37536 .32784 L .38018 .30211 L p
1 g
F P
s
P
p
.002 w
.38018 .30211 m .4387 .28765 L .43131 .31447 L p
1 g
F P
s
P
p
.002 w
.43432 .57563 m .4454 .57852 L .45096 .59892 L p
1 g
F P
s
P
p
.002 w
.47195 .59896 m .45096 .59892 L .4454 .57852 L p
1 g
F P
s
P
p
.002 w
.57959 .56507 m .56436 .59312 L .53506 .59018 L p
1 g
F P
s
P
p
.002 w
.56436 .59312 m .57959 .56507 L .60967 .55798 L p
1 g
F P
s
P
p
.002 w
.41026 .55372 m .41578 .56256 L .39351 .56799 L p
1 g
F P
s
P
p
.002 w
.39351 .56799 m .38263 .55084 L .41026 .55372 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50474 .29277 m .4387 .28765 L .44767 .26583 L p
1 g
F P
s
P
p
.002 w
.44767 .26583 m .51459 .27075 L .50474 .29277 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.38103 .51595 m .37826 .53287 L .35262 .51842 L p
1 g
F P
s
P
p
.002 w
.35262 .51842 m .35628 .49362 L .38103 .51595 L p
1 g
F P
s
P
p
.002 w
.3768 .38978 m .34196 .41276 L .33505 .38391 L p
1 g
F P
s
P
p
.002 w
.33505 .38391 m .37417 .35737 L .3768 .38978 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.4454 .57852 m .45618 .57848 L .47195 .59896 L p
1 g
F P
s
P
p
.002 w
.4903 .59329 m .47195 .59896 L .45618 .57848 L p
1 g
F P
s
P
p
.002 w
.64576 .43179 m .66206 .48428 L .63967 .50199 L p
1 g
F P
s
P
p
.002 w
.66206 .48428 m .64576 .43179 L .66248 .41028 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45438 .52567 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37025 .47285 m .35628 .49362 L .33625 .46981 L p
1 g
F P
s
P
p
.002 w
.33625 .46981 m .35378 .44275 L .37025 .47285 L p
1 g
F P
s
P
p
.002 w
.61253 .51796 m .60967 .55798 L .57959 .56507 L p
1 g
F P
s
P
p
.002 w
.60967 .55798 m .61253 .51796 L .63967 .50199 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.61944 .51389 L
s
P
p
.004 w
.6323 .52287 m
.64647 .53276 L
s
P
p
.004 w
.63126 .52215 m
.6323 .52287 L
s
P
p
.002 w
.40815 .54454 m .41026 .55372 L .38263 .55084 L p
1 g
F P
s
P
p
.002 w
.38263 .55084 m .37826 .53287 L .40815 .54454 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.66248 .41028 m .62462 .35858 L .63582 .3374 L p
1 g
F P
s
P
p
.002 w
.58029 .29568 m .63582 .3374 L .62462 .35858 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62462 .35858 m .66248 .41028 L .64576 .43179 L p
1 g
F P
s
P
p
.002 w
.4903 .59329 m .50406 .58238 L .53506 .59018 L p
1 g
F P
s
P
p
.50812 .58102 m .50905 .58134 L .50406 .58238 L 1 g
F
P
p
.002 w
.53506 .59018 m .50497 .5826 L p
.50905 .58134 L 1 g
F P
s
P
p
.002 w
.50497 .5826 m .50406 .58238 L p
.50905 .58134 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58075 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58075 L .52239 .57721 L 1 g
F
P
p
.002 w
.51095 .58075 m .51079 .57862 L p
.49835 .58111 L 1 g
F P
s
P
p
.002 w
.4903 .59329 m .4712 .57957 L p
.49191 .58134 L 1 g
F P
s
P
p
.002 w
.50406 .58238 m .50199 .58402 L p
.49191 .58134 L 1 g
F P
s
P
p
.002 w
.50199 .58402 m .4903 .59329 L p
.49191 .58134 L 1 g
F P
s
P
p
.002 w
.48906 .58058 m .48921 .57862 L p
.47832 .57773 L 1 g
F P
s
P
p
.002 w
.45618 .57848 m .44479 .55892 L p
.45238 .56499 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44275 .55372 m .44131 .55294 L .44231 .5532 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4383 .54744 L p
1 g
F P
s
P
p
.002 w
.44085 .55118 m .44131 .55294 L .43881 .54904 L p
1 g
F P
s
P
p
.002 w
.43881 .54904 m .4289 .5336 L p
.4383 .54744 L 1 g
F P
s
P
p
.4383 .54744 m .44085 .55118 L .43881 .54904 L 1 g
F
P
p
.002 w
.4383 .54744 m .43925 .54566 L p
.43525 .53775 L 1 g
F P
s
P
p
.45146 .56129 m .4383 .54744 L .43841 .54759 L 1 g
F
P
p
.45146 .56129 m .43829 .54747 L .43852 .54781 L 1 g
F
P
p
.45146 .56129 m .43826 .54753 L .43861 .54804 L 1 g
F
P
p
.45146 .56129 m .43821 .54762 L .43867 .54826 L 1 g
F
P
p
.002 w
.44142 .55201 m .44131 .55294 L .44085 .55118 L p
1 g
F P
s
P
p
.45146 .56129 m .43815 .54773 L .44195 .55275 L 1 g
F
P
p
.45146 .56129 m .44195 .55275 L .44203 .55285 L 1 g
F
P
p
.45146 .56129 m .44202 .55284 L .4427 .55368 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.47244 .54375 m .47614 .55307 L .4421 .55294 L p
1 g
F P
s
P
p
.002 w
.4421 .55294 m .44131 .55294 L .44195 .55275 L p
1 g
F P
s
P
p
.002 w
.44195 .55275 m .47244 .54375 L p
.4421 .55294 L 1 g
F P
s
P
p
.44203 .55285 m .44195 .55275 L .44202 .55284 L 1 g
F
P
p
.4427 .55368 m .44202 .55284 L .44256 .55356 L 1 g
F
P
p
.002 w
.47614 .55307 m .47612 .5621 L .44231 .5532 L p
1 g
F P
s
P
p
.002 w
.44231 .5532 m .44131 .55294 L .4421 .55294 L p
1 g
F P
s
P
p
.002 w
.4421 .55294 m .47614 .55307 L p
.44231 .5532 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52883 L p
1 g
F P
s
P
p
.43925 .54566 m .43244 .52883 L .43525 .53775 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.42296 .52434 m .43061 .52304 L p
.43244 .52883 L 1 g
F P
s
P
p
.42296 .52434 m .43244 .52883 L .43212 .53808 L 1 g
F
P
p
.002 w
.43244 .52883 m .43346 .52734 L p
.43312 .51771 L 1 g
F P
s
P
p
.43312 .51771 m .43309 .51809 L .43244 .52883 L 1 g
F
P
p
.42717 .48882 m .43451 .50358 L .43395 .50933 L 1 g
F
P
p
.002 w
.43287 .5203 m .43173 .51399 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43173 .51399 m .42717 .48882 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43824 .50034 L 1 g
F P
s
P
p
.43309 .51809 m .43265 .52269 L .43244 .52883 L 1 g
F
P
p
.43312 .51755 m .43287 .5203 L .43309 .51809 L 1 g
F
P
p
.43287 .5203 m .43265 .52269 L .43309 .51809 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43308 .51037 L p
1 g
F P
s
P
p
.43346 .52734 m .43308 .51037 L .43297 .51342 L 1 g
F
P
p
.43244 .52883 m .43328 .52259 L .43826 .5473 L 1 g
F
P
p
.002 w
.43061 .52304 m .43265 .52269 L p
.43244 .52883 L 1 g
F P
s
P
p
.002 w
.43265 .52269 m .43328 .52259 L p
.43244 .52883 L 1 g
F P
s
P
p
.002 w
.43308 .51037 m .43287 .51061 L p
.43297 .51342 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44246 .49149 L p
1 g
F P
s
P
p
.43485 .50826 m .44246 .49149 L .43824 .50034 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44978 .49141 m .44465 .52396 L p
.43303 .50059 L 1 g
F P
s
P
p
.002 w
.44246 .49149 m .44339 .4905 L p
.45086 .48335 L 1 g
F P
s
P
p
.002 w
.44978 .49141 m .44331 .49067 L p
.44689 .4872 L 1 g
F P
s
P
p
.45086 .48335 m .44331 .49067 L .44246 .49149 L 1 g
F
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45146 .48276 m .44978 .49141 L p
.44689 .4872 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45772 .47667 L p
1 g
F P
s
P
p
.002 w
.47195 .50007 m .44978 .49141 L .45146 .48276 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45772 .47667 m .47195 .50007 L .45146 .48276 L 1 g
F
P
p
.002 w
.45772 .47667 m .45826 .47608 L p
.46663 .47241 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47755 .46719 L p
1 g
F P
s
P
p
.45826 .47608 m .47755 .46719 L .46663 .47241 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48929 .46917 m .47195 .50007 L p
.46111 .46932 L 1 g
F P
s
P
p
.002 w
.47755 .46719 m .47786 .46667 L p
.49088 .46535 L 1 g
F P
s
P
p
.49088 .46535 m .48963 .46553 L .47755 .46719 L 1 g
F
P
p
.002 w
.48929 .46917 m .48254 .46654 L p
.4876 .46582 L 1 g
F P
s
P
p
.002 w
.49143 .46527 m .48929 .46917 L p
.4876 .46582 L 1 g
F P
s
P
p
.49109 .46532 m .48819 .46581 L .48254 .46654 L 1 g
F
P
p
.48963 .46553 m .48254 .46654 L .47755 .46719 L 1 g
F
P
p
.49109 .46532 m .48254 .46654 L .48963 .46553 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5174 .48948 m .48929 .46917 L .49143 .46527 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46382 m .5174 .48948 L .49143 .46527 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52236 .46705 L p
1 g
F P
s
P
p
.5 .4634 m .52236 .46705 L .50871 .46508 L 1 g
F
P
p
.51275 .46566 m .5174 .48948 L .5 .46382 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47661 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56589 .50914 L p
1 g
F P
s
P
p
.56909 .49616 m .57693 .53296 L .56589 .50914 L 1 g
F
P
p
.56551 .50381 m .56589 .50914 L .56446 .50605 L 1 g
F
P
p
.56909 .49616 m .56589 .50914 L .56551 .50381 L 1 g
F
P
p
.002 w
.56589 .50914 m .56515 .50826 L p
.56642 .51651 L 1 g
F P
s
P
p
.55661 .4905 m .56589 .50914 L .56332 .50359 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56728 .52842 L p
1 g
F P
s
P
p
.56589 .50914 m .57002 .51805 L .56678 .52153 L 1 g
F
P
p
.002 w
.57693 .53296 m .5651 .53667 L p
.57002 .51805 L 1 g
F P
s
P
p
.56515 .50826 m .56728 .52842 L .56642 .51651 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56138 .54685 L p
1 g
F P
s
P
p
.58147 .53153 m .55796 .55623 L .56138 .54685 L 1 g
F
P
p
.002 w
.5651 .53667 m .5701 .5351 L p
.56138 .54685 L 1 g
F P
s
P
p
.002 w
.5701 .5351 m .58147 .53153 L p
.56138 .54685 L 1 g
F P
s
P
p
.002 w
.56138 .54685 m .56075 .54566 L p
.55637 .55361 L 1 g
F P
s
P
p
.56654 .52734 m .56138 .54685 L .56372 .54045 L 1 g
F
P
p
.56654 .52734 m .56206 .54814 L .56425 .53987 L 1 g
F
P
p
.55796 .55623 m .54654 .56823 L .54973 .5628 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .5632 L p
1 g
F P
s
P
p
.55806 .55596 m .54973 .5628 L .55044 .56159 L 1 g
F
P
p
.55806 .55596 m .55044 .56159 L .56138 .54685 L 1 g
F
P
p
.55796 .55623 m .54973 .5628 L .55806 .55596 L 1 g
F
P
p
.56075 .54566 m .54925 .5632 L .55637 .55361 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.53732 .57259 m .54151 .57783 L .52236 .57966 L 1 g
F
P
p
.002 w
.53165 .57434 m .53128 .57265 L p
.52239 .57721 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53165 .57434 L p
1 g
F P
s
P
p
.54854 .56129 m .53165 .57434 L .53966 .56976 L 1 g
F
P
p
.49835 .58111 m .50128 .58127 L .51095 .58075 L 1 g
F
P
p
.002 w
.50457 .58136 m .50406 .58238 L .50128 .58127 L p
1 g
F P
s
P
p
.50128 .58127 m .50393 .58142 L .50457 .58136 L 1 g
F
P
p
.50128 .58127 m .50457 .58136 L .51095 .58075 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.50406 .58238 m .4712 .57957 L .49631 .58099 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58058 L p
1 g
F P
s
P
p
.002 w
.50128 .58127 m .50406 .58238 L p
.49631 .58099 L 1 g
F P
s
P
p
.002 w
.48906 .58058 m .48889 .583 L p
.49835 .58111 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58058 L .49835 .58111 L 1 g
F
P
p
.002 w
.4682 .57504 m .46872 .57265 L p
.46005 .56959 L 1 g
F P
s
P
p
.002 w
.46691 .57436 m .46553 .57549 L .45667 .56724 L p
1 g
F P
s
P
p
.002 w
.46553 .57549 m .46227 .57653 L p
.45238 .56499 L 1 g
F P
s
P
p
.002 w
.46227 .57653 m .45618 .57848 L p
.45238 .56499 L 1 g
F P
s
P
p
.002 w
.45667 .56724 m .46553 .57549 L p
.44479 .55892 L 1 g
F P
s
P
p
.46005 .56959 m .4529 .56707 L .46691 .57436 L 1 g
F
P
p
.46005 .56959 m .46691 .57436 L .4682 .57504 L 1 g
F
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44274 .55372 L 1 g
F P
s
P
p
.44274 .55372 m .44504 .55641 L .45078 .56312 L 1 g
F
P
p
.46872 .57265 m .45863 .56862 L .45999 .56957 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4682 .57504 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.47243 .56984 m .46691 .57436 L p
.44504 .55641 L 1 g
F P
s
P
p
.002 w
.45667 .56724 m .44504 .55641 L p
.46691 .57436 L 1 g
F P
s
P
p
.48921 .57862 m .4682 .57504 L .47832 .57773 L 1 g
F
P
p
.002 w
.46553 .57549 m .46691 .57436 L p
.47067 .57633 L 1 g
F P
s
P
p
.49631 .58099 m .46553 .57549 L .50128 .58127 L 1 g
F
P
p
.002 w
.4712 .57957 m .46553 .57549 L p
.47093 .57646 L 1 g
F P
s
P
p
.002 w
.45618 .57848 m .46553 .57549 L .4903 .59329 L p
1 g
F P
s
P
p
.002 w
.45618 .57848 m .4454 .57852 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .4529 .56707 L p
.44856 .56909 L 1 g
F P
s
P
p
.002 w
.4529 .56707 m .45002 .56518 L .44989 .56551 L p
1 g
F P
s
P
p
.002 w
.44989 .56551 m .44856 .56909 L p
.4529 .56707 L 1 g
F P
s
P
p
.002 w
.47243 .56984 m .50128 .58127 L p
.47067 .57633 L 1 g
F P
s
P
p
.002 w
.46691 .57436 m .47243 .56984 L p
.47067 .57633 L 1 g
F P
s
P
p
.002 w
.51163 .56725 m .50457 .58136 L p
.47243 .56984 L 1 g
F P
s
P
p
.002 w
.50128 .58127 m .47243 .56984 L p
.50457 .58136 L 1 g
F P
s
P
p
.53647 .57158 m .52236 .57966 L .50812 .58102 L 1 g
F
P
p
.54654 .56823 m .52236 .57966 L .53647 .57158 L 1 g
F
P
p
.002 w
.54151 .57783 m .53506 .59018 L p
.50812 .58102 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53165 .57434 L p
1 g
F P
s
P
p
.52239 .57721 m .51111 .583 L .53165 .57434 L 1 g
F
P
p
.002 w
.54654 .56823 m .5456 .57003 L p
.53732 .57259 L 1 g
F P
s
P
p
.002 w
.5456 .57003 m .54151 .57783 L p
.53732 .57259 L 1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.54755 .54218 m .5651 .53667 L p
.54973 .5628 L 1 g
F P
s
P
p
.002 w
.54654 .56823 m .54665 .56533 L p
.54973 .5628 L 1 g
F P
s
P
p
.54854 .56129 m .53966 .56976 L .54252 .56812 L 1 g
F
P
p
.002 w
.54665 .56533 m .54654 .56823 L .54252 .56812 L p
1 g
F P
s
P
p
.54525 .56628 m .54252 .56812 L .54496 .56672 L 1 g
F
P
p
.54854 .56129 m .54252 .56812 L .54525 .56628 L 1 g
F
P
p
.002 w
.54925 .5632 m .54854 .56129 L p
.54496 .56672 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54755 .54218 m .54665 .56533 L p
.51163 .56725 L 1 g
F P
s
P
p
.002 w
.54252 .56812 m .51163 .56725 L p
.54665 .56533 L 1 g
F P
s
P
p
.002 w
.54665 .56533 m .54755 .54218 L p
.54973 .5628 L 1 g
F P
s
P
p
.002 w
.54958 .56408 m .54925 .5632 L p
.54496 .56672 L 1 g
F P
s
P
p
.002 w
.50406 .58238 m .51163 .56725 L .54252 .56812 L p
1 g
F P
s
P
p
.002 w
.54252 .56812 m .54654 .56823 L p
.53647 .57158 L 1 g
F P
s
P
p
.53647 .57158 m .50406 .58238 L .54252 .56812 L 1 g
F
P
p
.002 w
.57959 .56507 m .54654 .56823 L p
.55877 .55537 L 1 g
F P
s
P
p
.002 w
.58147 .53153 m .58116 .53699 L p
.55877 .55537 L 1 g
F P
s
P
p
.002 w
.58116 .53699 m .57959 .56507 L p
.55877 .55537 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .54958 .56408 L p
.53613 .57397 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53424 .57552 L p
.53613 .57397 L 1 g
F P
s
P
p
.002 w
.53424 .57552 m .54998 .56518 L p
.53613 .57397 L 1 g
F P
s
P
p
.53966 .56976 m .5322 .57686 L .54958 .56408 L 1 g
F
P
p
.002 w
.53165 .57434 m .5322 .57686 L p
.53966 .56976 L 1 g
F P
s
P
p
.002 w
.54925 .5632 m .54998 .56518 L p
.55637 .55361 L 1 g
F P
s
P
p
.56138 .54685 m .55044 .56159 L .5651 .53667 L 1 g
F
P
p
.002 w
.53506 .59018 m .54654 .56823 L .57959 .56507 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .53424 .57552 L p
.53313 .58109 L 1 g
F P
s
P
p
.002 w
.53424 .57552 m .5322 .57686 L .53227 .57714 L p
1 g
F P
s
P
p
.002 w
.53227 .57714 m .53313 .58109 L p
.53424 .57552 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56138 .54685 L p
1 g
F P
s
P
p
.55637 .55361 m .54998 .56518 L .56138 .54685 L 1 g
F
P
p
.002 w
.56138 .54685 m .56206 .54814 L p
.56372 .54045 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5651 .53667 m .54755 .54218 L p
.57002 .51805 L 1 g
F P
s
P
p
.002 w
.56728 .52842 m .56854 .53025 L p
.56642 .51651 L 1 g
F P
s
P
p
.56446 .50605 m .56589 .50914 L .54755 .54218 L 1 g
F
P
p
.56589 .50914 m .56678 .52153 L .54755 .54218 L 1 g
F
P
p
.002 w
.56206 .54814 m .56257 .5491 L p
.56425 .53987 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56589 .50914 L p
1 g
F P
s
P
p
.56642 .51651 m .56854 .53025 L .56589 .50914 L 1 g
F
P
p
.55661 .4905 m .56332 .50359 L .56228 .50135 L 1 g
F
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.56186 .50045 m .56909 .49616 L p
.56446 .50605 L 1 g
F P
s
P
p
.002 w
.56909 .49616 m .56186 .50045 L p
.55448 .48558 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54755 .54218 m .53756 .51486 L .56186 .50045 L p
1 g
F P
s
P
p
.56446 .50605 m .54755 .54218 L .56186 .50045 L 1 g
F
P
p
.56228 .50135 m .5666 .50998 L .56287 .50248 L 1 g
F
P
p
.56332 .50359 m .5666 .50998 L .56228 .50135 L 1 g
F
P
p
.002 w
.56589 .50914 m .5666 .50998 L p
.56332 .50359 L 1 g
F P
s
P
p
.002 w
.56909 .49616 m .58147 .53153 L .57693 .53296 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55728 .49121 L p
1 g
F P
s
P
p
.5426 .47698 m .5534 .48745 L .53756 .51486 L 1 g
F
P
p
.54174 .47608 m .55728 .49121 L .54814 .48235 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56186 .50045 m .53756 .51486 L p
.55448 .48558 L 1 g
F P
s
P
p
.002 w
.55728 .49121 m .55834 .49233 L p
.54814 .48235 L 1 g
F P
s
P
p
.54187 .47645 m .5426 .47698 L .53756 .51486 L 1 g
F
P
p
.002 w
.54223 .47661 m .54174 .47608 L p
.54814 .48235 L 1 g
F P
s
P
p
.002 w
.56048 .48512 m .56909 .49616 L p
.54187 .47645 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54223 .47661 L p
1 g
F P
s
P
p
.54814 .48235 m .55834 .49233 L .54223 .47661 L 1 g
F
P
p
.002 w
.54336 .46318 m .56048 .48512 L p
.54223 .47661 L 1 g
F P
s
P
p
.54189 .47629 m .54223 .47661 L .54187 .47645 L 1 g
F
P
p
.54336 .46318 m .54223 .47661 L .54189 .47629 L 1 g
F
P
p
.5426 .47698 m .55448 .48558 L .5534 .48745 L 1 g
F
P
p
.002 w
.5666 .50998 m .56713 .51061 L p
.56287 .50248 L 1 g
F P
s
P
p
.52214 .46667 m .54223 .47661 L .53675 .47406 L 1 g
F
P
p
.002 w
.53756 .51486 m .5174 .48948 L .53392 .47274 L p
1 g
F P
s
P
p
.54187 .47645 m .53756 .51486 L .53392 .47274 L 1 g
F
P
p
.52214 .46667 m .5426 .47701 L .53276 .47217 L 1 g
F
P
p
.002 w
.53392 .47274 m .54336 .46318 L p
.54187 .47645 L 1 g
F P
s
P
p
.002 w
.53392 .47274 m .5174 .48948 L p
.51202 .46195 L 1 g
F P
s
P
p
.002 w
.5426 .47701 m .54302 .47747 L p
.53336 .47248 L 1 g
F P
s
P
p
.53276 .47217 m .53392 .47274 L .53336 .47248 L 1 g
F
P
p
.53392 .47274 m .5426 .47701 L .53336 .47248 L 1 g
F
P
p
.002 w
.54223 .47661 m .5426 .47701 L p
.53675 .47406 L 1 g
F P
s
P
p
.002 w
.5071 .43679 m .54336 .46318 L .53392 .47274 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.5071 .43679 m .53392 .47274 L .51202 .46195 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .4634 L p
.50871 .46508 L 1 g
F P
s
P
p
.50871 .46508 m .52282 .46778 L .5 .46382 L 1 g
F
P
p
.5071 .43679 m .51199 .46179 L .5 .46382 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .46442 L p
.49109 .46532 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .49109 .46532 L 1 g
F
P
p
.002 w
.49143 .46527 m .4928 .46278 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.4928 .46278 m .5071 .43679 L p
.5 .46382 L 1 g
F P
s
P
p
.51199 .46179 m .51275 .46566 L .5 .46382 L 1 g
F
P
p
.002 w
.52236 .46705 m .52282 .46778 L p
.50871 .46508 L 1 g
F P
s
P
p
.002 w
.46477 .4204 m .5071 .43679 L .49143 .46527 L p
1 g
F P
s
P
p
.46477 .4204 m .49143 .46527 L .4876 .46582 L 1 g
F
P
p
.002 w
.45657 .45645 m .46477 .4204 L p
.4876 .46582 L 1 g
F P
s
P
p
.002 w
.48254 .46654 m .45657 .45645 L p
.4876 .46582 L 1 g
F P
s
P
p
.49088 .46535 m .49109 .46532 L .48963 .46553 L 1 g
F
P
p
.49109 .46532 m .49523 .4649 L .48819 .46581 L 1 g
F
P
p
.002 w
.45657 .45645 m .48254 .46654 L p
.46111 .46932 L 1 g
F P
s
P
p
.002 w
.48254 .46654 m .48929 .46917 L p
.46111 .46932 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47755 .46719 L p
1 g
F P
s
P
p
.49523 .4649 m .5 .46442 L .47755 .46719 L 1 g
F
P
p
.002 w
.47755 .46719 m .47718 .46778 L p
.46663 .47241 L 1 g
F P
s
P
p
.45657 .45645 m .46217 .47234 L .45772 .47667 L 1 g
F
P
p
.44339 .4905 m .45772 .47667 L .45098 .48323 L 1 g
F
P
p
.002 w
.45146 .48276 m .45212 .47934 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.45212 .47934 m .45657 .45645 L p
.45772 .47667 L 1 g
F P
s
P
p
.46217 .47234 m .46284 .47422 L .45772 .47667 L 1 g
F
P
p
.46284 .47422 m .47195 .50007 L .45772 .47667 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45772 .47667 L p
1 g
F P
s
P
p
.46663 .47241 m .47718 .46778 L .45772 .47667 L 1 g
F
P
p
.002 w
.45772 .47667 m .45698 .47747 L p
.45098 .48323 L 1 g
F P
s
P
p
.002 w
.42326 .45284 m .45657 .45645 L .45146 .48276 L p
1 g
F P
s
P
p
.42326 .45284 m .45146 .48276 L .44689 .4872 L 1 g
F
P
p
.002 w
.44331 .49067 m .44978 .49141 L p
.43303 .50059 L 1 g
F P
s
P
p
.002 w
.44246 .49149 m .44166 .49233 L p
.43824 .50034 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44241 .49154 L p
1 g
F P
s
P
p
.002 w
.44241 .49154 m .44246 .49149 L p
.4433 .49068 L 1 g
F P
s
P
p
.4433 .49068 m .45698 .47747 L .44241 .49154 L 1 g
F
P
p
.45086 .48335 m .4568 .47765 L .44331 .49067 L 1 g
F
P
p
.002 w
.42717 .48882 m .42326 .45284 L p
.44689 .4872 L 1 g
F P
s
P
p
.002 w
.44331 .49067 m .42717 .48882 L p
.44689 .4872 L 1 g
F P
s
P
p
.002 w
.42717 .48882 m .44331 .49067 L p
.43303 .50059 L 1 g
F P
s
P
p
.4568 .47765 m .45698 .47747 L .44246 .49149 L 1 g
F
P
p
.43395 .50933 m .44465 .52396 L .43287 .5203 L 1 g
F
P
p
.43451 .50358 m .43563 .50582 L .43395 .50933 L 1 g
F
P
p
.43563 .50582 m .44465 .52396 L .43395 .50933 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43824 .50034 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.002 w
.44465 .52396 m .43328 .52259 L .43287 .5203 L p
1 g
F P
s
P
p
.43312 .51771 m .43312 .51755 L .43309 .51809 L 1 g
F
P
p
.002 w
.42296 .52434 m .40676 .49251 L p
.43272 .52195 L 1 g
F P
s
P
p
.002 w
.43265 .52269 m .42296 .52434 L p
.43272 .52195 L 1 g
F P
s
P
p
.002 w
.40676 .49251 m .42717 .48882 L .43287 .5203 L p
1 g
F P
s
P
p
.002 w
.43287 .5203 m .43328 .52259 L p
.43272 .52195 L 1 g
F P
s
P
p
.40676 .49251 m .43287 .5203 L .43272 .52195 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43204 .52941 L p
1 g
F P
s
P
p
.002 w
.43204 .52941 m .43244 .52883 L p
.43256 .52368 L 1 g
F P
s
P
p
.43256 .52368 m .43287 .51061 L .43204 .52941 L 1 g
F
P
p
.43312 .51755 m .43297 .51342 L .43265 .52269 L 1 g
F
P
p
.002 w
.43328 .52259 m .43265 .52269 L p
.43272 .52195 L 1 g
F P
s
P
p
.43297 .51342 m .43287 .51061 L .43244 .52883 L 1 g
F
P
p
.43212 .53808 m .43244 .52883 L .43826 .5473 L 1 g
F
P
p
.002 w
.43328 .52259 m .44085 .55118 L p
.43826 .5473 L 1 g
F P
s
P
p
.002 w
.43244 .52883 m .43146 .53025 L p
.43525 .53775 L 1 g
F P
s
P
p
.002 w
.4289 .5336 m .42296 .52434 L p
.44085 .55118 L 1 g
F P
s
P
p
.002 w
.41481 .52898 m .42271 .52448 L p
.43881 .54904 L 1 g
F P
s
P
p
.002 w
.4289 .5336 m .43881 .54904 L p
.42271 .52448 L 1 g
F P
s
P
p
.002 w
.43881 .54904 m .44131 .55294 L .43955 .55134 L p
1 g
F P
s
P
p
.002 w
.43955 .55134 m .41481 .52898 L p
.43881 .54904 L 1 g
F P
s
P
p
.002 w
.44166 .55235 m .44131 .55294 L .44142 .55201 L p
1 g
F P
s
P
p
.002 w
.44181 .55257 m .44131 .55294 L .44166 .55235 L p
1 g
F P
s
P
p
.002 w
.44195 .55275 m .44131 .55294 L .44181 .55257 L p
1 g
F P
s
P
p
.002 w
.43815 .54773 m .43743 .5491 L p
.44227 .55331 L 1 g
F P
s
P
p
.44256 .55356 m .44141 .55203 L .44227 .55331 L 1 g
F
P
p
.44141 .55203 m .43815 .54773 L .44227 .55331 L 1 g
F
P
p
.002 w
.42271 .52448 m .42296 .52434 L .4289 .5336 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.002 w
.4383 .54745 m .4383 .54744 L p
.43827 .54735 L 1 g
F P
s
P
p
.43827 .54735 m .43146 .53025 L .4383 .54745 L 1 g
F
P
p
.43525 .53775 m .43146 .53025 L .4383 .54744 L 1 g
F
P
p
.002 w
.4383 .54744 m .43829 .54747 L p
.43841 .54759 L 1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43328 .52259 m .44465 .52396 L .44142 .55201 L p
1 g
F P
s
P
p
.002 w
.44085 .55118 m .43328 .52259 L p
.44142 .55201 L 1 g
F P
s
P
p
.002 w
.43829 .54747 m .43826 .54753 L p
.43852 .54781 L 1 g
F P
s
P
p
.002 w
.43826 .54753 m .43821 .54762 L p
.43861 .54804 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44465 .52396 m .45577 .52832 L .44166 .55235 L p
1 g
F P
s
P
p
.002 w
.44142 .55201 m .44465 .52396 L p
.44166 .55235 L 1 g
F P
s
P
p
.002 w
.45577 .52832 m .4654 .53518 L .44181 .55257 L p
1 g
F P
s
P
p
.002 w
.44166 .55235 m .45577 .52832 L p
.44181 .55257 L 1 g
F P
s
P
p
.002 w
.43821 .54762 m .43815 .54773 L p
.43867 .54826 L 1 g
F P
s
P
p
.002 w
.4654 .53518 m .47244 .54375 L .44195 .55275 L p
1 g
F P
s
P
p
.002 w
.44181 .55257 m .4654 .53518 L p
.44195 .55275 L 1 g
F P
s
P
p
.002 w
.47612 .5621 m .47243 .56984 L .44275 .55372 L p
1 g
F P
s
P
p
.002 w
.44231 .5532 m .47612 .5621 L p
.44275 .55372 L 1 g
F P
s
P
p
.002 w
.44504 .55641 m .44131 .55294 L .44275 .55372 L p
1 g
F P
s
P
p
.44274 .55372 m .4427 .55368 L .44504 .55641 L 1 g
F
P
p
.002 w
.44275 .55372 m .47243 .56984 L p
.44504 .55641 L 1 g
F P
s
P
p
.002 w
.44479 .55892 m .44131 .55294 L .45667 .56724 L p
1 g
F P
s
P
p
.002 w
.43432 .57563 m .42409 .57012 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.4454 .57852 m .43432 .57563 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.42409 .57012 m .41578 .56256 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.41578 .56256 m .41026 .55372 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.41026 .55372 m .40815 .54454 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.40815 .54454 m .4097 .53598 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.4097 .53598 m .41481 .52898 L .44131 .55294 L closepath p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.4427 .55368 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.002 w
.45002 .56518 m .4529 .56707 L p
.45999 .56957 L 1 g
F P
s
P
p
.45863 .56862 m .45002 .56518 L .45999 .56957 L 1 g
F
P
p
.002 w
.4529 .56707 m .4678 .57686 L .4682 .57504 L p
1 g
F P
s
P
p
.47892 .57789 m .47522 .57869 L .47093 .57646 L 1 g
F
P
p
.47522 .57869 m .4712 .57957 L .47093 .57646 L 1 g
F
P
p
.49631 .58099 m .48906 .58058 L .47892 .57789 L 1 g
F
P
p
.48906 .58058 m .4712 .57957 L .47892 .57789 L 1 g
F
P
p
.002 w
.4682 .57504 m .4678 .57686 L p
.47832 .57773 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .58058 L p
1 g
F P
s
P
p
.47832 .57773 m .4678 .57686 L .48906 .58058 L 1 g
F
P
p
.49835 .58111 m .49021 .58273 L .50393 .58142 L 1 g
F
P
p
.002 w
.51095 .58075 m .51111 .583 L p
.52239 .57721 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58075 L p
1 g
F P
s
P
p
.49021 .58273 m .48889 .583 L .51095 .58075 L 1 g
F
P
p
.002 w
.42586 .34554 m .37417 .35737 L .37536 .32784 L p
1 g
F P
s
P
p
.002 w
.37536 .32784 m .43131 .31447 L .42586 .34554 L p
1 g
F P
s
P
p
.002 w
.56966 .31748 m .50474 .29277 L .51459 .27075 L p
1 g
F P
s
P
p
.002 w
.51459 .27075 m .58029 .29568 L .56966 .31748 L p
1 g
F P
s
P
p
.002 w
.4097 .53598 m .40815 .54454 L .37826 .53287 L p
1 g
F P
s
P
p
.002 w
.37826 .53287 m .38103 .51595 L .4097 .53598 L p
1 g
F P
s
P
p
.002 w
.38325 .42395 m .35378 .44275 L .34196 .41276 L p
1 g
F P
s
P
p
.002 w
.34196 .41276 m .3768 .38978 L .38325 .42395 L p
1 g
F P
s
P
p
.002 w
.39083 .50196 m .38103 .51595 L .35628 .49362 L p
1 g
F P
s
P
p
.002 w
.35628 .49362 m .37025 .47285 L .39083 .50196 L p
1 g
F P
s
P
p
.002 w
.62462 .35858 m .56966 .31748 L .58029 .29568 L p
1 g
F P
s
P
p
.002 w
.62416 .45381 m .63967 .50199 L .61253 .51796 L p
1 g
F P
s
P
p
.002 w
.63967 .50199 m .62416 .45381 L .64576 .43179 L p
1 g
F P
s
P
p
.002 w
.57959 .56507 m .58147 .53153 L .61253 .51796 L p
1 g
F P
s
P
p
.002 w
.49445 .31969 m .43131 .31447 L .4387 .28765 L p
1 g
F P
s
P
p
.002 w
.4387 .28765 m .50474 .29277 L .49445 .31969 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39335 .45862 m .37025 .47285 L .35378 .44275 L p
1 g
F P
s
P
p
.002 w
.35378 .44275 m .38325 .42395 L .39335 .45862 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.41481 .52898 m .4097 .53598 L .38103 .51595 L p
1 g
F P
s
P
p
.002 w
.38103 .51595 m .39083 .50196 L .41481 .52898 L p
1 g
F P
s
P
p
.002 w
.60927 .38261 m .64576 .43179 L .62416 .45381 L p
1 g
F P
s
P
p
.002 w
.64576 .43179 m .60927 .38261 L .62462 .35858 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4226 .37981 m .3768 .38978 L .37417 .35737 L p
1 g
F P
s
P
p
.002 w
.37417 .35737 m .42586 .34554 L .4226 .37981 L p
1 g
F P
s
P
p
.002 w
.56966 .31748 m .62462 .35858 L .60927 .38261 L p
1 g
F P
s
P
p
.002 w
.59831 .47554 m .61253 .51796 L .58147 .53153 L p
1 g
F P
s
P
p
.002 w
.61253 .51796 m .59831 .47554 L .62416 .45381 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.47243 .56984 m .47612 .5621 L .51163 .56725 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.55657 .34342 m .49445 .31969 L .50474 .29277 L p
1 g
F P
s
P
p
.002 w
.50474 .29277 m .56966 .31748 L .55657 .34342 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.512 .54945 m .51163 .56725 L .47612 .5621 L p
1 g
F P
s
P
p
.002 w
.51163 .56725 m .512 .54945 L .54755 .54218 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40676 .49251 m .39083 .50196 L .37025 .47285 L p
1 g
F P
s
P
p
.002 w
.37025 .47285 m .39335 .45862 L .40676 .49251 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4841 .35069 m .42586 .34554 L .43131 .31447 L p
1 g
F P
s
P
p
.002 w
.43131 .31447 m .49445 .31969 L .4841 .35069 L p
1 g
F P
s
P
p
.002 w
.47612 .5621 m .47614 .55307 L .512 .54945 L p
1 g
F P
s
P
p
.002 w
.60927 .38261 m .55657 .34342 L .56966 .31748 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42296 .52434 m .41481 .52898 L .39083 .50196 L p
1 g
F P
s
P
p
.002 w
.39083 .50196 m .40676 .49251 L .42296 .52434 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58147 .53153 m .56909 .49616 L .59831 .47554 L p
1 g
F P
s
P
p
.002 w
.42171 .41603 m .38325 .42395 L .3768 .38978 L p
1 g
F P
s
P
p
.002 w
.3768 .38978 m .4226 .37981 L .42171 .41603 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59017 .40869 m .62416 .45381 L .59831 .47554 L p
1 g
F P
s
P
p
.002 w
.62416 .45381 m .59017 .40869 L .60927 .38261 L p
1 g
F P
s
P
p
.002 w
.47614 .55307 m .47244 .54375 L .50493 .53092 L p
1 g
F P
s
P
p
.002 w
.50493 .53092 m .512 .54945 L .47614 .55307 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.53756 .51486 m .54755 .54218 L .512 .54945 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.512 .54945 m .50493 .53092 L .53756 .51486 L p
1 g
F P
s
P
p
.002 w
.55657 .34342 m .60927 .38261 L .59017 .40869 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.42326 .45284 m .39335 .45862 L .38325 .42395 L p
1 g
F P
s
P
p
.002 w
.38325 .42395 m .42171 .41603 L .42326 .45284 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47244 .54375 m .4654 .53518 L .49108 .51378 L p
1 g
F P
s
P
p
.002 w
.49108 .51378 m .50493 .53092 L .47244 .54375 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.47407 .38468 m .4226 .37981 L .42586 .34554 L p
1 g
F P
s
P
p
.002 w
.42586 .34554 m .4841 .35069 L .47407 .38468 L p
1 g
F P
s
P
p
.002 w
.42717 .48882 m .40676 .49251 L .39335 .45862 L p
1 g
F P
s
P
p
.002 w
.5414 .37267 m .4841 .35069 L .49445 .31969 L p
1 g
F P
s
P
p
.002 w
.49445 .31969 m .55657 .34342 L .5414 .37267 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.39335 .45862 m .42326 .45284 L .42717 .48882 L p
1 g
F P
s
P
p
.002 w
.4654 .53518 m .45577 .52832 L .47195 .50007 L p
1 g
F P
s
P
p
.002 w
.47195 .50007 m .49108 .51378 L .4654 .53518 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.45577 .52832 m .44465 .52396 L .44978 .49141 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.56793 .43589 m .59831 .47554 L .56909 .49616 L p
1 g
F P
s
P
p
.002 w
.59831 .47554 m .56793 .43589 L .59017 .40869 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44978 .49141 m .47195 .50007 L .45577 .52832 L p
1 g
F P
s
P
p
.002 w
.59017 .40869 m .5414 .37267 L .55657 .34342 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50493 .53092 m .49108 .51378 L .5174 .48948 L p
1 g
F P
s
P
p
.002 w
.5174 .48948 m .53756 .51486 L .50493 .53092 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56909 .49616 m .54336 .46318 L .56793 .43589 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.5414 .37267 m .59017 .40869 L .56793 .43589 L p
1 g
F P
s
P
p
.002 w
.46477 .4204 m .42171 .41603 L .4226 .37981 L p
1 g
F P
s
P
p
.002 w
.4226 .37981 m .47407 .38468 L .46477 .4204 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49108 .51378 m .47195 .50007 L .48929 .46917 L p
1 g
F P
s
P
p
.002 w
.48929 .46917 m .5174 .48948 L .49108 .51378 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52471 .40419 m .47407 .38468 L .4841 .35069 L p
1 g
F P
s
P
p
.002 w
.4841 .35069 m .5414 .37267 L .52471 .40419 L p
1 g
F P
s
P
p
.002 w
.45657 .45645 m .42326 .45284 L .42171 .41603 L p
1 g
F P
s
P
p
.002 w
.42171 .41603 m .46477 .4204 L .45657 .45645 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56793 .43589 m .52471 .40419 L .5414 .37267 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52471 .40419 m .56793 .43589 L .54336 .46318 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.004 w
.40661 .62533 m
.41713 .60338 L
s
P
p
.004 w
.41713 .60338 m
.42145 .59436 L
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54336 .46318 m .5071 .43679 L .52471 .40419 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5071 .43679 m .46477 .4204 L .47407 .38468 L p
1 g
F P
s
P
p
.002 w
.47407 .38468 m .52471 .40419 L .5071 .43679 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .7091 .57648 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40661 .62533 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.157364)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.157364)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4717 .43195 m .49908 .45376 L .51361 .42916 L p
1 g
F P
s
P
p
.002 w
.51361 .42916 m .49241 .41226 L .4717 .43195 L p
1 g
F P
s
P
p
.002 w
.53852 .43933 m .51361 .42916 L .49908 .45376 L p
1 g
F P
s
P
p
.002 w
.49241 .41226 m .51361 .42916 L .52783 .40455 L p
1 g
F P
s
P
p
.002 w
.51361 .42916 m .53852 .43933 L .54488 .41146 L p
1 g
F P
s
P
p
.002 w
.54488 .41146 m .52783 .40455 L .51361 .42916 L p
1 g
F P
s
P
p
.002 w
.45175 .40367 m .4717 .43195 L .49241 .41226 L p
1 g
F P
s
P
p
.002 w
.49241 .41226 m .47705 .39032 L .45175 .40367 L p
1 g
F P
s
P
p
.002 w
.47705 .39032 m .49241 .41226 L .51334 .39299 L p
1 g
F P
s
P
p
.002 w
.52783 .40455 m .51334 .39299 L .49241 .41226 L p
1 g
F P
s
P
p
.002 w
.45158 .45169 m .48451 .4779 L .49908 .45376 L p
1 g
F P
s
P
p
.002 w
.49908 .45376 m .4717 .43195 L .45158 .45169 L p
1 g
F P
s
P
p
.002 w
.53123 .46699 m .49908 .45376 L .48451 .4779 L p
1 g
F P
s
P
p
.002 w
.49908 .45376 m .53123 .46699 L .53852 .43933 L p
1 g
F P
s
P
p
.002 w
.42745 .41776 m .45158 .45169 L .4717 .43195 L p
1 g
F P
s
P
p
.002 w
.4717 .43195 m .45175 .40367 L .42745 .41776 L p
1 g
F P
s
P
p
.002 w
.51334 .39299 m .52783 .40455 L .54149 .38037 L p
1 g
F P
s
P
p
.002 w
.52783 .40455 m .54488 .41146 L .55019 .38387 L p
1 g
F P
s
P
p
.002 w
.55019 .38387 m .54149 .38037 L .52783 .40455 L p
1 g
F P
s
P
p
.002 w
.56468 .44172 m .53852 .43933 L .53123 .46699 L p
1 g
F P
s
P
p
.002 w
.53852 .43933 m .56468 .44172 L .56275 .41298 L p
1 g
F P
s
P
p
.002 w
.56275 .41298 m .54488 .41146 L .53852 .43933 L p
1 g
F P
s
P
p
.002 w
.51334 .39299 m .5029 .37796 L .47705 .39032 L p
1 g
F P
s
P
p
.002 w
.5029 .37796 m .51334 .39299 L .53411 .37448 L p
1 g
F P
s
P
p
.002 w
.54149 .38037 m .53411 .37448 L .51334 .39299 L p
1 g
F P
s
P
p
.002 w
.44128 .37161 m .45175 .40367 L .47705 .39032 L p
1 g
F P
s
P
p
.002 w
.47705 .39032 m .46913 .36549 L .44128 .37161 L p
1 g
F P
s
P
p
.002 w
.46913 .36549 m .47705 .39032 L .5029 .37796 L p
1 g
F P
s
P
p
.002 w
.48451 .4779 m .52313 .49393 L .53123 .46699 L p
1 g
F P
s
P
p
.002 w
.56505 .47028 m .53123 .46699 L .52313 .49393 L p
1 g
F P
s
P
p
.002 w
.53123 .46699 m .56505 .47028 L .56468 .44172 L p
1 g
F P
s
P
p
.002 w
.54488 .41146 m .56275 .41298 L .55929 .38459 L p
1 g
F P
s
P
p
.002 w
.55929 .38459 m .55019 .38387 L .54488 .41146 L p
1 g
F P
s
P
p
.002 w
.43241 .47113 m .47016 .50115 L .48451 .4779 L p
1 g
F P
s
P
p
.002 w
.48451 .4779 m .45158 .45169 L .43241 .47113 L p
1 g
F P
s
P
p
.002 w
.52313 .49393 m .48451 .4779 L .47016 .50115 L p
1 g
F P
s
P
p
.002 w
.5029 .37796 m .4976 .36098 L .46913 .36549 L p
1 g
F P
s
P
p
.002 w
.4976 .36098 m .5029 .37796 L .52882 .3668 L p
1 g
F P
s
P
p
.002 w
.53411 .37448 m .52882 .3668 L .5029 .37796 L p
1 g
F P
s
P
p
.002 w
.40463 .43234 m .43241 .47113 L .45158 .45169 L p
1 g
F P
s
P
p
.002 w
.45158 .45169 m .42745 .41776 L .40463 .43234 L p
1 g
F P
s
P
p
.002 w
.4146 .37925 m .42745 .41776 L .45175 .40367 L p
1 g
F P
s
P
p
.002 w
.45175 .40367 m .44128 .37161 L .4146 .37925 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .53411 .37448 L .54149 .38037 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .54149 .38037 L .55019 .38387 L closepath p
1 g
F P
s
P
p
.002 w
.5796 .4089 m .56275 .41298 L .56468 .44172 L p
1 g
F P
s
P
p
.002 w
.56275 .41298 m .5796 .4089 L .56782 .38244 L p
1 g
F P
s
P
p
.002 w
.56782 .38244 m .55929 .38459 L .56275 .41298 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .52882 .3668 L .53411 .37448 L closepath p
1 g
F P
s
P
p
.002 w
.58945 .43594 m .56468 .44172 L .56505 .47028 L p
1 g
F P
s
P
p
.002 w
.56468 .44172 m .58945 .43594 L .5796 .4089 L p
1 g
F P
s
P
p
.002 w
.47016 .50115 m .51437 .51964 L .52313 .49393 L p
1 g
F P
s
P
p
.002 w
.56381 .49812 m .52313 .49393 L .51437 .51964 L p
1 g
F P
s
P
p
.002 w
.52313 .49393 m .56381 .49812 L .56505 .47028 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .55019 .38387 L .55929 .38459 L closepath p
1 g
F P
s
P
p
.002 w
.46958 .34026 m .46913 .36549 L .4976 .36098 L p
1 g
F P
s
P
p
.002 w
.4976 .36098 m .49807 .3438 L .46958 .34026 L p
1 g
F P
s
P
p
.002 w
.49807 .3438 m .4976 .36098 L .52618 .35815 L p
1 g
F P
s
P
p
.002 w
.52882 .3668 m .52618 .35815 L .4976 .36098 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .52618 .35815 L .52882 .3668 L closepath p
1 g
F P
s
P
p
.002 w
.44157 .33892 m .44128 .37161 L .46913 .36549 L p
1 g
F P
s
P
p
.002 w
.46913 .36549 m .46958 .34026 L .44157 .33892 L p
1 g
F P
s
P
p
.002 w
.38961 .38828 m .40463 .43234 L .42745 .41776 L p
1 g
F P
s
P
p
.002 w
.42745 .41776 m .4146 .37925 L .38961 .38828 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .55929 .38459 L .56782 .38244 L closepath p
1 g
F P
s
P
p
.002 w
.59719 .46307 m .56505 .47028 L .56381 .49812 L p
1 g
F P
s
P
p
.002 w
.56505 .47028 m .59719 .46307 L .58945 .43594 L p
1 g
F P
s
P
p
.002 w
.41458 .48991 m .4563 .52306 L .47016 .50115 L p
1 g
F P
s
P
p
.002 w
.47016 .50115 m .43241 .47113 L .41458 .48991 L p
1 g
F P
s
P
p
.002 w
.51437 .51964 m .47016 .50115 L .4563 .52306 L p
1 g
F P
s
P
p
.002 w
.52618 .35815 m .5265 .34944 L .49807 .3438 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .5265 .34944 L .52618 .35815 L closepath p
1 g
F P
s
P
p
.002 w
.38374 .44715 m .41458 .48991 L .43241 .47113 L p
1 g
F P
s
P
p
.002 w
.43241 .47113 m .40463 .43234 L .38374 .44715 L p
1 g
F P
s
P
p
.002 w
.59362 .39955 m .5796 .4089 L .58945 .43594 L p
1 g
F P
s
P
p
.002 w
.5796 .4089 m .59362 .39955 L .57487 .37764 L p
1 g
F P
s
P
p
.002 w
.57487 .37764 m .56782 .38244 L .5796 .4089 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .56782 .38244 L .57487 .37764 L closepath p
1 g
F P
s
P
p
.002 w
.4146 .33985 m .4146 .37925 L .44128 .37161 L p
1 g
F P
s
P
p
.002 w
.44128 .37161 m .44157 .33892 L .4146 .33985 L p
1 g
F P
s
P
p
.002 w
.50435 .32824 m .49807 .3438 L .5265 .34944 L p
1 g
F P
s
P
p
.002 w
.5265 .34944 m .52977 .3416 L .50435 .32824 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .52977 .3416 L .5265 .34944 L closepath p
1 g
F P
s
P
p
.002 w
.47857 .31727 m .46958 .34026 L .49807 .3438 L p
1 g
F P
s
P
p
.002 w
.49807 .3438 m .50435 .32824 L .47857 .31727 L p
1 g
F P
s
P
p
.002 w
.61022 .42242 m .58945 .43594 L .59719 .46307 L p
1 g
F P
s
P
p
.002 w
.58945 .43594 m .61022 .42242 L .59362 .39955 L p
1 g
F P
s
P
p
.002 w
.4563 .52306 m .50509 .54361 L .51437 .51964 L p
1 g
F P
s
P
p
.002 w
.56098 .52471 m .51437 .51964 L .50509 .54361 L p
1 g
F P
s
P
p
.002 w
.51437 .51964 m .56098 .52471 L .56381 .49812 L p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .57487 .37764 L .57966 .37066 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .57966 .37066 L .58165 .36226 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .58165 .36226 L .5806 .35335 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .5806 .35335 L .5766 .3449 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .5766 .3449 L .57008 .33787 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .57008 .33787 L .56176 .33303 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .56176 .33303 L .55257 .33093 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .55257 .33093 L .54353 .33179 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .54353 .33179 L .53565 .33549 L closepath p
1 g
F P
s
P
p
.002 w
.55433 .35708 m .53565 .33549 L .52977 .3416 L closepath p
1 g
F P
s
P
p
.002 w
.57966 .37066 m .57487 .37764 L .59362 .39955 L p
1 g
F P
s
P
p
.002 w
.60261 .48976 m .56381 .49812 L .56098 .52471 L p
1 g
F P
s
P
p
.002 w
.56381 .49812 m .60261 .48976 L .59719 .46307 L p
1 g
F P
s
P
p
.002 w
.51587 .31601 m .50435 .32824 L .52977 .3416 L p
1 g
F P
s
P
p
.002 w
.52977 .3416 m .53565 .33549 L .51587 .31601 L p
1 g
F P
s
P
p
.002 w
.45293 .30897 m .44157 .33892 L .46958 .34026 L p
1 g
F P
s
P
p
.002 w
.46958 .34026 m .47857 .31727 L .45293 .30897 L p
1 g
F P
s
P
p
.002 w
.36687 .39856 m .38374 .44715 L .40463 .43234 L p
1 g
F P
s
P
p
.002 w
.40463 .43234 m .38961 .38828 L .36687 .39856 L p
1 g
F P
s
P
p
.002 w
.60326 .38586 m .59362 .39955 L .61022 .42242 L p
1 g
F P
s
P
p
.002 w
.59362 .39955 m .60326 .38586 L .57966 .37066 L p
1 g
F P
s
P
p
.002 w
.38924 .34307 m .38961 .38828 L .4146 .37925 L p
1 g
F P
s
P
p
.002 w
.4146 .37925 m .4146 .33985 L .38924 .34307 L p
1 g
F P
s
P
p
.002 w
.58165 .36226 m .57966 .37066 L .60326 .38586 L p
1 g
F P
s
P
p
.002 w
.53146 .30852 m .51587 .31601 L .53565 .33549 L p
1 g
F P
s
P
p
.002 w
.53565 .33549 m .54353 .33179 L .53146 .30852 L p
1 g
F P
s
P
p
.002 w
.39848 .50763 m .44322 .54315 L .4563 .52306 L p
1 g
F P
s
P
p
.002 w
.4563 .52306 m .41458 .48991 L .39848 .50763 L p
1 g
F P
s
P
p
.002 w
.50509 .54361 m .4563 .52306 L .44322 .54315 L p
1 g
F P
s
P
p
.002 w
.49537 .29907 m .47857 .31727 L .50435 .32824 L p
1 g
F P
s
P
p
.002 w
.50435 .32824 m .51587 .31601 L .49537 .29907 L p
1 g
F P
s
P
p
.002 w
.62429 .44581 m .59719 .46307 L .60261 .48976 L p
1 g
F P
s
P
p
.002 w
.59719 .46307 m .62429 .44581 L .61022 .42242 L p
1 g
F P
s
P
p
.002 w
.36528 .4619 m .39848 .50763 L .41458 .48991 L p
1 g
F P
s
P
p
.002 w
.41458 .48991 m .38374 .44715 L .36528 .4619 L p
1 g
F P
s
P
p
.002 w
.5806 .35335 m .58165 .36226 L .60737 .36923 L p
1 g
F P
s
P
p
.002 w
.60326 .38586 m .60737 .36923 L .58165 .36226 L p
1 g
F P
s
P
p
.002 w
.54945 .3067 m .53146 .30852 L .54353 .33179 L p
1 g
F P
s
P
p
.002 w
.54353 .33179 m .55257 .33093 L .54945 .3067 L p
1 g
F P
s
P
p
.002 w
.42796 .30358 m .4146 .33985 L .44157 .33892 L p
1 g
F P
s
P
p
.002 w
.44157 .33892 m .45293 .30897 L .42796 .30358 L p
1 g
F P
s
P
p
.002 w
.62463 .4024 m .61022 .42242 L .62429 .44581 L p
1 g
F P
s
P
p
.002 w
.61022 .42242 m .62463 .4024 L .60326 .38586 L p
1 g
F P
s
P
p
.002 w
.60737 .36923 m .60541 .35147 L .5806 .35335 L p
1 g
F P
s
P
p
.002 w
.5766 .3449 m .5806 .35335 L .60541 .35147 L p
1 g
F P
s
P
p
.002 w
.50509 .54361 m .55657 .54948 L .56098 .52471 L p
1 g
F P
s
P
p
.002 w
.60556 .51547 m .56098 .52471 L .55657 .54948 L p
1 g
F P
s
P
p
.002 w
.56098 .52471 m .60556 .51547 L .60261 .48976 L p
1 g
F P
s
P
p
.002 w
.60737 .36923 m .60326 .38586 L .62463 .4024 L p
1 g
F P
s
P
p
.002 w
.56781 .31083 m .54945 .3067 L .55257 .33093 L p
1 g
F P
s
P
p
.002 w
.55257 .33093 m .56176 .33303 L .56781 .31083 L p
1 g
F P
s
P
p
.002 w
.44322 .54315 m .49547 .56531 L .50509 .54361 L p
1 g
F P
s
P
p
.002 w
.55657 .54948 m .50509 .54361 L .49547 .56531 L p
1 g
F P
s
P
p
.002 w
.60541 .35147 m .59749 .33458 L .5766 .3449 L p
1 g
F P
s
P
p
.002 w
.57008 .33787 m .5766 .3449 L .59749 .33458 L p
1 g
F P
s
P
p
.002 w
.47454 .2851 m .45293 .30897 L .47857 .31727 L p
1 g
F P
s
P
p
.002 w
.47857 .31727 m .49537 .29907 L .47454 .2851 L p
1 g
F P
s
P
p
.002 w
.58447 .32049 m .56781 .31083 L .56176 .33303 L p
1 g
F P
s
P
p
.002 w
.56176 .33303 m .57008 .33787 L .58447 .32049 L p
1 g
F P
s
P
p
.002 w
.51832 .28781 m .49537 .29907 L .51587 .31601 L p
1 g
F P
s
P
p
.002 w
.51587 .31601 m .53146 .30852 L .51832 .28781 L p
1 g
F P
s
P
p
.002 w
.59749 .33458 m .58447 .32049 L .57008 .33787 L p
1 g
F P
s
P
p
.002 w
.34692 .40992 m .36528 .4619 L .38374 .44715 L p
1 g
F P
s
P
p
.002 w
.38374 .44715 m .36687 .39856 L .34692 .40992 L p
1 g
F P
s
P
p
.002 w
.36608 .34862 m .36687 .39856 L .38961 .38828 L p
1 g
F P
s
P
p
.002 w
.38961 .38828 m .38924 .34307 L .36608 .34862 L p
1 g
F P
s
P
p
.002 w
.63551 .46925 m .60261 .48976 L .60556 .51547 L p
1 g
F P
s
P
p
.002 w
.60261 .48976 m .63551 .46925 L .62429 .44581 L p
1 g
F P
s
P
p
.002 w
.62463 .4024 m .63093 .37789 L .60737 .36923 L p
1 g
F P
s
P
p
.002 w
.60541 .35147 m .60737 .36923 L .63093 .37789 L p
1 g
F P
s
P
p
.002 w
.40421 .3013 m .38924 .34307 L .4146 .33985 L p
1 g
F P
s
P
p
.002 w
.4146 .33985 m .42796 .30358 L .40421 .3013 L p
1 g
F P
s
P
p
.002 w
.64329 .41997 m .62429 .44581 L .63551 .46925 L p
1 g
F P
s
P
p
.002 w
.62429 .44581 m .64329 .41997 L .62463 .4024 L p
1 g
F P
s
P
p
.002 w
.54498 .28496 m .51832 .28781 L .53146 .30852 L p
1 g
F P
s
P
p
.002 w
.53146 .30852 m .54945 .3067 L .54498 .28496 L p
1 g
F P
s
P
p
.002 w
.38449 .5239 m .4312 .56096 L .44322 .54315 L p
1 g
F P
s
P
p
.002 w
.44322 .54315 m .39848 .50763 L .38449 .5239 L p
1 g
F P
s
P
p
.002 w
.49547 .56531 m .44322 .54315 L .4312 .56096 L p
1 g
F P
s
P
p
.002 w
.34973 .47627 m .38449 .5239 L .39848 .50763 L p
1 g
F P
s
P
p
.002 w
.39848 .50763 m .36528 .4619 L .34973 .47627 L p
1 g
F P
s
P
p
.002 w
.63093 .37789 m .62463 .4024 L .64329 .41997 L p
1 g
F P
s
P
p
.002 w
.45382 .27449 m .42796 .30358 L .45293 .30897 L p
1 g
F P
s
P
p
.002 w
.45293 .30897 m .47454 .2851 L .45382 .27449 L p
1 g
F P
s
P
p
.002 w
.50435 .27019 m .47454 .2851 L .49537 .29907 L p
1 g
F P
s
P
p
.002 w
.49537 .29907 m .51832 .28781 L .50435 .27019 L p
1 g
F P
s
P
p
.002 w
.49547 .56531 m .55061 .57187 L .55657 .54948 L p
1 g
F P
s
P
p
.002 w
.6059 .53963 m .55657 .54948 L .55061 .57187 L p
1 g
F P
s
P
p
.002 w
.55657 .54948 m .6059 .53963 L .60556 .51547 L p
1 g
F P
s
P
p
.002 w
.63093 .37789 m .62819 .35155 L .60541 .35147 L p
1 g
F P
s
P
p
.002 w
.59749 .33458 m .60541 .35147 L .62819 .35155 L p
1 g
F P
s
P
p
.002 w
.57232 .29101 m .54498 .28496 L .54945 .3067 L p
1 g
F P
s
P
p
.002 w
.54945 .3067 m .56781 .31083 L .57232 .29101 L p
1 g
F P
s
P
p
.002 w
.4312 .56096 m .48568 .5842 L .49547 .56531 L p
1 g
F P
s
P
p
.002 w
.55061 .57187 m .49547 .56531 L .48568 .5842 L p
1 g
F P
s
P
p
.002 w
.64353 .49227 m .60556 .51547 L .6059 .53963 L p
1 g
F P
s
P
p
.002 w
.60556 .51547 m .64353 .49227 L .63551 .46925 L p
1 g
F P
s
P
p
.002 w
.62819 .35155 m .61651 .32639 L .59749 .33458 L p
1 g
F P
s
P
p
.002 w
.58447 .32049 m .59749 .33458 L .61651 .32639 L p
1 g
F P
s
P
p
.002 w
.34572 .35644 m .34692 .40992 L .36687 .39856 L p
1 g
F P
s
P
p
.002 w
.36687 .39856 m .36608 .34862 L .34572 .35644 L p
1 g
F P
s
P
p
.002 w
.59715 .30538 m .57232 .29101 L .56781 .31083 L p
1 g
F P
s
P
p
.002 w
.56781 .31083 m .58447 .32049 L .59715 .30538 L p
1 g
F P
s
P
p
.002 w
.33033 .42217 m .34973 .47627 L .36528 .4619 L p
1 g
F P
s
P
p
.002 w
.36528 .4619 m .34692 .40992 L .33033 .42217 L p
1 g
F P
s
P
p
.002 w
.61651 .32639 m .59715 .30538 L .58447 .32049 L p
1 g
F P
s
P
p
.002 w
.65873 .43826 m .63551 .46925 L .64353 .49227 L p
1 g
F P
s
P
p
.002 w
.63551 .46925 m .65873 .43826 L .64329 .41997 L p
1 g
F P
s
P
p
.002 w
.38226 .30233 m .36608 .34862 L .38924 .34307 L p
1 g
F P
s
P
p
.002 w
.38924 .34307 m .40421 .3013 L .38226 .30233 L p
1 g
F P
s
P
p
.002 w
.64329 .41997 m .65176 .38811 L .63093 .37789 L p
1 g
F P
s
P
p
.002 w
.62819 .35155 m .63093 .37789 L .65176 .38811 L p
1 g
F P
s
P
p
.002 w
.65176 .38811 m .64329 .41997 L .65873 .43826 L p
1 g
F P
s
P
p
.002 w
.53921 .26628 m .50435 .27019 L .51832 .28781 L p
1 g
F P
s
P
p
.002 w
.51832 .28781 m .54498 .28496 L .53921 .26628 L p
1 g
F P
s
P
p
.002 w
.43367 .26764 m .40421 .3013 L .42796 .30358 L p
1 g
F P
s
P
p
.002 w
.42796 .30358 m .45382 .27449 L .43367 .26764 L p
1 g
F P
s
P
p
.002 w
.37302 .5383 m .42056 .576 L .4312 .56096 L p
1 g
F P
s
P
p
.002 w
.4312 .56096 m .38449 .5239 L .37302 .5383 L p
1 g
F P
s
P
p
.002 w
.48568 .5842 m .4312 .56096 L .42056 .576 L p
1 g
F P
s
P
p
.002 w
.48983 .25619 m .45382 .27449 L .47454 .2851 L p
1 g
F P
s
P
p
.002 w
.47454 .2851 m .50435 .27019 L .48983 .25619 L p
1 g
F P
s
P
p
.002 w
.33755 .48994 m .37302 .5383 L .38449 .5239 L p
1 g
F P
s
P
p
.002 w
.38449 .5239 m .34973 .47627 L .33755 .48994 L p
1 g
F P
s
P
p
.002 w
.48568 .5842 m .54316 .59128 L .55061 .57187 L p
1 g
F P
s
P
p
.002 w
.60351 .56166 m .55061 .57187 L .54316 .59128 L p
1 g
F P
s
P
p
.002 w
.55061 .57187 m .60351 .56166 L .6059 .53963 L p
1 g
F P
s
P
p
.002 w
.65176 .38811 m .64836 .35367 L .62819 .35155 L p
1 g
F P
s
P
p
.002 w
.61651 .32639 m .62819 .35155 L .64836 .35367 L p
1 g
F P
s
P
p
.002 w
.64805 .51432 m .6059 .53963 L .60351 .56166 L p
1 g
F P
s
P
p
.002 w
.6059 .53963 m .64805 .51432 L .64353 .49227 L p
1 g
F P
s
P
p
.002 w
.57511 .27413 m .53921 .26628 L .54498 .28496 L p
1 g
F P
s
P
p
.002 w
.54498 .28496 m .57232 .29101 L .57511 .27413 L p
1 g
F P
s
P
p
.002 w
.42056 .576 m .47594 .59974 L .48568 .5842 L p
1 g
F P
s
P
p
.002 w
.54316 .59128 m .48568 .5842 L .47594 .59974 L p
1 g
F P
s
P
p
.002 w
.32877 .36648 m .33033 .42217 L .34692 .40992 L p
1 g
F P
s
P
p
.002 w
.34692 .40992 m .34572 .35644 L .32877 .36648 L p
1 g
F P
s
P
p
.002 w
.67051 .45687 m .64353 .49227 L .64805 .51432 L p
1 g
F P
s
P
p
.002 w
.64353 .49227 m .67051 .45687 L .65873 .43826 L p
1 g
F P
s
P
p
.002 w
.64836 .35367 m .63316 .32063 L .61651 .32639 L p
1 g
F P
s
P
p
.002 w
.59715 .30538 m .61651 .32639 L .63316 .32063 L p
1 g
F P
s
P
p
.002 w
.36271 .30678 m .34572 .35644 L .36608 .34862 L p
1 g
F P
s
P
p
.002 w
.36608 .34862 m .38226 .30233 L .36271 .30678 L p
1 g
F P
s
P
p
.002 w
.31763 .43506 m .33755 .48994 L .34973 .47627 L p
1 g
F P
s
P
p
.002 w
.34973 .47627 m .33033 .42217 L .31763 .43506 L p
1 g
F P
s
P
p
.002 w
.60775 .29299 m .57511 .27413 L .57232 .29101 L p
1 g
F P
s
P
p
.002 w
.57232 .29101 m .59715 .30538 L .60775 .29299 L p
1 g
F P
s
P
p
.002 w
.64836 .35367 m .65176 .38811 L .66927 .39975 L p
1 g
F P
s
P
p
.002 w
.65873 .43826 m .66927 .39975 L .65176 .38811 L p
1 g
F P
s
P
p
.002 w
.63316 .32063 m .60775 .29299 L .59715 .30538 L p
1 g
F P
s
P
p
.002 w
.66927 .39975 m .65873 .43826 L .67051 .45687 L p
1 g
F P
s
P
p
.002 w
.5322 .25126 m .48983 .25619 L .50435 .27019 L p
1 g
F P
s
P
p
.002 w
.50435 .27019 m .53921 .26628 L .5322 .25126 L p
1 g
F P
s
P
p
.002 w
.41462 .26488 m .38226 .30233 L .40421 .3013 L p
1 g
F P
s
P
p
.002 w
.40421 .3013 m .43367 .26764 L .41462 .26488 L p
1 g
F P
s
P
p
.002 w
.47507 .24632 m .43367 .26764 L .45382 .27449 L p
1 g
F P
s
P
p
.002 w
.45382 .27449 m .48983 .25619 L .47507 .24632 L p
1 g
F P
s
P
p
.002 w
.36447 .5504 m .41161 .58777 L .42056 .576 L p
1 g
F P
s
P
p
.002 w
.42056 .576 m .37302 .5383 L .36447 .5504 L p
1 g
F P
s
P
p
.002 w
.47594 .59974 m .42056 .576 L .41161 .58777 L p
1 g
F P
s
P
p
.002 w
.47594 .59974 m .53432 .60714 L .54316 .59128 L p
1 g
F P
s
P
p
.002 w
.59833 .58095 m .54316 .59128 L .53432 .60714 L p
1 g
F P
s
P
p
.002 w
.54316 .59128 m .59833 .58095 L .60351 .56166 L p
1 g
F P
s
P
p
.002 w
.32923 .50254 m .36447 .5504 L .37302 .5383 L p
1 g
F P
s
P
p
.002 w
.37302 .5383 m .33755 .48994 L .32923 .50254 L p
1 g
F P
s
P
p
.002 w
.64882 .53487 m .60351 .56166 L .59833 .58095 L p
1 g
F P
s
P
p
.002 w
.60351 .56166 m .64882 .53487 L .64805 .51432 L p
1 g
F P
s
P
p
.002 w
.66927 .39975 m .66534 .35789 L .64836 .35367 L p
1 g
F P
s
P
p
.002 w
.63316 .32063 m .64836 .35367 L .66534 .35789 L p
1 g
F P
s
P
p
.002 w
.57601 .26075 m .5322 .25126 L .53921 .26628 L p
1 g
F P
s
P
p
.002 w
.53921 .26628 m .57511 .27413 L .57601 .26075 L p
1 g
F P
s
P
p
.002 w
.3158 .3786 m .31763 .43506 L .33033 .42217 L p
1 g
F P
s
P
p
.002 w
.33033 .42217 m .32877 .36648 L .3158 .3786 L p
1 g
F P
s
P
p
.002 w
.67815 .47539 m .64805 .51432 L .64882 .53487 L p
1 g
F P
s
P
p
.002 w
.64805 .51432 m .67815 .47539 L .67051 .45687 L p
1 g
F P
s
P
p
.002 w
.41161 .58777 m .46647 .61139 L .47594 .59974 L p
1 g
F P
s
P
p
.002 w
.53432 .60714 m .47594 .59974 L .46647 .61139 L p
1 g
F P
s
P
p
.002 w
.34618 .31472 m .32877 .36648 L .34572 .35644 L p
1 g
F P
s
P
p
.002 w
.34572 .35644 m .36271 .30678 L .34618 .31472 L p
1 g
F P
s
P
p
.002 w
.67051 .45687 m .6829 .4126 L .66927 .39975 L p
1 g
F P
s
P
p
.002 w
.66534 .35789 m .66927 .39975 L .6829 .4126 L p
1 g
F P
s
P
p
.002 w
.6829 .4126 m .67051 .45687 L .67815 .47539 L p
1 g
F P
s
P
p
.002 w
.66534 .35789 m .64692 .31756 L .63316 .32063 L p
1 g
F P
s
P
p
.002 w
.60775 .29299 m .63316 .32063 L .64692 .31756 L p
1 g
F P
s
P
p
.002 w
.30937 .44831 m .32923 .50254 L .33755 .48994 L p
1 g
F P
s
P
p
.002 w
.33755 .48994 m .31763 .43506 L .30937 .44831 L p
1 g
F P
s
P
p
.002 w
.6159 .28377 m .57601 .26075 L .57511 .27413 L p
1 g
F P
s
P
p
.002 w
.57511 .27413 m .60775 .29299 L .6159 .28377 L p
1 g
F P
s
P
p
.002 w
.39718 .2665 m .36271 .30678 L .38226 .30233 L p
1 g
F P
s
P
p
.002 w
.38226 .30233 m .41462 .26488 L .39718 .2665 L p
1 g
F P
s
P
p
.002 w
.52404 .24047 m .47507 .24632 L .48983 .25619 L p
1 g
F P
s
P
p
.002 w
.48983 .25619 m .5322 .25126 L .52404 .24047 L p
1 g
F P
s
P
p
.002 w
.64692 .31756 m .6159 .28377 L .60775 .29299 L p
1 g
F P
s
P
p
.002 w
.46042 .24106 m .41462 .26488 L .43367 .26764 L p
1 g
F P
s
P
p
.002 w
.43367 .26764 m .47507 .24632 L .46042 .24106 L p
1 g
F P
s
P
p
.002 w
.53432 .60714 m .59034 .5969 L .59833 .58095 L p
1 g
F P
s
P
p
.002 w
.64563 .55333 m .59833 .58095 L .59034 .5969 L p
1 g
F P
s
P
p
.002 w
.59833 .58095 m .64563 .55333 L .64882 .53487 L p
1 g
F P
s
P
p
.002 w
.46647 .61139 m .52423 .61887 L .53432 .60714 L p
1 g
F P
s
P
p
.002 w
.59034 .5969 m .53432 .60714 L .52423 .61887 L p
1 g
F P
s
P
p
.002 w
.3592 .55978 m .40467 .59581 L .41161 .58777 L p
1 g
F P
s
P
p
.002 w
.41161 .58777 m .36447 .5504 L .3592 .55978 L p
1 g
F P
s
P
p
.002 w
.46647 .61139 m .41161 .58777 L .40467 .59581 L p
1 g
F P
s
P
p
.002 w
.6829 .4126 m .67854 .36421 L .66534 .35789 L p
1 g
F P
s
P
p
.002 w
.64692 .31756 m .66534 .35789 L .67854 .36421 L p
1 g
F P
s
P
p
.002 w
.32519 .51371 m .3592 .55978 L .36447 .5504 L p
1 g
F P
s
P
p
.002 w
.36447 .5504 m .32923 .50254 L .32519 .51371 L p
1 g
F P
s
P
p
.002 w
.68128 .49335 m .64882 .53487 L .64563 .55333 L p
1 g
F P
s
P
p
.002 w
.64882 .53487 m .68128 .49335 L .67815 .47539 L p
1 g
F P
s
P
p
.002 w
.57488 .25141 m .52404 .24047 L .5322 .25126 L p
1 g
F P
s
P
p
.002 w
.5322 .25126 m .57601 .26075 L .57488 .25141 L p
1 g
F P
s
P
p
.002 w
.3074 .39259 m .30937 .44831 L .31763 .43506 L p
1 g
F P
s
P
p
.002 w
.31763 .43506 m .3158 .3786 L .3074 .39259 L p
1 g
F P
s
P
p
.002 w
.33326 .32614 m .3158 .3786 L .32877 .36648 L p
1 g
F P
s
P
p
.002 w
.32877 .36648 m .34618 .31472 L .33326 .32614 L p
1 g
F P
s
P
p
.002 w
.69212 .4264 m .67815 .47539 L .68128 .49335 L p
1 g
F P
s
P
p
.002 w
.67815 .47539 m .69212 .4264 L .6829 .4126 L p
1 g
F P
s
P
p
.002 w
.67854 .36421 m .6829 .4126 L .69212 .4264 L p
1 g
F P
s
P
p
.002 w
.40467 .59581 m .45752 .61862 L .46647 .61139 L p
1 g
F P
s
P
p
.002 w
.52423 .61887 m .46647 .61139 L .45752 .61862 L p
1 g
F P
s
P
p
.002 w
.38192 .27271 m .34618 .31472 L .36271 .30678 L p
1 g
F P
s
P
p
.002 w
.36271 .30678 m .39718 .2665 L .38192 .27271 L p
1 g
F P
s
P
p
.002 w
.67854 .36421 m .65726 .31743 L .64692 .31756 L p
1 g
F P
s
P
p
.002 w
.6159 .28377 m .64692 .31756 L .65726 .31743 L p
1 g
F P
s
P
p
.002 w
.306 .4616 m .32519 .51371 L .32923 .50254 L p
1 g
F P
s
P
p
.002 w
.32923 .50254 m .30937 .44831 L .306 .4616 L p
1 g
F P
s
P
p
.002 w
.5149 .23446 m .46042 .24106 L .47507 .24632 L p
1 g
F P
s
P
p
.002 w
.47507 .24632 m .52404 .24047 L .5149 .23446 L p
1 g
F P
s
P
p
.002 w
.62125 .27815 m .57488 .25141 L .57601 .26075 L p
1 g
F P
s
P
p
.002 w
.57601 .26075 m .6159 .28377 L .62125 .27815 L p
1 g
F P
s
P
p
.002 w
.44628 .24082 m .39718 .2665 L .41462 .26488 L p
1 g
F P
s
P
p
.002 w
.41462 .26488 m .46042 .24106 L .44628 .24082 L p
1 g
F P
s
P
p
.002 w
.65726 .31743 m .62125 .27815 L .6159 .28377 L p
1 g
F P
s
P
p
.002 w
.52423 .61887 m .57959 .60893 L .59034 .5969 L p
1 g
F P
s
P
p
.002 w
.63834 .56911 m .59034 .5969 L .57959 .60893 L p
1 g
F P
s
P
p
.002 w
.59034 .5969 m .63834 .56911 L .64563 .55333 L p
1 g
F P
s
P
p
.002 w
.45752 .61862 m .51308 .62592 L .52423 .61887 L p
1 g
F P
s
P
p
.002 w
.57959 .60893 m .52423 .61887 L .51308 .62592 L p
1 g
F P
s
P
p
.002 w
.69212 .4264 m .68739 .3726 L .67854 .36421 L p
1 g
F P
s
P
p
.002 w
.65726 .31743 m .67854 .36421 L .68739 .3726 L p
1 g
F P
s
P
p
.002 w
.67955 .51026 m .64563 .55333 L .63834 .56911 L p
1 g
F P
s
P
p
.002 w
.64563 .55333 m .67955 .51026 L .68128 .49335 L p
1 g
F P
s
P
p
.002 w
.35757 .56601 m .40004 .59966 L .40467 .59581 L p
1 g
F P
s
P
p
.002 w
.40467 .59581 m .3592 .55978 L .35757 .56601 L p
1 g
F P
s
P
p
.002 w
.45752 .61862 m .40467 .59581 L .40004 .59966 L p
1 g
F P
s
P
p
.002 w
.32581 .52304 m .35757 .56601 L .3592 .55978 L p
1 g
F P
s
P
p
.002 w
.3592 .55978 m .32519 .51371 L .32581 .52304 L p
1 g
F P
s
P
p
.002 w
.32451 .34091 m .3074 .39259 L .3158 .3786 L p
1 g
F P
s
P
p
.002 w
.3158 .3786 m .33326 .32614 L .32451 .34091 L p
1 g
F P
s
P
p
.002 w
.30404 .40818 m .306 .4616 L .30937 .44831 L p
1 g
F P
s
P
p
.002 w
.30937 .44831 m .3074 .39259 L .30404 .40818 L p
1 g
F P
s
P
p
.002 w
.57164 .24662 m .5149 .23446 L .52404 .24047 L p
1 g
F P
s
P
p
.002 w
.52404 .24047 m .57488 .25141 L .57164 .24662 L p
1 g
F P
s
P
p
.002 w
.69641 .44085 m .68128 .49335 L .67955 .51026 L p
1 g
F P
s
P
p
.002 w
.68128 .49335 m .69641 .44085 L .69212 .4264 L p
1 g
F P
s
P
p
.002 w
.68739 .3726 m .69212 .4264 L .69641 .44085 L p
1 g
F P
s
P
p
.002 w
.36938 .28358 m .33326 .32614 L .34618 .31472 L p
1 g
F P
s
P
p
.002 w
.34618 .31472 m .38192 .27271 L .36938 .28358 L p
1 g
F P
s
P
p
.002 w
.40004 .59966 m .44936 .62098 L .45752 .61862 L p
1 g
F P
s
P
p
.002 w
.51308 .62592 m .45752 .61862 L .44936 .62098 L p
1 g
F P
s
P
p
.002 w
.50494 .23368 m .44628 .24082 L .46042 .24106 L p
1 g
F P
s
P
p
.002 w
.46042 .24106 m .5149 .23446 L .50494 .23368 L p
1 g
F P
s
P
p
.002 w
.43309 .2459 m .38192 .27271 L .39718 .2665 L p
1 g
F P
s
P
p
.002 w
.39718 .2665 m .44628 .24082 L .43309 .2459 L p
1 g
F P
s
P
p
.002 w
.30791 .47456 m .32581 .52304 L .32519 .51371 L p
1 g
F P
s
P
p
.002 w
.32519 .51371 m .306 .4616 L .30791 .47456 L p
1 g
F P
s
P
p
.002 w
.68739 .3726 m .6637 .32041 L .65726 .31743 L p
1 g
F P
s
P
p
.002 w
.62125 .27815 m .65726 .31743 L .6637 .32041 L p
1 g
F P
s
P
p
.002 w
.62347 .2765 m .57164 .24662 L .57488 .25141 L p
1 g
F P
s
P
p
.002 w
.57488 .25141 m .62125 .27815 L .62347 .2765 L p
1 g
F P
s
P
p
.002 w
.6637 .32041 m .62347 .2765 L .62125 .27815 L p
1 g
F P
s
P
p
.002 w
.51308 .62592 m .56621 .61646 L .57959 .60893 L p
1 g
F P
s
P
p
.002 w
.57959 .60893 m .62694 .58164 L .63834 .56911 L p
1 g
F P
s
P
p
.002 w
.62694 .58164 m .57959 .60893 L .56621 .61646 L p
1 g
F P
s
P
p
.002 w
.63834 .56911 m .67274 .52559 L .67955 .51026 L p
1 g
F P
s
P
p
.002 w
.67274 .52559 m .63834 .56911 L .62694 .58164 L p
1 g
F P
s
P
p
.002 w
.44936 .62098 m .50111 .62781 L .51308 .62592 L p
1 g
F P
s
P
p
.002 w
.56621 .61646 m .51308 .62592 L .50111 .62781 L p
1 g
F P
s
P
p
.002 w
.69641 .44085 m .69138 .38296 L .68739 .3726 L p
1 g
F P
s
P
p
.002 w
.6637 .32041 m .68739 .3726 L .69138 .38296 L p
1 g
F P
s
P
p
.002 w
.32043 .35878 m .30404 .40818 L .3074 .39259 L p
1 g
F P
s
P
p
.002 w
.3074 .39259 m .32451 .34091 L .32043 .35878 L p
1 g
F P
s
P
p
.002 w
.67955 .51026 m .69538 .45558 L .69641 .44085 L p
1 g
F P
s
P
p
.002 w
.69538 .45558 m .67955 .51026 L .67274 .52559 L p
1 g
F P
s
P
p
.002 w
.35986 .56872 m .39801 .59894 L .40004 .59966 L p
1 g
F P
s
P
p
.002 w
.40004 .59966 m .35757 .56601 L .35986 .56872 L p
1 g
F P
s
P
p
.002 w
.44936 .62098 m .40004 .59966 L .39801 .59894 L p
1 g
F P
s
P
p
.002 w
.30612 .42502 m .30791 .47456 L .306 .4616 L p
1 g
F P
s
P
p
.002 w
.306 .4616 m .30404 .40818 L .30612 .42502 L p
1 g
F P
s
P
p
.002 w
.33136 .53017 m .35986 .56872 L .35757 .56601 L p
1 g
F P
s
P
p
.002 w
.35757 .56601 m .32581 .52304 L .33136 .53017 L p
1 g
F P
s
P
p
.002 w
.56622 .24683 m .50494 .23368 L .5149 .23446 L p
1 g
F P
s
P
p
.002 w
.5149 .23446 m .57164 .24662 L .56622 .24683 L p
1 g
F P
s
P
p
.002 w
.69138 .38296 m .69641 .44085 L .69538 .45558 L p
1 g
F P
s
P
p
.002 w
.36011 .29907 m .32451 .34091 L .33326 .32614 L p
1 g
F P
s
P
p
.002 w
.33326 .32614 m .36938 .28358 L .36011 .29907 L p
1 g
F P
s
P
p
.002 w
.39801 .59894 m .44228 .61808 L .44936 .62098 L p
1 g
F P
s
P
p
.002 w
.50111 .62781 m .44936 .62098 L .44228 .61808 L p
1 g
F P
s
P
p
.002 w
.42129 .25648 m .36938 .28358 L .38192 .27271 L p
1 g
F P
s
P
p
.002 w
.38192 .27271 m .43309 .2459 L .42129 .25648 L p
1 g
F P
s
P
p
.002 w
.49443 .23849 m .43309 .2459 L .44628 .24082 L p
1 g
F P
s
P
p
.002 w
.44628 .24082 m .50494 .23368 L .49443 .23849 L p
1 g
F P
s
P
p
.002 w
.31539 .48679 m .33136 .53017 L .32581 .52304 L p
1 g
F P
s
P
p
.002 w
.32581 .52304 m .30791 .47456 L .31539 .48679 L p
1 g
F P
s
P
p
.002 w
.69138 .38296 m .66581 .32663 L .6637 .32041 L p
1 g
F P
s
P
p
.002 w
.62347 .2765 m .6637 .32041 L .66581 .32663 L p
1 g
F P
s
P
p
.002 w
.62228 .27916 m .56622 .24683 L .57164 .24662 L p
1 g
F P
s
P
p
.002 w
.57164 .24662 m .62347 .2765 L .62228 .27916 L p
1 g
F P
s
P
p
.002 w
.66581 .32663 m .62228 .27916 L .62347 .2765 L p
1 g
F P
s
P
p
.002 w
.50111 .62781 m .55042 .61903 L .56621 .61646 L p
1 g
F P
s
P
p
.002 w
.6115 .59036 m .56621 .61646 L .55042 .61903 L p
1 g
F P
s
P
p
.002 w
.56621 .61646 m .6115 .59036 L .62694 .58164 L p
1 g
F P
s
P
p
.004 w
.62593 .59993 m
.66501 .65251 L
s
P
p
.002 w
.66076 .53879 m .62694 .58164 L .6115 .59036 L p
1 g
F P
s
P
p
.002 w
.62694 .58164 m .66076 .53879 L .67274 .52559 L p
1 g
F P
s
P
p
.002 w
.44228 .61808 m .48861 .62418 L .50111 .62781 L p
1 g
F P
s
P
p
.002 w
.55042 .61903 m .50111 .62781 L .48861 .62418 L p
1 g
F P
s
P
p
.002 w
.32141 .37939 m .30612 .42502 L .30404 .40818 L p
1 g
F P
s
P
p
.002 w
.30404 .40818 m .32043 .35878 L .32141 .37939 L p
1 g
F P
s
P
p
.002 w
.69538 .45558 m .69008 .3951 L .69138 .38296 L p
1 g
F P
s
P
p
.002 w
.66581 .32663 m .69138 .38296 L .69008 .3951 L p
1 g
F P
s
P
p
.002 w
.68873 .47018 m .67274 .52559 L .66076 .53879 L p
1 g
F P
s
P
p
.002 w
.67274 .52559 m .68873 .47018 L .69538 .45558 L p
1 g
F P
s
P
p
.002 w
.3139 .44264 m .31539 .48679 L .30791 .47456 L p
1 g
F P
s
P
p
.002 w
.30791 .47456 m .30612 .42502 L .3139 .44264 L p
1 g
F P
s
P
p
.002 w
.35456 .31896 m .32043 .35878 L .32451 .34091 L p
1 g
F P
s
P
p
.002 w
.32451 .34091 m .36011 .29907 L .35456 .31896 L p
1 g
F P
s
P
p
.002 w
.69008 .3951 m .69538 .45558 L .68873 .47018 L p
1 g
F P
s
P
p
.002 w
.36626 .56759 m .3988 .59337 L .39801 .59894 L p
1 g
F P
s
P
p
.002 w
.39801 .59894 m .35986 .56872 L .36626 .56759 L p
1 g
F P
s
P
p
.002 w
.44228 .61808 m .39801 .59894 L .3988 .59337 L p
1 g
F P
s
P
p
.002 w
.55866 .25235 m .49443 .23849 L .50494 .23368 L p
1 g
F P
s
P
p
.002 w
.50494 .23368 m .56622 .24683 L .55866 .25235 L p
1 g
F P
s
P
p
.002 w
.34201 .53473 m .36626 .56759 L .35986 .56872 L p
1 g
F P
s
P
p
.002 w
.35986 .56872 m .33136 .53017 L .34201 .53473 L p
1 g
F P
s
P
p
.002 w
.41133 .27255 m .36011 .29907 L .36938 .28358 L p
1 g
F P
s
P
p
.002 w
.36938 .28358 m .42129 .25648 L .41133 .27255 L p
1 g
F P
s
P
p
.002 w
.48365 .2491 m .42129 .25648 L .43309 .2459 L p
1 g
F P
s
P
p
.002 w
.43309 .2459 m .49443 .23849 L .48365 .2491 L p
1 g
F P
s
P
p
.002 w
.3988 .59337 m .43655 .60966 L .44228 .61808 L p
1 g
F P
s
P
p
.002 w
.48861 .62418 m .44228 .61808 L .43655 .60966 L p
1 g
F P
s
P
p
.002 w
.32852 .49787 m .34201 .53473 L .33136 .53017 L p
1 g
F P
s
P
p
.002 w
.33136 .53017 m .31539 .48679 L .32852 .49787 L p
1 g
F P
s
P
p
.002 w
.69008 .3951 m .66322 .33612 L .66581 .32663 L p
1 g
F P
s
P
p
.002 w
.62228 .27916 m .66581 .32663 L .66322 .33612 L p
1 g
F P
s
P
p
.002 w
.6175 .28632 m .55866 .25235 L .56622 .24683 L p
1 g
F P
s
P
p
.002 w
.56622 .24683 m .62228 .27916 L .6175 .28632 L p
1 g
F P
s
P
p
.002 w
.48861 .62418 m .53258 .61627 L .55042 .61903 L p
1 g
F P
s
P
p
.002 w
.59227 .59479 m .55042 .61903 L .53258 .61627 L p
1 g
F P
s
P
p
.002 w
.55042 .61903 m .59227 .59479 L .6115 .59036 L p
1 g
F P
s
P
p
.002 w
.64368 .54935 m .6115 .59036 L .59227 .59479 L p
1 g
F P
s
P
p
.002 w
.6115 .59036 m .64368 .54935 L .66076 .53879 L p
1 g
F P
s
P
p
.002 w
.66322 .33612 m .6175 .28632 L .62228 .27916 L p
1 g
F P
s
P
p
.002 w
.43655 .60966 m .47593 .61478 L .48861 .62418 L p
1 g
F P
s
P
p
.002 w
.53258 .61627 m .48861 .62418 L .47593 .61478 L p
1 g
F P
s
P
p
.002 w
.32769 .40221 m .3139 .44264 L .30612 .42502 L p
1 g
F P
s
P
p
.002 w
.30612 .42502 m .32141 .37939 L .32769 .40221 L p
1 g
F P
s
P
p
.002 w
.67634 .48419 m .66076 .53879 L .64368 .54935 L p
1 g
F P
s
P
p
.002 w
.66076 .53879 m .67634 .48419 L .68873 .47018 L p
1 g
F P
s
P
p
.002 w
.35313 .34282 m .32141 .37939 L .32043 .35878 L p
1 g
F P
s
P
p
.002 w
.32043 .35878 m .35456 .31896 L .35313 .34282 L p
1 g
F P
s
P
p
.002 w
.68873 .47018 m .68321 .40877 L .69008 .3951 L p
1 g
F P
s
P
p
.002 w
.66322 .33612 m .69008 .3951 L .68321 .40877 L p
1 g
F P
s
P
p
.002 w
.32742 .46053 m .32852 .49787 L .31539 .48679 L p
1 g
F P
s
P
p
.002 w
.31539 .48679 m .3139 .44264 L .32742 .46053 L p
1 g
F P
s
P
p
.002 w
.68321 .40877 m .68873 .47018 L .67634 .48419 L p
1 g
F P
s
P
p
.002 w
.54905 .26335 m .48365 .2491 L .49443 .23849 L p
1 g
F P
s
P
p
.002 w
.49443 .23849 m .55866 .25235 L .54905 .26335 L p
1 g
F P
s
P
p
.002 w
.40366 .29389 m .35456 .31896 L .36011 .29907 L p
1 g
F P
s
P
p
.002 w
.36011 .29907 m .41133 .27255 L .40366 .29389 L p
1 g
F P
s
P
p
.002 w
.37685 .5624 m .40259 .5828 L .3988 .59337 L p
1 g
F P
s
P
p
.002 w
.3988 .59337 m .36626 .56759 L .37685 .5624 L p
1 g
F P
s
P
p
.002 w
.43655 .60966 m .3988 .59337 L .40259 .5828 L p
1 g
F P
s
P
p
.002 w
.35774 .53642 m .37685 .5624 L .36626 .56759 L p
1 g
F P
s
P
p
.002 w
.36626 .56759 m .34201 .53473 L .35774 .53642 L p
1 g
F P
s
P
p
.002 w
.47293 .26551 m .41133 .27255 L .42129 .25648 L p
1 g
F P
s
P
p
.002 w
.42129 .25648 m .48365 .2491 L .47293 .26551 L p
1 g
F P
s
P
p
.002 w
.40259 .5828 m .43243 .59564 L .43655 .60966 L p
1 g
F P
s
P
p
.002 w
.47593 .61478 m .43655 .60966 L .43243 .59564 L p
1 g
F P
s
P
p
.002 w
.34722 .50736 m .35774 .53642 L .34201 .53473 L p
1 g
F P
s
P
p
.002 w
.34201 .53473 m .32852 .49787 L .34722 .50736 L p
1 g
F P
s
P
p
.002 w
.47593 .61478 m .51313 .60795 L .53258 .61627 L p
1 g
F P
s
P
p
.002 w
.56967 .59456 m .53258 .61627 L .51313 .60795 L p
1 g
F P
s
P
p
.002 w
.53258 .61627 m .56967 .59456 L .59227 .59479 L p
1 g
F P
s
P
p
.002 w
.68321 .40877 m .65572 .34878 L .66322 .33612 L p
1 g
F P
s
P
p
.002 w
.6175 .28632 m .66322 .33612 L .65572 .34878 L p
1 g
F P
s
P
p
.002 w
.62179 .55678 m .59227 .59479 L .56967 .59456 L p
1 g
F P
s
P
p
.002 w
.59227 .59479 m .62179 .55678 L .64368 .54935 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.60363 .56994 L
s
P
p
.002 w
.60905 .29804 m .54905 .26335 L .55866 .25235 L p
1 g
F P
s
P
p
.002 w
.55866 .25235 m .6175 .28632 L .60905 .29804 L p
1 g
F P
s
P
p
.002 w
.3393 .42656 m .32742 .46053 L .3139 .44264 L p
1 g
F P
s
P
p
.002 w
.3139 .44264 m .32769 .40221 L .3393 .42656 L p
1 g
F P
s
P
p
.002 w
.6583 .49711 m .64368 .54935 L .62179 .55678 L p
1 g
F P
s
P
p
.002 w
.64368 .54935 m .6583 .49711 L .67634 .48419 L p
1 g
F P
s
P
p
.002 w
.65572 .34878 m .60905 .29804 L .6175 .28632 L p
1 g
F P
s
P
p
.002 w
.43243 .59564 m .46348 .59959 L .47593 .61478 L p
1 g
F P
s
P
p
.002 w
.51313 .60795 m .47593 .61478 L .46348 .59959 L p
1 g
F P
s
P
p
.002 w
.35607 .37003 m .32769 .40221 L .32141 .37939 L p
1 g
F P
s
P
p
.002 w
.32141 .37939 m .35313 .34282 L .35607 .37003 L p
1 g
F P
s
P
p
.002 w
.67634 .48419 m .67065 .42361 L .68321 .40877 L p
1 g
F P
s
P
p
.002 w
.65572 .34878 m .68321 .40877 L .67065 .42361 L p
1 g
F P
s
P
p
.002 w
.67065 .42361 m .67634 .48419 L .6583 .49711 L p
1 g
F P
s
P
p
.002 w
.34654 .4781 m .34722 .50736 L .32852 .49787 L p
1 g
F P
s
P
p
.002 w
.32852 .49787 m .32742 .46053 L .34654 .4781 L p
1 g
F P
s
P
p
.002 w
.39864 .32001 m .35313 .34282 L .35456 .31896 L p
1 g
F P
s
P
p
.002 w
.35456 .31896 m .40366 .29389 L .39864 .32001 L p
1 g
F P
s
P
p
.002 w
.53759 .2798 m .47293 .26551 L .48365 .2491 L p
1 g
F P
s
P
p
.002 w
.48365 .2491 m .54905 .26335 L .53759 .2798 L p
1 g
F P
s
P
p
.002 w
.46266 .28747 m .40366 .29389 L .41133 .27255 L p
1 g
F P
s
P
p
.002 w
.41133 .27255 m .47293 .26551 L .46266 .28747 L p
1 g
F P
s
P
p
.002 w
.39154 .55308 m .40943 .56727 L .40259 .5828 L p
1 g
F P
s
P
p
.002 w
.40259 .5828 m .37685 .5624 L .39154 .55308 L p
1 g
F P
s
P
p
.002 w
.43243 .59564 m .40259 .5828 L .40943 .56727 L p
1 g
F P
s
P
p
.002 w
.37831 .53501 m .39154 .55308 L .37685 .5624 L p
1 g
F P
s
P
p
.002 w
.37685 .5624 m .35774 .53642 L .37831 .53501 L p
1 g
F P
s
P
p
.002 w
.40943 .56727 m .43018 .57615 L .43243 .59564 L p
1 g
F P
s
P
p
.002 w
.46348 .59959 m .43243 .59564 L .43018 .57615 L p
1 g
F P
s
P
p
.002 w
.51313 .60795 m .54427 .58944 L .56967 .59456 L p
1 g
F P
s
P
p
.002 w
.59557 .56066 m .56967 .59456 L .54427 .58944 L p
1 g
F P
s
P
p
.002 w
.56967 .59456 m .59557 .56066 L .62179 .55678 L p
1 g
F P
s
P
p
.004 w
.60945 .57777 m
.61647 .5872 L
s
P
p
.004 w
.61647 .5872 m
.62593 .59993 L
s
P
p
.004 w
.60457 .57119 m
.60539 .57229 L
s
P
p
.004 w
.60539 .57229 m
.60945 .57777 L
s
P
p
.002 w
.46348 .59959 m .49264 .59407 L .51313 .60795 L p
1 g
F P
s
P
p
.002 w
.54427 .58944 m .51313 .60795 L .49264 .59407 L p
1 g
F P
s
P
p
.002 w
.37113 .51487 m .37831 .53501 L .35774 .53642 L p
1 g
F P
s
P
p
.002 w
.35774 .53642 m .34722 .50736 L .37113 .51487 L p
1 g
F P
s
P
p
.002 w
.67065 .42361 m .64327 .36437 L .65572 .34878 L p
1 g
F P
s
P
p
.002 w
.60905 .29804 m .65572 .34878 L .64327 .36437 L p
1 g
F P
s
P
p
.002 w
.63493 .50845 m .62179 .55678 L .59557 .56066 L p
1 g
F P
s
P
p
.002 w
.62179 .55678 m .63493 .50845 L .6583 .49711 L p
1 g
F P
s
P
p
.002 w
.35608 .45167 m .34654 .4781 L .32742 .46053 L p
1 g
F P
s
P
p
.002 w
.32742 .46053 m .3393 .42656 L .35608 .45167 L p
1 g
F P
s
P
p
.002 w
.36344 .39977 m .3393 .42656 L .32769 .40221 L p
1 g
F P
s
P
p
.002 w
.32769 .40221 m .35607 .37003 L .36344 .39977 L p
1 g
F P
s
P
p
.002 w
.59698 .3142 m .53759 .2798 L .54905 .26335 L p
1 g
F P
s
P
p
.002 w
.54905 .26335 m .60905 .29804 L .59698 .3142 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.43018 .57615 m .4517 .5788 L .46348 .59959 L p
1 g
F P
s
P
p
.002 w
.49264 .59407 m .46348 .59959 L .4517 .5788 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.65252 .43918 m .6583 .49711 L .63493 .50845 L p
1 g
F P
s
P
p
.002 w
.6583 .49711 m .65252 .43918 L .67065 .42361 L p
1 g
F P
s
P
p
.002 w
.64327 .36437 m .59698 .3142 L .60905 .29804 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.39658 .3502 m .35607 .37003 L .35313 .34282 L p
1 g
F P
s
P
p
.002 w
.35313 .34282 m .39864 .32001 L .39658 .3502 L p
1 g
F P
s
P
p
.002 w
.37083 .49471 m .37113 .51487 L .34722 .50736 L p
1 g
F P
s
P
p
.002 w
.34722 .50736 m .34654 .4781 L .37083 .49471 L p
1 g
F P
s
P
p
.002 w
.64327 .36437 m .67065 .42361 L .65252 .43918 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.5246 .3014 m .46266 .28747 L .47293 .26551 L p
1 g
F P
s
P
p
.002 w
.47293 .26551 m .53759 .2798 L .5246 .3014 L p
1 g
F P
s
P
p
.002 w
.45323 .31446 m .39864 .32001 L .40366 .29389 L p
1 g
F P
s
P
p
.002 w
.40366 .29389 m .46266 .28747 L .45323 .31446 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.49264 .59407 m .51434 .5809 L p
.54427 .58944 L 1 g
F P
s
P
p
.002 w
.51095 .58083 m .51079 .57862 L p
.50084 .58061 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.46872 .57265 m .45934 .5689 L .46013 .56945 L 1 g
F
P
p
.002 w
.46881 .57543 m .4517 .5788 L .44659 .56639 L p
1 g
F P
s
P
p
.002 w
.44659 .56639 m .44298 .55763 L p
.45081 .56302 L 1 g
F P
s
P
p
.45748 .57073 m .44659 .56639 L .45081 .56302 L 1 g
F
P
p
.002 w
.45081 .56302 m .45146 .56129 L p
.44283 .55379 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4682 .57501 L p
1 g
F P
s
P
p
.48921 .57862 m .4682 .57501 L .46858 .57516 L 1 g
F
P
p
.4682 .57501 m .45748 .57073 L .45081 .56302 L 1 g
F
P
p
.46881 .57543 m .44659 .56639 L .4682 .57501 L 1 g
F
P
p
.002 w
.46819 .5751 m .4682 .57501 L p
.45177 .56633 L 1 g
F P
s
P
p
.002 w
.4682 .57501 m .46872 .57265 L p
.46013 .56945 L 1 g
F P
s
P
p
.46013 .56945 m .45177 .56633 L .4682 .57501 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.44298 .55763 m .44103 .55287 L p
.46838 .57508 L 1 g
F P
s
P
p
.46881 .57543 m .4682 .57501 L .46838 .57508 L 1 g
F
P
p
.4682 .57501 m .44298 .55763 L .46838 .57508 L 1 g
F
P
p
.48921 .57862 m .46858 .57516 L .47067 .57584 L 1 g
F
P
p
.002 w
.4691 .57537 m .46881 .57543 L p
.46838 .57508 L 1 g
F P
s
P
p
.46858 .57516 m .46819 .5751 L .4691 .57537 L 1 g
F
P
p
.46858 .57516 m .4691 .57537 L .47067 .57584 L 1 g
F
P
p
.002 w
.4517 .5788 m .46881 .57543 L p
.49264 .59407 L 1 g
F P
s
P
p
.002 w
.46881 .57543 m .4691 .57537 L p
.46992 .57602 L 1 g
F P
s
P
p
.49264 .59407 m .46881 .57543 L .46992 .57602 L 1 g
F
P
p
.002 w
.47391 .57681 m .49264 .59407 L p
.4691 .57537 L 1 g
F P
s
P
p
.002 w
.46819 .5751 m .46811 .57545 L p
.47004 .57575 L 1 g
F P
s
P
p
.47067 .57584 m .4691 .57537 L .47004 .57575 L 1 g
F
P
p
.4691 .57537 m .46819 .5751 L .47004 .57575 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.42997 .55157 m .43097 .53663 L p
.43896 .54953 L 1 g
F P
s
P
p
.002 w
.4383 .54745 m .43925 .54566 L p
.43524 .53773 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4383 .54745 L p
1 g
F P
s
P
p
.45146 .56129 m .4383 .54745 L .44027 .55034 L 1 g
F
P
p
.002 w
.44188 .55269 m .44103 .55287 L .44027 .55034 L p
1 g
F P
s
P
p
.44039 .55052 m .44027 .55034 L .44038 .55051 L 1 g
F
P
p
.45146 .56129 m .44027 .55034 L .44039 .55052 L 1 g
F
P
p
.002 w
.44027 .55034 m .44103 .55287 L p
.43097 .53663 L 1 g
F P
s
P
p
.45146 .56129 m .43794 .54814 L .44283 .55379 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.4319 .52254 m .43262 .52359 L p
.43258 .52459 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52883 L p
1 g
F P
s
P
p
.002 w
.43097 .53663 m .43165 .52634 L p
.43215 .52792 L 1 g
F P
s
P
p
.43925 .54566 m .43244 .52883 L .43524 .53773 L 1 g
F
P
p
.002 w
.43244 .52883 m .43346 .52734 L p
.43258 .52478 L 1 g
F P
s
P
p
.002 w
.43258 .52478 m .44027 .55034 L p
.43211 .53832 L 1 g
F P
s
P
p
.43211 .53832 m .43097 .53663 L .43258 .52478 L 1 g
F
P
p
.002 w
.43244 .52883 m .43146 .53025 L p
.43524 .53773 L 1 g
F P
s
P
p
.002 w
.4319 .52254 m .43258 .52478 L p
.43215 .52792 L 1 g
F P
s
P
p
.002 w
.43165 .52634 m .4319 .52254 L p
.43215 .52792 L 1 g
F P
s
P
p
.43346 .52734 m .43312 .5177 L .43258 .52478 L 1 g
F
P
p
.002 w
.43299 .51911 m .4319 .52254 L p
.43332 .51063 L 1 g
F P
s
P
p
.43573 .49037 m .43392 .50937 L .43332 .51063 L 1 g
F
P
p
.43392 .50937 m .43299 .51911 L .43332 .51063 L 1 g
F
P
p
.002 w
.4319 .52254 m .43032 .48896 L .43573 .49037 L p
1 g
F P
s
P
p
.002 w
.43392 .50937 m .43485 .50826 L p
.43857 .49956 L 1 g
F P
s
P
p
.43312 .5177 m .43311 .51782 L .43258 .52478 L 1 g
F
P
p
.43312 .51768 m .43304 .51851 L .43258 .52478 L 1 g
F
P
p
.43312 .51753 m .43297 .51915 L .43258 .52478 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44027 .55034 m .43258 .52478 L p
.44188 .55269 L 1 g
F P
s
P
p
.002 w
.43258 .52478 m .4319 .52254 L p
.43258 .52459 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43312 .51032 L p
1 g
F P
s
P
p
.43346 .52734 m .43312 .51032 L .43299 .51382 L 1 g
F
P
p
.43311 .51725 m .4329 .51982 L .43258 .52478 L 1 g
F
P
p
.002 w
.43277 .52149 m .4319 .52254 L .43299 .51911 L p
1 g
F P
s
P
p
.43309 .51682 m .43282 .52058 L .43258 .52478 L 1 g
F
P
p
.43307 .51622 m .43274 .52146 L .43258 .52478 L 1 g
F
P
p
.002 w
.43271 .52209 m .4319 .52254 L .43277 .52149 L p
1 g
F P
s
P
p
.43305 .51547 m .43268 .52247 L .43258 .52478 L 1 g
F
P
p
.002 w
.43269 .52241 m .4319 .52254 L .43271 .52209 L p
1 g
F P
s
P
p
.43302 .51462 m .43262 .52359 L .43258 .52478 L 1 g
F
P
p
.44188 .55269 m .43258 .52478 L .43258 .52459 L 1 g
F
P
p
.002 w
.43312 .51032 m .43287 .51061 L p
.43299 .51382 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43573 .49037 m .4416 .49188 L .44037 .49576 L p
1 g
F P
s
P
p
.002 w
.4416 .49188 m .45329 .45878 L p
.45288 .47073 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44238 .49157 L p
1 g
F P
s
P
p
.43485 .50826 m .44238 .49157 L .44221 .49191 L 1 g
F
P
p
.45288 .47073 m .44238 .49157 L .4416 .49188 L 1 g
F
P
p
.002 w
.44208 .49217 m .44189 .49205 L p
.44238 .49157 L 1 g
F P
s
P
p
.002 w
.44189 .49205 m .4416 .49188 L p
.44238 .49157 L 1 g
F P
s
P
p
.44229 .49172 m .44234 .49161 L .44229 .49172 L 1 g
F
P
p
.43485 .50826 m .44234 .49161 L .44229 .49172 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44238 .49157 m .44339 .4905 L p
.45032 .48386 L 1 g
F P
s
P
p
.43485 .50826 m .44229 .49172 L .43857 .49956 L 1 g
F
P
p
.002 w
.4416 .49188 m .44208 .49217 L p
.44056 .49537 L 1 g
F P
s
P
p
.44229 .49172 m .44234 .49162 L .44037 .49576 L 1 g
F
P
p
.44229 .49172 m .44037 .49576 L .43857 .49956 L 1 g
F
P
p
.002 w
.43299 .51911 m .44037 .49576 L p
.43277 .52149 L 1 g
F P
s
P
p
.002 w
.44037 .49576 m .4416 .49188 L p
.44056 .49537 L 1 g
F P
s
P
p
.44056 .49537 m .43277 .52149 L .44037 .49576 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45196 .49802 m .44208 .49217 L p
.44238 .49157 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4577 .47669 L p
1 g
F P
s
P
p
.44339 .4905 m .4577 .47669 L .45032 .48386 L 1 g
F
P
p
.45288 .47073 m .45251 .48173 L .44238 .49157 L 1 g
F
P
p
.45251 .48173 m .45196 .49802 L .44238 .49157 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47389 .47094 m .45196 .49802 L p
.4526 .47909 L 1 g
F P
s
P
p
.002 w
.4577 .47669 m .45826 .47608 L p
.46933 .47123 L 1 g
F P
s
P
p
.002 w
.47214 .46991 m .47389 .47094 L p
.4526 .47909 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46726 L p
1 g
F P
s
P
p
.002 w
.49027 .4882 m .47389 .47094 L .4764 .46781 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.4775 .46726 m .49027 .4882 L .4764 .46781 L 1 g
F
P
p
.002 w
.4775 .46726 m .47786 .46667 L p
.48813 .46563 L 1 g
F P
s
P
p
.49364 .46478 m .49027 .4882 L .4775 .46726 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .48813 .46563 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52089 .46774 m .49027 .4882 L p
.49392 .46283 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .4673 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54216 .47653 L p
1 g
F P
s
P
p
.53431 .47284 m .53579 .49769 L .52252 .4673 L 1 g
F
P
p
.52214 .46667 m .54216 .47653 L .53167 .4716 L 1 g
F
P
p
.54202 .4764 m .542 .47646 L .53406 .46866 L 1 g
F
P
p
.542 .47646 m .53579 .49769 L .53431 .47284 L 1 g
F
P
p
.542 .47646 m .53431 .47284 L .53406 .46866 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56583 .50906 L p
1 g
F P
s
P
p
.56981 .48479 m .57328 .52472 L .56583 .50906 L 1 g
F
P
p
.5643 .49288 m .56583 .50906 L .56067 .49822 L 1 g
F
P
p
.56981 .48479 m .56583 .50906 L .5643 .49288 L 1 g
F
P
p
.002 w
.56583 .50906 m .56515 .50826 L p
.56669 .51827 L 1 g
F P
s
P
p
.55661 .4905 m .56583 .50906 L .56088 .49867 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56745 .52867 L p
1 g
F P
s
P
p
.57481 .52454 m .5675 .53023 L .56745 .52867 L 1 g
F
P
p
.002 w
.56737 .5254 m .5686 .52526 L p
.56745 .52867 L 1 g
F P
s
P
p
.002 w
.5686 .52526 m .57481 .52454 L p
.56745 .52867 L 1 g
F P
s
P
p
.002 w
.56745 .52867 m .56654 .52734 L p
.56491 .53627 L 1 g
F P
s
P
p
.56515 .50826 m .56745 .52867 L .5674 .52649 L 1 g
F
P
p
.56515 .50826 m .56771 .52904 L .56669 .51827 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56137 .54683 L p
1 g
F P
s
P
p
.56654 .52734 m .56137 .54683 L .56491 .53627 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56745 .52867 m .53333 .55681 L .56737 .5254 L 1 g
F
P
p
.5675 .53023 m .56673 .53083 L .56745 .52867 L 1 g
F
P
p
.56673 .53083 m .53333 .55681 L .56745 .52867 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.57481 .52454 m .57343 .53006 L p
.53333 .55681 L 1 g
F P
s
P
p
.002 w
.57343 .53006 m .56577 .56072 L .55253 .55912 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56282 L p
1 g
F P
s
P
p
.56577 .56072 m .54304 .56939 L .54911 .56282 L 1 g
F
P
p
.002 w
.55253 .55912 m .55445 .55936 L p
.54911 .56282 L 1 g
F P
s
P
p
.002 w
.55445 .55936 m .56577 .56072 L p
.54911 .56282 L 1 g
F P
s
P
p
.002 w
.54911 .56282 m .54854 .56129 L p
.54229 .56725 L 1 g
F P
s
P
p
.56075 .54566 m .54911 .56282 L .55137 .56038 L 1 g
F
P
p
.56075 .54566 m .54937 .56352 L .55594 .55438 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58083 L p
1 g
F P
s
P
p
.51434 .5809 m .51095 .58083 L .51218 .5806 L 1 g
F
P
p
.53128 .57265 m .51095 .58083 L .51604 .57987 L 1 g
F
P
p
.002 w
.56512 .56159 m .54427 .58944 L .52115 .58096 L p
1 g
F P
s
P
p
.002 w
.52115 .58096 m .5173 .57955 L p
.53161 .57418 L 1 g
F P
s
P
p
.56512 .56159 m .52115 .58096 L .53161 .57418 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53161 .57418 L p
1 g
F P
s
P
p
.54854 .56129 m .53161 .57418 L .54229 .56725 L 1 g
F
P
p
.53128 .57265 m .51604 .57987 L .5173 .57955 L 1 g
F
P
p
.51926 .57882 m .5173 .57955 L .51832 .5793 L 1 g
F
P
p
.53128 .57265 m .5173 .57955 L .51926 .57882 L 1 g
F
P
p
.002 w
.51434 .5809 m .51604 .57987 L p
.51994 .58052 L 1 g
F P
s
P
p
.002 w
.5173 .57955 m .51994 .58052 L p
.51604 .57987 L 1 g
F P
s
P
p
.002 w
.51994 .58052 m .54427 .58944 L p
.51434 .5809 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.56577 .56072 m .56512 .56159 L p
.51684 .57938 L 1 g
F P
s
P
p
.002 w
.5173 .57955 m .51684 .57938 L p
.56512 .56159 L 1 g
F P
s
P
p
.54911 .56282 m .51684 .57938 L .55253 .55912 L 1 g
F
P
p
.54304 .56939 m .53321 .57314 L .54911 .56282 L 1 g
F
P
p
.53321 .57314 m .51684 .57938 L .54911 .56282 L 1 g
F
P
p
.002 w
.53161 .57418 m .5322 .57686 L p
.54229 .56725 L 1 g
F P
s
P
p
.51832 .5793 m .5173 .57955 L .5179 .57952 L 1 g
F
P
p
.5173 .57955 m .51604 .57987 L .51689 .57971 L 1 g
F
P
p
.5173 .57955 m .51689 .57971 L .5179 .57952 L 1 g
F
P
p
.002 w
.51604 .57987 m .51684 .57938 L .5173 .57955 L p
1 g
F P
s
P
p
.002 w
.49264 .59407 m .47748 .5801 L p
.48908 .58035 L 1 g
F P
s
P
p
.002 w
.51434 .5809 m .50797 .58476 L p
.48908 .58035 L 1 g
F P
s
P
p
.002 w
.50797 .58476 m .49264 .59407 L p
.48908 .58035 L 1 g
F P
s
P
p
.002 w
.47748 .5801 m .47391 .57681 L p
.48908 .58035 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58035 L p
1 g
F P
s
P
p
.002 w
.48908 .58035 m .48921 .57862 L p
.47757 .57766 L 1 g
F P
s
P
p
.47757 .57766 m .4678 .57686 L .48908 .58035 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.51684 .57938 m .51434 .5809 L p
.47178 .57484 L 1 g
F P
s
P
p
.002 w
.51095 .58083 m .51111 .583 L p
.5179 .57952 L 1 g
F P
s
P
p
.48921 .57862 m .46811 .57545 L .47757 .57766 L 1 g
F
P
p
.51218 .5806 m .48908 .58035 L .47178 .57484 L 1 g
F
P
p
.51095 .58083 m .48908 .58035 L .51218 .5806 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56282 L p
1 g
F P
s
P
p
.54229 .56725 m .5322 .57686 L .54911 .56282 L 1 g
F
P
p
.002 w
.54911 .56282 m .54937 .56352 L p
.55137 .56038 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.51684 .57938 m .53333 .55681 L .55253 .55912 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55253 .55912 m .53333 .55681 L p
.57343 .53006 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54998 .56518 L p
.55594 .55438 L 1 g
F P
s
P
p
.002 w
.56137 .54683 m .56257 .5491 L p
.56491 .53627 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56745 .52867 L p
1 g
F P
s
P
p
.56491 .53627 m .56257 .5491 L .56745 .52867 L 1 g
F
P
p
.002 w
.56745 .52867 m .56771 .52904 L p
.5674 .52649 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.53333 .55681 m .54001 .52856 L .56737 .5254 L p
1 g
F P
s
P
p
.002 w
.55738 .49132 m .55661 .4905 L p
.56088 .49867 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55738 .49132 L p
1 g
F P
s
P
p
.54174 .47608 m .55738 .49132 L .5565 .49047 L 1 g
F
P
p
.56067 .49822 m .54001 .52856 L .5564 .49037 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55738 .49132 m .5564 .49037 L .55665 .48978 L 1 g
F
P
p
.56067 .49822 m .5564 .49037 L .55738 .49132 L 1 g
F
P
p
.5622 .49597 m .56067 .49822 L .55738 .49132 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55738 .49132 L p
1 g
F P
s
P
p
.56088 .49867 m .56713 .51061 L .55738 .49132 L 1 g
F
P
p
.002 w
.54001 .52856 m .53579 .49769 L .55603 .49002 L p
1 g
F P
s
P
p
.002 w
.55603 .49002 m .55665 .48978 L p
.5564 .49037 L 1 g
F P
s
P
p
.5564 .49037 m .54001 .52856 L .55603 .49002 L 1 g
F
P
p
.54174 .47608 m .5565 .49047 L .5484 .4826 L 1 g
F
P
p
.5565 .49047 m .55749 .49143 L .55603 .49002 L 1 g
F
P
p
.5565 .49047 m .55603 .49002 L .5484 .4826 L 1 g
F
P
p
.002 w
.55088 .44609 m .56981 .48479 L .55603 .49002 L p
1 g
F P
s
P
p
.002 w
.55603 .49002 m .53579 .49769 L p
.54202 .4764 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.55088 .44609 m .55603 .49002 L .54202 .4764 L 1 g
F
P
p
.002 w
.55749 .49143 m .55834 .49233 L p
.55199 .48612 L 1 g
F P
s
P
p
.5484 .4826 m .55603 .49002 L .55199 .48612 L 1 g
F
P
p
.55603 .49002 m .55749 .49143 L .55199 .48612 L 1 g
F
P
p
.002 w
.55738 .49132 m .55749 .49143 L p
.5565 .49047 L 1 g
F P
s
P
p
.002 w
.55665 .48978 m .56981 .48479 L p
.5622 .49597 L 1 g
F P
s
P
p
.5622 .49597 m .55738 .49132 L .55665 .48978 L 1 g
F
P
p
.56067 .49822 m .56583 .50906 L .54001 .52856 L 1 g
F
P
p
.002 w
.57328 .52472 m .56737 .5254 L p
.56583 .50906 L 1 g
F P
s
P
p
.002 w
.56737 .5254 m .54001 .52856 L p
.56583 .50906 L 1 g
F P
s
P
p
.002 w
.56771 .52904 m .56854 .53025 L p
.56669 .51827 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56583 .50906 L p
1 g
F P
s
P
p
.56669 .51827 m .56854 .53025 L .56583 .50906 L 1 g
F
P
p
.002 w
.56583 .50906 m .56713 .51061 L p
.56088 .49867 L 1 g
F P
s
P
p
.002 w
.56981 .48479 m .57481 .52454 L .57328 .52472 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52252 .4673 L p
1 g
F P
s
P
p
.002 w
.52252 .4673 m .52214 .46667 L p
.53167 .4716 L 1 g
F P
s
P
p
.53167 .4716 m .54302 .47747 L .52252 .4673 L 1 g
F
P
p
.002 w
.54216 .47653 m .54302 .47747 L p
.53167 .4716 L 1 g
F P
s
P
p
.52252 .4673 m .53579 .49769 L .52164 .4672 L 1 g
F
P
p
.53406 .46866 m .53431 .47284 L .52252 .4673 L 1 g
F
P
p
.54394 .46983 m .54202 .4764 L .53406 .46866 L 1 g
F
P
p
.5 .4634 m .52252 .4673 L .52147 .46718 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.52001 .41322 m .55088 .44609 L .52164 .4672 L p
1 g
F P
s
P
p
.002 w
.52164 .4672 m .52089 .46774 L p
.52088 .46709 L 1 g
F P
s
P
p
.002 w
.53579 .49769 m .52089 .46774 L .52164 .4672 L p
1 g
F P
s
P
p
.5 .4634 m .52136 .46716 L .51174 .46566 L 1 g
F
P
p
.52136 .46716 m .52256 .46737 L .52018 .46699 L 1 g
F
P
p
.52136 .46716 m .52018 .46699 L .51174 .46566 L 1 g
F
P
p
.002 w
.49687 .4423 m .52001 .41322 L p
.52088 .46709 L 1 g
F P
s
P
p
.002 w
.52089 .46774 m .52018 .46699 L p
.52088 .46709 L 1 g
F P
s
P
p
.002 w
.52018 .46699 m .49687 .4423 L p
.52088 .46709 L 1 g
F P
s
P
p
.52001 .41322 m .52164 .4672 L .52088 .46709 L 1 g
F
P
p
.52147 .46718 m .52164 .4672 L .52256 .46737 L 1 g
F
P
p
.002 w
.52252 .4673 m .52254 .46732 L p
.52164 .4672 L 1 g
F P
s
P
p
.002 w
.52254 .46732 m .52256 .46737 L p
.52164 .4672 L 1 g
F P
s
P
p
.002 w
.52164 .4672 m .55088 .44609 L p
.54394 .46983 L 1 g
F P
s
P
p
.002 w
.52018 .46699 m .52089 .46774 L p
.49392 .46283 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49687 .4423 m .52018 .46699 L p
.49392 .46283 L 1 g
F P
s
P
p
.002 w
.52256 .46737 m .52282 .46778 L p
.51174 .46566 L 1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .46442 L p
.48813 .46563 L 1 g
F P
s
P
p
.49687 .4423 m .4945 .45877 L .4775 .46726 L 1 g
F
P
p
.45826 .47608 m .4775 .46726 L .4764 .46781 L 1 g
F
P
p
.002 w
.47389 .47094 m .47214 .46991 L p
.47361 .46918 L 1 g
F P
s
P
p
.45826 .47608 m .4764 .46781 L .47045 .47073 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46656 .42446 m .49687 .4423 L .4764 .46781 L p
1 g
F P
s
P
p
.002 w
.4764 .46781 m .47389 .47094 L p
.47361 .46918 L 1 g
F P
s
P
p
.46656 .42446 m .4764 .46781 L .47361 .46918 L 1 g
F
P
p
.47126 .47038 m .4764 .46781 L .47718 .46778 L 1 g
F
P
p
.002 w
.4775 .46726 m .4775 .46727 L p
.4764 .46781 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .47718 .46778 L p
.4764 .46781 L 1 g
F P
s
P
p
.47045 .47073 m .4764 .46781 L .47126 .47038 L 1 g
F
P
p
.002 w
.45329 .45878 m .46656 .42446 L p
.47361 .46918 L 1 g
F P
s
P
p
.002 w
.47214 .46991 m .45329 .45878 L p
.47361 .46918 L 1 g
F P
s
P
p
.002 w
.4764 .46781 m .47675 .46738 L p
.4775 .46726 L 1 g
F P
s
P
p
.002 w
.47675 .46738 m .49687 .4423 L p
.4775 .46726 L 1 g
F P
s
P
p
.4945 .45877 m .49364 .46478 L .4775 .46726 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46726 L p
1 g
F P
s
P
p
.48813 .46563 m .5 .46442 L .4775 .46726 L 1 g
F
P
p
.002 w
.45329 .45878 m .47214 .46991 L p
.4526 .47909 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4577 .47669 L p
1 g
F P
s
P
p
.46933 .47123 m .47718 .46778 L .4577 .47669 L 1 g
F
P
p
.002 w
.4577 .47669 m .45698 .47747 L p
.45032 .48386 L 1 g
F P
s
P
p
.002 w
.44238 .49157 m .44234 .49161 L p
.44221 .49191 L 1 g
F P
s
P
p
.002 w
.44234 .49161 m .44234 .49162 L p
.44229 .49172 L 1 g
F P
s
P
p
.43573 .49037 m .44037 .49576 L .43392 .50937 L 1 g
F
P
p
.002 w
.44234 .49162 m .44166 .49233 L p
.43857 .49956 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44238 .49157 L p
1 g
F P
s
P
p
.45032 .48386 m .45698 .47747 L .44238 .49157 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.45196 .49802 m .43277 .52149 L p
.44056 .49537 L 1 g
F P
s
P
p
.002 w
.44208 .49217 m .45196 .49802 L p
.44056 .49537 L 1 g
F P
s
P
p
.002 w
.44037 .49576 m .43299 .51911 L p
.43392 .50937 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43392 .50937 L p
1 g
F P
s
P
p
.43857 .49956 m .44166 .49233 L .43392 .50937 L 1 g
F
P
p
.43312 .5177 m .43312 .51768 L .43311 .51782 L 1 g
F
P
p
.43312 .51768 m .43312 .51753 L .43304 .51851 L 1 g
F
P
p
.43312 .51753 m .43311 .51725 L .43297 .51915 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.45196 .49802 m .46023 .50669 L .43271 .52209 L p
1 g
F P
s
P
p
.002 w
.43277 .52149 m .45196 .49802 L p
.43271 .52209 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.46023 .50669 m .46549 .51692 L .43269 .52241 L p
1 g
F P
s
P
p
.002 w
.43271 .52209 m .46023 .50669 L p
.43269 .52241 L 1 g
F P
s
P
p
.43311 .51725 m .43309 .51682 L .4329 .51982 L 1 g
F
P
p
.43309 .51682 m .43307 .51622 L .43282 .52058 L 1 g
F
P
p
.002 w
.46549 .51692 m .46717 .52755 L .43267 .52265 L p
1 g
F P
s
P
p
.002 w
.43267 .52265 m .4319 .52254 L .43269 .52241 L p
1 g
F P
s
P
p
.002 w
.43269 .52241 m .46549 .51692 L p
.43267 .52265 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.46717 .52755 m .46513 .5374 L .43265 .52288 L p
1 g
F P
s
P
p
.002 w
.43265 .52288 m .4319 .52254 L .43267 .52265 L p
1 g
F P
s
P
p
.002 w
.43267 .52265 m .46717 .52755 L p
.43265 .52288 L 1 g
F P
s
P
p
.43307 .51622 m .43305 .51547 L .43274 .52146 L 1 g
F
P
p
.43305 .51547 m .43302 .51462 L .43268 .52247 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.46513 .5374 m .45962 .54542 L .43264 .52315 L p
1 g
F P
s
P
p
.002 w
.43264 .52315 m .4319 .52254 L .43265 .52288 L p
1 g
F P
s
P
p
.002 w
.43265 .52288 m .46513 .5374 L p
.43264 .52315 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45962 .54542 m .45127 .55075 L .43262 .52359 L p
1 g
F P
s
P
p
.002 w
.43262 .52359 m .4319 .52254 L .43264 .52315 L p
1 g
F P
s
P
p
.002 w
.43264 .52315 m .45962 .54542 L p
.43262 .52359 L 1 g
F P
s
P
p
.43302 .51462 m .43299 .51382 L .43262 .52359 L 1 g
F
P
p
.002 w
.43242 .52885 m .43244 .52883 L p
.43258 .52478 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43242 .52885 L p
1 g
F P
s
P
p
.43299 .51382 m .43287 .51061 L .43242 .52885 L 1 g
F
P
p
.002 w
.45127 .55075 m .44188 .55269 L p
.43258 .52459 L 1 g
F P
s
P
p
.002 w
.43262 .52359 m .45127 .55075 L p
.43258 .52459 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.43524 .53773 m .43146 .53025 L .4383 .54745 L 1 g
F
P
p
.002 w
.44103 .55287 m .43997 .55274 L p
.43896 .54953 L 1 g
F P
s
P
p
.002 w
.43997 .55274 m .42997 .55157 L p
.43896 .54953 L 1 g
F P
s
P
p
.002 w
.4383 .54745 m .43794 .54814 L p
.44038 .55051 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.44103 .55287 m .45127 .55075 L .47178 .57484 L p
1 g
F P
s
P
p
.002 w
.43794 .54814 m .43743 .5491 L p
.44283 .55379 L 1 g
F P
s
P
p
.002 w
.47178 .57484 m .4691 .57537 L p
.4443 .55549 L 1 g
F P
s
P
p
.44366 .55475 m .4443 .55549 L .44103 .55287 L 1 g
F
P
p
.47178 .57484 m .4443 .55549 L .44366 .55475 L 1 g
F
P
p
.4691 .57537 m .46838 .57508 L .44103 .55287 L 1 g
F
P
p
.002 w
.42997 .55157 m .44103 .55287 L .4517 .5788 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45081 .56302 L p
1 g
F P
s
P
p
.44283 .55379 m .43743 .5491 L .45081 .56302 L 1 g
F
P
p
.002 w
.4682 .57501 m .46819 .5751 L p
.46858 .57516 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .45177 .56633 L p
.46013 .56945 L 1 g
F P
s
P
p
.45934 .5689 m .45002 .56518 L .46013 .56945 L 1 g
F
P
p
.002 w
.45177 .56633 m .4678 .57686 L .46819 .5751 L p
1 g
F P
s
P
p
.002 w
.4691 .57537 m .47178 .57484 L .47391 .57681 L p
1 g
F P
s
P
p
.002 w
.46811 .57545 m .4678 .57686 L p
.47757 .57766 L 1 g
F P
s
P
p
.002 w
.47391 .57681 m .47178 .57484 L p
.48908 .58035 L 1 g
F P
s
P
p
.002 w
.51098 .58113 m .51095 .58083 L p
.4916 .58246 L 1 g
F P
s
P
p
.50084 .58061 m .4916 .58246 L .51095 .58083 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58113 L p
1 g
F P
s
P
p
.4916 .58246 m .48889 .583 L .51098 .58113 L 1 g
F
P
p
.002 w
.54427 .58944 m .56577 .56072 L .59557 .56066 L p
1 g
F P
s
P
p
.004 w
.49297 .44001 m
.5 .43051 L
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.41005 .5397 m .41927 .54701 L .40943 .56727 L p
1 g
F P
s
P
p
.002 w
.40943 .56727 m .39154 .55308 L .41005 .5397 L p
1 g
F P
s
P
p
.004 w
.39095 .57789 m
.40342 .56103 L
s
P
p
.002 w
.43018 .57615 m .40943 .56727 L .41927 .54701 L p
1 g
F P
s
P
p
.002 w
.40327 .53037 m .41005 .5397 L .39154 .55308 L p
1 g
F P
s
P
p
.002 w
.39154 .55308 m .37831 .53501 L .40327 .53037 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.41927 .54701 m .42997 .55157 L .43018 .57615 L p
1 g
F P
s
P
p
.002 w
.4517 .5788 m .43018 .57615 L .42997 .55157 L p
1 g
F P
s
P
p
.002 w
.60681 .51773 m .59557 .56066 L .56577 .56072 L p
1 g
F P
s
P
p
.002 w
.59557 .56066 m .60681 .51773 L .63493 .50845 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.37513 .43103 m .35608 .45167 L .3393 .42656 L p
1 g
F P
s
P
p
.002 w
.3393 .42656 m .36344 .39977 L .37513 .43103 L p
1 g
F P
s
P
p
.002 w
.37758 .47665 m .37083 .49471 L .34654 .4781 L p
1 g
F P
s
P
p
.002 w
.34654 .4781 m .35608 .45167 L .37758 .47665 L p
1 g
F P
s
P
p
.002 w
.39965 .52002 m .40327 .53037 L .37831 .53501 L p
1 g
F P
s
P
p
.002 w
.37831 .53501 m .37113 .51487 L .39965 .52002 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.65252 .43918 m .62603 .38251 L .64327 .36437 L p
1 g
F P
s
P
p
.002 w
.59698 .3142 m .64327 .36437 L .62603 .38251 L p
1 g
F P
s
P
p
.002 w
.39766 .38348 m .36344 .39977 L .35607 .37003 L p
1 g
F P
s
P
p
.002 w
.35607 .37003 m .39658 .3502 L .39766 .38348 L p
1 g
F P
s
P
p
.002 w
.62919 .45495 m .63493 .50845 L .60681 .51773 L p
1 g
F P
s
P
p
.002 w
.63493 .50845 m .62919 .45495 L .65252 .43918 L p
1 g
F P
s
P
p
.002 w
.58155 .33446 m .5246 .3014 L .53759 .2798 L p
1 g
F P
s
P
p
.002 w
.53759 .2798 m .59698 .3142 L .58155 .33446 L p
1 g
F P
s
P
p
.002 w
.39959 .50972 m .39965 .52002 L .37113 .51487 L p
1 g
F P
s
P
p
.002 w
.37113 .51487 m .37083 .49471 L .39959 .50972 L p
1 g
F P
s
P
p
.002 w
.62603 .38251 m .65252 .43918 L .62919 .45495 L p
1 g
F P
s
P
p
.002 w
.62603 .38251 m .58155 .33446 L .59698 .3142 L p
1 g
F P
s
P
p
.002 w
.44502 .34567 m .39658 .3502 L .39864 .32001 L p
1 g
F P
s
P
p
.002 w
.39864 .32001 m .45323 .31446 L .44502 .34567 L p
1 g
F P
s
P
p
.002 w
.47178 .57484 m .48828 .56458 L .51684 .57938 L p
1 g
F P
s
P
p
.002 w
.53333 .55681 m .51684 .57938 L .48828 .56458 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51048 .3276 m .45323 .31446 L .46266 .28747 L p
1 g
F P
s
P
p
.002 w
.46266 .28747 m .5246 .3014 L .51048 .3276 L p
1 g
F P
s
P
p
.002 w
.48828 .56458 m .47178 .57484 L .45127 .55075 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.56577 .56072 m .57481 .52454 L .60681 .51773 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39083 .4627 m .37758 .47665 L .35608 .45167 L p
1 g
F P
s
P
p
.002 w
.35608 .45167 m .37513 .43103 L .39083 .4627 L p
1 g
F P
s
P
p
.002 w
.40315 .50058 m .39959 .50972 L .37083 .49471 L p
1 g
F P
s
P
p
.002 w
.37083 .49471 m .37758 .47665 L .40315 .50058 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.41927 .54701 m .41005 .5397 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.42997 .55157 m .41927 .54701 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.41005 .5397 m .40327 .53037 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40192 .41869 m .37513 .43103 L .36344 .39977 L p
1 g
F P
s
P
p
.002 w
.36344 .39977 m .39766 .38348 L .40192 .41869 L p
1 g
F P
s
P
p
.002 w
.40327 .53037 m .39965 .52002 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.60132 .47035 m .60681 .51773 L .57481 .52454 L p
1 g
F P
s
P
p
.002 w
.60681 .51773 m .60132 .47035 L .62919 .45495 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.62919 .45495 m .60442 .40266 L .62603 .38251 L p
1 g
F P
s
P
p
.002 w
.58155 .33446 m .62603 .38251 L .60442 .40266 L p
1 g
F P
s
P
p
.002 w
.45127 .55075 m .45962 .54542 L .48828 .56458 L p
1 g
F P
s
P
p
.002 w
.49936 .54896 m .48828 .56458 L .45962 .54542 L p
1 g
F P
s
P
p
.002 w
.48828 .56458 m .49936 .54896 L .53333 .55681 L p
1 g
F P
s
P
p
.002 w
.39965 .52002 m .39959 .50972 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60442 .40266 m .62919 .45495 L .60132 .47035 L p
1 g
F P
s
P
p
.002 w
.56315 .35827 m .51048 .3276 L .5246 .3014 L p
1 g
F P
s
P
p
.002 w
.5246 .3014 m .58155 .33446 L .56315 .35827 L p
1 g
F P
s
P
p
.002 w
.43838 .38004 m .39766 .38348 L .39658 .3502 L p
1 g
F P
s
P
p
.002 w
.39658 .3502 m .44502 .34567 L .43838 .38004 L p
1 g
F P
s
P
p
.002 w
.40998 .4936 m .40315 .50058 L .37758 .47665 L p
1 g
F P
s
P
p
.002 w
.37758 .47665 m .39083 .4627 L .40998 .4936 L p
1 g
F P
s
P
p
.002 w
.54001 .52856 m .53333 .55681 L .49936 .54896 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.39959 .50972 m .40315 .50058 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.60442 .40266 m .56315 .35827 L .58155 .33446 L p
1 g
F P
s
P
p
.002 w
.49573 .35758 m .44502 .34567 L .45323 .31446 L p
1 g
F P
s
P
p
.002 w
.45323 .31446 m .51048 .3276 L .49573 .35758 L p
1 g
F P
s
P
p
.002 w
.40925 .4545 m .39083 .4627 L .37513 .43103 L p
1 g
F P
s
P
p
.002 w
.37513 .43103 m .40192 .41869 L .40925 .4545 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.45962 .54542 m .46513 .5374 L .49936 .54896 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57481 .52454 m .56981 .48479 L .60132 .47035 L p
1 g
F P
s
P
p
.002 w
.40315 .50058 m .40998 .4936 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.50367 .52958 m .49936 .54896 L .46513 .5374 L p
1 g
F P
s
P
p
.002 w
.49936 .54896 m .50367 .52958 L .54001 .52856 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.41938 .48956 m .43032 .48896 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.40998 .4936 m .41938 .48956 L .4319 .52254 L closepath p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.41938 .48956 m .40998 .4936 L .39083 .4627 L p
1 g
F P
s
P
p
.002 w
.39083 .4627 m .40925 .4545 L .41938 .48956 L p
1 g
F P
s
P
p
.002 w
.4336 .41632 m .40192 .41869 L .39766 .38348 L p
1 g
F P
s
P
p
.002 w
.39766 .38348 m .43838 .38004 L .4336 .41632 L p
1 g
F P
s
P
p
.002 w
.46513 .5374 m .46717 .52755 L .50367 .52958 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.57907 .42411 m .60132 .47035 L .56981 .48479 L p
1 g
F P
s
P
p
.002 w
.60132 .47035 m .57907 .42411 L .60442 .40266 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.56315 .35827 m .60442 .40266 L .57907 .42411 L p
1 g
F P
s
P
p
.002 w
.53579 .49769 m .54001 .52856 L .50367 .52958 L p
1 g
F P
s
P
p
.002 w
.54238 .38485 m .49573 .35758 L .51048 .3276 L p
1 g
F P
s
P
p
.002 w
.51048 .3276 m .56315 .35827 L .54238 .38485 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.46717 .52755 m .46549 .51692 L .50057 .50854 L p
1 g
F P
s
P
p
.002 w
.50057 .50854 m .50367 .52958 L .46717 .52755 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48089 .39028 m .43838 .38004 L .44502 .34567 L p
1 g
F P
s
P
p
.002 w
.44502 .34567 m .49573 .35758 L .48089 .39028 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43032 .48896 m .41938 .48956 L .40925 .4545 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50367 .52958 m .50057 .50854 L .53579 .49769 L p
1 g
F P
s
P
p
.002 w
.43088 .4531 m .40925 .4545 L .40192 .41869 L p
1 g
F P
s
P
p
.002 w
.40192 .41869 m .4336 .41632 L .43088 .4531 L p
1 g
F P
s
P
p
.002 w
.57907 .42411 m .54238 .38485 L .56315 .35827 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.40925 .4545 m .43088 .4531 L .43032 .48896 L p
1 g
F P
s
P
p
.002 w
.46549 .51692 m .46023 .50669 L .49027 .4882 L p
1 g
F P
s
P
p
.002 w
.49027 .4882 m .50057 .50854 L .46549 .51692 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.4416 .49188 m .43032 .48896 L .43088 .4531 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56981 .48479 m .55088 .44609 L .57907 .42411 L p
1 g
F P
s
P
p
.002 w
.46023 .50669 m .45196 .49802 L .47389 .47094 L p
1 g
F P
s
P
p
.002 w
.47389 .47094 m .49027 .4882 L .46023 .50669 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.43088 .4531 m .45329 .45878 L .4416 .49188 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46656 .42446 m .4336 .41632 L .43838 .38004 L p
1 g
F P
s
P
p
.002 w
.43838 .38004 m .48089 .39028 L .46656 .42446 L p
1 g
F P
s
P
p
.002 w
.54238 .38485 m .57907 .42411 L .55088 .44609 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.50057 .50854 m .49027 .4882 L .52089 .46774 L p
1 g
F P
s
P
p
.002 w
.52089 .46774 m .53579 .49769 L .50057 .50854 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52001 .41322 m .48089 .39028 L .49573 .35758 L p
1 g
F P
s
P
p
.002 w
.49573 .35758 m .54238 .38485 L .52001 .41322 L p
1 g
F P
s
P
p
.002 w
.45329 .45878 m .43088 .4531 L .4336 .41632 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.4336 .41632 m .46656 .42446 L .45329 .45878 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.55088 .44609 m .52001 .41322 L .54238 .38485 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49687 .4423 m .46656 .42446 L .48089 .39028 L p
1 g
F P
s
P
p
.002 w
.48089 .39028 m .52001 .41322 L .49687 .4423 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.40342 .56103 m
.40921 .55321 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .66501 .65251 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39095 .57789 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.162791)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.162791)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47484 .42942 m .49337 .44922 L .51103 .42676 L p
1 g
F P
s
P
p
.002 w
.51103 .42676 m .4984 .41326 L .47484 .42942 L p
1 g
F P
s
P
p
.002 w
.52711 .43578 m .51103 .42676 L .49337 .44922 L p
1 g
F P
s
P
p
.002 w
.4984 .41326 m .51103 .42676 L .52846 .40435 L p
1 g
F P
s
P
p
.002 w
.51103 .42676 m .52711 .43578 L .53664 .40891 L p
1 g
F P
s
P
p
.002 w
.53664 .40891 m .52846 .40435 L .51103 .42676 L p
1 g
F P
s
P
p
.002 w
.46323 .40512 m .47484 .42942 L .4984 .41326 L p
1 g
F P
s
P
p
.002 w
.4984 .41326 m .49054 .39667 L .46323 .40512 L p
1 g
F P
s
P
p
.002 w
.49054 .39667 m .4984 .41326 L .52205 .39748 L p
1 g
F P
s
P
p
.002 w
.52846 .40435 m .52205 .39748 L .4984 .41326 L p
1 g
F P
s
P
p
.002 w
.45178 .44569 m .4758 .47131 L .49337 .44922 L p
1 g
F P
s
P
p
.002 w
.49337 .44922 m .47484 .42942 L .45178 .44569 L p
1 g
F P
s
P
p
.002 w
.51693 .46249 m .49337 .44922 L .4758 .47131 L p
1 g
F P
s
P
p
.002 w
.49337 .44922 m .51693 .46249 L .52711 .43578 L p
1 g
F P
s
P
p
.002 w
.43665 .41423 m .45178 .44569 L .47484 .42942 L p
1 g
F P
s
P
p
.002 w
.47484 .42942 m .46323 .40512 L .43665 .41423 L p
1 g
F P
s
P
p
.002 w
.54496 .43935 m .52711 .43578 L .51693 .46249 L p
1 g
F P
s
P
p
.002 w
.52711 .43578 m .54496 .43935 L .54571 .41069 L p
1 g
F P
s
P
p
.002 w
.54571 .41069 m .53664 .40891 L .52711 .43578 L p
1 g
F P
s
P
p
.002 w
.45979 .37877 m .46323 .40512 L .49054 .39667 L p
1 g
F P
s
P
p
.002 w
.49054 .39667 m .48828 .37872 L .45979 .37877 L p
1 g
F P
s
P
p
.002 w
.48828 .37872 m .49054 .39667 L .51808 .38905 L p
1 g
F P
s
P
p
.002 w
.52205 .39748 m .51808 .38905 L .49054 .39667 L p
1 g
F P
s
P
p
.002 w
.4758 .47131 m .50629 .48856 L .51693 .46249 L p
1 g
F P
s
P
p
.002 w
.54313 .46785 m .51693 .46249 L .50629 .48856 L p
1 g
F P
s
P
p
.002 w
.51693 .46249 m .54313 .46785 L .54496 .43935 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .52205 .39748 L .52846 .40435 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .52846 .40435 L .53664 .40891 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .51808 .38905 L .52205 .39748 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .53664 .40891 L .54571 .41069 L closepath p
1 g
F P
s
P
p
.002 w
.43202 .38007 m .43665 .41423 L .46323 .40512 L p
1 g
F P
s
P
p
.002 w
.46323 .40512 m .45979 .37877 L .43202 .38007 L p
1 g
F P
s
P
p
.002 w
.51808 .38905 m .51698 .37993 L .48828 .37872 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .51698 .37993 L .51808 .38905 L closepath p
1 g
F P
s
P
p
.002 w
.56274 .43707 m .54496 .43935 L .54313 .46785 L p
1 g
F P
s
P
p
.002 w
.54496 .43935 m .56274 .43707 L .55471 .40948 L p
1 g
F P
s
P
p
.002 w
.55471 .40948 m .54571 .41069 L .54496 .43935 L p
1 g
F P
s
P
p
.002 w
.42966 .46175 m .45863 .49265 L .4758 .47131 L p
1 g
F P
s
P
p
.002 w
.4758 .47131 m .45178 .44569 L .42966 .46175 L p
1 g
F P
s
P
p
.002 w
.50629 .48856 m .4758 .47131 L .45863 .49265 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .54571 .41069 L .55471 .40948 L closepath p
1 g
F P
s
P
p
.002 w
.4113 .42386 m .42966 .46175 L .45178 .44569 L p
1 g
F P
s
P
p
.002 w
.45178 .44569 m .43665 .41423 L .4113 .42386 L p
1 g
F P
s
P
p
.002 w
.46498 .35308 m .45979 .37877 L .48828 .37872 L p
1 g
F P
s
P
p
.002 w
.48828 .37872 m .49193 .36128 L .46498 .35308 L p
1 g
F P
s
P
p
.002 w
.49193 .36128 m .48828 .37872 L .51698 .37993 L p
1 g
F P
s
P
p
.002 w
.51698 .37993 m .51888 .37111 L .49193 .36128 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .51888 .37111 L .51698 .37993 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .48856 m .54022 .49565 L .54313 .46785 L p
1 g
F P
s
P
p
.002 w
.56928 .46465 m .54313 .46785 L .54022 .49565 L p
1 g
F P
s
P
p
.002 w
.54313 .46785 m .56928 .46465 L .56274 .43707 L p
1 g
F P
s
P
p
.002 w
.45863 .49265 m .49537 .51352 L .50629 .48856 L p
1 g
F P
s
P
p
.002 w
.54022 .49565 m .50629 .48856 L .49537 .51352 L p
1 g
F P
s
P
p
.002 w
.56268 .4054 m .55471 .40948 L .56274 .43707 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .55471 .40948 L .56268 .4054 L closepath p
1 g
F P
s
P
p
.002 w
.50115 .34623 m .49193 .36128 L .51888 .37111 L p
1 g
F P
s
P
p
.002 w
.51888 .37111 m .5236 .36354 L .50115 .34623 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .5236 .36354 L .51888 .37111 L closepath p
1 g
F P
s
P
p
.002 w
.57855 .42911 m .56274 .43707 L .56928 .46465 L p
1 g
F P
s
P
p
.002 w
.56274 .43707 m .57855 .42911 L .56268 .4054 L p
1 g
F P
s
P
p
.002 w
.40552 .38265 m .4113 .42386 L .43665 .41423 L p
1 g
F P
s
P
p
.002 w
.43665 .41423 m .43202 .38007 L .40552 .38265 L p
1 g
F P
s
P
p
.002 w
.43856 .34668 m .43202 .38007 L .45979 .37877 L p
1 g
F P
s
P
p
.002 w
.45979 .37877 m .46498 .35308 L .43856 .34668 L p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .56875 .39886 L .57223 .39056 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .57223 .39056 L .57275 .3814 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .57275 .3814 L .57021 .37238 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .57021 .37238 L .5649 .3645 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .5649 .3645 L .55739 .35864 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .55739 .35864 L .54852 .35543 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .54852 .35543 L .53926 .35523 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .53926 .35523 L .53065 .35804 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .53065 .35804 L .5236 .36354 L closepath p
1 g
F P
s
P
p
.002 w
.54535 .38238 m .56268 .4054 L .56875 .39886 L closepath p
1 g
F P
s
P
p
.002 w
.56875 .39886 m .56268 .4054 L .57855 .42911 L p
1 g
F P
s
P
p
.002 w
.47842 .3308 m .46498 .35308 L .49193 .36128 L p
1 g
F P
s
P
p
.002 w
.49193 .36128 m .50115 .34623 L .47842 .3308 L p
1 g
F P
s
P
p
.002 w
.51504 .33523 m .50115 .34623 L .5236 .36354 L p
1 g
F P
s
P
p
.002 w
.5236 .36354 m .53065 .35804 L .51504 .33523 L p
1 g
F P
s
P
p
.002 w
.40889 .47732 m .4422 .51281 L .45863 .49265 L p
1 g
F P
s
P
p
.002 w
.45863 .49265 m .42966 .46175 L .40889 .47732 L p
1 g
F P
s
P
p
.002 w
.49537 .51352 m .45863 .49265 L .4422 .51281 L p
1 g
F P
s
P
p
.002 w
.57223 .39056 m .56875 .39886 L .59065 .41625 L p
1 g
F P
s
P
p
.002 w
.57855 .42911 m .59065 .41625 L .56875 .39886 L p
1 g
F P
s
P
p
.002 w
.49537 .51352 m .53629 .52223 L .54022 .49565 L p
1 g
F P
s
P
p
.002 w
.57419 .49169 m .54022 .49565 L .53629 .52223 L p
1 g
F P
s
P
p
.002 w
.54022 .49565 m .57419 .49169 L .56928 .46465 L p
1 g
F P
s
P
p
.002 w
.38768 .43382 m .40889 .47732 L .42966 .46175 L p
1 g
F P
s
P
p
.002 w
.42966 .46175 m .4113 .42386 L .38768 .43382 L p
1 g
F P
s
P
p
.002 w
.59264 .45309 m .56928 .46465 L .57419 .49169 L p
1 g
F P
s
P
p
.002 w
.56928 .46465 m .59264 .45309 L .57855 .42911 L p
1 g
F P
s
P
p
.002 w
.59065 .41625 m .57855 .42911 L .59264 .45309 L p
1 g
F P
s
P
p
.002 w
.53212 .32953 m .51504 .33523 L .53065 .35804 L p
1 g
F P
s
P
p
.002 w
.53065 .35804 m .53926 .35523 L .53212 .32953 L p
1 g
F P
s
P
p
.002 w
.59065 .41625 m .59769 .39983 L .57223 .39056 L p
1 g
F P
s
P
p
.002 w
.57275 .3814 m .57223 .39056 L .59769 .39983 L p
1 g
F P
s
P
p
.002 w
.4422 .51281 m .48437 .53686 L .49537 .51352 L p
1 g
F P
s
P
p
.002 w
.53629 .52223 m .49537 .51352 L .48437 .53686 L p
1 g
F P
s
P
p
.002 w
.4988 .3144 m .47842 .3308 L .50115 .34623 L p
1 g
F P
s
P
p
.002 w
.50115 .34623 m .51504 .33523 L .4988 .3144 L p
1 g
F P
s
P
p
.002 w
.41317 .34225 m .40552 .38265 L .43202 .38007 L p
1 g
F P
s
P
p
.002 w
.43202 .38007 m .43856 .34668 L .41317 .34225 L p
1 g
F P
s
P
p
.002 w
.55054 .32985 m .53212 .32953 L .53926 .35523 L p
1 g
F P
s
P
p
.002 w
.53926 .35523 m .54852 .35543 L .55054 .32985 L p
1 g
F P
s
P
p
.002 w
.45582 .31758 m .43856 .34668 L .46498 .35308 L p
1 g
F P
s
P
p
.002 w
.46498 .35308 m .47842 .3308 L .45582 .31758 L p
1 g
F P
s
P
p
.002 w
.59769 .39983 m .59881 .38162 L .57275 .3814 L p
1 g
F P
s
P
p
.002 w
.57021 .37238 m .57275 .3814 L .59881 .38162 L p
1 g
F P
s
P
p
.002 w
.38082 .38647 m .38768 .43382 L .4113 .42386 L p
1 g
F P
s
P
p
.002 w
.4113 .42386 m .40552 .38265 L .38082 .38647 L p
1 g
F P
s
P
p
.002 w
.56825 .33619 m .55054 .32985 L .54852 .35543 L p
1 g
F P
s
P
p
.002 w
.54852 .35543 m .55739 .35864 L .56825 .33619 L p
1 g
F P
s
P
p
.002 w
.59881 .38162 m .59382 .36363 L .57021 .37238 L p
1 g
F P
s
P
p
.002 w
.5649 .3645 m .57021 .37238 L .59382 .36363 L p
1 g
F P
s
P
p
.002 w
.59769 .39983 m .59065 .41625 L .61063 .43425 L p
1 g
F P
s
P
p
.002 w
.59264 .45309 m .61063 .43425 L .59065 .41625 L p
1 g
F P
s
P
p
.002 w
.58324 .34789 m .56825 .33619 L .55739 .35864 L p
1 g
F P
s
P
p
.002 w
.55739 .35864 m .5649 .3645 L .58324 .34789 L p
1 g
F P
s
P
p
.002 w
.59382 .36363 m .58324 .34789 L .5649 .3645 L p
1 g
F P
s
P
p
.002 w
.57419 .49169 m .60465 .47687 L .59264 .45309 L p
1 g
F P
s
P
p
.002 w
.61063 .43425 m .59264 .45309 L .60465 .47687 L p
1 g
F P
s
P
p
.002 w
.53629 .52223 m .57734 .51767 L .57419 .49169 L p
1 g
F P
s
P
p
.002 w
.60465 .47687 m .57419 .49169 L .57734 .51767 L p
1 g
F P
s
P
p
.002 w
.52403 .30583 m .4988 .3144 L .51504 .33523 L p
1 g
F P
s
P
p
.002 w
.51504 .33523 m .53212 .32953 L .52403 .30583 L p
1 g
F P
s
P
p
.002 w
.48437 .53686 m .53137 .54705 L .53629 .52223 L p
1 g
F P
s
P
p
.002 w
.57734 .51767 m .53629 .52223 L .53137 .54705 L p
1 g
F P
s
P
p
.002 w
.38992 .49208 m .42684 .53137 L .4422 .51281 L p
1 g
F P
s
P
p
.002 w
.4422 .51281 m .40889 .47732 L .38992 .49208 L p
1 g
F P
s
P
p
.002 w
.48437 .53686 m .4422 .51281 L .42684 .53137 L p
1 g
F P
s
P
p
.002 w
.48224 .29605 m .45582 .31758 L .47842 .3308 L p
1 g
F P
s
P
p
.002 w
.47842 .3308 m .4988 .3144 L .48224 .29605 L p
1 g
F P
s
P
p
.002 w
.61063 .43425 m .62119 .41004 L .59769 .39983 L p
1 g
F P
s
P
p
.002 w
.59881 .38162 m .59769 .39983 L .62119 .41004 L p
1 g
F P
s
P
p
.002 w
.36631 .44394 m .38992 .49208 L .40889 .47732 L p
1 g
F P
s
P
p
.002 w
.40889 .47732 m .38768 .43382 L .36631 .44394 L p
1 g
F P
s
P
p
.002 w
.43384 .30691 m .41317 .34225 L .43856 .34668 L p
1 g
F P
s
P
p
.002 w
.43856 .34668 m .45582 .31758 L .43384 .30691 L p
1 g
F P
s
P
p
.002 w
.38938 .33994 m .38082 .38647 L .40552 .38265 L p
1 g
F P
s
P
p
.002 w
.40552 .38265 m .41317 .34225 L .38938 .33994 L p
1 g
F P
s
P
p
.002 w
.55135 .30618 m .52403 .30583 L .53212 .32953 L p
1 g
F P
s
P
p
.002 w
.53212 .32953 m .55054 .32985 L .55135 .30618 L p
1 g
F P
s
P
p
.002 w
.42684 .53137 m .47351 .55809 L .48437 .53686 L p
1 g
F P
s
P
p
.002 w
.53137 .54705 m .48437 .53686 L .47351 .55809 L p
1 g
F P
s
P
p
.002 w
.62119 .41004 m .62298 .38306 L .59881 .38162 L p
1 g
F P
s
P
p
.002 w
.59382 .36363 m .59881 .38162 L .62298 .38306 L p
1 g
F P
s
P
p
.002 w
.60465 .47687 m .62824 .45251 L .61063 .43425 L p
1 g
F P
s
P
p
.002 w
.62119 .41004 m .61063 .43425 L .62824 .45251 L p
1 g
F P
s
P
p
.002 w
.35851 .39151 m .36631 .44394 L .38768 .43382 L p
1 g
F P
s
P
p
.002 w
.38768 .43382 m .38082 .38647 L .35851 .39151 L p
1 g
F P
s
P
p
.002 w
.57767 .31555 m .55135 .30618 L .55054 .32985 L p
1 g
F P
s
P
p
.002 w
.55054 .32985 m .56825 .33619 L .57767 .31555 L p
1 g
F P
s
P
p
.002 w
.57734 .51767 m .61428 .49999 L .60465 .47687 L p
1 g
F P
s
P
p
.002 w
.62824 .45251 m .60465 .47687 L .61428 .49999 L p
1 g
F P
s
P
p
.002 w
.62298 .38306 m .61567 .35634 L .59382 .36363 L p
1 g
F P
s
P
p
.002 w
.58324 .34789 m .59382 .36363 L .61567 .35634 L p
1 g
F P
s
P
p
.002 w
.51512 .28467 m .48224 .29605 L .4988 .3144 L p
1 g
F P
s
P
p
.002 w
.4988 .3144 m .52403 .30583 L .51512 .28467 L p
1 g
F P
s
P
p
.002 w
.59997 .33293 m .57767 .31555 L .56825 .33619 L p
1 g
F P
s
P
p
.002 w
.56825 .33619 m .58324 .34789 L .59997 .33293 L p
1 g
F P
s
P
p
.002 w
.53137 .54705 m .57862 .54205 L .57734 .51767 L p
1 g
F P
s
P
p
.002 w
.61428 .49999 m .57734 .51767 L .57862 .54205 L p
1 g
F P
s
P
p
.002 w
.61567 .35634 m .59997 .33293 L .58324 .34789 L p
1 g
F P
s
P
p
.002 w
.47351 .55809 m .52555 .56955 L .53137 .54705 L p
1 g
F P
s
P
p
.002 w
.57862 .54205 m .53137 .54705 L .52555 .56955 L p
1 g
F P
s
P
p
.002 w
.46569 .28062 m .43384 .30691 L .45582 .31758 L p
1 g
F P
s
P
p
.002 w
.45582 .31758 m .48224 .29605 L .46569 .28062 L p
1 g
F P
s
P
p
.002 w
.62824 .45251 m .6422 .42101 L .62119 .41004 L p
1 g
F P
s
P
p
.002 w
.62298 .38306 m .62119 .41004 L .6422 .42101 L p
1 g
F P
s
P
p
.002 w
.41294 .2991 m .38938 .33994 L .41317 .34225 L p
1 g
F P
s
P
p
.002 w
.41317 .34225 m .43384 .30691 L .41294 .2991 L p
1 g
F P
s
P
p
.002 w
.37321 .50569 m .4129 .54789 L .42684 .53137 L p
1 g
F P
s
P
p
.002 w
.42684 .53137 m .38992 .49208 L .37321 .50569 L p
1 g
F P
s
P
p
.002 w
.47351 .55809 m .42684 .53137 L .4129 .54789 L p
1 g
F P
s
P
p
.002 w
.34773 .45402 m .37321 .50569 L .38992 .49208 L p
1 g
F P
s
P
p
.002 w
.38992 .49208 m .36631 .44394 L .34773 .45402 L p
1 g
F P
s
P
p
.002 w
.55087 .285 m .51512 .28467 L .52403 .30583 L p
1 g
F P
s
P
p
.002 w
.52403 .30583 m .55135 .30618 L .55087 .285 L p
1 g
F P
s
P
p
.002 w
.36773 .33988 m .35851 .39151 L .38082 .38647 L p
1 g
F P
s
P
p
.002 w
.38082 .38647 m .38938 .33994 L .36773 .33988 L p
1 g
F P
s
P
p
.002 w
.61428 .49999 m .64304 .47067 L .62824 .45251 L p
1 g
F P
s
P
p
.002 w
.6422 .42101 m .62824 .45251 L .64304 .47067 L p
1 g
F P
s
P
p
.002 w
.4129 .54789 m .46301 .57668 L .47351 .55809 L p
1 g
F P
s
P
p
.002 w
.52555 .56955 m .47351 .55809 L .46301 .57668 L p
1 g
F P
s
P
p
.002 w
.6422 .42101 m .64471 .38576 L .62298 .38306 L p
1 g
F P
s
P
p
.002 w
.61567 .35634 m .62298 .38306 L .64471 .38576 L p
1 g
F P
s
P
p
.002 w
.57862 .54205 m .62126 .52195 L .61428 .49999 L p
1 g
F P
s
P
p
.002 w
.64304 .47067 m .61428 .49999 L .62126 .52195 L p
1 g
F P
s
P
p
.002 w
.33915 .3977 m .34773 .45402 L .36631 .44394 L p
1 g
F P
s
P
p
.002 w
.36631 .44394 m .35851 .39151 L .33915 .3977 L p
1 g
F P
s
P
p
.002 w
.5854 .2972 m .55087 .285 L .55135 .30618 L p
1 g
F P
s
P
p
.002 w
.55135 .30618 m .57767 .31555 L .5854 .2972 L p
1 g
F P
s
P
p
.002 w
.50555 .26662 m .46569 .28062 L .48224 .29605 L p
1 g
F P
s
P
p
.002 w
.48224 .29605 m .51512 .28467 L .50555 .26662 L p
1 g
F P
s
P
p
.002 w
.52555 .56955 m .57793 .56425 L .57862 .54205 L p
1 g
F P
s
P
p
.002 w
.62126 .52195 m .57862 .54205 L .57793 .56425 L p
1 g
F P
s
P
p
.002 w
.64471 .38576 m .63522 .35072 L .61567 .35634 L p
1 g
F P
s
P
p
.002 w
.59997 .33293 m .61567 .35634 L .63522 .35072 L p
1 g
F P
s
P
p
.002 w
.61467 .31999 m .5854 .2972 L .57767 .31555 L p
1 g
F P
s
P
p
.002 w
.57767 .31555 m .59997 .33293 L .61467 .31999 L p
1 g
F P
s
P
p
.002 w
.63522 .35072 m .61467 .31999 L .59997 .33293 L p
1 g
F P
s
P
p
.002 w
.44952 .2686 m .41294 .2991 L .43384 .30691 L p
1 g
F P
s
P
p
.002 w
.43384 .30691 m .46569 .28062 L .44952 .2686 L p
1 g
F P
s
P
p
.002 w
.46301 .57668 m .51889 .58916 L .52555 .56955 L p
1 g
F P
s
P
p
.002 w
.57793 .56425 m .52555 .56955 L .51889 .58916 L p
1 g
F P
s
P
p
.002 w
.64304 .47067 m .66018 .43255 L .6422 .42101 L p
1 g
F P
s
P
p
.002 w
.64471 .38576 m .6422 .42101 L .66018 .43255 L p
1 g
F P
s
P
p
.002 w
.39363 .29447 m .36773 .33988 L .38938 .33994 L p
1 g
F P
s
P
p
.002 w
.38938 .33994 m .41294 .2991 L .39363 .29447 L p
1 g
F P
s
P
p
.002 w
.35921 .51781 m .40074 .56194 L .4129 .54789 L p
1 g
F P
s
P
p
.002 w
.4129 .54789 m .37321 .50569 L .35921 .51781 L p
1 g
F P
s
P
p
.002 w
.46301 .57668 m .4129 .54789 L .40074 .56194 L p
1 g
F P
s
P
p
.002 w
.54905 .26687 m .50555 .26662 L .51512 .28467 L p
1 g
F P
s
P
p
.002 w
.51512 .28467 m .55087 .285 L .54905 .26687 L p
1 g
F P
s
P
p
.002 w
.34882 .34219 m .33915 .3977 L .35851 .39151 L p
1 g
F P
s
P
p
.002 w
.35851 .39151 m .36773 .33988 L .34882 .34219 L p
1 g
F P
s
P
p
.002 w
.33247 .46382 m .35921 .51781 L .37321 .50569 L p
1 g
F P
s
P
p
.002 w
.37321 .50569 m .34773 .45402 L .33247 .46382 L p
1 g
F P
s
P
p
.002 w
.66018 .43255 m .64304 .47067 L .6546 .48833 L p
1 g
F P
s
P
p
.002 w
.62126 .52195 m .6546 .48833 L .64304 .47067 L p
1 g
F P
s
P
p
.002 w
.40074 .56194 m .45312 .59212 L .46301 .57668 L p
1 g
F P
s
P
p
.002 w
.51889 .58916 m .46301 .57668 L .45312 .59212 L p
1 g
F P
s
P
p
.002 w
.66018 .43255 m .66339 .3897 L .64471 .38576 L p
1 g
F P
s
P
p
.002 w
.63522 .35072 m .64471 .38576 L .66339 .3897 L p
1 g
F P
s
P
p
.002 w
.57793 .56425 m .62532 .54221 L .62126 .52195 L p
1 g
F P
s
P
p
.002 w
.6546 .48833 m .62126 .52195 L .62532 .54221 L p
1 g
F P
s
P
p
.002 w
.4955 .25223 m .44952 .2686 L .46569 .28062 L p
1 g
F P
s
P
p
.002 w
.46569 .28062 m .50555 .26662 L .4955 .25223 L p
1 g
F P
s
P
p
.002 w
.32333 .40497 m .33247 .46382 L .34773 .45402 L p
1 g
F P
s
P
p
.002 w
.34773 .45402 m .33915 .3977 L .32333 .40497 L p
1 g
F P
s
P
p
.002 w
.59118 .28167 m .54905 .26687 L .55087 .285 L p
1 g
F P
s
P
p
.002 w
.55087 .285 m .5854 .2972 L .59118 .28167 L p
1 g
F P
s
P
p
.002 w
.51889 .58916 m .5752 .5837 L .57793 .56425 L p
1 g
F P
s
P
p
.002 w
.62532 .54221 m .57793 .56425 L .5752 .5837 L p
1 g
F P
s
P
p
.002 w
.66339 .3897 m .65193 .34698 L .63522 .35072 L p
1 g
F P
s
P
p
.002 w
.61467 .31999 m .63522 .35072 L .65193 .34698 L p
1 g
F P
s
P
p
.002 w
.4341 .26042 m .39363 .29447 L .41294 .2991 L p
1 g
F P
s
P
p
.002 w
.41294 .2991 m .44952 .2686 L .4341 .26042 L p
1 g
F P
s
P
p
.002 w
.6269 .30947 m .59118 .28167 L .5854 .2972 L p
1 g
F P
s
P
p
.002 w
.5854 .2972 m .61467 .31999 L .6269 .30947 L p
1 g
F P
s
P
p
.002 w
.65193 .34698 m .6269 .30947 L .61467 .31999 L p
1 g
F P
s
P
p
.002 w
.45312 .59212 m .51151 .60531 L .51889 .58916 L p
1 g
F P
s
P
p
.002 w
.5752 .5837 m .51889 .58916 L .51151 .60531 L p
1 g
F P
s
P
p
.002 w
.6546 .48833 m .67459 .44442 L .66018 .43255 L p
1 g
F P
s
P
p
.002 w
.66339 .3897 m .66018 .43255 L .67459 .44442 L p
1 g
F P
s
P
p
.002 w
.37646 .29326 m .34882 .34219 L .36773 .33988 L p
1 g
F P
s
P
p
.002 w
.36773 .33988 m .39363 .29447 L .37646 .29326 L p
1 g
F P
s
P
p
.002 w
.54587 .25239 m .4955 .25223 L .50555 .26662 L p
1 g
F P
s
P
p
.002 w
.50555 .26662 m .54905 .26687 L .54587 .25239 L p
1 g
F P
s
P
p
.002 w
.33324 .34693 m .32333 .40497 L .33915 .3977 L p
1 g
F P
s
P
p
.002 w
.33915 .3977 m .34882 .34219 L .33324 .34693 L p
1 g
F P
s
P
p
.002 w
.34839 .52808 m .39074 .57306 L .40074 .56194 L p
1 g
F P
s
P
p
.002 w
.40074 .56194 m .35921 .51781 L .34839 .52808 L p
1 g
F P
s
P
p
.002 w
.45312 .59212 m .40074 .56194 L .39074 .57306 L p
1 g
F P
s
P
p
.002 w
.62532 .54221 m .66249 .50508 L .6546 .48833 L p
1 g
F P
s
P
p
.002 w
.67459 .44442 m .6546 .48833 L .66249 .50508 L p
1 g
F P
s
P
p
.002 w
.32106 .47311 m .34839 .52808 L .35921 .51781 L p
1 g
F P
s
P
p
.002 w
.35921 .51781 m .33247 .46382 L .32106 .47311 L p
1 g
F P
s
P
p
.002 w
.5752 .5837 m .62622 .56022 L .62532 .54221 L p
1 g
F P
s
P
p
.002 w
.66249 .50508 m .62532 .54221 L .62622 .56022 L p
1 g
F P
s
P
p
.002 w
.39074 .57306 m .4441 .60387 L .45312 .59212 L p
1 g
F P
s
P
p
.002 w
.51151 .60531 m .45312 .59212 L .4441 .60387 L p
1 g
F P
s
P
p
.002 w
.67459 .44442 m .67845 .39485 L .66339 .3897 L p
1 g
F P
s
P
p
.002 w
.65193 .34698 m .66339 .3897 L .67845 .39485 L p
1 g
F P
s
P
p
.002 w
.48519 .24206 m .4341 .26042 L .44952 .2686 L p
1 g
F P
s
P
p
.002 w
.44952 .2686 m .4955 .25223 L .48519 .24206 L p
1 g
F P
s
P
p
.002 w
.51151 .60531 m .57038 .59979 L .5752 .5837 L p
1 g
F P
s
P
p
.002 w
.62622 .56022 m .5752 .5837 L .57038 .59979 L p
1 g
F P
s
P
p
.002 w
.31162 .4132 m .32106 .47311 L .33247 .46382 L p
1 g
F P
s
P
p
.002 w
.33247 .46382 m .32333 .40497 L .31162 .4132 L p
1 g
F P
s
P
p
.002 w
.59476 .2695 m .54587 .25239 L .54905 .26687 L p
1 g
F P
s
P
p
.002 w
.54905 .26687 m .59118 .28167 L .59476 .2695 L p
1 g
F P
s
P
p
.002 w
.41987 .2565 m .37646 .29326 L .39363 .29447 L p
1 g
F P
s
P
p
.002 w
.39363 .29447 m .4341 .26042 L .41987 .2565 L p
1 g
F P
s
P
p
.002 w
.67845 .39485 m .66526 .34531 L .65193 .34698 L p
1 g
F P
s
P
p
.002 w
.6269 .30947 m .65193 .34698 L .66526 .34531 L p
1 g
F P
s
P
p
.002 w
.63624 .30175 m .59476 .2695 L .59118 .28167 L p
1 g
F P
s
P
p
.002 w
.59118 .28167 m .6269 .30947 L .63624 .30175 L p
1 g
F P
s
P
p
.002 w
.36196 .29572 m .33324 .34693 L .34882 .34219 L p
1 g
F P
s
P
p
.002 w
.34882 .34219 m .37646 .29326 L .36196 .29572 L p
1 g
F P
s
P
p
.002 w
.66249 .50508 m .68488 .45635 L .67459 .44442 L p
1 g
F P
s
P
p
.002 w
.67845 .39485 m .67459 .44442 L .68488 .45635 L p
1 g
F P
s
P
p
.002 w
.4441 .60387 m .50355 .61742 L .51151 .60531 L p
1 g
F P
s
P
p
.002 w
.57038 .59979 m .51151 .60531 L .50355 .61742 L p
1 g
F P
s
P
p
.002 w
.66526 .34531 m .63624 .30175 L .6269 .30947 L p
1 g
F P
s
P
p
.002 w
.54132 .24214 m .48519 .24206 L .4955 .25223 L p
1 g
F P
s
P
p
.002 w
.4955 .25223 m .54587 .25239 L .54132 .24214 L p
1 g
F P
s
P
p
.002 w
.32157 .35412 m .31162 .4132 L .32333 .40497 L p
1 g
F P
s
P
p
.002 w
.32333 .40497 m .33324 .34693 L .32157 .35412 L p
1 g
F P
s
P
p
.002 w
.62622 .56022 m .66634 .52045 L .66249 .50508 L p
1 g
F P
s
P
p
.002 w
.68488 .45635 m .66249 .50508 L .66634 .52045 L p
1 g
F P
s
P
p
.002 w
.3412 .53616 m .38326 .58081 L .39074 .57306 L p
1 g
F P
s
P
p
.002 w
.39074 .57306 m .34839 .52808 L .3412 .53616 L p
1 g
F P
s
P
p
.002 w
.4441 .60387 m .39074 .57306 L .38326 .58081 L p
1 g
F P
s
P
p
.002 w
.31402 .48162 m .3412 .53616 L .34839 .52808 L p
1 g
F P
s
P
p
.002 w
.34839 .52808 m .32106 .47311 L .31402 .48162 L p
1 g
F P
s
P
p
.002 w
.57038 .59979 m .62378 .57544 L .62622 .56022 L p
1 g
F P
s
P
p
.002 w
.66634 .52045 m .62622 .56022 L .62378 .57544 L p
1 g
F P
s
P
p
.002 w
.68488 .45635 m .68932 .40117 L .67845 .39485 L p
1 g
F P
s
P
p
.002 w
.66526 .34531 m .67845 .39485 L .68932 .40117 L p
1 g
F P
s
P
p
.002 w
.38326 .58081 m .43621 .61143 L .4441 .60387 L p
1 g
F P
s
P
p
.002 w
.50355 .61742 m .4441 .60387 L .43621 .61143 L p
1 g
F P
s
P
p
.002 w
.47486 .23661 m .41987 .2565 L .4341 .26042 L p
1 g
F P
s
P
p
.002 w
.4341 .26042 m .48519 .24206 L .47486 .23661 L p
1 g
F P
s
P
p
.002 w
.50355 .61742 m .56348 .61196 L .57038 .59979 L p
1 g
F P
s
P
p
.002 w
.62378 .57544 m .57038 .59979 L .56348 .61196 L p
1 g
F P
s
P
p
.002 w
.59592 .26118 m .54132 .24214 L .54587 .25239 L p
1 g
F P
s
P
p
.002 w
.54587 .25239 m .59476 .2695 L .59592 .26118 L p
1 g
F P
s
P
p
.002 w
.30457 .42224 m .31402 .48162 L .32106 .47311 L p
1 g
F P
s
P
p
.002 w
.32106 .47311 m .31162 .4132 L .30457 .42224 L p
1 g
F P
s
P
p
.002 w
.40726 .2572 m .36196 .29572 L .37646 .29326 L p
1 g
F P
s
P
p
.002 w
.37646 .29326 m .41987 .2565 L .40726 .2572 L p
1 g
F P
s
P
p
.002 w
.68932 .40117 m .67467 .34589 L .66526 .34531 L p
1 g
F P
s
P
p
.002 w
.63624 .30175 m .66526 .34531 L .67467 .34589 L p
1 g
F P
s
P
p
.002 w
.35068 .30198 m .32157 .35412 L .33324 .34693 L p
1 g
F P
s
P
p
.002 w
.33324 .34693 m .36196 .29572 L .35068 .30198 L p
1 g
F P
s
P
p
.002 w
.66634 .52045 m .69057 .46806 L .68488 .45635 L p
1 g
F P
s
P
p
.002 w
.68932 .40117 m .68488 .45635 L .69057 .46806 L p
1 g
F P
s
P
p
.002 w
.64227 .29721 m .59592 .26118 L .59476 .2695 L p
1 g
F P
s
P
p
.002 w
.59476 .2695 m .63624 .30175 L .64227 .29721 L p
1 g
F P
s
P
p
.002 w
.43621 .61143 m .49517 .62496 L .50355 .61742 L p
1 g
F P
s
P
p
.002 w
.56348 .61196 m .50355 .61742 L .49517 .62496 L p
1 g
F P
s
P
p
.002 w
.67467 .34589 m .64227 .29721 L .63624 .30175 L p
1 g
F P
s
P
p
.002 w
.53545 .23663 m .47486 .23661 L .48519 .24206 L p
1 g
F P
s
P
p
.002 w
.48519 .24206 m .54132 .24214 L .53545 .23663 L p
1 g
F P
s
P
p
.002 w
.62378 .57544 m .6658 .53399 L .66634 .52045 L p
1 g
F P
s
P
p
.002 w
.69057 .46806 m .66634 .52045 L .6658 .53399 L p
1 g
F P
s
P
p
.002 w
.31435 .36371 m .30457 .42224 L .31162 .4132 L p
1 g
F P
s
P
p
.002 w
.31162 .4132 m .32157 .35412 L .31435 .36371 L p
1 g
F P
s
P
p
.002 w
.33805 .54169 m .37865 .58479 L .38326 .58081 L p
1 g
F P
s
P
p
.002 w
.38326 .58081 m .3412 .53616 L .33805 .54169 L p
1 g
F P
s
P
p
.002 w
.43621 .61143 m .38326 .58081 L .37865 .58479 L p
1 g
F P
s
P
p
.002 w
.56348 .61196 m .61785 .5873 L .62378 .57544 L p
1 g
F P
s
P
p
.002 w
.6658 .53399 m .62378 .57544 L .61785 .5873 L p
1 g
F P
s
P
p
.002 w
.31181 .4891 m .33805 .54169 L .3412 .53616 L p
1 g
F P
s
P
p
.002 w
.3412 .53616 m .31402 .48162 L .31181 .4891 L p
1 g
F P
s
P
p
.002 w
.4648 .23633 m .40726 .2572 L .41987 .2565 L p
1 g
F P
s
P
p
.002 w
.41987 .2565 m .47486 .23661 L .4648 .23633 L p
1 g
F P
s
P
p
.002 w
.69057 .46806 m .69544 .40856 L .68932 .40117 L p
1 g
F P
s
P
p
.002 w
.67467 .34589 m .68932 .40117 L .69544 .40856 L p
1 g
F P
s
P
p
.002 w
.37865 .58479 m .42973 .61435 L .43621 .61143 L p
1 g
F P
s
P
p
.002 w
.49517 .62496 m .43621 .61143 L .42973 .61435 L p
1 g
F P
s
P
p
.002 w
.49517 .62496 m .55456 .61963 L .56348 .61196 L p
1 g
F P
s
P
p
.002 w
.61785 .5873 m .56348 .61196 L .55456 .61963 L p
1 g
F P
s
P
p
.002 w
.59447 .2572 m .53545 .23663 L .54132 .24214 L p
1 g
F P
s
P
p
.002 w
.54132 .24214 m .59592 .26118 L .59447 .2572 L p
1 g
F P
s
P
p
.002 w
.30267 .43189 m .31181 .4891 L .31402 .48162 L p
1 g
F P
s
P
p
.002 w
.31402 .48162 m .30457 .42224 L .30267 .43189 L p
1 g
F P
s
P
p
.002 w
.39673 .26277 m .35068 .30198 L .36196 .29572 L p
1 g
F P
s
P
p
.002 w
.36196 .29572 m .40726 .2572 L .39673 .26277 L p
1 g
F P
s
P
p
.002 w
.69544 .40856 m .67965 .34883 L .67467 .34589 L p
1 g
F P
s
P
p
.002 w
.64227 .29721 m .67467 .34589 L .67965 .34883 L p
1 g
F P
s
P
p
.002 w
.34313 .31212 m .31435 .36371 L .32157 .35412 L p
1 g
F P
s
P
p
.002 w
.32157 .35412 m .35068 .30198 L .34313 .31212 L p
1 g
F P
s
P
p
.002 w
.6658 .53399 m .69123 .47921 L .69057 .46806 L p
1 g
F P
s
P
p
.002 w
.69544 .40856 m .69057 .46806 L .69123 .47921 L p
1 g
F P
s
P
p
.002 w
.42973 .61435 m .48656 .62743 L .49517 .62496 L p
1 g
F P
s
P
p
.002 w
.55456 .61963 m .49517 .62496 L .48656 .62743 L p
1 g
F P
s
P
p
.002 w
.64461 .29618 m .59447 .2572 L .59592 .26118 L p
1 g
F P
s
P
p
.002 w
.59592 .26118 m .64227 .29721 L .64461 .29618 L p
1 g
F P
s
P
p
.002 w
.67965 .34883 m .64461 .29618 L .64227 .29721 L p
1 g
F P
s
P
p
.002 w
.61785 .5873 m .66063 .5452 L .6658 .53399 L p
1 g
F P
s
P
p
.002 w
.69123 .47921 m .6658 .53399 L .66063 .5452 L p
1 g
F P
s
P
p
.002 w
.52831 .23635 m .4648 .23633 L .47486 .23661 L p
1 g
F P
s
P
p
.002 w
.47486 .23661 m .53545 .23663 L .52831 .23635 L p
1 g
F P
s
P
p
.002 w
.31207 .37559 m .30267 .43189 L .30457 .42224 L p
1 g
F P
s
P
p
.002 w
.30457 .42224 m .31435 .36371 L .31207 .37559 L p
1 g
F P
s
P
p
.004 w
.56381 .62334 m
.56434 .62494 L
s
P
p
.004 w
.56434 .62494 m
.56892 .63881 L
s
P
p
.004 w
.56892 .63881 m
.57159 .64687 L
s
P
p
.004 w
.57159 .64687 m
.58996 .70238 L
s
P
p
.002 w
.55456 .61963 m .60839 .59528 L .61785 .5873 L p
1 g
F P
s
P
p
.002 w
.66063 .5452 m .61785 .5873 L .60839 .59528 L p
1 g
F P
s
P
p
.002 w
.3393 .54435 m .37723 .58462 L .37865 .58479 L p
1 g
F P
s
P
p
.002 w
.37865 .58479 m .33805 .54169 L .3393 .54435 L p
1 g
F P
s
P
p
.002 w
.42973 .61435 m .37865 .58479 L .37723 .58462 L p
1 g
F P
s
P
p
.002 w
.31479 .49525 m .3393 .54435 L .33805 .54169 L p
1 g
F P
s
P
p
.002 w
.33805 .54169 m .31181 .4891 L .31479 .49525 L p
1 g
F P
s
P
p
.002 w
.45531 .24155 m .39673 .26277 L .40726 .2572 L p
1 g
F P
s
P
p
.002 w
.40726 .2572 m .4648 .23633 L .45531 .24155 L p
1 g
F P
s
P
p
.002 w
.69123 .47921 m .69635 .41688 L .69544 .40856 L p
1 g
F P
s
P
p
.002 w
.67965 .34883 m .69544 .40856 L .69635 .41688 L p
1 g
F P
s
P
p
.002 w
.37723 .58462 m .42495 .61224 L .42973 .61435 L p
1 g
F P
s
P
p
.002 w
.48656 .62743 m .42973 .61435 L .42495 .61224 L p
1 g
F P
s
P
p
.002 w
.48656 .62743 m .54373 .62232 L .55456 .61963 L p
1 g
F P
s
P
p
.002 w
.60839 .59528 m .55456 .61963 L .54373 .62232 L p
1 g
F P
s
P
p
.002 w
.3887 .27337 m .34313 .31212 L .35068 .30198 L p
1 g
F P
s
P
p
.002 w
.35068 .30198 m .39673 .26277 L .3887 .27337 L p
1 g
F P
s
P
p
.002 w
.59027 .25795 m .52831 .23635 L .53545 .23663 L p
1 g
F P
s
P
p
.002 w
.53545 .23663 m .59447 .2572 L .59027 .25795 L p
1 g
F P
s
P
p
.002 w
.3063 .44191 m .31479 .49525 L .31181 .4891 L p
1 g
F P
s
P
p
.002 w
.31181 .4891 m .30267 .43189 L .3063 .44191 L p
1 g
F P
s
P
p
.002 w
.33976 .32606 m .31207 .37559 L .31435 .36371 L p
1 g
F P
s
P
p
.002 w
.31435 .36371 m .34313 .31212 L .33976 .32606 L p
1 g
F P
s
P
p
.002 w
.66063 .5452 m .68651 .48946 L .69123 .47921 L p
1 g
F P
s
P
p
.002 w
.69635 .41688 m .69123 .47921 L .68651 .48946 L p
1 g
F P
s
P
p
.002 w
.69635 .41688 m .67977 .35421 L .67965 .34883 L p
1 g
F P
s
P
p
.002 w
.64461 .29618 m .67965 .34883 L .67977 .35421 L p
1 g
F P
s
P
p
.002 w
.42495 .61224 m .47797 .62443 L .48656 .62743 L p
1 g
F P
s
P
p
.002 w
.54373 .62232 m .48656 .62743 L .47797 .62443 L p
1 g
F P
s
P
p
.002 w
.64296 .29891 m .59027 .25795 L .59447 .2572 L p
1 g
F P
s
P
p
.002 w
.59447 .2572 m .64461 .29618 L .64296 .29891 L p
1 g
F P
s
P
p
.002 w
.67977 .35421 m .64296 .29891 L .64461 .29618 L p
1 g
F P
s
P
p
.002 w
.60839 .59528 m .6507 .55361 L .66063 .5452 L p
1 g
F P
s
P
p
.002 w
.68651 .48946 m .66063 .5452 L .6507 .55361 L p
1 g
F P
s
P
p
.002 w
.52006 .24163 m .45531 .24155 L .4648 .23633 L p
1 g
F P
s
P
p
.002 w
.4648 .23633 m .52831 .23635 L .52006 .24163 L p
1 g
F P
s
P
p
.002 w
.3151 .38954 m .3063 .44191 L .30267 .43189 L p
1 g
F P
s
P
p
.002 w
.30267 .43189 m .31207 .37559 L .3151 .38954 L p
1 g
F P
s
P
p
.002 w
.54373 .62232 m .59545 .59888 L .60839 .59528 L p
1 g
F P
s
P
p
.002 w
.6507 .55361 m .60839 .59528 L .59545 .59888 L p
1 g
F P
s
P
p
.002 w
.3452 .54388 m .37926 .58004 L .37723 .58462 L p
1 g
F P
s
P
p
.002 w
.37723 .58462 m .3393 .54435 L .3452 .54388 L p
1 g
F P
s
P
p
.002 w
.42495 .61224 m .37723 .58462 L .37926 .58004 L p
1 g
F P
s
P
p
.002 w
.44672 .25247 m .3887 .27337 L .39673 .26277 L p
1 g
F P
s
P
p
.002 w
.39673 .26277 m .45531 .24155 L .44672 .25247 L p
1 g
F P
s
P
p
.002 w
.32324 .4998 m .3452 .54388 L .3393 .54435 L p
1 g
F P
s
P
p
.002 w
.3393 .54435 m .31479 .49525 L .32324 .4998 L p
1 g
F P
s
P
p
.002 w
.68651 .48946 m .69167 .42595 L .69635 .41688 L p
1 g
F P
s
P
p
.002 w
.67977 .35421 m .69635 .41688 L .69167 .42595 L p
1 g
F P
s
P
p
.002 w
.47797 .62443 m .5312 .61963 L .54373 .62232 L p
1 g
F P
s
P
p
.002 w
.59545 .59888 m .54373 .62232 L .5312 .61963 L p
1 g
F P
s
P
p
.002 w
.37926 .58004 m .4221 .60482 L .42495 .61224 L p
1 g
F P
s
P
p
.002 w
.47797 .62443 m .42495 .61224 L .4221 .60482 L p
1 g
F P
s
P
p
.002 w
.3836 .28896 m .33976 .32606 L .34313 .31212 L p
1 g
F P
s
P
p
.002 w
.34313 .31212 m .3887 .27337 L .3836 .28896 L p
1 g
F P
s
P
p
.002 w
.58328 .26373 m .52006 .24163 L .52831 .23635 L p
1 g
F P
s
P
p
.002 w
.52831 .23635 m .59027 .25795 L .58328 .26373 L p
1 g
F P
s
P
p
.002 w
.31569 .45202 m .32324 .4998 L .31479 .49525 L p
1 g
F P
s
P
p
.002 w
.31479 .49525 m .3063 .44191 L .31569 .45202 L p
1 g
F P
s
P
p
.002 w
.34095 .3436 m .3151 .38954 L .31207 .37559 L p
1 g
F P
s
P
p
.002 w
.31207 .37559 m .33976 .32606 L .34095 .3436 L p
1 g
F P
s
P
p
.002 w
.6507 .55361 m .67622 .49844 L .68651 .48946 L p
1 g
F P
s
P
p
.002 w
.69167 .42595 m .68651 .48946 L .67622 .49844 L p
1 g
F P
s
P
p
.002 w
.69167 .42595 m .67469 .36203 L .67977 .35421 L p
1 g
F P
s
P
p
.002 w
.64296 .29891 m .67977 .35421 L .67469 .36203 L p
1 g
F P
s
P
p
.002 w
.4221 .60482 m .46964 .6157 L .47797 .62443 L p
1 g
F P
s
P
p
.002 w
.5312 .61963 m .47797 .62443 L .46964 .6157 L p
1 g
F P
s
P
p
.002 w
.63708 .30558 m .58328 .26373 L .59027 .25795 L p
1 g
F P
s
P
p
.002 w
.59027 .25795 m .64296 .29891 L .63708 .30558 L p
1 g
F P
s
P
p
.002 w
.59545 .59888 m .636 .55881 L .6507 .55361 L p
1 g
F P
s
P
p
.002 w
.67622 .49844 m .6507 .55361 L .636 .55881 L p
1 g
F P
s
P
p
.002 w
.67469 .36203 m .63708 .30558 L .64296 .29891 L p
1 g
F P
s
P
p
.002 w
.51087 .25267 m .44672 .25247 L .45531 .24155 L p
1 g
F P
s
P
p
.002 w
.45531 .24155 m .52006 .24163 L .51087 .25267 L p
1 g
F P
s
P
p
.002 w
.32368 .40524 m .31569 .45202 L .3063 .44191 L p
1 g
F P
s
P
p
.002 w
.3063 .44191 m .3151 .38954 L .32368 .40524 L p
1 g
F P
s
P
p
.002 w
.5312 .61963 m .57922 .59775 L .59545 .59888 L p
1 g
F P
s
P
p
.002 w
.636 .55881 m .59545 .59888 L .57922 .59775 L p
1 g
F P
s
P
p
.002 w
.43937 .26907 m .3836 .28896 L .3887 .27337 L p
1 g
F P
s
P
p
.002 w
.3887 .27337 m .44672 .25247 L .43937 .26907 L p
1 g
F P
s
P
p
.002 w
.35588 .54007 m .38491 .57089 L .37926 .58004 L p
1 g
F P
s
P
p
.002 w
.37926 .58004 m .3452 .54388 L .35588 .54007 L p
1 g
F P
s
P
p
.002 w
.4221 .60482 m .37926 .58004 L .38491 .57089 L p
1 g
F P
s
P
p
.002 w
.33722 .50251 m .35588 .54007 L .3452 .54388 L p
1 g
F P
s
P
p
.002 w
.3452 .54388 m .32324 .4998 L .33722 .50251 L p
1 g
F P
s
P
p
.002 w
.67622 .49844 m .68121 .43553 L .69167 .42595 L p
1 g
F P
s
P
p
.002 w
.67469 .36203 m .69167 .42595 L .68121 .43553 L p
1 g
F P
s
P
p
.002 w
.46964 .6157 m .51725 .61131 L .5312 .61963 L p
1 g
F P
s
P
p
.002 w
.57922 .59775 m .5312 .61963 L .51725 .61131 L p
1 g
F P
s
P
p
.004 w
.56001 .61186 m
.56381 .62334 L
s
P
p
.002 w
.38176 .30934 m .34095 .3436 L .33976 .32606 L p
1 g
F P
s
P
p
.002 w
.33976 .32606 m .3836 .28896 L .38176 .30934 L p
1 g
F P
s
P
p
.002 w
.38491 .57089 m .42142 .59198 L .4221 .60482 L p
1 g
F P
s
P
p
.002 w
.46964 .6157 m .4221 .60482 L .42142 .59198 L p
1 g
F P
s
P
p
.002 w
.57353 .27469 m .51087 .25267 L .52006 .24163 L p
1 g
F P
s
P
p
.002 w
.52006 .24163 m .58328 .26373 L .57353 .27469 L p
1 g
F P
s
P
p
.002 w
.3309 .46189 m .33722 .50251 L .32324 .4998 L p
1 g
F P
s
P
p
.002 w
.32324 .4998 m .31569 .45202 L .3309 .46189 L p
1 g
F P
s
P
p
.002 w
.3469 .36437 m .32368 .40524 L .3151 .38954 L p
1 g
F P
s
P
p
.002 w
.3151 .38954 m .34095 .3436 L .3469 .36437 L p
1 g
F P
s
P
p
.002 w
.636 .55881 m .66034 .50577 L .67622 .49844 L p
1 g
F P
s
P
p
.002 w
.68121 .43553 m .67622 .49844 L .66034 .50577 L p
1 g
F P
s
P
p
.002 w
.42142 .59198 m .46188 .60116 L .46964 .6157 L p
1 g
F P
s
P
p
.002 w
.51725 .61131 m .46964 .6157 L .46188 .60116 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.55695 .60262 L
s
P
p
.002 w
.68121 .43553 m .66426 .37219 L .67469 .36203 L p
1 g
F P
s
P
p
.002 w
.63708 .30558 m .67469 .36203 L .66426 .37219 L p
1 g
F P
s
P
p
.002 w
.57922 .59775 m .61673 .56043 L .636 .55881 L p
1 g
F P
s
P
p
.002 w
.66034 .50577 m .636 .55881 L .61673 .56043 L p
1 g
F P
s
P
p
.002 w
.6269 .31622 m .57353 .27469 L .58328 .26373 L p
1 g
F P
s
P
p
.002 w
.58328 .26373 m .63708 .30558 L .6269 .31622 L p
1 g
F P
s
P
p
.002 w
.501 .26946 m .43937 .26907 L .44672 .25247 L p
1 g
F P
s
P
p
.002 w
.44672 .25247 m .51087 .25267 L .501 .26946 L p
1 g
F P
s
P
p
.002 w
.33783 .42226 m .3309 .46189 L .31569 .45202 L p
1 g
F P
s
P
p
.002 w
.31569 .45202 m .32368 .40524 L .33783 .42226 L p
1 g
F P
s
P
p
.002 w
.66426 .37219 m .6269 .31622 L .63708 .30558 L p
1 g
F P
s
P
p
.002 w
.51725 .61131 m .56004 .59163 L .57922 .59775 L p
1 g
F P
s
P
p
.004 w
.55736 .60386 m
.5578 .60519 L
s
P
p
.004 w
.5578 .60519 m
.56001 .61186 L
s
P
p
.002 w
.61673 .56043 m .57922 .59775 L .56004 .59163 L p
1 g
F P
s
P
p
.002 w
.43357 .29112 m .38176 .30934 L .3836 .28896 L p
1 g
F P
s
P
p
.002 w
.3836 .28896 m .43937 .26907 L .43357 .29112 L p
1 g
F P
s
P
p
.002 w
.46188 .60116 m .50226 .5973 L .51725 .61131 L p
1 g
F P
s
P
p
.002 w
.56004 .59163 m .51725 .61131 L .50226 .5973 L p
1 g
F P
s
P
p
.002 w
.37128 .53284 m .3942 .55719 L .38491 .57089 L p
1 g
F P
s
P
p
.002 w
.38491 .57089 m .35588 .54007 L .37128 .53284 L p
1 g
F P
s
P
p
.002 w
.42142 .59198 m .38491 .57089 L .3942 .55719 L p
1 g
F P
s
P
p
.002 w
.66034 .50577 m .66494 .44534 L .68121 .43553 L p
1 g
F P
s
P
p
.002 w
.66426 .37219 m .68121 .43553 L .66494 .44534 L p
1 g
F P
s
P
p
.002 w
.38341 .33406 m .3469 .36437 L .34095 .3436 L p
1 g
F P
s
P
p
.002 w
.34095 .3436 m .38176 .30934 L .38341 .33406 L p
1 g
F P
s
P
p
.002 w
.35661 .50318 m .37128 .53284 L .35588 .54007 L p
1 g
F P
s
P
p
.002 w
.35588 .54007 m .33722 .50251 L .35661 .50318 L p
1 g
F P
s
P
p
.002 w
.3942 .55719 m .42305 .57381 L .42142 .59198 L p
1 g
F P
s
P
p
.002 w
.46188 .60116 m .42142 .59198 L .42305 .57381 L p
1 g
F P
s
P
p
.002 w
.5612 .29075 m .501 .26946 L .51087 .25267 L p
1 g
F P
s
P
p
.002 w
.51087 .25267 m .57353 .27469 L .5612 .29075 L p
1 g
F P
s
P
p
.002 w
.35767 .38781 m .33783 .42226 L .32368 .40524 L p
1 g
F P
s
P
p
.002 w
.32368 .40524 m .3469 .36437 L .35767 .38781 L p
1 g
F P
s
P
p
.002 w
.35174 .47117 m .35661 .50318 L .33722 .50251 L p
1 g
F P
s
P
p
.002 w
.33722 .50251 m .3309 .46189 L .35174 .47117 L p
1 g
F P
s
P
p
.002 w
.61673 .56043 m .6391 .51113 L .66034 .50577 L p
1 g
F P
s
P
p
.002 w
.66494 .44534 m .66034 .50577 L .6391 .51113 L p
1 g
F P
s
P
p
.002 w
.42305 .57381 m .45496 .58097 L .46188 .60116 L p
1 g
F P
s
P
p
.002 w
.50226 .5973 m .46188 .60116 L .45496 .58097 L p
1 g
F P
s
P
p
.002 w
.56004 .59163 m .59329 .55821 L .61673 .56043 L p
1 g
F P
s
P
p
.002 w
.6391 .51113 m .61673 .56043 L .59329 .55821 L p
1 g
F P
s
P
p
.002 w
.66494 .44534 m .6485 .3845 L .66426 .37219 L p
1 g
F P
s
P
p
.002 w
.6269 .31622 m .66426 .37219 L .6485 .3845 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.49075 .29172 m .43357 .29112 L .43937 .26907 L p
1 g
F P
s
P
p
.002 w
.43937 .26907 m .501 .26946 L .49075 .29172 L p
1 g
F P
s
P
p
.002 w
.6125 .33072 m .5612 .29075 L .57353 .27469 L p
1 g
F P
s
P
p
.002 w
.57353 .27469 m .6269 .31622 L .6125 .33072 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.35735 .44008 m .35174 .47117 L .3309 .46189 L p
1 g
F P
s
P
p
.002 w
.3309 .46189 m .33783 .42226 L .35735 .44008 L p
1 g
F P
s
P
p
.002 w
.50226 .5973 m .5384 .58047 L .56004 .59163 L p
1 g
F P
s
P
p
.002 w
.59329 .55821 m .56004 .59163 L .5384 .58047 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.6485 .3845 m .6125 .33072 L .6269 .31622 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.42962 .31812 m .38341 .33406 L .38176 .30934 L p
1 g
F P
s
P
p
.002 w
.38176 .30934 m .43357 .29112 L .42962 .31812 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.45496 .58097 m .47993 .57847 L p
.50226 .5973 L 1 g
F P
s
P
p
.002 w
.48925 .58099 m .50226 .5973 L p
.48217 .58036 L 1 g
F P
s
P
p
.48217 .58036 m .47993 .57847 L .48904 .58093 L 1 g
F
P
p
.48217 .58036 m .48904 .58093 L .48925 .58099 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51089 .58 L p
1 g
F P
s
P
p
.002 w
.5384 .58047 m .50226 .5973 L .4922 .58469 L p
1 g
F P
s
P
p
.5384 .58047 m .4922 .58469 L .50786 .58076 L 1 g
F
P
p
.53128 .57265 m .51089 .58 L .52273 .57703 L 1 g
F
P
p
.002 w
.51089 .58 m .51079 .57862 L p
.50192 .58039 L 1 g
F P
s
P
p
.002 w
.48904 .58093 m .48921 .57862 L p
.47768 .57767 L 1 g
F P
s
P
p
.002 w
.45496 .58097 m .45218 .56871 L p
.46834 .57439 L 1 g
F P
s
P
p
.002 w
.47993 .57847 m .47546 .57891 L p
.46834 .57439 L 1 g
F P
s
P
p
.002 w
.47546 .57891 m .45496 .58097 L p
.46834 .57439 L 1 g
F P
s
P
p
.002 w
.46834 .57439 m .46872 .57265 L p
.46034 .5693 L 1 g
F P
s
P
p
.47768 .57767 m .47993 .57847 L .48904 .58093 L 1 g
F
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45075 .56319 L p
1 g
F P
s
P
p
.45496 .58097 m .43662 .55276 L .45075 .56319 L 1 g
F
P
p
.002 w
.45096 .56334 m .45099 .56347 L p
.45075 .56319 L 1 g
F P
s
P
p
.002 w
.45099 .56347 m .45496 .58097 L p
.45075 .56319 L 1 g
F P
s
P
p
.002 w
.45075 .56319 m .45146 .56129 L p
.44306 .55399 L 1 g
F P
s
P
p
.002 w
.42708 .55065 m .43049 .53592 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.44321 .55421 m .44043 .5536 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.44043 .5536 m .42708 .55065 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.43839 .54728 m .43925 .54566 L p
.43543 .5381 L 1 g
F P
s
P
p
.44306 .55399 m .44321 .55421 L .45075 .56319 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43801 .54801 L p
1 g
F P
s
P
p
.45146 .56129 m .43801 .54801 L .44295 .55389 L 1 g
F
P
p
.46872 .57265 m .45075 .56319 L .45085 .56326 L 1 g
F
P
p
.46872 .57265 m .45075 .56321 L .46034 .5693 L 1 g
F
P
p
.002 w
.44919 .55553 m .45096 .56334 L p
.45075 .56319 L 1 g
F P
s
P
p
.002 w
.43662 .55276 m .44321 .55421 L p
.45075 .56319 L 1 g
F P
s
P
p
.002 w
.44321 .55421 m .44919 .55553 L p
.45075 .56319 L 1 g
F P
s
P
p
.002 w
.43801 .54801 m .43743 .5491 L p
.44295 .55389 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43243 .52883 L p
1 g
F P
s
P
p
.43925 .54566 m .43243 .52883 L .43543 .5381 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.42316 .5172 m .43266 .52263 L p
.42708 .55065 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43392 .50937 L p
1 g
F P
s
P
p
.002 w
.42316 .5172 m .43463 .50191 L p
.43392 .50937 L 1 g
F P
s
P
p
.002 w
.43266 .52263 m .4287 .52036 L p
.43392 .50937 L 1 g
F P
s
P
p
.002 w
.4287 .52036 m .42316 .5172 L p
.43392 .50937 L 1 g
F P
s
P
p
.002 w
.43392 .50937 m .43485 .50826 L p
.43856 .49959 L 1 g
F P
s
P
p
.43346 .52734 m .43392 .50937 L .43324 .5165 L 1 g
F
P
p
.43346 .52734 m .43311 .51033 L .43306 .51186 L 1 g
F
P
p
.43346 .52734 m .43302 .51044 L .43295 .5127 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43248 .52735 m .43226 .5283 L p
.43266 .52263 L 1 g
F P
s
P
p
.002 w
.43226 .5283 m .42708 .55065 L p
.43182 .52683 L 1 g
F P
s
P
p
.43182 .52683 m .43266 .52263 L .43226 .5283 L 1 g
F
P
p
.002 w
.43049 .53592 m .43226 .5283 L p
.43243 .52883 L 1 g
F P
s
P
p
.002 w
.43226 .5283 m .43248 .52735 L p
.43243 .52883 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43243 .52883 L p
1 g
F P
s
P
p
.002 w
.43243 .52883 m .43346 .52734 L p
.43295 .5127 L 1 g
F P
s
P
p
.43295 .5127 m .43287 .51061 L .43243 .52883 L 1 g
F
P
p
.43839 .54728 m .43213 .53828 L .43243 .52883 L 1 g
F
P
p
.43213 .53828 m .43049 .53592 L .43243 .52883 L 1 g
F
P
p
.002 w
.43243 .52883 m .43243 .52885 L p
.43543 .5381 L 1 g
F P
s
P
p
.002 w
.43243 .52885 m .43146 .53025 L p
.43489 .53703 L 1 g
F P
s
P
p
.43543 .5381 m .43243 .52885 L .43489 .53703 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43463 .50191 m .44208 .49198 L p
.44192 .49251 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44237 .49158 L p
1 g
F P
s
P
p
.002 w
.44225 .49183 m .44208 .49198 L .4422 .49175 L p
1 g
F P
s
P
p
.002 w
.4422 .49175 m .44543 .4855 L p
.44237 .49158 L 1 g
F P
s
P
p
.44237 .49158 m .44225 .49183 L .4422 .49175 L 1 g
F
P
p
.002 w
.44237 .49158 m .44237 .49159 L p
.44237 .49159 L 1 g
F P
s
P
p
.43485 .50826 m .44237 .49158 L .44237 .49159 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44237 .49158 m .44339 .4905 L p
.45057 .48362 L 1 g
F P
s
P
p
.43485 .50826 m .44237 .49159 L .44236 .49161 L 1 g
F
P
p
.43485 .50826 m .44237 .49159 L .44235 .49162 L 1 g
F
P
p
.43485 .50826 m .44236 .49159 L .44234 .49164 L 1 g
F
P
p
.43485 .50826 m .44236 .49159 L .44233 .49165 L 1 g
F
P
p
.43485 .50826 m .44236 .4916 L .44233 .49166 L 1 g
F
P
p
.43485 .50826 m .44235 .4916 L .44232 .49166 L 1 g
F
P
p
.43485 .50826 m .44235 .49161 L .44232 .49166 L 1 g
F
P
p
.43485 .50826 m .44235 .49161 L .44233 .49164 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44238 .49158 m .45965 .47581 L .44225 .49183 L 1 g
F
P
p
.002 w
.45974 .47576 m .44225 .49183 L p
.45965 .47581 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.46766 .4685 m .49454 .44356 L p
.48233 .46484 L 1 g
F P
s
P
p
.002 w
.4745 .47847 m .4695 .47118 L p
.47754 .46721 L 1 g
F P
s
P
p
.48128 .46666 m .4745 .47847 L .47754 .46721 L 1 g
F
P
p
.002 w
.47754 .46721 m .47786 .46667 L p
.48871 .46557 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47789 .48979 m .4745 .47847 L .50493 .46473 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46713 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51462 .48573 m .50862 .46531 L p
.52242 .46713 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .53127 .4714 L 1 g
F
P
p
.52624 .46897 m .51462 .48573 L .52242 .46713 L 1 g
F
P
p
.002 w
.52242 .46713 m .52214 .46667 L p
.53127 .4714 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.58513 .47271 m .56823 .51396 L .56595 .50921 L 1 g
F
P
p
.56445 .49574 m .56595 .50921 L .5612 .49935 L 1 g
F
P
p
.58513 .47271 m .56595 .50921 L .56445 .49574 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5672 .5283 L p
1 g
F P
s
P
p
.002 w
.58262 .51481 m .58191 .51644 L p
.56702 .52484 L 1 g
F P
s
P
p
.58262 .51481 m .56702 .52484 L .56698 .52405 L 1 g
F
P
p
.56515 .50826 m .5672 .5283 L .56669 .51823 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54904 .56264 L p
1 g
F P
s
P
p
.5663 .55205 m .53556 .57852 L .54904 .56264 L 1 g
F
P
p
.5633 .55277 m .54904 .56264 L .5559 .55456 L 1 g
F
P
p
.5663 .55205 m .54904 .56264 L .5633 .55277 L 1 g
F
P
p
.002 w
.54904 .56264 m .54854 .56129 L p
.54207 .56745 L 1 g
F P
s
P
p
.56075 .54566 m .54904 .56264 L .55549 .55503 L 1 g
F
P
p
.55575 .55473 m .54991 .56498 L .55102 .5633 L 1 g
F
P
p
.56075 .54566 m .55549 .55503 L .55575 .55473 L 1 g
F
P
p
.55549 .55503 m .54991 .56498 L .55575 .55473 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55987 .54988 m .5663 .55205 L p
.5559 .55456 L 1 g
F P
s
P
p
.002 w
.58191 .51644 m .5663 .55205 L .56073 .55017 L p
1 g
F P
s
P
p
.002 w
.56073 .55017 m .55987 .54988 L p
.5616 .54725 L 1 g
F P
s
P
p
.58191 .51644 m .56073 .55017 L .5616 .54725 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54725 L p
1 g
F P
s
P
p
.56654 .52734 m .5616 .54725 L .56501 .53569 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5616 .54725 L p
1 g
F P
s
P
p
.002 w
.5616 .54725 m .56075 .54566 L p
.55102 .5633 L 1 g
F P
s
P
p
.55102 .5633 m .54998 .56518 L .5616 .54725 L 1 g
F
P
p
.58191 .51644 m .5616 .54725 L .56846 .52402 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55987 .54988 m .5366 .54201 L p
.56846 .52402 L 1 g
F P
s
P
p
.5616 .54725 m .55987 .54988 L .56846 .52402 L 1 g
F
P
p
.002 w
.5616 .54725 m .56257 .5491 L p
.56501 .53569 L 1 g
F P
s
P
p
.002 w
.51495 .56441 m .5366 .54201 L .55987 .54988 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.5559 .55456 m .51495 .56441 L .55987 .54988 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57462 L p
1 g
F P
s
P
p
.54904 .56264 m .54243 .57043 L .53889 .56966 L 1 g
F
P
p
.002 w
.53556 .57852 m .53053 .57508 L p
.54243 .57043 L 1 g
F P
s
P
p
.54854 .56129 m .53171 .57462 L .54207 .56745 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4922 .58469 m .48922 .58095 L p
.50786 .58076 L 1 g
F P
s
P
p
.5384 .58047 m .48922 .58095 L .52098 .57956 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58093 L p
1 g
F P
s
P
p
.002 w
.48922 .58095 m .48925 .58099 L p
.48904 .58093 L 1 g
F P
s
P
p
.002 w
.48904 .58093 m .48889 .583 L p
.49623 .58153 L 1 g
F P
s
P
p
.002 w
.53171 .57462 m .53128 .57265 L p
.52273 .57703 L 1 g
F P
s
P
p
.52273 .57703 m .53053 .57508 L .53171 .57462 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53053 .57508 m .51495 .56441 L p
.53889 .56966 L 1 g
F P
s
P
p
.54243 .57043 m .53171 .57462 L .53889 .56966 L 1 g
F
P
p
.53171 .57462 m .53053 .57508 L .53889 .56966 L 1 g
F
P
p
.002 w
.53171 .57462 m .53174 .57478 L p
.54207 .56745 L 1 g
F P
s
P
p
.002 w
.53079 .57525 m .53612 .5789 L p
.52407 .57863 L 1 g
F P
s
P
p
.002 w
.53174 .57478 m .5322 .57686 L p
.53735 .57196 L 1 g
F P
s
P
p
.54207 .56745 m .53174 .57478 L .53735 .57196 L 1 g
F
P
p
.002 w
.53053 .57508 m .53079 .57525 L p
.52955 .57533 L 1 g
F P
s
P
p
.52407 .57863 m .517 .57847 L .53079 .57525 L 1 g
F
P
p
.517 .57847 m .4867 .57779 L .52955 .57533 L 1 g
F
P
p
.517 .57847 m .52955 .57533 L .53079 .57525 L 1 g
F
P
p
.51079 .57862 m .48904 .58093 L .48922 .58095 L 1 g
F
P
p
.51079 .57862 m .48922 .58095 L .50192 .58039 L 1 g
F
P
p
.52098 .57956 m .4867 .57779 L .53612 .5789 L 1 g
F
P
p
.52098 .57956 m .51089 .58 L .51407 .57921 L 1 g
F
P
p
.5138 .58162 m .51111 .583 L .53065 .57505 L 1 g
F
P
p
.53053 .57508 m .53065 .57505 L .53171 .57462 L 1 g
F
P
p
.5138 .58162 m .53065 .57505 L .53053 .57508 L 1 g
F
P
p
.002 w
.53612 .5789 m .5384 .58047 L p
.52098 .57956 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53174 .57478 L p
1 g
F P
s
P
p
.002 w
.53174 .57478 m .53171 .57462 L p
.53065 .57505 L 1 g
F P
s
P
p
.53065 .57505 m .51111 .583 L .53174 .57478 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.4867 .57779 m .51495 .56441 L .53053 .57508 L p
1 g
F P
s
P
p
.52955 .57533 m .4867 .57779 L .53053 .57508 L 1 g
F
P
p
.50192 .58039 m .48922 .58095 L .49623 .58153 L 1 g
F
P
p
.002 w
.47993 .57847 m .4867 .57779 L .48922 .58095 L p
1 g
F P
s
P
p
.48904 .58093 m .47993 .57847 L .48922 .58095 L 1 g
F
P
p
.002 w
.48922 .58095 m .4867 .57779 L p
.51407 .57921 L 1 g
F P
s
P
p
.51089 .58 m .48922 .58095 L .51407 .57921 L 1 g
F
P
p
.52273 .57703 m .5138 .58162 L .53053 .57508 L 1 g
F
P
p
.5559 .55456 m .54904 .56264 L .51495 .56441 L 1 g
F
P
p
.54904 .56264 m .53889 .56966 L .51495 .56441 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54904 .56264 L p
1 g
F P
s
P
p
.54207 .56745 m .5322 .57686 L .54904 .56264 L 1 g
F
P
p
.002 w
.54904 .56264 m .54991 .56498 L p
.55549 .55503 L 1 g
F P
s
P
p
.002 w
.5663 .55205 m .5384 .58047 L .53556 .57852 L p
1 g
F P
s
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56669 .51823 L 1 g
F P
s
P
p
.002 w
.56646 .51385 m .58262 .51481 L p
.56698 .52405 L 1 g
F P
s
P
p
.56669 .51823 m .56765 .52446 L .56646 .51385 L 1 g
F
P
p
.56669 .51823 m .56646 .51385 L .56595 .50921 L 1 g
F
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.5366 .54201 m .54911 .51282 L .56646 .51385 L p
1 g
F P
s
P
p
.56698 .52405 m .5366 .54201 L .56646 .51385 L 1 g
F
P
p
.002 w
.5672 .5283 m .56854 .53025 L p
.56669 .51823 L 1 g
F P
s
P
p
.56698 .52405 m .56702 .52484 L .5366 .54201 L 1 g
F
P
p
.002 w
.54991 .56498 m .54998 .56518 L p
.55102 .5633 L 1 g
F P
s
P
p
.55661 .4905 m .56595 .50921 L .56079 .4985 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56823 .51396 m .54911 .51282 L p
.5612 .49935 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56765 .52446 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.5633 .49702 m .5612 .49935 L .55729 .49122 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55729 .49122 L p
1 g
F P
s
P
p
.002 w
.55729 .49122 m .55661 .4905 L p
.56079 .4985 L 1 g
F P
s
P
p
.56079 .4985 m .56713 .51061 L .55729 .49122 L 1 g
F
P
p
.002 w
.54911 .51282 m .55058 .48475 L p
.55729 .49122 L 1 g
F P
s
P
p
.5612 .49935 m .54911 .51282 L .55729 .49122 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55729 .49122 L p
1 g
F P
s
P
p
.002 w
.55729 .49122 m .55834 .49233 L p
.55123 .48538 L 1 g
F P
s
P
p
.54174 .47608 m .55729 .49122 L .55123 .48538 L 1 g
F
P
p
.002 w
.55084 .47996 m .58513 .47271 L p
.5633 .49702 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54233 .47673 m .54174 .47608 L p
.55159 .48573 L 1 g
F P
s
P
p
.002 w
.54911 .51282 m .51361 .50823 L p
.54792 .48217 L 1 g
F P
s
P
p
.002 w
.55058 .48475 m .54911 .51282 L p
.54792 .48217 L 1 g
F P
s
P
p
.55159 .48573 m .54638 .48067 L .54233 .47673 L 1 g
F
P
p
.002 w
.51361 .50823 m .51462 .48573 L .54638 .48067 L p
1 g
F P
s
P
p
.002 w
.54638 .48067 m .55084 .47996 L p
.54792 .48217 L 1 g
F P
s
P
p
.54792 .48217 m .51361 .50823 L .54638 .48067 L 1 g
F
P
p
.002 w
.54638 .48067 m .51462 .48573 L p
.52951 .46424 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54247 .47688 L p
1 g
F P
s
P
p
.002 w
.54247 .47688 m .54233 .47673 L p
.54574 .48005 L 1 g
F P
s
P
p
.54574 .48005 m .55834 .49233 L .54247 .47688 L 1 g
F
P
p
.55159 .48573 m .55588 .48992 L .54638 .48067 L 1 g
F
P
p
.002 w
.55084 .47996 m .55058 .48475 L p
.54792 .48217 L 1 g
F P
s
P
p
.002 w
.54137 .44713 m .55084 .47996 L .54638 .48067 L p
1 g
F P
s
P
p
.54137 .44713 m .54638 .48067 L .52951 .46424 L 1 g
F
P
p
.55588 .48992 m .55834 .49233 L .54233 .47673 L 1 g
F
P
p
.002 w
.55058 .48475 m .55084 .47996 L p
.5633 .49702 L 1 g
F P
s
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.56079 .4985 L 1 g
F P
s
P
p
.002 w
.58513 .47271 m .58262 .51481 L .56823 .51396 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52242 .46713 L p
1 g
F P
s
P
p
.53127 .4714 m .54302 .47747 L .52242 .46713 L 1 g
F
P
p
.5 .4634 m .52242 .46713 L .51531 .46619 L 1 g
F
P
p
.5 .4634 m .52266 .46753 L .51805 .4668 L 1 g
F
P
p
.51615 .4665 m .52276 .46769 L .51962 .46717 L 1 g
F
P
p
.5 .4634 m .51805 .4668 L .51615 .4665 L 1 g
F
P
p
.51805 .4668 m .52276 .46769 L .51615 .4665 L 1 g
F
P
p
.002 w
.51462 .48573 m .47789 .48979 L p
.50621 .46493 L 1 g
F P
s
P
p
.002 w
.50862 .46531 m .51462 .48573 L p
.50621 .46493 L 1 g
F P
s
P
p
.50621 .46493 m .47789 .48979 L .50493 .46473 L 1 g
F
P
p
.48128 .46666 m .50143 .46415 L .4745 .47847 L 1 g
F
P
p
.002 w
.50493 .46473 m .4745 .47847 L p
.50143 .46415 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .4634 L p
.51962 .46717 L 1 g
F P
s
P
p
.002 w
.50767 .46278 m .50804 .46332 L p
.48128 .46666 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46391 L p
1 g
F P
s
P
p
.51962 .46717 m .52282 .46778 L .5 .46391 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.49454 .44356 m .50767 .46278 L p
.5 .46391 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46391 L .48871 .46557 L 1 g
F
P
p
.48435 .46131 m .5 .46391 L .48128 .46666 L 1 g
F
P
p
.49454 .44356 m .5 .46391 L .48435 .46131 L 1 g
F
P
p
.002 w
.50804 .46332 m .50862 .46531 L p
.50621 .46493 L 1 g
F P
s
P
p
.002 w
.50862 .46531 m .50804 .46332 L p
.52054 .46623 L 1 g
F P
s
P
p
.52708 .46775 m .52242 .46713 L .52054 .46623 L 1 g
F
P
p
.52242 .46713 m .50862 .46531 L .52054 .46623 L 1 g
F
P
p
.52708 .46775 m .52624 .46897 L .52242 .46713 L 1 g
F
P
p
.002 w
.54233 .47673 m .54302 .47747 L p
.53127 .4714 L 1 g
F P
s
P
p
.002 w
.52242 .46713 m .52266 .46753 L p
.51531 .46619 L 1 g
F P
s
P
p
.002 w
.50804 .46332 m .54137 .44713 L p
.52708 .46775 L 1 g
F P
s
P
p
.002 w
.50493 .46473 m .50804 .46332 L p
.50621 .46493 L 1 g
F P
s
P
p
.002 w
.52266 .46753 m .52276 .46769 L p
.51805 .4668 L 1 g
F P
s
P
p
.002 w
.52276 .46769 m .52282 .46778 L p
.51962 .46717 L 1 g
F P
s
P
p
.002 w
.50804 .46332 m .50493 .46473 L p
.50143 .46415 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .46442 L p
.48871 .46557 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47754 .46721 L p
1 g
F P
s
P
p
.48871 .46557 m .5 .46442 L .47754 .46721 L 1 g
F
P
p
.48233 .46484 m .48128 .46666 L .47754 .46721 L 1 g
F
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.47006 .4709 L 1 g
F P
s
P
p
.47006 .4709 m .46951 .47118 L .45765 .47674 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47736 .46749 L p
1 g
F P
s
P
p
.002 w
.47736 .46749 m .47734 .46752 L p
.47632 .46798 L 1 g
F P
s
P
p
.45826 .47608 m .47736 .46749 L .47632 .46798 L 1 g
F
P
p
.43485 .50826 m .44234 .49161 L .43856 .49959 L 1 g
F
P
p
.002 w
.44225 .49183 m .45974 .47576 L p
.44219 .49194 L 1 g
F P
s
P
p
.45826 .47608 m .47734 .46752 L .47096 .47051 L 1 g
F
P
p
.47052 .4707 m .45974 .47576 L .45765 .47674 L 1 g
F
P
p
.002 w
.45974 .47576 m .46766 .4685 L p
.45978 .47575 L 1 g
F P
s
P
p
.45978 .47575 m .44219 .49194 L .45974 .47576 L 1 g
F
P
p
.002 w
.46682 .46784 m .46766 .4685 L p
.45965 .47581 L 1 g
F P
s
P
p
.45765 .47674 m .45965 .47581 L .44238 .49158 L 1 g
F
P
p
.46682 .46784 m .45965 .47581 L .45765 .47674 L 1 g
F
P
p
.002 w
.47734 .46752 m .47718 .46778 L p
.47096 .47051 L 1 g
F P
s
P
p
.002 w
.4695 .47118 m .46766 .4685 L p
.48233 .46484 L 1 g
F P
s
P
p
.47006 .4709 m .47052 .4707 L .46951 .47118 L 1 g
F
P
p
.002 w
.4695 .47118 m .4745 .47847 L p
.45978 .47575 L 1 g
F P
s
P
p
.47052 .4707 m .47096 .47051 L .45974 .47576 L 1 g
F
P
p
.002 w
.4745 .47847 m .44219 .49194 L p
.45978 .47575 L 1 g
F P
s
P
p
.002 w
.46766 .4685 m .4695 .47118 L p
.45978 .47575 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.47096 .47051 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.002 w
.46766 .4685 m .45974 .47576 L p
.45965 .47581 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45765 .47674 L p
1 g
F P
s
P
p
.44339 .4905 m .45765 .47674 L .45057 .48362 L 1 g
F
P
p
.002 w
.45811 .46098 m .46682 .46784 L p
.44238 .49158 L 1 g
F P
s
P
p
.002 w
.45765 .47674 m .45698 .47747 L p
.45057 .48362 L 1 g
F P
s
P
p
.002 w
.44543 .4855 m .45811 .46098 L p
.44225 .49183 L 1 g
F P
s
P
p
.002 w
.44237 .49159 m .44237 .49159 L p
.44236 .49161 L 1 g
F P
s
P
p
.002 w
.44237 .49159 m .44236 .49159 L p
.44235 .49162 L 1 g
F P
s
P
p
.002 w
.44236 .49159 m .44236 .49159 L p
.44234 .49164 L 1 g
F P
s
P
p
.002 w
.44236 .49159 m .44236 .4916 L p
.44233 .49165 L 1 g
F P
s
P
p
.002 w
.44236 .4916 m .44235 .4916 L p
.44233 .49166 L 1 g
F P
s
P
p
.002 w
.44235 .4916 m .44235 .49161 L p
.44232 .49166 L 1 g
F P
s
P
p
.002 w
.44235 .49161 m .44235 .49161 L p
.44232 .49166 L 1 g
F P
s
P
p
.002 w
.44235 .49161 m .44234 .49161 L p
.44233 .49164 L 1 g
F P
s
P
p
.002 w
.44219 .49194 m .44208 .49198 L .44225 .49183 L p
1 g
F P
s
P
p
.002 w
.44217 .49198 m .44208 .49198 L .44219 .49194 L p
1 g
F P
s
P
p
.002 w
.44216 .492 m .44208 .49198 L .44217 .49198 L p
1 g
F P
s
P
p
.002 w
.44215 .49203 m .44208 .49198 L .44216 .492 L p
1 g
F P
s
P
p
.002 w
.44214 .49205 m .44208 .49198 L .44215 .49203 L p
1 g
F P
s
P
p
.002 w
.44212 .49208 m .44208 .49198 L .44214 .49205 L p
1 g
F P
s
P
p
.002 w
.44209 .49214 m .44208 .49198 L .44212 .49208 L p
1 g
F P
s
P
p
.002 w
.44196 .49243 m .44208 .49198 L .44209 .49214 L p
1 g
F P
s
P
p
.43392 .50937 m .43463 .50191 L .44192 .49251 L 1 g
F
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44208 .49198 m .43347 .52309 L .43266 .52263 L p
1 g
F P
s
P
p
.002 w
.42316 .5172 m .41499 .5085 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.41499 .5085 m .40982 .49791 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.40982 .49791 m .4082 .48655 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.4082 .48655 m .41033 .47562 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.41033 .47562 m .41601 .46629 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.41601 .46629 m .42466 .4596 L .44204 .49191 L p
1 g
F P
s
P
p
.002 w
.44204 .49191 m .44208 .49198 L .44202 .49192 L p
1 g
F P
s
P
p
.002 w
.44202 .49192 m .41601 .46629 L p
.44204 .49191 L 1 g
F P
s
P
p
.002 w
.42466 .4596 m .43535 .45629 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.44229 .49172 m .44166 .49233 L p
.43856 .49959 L 1 g
F P
s
P
p
.002 w
.44693 .45676 m .45811 .46098 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.43535 .45629 m .44693 .45676 L .44208 .49198 L closepath p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44236 .49159 L p
1 g
F P
s
P
p
.002 w
.44236 .49159 m .44237 .49158 L p
.44271 .49126 L 1 g
F P
s
P
p
.44271 .49126 m .45698 .47747 L .44236 .49159 L 1 g
F
P
p
.45057 .48362 m .45698 .47747 L .44237 .49158 L 1 g
F
P
p
.002 w
.4745 .47847 m .47789 .48979 L .44217 .49198 L p
1 g
F P
s
P
p
.002 w
.44219 .49194 m .4745 .47847 L p
.44217 .49198 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.47789 .48979 m .47747 .5012 L .44216 .492 L p
1 g
F P
s
P
p
.002 w
.44217 .49198 m .47789 .48979 L p
.44216 .492 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.47747 .5012 m .4733 .51145 L .44215 .49203 L p
1 g
F P
s
P
p
.002 w
.44216 .492 m .47747 .5012 L p
.44215 .49203 L 1 g
F P
s
P
p
.002 w
.4733 .51145 m .46588 .51942 L .44214 .49205 L p
1 g
F P
s
P
p
.002 w
.44215 .49203 m .4733 .51145 L p
.44214 .49205 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46588 .51942 m .45603 .52429 L .44212 .49208 L p
1 g
F P
s
P
p
.002 w
.44214 .49205 m .46588 .51942 L p
.44212 .49208 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.45603 .52429 m .44482 .52554 L .44209 .49214 L p
1 g
F P
s
P
p
.002 w
.44212 .49208 m .45603 .52429 L p
.44209 .49214 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44482 .52554 m .43347 .52309 L .44196 .49243 L p
1 g
F P
s
P
p
.002 w
.44209 .49214 m .44482 .52554 L p
.44196 .49243 L 1 g
F P
s
P
p
.43266 .52263 m .43392 .50937 L .44192 .49251 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43392 .50937 L p
1 g
F P
s
P
p
.43856 .49959 m .44166 .49233 L .43392 .50937 L 1 g
F
P
p
.002 w
.43392 .50937 m .43311 .51033 L p
.43324 .5165 L 1 g
F P
s
P
p
.002 w
.43266 .52263 m .43347 .52309 L .43248 .52735 L p
1 g
F P
s
P
p
.002 w
.43311 .51033 m .43302 .51044 L p
.43306 .51186 L 1 g
F P
s
P
p
.002 w
.43302 .51044 m .43287 .51061 L p
.43295 .5127 L 1 g
F P
s
P
p
.43839 .54728 m .43243 .52883 L .43347 .52309 L 1 g
F
P
p
.002 w
.43248 .52735 m .43347 .52309 L p
.43243 .52883 L 1 g
F P
s
P
p
.44321 .55421 m .43839 .54728 L .43347 .52309 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43839 .54728 L p
1 g
F P
s
P
p
.43543 .5381 m .43146 .53025 L .43839 .54728 L 1 g
F
P
p
.44306 .55399 m .44295 .55389 L .44321 .55421 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44919 .55553 m .44321 .55421 L p
.43347 .52309 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45075 .56319 L p
1 g
F P
s
P
p
.44295 .55389 m .43743 .5491 L .45075 .56319 L 1 g
F
P
p
.002 w
.45075 .56319 m .45075 .56321 L p
.45085 .56326 L 1 g
F P
s
P
p
.002 w
.42708 .55065 m .43662 .55276 L p
.45496 .58097 L 1 g
F P
s
P
p
.47993 .57847 m .46834 .57439 L .44919 .55553 L 1 g
F
P
p
.002 w
.45218 .56871 m .45096 .56334 L p
.46834 .57439 L 1 g
F P
s
P
p
.002 w
.45096 .56334 m .44919 .55553 L p
.46834 .57439 L 1 g
F P
s
P
p
.002 w
.45075 .56321 m .45002 .56518 L p
.46034 .5693 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .57439 L p
1 g
F P
s
P
p
.46034 .5693 m .45002 .56518 L .46834 .57439 L 1 g
F
P
p
.47768 .57767 m .4767 .57759 L .47993 .57847 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.4867 .57779 m .47993 .57847 L p
.44919 .55553 L 1 g
F P
s
P
p
.002 w
.51089 .58 m .51111 .583 L p
.52273 .57703 L 1 g
F P
s
P
p
.002 w
.5111 .58277 m .51089 .58 L p
.49623 .58153 L 1 g
F P
s
P
p
.50192 .58039 m .49623 .58153 L .51089 .58 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .5111 .58277 L p
1 g
F P
s
P
p
.49623 .58153 m .48889 .583 L .5111 .58277 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58093 L p
1 g
F P
s
P
p
.4767 .57759 m .4678 .57686 L .48904 .58093 L 1 g
F
P
p
.002 w
.38866 .36244 m .35767 .38781 L .3469 .36437 L p
1 g
F P
s
P
p
.002 w
.3469 .36437 m .38341 .33406 L .38866 .36244 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.46568 .46694 m
.5 .43051 L
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.6391 .51113 m .64312 .45504 L .66494 .44534 L p
1 g
F P
s
P
p
.002 w
.6485 .3845 m .66494 .44534 L .64312 .45504 L p
1 g
F P
s
P
p
.002 w
.39115 .52225 m .40705 .53915 L .3942 .55719 L p
1 g
F P
s
P
p
.002 w
.3942 .55719 m .37128 .53284 L .39115 .52225 L p
1 g
F P
s
P
p
.002 w
.42305 .57381 m .3942 .55719 L .40705 .53915 L p
1 g
F P
s
P
p
.002 w
.38102 .50166 m .39115 .52225 L .37128 .53284 L p
1 g
F P
s
P
p
.002 w
.37128 .53284 m .35661 .50318 L .38102 .50166 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.40705 .53915 m .42708 .55065 L .42305 .57381 L p
1 g
F P
s
P
p
.002 w
.45496 .58097 m .42305 .57381 L .42708 .55065 L p
1 g
F P
s
P
p
.002 w
.37308 .41321 m .35735 .44008 L .33783 .42226 L p
1 g
F P
s
P
p
.002 w
.33783 .42226 m .35767 .38781 L .37308 .41321 L p
1 g
F P
s
P
p
.002 w
.54658 .31162 m .49075 .29172 L .501 .26946 L p
1 g
F P
s
P
p
.002 w
.501 .26946 m .5612 .29075 L .54658 .31162 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.59329 .55821 m .61294 .51421 L .6391 .51113 L p
1 g
F P
s
P
p
.002 w
.64312 .45504 m .6391 .51113 L .61294 .51421 L p
1 g
F P
s
P
p
.002 w
.37775 .47951 m .38102 .50166 L .35661 .50318 L p
1 g
F P
s
P
p
.002 w
.35661 .50318 m .35174 .47117 L .37775 .47951 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.61294 .51421 m .59329 .55821 L .5663 .55205 L p
1 g
F P
s
P
p
.002 w
.5384 .58047 m .5663 .55205 L .59329 .55821 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.64312 .45504 m .62767 .39863 L .6485 .3845 L p
1 g
F P
s
P
p
.002 w
.6125 .33072 m .6485 .3845 L .62767 .39863 L p
1 g
F P
s
P
p
.002 w
.48049 .3189 m .42962 .31812 L .43357 .29112 L p
1 g
F P
s
P
p
.002 w
.43357 .29112 m .49075 .29172 L .48049 .3189 L p
1 g
F P
s
P
p
.002 w
.38176 .45809 m .37775 .47951 L .35174 .47117 L p
1 g
F P
s
P
p
.002 w
.35174 .47117 m .35735 .44008 L .38176 .45809 L p
1 g
F P
s
P
p
.002 w
.59418 .34876 m .54658 .31162 L .5612 .29075 L p
1 g
F P
s
P
p
.002 w
.5612 .29075 m .6125 .33072 L .59418 .34876 L p
1 g
F P
s
P
p
.002 w
.42773 .34926 m .38866 .36244 L .38341 .33406 L p
1 g
F P
s
P
p
.002 w
.38341 .33406 m .42962 .31812 L .42773 .34926 L p
1 g
F P
s
P
p
.002 w
.62767 .39863 m .59418 .34876 L .6125 .33072 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39747 .39357 m .37308 .41321 L .35767 .38781 L p
1 g
F P
s
P
p
.002 w
.35767 .38781 m .38866 .36244 L .39747 .39357 L p
1 g
F P
s
P
p
.002 w
.44919 .55553 m .4711 .55321 L .4867 .57779 L p
1 g
F P
s
P
p
.002 w
.51495 .56441 m .4867 .57779 L .4711 .55321 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61294 .51421 m .61625 .46429 L .64312 .45504 L p
1 g
F P
s
P
p
.002 w
.62767 .39863 m .64312 .45504 L .61625 .46429 L p
1 g
F P
s
P
p
.002 w
.41499 .5085 m .42316 .5172 L .40705 .53915 L p
1 g
F P
s
P
p
.002 w
.40705 .53915 m .39115 .52225 L .41499 .5085 L p
1 g
F P
s
P
p
.002 w
.42708 .55065 m .40705 .53915 L .42316 .5172 L p
1 g
F P
s
P
p
.002 w
.39273 .43969 m .38176 .45809 L .35735 .44008 L p
1 g
F P
s
P
p
.002 w
.35735 .44008 m .37308 .41321 L .39273 .43969 L p
1 g
F P
s
P
p
.002 w
.40982 .49791 m .41499 .5085 L .39115 .52225 L p
1 g
F P
s
P
p
.002 w
.39115 .52225 m .38102 .50166 L .40982 .49791 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.5663 .55205 m .58262 .51481 L .61294 .51421 L p
1 g
F P
s
P
p
.002 w
.61625 .46429 m .61294 .51421 L .58262 .51481 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.53011 .33676 m .48049 .3189 L .49075 .29172 L p
1 g
F P
s
P
p
.002 w
.49075 .29172 m .54658 .31162 L .53011 .33676 L p
1 g
F P
s
P
p
.002 w
.4082 .48655 m .40982 .49791 L .38102 .50166 L p
1 g
F P
s
P
p
.002 w
.38102 .50166 m .37775 .47951 L .4082 .48655 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.43347 .52309 m .44482 .52554 L .44919 .55553 L p
1 g
F P
s
P
p
.002 w
.4711 .55321 m .44919 .55553 L .44482 .52554 L p
1 g
F P
s
P
p
.002 w
.4711 .55321 m .49048 .54385 L .51495 .56441 L p
1 g
F P
s
P
p
.002 w
.5366 .54201 m .51495 .56441 L .49048 .54385 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.4706 .35017 m .42773 .34926 L .42962 .31812 L p
1 g
F P
s
P
p
.002 w
.42962 .31812 m .48049 .3189 L .4706 .35017 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.41033 .47562 m .4082 .48655 L .37775 .47951 L p
1 g
F P
s
P
p
.002 w
.37775 .47951 m .38176 .45809 L .41033 .47562 L p
1 g
F P
s
P
p
.002 w
.61625 .46429 m .60231 .41415 L .62767 .39863 L p
1 g
F P
s
P
p
.002 w
.59418 .34876 m .62767 .39863 L .60231 .41415 L p
1 g
F P
s
P
p
.002 w
.42805 .38353 m .39747 .39357 L .38866 .36244 L p
1 g
F P
s
P
p
.002 w
.38866 .36244 m .42773 .34926 L .42805 .38353 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4096 .42637 m .39273 .43969 L .37308 .41321 L p
1 g
F P
s
P
p
.002 w
.37308 .41321 m .39747 .39357 L .4096 .42637 L p
1 g
F P
s
P
p
.002 w
.57243 .36983 m .53011 .33676 L .54658 .31162 L p
1 g
F P
s
P
p
.002 w
.54658 .31162 m .59418 .34876 L .57243 .36983 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.44482 .52554 m .45603 .52429 L .4711 .55321 L p
1 g
F P
s
P
p
.002 w
.49048 .54385 m .4711 .55321 L .45603 .52429 L p
1 g
F P
s
P
p
.002 w
.60231 .41415 m .57243 .36983 L .59418 .34876 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.41601 .46629 m .41033 .47562 L .38176 .45809 L p
1 g
F P
s
P
p
.002 w
.38176 .45809 m .39273 .43969 L .41601 .46629 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58262 .51481 m .58513 .47271 L .61625 .46429 L p
1 g
F P
s
P
p
.002 w
.60231 .41415 m .61625 .46429 L .58513 .47271 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.54911 .51282 m .5366 .54201 L .50521 .52832 L p
1 g
F P
s
P
p
.002 w
.49048 .54385 m .50521 .52832 L .5366 .54201 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45603 .52429 m .46588 .51942 L .49048 .54385 L p
1 g
F P
s
P
p
.002 w
.50521 .52832 m .49048 .54385 L .46588 .51942 L p
1 g
F P
s
P
p
.002 w
.51234 .36536 m .4706 .35017 L .48049 .3189 L p
1 g
F P
s
P
p
.002 w
.48049 .3189 m .53011 .33676 L .51234 .36536 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43061 .41967 m .4096 .42637 L .39747 .39357 L p
1 g
F P
s
P
p
.002 w
.39747 .39357 m .42805 .38353 L .43061 .41967 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.46147 .38444 m .42805 .38353 L .42773 .34926 L p
1 g
F P
s
P
p
.002 w
.42773 .34926 m .4706 .35017 L .46147 .38444 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.42466 .4596 m .41601 .46629 L .39273 .43969 L p
1 g
F P
s
P
p
.002 w
.39273 .43969 m .4096 .42637 L .42466 .4596 L p
1 g
F P
s
P
p
.002 w
.58513 .47271 m .5732 .43052 L .60231 .41415 L p
1 g
F P
s
P
p
.002 w
.57243 .36983 m .60231 .41415 L .5732 .43052 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54796 .39324 m .51234 .36536 L .53011 .33676 L p
1 g
F P
s
P
p
.002 w
.53011 .33676 m .57243 .36983 L .54796 .39324 L p
1 g
F P
s
P
p
.002 w
.46588 .51942 m .4733 .51145 L .50521 .52832 L p
1 g
F P
s
P
p
.002 w
.51361 .50823 m .50521 .52832 L .4733 .51145 L p
1 g
F P
s
P
p
.002 w
.50521 .52832 m .51361 .50823 L .54911 .51282 L p
1 g
F P
s
P
p
.002 w
.5732 .43052 m .58513 .47271 L .55084 .47996 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.5732 .43052 m .54796 .39324 L .57243 .36983 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43535 .45629 m .42466 .4596 L .4096 .42637 L p
1 g
F P
s
P
p
.002 w
.4096 .42637 m .43061 .41967 L .43535 .45629 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.45347 .42044 m .43061 .41967 L .42805 .38353 L p
1 g
F P
s
P
p
.002 w
.42805 .38353 m .46147 .38444 L .45347 .42044 L p
1 g
F P
s
P
p
.002 w
.49394 .39641 m .46147 .38444 L .4706 .35017 L p
1 g
F P
s
P
p
.002 w
.4706 .35017 m .51234 .36536 L .49394 .39641 L p
1 g
F P
s
P
p
.002 w
.4733 .51145 m .47747 .5012 L .51361 .50823 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.51462 .48573 m .51361 .50823 L .47747 .5012 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47747 .5012 m .47789 .48979 L .51462 .48573 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.55084 .47996 m .54137 .44713 L .5732 .43052 L p
1 g
F P
s
P
p
.002 w
.54796 .39324 m .5732 .43052 L .54137 .44713 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.44693 .45676 m .43535 .45629 L .43061 .41967 L p
1 g
F P
s
P
p
.002 w
.43061 .41967 m .45347 .42044 L .44693 .45676 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52166 .41814 m .49394 .39641 L .51234 .36536 L p
1 g
F P
s
P
p
.002 w
.51234 .36536 m .54796 .39324 L .52166 .41814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54137 .44713 m .52166 .41814 L .54796 .39324 L p
1 g
F P
s
P
p
.002 w
.47563 .4287 m .45347 .42044 L .46147 .38444 L p
1 g
F P
s
P
p
.002 w
.46147 .38444 m .49394 .39641 L .47563 .4287 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.45811 .46098 m .44693 .45676 L .45347 .42044 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46766 .4685 m .45811 .46098 L .47563 .4287 L p
1 g
F P
s
P
p
.002 w
.45347 .42044 m .47563 .4287 L .45811 .46098 L p
1 g
F P
s
P
p
.002 w
.47563 .4287 m .49454 .44356 L .46766 .4685 L p
1 g
F P
s
P
p
.002 w
.52166 .41814 m .54137 .44713 L .50804 .46332 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.49454 .44356 m .47563 .4287 L .49394 .39641 L p
1 g
F P
s
P
p
.002 w
.49394 .39641 m .52166 .41814 L .49454 .44356 L p
1 g
F P
s
P
p
.002 w
.50804 .46332 m .49454 .44356 L .52166 .41814 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.40665 .52958 m
.42169 .51362 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .58996 .70238 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40665 .52958 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.168217)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.168217)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47257 .42511 m .48341 .44007 L .50355 .41981 L p
1 g
F P
s
P
p
.002 w
.50355 .41981 m .49807 .41222 L .47257 .42511 L p
1 g
F P
s
P
p
.002 w
.51117 .42527 m .50355 .41981 L .48341 .44007 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .49807 .41222 L .50355 .41981 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .50355 .41981 L .51117 .42527 L closepath p
1 g
F P
s
P
p
.002 w
.48341 .44007 m .49845 .45085 L .51117 .42527 L p
1 g
F P
s
P
p
.002 w
.52011 .42802 m .51117 .42527 L .49845 .45085 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .51117 .42527 L .52011 .42802 L closepath p
1 g
F P
s
P
p
.002 w
.46709 .40754 m .47257 .42511 L .49807 .41222 L p
1 g
F P
s
P
p
.002 w
.49807 .41222 m .49532 .40332 L .46709 .40754 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .49532 .40332 L .49807 .41222 L closepath p
1 g
F P
s
P
p
.002 w
.44762 .43819 m .46359 .46018 L .48341 .44007 L p
1 g
F P
s
P
p
.002 w
.48341 .44007 m .47257 .42511 L .44762 .43819 L p
1 g
F P
s
P
p
.002 w
.49845 .45085 m .48341 .44007 L .46359 .46018 L p
1 g
F P
s
P
p
.002 w
.49845 .45085 m .51609 .4563 L .52011 .42802 L p
1 g
F P
s
P
p
.002 w
.52941 .42775 m .52011 .42802 L .51609 .4563 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .52011 .42802 L .52941 .42775 L closepath p
1 g
F P
s
P
p
.002 w
.46359 .46018 m .48571 .47604 L .49845 .45085 L p
1 g
F P
s
P
p
.002 w
.51609 .4563 m .49845 .45085 L .48571 .47604 L p
1 g
F P
s
P
p
.002 w
.46756 .38923 m .46709 .40754 L .49532 .40332 L p
1 g
F P
s
P
p
.002 w
.49532 .40332 m .49559 .39406 L .46756 .38923 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .49559 .39406 L .49532 .40332 L closepath p
1 g
F P
s
P
p
.002 w
.43947 .41235 m .44762 .43819 L .47257 .42511 L p
1 g
F P
s
P
p
.002 w
.47257 .42511 m .46709 .40754 L .43947 .41235 L p
1 g
F P
s
P
p
.002 w
.51609 .4563 m .53447 .45583 L .52941 .42775 L p
1 g
F P
s
P
p
.002 w
.53808 .4245 m .52941 .42775 L .53447 .45583 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .52941 .42775 L .53808 .4245 L closepath p
1 g
F P
s
P
p
.002 w
.48571 .47604 m .51165 .4841 L .51609 .4563 L p
1 g
F P
s
P
p
.002 w
.53447 .45583 m .51609 .4563 L .51165 .4841 L p
1 g
F P
s
P
p
.002 w
.47399 .37212 m .46756 .38923 L .49559 .39406 L p
1 g
F P
s
P
p
.002 w
.49559 .39406 m .49887 .38543 L .47399 .37212 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .49887 .38543 L .49559 .39406 L closepath p
1 g
F P
s
P
p
.002 w
.54518 .41861 m .53808 .4245 L .55163 .44947 L p
1 g
F P
s
P
p
.002 w
.53447 .45583 m .55163 .44947 L .53808 .4245 L p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .53808 .4245 L .54518 .41861 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .54518 .41861 L .54993 .41069 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .54993 .41069 L .55181 .4016 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .55181 .4016 L .55059 .39233 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .55059 .39233 L .54642 .3839 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .54642 .3839 L .53973 .37722 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .53973 .37722 L .53126 .37304 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .53126 .37304 L .52194 .37181 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .52194 .37181 L .5128 .37366 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .5128 .37366 L .50482 .37837 L closepath p
1 g
F P
s
P
p
.002 w
.52365 .39976 m .50482 .37837 L .49887 .38543 L closepath p
1 g
F P
s
P
p
.002 w
.44008 .38536 m .43947 .41235 L .46709 .40754 L p
1 g
F P
s
P
p
.002 w
.46709 .40754 m .46756 .38923 L .44008 .38536 L p
1 g
F P
s
P
p
.002 w
.51165 .4841 m .53872 .48349 L .53447 .45583 L p
1 g
F P
s
P
p
.002 w
.55163 .44947 m .53447 .45583 L .53872 .48349 L p
1 g
F P
s
P
p
.002 w
.48571 .35808 m .47399 .37212 L .49887 .38543 L p
1 g
F P
s
P
p
.002 w
.49887 .38543 m .50482 .37837 L .48571 .35808 L p
1 g
F P
s
P
p
.002 w
.55163 .44947 m .56573 .43785 L .54518 .41861 L p
1 g
F P
s
P
p
.002 w
.54993 .41069 m .54518 .41861 L .56573 .43785 L p
1 g
F P
s
P
p
.002 w
.42366 .45123 m .44445 .47978 L .46359 .46018 L p
1 g
F P
s
P
p
.002 w
.46359 .46018 m .44762 .43819 L .42366 .45123 L p
1 g
F P
s
P
p
.002 w
.48571 .47604 m .46359 .46018 L .44445 .47978 L p
1 g
F P
s
P
p
.002 w
.44445 .47978 m .47319 .50039 L .48571 .47604 L p
1 g
F P
s
P
p
.002 w
.51165 .4841 m .48571 .47604 L .47319 .50039 L p
1 g
F P
s
P
p
.002 w
.50151 .34867 m .48571 .35808 L .50482 .37837 L p
1 g
F P
s
P
p
.002 w
.50482 .37837 m .5128 .37366 L .50151 .34867 L p
1 g
F P
s
P
p
.002 w
.44946 .36009 m .44008 .38536 L .46756 .38923 L p
1 g
F P
s
P
p
.002 w
.46756 .38923 m .47399 .37212 L .44946 .36009 L p
1 g
F P
s
P
p
.002 w
.41299 .41766 m .42366 .45123 L .44762 .43819 L p
1 g
F P
s
P
p
.002 w
.44762 .43819 m .43947 .41235 L .41299 .41766 L p
1 g
F P
s
P
p
.002 w
.56573 .43785 m .57521 .42219 L .54993 .41069 L p
1 g
F P
s
P
p
.002 w
.55181 .4016 m .54993 .41069 L .57521 .42219 L p
1 g
F P
s
P
p
.002 w
.47319 .50039 m .50688 .51091 L .51165 .4841 L p
1 g
F P
s
P
p
.002 w
.53872 .48349 m .51165 .4841 L .50688 .51091 L p
1 g
F P
s
P
p
.002 w
.56573 .43785 m .55163 .44947 L .56405 .4742 L p
1 g
F P
s
P
p
.002 w
.53872 .48349 m .56405 .4742 L .55163 .44947 L p
1 g
F P
s
P
p
.002 w
.51967 .34494 m .50151 .34867 L .5128 .37366 L p
1 g
F P
s
P
p
.002 w
.5128 .37366 m .52194 .37181 L .51967 .34494 L p
1 g
F P
s
P
p
.002 w
.57521 .42219 m .57901 .40416 L .55181 .4016 L p
1 g
F P
s
P
p
.002 w
.55059 .39233 m .55181 .4016 L .57901 .40416 L p
1 g
F P
s
P
p
.002 w
.53821 .34735 m .51967 .34494 L .52194 .37181 L p
1 g
F P
s
P
p
.002 w
.52194 .37181 m .53126 .37304 L .53821 .34735 L p
1 g
F P
s
P
p
.002 w
.41367 .38255 m .41299 .41766 L .43947 .41235 L p
1 g
F P
s
P
p
.002 w
.43947 .41235 m .44008 .38536 L .41367 .38255 L p
1 g
F P
s
P
p
.002 w
.57901 .40416 m .57665 .38574 L .55059 .39233 L p
1 g
F P
s
P
p
.002 w
.54642 .3839 m .55059 .39233 L .57665 .38574 L p
1 g
F P
s
P
p
.002 w
.46669 .33929 m .44946 .36009 L .47399 .37212 L p
1 g
F P
s
P
p
.002 w
.47399 .37212 m .48571 .35808 L .46669 .33929 L p
1 g
F P
s
P
p
.002 w
.55507 .35566 m .53821 .34735 L .53126 .37304 L p
1 g
F P
s
P
p
.002 w
.53126 .37304 m .53973 .37722 L .55507 .35566 L p
1 g
F P
s
P
p
.002 w
.50688 .51091 m .54208 .51021 L .53872 .48349 L p
1 g
F P
s
P
p
.002 w
.56405 .4742 m .53872 .48349 L .54208 .51021 L p
1 g
F P
s
P
p
.002 w
.57665 .38574 m .56837 .36895 L .54642 .3839 L p
1 g
F P
s
P
p
.002 w
.53973 .37722 m .54642 .3839 L .56837 .36895 L p
1 g
F P
s
P
p
.002 w
.56405 .4742 m .58492 .45714 L .56573 .43785 L p
1 g
F P
s
P
p
.002 w
.57521 .42219 m .56573 .43785 L .58492 .45714 L p
1 g
F P
s
P
p
.002 w
.56837 .36895 m .55507 .35566 L .53973 .37722 L p
1 g
F P
s
P
p
.002 w
.49 .32528 m .46669 .33929 L .48571 .35808 L p
1 g
F P
s
P
p
.002 w
.48571 .35808 m .50151 .34867 L .49 .32528 L p
1 g
F P
s
P
p
.002 w
.40117 .46398 m .42637 .49849 L .44445 .47978 L p
1 g
F P
s
P
p
.002 w
.44445 .47978 m .42366 .45123 L .40117 .46398 L p
1 g
F P
s
P
p
.002 w
.47319 .50039 m .44445 .47978 L .42637 .49849 L p
1 g
F P
s
P
p
.002 w
.42637 .49849 m .46111 .52342 L .47319 .50039 L p
1 g
F P
s
P
p
.002 w
.50688 .51091 m .47319 .50039 L .46111 .52342 L p
1 g
F P
s
P
p
.002 w
.42575 .3496 m .41367 .38255 L .44008 .38536 L p
1 g
F P
s
P
p
.002 w
.44008 .38536 m .44946 .36009 L .42575 .3496 L p
1 g
F P
s
P
p
.002 w
.58492 .45714 m .59902 .43406 L .57521 .42219 L p
1 g
F P
s
P
p
.002 w
.57901 .40416 m .57521 .42219 L .59902 .43406 L p
1 g
F P
s
P
p
.002 w
.58492 .45714 m .56405 .4742 L .57508 .49824 L p
1 g
F P
s
P
p
.002 w
.54208 .51021 m .57508 .49824 L .56405 .4742 L p
1 g
F P
s
P
p
.002 w
.38817 .42339 m .40117 .46398 L .42366 .45123 L p
1 g
F P
s
P
p
.002 w
.42366 .45123 m .41299 .41766 L .38817 .42339 L p
1 g
F P
s
P
p
.002 w
.46111 .52342 m .50186 .53621 L .50688 .51091 L p
1 g
F P
s
P
p
.002 w
.54208 .51021 m .50688 .51091 L .50186 .53621 L p
1 g
F P
s
P
p
.002 w
.51688 .31969 m .49 .32528 L .50151 .34867 L p
1 g
F P
s
P
p
.002 w
.50151 .34867 m .51967 .34494 L .51688 .31969 L p
1 g
F P
s
P
p
.002 w
.59902 .43406 m .60472 .40742 L .57901 .40416 L p
1 g
F P
s
P
p
.002 w
.57665 .38574 m .57901 .40416 L .60472 .40742 L p
1 g
F P
s
P
p
.002 w
.44812 .32239 m .42575 .3496 L .44946 .36009 L p
1 g
F P
s
P
p
.002 w
.44946 .36009 m .46669 .33929 L .44812 .32239 L p
1 g
F P
s
P
p
.002 w
.54436 .32321 m .51688 .31969 L .51967 .34494 L p
1 g
F P
s
P
p
.002 w
.51967 .34494 m .53821 .34735 L .54436 .32321 L p
1 g
F P
s
P
p
.002 w
.38886 .38087 m .38817 .42339 L .41299 .41766 L p
1 g
F P
s
P
p
.002 w
.41299 .41766 m .41367 .38255 L .38886 .38087 L p
1 g
F P
s
P
p
.002 w
.60472 .40742 m .60131 .38013 L .57665 .38574 L p
1 g
F P
s
P
p
.002 w
.56837 .36895 m .57665 .38574 L .60131 .38013 L p
1 g
F P
s
P
p
.002 w
.57508 .49824 m .60235 .47612 L .58492 .45714 L p
1 g
F P
s
P
p
.002 w
.59902 .43406 m .58492 .45714 L .60235 .47612 L p
1 g
F P
s
P
p
.002 w
.50186 .53621 m .54445 .53546 L .54208 .51021 L p
1 g
F P
s
P
p
.002 w
.57508 .49824 m .54208 .51021 L .54445 .53546 L p
1 g
F P
s
P
p
.002 w
.56936 .3355 m .54436 .32321 L .53821 .34735 L p
1 g
F P
s
P
p
.002 w
.53821 .34735 m .55507 .35566 L .56936 .3355 L p
1 g
F P
s
P
p
.002 w
.60131 .38013 m .58908 .35522 L .56837 .36895 L p
1 g
F P
s
P
p
.002 w
.55507 .35566 m .56837 .36895 L .58908 .35522 L p
1 g
F P
s
P
p
.002 w
.58908 .35522 m .56936 .3355 L .55507 .35566 L p
1 g
F P
s
P
p
.002 w
.47848 .304 m .44812 .32239 L .46669 .33929 L p
1 g
F P
s
P
p
.002 w
.46669 .33929 m .49 .32528 L .47848 .304 L p
1 g
F P
s
P
p
.002 w
.40336 .34088 m .38886 .38087 L .41367 .38255 L p
1 g
F P
s
P
p
.002 w
.41367 .38255 m .42575 .3496 L .40336 .34088 L p
1 g
F P
s
P
p
.002 w
.60235 .47612 m .62085 .4461 L .59902 .43406 L p
1 g
F P
s
P
p
.002 w
.60472 .40742 m .59902 .43406 L .62085 .4461 L p
1 g
F P
s
P
p
.002 w
.38063 .4762 m .40971 .51593 L .42637 .49849 L p
1 g
F P
s
P
p
.002 w
.42637 .49849 m .40117 .46398 L .38063 .4762 L p
1 g
F P
s
P
p
.002 w
.46111 .52342 m .42637 .49849 L .40971 .51593 L p
1 g
F P
s
P
p
.002 w
.40971 .51593 m .44974 .54466 L .46111 .52342 L p
1 g
F P
s
P
p
.002 w
.50186 .53621 m .46111 .52342 L .44974 .54466 L p
1 g
F P
s
P
p
.002 w
.60235 .47612 m .57508 .49824 L .58447 .52109 L p
1 g
F P
s
P
p
.002 w
.54445 .53546 m .58447 .52109 L .57508 .49824 L p
1 g
F P
s
P
p
.002 w
.36555 .42944 m .38063 .4762 L .40117 .46398 L p
1 g
F P
s
P
p
.002 w
.40117 .46398 m .38817 .42339 L .36555 .42944 L p
1 g
F P
s
P
p
.002 w
.51359 .29659 m .47848 .304 L .49 .32528 L p
1 g
F P
s
P
p
.002 w
.49 .32528 m .51688 .31969 L .51359 .29659 L p
1 g
F P
s
P
p
.002 w
.44974 .54466 m .49668 .55945 L .50186 .53621 L p
1 g
F P
s
P
p
.002 w
.54445 .53546 m .50186 .53621 L .49668 .55945 L p
1 g
F P
s
P
p
.002 w
.62085 .4461 m .62841 .41134 L .60472 .40742 L p
1 g
F P
s
P
p
.002 w
.60131 .38013 m .60472 .40742 L .62841 .41134 L p
1 g
F P
s
P
p
.002 w
.43038 .30778 m .40336 .34088 L .42575 .3496 L p
1 g
F P
s
P
p
.002 w
.42575 .3496 m .44812 .32239 L .43038 .30778 L p
1 g
F P
s
P
p
.002 w
.58447 .52109 m .61762 .4944 L .60235 .47612 L p
1 g
F P
s
P
p
.002 w
.62085 .4461 m .60235 .47612 L .61762 .4944 L p
1 g
F P
s
P
p
.002 w
.36621 .3804 m .36555 .42944 L .38817 .42339 L p
1 g
F P
s
P
p
.002 w
.38817 .42339 m .38886 .38087 L .36621 .3804 L p
1 g
F P
s
P
p
.002 w
.54954 .30113 m .51359 .29659 L .51688 .31969 L p
1 g
F P
s
P
p
.002 w
.51688 .31969 m .54436 .32321 L .54954 .30113 L p
1 g
F P
s
P
p
.002 w
.62841 .41134 m .62404 .37564 L .60131 .38013 L p
1 g
F P
s
P
p
.002 w
.58908 .35522 m .60131 .38013 L .62404 .37564 L p
1 g
F P
s
P
p
.002 w
.49668 .55945 m .54578 .5587 L .54445 .53546 L p
1 g
F P
s
P
p
.002 w
.58447 .52109 m .54445 .53546 L .54578 .5587 L p
1 g
F P
s
P
p
.002 w
.58229 .31721 m .54954 .30113 L .54436 .32321 L p
1 g
F P
s
P
p
.002 w
.54436 .32321 m .56936 .3355 L .58229 .31721 L p
1 g
F P
s
P
p
.002 w
.62404 .37564 m .60809 .34303 L .58908 .35522 L p
1 g
F P
s
P
p
.002 w
.56936 .3355 m .58908 .35522 L .60809 .34303 L p
1 g
F P
s
P
p
.002 w
.60809 .34303 m .58229 .31721 L .56936 .3355 L p
1 g
F P
s
P
p
.002 w
.46719 .28533 m .43038 .30778 L .44812 .32239 L p
1 g
F P
s
P
p
.002 w
.44812 .32239 m .47848 .304 L .46719 .28533 L p
1 g
F P
s
P
p
.002 w
.3828 .33421 m .36621 .3804 L .38886 .38087 L p
1 g
F P
s
P
p
.002 w
.38886 .38087 m .40336 .34088 L .3828 .33421 L p
1 g
F P
s
P
p
.002 w
.61762 .4944 m .64019 .45804 L .62085 .4461 L p
1 g
F P
s
P
p
.002 w
.62841 .41134 m .62085 .4461 L .64019 .45804 L p
1 g
F P
s
P
p
.002 w
.61762 .4944 m .58447 .52109 L .59197 .54226 L p
1 g
F P
s
P
p
.002 w
.54578 .5587 m .59197 .54226 L .58447 .52109 L p
1 g
F P
s
P
p
.002 w
.36254 .4876 m .39487 .53169 L .40971 .51593 L p
1 g
F P
s
P
p
.002 w
.40971 .51593 m .38063 .4762 L .36254 .4876 L p
1 g
F P
s
P
p
.002 w
.44974 .54466 m .40971 .51593 L .39487 .53169 L p
1 g
F P
s
P
p
.002 w
.39487 .53169 m .43932 .5636 L .44974 .54466 L p
1 g
F P
s
P
p
.002 w
.49668 .55945 m .44974 .54466 L .43932 .5636 L p
1 g
F P
s
P
p
.002 w
.34569 .43569 m .36254 .4876 L .38063 .4762 L p
1 g
F P
s
P
p
.002 w
.38063 .4762 m .36555 .42944 L .34569 .43569 L p
1 g
F P
s
P
p
.002 w
.50985 .27622 m .46719 .28533 L .47848 .304 L p
1 g
F P
s
P
p
.002 w
.47848 .304 m .51359 .29659 L .50985 .27622 L p
1 g
F P
s
P
p
.002 w
.43932 .5636 m .49143 .58009 L .49668 .55945 L p
1 g
F P
s
P
p
.002 w
.54578 .5587 m .49668 .55945 L .49143 .58009 L p
1 g
F P
s
P
p
.002 w
.64019 .45804 m .64951 .41584 L .62841 .41134 L p
1 g
F P
s
P
p
.002 w
.62404 .37564 m .62841 .41134 L .64951 .41584 L p
1 g
F P
s
P
p
.002 w
.41389 .29588 m .3828 .33421 L .40336 .34088 L p
1 g
F P
s
P
p
.002 w
.40336 .34088 m .43038 .30778 L .41389 .29588 L p
1 g
F P
s
P
p
.002 w
.59197 .54226 m .63033 .51158 L .61762 .4944 L p
1 g
F P
s
P
p
.002 w
.64019 .45804 m .61762 .4944 L .63033 .51158 L p
1 g
F P
s
P
p
.002 w
.34628 .3812 m .34569 .43569 L .36555 .42944 L p
1 g
F P
s
P
p
.002 w
.36555 .42944 m .36621 .3804 L .34628 .3812 L p
1 g
F P
s
P
p
.002 w
.55362 .28169 m .50985 .27622 L .51359 .29659 L p
1 g
F P
s
P
p
.002 w
.51359 .29659 m .54954 .30113 L .55362 .28169 L p
1 g
F P
s
P
p
.002 w
.64951 .41584 m .64429 .37242 L .62404 .37564 L p
1 g
F P
s
P
p
.002 w
.60809 .34303 m .62404 .37564 L .64429 .37242 L p
1 g
F P
s
P
p
.002 w
.49143 .58009 m .54597 .57936 L .54578 .5587 L p
1 g
F P
s
P
p
.002 w
.59197 .54226 m .54578 .5587 L .54597 .57936 L p
1 g
F P
s
P
p
.002 w
.59351 .30124 m .55362 .28169 L .54954 .30113 L p
1 g
F P
s
P
p
.002 w
.54954 .30113 m .58229 .31721 L .59351 .30124 L p
1 g
F P
s
P
p
.002 w
.64429 .37242 m .62492 .3327 L .60809 .34303 L p
1 g
F P
s
P
p
.002 w
.58229 .31721 m .60809 .34303 L .62492 .3327 L p
1 g
F P
s
P
p
.002 w
.62492 .3327 m .59351 .30124 L .58229 .31721 L p
1 g
F P
s
P
p
.002 w
.45638 .2698 m .41389 .29588 L .43038 .30778 L p
1 g
F P
s
P
p
.002 w
.43038 .30778 m .46719 .28533 L .45638 .2698 L p
1 g
F P
s
P
p
.002 w
.36459 .3298 m .34628 .3812 L .36621 .3804 L p
1 g
F P
s
P
p
.002 w
.36621 .3804 m .3828 .33421 L .36459 .3298 L p
1 g
F P
s
P
p
.002 w
.63033 .51158 m .65654 .46966 L .64019 .45804 L p
1 g
F P
s
P
p
.002 w
.64951 .41584 m .64019 .45804 L .65654 .46966 L p
1 g
F P
s
P
p
.002 w
.63033 .51158 m .59197 .54226 L .59735 .56123 L p
1 g
F P
s
P
p
.002 w
.54597 .57936 m .59735 .56123 L .59197 .54226 L p
1 g
F P
s
P
p
.002 w
.34739 .4979 m .38225 .54537 L .39487 .53169 L p
1 g
F P
s
P
p
.002 w
.39487 .53169 m .36254 .4876 L .34739 .4979 L p
1 g
F P
s
P
p
.002 w
.43932 .5636 m .39487 .53169 L .38225 .54537 L p
1 g
F P
s
P
p
.002 w
.38225 .54537 m .43012 .57973 L .43932 .5636 L p
1 g
F P
s
P
p
.002 w
.49143 .58009 m .43932 .5636 L .43012 .57973 L p
1 g
F P
s
P
p
.002 w
.50573 .25916 m .45638 .2698 L .46719 .28533 L p
1 g
F P
s
P
p
.002 w
.46719 .28533 m .50985 .27622 L .50573 .25916 L p
1 g
F P
s
P
p
.002 w
.32916 .44202 m .34739 .4979 L .36254 .4876 L p
1 g
F P
s
P
p
.002 w
.36254 .4876 m .34569 .43569 L .32916 .44202 L p
1 g
F P
s
P
p
.002 w
.43012 .57973 m .48622 .59755 L .49143 .58009 L p
1 g
F P
s
P
p
.002 w
.54597 .57936 m .49143 .58009 L .48622 .59755 L p
1 g
F P
s
P
p
.002 w
.65654 .46966 m .66744 .42088 L .64951 .41584 L p
1 g
F P
s
P
p
.002 w
.64429 .37242 m .64951 .41584 L .66744 .42088 L p
1 g
F P
s
P
p
.002 w
.39906 .28707 m .36459 .3298 L .3828 .33421 L p
1 g
F P
s
P
p
.002 w
.3828 .33421 m .41389 .29588 L .39906 .28707 L p
1 g
F P
s
P
p
.002 w
.59735 .56123 m .64009 .52723 L .63033 .51158 L p
1 g
F P
s
P
p
.002 w
.65654 .46966 m .63033 .51158 L .64009 .52723 L p
1 g
F P
s
P
p
.002 w
.32967 .38332 m .32916 .44202 L .34569 .43569 L p
1 g
F P
s
P
p
.002 w
.34569 .43569 m .34628 .3812 L .32967 .38332 L p
1 g
F P
s
P
p
.002 w
.55645 .26543 m .50573 .25916 L .50985 .27622 L p
1 g
F P
s
P
p
.002 w
.50985 .27622 m .55362 .28169 L .55645 .26543 L p
1 g
F P
s
P
p
.002 w
.66744 .42088 m .66149 .3706 L .64429 .37242 L p
1 g
F P
s
P
p
.002 w
.62492 .3327 m .64429 .37242 L .66149 .3706 L p
1 g
F P
s
P
p
.002 w
.48622 .59755 m .54497 .59687 L .54597 .57936 L p
1 g
F P
s
P
p
.002 w
.59735 .56123 m .54597 .57936 L .54497 .59687 L p
1 g
F P
s
P
p
.002 w
.6027 .28807 m .55645 .26543 L .55362 .28169 L p
1 g
F P
s
P
p
.002 w
.55362 .28169 m .59351 .30124 L .6027 .28807 L p
1 g
F P
s
P
p
.002 w
.66149 .3706 m .6391 .32455 L .62492 .3327 L p
1 g
F P
s
P
p
.002 w
.59351 .30124 m .62492 .3327 L .6391 .32455 L p
1 g
F P
s
P
p
.002 w
.6391 .32455 m .6027 .28807 L .59351 .30124 L p
1 g
F P
s
P
p
.002 w
.44631 .25793 m .39906 .28707 L .41389 .29588 L p
1 g
F P
s
P
p
.002 w
.41389 .29588 m .45638 .2698 L .44631 .25793 L p
1 g
F P
s
P
p
.002 w
.64009 .52723 m .66937 .48066 L .65654 .46966 L p
1 g
F P
s
P
p
.002 w
.66744 .42088 m .65654 .46966 L .66937 .48066 L p
1 g
F P
s
P
p
.002 w
.34928 .32788 m .32967 .38332 L .34628 .3812 L p
1 g
F P
s
P
p
.002 w
.34628 .3812 m .36459 .3298 L .34928 .32788 L p
1 g
F P
s
P
p
.002 w
.54497 .59687 m .60037 .57745 L .59735 .56123 L p
1 g
F P
s
P
p
.002 w
.64009 .52723 m .59735 .56123 L .60037 .57745 L p
1 g
F P
s
P
p
.002 w
.33569 .50682 m .37225 .55653 L .38225 .54537 L p
1 g
F P
s
P
p
.002 w
.38225 .54537 m .34739 .4979 L .33569 .50682 L p
1 g
F P
s
P
p
.002 w
.43012 .57973 m .38225 .54537 L .37225 .55653 L p
1 g
F P
s
P
p
.002 w
.37225 .55653 m .42241 .59255 L .43012 .57973 L p
1 g
F P
s
P
p
.002 w
.48622 .59755 m .43012 .57973 L .42241 .59255 L p
1 g
F P
s
P
p
.002 w
.50131 .24598 m .44631 .25793 L .45638 .2698 L p
1 g
F P
s
P
p
.002 w
.45638 .2698 m .50573 .25916 L .50131 .24598 L p
1 g
F P
s
P
p
.002 w
.31651 .44829 m .33569 .50682 L .34739 .4979 L p
1 g
F P
s
P
p
.002 w
.34739 .4979 m .32916 .44202 L .31651 .44829 L p
1 g
F P
s
P
p
.002 w
.42241 .59255 m .48119 .61127 L .48622 .59755 L p
1 g
F P
s
P
p
.002 w
.54497 .59687 m .48622 .59755 L .48119 .61127 L p
1 g
F P
s
P
p
.002 w
.66937 .48066 m .68162 .42636 L .66744 .42088 L p
1 g
F P
s
P
p
.002 w
.66149 .3706 m .66744 .42088 L .68162 .42636 L p
1 g
F P
s
P
p
.002 w
.38635 .28173 m .34928 .32788 L .36459 .3298 L p
1 g
F P
s
P
p
.002 w
.36459 .3298 m .39906 .28707 L .38635 .28173 L p
1 g
F P
s
P
p
.002 w
.60037 .57745 m .64652 .54091 L .64009 .52723 L p
1 g
F P
s
P
p
.002 w
.66937 .48066 m .64009 .52723 L .64652 .54091 L p
1 g
F P
s
P
p
.002 w
.31695 .38678 m .31651 .44829 L .32916 .44202 L p
1 g
F P
s
P
p
.002 w
.32916 .44202 m .32967 .38332 L .31695 .38678 L p
1 g
F P
s
P
p
.002 w
.55789 .25292 m .50131 .24598 L .50573 .25916 L p
1 g
F P
s
P
p
.002 w
.50573 .25916 m .55645 .26543 L .55789 .25292 L p
1 g
F P
s
P
p
.002 w
.68162 .42636 m .67507 .3703 L .66149 .3706 L p
1 g
F P
s
P
p
.002 w
.6391 .32455 m .66149 .3706 L .67507 .3703 L p
1 g
F P
s
P
p
.002 w
.48119 .61127 m .54275 .61064 L .54497 .59687 L p
1 g
F P
s
P
p
.002 w
.60037 .57745 m .54497 .59687 L .54275 .61064 L p
1 g
F P
s
P
p
.002 w
.60951 .27817 m .55789 .25292 L .55645 .26543 L p
1 g
F P
s
P
p
.002 w
.55645 .26543 m .6027 .28807 L .60951 .27817 L p
1 g
F P
s
P
p
.002 w
.67507 .3703 m .65014 .31889 L .6391 .32455 L p
1 g
F P
s
P
p
.002 w
.6027 .28807 m .6391 .32455 L .65014 .31889 L p
1 g
F P
s
P
p
.002 w
.43728 .25021 m .38635 .28173 L .39906 .28707 L p
1 g
F P
s
P
p
.002 w
.39906 .28707 m .44631 .25793 L .43728 .25021 L p
1 g
F P
s
P
p
.002 w
.65014 .31889 m .60951 .27817 L .6027 .28807 L p
1 g
F P
s
P
p
.002 w
.64652 .54091 m .67819 .49075 L .66937 .48066 L p
1 g
F P
s
P
p
.002 w
.68162 .42636 m .66937 .48066 L .67819 .49075 L p
1 g
F P
s
P
p
.002 w
.3374 .32865 m .31695 .38678 L .32967 .38332 L p
1 g
F P
s
P
p
.002 w
.32967 .38332 m .34928 .32788 L .3374 .32865 L p
1 g
F P
s
P
p
.002 w
.54275 .61064 m .60083 .59038 L .60037 .57745 L p
1 g
F P
s
P
p
.002 w
.64652 .54091 m .60037 .57745 L .60083 .59038 L p
1 g
F P
s
P
p
.002 w
.32792 .51405 m .36526 .56478 L .37225 .55653 L p
1 g
F P
s
P
p
.002 w
.37225 .55653 m .33569 .50682 L .32792 .51405 L p
1 g
F P
s
P
p
.002 w
.42241 .59255 m .37225 .55653 L .36526 .56478 L p
1 g
F P
s
P
p
.002 w
.36526 .56478 m .41647 .60155 L .42241 .59255 L p
1 g
F P
s
P
p
.002 w
.48119 .61127 m .42241 .59255 L .41647 .60155 L p
1 g
F P
s
P
p
.002 w
.49666 .23724 m .43728 .25021 L .44631 .25793 L p
1 g
F P
s
P
p
.002 w
.44631 .25793 m .50131 .24598 L .49666 .23724 L p
1 g
F P
s
P
p
.002 w
.3083 .45434 m .32792 .51405 L .33569 .50682 L p
1 g
F P
s
P
p
.002 w
.33569 .50682 m .31651 .44829 L .3083 .45434 L p
1 g
F P
s
P
p
.002 w
.67819 .49075 m .6915 .43217 L .68162 .42636 L p
1 g
F P
s
P
p
.002 w
.67507 .3703 m .68162 .42636 L .6915 .43217 L p
1 g
F P
s
P
p
.002 w
.41647 .60155 m .47645 .62069 L .48119 .61127 L p
1 g
F P
s
P
p
.002 w
.54275 .61064 m .48119 .61127 L .47645 .62069 L p
1 g
F P
s
P
p
.002 w
.37621 .28022 m .3374 .32865 L .34928 .32788 L p
1 g
F P
s
P
p
.002 w
.34928 .32788 m .38635 .28173 L .37621 .28022 L p
1 g
F P
s
P
p
.002 w
.60083 .59038 m .64925 .55216 L .64652 .54091 L p
1 g
F P
s
P
p
.002 w
.67819 .49075 m .64652 .54091 L .64925 .55216 L p
1 g
F P
s
P
p
.002 w
.30869 .39158 m .3083 .45434 L .31651 .44829 L p
1 g
F P
s
P
p
.002 w
.31651 .44829 m .31695 .38678 L .30869 .39158 L p
1 g
F P
s
P
p
.002 w
.55782 .2447 m .49666 .23724 L .50131 .24598 L p
1 g
F P
s
P
p
.002 w
.50131 .24598 m .55789 .25292 L .55782 .2447 L p
1 g
F P
s
P
p
.002 w
.47645 .62069 m .53928 .6201 L .54275 .61064 L p
1 g
F P
s
P
p
.002 w
.60083 .59038 m .54275 .61064 L .53928 .6201 L p
1 g
F P
s
P
p
.002 w
.6915 .43217 m .68448 .37161 L .67507 .3703 L p
1 g
F P
s
P
p
.002 w
.65014 .31889 m .67507 .3703 L .68448 .37161 L p
1 g
F P
s
P
p
.002 w
.61364 .27199 m .55782 .2447 L .55789 .25292 L p
1 g
F P
s
P
p
.002 w
.55789 .25292 m .60951 .27817 L .61364 .27199 L p
1 g
F P
s
P
p
.002 w
.68448 .37161 m .65756 .31603 L .65014 .31889 L p
1 g
F P
s
P
p
.002 w
.60951 .27817 m .65014 .31889 L .65756 .31603 L p
1 g
F P
s
P
p
.002 w
.42959 .2471 m .37621 .28022 L .38635 .28173 L p
1 g
F P
s
P
p
.002 w
.38635 .28173 m .43728 .25021 L .42959 .2471 L p
1 g
F P
s
P
p
.002 w
.65756 .31603 m .61364 .27199 L .60951 .27817 L p
1 g
F P
s
P
p
.002 w
.64925 .55216 m .68253 .49962 L .67819 .49075 L p
1 g
F P
s
P
p
.002 w
.6915 .43217 m .67819 .49075 L .68253 .49962 L p
1 g
F P
s
P
p
.002 w
.3295 .33225 m .30869 .39158 L .31695 .38678 L p
1 g
F P
s
P
p
.002 w
.31695 .38678 m .3374 .32865 L .3295 .33225 L p
1 g
F P
s
P
p
.002 w
.53928 .6201 m .59856 .59949 L .60083 .59038 L p
1 g
F P
s
P
p
.002 w
.64925 .55216 m .60083 .59038 L .59856 .59949 L p
1 g
F P
s
P
p
.002 w
.32455 .5193 m .36167 .56971 L .36526 .56478 L p
1 g
F P
s
P
p
.002 w
.36526 .56478 m .32792 .51405 L .32455 .5193 L p
1 g
F P
s
P
p
.002 w
.41647 .60155 m .36526 .56478 L .36167 .56971 L p
1 g
F P
s
P
p
.002 w
.36167 .56971 m .41255 .60625 L .41647 .60155 L p
1 g
F P
s
P
p
.002 w
.47645 .62069 m .41647 .60155 L .41255 .60625 L p
1 g
F P
s
P
p
.002 w
.49191 .23346 m .42959 .2471 L .43728 .25021 L p
1 g
F P
s
P
p
.002 w
.43728 .25021 m .49666 .23724 L .49191 .23346 L p
1 g
F P
s
P
p
.002 w
.30503 .45999 m .32455 .5193 L .32792 .51405 L p
1 g
F P
s
P
p
.002 w
.32792 .51405 m .3083 .45434 L .30503 .45999 L p
1 g
F P
s
P
p
.002 w
.68253 .49962 m .69654 .43818 L .6915 .43217 L p
1 g
F P
s
P
p
.002 w
.68448 .37161 m .6915 .43217 L .69654 .43818 L p
1 g
F P
s
P
p
.002 w
.41255 .60625 m .47216 .62529 L .47645 .62069 L p
1 g
F P
s
P
p
.002 w
.53928 .6201 m .47645 .62069 L .47216 .62529 L p
1 g
F P
s
P
p
.002 w
.36906 .28281 m .3295 .33225 L .3374 .32865 L p
1 g
F P
s
P
p
.002 w
.3374 .32865 m .37621 .28022 L .36906 .28281 L p
1 g
F P
s
P
p
.002 w
.59856 .59949 m .64799 .56054 L .64925 .55216 L p
1 g
F P
s
P
p
.002 w
.68253 .49962 m .64925 .55216 L .64799 .56054 L p
1 g
F P
s
P
p
.002 w
.30538 .39766 m .30503 .45999 L .3083 .45434 L p
1 g
F P
s
P
p
.002 w
.3083 .45434 m .30869 .39158 L .30538 .39766 L p
1 g
F P
s
P
p
.002 w
.55614 .24128 m .49191 .23346 L .49666 .23724 L p
1 g
F P
s
P
p
.002 w
.49666 .23724 m .55782 .2447 L .55614 .24128 L p
1 g
F P
s
P
p
.002 w
.47216 .62529 m .53457 .62473 L .53928 .6201 L p
1 g
F P
s
P
p
.002 w
.59856 .59949 m .53928 .6201 L .53457 .62473 L p
1 g
F P
s
P
p
.002 w
.69654 .43818 m .6892 .3746 L .68448 .37161 L p
1 g
F P
s
P
p
.002 w
.65756 .31603 m .68448 .37161 L .6892 .3746 L p
1 g
F P
s
P
p
.002 w
.61479 .26995 m .55614 .24128 L .55782 .2447 L p
1 g
F P
s
P
p
.002 w
.55782 .2447 m .61364 .27199 L .61479 .26995 L p
1 g
F P
s
P
p
.002 w
.42354 .249 m .36906 .28281 L .37621 .28022 L p
1 g
F P
s
P
p
.002 w
.37621 .28022 m .42959 .2471 L .42354 .249 L p
1 g
F P
s
P
p
.002 w
.6892 .3746 m .66094 .31622 L .65756 .31603 L p
1 g
F P
s
P
p
.002 w
.61364 .27199 m .65756 .31603 L .66094 .31622 L p
1 g
F P
s
P
p
.002 w
.66094 .31622 m .61479 .26995 L .61364 .27199 L p
1 g
F P
s
P
p
.002 w
.64799 .56054 m .68197 .50695 L .68253 .49962 L p
1 g
F P
s
P
p
.002 w
.69654 .43818 m .68253 .49962 L .68197 .50695 L p
1 g
F P
s
P
p
.002 w
.32603 .33876 m .30538 .39766 L .30869 .39158 L p
1 g
F P
s
P
p
.002 w
.30869 .39158 m .3295 .33225 L .32603 .33876 L p
1 g
F P
s
P
p
.002 w
.64799 .56054 m .59856 .59949 L .59344 .60429 L p
1 g
F P
s
P
p
.002 w
.53457 .62473 m .59344 .60429 L .59856 .59949 L p
1 g
F P
s
P
p
.004 w
.49997 .71917 m
.49998 .63724 L
s
P
p
.002 w
.32594 .5223 m .36178 .57096 L .36167 .56971 L p
1 g
F P
s
P
p
.002 w
.36167 .56971 m .32455 .5193 L .32594 .5223 L p
1 g
F P
s
P
p
.002 w
.41255 .60625 m .36167 .56971 L .36178 .57096 L p
1 g
F P
s
P
p
.002 w
.36178 .57096 m .41092 .60625 L .41255 .60625 L p
1 g
F P
s
P
p
.002 w
.47216 .62529 m .41255 .60625 L .41092 .60625 L p
1 g
F P
s
P
p
.002 w
.48717 .23507 m .42354 .249 L .42959 .2471 L p
1 g
F P
s
P
p
.002 w
.42959 .2471 m .49191 .23346 L .48717 .23507 L p
1 g
F P
s
P
p
.002 w
.30711 .46505 m .32594 .5223 L .32455 .5193 L p
1 g
F P
s
P
p
.002 w
.32455 .5193 m .30503 .45999 L .30711 .46505 L p
1 g
F P
s
P
p
.002 w
.68197 .50695 m .69628 .44424 L .69654 .43818 L p
1 g
F P
s
P
p
.002 w
.6892 .3746 m .69654 .43818 L .69628 .44424 L p
1 g
F P
s
P
p
.002 w
.41092 .60625 m .46846 .62463 L .47216 .62529 L p
1 g
F P
s
P
p
.002 w
.53457 .62473 m .47216 .62529 L .46846 .62463 L p
1 g
F P
s
P
p
.002 w
.36531 .2897 m .32603 .33876 L .3295 .33225 L p
1 g
F P
s
P
p
.002 w
.3295 .33225 m .36906 .28281 L .36531 .2897 L p
1 g
F P
s
P
p
.002 w
.59344 .60429 m .64252 .56563 L .64799 .56054 L p
1 g
F P
s
P
p
.002 w
.68197 .50695 m .64799 .56054 L .64252 .56563 L p
1 g
F P
s
P
p
.002 w
.30747 .40494 m .30711 .46505 L .30503 .45999 L p
1 g
F P
s
P
p
.002 w
.30503 .45999 m .30538 .39766 L .30747 .40494 L p
1 g
F P
s
P
p
.002 w
.55279 .24307 m .48717 .23507 L .49191 .23346 L p
1 g
F P
s
P
p
.002 w
.49191 .23346 m .55614 .24128 L .55279 .24307 L p
1 g
F P
s
P
p
.002 w
.46846 .62463 m .52868 .62409 L .53457 .62473 L p
1 g
F P
s
P
p
.002 w
.59344 .60429 m .53457 .62473 L .52868 .62409 L p
1 g
F P
s
P
p
.002 w
.69628 .44424 m .68879 .37931 L .6892 .3746 L p
1 g
F P
s
P
p
.002 w
.66094 .31622 m .6892 .3746 L .68879 .37931 L p
1 g
F P
s
P
p
.002 w
.41941 .25617 m .36531 .2897 L .36906 .28281 L p
1 g
F P
s
P
p
.002 w
.36906 .28281 m .42354 .249 L .41941 .25617 L p
1 g
F P
s
P
p
.002 w
.61273 .27238 m .55279 .24307 L .55614 .24128 L p
1 g
F P
s
P
p
.002 w
.55614 .24128 m .61479 .26995 L .61273 .27238 L p
1 g
F P
s
P
p
.002 w
.68879 .37931 m .6599 .31967 L .66094 .31622 L p
1 g
F P
s
P
p
.002 w
.61479 .26995 m .66094 .31622 L .6599 .31967 L p
1 g
F P
s
P
p
.002 w
.6599 .31967 m .61273 .27238 L .61479 .26995 L p
1 g
F P
s
P
p
.002 w
.64252 .56563 m .67623 .51243 L .68197 .50695 L p
1 g
F P
s
P
p
.002 w
.69628 .44424 m .68197 .50695 L .67623 .51243 L p
1 g
F P
s
P
p
.002 w
.32741 .34819 m .30747 .40494 L .30538 .39766 L p
1 g
F P
s
P
p
.002 w
.30538 .39766 m .32603 .33876 L .32741 .34819 L p
1 g
F P
s
P
p
.002 w
.64252 .56563 m .59344 .60429 L .58544 .60435 L p
1 g
F P
s
P
p
.002 w
.52868 .62409 m .58544 .60435 L .59344 .60429 L p
1 g
F P
s
P
p
.002 w
.33239 .52279 m .36585 .56825 L .36178 .57096 L p
1 g
F P
s
P
p
.002 w
.36178 .57096 m .32594 .5223 L .33239 .52279 L p
1 g
F P
s
P
p
.002 w
.41092 .60625 m .36178 .57096 L .36585 .56825 L p
1 g
F P
s
P
p
.002 w
.36585 .56825 m .41175 .60121 L .41092 .60625 L p
1 g
F P
s
P
p
.002 w
.46846 .62463 m .41092 .60625 L .41175 .60121 L p
1 g
F P
s
P
p
.002 w
.4826 .24238 m .41941 .25617 L .42354 .249 L p
1 g
F P
s
P
p
.002 w
.42354 .249 m .48717 .23507 L .4826 .24238 L p
1 g
F P
s
P
p
.002 w
.31483 .46935 m .33239 .52279 L .32594 .5223 L p
1 g
F P
s
P
p
.002 w
.32594 .5223 m .30711 .46505 L .31483 .46935 L p
1 g
F P
s
P
p
.002 w
.67623 .51243 m .6904 .45017 L .69628 .44424 L p
1 g
F P
s
P
p
.002 w
.68879 .37931 m .69628 .44424 L .6904 .45017 L p
1 g
F P
s
P
p
.002 w
.3653 .30096 m .32741 .34819 L .32603 .33876 L p
1 g
F P
s
P
p
.002 w
.32603 .33876 m .36531 .2897 L .3653 .30096 L p
1 g
F P
s
P
p
.002 w
.41175 .60121 m .4655 .61837 L .46846 .62463 L p
1 g
F P
s
P
p
.002 w
.52868 .62409 m .46846 .62463 L .4655 .61837 L p
1 g
F P
s
P
p
.002 w
.58544 .60435 m .63271 .56706 L .64252 .56563 L p
1 g
F P
s
P
p
.002 w
.67623 .51243 m .64252 .56563 L .63271 .56706 L p
1 g
F P
s
P
p
.002 w
.31522 .41328 m .31483 .46935 L .30711 .46505 L p
1 g
F P
s
P
p
.002 w
.30711 .46505 m .30747 .40494 L .31522 .41328 L p
1 g
F P
s
P
p
.002 w
.54777 .25037 m .4826 .24238 L .48717 .23507 L p
1 g
F P
s
P
p
.002 w
.48717 .23507 m .55279 .24307 L .54777 .25037 L p
1 g
F P
s
P
p
.002 w
.4655 .61837 m .5217 .61783 L .52868 .62409 L p
1 g
F P
s
P
p
.004 w
.49998 .63724 m
.49998 .62338 L
s
P
p
.002 w
.58544 .60435 m .52868 .62409 L .5217 .61783 L p
1 g
F P
s
P
p
.002 w
.6904 .45017 m .6829 .3857 L .68879 .37931 L p
1 g
F P
s
P
p
.002 w
.6599 .31967 m .68879 .37931 L .6829 .3857 L p
1 g
F P
s
P
p
.002 w
.41745 .26873 m .3653 .30096 L .36531 .2897 L p
1 g
F P
s
P
p
.002 w
.36531 .2897 m .41941 .25617 L .41745 .26873 L p
1 g
F P
s
P
p
.002 w
.60731 .2795 m .54777 .25037 L .55279 .24307 L p
1 g
F P
s
P
p
.002 w
.55279 .24307 m .61273 .27238 L .60731 .2795 L p
1 g
F P
s
P
p
.002 w
.6829 .3857 m .65418 .32647 L .6599 .31967 L p
1 g
F P
s
P
p
.002 w
.61273 .27238 m .6599 .31967 L .65418 .32647 L p
1 g
F P
s
P
p
.002 w
.63271 .56706 m .66513 .51577 L .67623 .51243 L p
1 g
F P
s
P
p
.002 w
.6904 .45017 m .67623 .51243 L .66513 .51577 L p
1 g
F P
s
P
p
.002 w
.33388 .36041 m .31522 .41328 L .30747 .40494 L p
1 g
F P
s
P
p
.002 w
.30747 .40494 m .32741 .34819 L .33388 .36041 L p
1 g
F P
s
P
p
.002 w
.65418 .32647 m .60731 .2795 L .61273 .27238 L p
1 g
F P
s
P
p
.002 w
.5217 .61783 m .57462 .59937 L .58544 .60435 L p
1 g
F P
s
P
p
.002 w
.63271 .56706 m .58544 .60435 L .57462 .59937 L p
1 g
F P
s
P
p
.002 w
.34401 .52061 m .37401 .5614 L .36585 .56825 L p
1 g
F P
s
P
p
.002 w
.36585 .56825 m .33239 .52279 L .34401 .52061 L p
1 g
F P
s
P
p
.002 w
.41175 .60121 m .36585 .56825 L .37401 .5614 L p
1 g
F P
s
P
p
.002 w
.37401 .5614 m .4152 .59098 L .41175 .60121 L p
1 g
F P
s
P
p
.002 w
.4655 .61837 m .41175 .60121 L .4152 .59098 L p
1 g
F P
s
P
p
.002 w
.47835 .25553 m .41745 .26873 L .41941 .25617 L p
1 g
F P
s
P
p
.002 w
.41941 .25617 m .4826 .24238 L .47835 .25553 L p
1 g
F P
s
P
p
.002 w
.66513 .51577 m .67869 .45577 L .6904 .45017 L p
1 g
F P
s
P
p
.002 w
.6829 .3857 m .6904 .45017 L .67869 .45577 L p
1 g
F P
s
P
p
.002 w
.32832 .47268 m .34401 .52061 L .33239 .52279 L p
1 g
F P
s
P
p
.002 w
.33239 .52279 m .31483 .46935 L .32832 .47268 L p
1 g
F P
s
P
p
.002 w
.36926 .3165 m .33388 .36041 L .32741 .34819 L p
1 g
F P
s
P
p
.002 w
.32741 .34819 m .3653 .30096 L .36926 .3165 L p
1 g
F P
s
P
p
.002 w
.4152 .59098 m .46342 .60634 L .4655 .61837 L p
1 g
F P
s
P
p
.002 w
.5217 .61783 m .4655 .61837 L .46342 .60634 L p
1 g
F P
s
P
p
.002 w
.57462 .59937 m .61861 .56455 L .63271 .56706 L p
1 g
F P
s
P
p
.002 w
.66513 .51577 m .63271 .56706 L .61861 .56455 L p
1 g
F P
s
P
p
.002 w
.32876 .42247 m .32832 .47268 L .31483 .46935 L p
1 g
F P
s
P
p
.002 w
.31483 .46935 m .31522 .41328 L .32876 .42247 L p
1 g
F P
s
P
p
.002 w
.54113 .26329 m .47835 .25553 L .4826 .24238 L p
1 g
F P
s
P
p
.002 w
.4826 .24238 m .54777 .25037 L .54113 .26329 L p
1 g
F P
s
P
p
.002 w
.46342 .60634 m .5138 .6058 L .5217 .61783 L p
1 g
F P
s
P
p
.004 w
.49998 .60595 m
.5 .43051 L
s
P
p
.004 w
.49998 .61631 m
.49998 .61489 L
s
P
p
.004 w
.49998 .62338 m
.49998 .61631 L
s
P
p
.002 w
.57462 .59937 m .5217 .61783 L .5138 .6058 L p
1 g
F P
s
P
p
.002 w
.67869 .45577 m .67139 .39368 L .6829 .3857 L p
1 g
F P
s
P
p
.002 w
.65418 .32647 m .6829 .3857 L .67139 .39368 L p
1 g
F P
s
P
p
.002 w
.41788 .28661 m .36926 .3165 L .3653 .30096 L p
1 g
F P
s
P
p
.002 w
.3653 .30096 m .41745 .26873 L .41788 .28661 L p
1 g
F P
s
P
p
.002 w
.59849 .29139 m .54113 .26329 L .54777 .25037 L p
1 g
F P
s
P
p
.002 w
.54777 .25037 m .60731 .2795 L .59849 .29139 L p
1 g
F P
s
P
p
.002 w
.67139 .39368 m .64366 .33664 L .65418 .32647 L p
1 g
F P
s
P
p
.002 w
.60731 .2795 m .65418 .32647 L .64366 .33664 L p
1 g
F P
s
P
p
.002 w
.61861 .56455 m .6487 .51672 L .66513 .51577 L p
1 g
F P
s
P
p
.002 w
.67869 .45577 m .66513 .51577 L .6487 .51672 L p
1 g
F P
s
P
p
.002 w
.34556 .37521 m .32876 .42247 L .31522 .41328 L p
1 g
F P
s
P
p
.002 w
.31522 .41328 m .33388 .36041 L .34556 .37521 L p
1 g
F P
s
P
p
.002 w
.64366 .33664 m .59849 .29139 L .60731 .2795 L p
1 g
F P
s
P
p
.002 w
.61861 .56455 m .57462 .59937 L .56115 .58918 L p
1 g
F P
s
P
p
.002 w
.5138 .6058 m .56115 .58918 L .57462 .59937 L p
1 g
F P
s
P
p
.002 w
.36075 .51565 m .38626 .55038 L .37401 .5614 L p
1 g
F P
s
P
p
.002 w
.37401 .5614 m .34401 .52061 L .36075 .51565 L p
1 g
F P
s
P
p
.002 w
.4152 .59098 m .37401 .5614 L .38626 .55038 L p
1 g
F P
s
P
p
.002 w
.47457 .27444 m .41788 .28661 L .41745 .26873 L p
1 g
F P
s
P
p
.002 w
.41745 .26873 m .47835 .25553 L .47457 .27444 L p
1 g
F P
s
P
p
.002 w
.38626 .55038 m .42132 .57556 L .4152 .59098 L p
1 g
F P
s
P
p
.002 w
.46342 .60634 m .4152 .59098 L .42132 .57556 L p
1 g
F P
s
P
p
.002 w
.6487 .51672 m .6612 .46085 L .67869 .45577 L p
1 g
F P
s
P
p
.002 w
.67139 .39368 m .67869 .45577 L .6612 .46085 L p
1 g
F P
s
P
p
.002 w
.37729 .33605 m .34556 .37521 L .33388 .36041 L p
1 g
F P
s
P
p
.002 w
.33388 .36041 m .36926 .3165 L .37729 .33605 L p
1 g
F P
s
P
p
.002 w
.34748 .47488 m .36075 .51565 L .34401 .52061 L p
1 g
F P
s
P
p
.002 w
.34401 .52061 m .32832 .47268 L .34748 .47488 L p
1 g
F P
s
P
p
.002 w
.42132 .57556 m .46235 .58858 L .46342 .60634 L p
1 g
F P
s
P
p
.002 w
.5138 .6058 m .46342 .60634 L .46235 .58858 L p
1 g
F P
s
P
p
.002 w
.56115 .58918 m .60042 .55794 L .61861 .56455 L p
1 g
F P
s
P
p
.002 w
.6487 .51672 m .61861 .56455 L .60042 .55794 L p
1 g
F P
s
P
p
.002 w
.34795 .43224 m .34748 .47488 L .32832 .47268 L p
1 g
F P
s
P
p
.002 w
.32832 .47268 m .32876 .42247 L .34795 .43224 L p
1 g
F P
s
P
p
.002 w
.53299 .28175 m .47457 .27444 L .47835 .25553 L p
1 g
F P
s
P
p
.002 w
.47835 .25553 m .54113 .26329 L .53299 .28175 L p
1 g
F P
s
P
p
.002 w
.46235 .58858 m .50518 .58805 L .5138 .6058 L p
1 g
F P
s
P
p
.002 w
.56115 .58918 m .5138 .6058 L .50518 .58805 L p
1 g
F P
s
P
p
.002 w
.6612 .46085 m .65429 .40308 L .67139 .39368 L p
1 g
F P
s
P
p
.002 w
.64366 .33664 m .67139 .39368 L .65429 .40308 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.4208 .30948 m .37729 .33605 L .36926 .3165 L p
1 g
F P
s
P
p
.002 w
.36926 .3165 m .41788 .28661 L .4208 .30948 L p
1 g
F P
s
P
p
.002 w
.58636 .30793 m .53299 .28175 L .54113 .26329 L p
1 g
F P
s
P
p
.002 w
.54113 .26329 m .59849 .29139 L .58636 .30793 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.60042 .55794 m .62719 .51512 L .6487 .51672 L p
1 g
F P
s
P
p
.002 w
.6612 .46085 m .6487 .51672 L .62719 .51512 L p
1 g
F P
s
P
p
.002 w
.65429 .40308 m .62842 .35002 L .64366 .33664 L p
1 g
F P
s
P
p
.002 w
.59849 .29139 m .64366 .33664 L .62842 .35002 L p
1 g
F P
s
P
p
.002 w
.36233 .3922 m .34795 .43224 L .32876 .42247 L p
1 g
F P
s
P
p
.002 w
.32876 .42247 m .34556 .37521 L .36233 .3922 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.62842 .35002 m .58636 .30793 L .59849 .29139 L p
1 g
F P
s
P
p
.002 w
.60042 .55794 m .56115 .58918 L .54534 .57384 L p
1 g
F P
s
P
p
.002 w
.50518 .58805 m .54534 .57384 L .56115 .58918 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.47144 .29875 m .4208 .30948 L .41788 .28661 L p
1 g
F P
s
P
p
.002 w
.41788 .28661 m .47457 .27444 L .47144 .29875 L p
1 g
F P
s
P
p
.002 w
.38232 .50794 m .4024 .53533 L .38626 .55038 L p
1 g
F P
s
P
p
.002 w
.38626 .55038 m .36075 .51565 L .38232 .50794 L p
1 g
F P
s
P
p
.002 w
.42132 .57556 m .38626 .55038 L .4024 .53533 L p
1 g
F P
s
P
p
.002 w
.4024 .53533 m .43004 .55517 L .42132 .57556 L p
1 g
F P
s
P
p
.002 w
.46235 .58858 m .42132 .57556 L .43004 .55517 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.38934 .35913 m .36233 .3922 L .34556 .37521 L p
1 g
F P
s
P
p
.002 w
.34556 .37521 m .37729 .33605 L .38934 .35913 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62719 .51512 m .6382 .46519 L .6612 .46085 L p
1 g
F P
s
P
p
.002 w
.65429 .40308 m .6612 .46085 L .6382 .46519 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.37194 .47581 m .38232 .50794 L .36075 .51565 L p
1 g
F P
s
P
p
.002 w
.36075 .51565 m .34748 .47488 L .37194 .47581 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46235 .58858 m .44721 .56059 L .45079 .56308 L 1 g
F
P
p
.002 w
.46238 .57112 m .46237 .57601 L p
.45079 .56308 L 1 g
F P
s
P
p
.002 w
.46237 .57601 m .46235 .58858 L p
.45079 .56308 L 1 g
F P
s
P
p
.002 w
.43004 .55517 m .44721 .56059 L p
.46235 .58858 L 1 g
F P
s
P
p
.002 w
.45079 .56308 m .45146 .56129 L p
.44478 .55549 L 1 g
F P
s
P
p
.002 w
.43004 .55517 m .43543 .54314 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.4491 .56119 m .44277 .55919 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.44277 .55919 m .43004 .55517 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.43846 .54714 m .43925 .54566 L p
.43532 .53788 L 1 g
F P
s
P
p
.43004 .55517 m .43065 .52273 L .4325 .52874 L 1 g
F
P
p
.002 w
.43632 .54115 m .43177 .55129 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.43177 .55129 m .43004 .55517 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.4325 .52874 m .43346 .52734 L p
.43315 .51845 L 1 g
F P
s
P
p
.002 w
.42206 .51657 m .43437 .50462 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43265 .52417 m .42839 .52111 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.42839 .52111 m .42206 .51657 L p
.43395 .50933 L 1 g
F P
s
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43857 .49957 L 1 g
F P
s
P
p
.002 w
.4377 .50138 m .42206 .51657 L p
.44234 .49161 L 1 g
F P
s
P
p
.44234 .49161 m .44239 .49155 L .44238 .49157 L 1 g
F
P
p
.44234 .49161 m .44238 .49157 L .4377 .50138 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44238 .49158 L p
1 g
F P
s
P
p
.002 w
.43755 .48492 m .44239 .49155 L p
.42206 .51657 L 1 g
F P
s
P
p
.002 w
.44238 .49158 m .44166 .49233 L p
.43976 .49679 L 1 g
F P
s
P
p
.43485 .50826 m .44238 .49158 L .44163 .49306 L 1 g
F
P
p
.43485 .50826 m .44163 .49306 L .43865 .49938 L 1 g
F
P
p
.43315 .51845 m .43265 .52417 L .4325 .52874 L 1 g
F
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43532 .53788 m .43632 .54115 L .43846 .54714 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4321 .52932 L p
1 g
F P
s
P
p
.43925 .54566 m .4321 .52932 L .43477 .53679 L 1 g
F
P
p
.44478 .55549 m .4491 .56119 L .45079 .56308 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.4491 .56119 m .43846 .54714 L .44119 .53029 L 1 g
F
P
p
.002 w
.43543 .54314 m .43632 .54115 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.43632 .54115 m .44119 .53029 L p
.43846 .54714 L 1 g
F P
s
P
p
.002 w
.4321 .52932 m .43146 .53025 L p
.43477 .53679 L 1 g
F P
s
P
p
.002 w
.44119 .53029 m .43632 .54115 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.43065 .52273 m .43265 .52417 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43309 .51035 L p
1 g
F P
s
P
p
.43346 .52734 m .43309 .51035 L .43298 .51373 L 1 g
F
P
p
.002 w
.43265 .52417 m .44119 .53029 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.43309 .51035 m .43287 .51061 L p
.43298 .51373 L 1 g
F P
s
P
p
.43265 .52417 m .43395 .50933 L .44465 .49465 L 1 g
F
P
p
.002 w
.43437 .50462 m .4377 .50138 L p
.43395 .50933 L 1 g
F P
s
P
p
.43857 .49957 m .4377 .50138 L .43395 .50933 L 1 g
F
P
p
.002 w
.4377 .50138 m .44465 .49465 L p
.43395 .50933 L 1 g
F P
s
P
p
.43865 .49938 m .44163 .49306 L .43976 .49679 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46593 .50527 m .45445 .50168 L .46882 .4715 L p
1 g
F P
s
P
p
.002 w
.48895 .50096 m .47786 .50502 L .46959 .47114 L p
1 g
F P
s
P
p
.002 w
.50405 .48341 m .49801 .49349 L .47011 .47089 L p
1 g
F P
s
P
p
.002 w
.47047 .47071 m .50405 .48341 L p
.47011 .47089 L 1 g
F P
s
P
p
.002 w
.5064 .4718 m .50405 .48341 L .47047 .47071 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.46939 .47031 m .49935 .44909 L .5023 .45499 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.48221 .46655 m .47409 .46893 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.5064 .4718 m .47115 .47038 L p
.48461 .4662 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46394 m .5064 .4718 L .48461 .4662 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.51467 .4661 m .52438 .46811 L .5064 .4718 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54245 .47686 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53842 .49479 m .54216 .47673 L p
.54245 .47686 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56614 .50944 L p
1 g
F P
s
P
p
.002 w
.57116 .50405 m .56689 .51101 L p
.56614 .50944 L 1 g
F P
s
P
p
.56577 .50532 m .56614 .50944 L .56434 .50565 L 1 g
F
P
p
.57116 .50405 m .56614 .50944 L .56577 .50532 L 1 g
F
P
p
.002 w
.56614 .50944 m .56515 .50826 L p
.56673 .51851 L 1 g
F P
s
P
p
.002 w
.56636 .51187 m .57116 .50405 L p
.56717 .52643 L 1 g
F P
s
P
p
.56673 .51851 m .5673 .52221 L .56636 .51187 L 1 g
F
P
p
.56673 .51851 m .56636 .51187 L .56614 .50944 L 1 g
F
P
p
.002 w
.57116 .50405 m .60109 .51089 L p
.56717 .52643 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56728 .52842 L p
1 g
F P
s
P
p
.60109 .51089 m .56798 .54104 L .56728 .52842 L 1 g
F
P
p
.56792 .52608 m .56728 .52842 L .56717 .52643 L 1 g
F
P
p
.60109 .51089 m .56728 .52842 L .56792 .52608 L 1 g
F
P
p
.002 w
.56728 .52842 m .56654 .52734 L p
.56448 .5386 L 1 g
F P
s
P
p
.56515 .50826 m .56728 .52842 L .56689 .52138 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56141 .5469 L p
1 g
F P
s
P
p
.57855 .54724 m .56043 .54951 L .56141 .5469 L 1 g
F
P
p
.002 w
.56439 .53894 m .56659 .54023 L p
.56141 .5469 L 1 g
F P
s
P
p
.002 w
.56659 .54023 m .57855 .54724 L p
.56141 .5469 L 1 g
F P
s
P
p
.002 w
.56141 .5469 m .56075 .54566 L p
.55681 .55281 L 1 g
F P
s
P
p
.56654 .52734 m .56141 .5469 L .56327 .54193 L 1 g
F
P
p
.56654 .52734 m .56193 .54789 L .56448 .5386 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54908 .56274 L p
1 g
F P
s
P
p
.56075 .54566 m .54908 .56274 L .55681 .55281 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56141 .5469 m .52764 .55362 L .56439 .53894 L 1 g
F
P
p
.56043 .54951 m .55926 .54966 L .56141 .5469 L 1 g
F
P
p
.55926 .54966 m .52764 .55362 L .56141 .5469 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.57855 .54724 m .54534 .57384 L .54102 .5689 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53163 .57426 L p
1 g
F P
s
P
p
.002 w
.54534 .57384 m .51117 .58593 L p
.53163 .57426 L 1 g
F P
s
P
p
.53774 .57246 m .53163 .57426 L .5355 .57205 L 1 g
F
P
p
.54534 .57384 m .53163 .57426 L .53774 .57246 L 1 g
F
P
p
.002 w
.53163 .57426 m .53128 .57265 L p
.52344 .57667 L 1 g
F P
s
P
p
.54854 .56129 m .53163 .57426 L .5377 .5708 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58036 L p
1 g
F P
s
P
p
.53092 .57447 m .52111 .57964 L .51853 .57812 L 1 g
F
P
p
.002 w
.50518 .58805 m .5024 .58096 L p
.52111 .57964 L 1 g
F P
s
P
p
.53128 .57265 m .51092 .58036 L .52344 .57667 L 1 g
F
P
p
.002 w
.51092 .58036 m .51079 .57862 L p
.49989 .5808 L 1 g
F P
s
P
p
.002 w
.5024 .58096 m .50518 .58805 L p
.49029 .58017 L 1 g
F P
s
P
p
.49989 .5808 m .49725 .58133 L .5024 .58096 L 1 g
F
P
p
.49989 .5808 m .5024 .58096 L .51092 .58036 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58009 L p
1 g
F P
s
P
p
.50518 .58805 m .46237 .57834 L .4891 .58009 L 1 g
F
P
p
.4913 .5807 m .4891 .58009 L .49029 .58017 L 1 g
F
P
p
.50518 .58805 m .4891 .58009 L .4913 .5807 L 1 g
F
P
p
.002 w
.4891 .58009 m .48921 .57862 L p
.48154 .57799 L 1 g
F P
s
P
p
.51079 .57862 m .4891 .58009 L .49989 .5808 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46835 .57433 L p
1 g
F P
s
P
p
.4891 .58009 m .47769 .57934 L .47387 .57586 L 1 g
F
P
p
.002 w
.46237 .57834 m .46238 .57112 L p
.47769 .57934 L 1 g
F P
s
P
p
.48921 .57862 m .46835 .57433 L .48154 .57799 L 1 g
F
P
p
.46872 .57265 m .45898 .56876 L .46238 .57112 L 1 g
F
P
p
.002 w
.46835 .57433 m .46872 .57265 L p
.46238 .57112 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.46238 .57112 m .46239 .56539 L p
.47769 .57934 L 1 g
F P
s
P
p
.002 w
.46835 .57433 m .4678 .57686 L p
.48154 .57799 L 1 g
F P
s
P
p
.49029 .58017 m .4891 .58009 L .46239 .56539 L 1 g
F
P
p
.4891 .58009 m .47387 .57586 L .46239 .56539 L 1 g
F
P
p
.002 w
.46818 .57514 m .46835 .57433 L p
.46238 .57112 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58009 L p
1 g
F P
s
P
p
.48154 .57799 m .4678 .57686 L .4891 .58009 L 1 g
F
P
p
.002 w
.4891 .58009 m .48889 .583 L p
.49989 .5808 L 1 g
F P
s
P
p
.002 w
.50518 .58805 m .46235 .58858 L .46237 .57834 L p
1 g
F P
s
P
p
.002 w
.46239 .56539 m .4961 .5649 L .5024 .58096 L p
1 g
F P
s
P
p
.49029 .58017 m .46239 .56539 L .5024 .58096 L 1 g
F
P
p
.002 w
.5024 .58096 m .4961 .5649 L p
.52111 .57964 L 1 g
F P
s
P
p
.002 w
.51092 .58036 m .51111 .583 L p
.52344 .57667 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.5355 .57205 m .53092 .57447 L .4961 .5649 L 1 g
F
P
p
.53092 .57447 m .51853 .57812 L .4961 .5649 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58036 L p
1 g
F P
s
P
p
.49725 .58133 m .48889 .583 L .51092 .58036 L 1 g
F
P
p
.002 w
.51117 .58593 m .50518 .58805 L p
.5355 .57205 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53163 .57426 L p
1 g
F P
s
P
p
.52344 .57667 m .51111 .583 L .53163 .57426 L 1 g
F
P
p
.54854 .56129 m .5377 .5708 L .53985 .56957 L 1 g
F
P
p
.002 w
.54102 .5689 m .54534 .57384 L p
.5355 .57205 L 1 g
F P
s
P
p
.57855 .54724 m .54102 .5689 L .56756 .54862 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.4961 .5649 m .52764 .55362 L .54102 .5689 L p
1 g
F P
s
P
p
.5355 .57205 m .4961 .5649 L .54102 .5689 L 1 g
F
P
p
.53985 .56957 m .53197 .57582 L .53865 .57071 L 1 g
F
P
p
.5377 .5708 m .53197 .57582 L .53985 .56957 L 1 g
F
P
p
.002 w
.53163 .57426 m .53197 .57582 L p
.5377 .5708 L 1 g
F P
s
P
p
.002 w
.54102 .5689 m .52764 .55362 L p
.56756 .54862 L 1 g
F P
s
P
p
.002 w
.53197 .57582 m .5322 .57686 L p
.53865 .57071 L 1 g
F P
s
P
p
.002 w
.54908 .56274 m .54998 .56518 L p
.55681 .55281 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56141 .5469 L p
1 g
F P
s
P
p
.55681 .55281 m .54998 .56518 L .56141 .5469 L 1 g
F
P
p
.002 w
.56141 .5469 m .56193 .54789 L p
.56327 .54193 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52764 .55362 m .55362 .53263 L .56439 .53894 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56717 .52643 m .56728 .52842 L .55362 .53263 L 1 g
F
P
p
.002 w
.56798 .54104 m .56439 .53894 L p
.56728 .52842 L 1 g
F P
s
P
p
.002 w
.56439 .53894 m .55362 .53263 L p
.56728 .52842 L 1 g
F P
s
P
p
.002 w
.56193 .54789 m .56257 .5491 L p
.56448 .5386 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56728 .52842 L p
1 g
F P
s
P
p
.56448 .5386 m .56257 .5491 L .56728 .52842 L 1 g
F
P
p
.002 w
.56728 .52842 m .56795 .5294 L p
.56689 .52138 L 1 g
F P
s
P
p
.002 w
.60109 .51089 m .57855 .54724 L .56798 .54104 L p
1 g
F P
s
P
p
.56515 .50826 m .56795 .5294 L .5673 .52221 L 1 g
F
P
p
.55661 .4905 m .56614 .50944 L .5624 .50157 L 1 g
F
P
p
.5782 .47091 m .5624 .50157 L .55434 .48523 L 1 g
F
P
p
.56235 .50147 m .5624 .50157 L .56237 .50151 L 1 g
F
P
p
.55661 .4905 m .5624 .50157 L .56235 .50147 L 1 g
F
P
p
.002 w
.5782 .47091 m .57116 .50405 L .5624 .50157 L p
1 g
F P
s
P
p
.002 w
.5624 .50157 m .57116 .50405 L p
.56434 .50565 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55764 .4916 L p
1 g
F P
s
P
p
.002 w
.55764 .4916 m .55661 .4905 L p
.56237 .50151 L 1 g
F P
s
P
p
.56237 .50151 m .56713 .51061 L .55764 .4916 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.52645 .51452 m .53842 .49479 L .5624 .50157 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.56434 .50565 m .52645 .51452 L .5624 .50157 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5573 .49123 L p
1 g
F P
s
P
p
.002 w
.5624 .50157 m .53842 .49479 L p
.55234 .48643 L 1 g
F P
s
P
p
.54174 .47608 m .5573 .49123 L .54973 .4839 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55434 .48523 m .5573 .49123 L .55234 .48643 L 1 g
F
P
p
.5573 .49123 m .5624 .50157 L .55234 .48643 L 1 g
F
P
p
.56614 .50944 m .55362 .53263 L .56434 .50565 L 1 g
F
P
p
.002 w
.56689 .51101 m .56636 .51187 L p
.56614 .50944 L 1 g
F P
s
P
p
.002 w
.56636 .51187 m .55362 .53263 L p
.56614 .50944 L 1 g
F P
s
P
p
.002 w
.56795 .5294 m .56854 .53025 L p
.5673 .52221 L 1 g
F P
s
P
p
.002 w
.55362 .53263 m .56636 .51187 L p
.56717 .52643 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56614 .50944 L p
1 g
F P
s
P
p
.5673 .52221 m .56854 .53025 L .56614 .50944 L 1 g
F
P
p
.002 w
.56614 .50944 m .56713 .51061 L p
.56237 .50151 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55362 .53263 m .52645 .51452 L p
.56434 .50565 L 1 g
F P
s
P
p
.55234 .48643 m .53842 .49479 L .54245 .47686 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54245 .47686 L p
1 g
F P
s
P
p
.002 w
.54245 .47686 m .54174 .47608 L p
.54973 .4839 L 1 g
F P
s
P
p
.54973 .4839 m .55834 .49233 L .54245 .47686 L 1 g
F
P
p
.55713 .48356 m .54245 .47686 L .54314 .472 L 1 g
F
P
p
.002 w
.54216 .47673 m .54219 .4766 L p
.54245 .47686 L 1 g
F P
s
P
p
.002 w
.54219 .4766 m .54314 .472 L p
.54245 .47686 L 1 g
F P
s
P
p
.55713 .48356 m .55234 .48643 L .54245 .47686 L 1 g
F
P
p
.002 w
.5573 .49123 m .55834 .49233 L p
.54973 .4839 L 1 g
F P
s
P
p
.002 w
.53842 .49479 m .50405 .48341 L p
.53642 .47396 L 1 g
F P
s
P
p
.52214 .46667 m .54245 .47686 L .54216 .47673 L 1 g
F
P
p
.002 w
.54216 .47673 m .53842 .49479 L p
.53642 .47396 L 1 g
F P
s
P
p
.54011 .47573 m .54216 .47673 L .5412 .47628 L 1 g
F
P
p
.52214 .46667 m .54216 .47673 L .54011 .47573 L 1 g
F
P
p
.002 w
.50405 .48341 m .5064 .4718 L .53223 .47194 L p
1 g
F P
s
P
p
.53642 .47396 m .50405 .48341 L .53223 .47194 L 1 g
F
P
p
.52214 .46667 m .54255 .47697 L .53371 .47266 L 1 g
F
P
p
.002 w
.53223 .47194 m .5064 .4718 L p
.52438 .46811 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.53371 .47266 L 1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54287 .46997 m .54314 .472 L p
.51467 .4661 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46717 L p
1 g
F P
s
P
p
.53371 .47266 m .54302 .47747 L .52244 .46717 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54004 .44862 m .54287 .46997 L p
.52244 .46717 L 1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .51336 .46592 L 1 g
F
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.51698 .46451 m .52244 .46717 L .51467 .4661 L 1 g
F
P
p
.54004 .44862 m .52244 .46717 L .51698 .46451 L 1 g
F
P
p
.002 w
.53223 .47194 m .54314 .472 L p
.53642 .47396 L 1 g
F P
s
P
p
.002 w
.54314 .472 m .54216 .47673 L p
.53642 .47396 L 1 g
F P
s
P
p
.5412 .47628 m .54216 .47673 L .54255 .47697 L 1 g
F
P
p
.002 w
.54245 .47686 m .54246 .47687 L p
.54216 .47673 L 1 g
F P
s
P
p
.002 w
.54246 .47687 m .54255 .47697 L p
.54216 .47673 L 1 g
F P
s
P
p
.002 w
.54314 .472 m .5782 .47091 L p
.55713 .48356 L 1 g
F P
s
P
p
.002 w
.54314 .472 m .53223 .47194 L p
.52438 .46811 L 1 g
F P
s
P
p
.002 w
.54255 .47697 m .54302 .47747 L p
.53371 .47266 L 1 g
F P
s
P
p
.002 w
.50478 .45993 m .54004 .44862 L p
.51467 .4661 L 1 g
F P
s
P
p
.002 w
.5064 .4718 m .50545 .46484 L p
.51467 .4661 L 1 g
F P
s
P
p
.5 .4634 m .51336 .46592 L .51253 .46581 L 1 g
F
P
p
.002 w
.50545 .46484 m .5064 .4718 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46394 L p
1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .4634 L p
.51989 .46722 L 1 g
F P
s
P
p
.51989 .46722 m .52282 .46778 L .5 .46394 L 1 g
F
P
p
.002 w
.50478 .45993 m .50522 .46317 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.47752 .46723 m .47786 .46667 L p
.48932 .4655 L 1 g
F P
s
P
p
.48932 .4655 m .48221 .46655 L .47752 .46723 L 1 g
F
P
p
.002 w
.47409 .46893 m .48221 .46655 L p
.47115 .47038 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .46442 L p
.48943 .46549 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46395 L .48943 .46549 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47752 .46723 L p
1 g
F P
s
P
p
.45826 .47608 m .47752 .46723 L .47745 .46727 L 1 g
F
P
p
.45826 .47608 m .47752 .46724 L .47715 .46742 L 1 g
F
P
p
.45826 .47608 m .47751 .46725 L .47321 .46936 L 1 g
F
P
p
.002 w
.47409 .46893 m .46939 .47031 L p
.4753 .46756 L 1 g
F P
s
P
p
.5023 .45499 m .47752 .46723 L .4753 .46756 L 1 g
F
P
p
.47752 .46723 m .47409 .46893 L .4753 .46756 L 1 g
F
P
p
.002 w
.48221 .46655 m .50478 .45993 L p
.48461 .4662 L 1 g
F P
s
P
p
.48461 .4662 m .47115 .47038 L .48221 .46655 L 1 g
F
P
p
.48943 .46549 m .5 .46442 L .47767 .46721 L 1 g
F
P
p
.48221 .46655 m .47767 .46721 L .47752 .46723 L 1 g
F
P
p
.48943 .46549 m .47767 .46721 L .48221 .46655 L 1 g
F
P
p
.48932 .4655 m .48943 .46549 L .48221 .46655 L 1 g
F
P
p
.49469 .46306 m .5 .46394 L .48461 .4662 L 1 g
F
P
p
.50478 .45993 m .5 .46394 L .49469 .46306 L 1 g
F
P
p
.002 w
.50545 .46484 m .50478 .45993 L p
.51467 .4661 L 1 g
F P
s
P
p
.51253 .46581 m .52276 .4677 L .51989 .46722 L 1 g
F
P
p
.51336 .46592 m .52276 .4677 L .51253 .46581 L 1 g
F
P
p
.002 w
.52244 .46717 m .52276 .4677 L p
.51336 .46592 L 1 g
F P
s
P
p
.002 w
.50522 .46317 m .50545 .46484 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.52276 .4677 m .52282 .46778 L p
.51989 .46722 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46724 L p
1 g
F P
s
P
p
.002 w
.47752 .46724 m .47752 .46723 L p
.47767 .46721 L 1 g
F P
s
P
p
.47767 .46721 m .5 .46442 L .47752 .46724 L 1 g
F
P
p
.002 w
.5023 .45499 m .50478 .45993 L .48221 .46655 L p
1 g
F P
s
P
p
.5023 .45499 m .48221 .46655 L .47752 .46723 L 1 g
F
P
p
.002 w
.47752 .46723 m .47752 .46724 L p
.47745 .46727 L 1 g
F P
s
P
p
.002 w
.47752 .46724 m .47751 .46725 L p
.47715 .46742 L 1 g
F P
s
P
p
.002 w
.47115 .47038 m .5064 .4718 L p
.47047 .47071 L 1 g
F P
s
P
p
.45826 .47608 m .47735 .4675 L .47067 .47064 L 1 g
F
P
p
.002 w
.47115 .47038 m .46939 .47031 L .47409 .46893 L p
1 g
F P
s
P
p
.002 w
.47047 .47071 m .46939 .47031 L .47115 .47038 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47735 .4675 L p
.47321 .46936 L 1 g
F P
s
P
p
.002 w
.47735 .4675 m .47718 .46778 L p
.47067 .47064 L 1 g
F P
s
P
p
.002 w
.44238 .49157 m .44339 .4905 L p
.44884 .4853 L 1 g
F P
s
P
p
.4424 .49156 m .45765 .47674 L .46647 .47261 L 1 g
F
P
p
.44884 .4853 m .45351 .48084 L .4424 .49156 L 1 g
F
P
p
.44884 .4853 m .4424 .49156 L .44238 .49157 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.4424 .49156 m .44239 .49155 L p
.45765 .47674 L 1 g
F P
s
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.47019 .47085 L 1 g
F P
s
P
p
.45765 .47674 m .45765 .47674 L .4597 .47475 L 1 g
F
P
p
.4424 .49156 m .45765 .47674 L .45765 .47674 L 1 g
F
P
p
.002 w
.47011 .47089 m .46939 .47031 L .47047 .47071 L p
1 g
F P
s
P
p
.47019 .47085 m .4702 .47085 L .47018 .47085 L 1 g
F
P
p
.47019 .47085 m .47018 .47085 L .45765 .47674 L 1 g
F
P
p
.4702 .47085 m .47023 .47083 L .47012 .47088 L 1 g
F
P
p
.4702 .47085 m .47012 .47088 L .45765 .47674 L 1 g
F
P
p
.002 w
.49801 .49349 m .48895 .50096 L .46985 .47102 L p
1 g
F P
s
P
p
.002 w
.46985 .47102 m .46939 .47031 L .47011 .47089 L p
1 g
F P
s
P
p
.002 w
.47011 .47089 m .49801 .49349 L p
.46985 .47102 L 1 g
F P
s
P
p
.47023 .47083 m .47003 .47093 L .45765 .47674 L 1 g
F
P
p
.002 w
.46959 .47114 m .46939 .47031 L .46985 .47102 L p
1 g
F P
s
P
p
.002 w
.46985 .47102 m .48895 .50096 L p
.46959 .47114 L 1 g
F P
s
P
p
.47023 .47083 m .4703 .4708 L .47003 .47093 L 1 g
F
P
p
.4703 .4708 m .47041 .47075 L .46983 .47102 L 1 g
F
P
p
.4703 .4708 m .46983 .47102 L .45765 .47674 L 1 g
F
P
p
.002 w
.47786 .50502 m .46593 .50527 L .4693 .47128 L p
1 g
F P
s
P
p
.002 w
.4693 .47128 m .46939 .47031 L .46959 .47114 L p
1 g
F P
s
P
p
.002 w
.46959 .47114 m .47786 .50502 L p
.4693 .47128 L 1 g
F P
s
P
p
.002 w
.46882 .4715 m .46939 .47031 L .4693 .47128 L p
1 g
F P
s
P
p
.002 w
.4693 .47128 m .46593 .50527 L p
.46882 .4715 L 1 g
F P
s
P
p
.47041 .47075 m .47053 .4707 L .46931 .47127 L 1 g
F
P
p
.47041 .47075 m .46931 .47127 L .45765 .47674 L 1 g
F
P
p
.47053 .4707 m .47067 .47064 L .46758 .47209 L 1 g
F
P
p
.47053 .4707 m .46758 .47209 L .45765 .47674 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45445 .50168 m .44465 .49465 L .46758 .47209 L p
1 g
F P
s
P
p
.002 w
.46758 .47209 m .46939 .47031 L .46882 .4715 L p
1 g
F P
s
P
p
.002 w
.46882 .4715 m .45445 .50168 L p
.46758 .47209 L 1 g
F P
s
P
p
.002 w
.4597 .47475 m .46939 .47031 L p
.46647 .47261 L 1 g
F P
s
P
p
.45765 .47674 m .4597 .47475 L .46647 .47261 L 1 g
F
P
p
.002 w
.46939 .47031 m .44465 .49465 L .4424 .49156 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.47067 .47064 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.002 w
.44239 .49155 m .43755 .48492 L .44817 .48004 L p
1 g
F P
s
P
p
.44339 .4905 m .45054 .48365 L .44884 .4853 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44817 .48004 m .4597 .47475 L p
.44239 .49155 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .45351 .48084 L p
.44884 .4853 L 1 g
F P
s
P
p
.45054 .48365 m .45698 .47747 L .44884 .4853 L 1 g
F
P
p
.002 w
.44239 .49155 m .44465 .49465 L .4377 .50138 L p
1 g
F P
s
P
p
.002 w
.45351 .48084 m .44166 .49233 L .44238 .49157 L p
1 g
F P
s
P
p
.43857 .49957 m .43865 .49938 L .4377 .50138 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43865 .49938 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.43315 .51845 m .43298 .51373 L .43265 .52417 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44119 .53029 m .43265 .52417 L p
.44465 .49465 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52874 L p
1 g
F P
s
P
p
.43298 .51373 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.43532 .53788 m .43477 .53679 L .43632 .54115 L 1 g
F
P
p
.002 w
.42206 .51657 m .43065 .52273 L p
.43004 .55517 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43846 .54714 L p
1 g
F P
s
P
p
.43477 .53679 m .43146 .53025 L .43846 .54714 L 1 g
F
P
p
.44478 .55549 m .44124 .55241 L .4491 .56119 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46239 .56539 m .4491 .56119 L p
.44119 .53029 L 1 g
F P
s
P
p
.002 w
.44721 .56059 m .46239 .56539 L .46238 .57112 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56308 L p
1 g
F P
s
P
p
.44124 .55241 m .43743 .5491 L .45079 .56308 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46818 .57514 L p
1 g
F P
s
P
p
.45898 .56876 m .45002 .56518 L .46818 .57514 L 1 g
F
P
p
.002 w
.54534 .57384 m .57855 .54724 L .60042 .55794 L p
1 g
F P
s
P
p
.002 w
.62719 .51512 m .60042 .55794 L .57855 .54724 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.37241 .44228 m .37194 .47581 L .34748 .47488 L p
1 g
F P
s
P
p
.002 w
.34748 .47488 m .34795 .43224 L .37241 .44228 L p
1 g
F P
s
P
p
.002 w
.52357 .30537 m .47144 .29875 L .47457 .27444 L p
1 g
F P
s
P
p
.002 w
.47457 .27444 m .53299 .28175 L .52357 .30537 L p
1 g
F P
s
P
p
.002 w
.6382 .46519 m .6319 .41363 L .65429 .40308 L p
1 g
F P
s
P
p
.002 w
.62842 .35002 m .65429 .40308 L .6319 .41363 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.42624 .33678 m .38934 .35913 L .37729 .33605 L p
1 g
F P
s
P
p
.002 w
.37729 .33605 m .4208 .30948 L .42624 .33678 L p
1 g
F P
s
P
p
.002 w
.57855 .54724 m .60109 .51089 L .62719 .51512 L p
1 g
F P
s
P
p
.002 w
.6382 .46519 m .62719 .51512 L .60109 .51089 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.57118 .32877 m .52357 .30537 L .53299 .28175 L p
1 g
F P
s
P
p
.002 w
.53299 .28175 m .58636 .30793 L .57118 .32877 L p
1 g
F P
s
P
p
.002 w
.38383 .41088 m .37241 .44228 L .34795 .43224 L p
1 g
F P
s
P
p
.002 w
.34795 .43224 m .36233 .3922 L .38383 .41088 L p
1 g
F P
s
P
p
.002 w
.6319 .41363 m .60873 .36632 L .62842 .35002 L p
1 g
F P
s
P
p
.002 w
.58636 .30793 m .62842 .35002 L .60873 .36632 L p
1 g
F P
s
P
p
.002 w
.60873 .36632 m .57118 .32877 L .58636 .30793 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4691 .32784 m .42624 .33678 L .4208 .30948 L p
1 g
F P
s
P
p
.002 w
.4208 .30948 m .47144 .29875 L .4691 .32784 L p
1 g
F P
s
P
p
.002 w
.40819 .4976 m .42206 .51657 L .4024 .53533 L p
1 g
F P
s
P
p
.002 w
.4024 .53533 m .38232 .50794 L .40819 .4976 L p
1 g
F P
s
P
p
.002 w
.43004 .55517 m .4024 .53533 L .42206 .51657 L p
1 g
F P
s
P
p
.002 w
.40512 .38504 m .38383 .41088 L .36233 .3922 L p
1 g
F P
s
P
p
.002 w
.36233 .3922 m .38934 .35913 L .40512 .38504 L p
1 g
F P
s
P
p
.002 w
.60109 .51089 m .61025 .4686 L .6382 .46519 L p
1 g
F P
s
P
p
.002 w
.6319 .41363 m .6382 .46519 L .61025 .4686 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40106 .47537 m .40819 .4976 L .38232 .50794 L p
1 g
F P
s
P
p
.002 w
.38232 .50794 m .37194 .47581 L .40106 .47537 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44119 .53029 m .46358 .53734 L .46239 .56539 L p
1 g
F P
s
P
p
.002 w
.4961 .5649 m .46239 .56539 L .46358 .53734 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40148 .45222 m .40106 .47537 L .37194 .47581 L p
1 g
F P
s
P
p
.002 w
.37194 .47581 m .37241 .44228 L .40148 .45222 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.51316 .33354 m .4691 .32784 L .47144 .29875 L p
1 g
F P
s
P
p
.002 w
.47144 .29875 m .52357 .30537 L .51316 .33354 L p
1 g
F P
s
P
p
.002 w
.46358 .53734 m .48687 .53693 L .4961 .5649 L p
1 g
F P
s
P
p
.002 w
.52764 .55362 m .4961 .5649 L .48687 .53693 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.61025 .4686 m .60479 .42502 L .6319 .41363 L p
1 g
F P
s
P
p
.002 w
.60873 .36632 m .6319 .41363 L .60479 .42502 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.4341 .36766 m .40512 .38504 L .38934 .35913 L p
1 g
F P
s
P
p
.002 w
.38934 .35913 m .42624 .33678 L .4341 .36766 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61025 .4686 m .60109 .51089 L .57116 .50405 L p
1 g
F P
s
P
p
.002 w
.40945 .43062 m .40148 .45222 L .37241 .44228 L p
1 g
F P
s
P
p
.002 w
.37241 .44228 m .38383 .41088 L .40945 .43062 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.55337 .35335 m .51316 .33354 L .52357 .30537 L p
1 g
F P
s
P
p
.002 w
.52357 .30537 m .57118 .32877 L .55337 .35335 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.60479 .42502 m .58512 .38506 L .60873 .36632 L p
1 g
F P
s
P
p
.002 w
.57118 .32877 m .60873 .36632 L .58512 .38506 L p
1 g
F P
s
P
p
.002 w
.55362 .53263 m .52764 .55362 L .50861 .52906 L p
1 g
F P
s
P
p
.002 w
.48687 .53693 m .50861 .52906 L .52764 .55362 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.58512 .38506 m .55337 .35335 L .57118 .32877 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.46767 .36079 m .4341 .36766 L .42624 .33678 L p
1 g
F P
s
P
p
.002 w
.42624 .33678 m .4691 .32784 L .46767 .36079 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42419 .41291 m .40945 .43062 L .38383 .41088 L p
1 g
F P
s
P
p
.002 w
.38383 .41088 m .40512 .38504 L .42419 .41291 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57116 .50405 m .5782 .47091 L .61025 .4686 L p
1 g
F P
s
P
p
.002 w
.60479 .42502 m .61025 .4686 L .5782 .47091 L p
1 g
F P
s
P
p
.002 w
.42206 .51657 m .40819 .4976 L .43755 .48492 L p
1 g
F P
s
P
p
.002 w
.44465 .49465 m .45445 .50168 L .44119 .53029 L p
1 g
F P
s
P
p
.002 w
.46358 .53734 m .44119 .53029 L .45445 .50168 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.50861 .52906 m .52645 .51452 L .55362 .53263 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43394 .47353 m .43755 .48492 L .40819 .4976 L p
1 g
F P
s
P
p
.002 w
.40819 .4976 m .40106 .47537 L .43394 .47353 L p
1 g
F P
s
P
p
.002 w
.45445 .50168 m .46593 .50527 L .46358 .53734 L p
1 g
F P
s
P
p
.002 w
.48687 .53693 m .46358 .53734 L .46593 .50527 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.4342 .46169 m .43394 .47353 L .40106 .47537 L p
1 g
F P
s
P
p
.002 w
.40106 .47537 m .40148 .45222 L .4342 .46169 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46593 .50527 m .47786 .50502 L .48687 .53693 L p
1 g
F P
s
P
p
.002 w
.50861 .52906 m .48687 .53693 L .47786 .50502 L p
1 g
F P
s
P
p
.002 w
.5021 .36533 m .46767 .36079 L .4691 .32784 L p
1 g
F P
s
P
p
.002 w
.4691 .32784 m .51316 .33354 L .5021 .36533 L p
1 g
F P
s
P
p
.002 w
.44416 .40106 m .42419 .41291 L .40512 .38504 L p
1 g
F P
s
P
p
.002 w
.40512 .38504 m .4341 .36766 L .44416 .40106 L p
1 g
F P
s
P
p
.002 w
.5782 .47091 m .57381 .43683 L .60479 .42502 L p
1 g
F P
s
P
p
.002 w
.58512 .38506 m .60479 .42502 L .57381 .43683 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.43832 .45068 m .4342 .46169 L .40148 .45222 L p
1 g
F P
s
P
p
.002 w
.40148 .45222 m .40945 .43062 L .43832 .45068 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.47786 .50502 m .48895 .50096 L .50861 .52906 L p
1 g
F P
s
P
p
.002 w
.52645 .51452 m .50861 .52906 L .48895 .50096 L p
1 g
F P
s
P
p
.002 w
.53353 .38085 m .5021 .36533 L .51316 .33354 L p
1 g
F P
s
P
p
.002 w
.51316 .33354 m .55337 .35335 L .53353 .38085 L p
1 g
F P
s
P
p
.002 w
.57381 .43683 m .55836 .40562 L .58512 .38506 L p
1 g
F P
s
P
p
.002 w
.55337 .35335 m .58512 .38506 L .55836 .40562 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.55836 .40562 m .53353 .38085 L .55337 .35335 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46722 .39644 m .44416 .40106 L .4341 .36766 L p
1 g
F P
s
P
p
.002 w
.4341 .36766 m .46767 .36079 L .46722 .39644 L p
1 g
F P
s
P
p
.002 w
.44588 .4417 m .43832 .45068 L .40945 .43062 L p
1 g
F P
s
P
p
.002 w
.40945 .43062 m .42419 .41291 L .44588 .4417 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.48895 .50096 m .49801 .49349 L .52645 .51452 L p
1 g
F P
s
P
p
.002 w
.53842 .49479 m .52645 .51452 L .49801 .49349 L p
1 g
F P
s
P
p
.002 w
.57381 .43683 m .5782 .47091 L .54314 .472 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.43755 .48492 m .43394 .47353 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.43394 .47353 m .4342 .46169 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.45608 .43572 m .44588 .4417 L .42419 .41291 L p
1 g
F P
s
P
p
.002 w
.42419 .41291 m .44416 .40106 L .45608 .43572 L p
1 g
F P
s
P
p
.002 w
.49083 .39962 m .46722 .39644 L .46767 .36079 L p
1 g
F P
s
P
p
.002 w
.46767 .36079 m .5021 .36533 L .49083 .39962 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49801 .49349 m .50405 .48341 L .53842 .49479 L p
1 g
F P
s
P
p
.002 w
.54314 .472 m .54004 .44862 L .57381 .43683 L p
1 g
F P
s
P
p
.002 w
.55836 .40562 m .57381 .43683 L .54004 .44862 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.4342 .46169 m .43832 .45068 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.51236 .41028 m .49083 .39962 L .5021 .36533 L p
1 g
F P
s
P
p
.002 w
.5021 .36533 m .53353 .38085 L .51236 .41028 L p
1 g
F P
s
P
p
.002 w
.43832 .45068 m .44588 .4417 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.54004 .44862 m .5294 .42725 L .55836 .40562 L p
1 g
F P
s
P
p
.002 w
.53353 .38085 m .55836 .40562 L .5294 .42725 L p
1 g
F P
s
P
p
.002 w
.4678 .43343 m .45608 .43572 L .44416 .40106 L p
1 g
F P
s
P
p
.002 w
.44416 .40106 m .46722 .39644 L .4678 .43343 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.5294 .42725 m .51236 .41028 L .53353 .38085 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.44588 .4417 m .45608 .43572 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.4907 .44049 m .49935 .44909 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.004 w
.49162 .44141 m
.5 .43051 L
s
P
p
.002 w
.47978 .43507 m .4907 .44049 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.4678 .43343 m .47978 .43507 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.45608 .43572 m .4678 .43343 L .46939 .47031 L closepath p
1 g
F P
s
P
p
.002 w
.47978 .43507 m .4678 .43343 L .46722 .39644 L p
1 g
F P
s
P
p
.002 w
.46722 .39644 m .49083 .39962 L .47978 .43507 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.5294 .42725 m .54004 .44862 L .50478 .45993 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.4907 .44049 m .47978 .43507 L .49083 .39962 L p
1 g
F P
s
P
p
.002 w
.49083 .39962 m .51236 .41028 L .4907 .44049 L p
1 g
F P
s
P
p
.002 w
.50478 .45993 m .49935 .44909 L .5294 .42725 L p
1 g
F P
s
P
p
.002 w
.51236 .41028 m .5294 .42725 L .49935 .44909 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.49935 .44909 m .4907 .44049 L .51236 .41028 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.004 w
.4684 .47159 m
.46939 .47031 L
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.45044 .49494 m
.4684 .47159 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .49997 .71917 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .45044 .49494 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.173643)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.173643)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50697 .43064 m .49789 .43297 L .5004 .46134 L p
1 g
F P
s
P
p
.002 w
.48194 .45995 m .5004 .46134 L .49789 .43297 L p
1 g
F P
s
P
p
.002 w
.49789 .43297 m .48855 .43225 L .48194 .45995 L p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .49789 .43297 L .50697 .43064 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .48855 .43225 L .49789 .43297 L closepath p
1 g
F P
s
P
p
.002 w
.5004 .46134 m .51834 .45675 L .50697 .43064 L p
1 g
F P
s
P
p
.002 w
.5148 .42553 m .50697 .43064 L .51834 .45675 L p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .50697 .43064 L .5148 .42553 L closepath p
1 g
F P
s
P
p
.002 w
.46493 .4527 m .48194 .45995 L .48855 .43225 L p
1 g
F P
s
P
p
.002 w
.48855 .43225 m .47995 .42858 L .46493 .4527 L p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .47995 .42858 L .48855 .43225 L closepath p
1 g
F P
s
P
p
.002 w
.51834 .45675 m .53385 .44667 L .5148 .42553 L p
1 g
F P
s
P
p
.002 w
.52056 .41818 m .5148 .42553 L .53385 .44667 L p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .5148 .42553 L .52056 .41818 L closepath p
1 g
F P
s
P
p
.002 w
.4512 .44038 m .46493 .4527 L .47995 .42858 L p
1 g
F P
s
P
p
.002 w
.47995 .42858 m .47303 .42233 L .4512 .44038 L p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .47303 .42233 L .47995 .42858 L closepath p
1 g
F P
s
P
p
.002 w
.53385 .44667 m .54527 .43214 L .52056 .41818 L p
1 g
F P
s
P
p
.002 w
.52361 .40937 m .52056 .41818 L .54527 .43214 L p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .52056 .41818 L .52361 .40937 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .52361 .40937 L .52362 .40006 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .52362 .40006 L .52058 .39125 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .52058 .39125 L .5148 .38391 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .5148 .38391 L .50692 .37883 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .50692 .37883 L .49779 .37657 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .49779 .37657 L .4884 .37738 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .4884 .37738 L .47978 .38119 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .47978 .38119 L .47288 .38756 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .47288 .38756 L .46843 .3958 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .46843 .3958 L .46693 .405 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .46693 .405 L .46852 .41418 L closepath p
1 g
F P
s
P
p
.002 w
.49543 .40455 m .46852 .41418 L .47303 .42233 L closepath p
1 g
F P
s
P
p
.002 w
.44223 .42426 m .4512 .44038 L .47303 .42233 L p
1 g
F P
s
P
p
.002 w
.47303 .42233 m .46852 .41418 L .44223 .42426 L p
1 g
F P
s
P
p
.002 w
.51834 .45675 m .5004 .46134 L .50292 .48916 L p
1 g
F P
s
P
p
.002 w
.47573 .48713 m .50292 .48916 L .5004 .46134 L p
1 g
F P
s
P
p
.002 w
.5004 .46134 m .48194 .45995 L .47573 .48713 L p
1 g
F P
s
P
p
.002 w
.54527 .43214 m .55135 .41473 L .52361 .40937 L p
1 g
F P
s
P
p
.002 w
.52362 .40006 m .52361 .40937 L .55135 .41473 L p
1 g
F P
s
P
p
.002 w
.50292 .48916 m .52936 .48241 L .51834 .45675 L p
1 g
F P
s
P
p
.002 w
.53385 .44667 m .51834 .45675 L .52936 .48241 L p
1 g
F P
s
P
p
.002 w
.45064 .47649 m .47573 .48713 L .48194 .45995 L p
1 g
F P
s
P
p
.002 w
.48194 .45995 m .46493 .4527 L .45064 .47649 L p
1 g
F P
s
P
p
.002 w
.43903 .40609 m .44223 .42426 L .46852 .41418 L p
1 g
F P
s
P
p
.002 w
.46852 .41418 m .46693 .405 L .43903 .40609 L p
1 g
F P
s
P
p
.002 w
.52936 .48241 m .55222 .46757 L .53385 .44667 L p
1 g
F P
s
P
p
.002 w
.54527 .43214 m .53385 .44667 L .55222 .46757 L p
1 g
F P
s
P
p
.002 w
.55135 .41473 m .55142 .39629 L .52362 .40006 L p
1 g
F P
s
P
p
.002 w
.52058 .39125 m .52362 .40006 L .55142 .39629 L p
1 g
F P
s
P
p
.002 w
.43035 .45836 m .45064 .47649 L .46493 .4527 L p
1 g
F P
s
P
p
.002 w
.46493 .4527 m .4512 .44038 L .43035 .45836 L p
1 g
F P
s
P
p
.002 w
.44196 .38781 m .43903 .40609 L .46693 .405 L p
1 g
F P
s
P
p
.002 w
.46693 .405 m .46843 .3958 L .44196 .38781 L p
1 g
F P
s
P
p
.002 w
.55142 .39629 m .54543 .37881 L .52058 .39125 L p
1 g
F P
s
P
p
.002 w
.5148 .38391 m .52058 .39125 L .54543 .37881 L p
1 g
F P
s
P
p
.002 w
.55222 .46757 m .56909 .44619 L .54527 .43214 L p
1 g
F P
s
P
p
.002 w
.55135 .41473 m .54527 .43214 L .56909 .44619 L p
1 g
F P
s
P
p
.002 w
.45075 .37143 m .44196 .38781 L .46843 .3958 L p
1 g
F P
s
P
p
.002 w
.46843 .3958 m .47288 .38756 L .45075 .37143 L p
1 g
F P
s
P
p
.002 w
.54543 .37881 m .53401 .3642 L .5148 .38391 L p
1 g
F P
s
P
p
.002 w
.50692 .37883 m .5148 .38391 L .53401 .3642 L p
1 g
F P
s
P
p
.002 w
.41706 .43461 m .43035 .45836 L .4512 .44038 L p
1 g
F P
s
P
p
.002 w
.4512 .44038 m .44223 .42426 L .41706 .43461 L p
1 g
F P
s
P
p
.002 w
.46445 .35876 m .45075 .37143 L .47288 .38756 L p
1 g
F P
s
P
p
.002 w
.47288 .38756 m .47978 .38119 L .46445 .35876 L p
1 g
F P
s
P
p
.002 w
.53401 .3642 m .51837 .35408 L .50692 .37883 L p
1 g
F P
s
P
p
.002 w
.49779 .37657 m .50692 .37883 L .51837 .35408 L p
1 g
F P
s
P
p
.002 w
.48157 .35119 m .46445 .35876 L .47978 .38119 L p
1 g
F P
s
P
p
.002 w
.47978 .38119 m .4884 .37738 L .48157 .35119 L p
1 g
F P
s
P
p
.002 w
.56909 .44619 m .57813 .42053 L .55135 .41473 L p
1 g
F P
s
P
p
.002 w
.55142 .39629 m .55135 .41473 L .57813 .42053 L p
1 g
F P
s
P
p
.002 w
.51837 .35408 m .50023 .34957 L .49779 .37657 L p
1 g
F P
s
P
p
.002 w
.4884 .37738 m .49779 .37657 L .50023 .34957 L p
1 g
F P
s
P
p
.002 w
.50023 .34957 m .48157 .35119 L .4884 .37738 L p
1 g
F P
s
P
p
.002 w
.41225 .40778 m .41706 .43461 L .44223 .42426 L p
1 g
F P
s
P
p
.002 w
.44223 .42426 m .43903 .40609 L .41225 .40778 L p
1 g
F P
s
P
p
.002 w
.52936 .48241 m .50292 .48916 L .50541 .51591 L p
1 g
F P
s
P
p
.002 w
.47002 .51329 m .50541 .51591 L .50292 .48916 L p
1 g
F P
s
P
p
.002 w
.50292 .48916 m .47573 .48713 L .47002 .51329 L p
1 g
F P
s
P
p
.002 w
.50541 .51591 m .5398 .50713 L .52936 .48241 L p
1 g
F P
s
P
p
.002 w
.55222 .46757 m .52936 .48241 L .5398 .50713 L p
1 g
F P
s
P
p
.002 w
.43736 .4995 m .47002 .51329 L .47573 .48713 L p
1 g
F P
s
P
p
.002 w
.47573 .48713 m .45064 .47649 L .43736 .4995 L p
1 g
F P
s
P
p
.002 w
.57813 .42053 m .5783 .3933 L .55142 .39629 L p
1 g
F P
s
P
p
.002 w
.54543 .37881 m .55142 .39629 L .5783 .3933 L p
1 g
F P
s
P
p
.002 w
.5398 .50713 m .56957 .48786 L .55222 .46757 L p
1 g
F P
s
P
p
.002 w
.56909 .44619 m .55222 .46757 L .56957 .48786 L p
1 g
F P
s
P
p
.002 w
.41652 .38076 m .41225 .40778 L .43903 .40609 L p
1 g
F P
s
P
p
.002 w
.43903 .40609 m .44196 .38781 L .41652 .38076 L p
1 g
F P
s
P
p
.002 w
.41088 .47594 m .43736 .4995 L .45064 .47649 L p
1 g
F P
s
P
p
.002 w
.45064 .47649 m .43035 .45836 L .41088 .47594 L p
1 g
F P
s
P
p
.002 w
.5783 .3933 m .56953 .36745 L .54543 .37881 L p
1 g
F P
s
P
p
.002 w
.53401 .3642 m .54543 .37881 L .56953 .36745 L p
1 g
F P
s
P
p
.002 w
.56957 .48786 m .59158 .46007 L .56909 .44619 L p
1 g
F P
s
P
p
.002 w
.57813 .42053 m .56909 .44619 L .59158 .46007 L p
1 g
F P
s
P
p
.002 w
.42947 .3565 m .41652 .38076 L .44196 .38781 L p
1 g
F P
s
P
p
.002 w
.44196 .38781 m .45075 .37143 L .42947 .3565 L p
1 g
F P
s
P
p
.002 w
.56953 .36745 m .55268 .34581 L .53401 .3642 L p
1 g
F P
s
P
p
.002 w
.51837 .35408 m .53401 .3642 L .55268 .34581 L p
1 g
F P
s
P
p
.002 w
.39348 .44505 m .41088 .47594 L .43035 .45836 L p
1 g
F P
s
P
p
.002 w
.43035 .45836 m .41706 .43461 L .39348 .44505 L p
1 g
F P
s
P
p
.002 w
.44972 .3377 m .42947 .3565 L .45075 .37143 L p
1 g
F P
s
P
p
.002 w
.45075 .37143 m .46445 .35876 L .44972 .3377 L p
1 g
F P
s
P
p
.002 w
.55268 .34581 m .52957 .33079 L .51837 .35408 L p
1 g
F P
s
P
p
.002 w
.50023 .34957 m .51837 .35408 L .52957 .33079 L p
1 g
F P
s
P
p
.002 w
.59158 .46007 m .60343 .42667 L .57813 .42053 L p
1 g
F P
s
P
p
.002 w
.5783 .3933 m .57813 .42053 L .60343 .42667 L p
1 g
F P
s
P
p
.002 w
.47507 .32648 m .44972 .3377 L .46445 .35876 L p
1 g
F P
s
P
p
.002 w
.46445 .35876 m .48157 .35119 L .47507 .32648 L p
1 g
F P
s
P
p
.002 w
.52957 .33079 m .50271 .32409 L .50023 .34957 L p
1 g
F P
s
P
p
.002 w
.48157 .35119 m .50023 .34957 L .50271 .32409 L p
1 g
F P
s
P
p
.002 w
.50271 .32409 m .47507 .32648 L .48157 .35119 L p
1 g
F P
s
P
p
.002 w
.38712 .41007 m .39348 .44505 L .41706 .43461 L p
1 g
F P
s
P
p
.002 w
.41706 .43461 m .41225 .40778 L .38712 .41007 L p
1 g
F P
s
P
p
.002 w
.5398 .50713 m .50541 .51591 L .5078 .54106 L p
1 g
F P
s
P
p
.002 w
.46495 .53791 m .5078 .54106 L .50541 .51591 L p
1 g
F P
s
P
p
.002 w
.50541 .51591 m .47002 .51329 L .46495 .53791 L p
1 g
F P
s
P
p
.002 w
.5078 .54106 m .54945 .53044 L .5398 .50713 L p
1 g
F P
s
P
p
.002 w
.56957 .48786 m .5398 .50713 L .54945 .53044 L p
1 g
F P
s
P
p
.002 w
.60343 .42667 m .60374 .39119 L .5783 .3933 L p
1 g
F P
s
P
p
.002 w
.56953 .36745 m .5783 .3933 L .60374 .39119 L p
1 g
F P
s
P
p
.002 w
.42535 .52126 m .46495 .53791 L .47002 .51329 L p
1 g
F P
s
P
p
.002 w
.47002 .51329 m .43736 .4995 L .42535 .52126 L p
1 g
F P
s
P
p
.002 w
.54945 .53044 m .58554 .50713 L .56957 .48786 L p
1 g
F P
s
P
p
.002 w
.59158 .46007 m .56957 .48786 L .58554 .50713 L p
1 g
F P
s
P
p
.002 w
.39261 .37479 m .38712 .41007 L .41225 .40778 L p
1 g
F P
s
P
p
.002 w
.41225 .40778 m .41652 .38076 L .39261 .37479 L p
1 g
F P
s
P
p
.002 w
.39321 .49277 m .42535 .52126 L .43736 .4995 L p
1 g
F P
s
P
p
.002 w
.43736 .4995 m .41088 .47594 L .39321 .49277 L p
1 g
F P
s
P
p
.002 w
.60374 .39119 m .59238 .35743 L .56953 .36745 L p
1 g
F P
s
P
p
.002 w
.55268 .34581 m .56953 .36745 L .59238 .35743 L p
1 g
F P
s
P
p
.002 w
.58554 .50713 m .61226 .47351 L .59158 .46007 L p
1 g
F P
s
P
p
.002 w
.60343 .42667 m .59158 .46007 L .61226 .47351 L p
1 g
F P
s
P
p
.002 w
.40946 .34307 m .39261 .37479 L .41652 .38076 L p
1 g
F P
s
P
p
.002 w
.41652 .38076 m .42947 .3565 L .40946 .34307 L p
1 g
F P
s
P
p
.002 w
.59238 .35743 m .57046 .32913 L .55268 .34581 L p
1 g
F P
s
P
p
.002 w
.52957 .33079 m .55268 .34581 L .57046 .32913 L p
1 g
F P
s
P
p
.002 w
.37203 .45536 m .39321 .49277 L .41088 .47594 L p
1 g
F P
s
P
p
.002 w
.41088 .47594 m .39348 .44505 L .37203 .45536 L p
1 g
F P
s
P
p
.002 w
.4359 .31847 m .40946 .34307 L .42947 .3565 L p
1 g
F P
s
P
p
.002 w
.42947 .3565 m .44972 .3377 L .4359 .31847 L p
1 g
F P
s
P
p
.002 w
.61226 .47351 m .62671 .43305 L .60343 .42667 L p
1 g
F P
s
P
p
.002 w
.60374 .39119 m .60343 .42667 L .62671 .43305 L p
1 g
F P
s
P
p
.002 w
.57046 .32913 m .54029 .30945 L .52957 .33079 L p
1 g
F P
s
P
p
.002 w
.50271 .32409 m .52957 .33079 L .54029 .30945 L p
1 g
F P
s
P
p
.002 w
.46904 .30378 m .4359 .31847 L .44972 .3377 L p
1 g
F P
s
P
p
.002 w
.44972 .3377 m .47507 .32648 L .46904 .30378 L p
1 g
F P
s
P
p
.002 w
.54029 .30945 m .50519 .30066 L .50271 .32409 L p
1 g
F P
s
P
p
.002 w
.47507 .32648 m .50271 .32409 L .50519 .30066 L p
1 g
F P
s
P
p
.002 w
.50519 .30066 m .46904 .30378 L .47507 .32648 L p
1 g
F P
s
P
p
.002 w
.3642 .41293 m .37203 .45536 L .39348 .44505 L p
1 g
F P
s
P
p
.002 w
.39348 .44505 m .38712 .41007 L .3642 .41293 L p
1 g
F P
s
P
p
.002 w
.54945 .53044 m .5078 .54106 L .51007 .56407 L p
1 g
F P
s
P
p
.002 w
.46062 .56046 m .51007 .56407 L .5078 .54106 L p
1 g
F P
s
P
p
.002 w
.5078 .54106 m .46495 .53791 L .46062 .56046 L p
1 g
F P
s
P
p
.002 w
.62671 .43305 m .6272 .39 L .60374 .39119 L p
1 g
F P
s
P
p
.002 w
.59238 .35743 m .60374 .39119 L .6272 .39 L p
1 g
F P
s
P
p
.002 w
.51007 .56407 m .55811 .55182 L .54945 .53044 L p
1 g
F P
s
P
p
.002 w
.58554 .50713 m .54945 .53044 L .55811 .55182 L p
1 g
F P
s
P
p
.002 w
.41492 .5413 m .46062 .56046 L .46495 .53791 L p
1 g
F P
s
P
p
.002 w
.46495 .53791 m .42535 .52126 L .41492 .5413 L p
1 g
F P
s
P
p
.002 w
.37078 .37007 m .3642 .41293 L .38712 .41007 L p
1 g
F P
s
P
p
.002 w
.38712 .41007 m .39261 .37479 L .37078 .37007 L p
1 g
F P
s
P
p
.002 w
.55811 .55182 m .59977 .52496 L .58554 .50713 L p
1 g
F P
s
P
p
.002 w
.61226 .47351 m .58554 .50713 L .59977 .52496 L p
1 g
F P
s
P
p
.002 w
.37776 .50849 m .41492 .5413 L .42535 .52126 L p
1 g
F P
s
P
p
.002 w
.42535 .52126 m .39321 .49277 L .37776 .50849 L p
1 g
F P
s
P
p
.002 w
.6272 .39 m .6135 .34899 L .59238 .35743 L p
1 g
F P
s
P
p
.002 w
.57046 .32913 m .59238 .35743 L .6135 .34899 L p
1 g
F P
s
P
p
.002 w
.59977 .52496 m .63067 .48622 L .61226 .47351 L p
1 g
F P
s
P
p
.002 w
.62671 .43305 m .61226 .47351 L .63067 .48622 L p
1 g
F P
s
P
p
.002 w
.39119 .33148 m .37078 .37007 L .39261 .37479 L p
1 g
F P
s
P
p
.002 w
.39261 .37479 m .40946 .34307 L .39119 .33148 L p
1 g
F P
s
P
p
.002 w
.6135 .34899 m .58693 .31455 L .57046 .32913 L p
1 g
F P
s
P
p
.002 w
.54029 .30945 m .57046 .32913 L .58693 .31455 L p
1 g
F P
s
P
p
.002 w
.3532 .46533 m .37776 .50849 L .39321 .49277 L p
1 g
F P
s
P
p
.002 w
.39321 .49277 m .37203 .45536 L .3532 .46533 L p
1 g
F P
s
P
p
.002 w
.42332 .30153 m .39119 .33148 L .40946 .34307 L p
1 g
F P
s
P
p
.002 w
.40946 .34307 m .4359 .31847 L .42332 .30153 L p
1 g
F P
s
P
p
.002 w
.63067 .48622 m .64744 .43954 L .62671 .43305 L p
1 g
F P
s
P
p
.002 w
.6272 .39 m .62671 .43305 L .64744 .43954 L p
1 g
F P
s
P
p
.002 w
.58693 .31455 m .55029 .29058 L .54029 .30945 L p
1 g
F P
s
P
p
.002 w
.50519 .30066 m .54029 .30945 L .55029 .29058 L p
1 g
F P
s
P
p
.002 w
.46362 .28363 m .42332 .30153 L .4359 .31847 L p
1 g
F P
s
P
p
.002 w
.4359 .31847 m .46904 .30378 L .46362 .28363 L p
1 g
F P
s
P
p
.002 w
.55029 .29058 m .5076 .27985 L .50519 .30066 L p
1 g
F P
s
P
p
.002 w
.46904 .30378 m .50519 .30066 L .5076 .27985 L p
1 g
F P
s
P
p
.002 w
.34406 .41633 m .3532 .46533 L .37203 .45536 L p
1 g
F P
s
P
p
.002 w
.37203 .45536 m .3642 .41293 L .34406 .41633 L p
1 g
F P
s
P
p
.002 w
.5076 .27985 m .46362 .28363 L .46904 .30378 L p
1 g
F P
s
P
p
.002 w
.64744 .43954 m .64811 .38982 L .6272 .39 L p
1 g
F P
s
P
p
.002 w
.6135 .34899 m .6272 .39 L .64811 .38982 L p
1 g
F P
s
P
p
.002 w
.55811 .55182 m .51007 .56407 L .51214 .58436 L p
1 g
F P
s
P
p
.002 w
.45717 .58037 m .51214 .58436 L .51007 .56407 L p
1 g
F P
s
P
p
.002 w
.51007 .56407 m .46062 .56046 L .45717 .58037 L p
1 g
F P
s
P
p
.002 w
.51214 .58436 m .56554 .57075 L .55811 .55182 L p
1 g
F P
s
P
p
.002 w
.59977 .52496 m .55811 .55182 L .56554 .57075 L p
1 g
F P
s
P
p
.002 w
.40633 .55914 m .45717 .58037 L .46062 .56046 L p
1 g
F P
s
P
p
.002 w
.46062 .56046 m .41492 .5413 L .40633 .55914 L p
1 g
F P
s
P
p
.002 w
.35157 .36675 m .34406 .41633 L .3642 .41293 L p
1 g
F P
s
P
p
.002 w
.3642 .41293 m .37078 .37007 L .35157 .36675 L p
1 g
F P
s
P
p
.002 w
.56554 .57075 m .61188 .54093 L .59977 .52496 L p
1 g
F P
s
P
p
.002 w
.63067 .48622 m .59977 .52496 L .61188 .54093 L p
1 g
F P
s
P
p
.002 w
.36496 .52271 m .40633 .55914 L .41492 .5413 L p
1 g
F P
s
P
p
.002 w
.41492 .5413 m .37776 .50849 L .36496 .52271 L p
1 g
F P
s
P
p
.002 w
.64811 .38982 m .63237 .34238 L .6135 .34899 L p
1 g
F P
s
P
p
.002 w
.58693 .31455 m .6135 .34899 L .63237 .34238 L p
1 g
F P
s
P
p
.002 w
.61188 .54093 m .6463 .4979 L .63067 .48622 L p
1 g
F P
s
P
p
.002 w
.64744 .43954 m .63067 .48622 L .6463 .4979 L p
1 g
F P
s
P
p
.002 w
.37512 .32207 m .35157 .36675 L .37078 .37007 L p
1 g
F P
s
P
p
.002 w
.37078 .37007 m .39119 .33148 L .37512 .32207 L p
1 g
F P
s
P
p
.002 w
.63237 .34238 m .6017 .30249 L .58693 .31455 L p
1 g
F P
s
P
p
.002 w
.55029 .29058 m .58693 .31455 L .6017 .30249 L p
1 g
F P
s
P
p
.002 w
.33755 .47474 m .36496 .52271 L .37776 .50849 L p
1 g
F P
s
P
p
.002 w
.37776 .50849 m .3532 .46533 L .33755 .47474 L p
1 g
F P
s
P
p
.002 w
.41228 .28735 m .37512 .32207 L .39119 .33148 L p
1 g
F P
s
P
p
.002 w
.39119 .33148 m .42332 .30153 L .41228 .28735 L p
1 g
F P
s
P
p
.002 w
.6463 .4979 m .66504 .44601 L .64744 .43954 L p
1 g
F P
s
P
p
.002 w
.64811 .38982 m .64744 .43954 L .66504 .44601 L p
1 g
F P
s
P
p
.002 w
.6017 .30249 m .55933 .27469 L .55029 .29058 L p
1 g
F P
s
P
p
.002 w
.5076 .27985 m .55029 .29058 L .55933 .27469 L p
1 g
F P
s
P
p
.002 w
.45896 .2666 m .41228 .28735 L .42332 .30153 L p
1 g
F P
s
P
p
.002 w
.42332 .30153 m .46362 .28363 L .45896 .2666 L p
1 g
F P
s
P
p
.002 w
.55933 .27469 m .5099 .26222 L .5076 .27985 L p
1 g
F P
s
P
p
.002 w
.46362 .28363 m .5076 .27985 L .5099 .26222 L p
1 g
F P
s
P
p
.002 w
.32728 .42022 m .33755 .47474 L .3532 .46533 L p
1 g
F P
s
P
p
.002 w
.3532 .46533 m .34406 .41633 L .32728 .42022 L p
1 g
F P
s
P
p
.002 w
.5099 .26222 m .45896 .2666 L .46362 .28363 L p
1 g
F P
s
P
p
.002 w
.66504 .44601 m .66589 .39068 L .64811 .38982 L p
1 g
F P
s
P
p
.002 w
.63237 .34238 m .64811 .38982 L .66589 .39068 L p
1 g
F P
s
P
p
.002 w
.56554 .57075 m .51214 .58436 L .51397 .60136 L p
1 g
F P
s
P
p
.002 w
.45472 .59709 m .51397 .60136 L .51214 .58436 L p
1 g
F P
s
P
p
.002 w
.51214 .58436 m .45717 .58037 L .45472 .59709 L p
1 g
F P
s
P
p
.002 w
.51397 .60136 m .57154 .5867 L .56554 .57075 L p
1 g
F P
s
P
p
.002 w
.61188 .54093 m .56554 .57075 L .57154 .5867 L p
1 g
F P
s
P
p
.002 w
.39988 .57425 m .45472 .59709 L .45717 .58037 L p
1 g
F P
s
P
p
.002 w
.45717 .58037 m .40633 .55914 L .39988 .57425 L p
1 g
F P
s
P
p
.002 w
.33555 .36498 m .32728 .42022 L .34406 .41633 L p
1 g
F P
s
P
p
.002 w
.34406 .41633 m .35157 .36675 L .33555 .36498 L p
1 g
F P
s
P
p
.002 w
.57154 .5867 m .62151 .5546 L .61188 .54093 L p
1 g
F P
s
P
p
.002 w
.6463 .4979 m .61188 .54093 L .62151 .5546 L p
1 g
F P
s
P
p
.002 w
.66589 .39068 m .64845 .33784 L .63237 .34238 L p
1 g
F P
s
P
p
.002 w
.6017 .30249 m .63237 .34238 L .64845 .33784 L p
1 g
F P
s
P
p
.002 w
.35522 .53503 m .39988 .57425 L .40633 .55914 L p
1 g
F P
s
P
p
.002 w
.40633 .55914 m .36496 .52271 L .35522 .53503 L p
1 g
F P
s
P
p
.002 w
.62151 .5546 m .65867 .50824 L .6463 .4979 L p
1 g
F P
s
P
p
.002 w
.66504 .44601 m .6463 .4979 L .65867 .50824 L p
1 g
F P
s
P
p
.002 w
.36174 .31515 m .33555 .36498 L .35157 .36675 L p
1 g
F P
s
P
p
.002 w
.35157 .36675 m .37512 .32207 L .36174 .31515 L p
1 g
F P
s
P
p
.002 w
.64845 .33784 m .61435 .29334 L .6017 .30249 L p
1 g
F P
s
P
p
.002 w
.55933 .27469 m .6017 .30249 L .61435 .29334 L p
1 g
F P
s
P
p
.002 w
.32559 .48334 m .35522 .53503 L .36496 .52271 L p
1 g
F P
s
P
p
.002 w
.36496 .52271 m .33755 .47474 L .32559 .48334 L p
1 g
F P
s
P
p
.002 w
.40314 .2764 m .36174 .31515 L .37512 .32207 L p
1 g
F P
s
P
p
.002 w
.37512 .32207 m .41228 .28735 L .40314 .2764 L p
1 g
F P
s
P
p
.002 w
.65867 .50824 m .67896 .45231 L .66504 .44601 L p
1 g
F P
s
P
p
.002 w
.66589 .39068 m .66504 .44601 L .67896 .45231 L p
1 g
F P
s
P
p
.002 w
.61435 .29334 m .56715 .2623 L .55933 .27469 L p
1 g
F P
s
P
p
.002 w
.5099 .26222 m .55933 .27469 L .56715 .2623 L p
1 g
F P
s
P
p
.002 w
.4552 .25324 m .40314 .2764 L .41228 .28735 L p
1 g
F P
s
P
p
.002 w
.41228 .28735 m .45896 .2666 L .4552 .25324 L p
1 g
F P
s
P
p
.002 w
.31442 .42452 m .32559 .48334 L .33755 .47474 L p
1 g
F P
s
P
p
.002 w
.33755 .47474 m .32728 .42022 L .31442 .42452 L p
1 g
F P
s
P
p
.002 w
.56715 .2623 m .51202 .24836 L .5099 .26222 L p
1 g
F P
s
P
p
.002 w
.45896 .2666 m .5099 .26222 L .51202 .24836 L p
1 g
F P
s
P
p
.002 w
.51202 .24836 m .4552 .25324 L .45896 .2666 L p
1 g
F P
s
P
p
.002 w
.67896 .45231 m .67995 .39263 L .66589 .39068 L p
1 g
F P
s
P
p
.002 w
.64845 .33784 m .66589 .39068 L .67995 .39263 L p
1 g
F P
s
P
p
.002 w
.57154 .5867 m .51397 .60136 L .5155 .61451 L p
1 g
F P
s
P
p
.002 w
.45336 .61005 m .5155 .61451 L .51397 .60136 L p
1 g
F P
s
P
p
.002 w
.51397 .60136 m .45472 .59709 L .45336 .61005 L p
1 g
F P
s
P
p
.002 w
.5155 .61451 m .57587 .59914 L .57154 .5867 L p
1 g
F P
s
P
p
.002 w
.62151 .5546 m .57154 .5867 L .57587 .59914 L p
1 g
F P
s
P
p
.002 w
.39585 .58613 m .45336 .61005 L .45472 .59709 L p
1 g
F P
s
P
p
.002 w
.45472 .59709 m .39988 .57425 L .39585 .58613 L p
1 g
F P
s
P
p
.002 w
.32328 .36488 m .31442 .42452 L .32728 .42022 L p
1 g
F P
s
P
p
.002 w
.32728 .42022 m .33555 .36498 L .32328 .36488 L p
1 g
F P
s
P
p
.002 w
.57587 .59914 m .62829 .5655 L .62151 .5546 L p
1 g
F P
s
P
p
.002 w
.65867 .50824 m .62151 .5546 L .62829 .5655 L p
1 g
F P
s
P
p
.002 w
.67995 .39263 m .66121 .33557 L .64845 .33784 L p
1 g
F P
s
P
p
.002 w
.61435 .29334 m .64845 .33784 L .66121 .33557 L p
1 g
F P
s
P
p
.002 w
.34897 .54505 m .39585 .58613 L .39988 .57425 L p
1 g
F P
s
P
p
.002 w
.39988 .57425 m .35522 .53503 L .34897 .54505 L p
1 g
F P
s
P
p
.002 w
.62829 .5655 m .6673 .51691 L .65867 .50824 L p
1 g
F P
s
P
p
.002 w
.67896 .45231 m .65867 .50824 L .6673 .51691 L p
1 g
F P
s
P
p
.002 w
.35152 .31104 m .32328 .36488 L .33555 .36498 L p
1 g
F P
s
P
p
.002 w
.33555 .36498 m .36174 .31515 L .35152 .31104 L p
1 g
F P
s
P
p
.002 w
.31783 .49086 m .34897 .54505 L .35522 .53503 L p
1 g
F P
s
P
p
.002 w
.35522 .53503 m .32559 .48334 L .31783 .49086 L p
1 g
F P
s
P
p
.002 w
.66121 .33557 m .62444 .2875 L .61435 .29334 L p
1 g
F P
s
P
p
.002 w
.56715 .2623 m .61435 .29334 L .62444 .2875 L p
1 g
F P
s
P
p
.002 w
.39624 .26915 m .35152 .31104 L .36174 .31515 L p
1 g
F P
s
P
p
.002 w
.36174 .31515 m .40314 .2764 L .39624 .26915 L p
1 g
F P
s
P
p
.002 w
.6673 .51691 m .68863 .45828 L .67896 .45231 L p
1 g
F P
s
P
p
.002 w
.67995 .39263 m .67896 .45231 L .68863 .45828 L p
1 g
F P
s
P
p
.002 w
.62444 .2875 m .57348 .25392 L .56715 .2623 L p
1 g
F P
s
P
p
.002 w
.51202 .24836 m .56715 .2623 L .57348 .25392 L p
1 g
F P
s
P
p
.002 w
.45249 .24411 m .39624 .26915 L .40314 .2764 L p
1 g
F P
s
P
p
.002 w
.40314 .2764 m .4552 .25324 L .45249 .24411 L p
1 g
F P
s
P
p
.002 w
.30606 .42917 m .31783 .49086 L .32559 .48334 L p
1 g
F P
s
P
p
.002 w
.32559 .48334 m .31442 .42452 L .30606 .42917 L p
1 g
F P
s
P
p
.002 w
.57348 .25392 m .51391 .23884 L .51202 .24836 L p
1 g
F P
s
P
p
.002 w
.4552 .25324 m .51202 .24836 L .51391 .23884 L p
1 g
F P
s
P
p
.002 w
.51391 .23884 m .45249 .24411 L .4552 .25324 L p
1 g
F P
s
P
p
.002 w
.68863 .45828 m .68974 .39568 L .67995 .39263 L p
1 g
F P
s
P
p
.002 w
.66121 .33557 m .67995 .39263 L .68974 .39568 L p
1 g
F P
s
P
p
.002 w
.57587 .59914 m .5155 .61451 L .51667 .62322 L p
1 g
F P
s
P
p
.002 w
.45322 .61868 m .51667 .62322 L .5155 .61451 L p
1 g
F P
s
P
p
.002 w
.5155 .61451 m .45336 .61005 L .45322 .61868 L p
1 g
F P
s
P
p
.002 w
.51667 .62322 m .57833 .60753 L .57587 .59914 L p
1 g
F P
s
P
p
.002 w
.62829 .5655 m .57587 .59914 L .57833 .60753 L p
1 g
F P
s
P
p
.002 w
.39447 .59429 m .45322 .61868 L .45336 .61005 L p
1 g
F P
s
P
p
.002 w
.45336 .61005 m .39585 .58613 L .39447 .59429 L p
1 g
F P
s
P
p
.002 w
.31531 .36657 m .30606 .42917 L .31442 .42452 L p
1 g
F P
s
P
p
.002 w
.31442 .42452 m .32328 .36488 L .31531 .36657 L p
1 g
F P
s
P
p
.002 w
.57833 .60753 m .63188 .57319 L .62829 .5655 L p
1 g
F P
s
P
p
.002 w
.6673 .51691 m .62829 .5655 L .63188 .57319 L p
1 g
F P
s
P
p
.002 w
.68974 .39568 m .67013 .3358 L .66121 .33557 L p
1 g
F P
s
P
p
.002 w
.62444 .2875 m .66121 .33557 L .67013 .3358 L p
1 g
F P
s
P
p
.002 w
.34658 .55236 m .39447 .59429 L .39585 .58613 L p
1 g
F P
s
P
p
.002 w
.39585 .58613 m .34897 .54505 L .34658 .55236 L p
1 g
F P
s
P
p
.002 w
.63188 .57319 m .67174 .5236 L .6673 .51691 L p
1 g
F P
s
P
p
.002 w
.68863 .45828 m .6673 .51691 L .67174 .5236 L p
1 g
F P
s
P
p
.002 w
.34493 .31003 m .31531 .36657 L .32328 .36488 L p
1 g
F P
s
P
p
.002 w
.32328 .36488 m .35152 .31104 L .34493 .31003 L p
1 g
F P
s
P
p
.002 w
.31475 .49705 m .34658 .55236 L .34897 .54505 L p
1 g
F P
s
P
p
.002 w
.34897 .54505 m .31783 .49086 L .31475 .49705 L p
1 g
F P
s
P
p
.002 w
.67013 .3358 m .63157 .28531 L .62444 .2875 L p
1 g
F P
s
P
p
.002 w
.57348 .25392 m .62444 .2875 L .63157 .28531 L p
1 g
F P
s
P
p
.002 w
.39188 .26602 m .34493 .31003 L .35152 .31104 L p
1 g
F P
s
P
p
.002 w
.35152 .31104 m .39624 .26915 L .39188 .26602 L p
1 g
F P
s
P
p
.002 w
.67174 .5236 m .69356 .46375 L .68863 .45828 L p
1 g
F P
s
P
p
.002 w
.68974 .39568 m .68863 .45828 L .69356 .46375 L p
1 g
F P
s
P
p
.002 w
.63157 .28531 m .57806 .25003 L .57348 .25392 L p
1 g
F P
s
P
p
.002 w
.51391 .23884 m .57348 .25392 L .57806 .25003 L p
1 g
F P
s
P
p
.002 w
.45098 .23971 m .39188 .26602 L .39624 .26915 L p
1 g
F P
s
P
p
.002 w
.39624 .26915 m .45249 .24411 L .45098 .23971 L p
1 g
F P
s
P
p
.002 w
.3027 .43406 m .31475 .49705 L .31783 .49086 L p
1 g
F P
s
P
p
.002 w
.31783 .49086 m .30606 .42917 L .3027 .43406 L p
1 g
F P
s
P
p
.002 w
.57806 .25003 m .5155 .23418 L .51391 .23884 L p
1 g
F P
s
P
p
.002 w
.45249 .24411 m .51391 .23884 L .5155 .23418 L p
1 g
F P
s
P
p
.002 w
.5155 .23418 m .45098 .23971 L .45249 .24411 L p
1 g
F P
s
P
p
.002 w
.69356 .46375 m .69472 .39982 L .68974 .39568 L p
1 g
F P
s
P
p
.002 w
.67013 .3358 m .68974 .39568 L .69472 .39982 L p
1 g
F P
s
P
p
.002 w
.57833 .60753 m .51667 .62322 L .51744 .627 L p
1 g
F P
s
P
p
.002 w
.45436 .62249 m .51744 .627 L .51667 .62322 L p
1 g
F P
s
P
p
.002 w
.51667 .62322 m .45322 .61868 L .45436 .62249 L p
1 g
F P
s
P
p
.002 w
.51744 .627 m .57874 .6114 L .57833 .60753 L p
1 g
F P
s
P
p
.002 w
.63188 .57319 m .57833 .60753 L .57874 .6114 L p
1 g
F P
s
P
p
.002 w
.39596 .59825 m .45436 .62249 L .45322 .61868 L p
1 g
F P
s
P
p
.002 w
.45322 .61868 m .39447 .59429 L .39596 .59825 L p
1 g
F P
s
P
p
.002 w
.31213 .37012 m .3027 .43406 L .30606 .42917 L p
1 g
F P
s
P
p
.002 w
.30606 .42917 m .31531 .36657 L .31213 .37012 L p
1 g
F P
s
P
p
.002 w
.57874 .6114 m .63197 .57727 L .63188 .57319 L p
1 g
F P
s
P
p
.002 w
.67174 .5236 m .63188 .57319 L .63197 .57727 L p
1 g
F P
s
P
p
.002 w
.69472 .39982 m .67471 .33866 L .67013 .3358 L p
1 g
F P
s
P
p
.002 w
.63157 .28531 m .67013 .3358 L .67471 .33866 L p
1 g
F P
s
P
p
.002 w
.34836 .5566 m .39596 .59825 L .39447 .59429 L p
1 g
F P
s
P
p
.002 w
.39447 .59429 m .34658 .55236 L .34836 .5566 L p
1 g
F P
s
P
p
.002 w
.63197 .57727 m .67159 .528 L .67174 .5236 L p
1 g
F P
s
P
p
.002 w
.69356 .46375 m .67174 .5236 L .67159 .528 L p
1 g
F P
s
P
p
.002 w
.34239 .31235 m .31213 .37012 L .31531 .36657 L p
1 g
F P
s
P
p
.002 w
.31531 .36657 m .34493 .31003 L .34239 .31235 L p
1 g
F P
s
P
p
.004 w
.43441 .63161 m
.43686 .62412 L
s
P
p
.004 w
.41164 .70145 m
.43441 .63161 L
s
P
p
.002 w
.31674 .50164 m .34836 .5566 L .34658 .55236 L p
1 g
F P
s
P
p
.002 w
.34658 .55236 m .31475 .49705 L .31674 .50164 L p
1 g
F P
s
P
p
.002 w
.67471 .33866 m .63533 .28708 L .63157 .28531 L p
1 g
F P
s
P
p
.002 w
.57806 .25003 m .63157 .28531 L .63533 .28708 L p
1 g
F P
s
P
p
.002 w
.39037 .26738 m .34239 .31235 L .34493 .31003 L p
1 g
F P
s
P
p
.002 w
.34493 .31003 m .39188 .26602 L .39037 .26738 L p
1 g
F P
s
P
p
.002 w
.67159 .528 m .69328 .46852 L .69356 .46375 L p
1 g
F P
s
P
p
.002 w
.69472 .39982 m .69356 .46375 L .69328 .46852 L p
1 g
F P
s
P
p
.002 w
.63533 .28708 m .58066 .25103 L .57806 .25003 L p
1 g
F P
s
P
p
.002 w
.5155 .23418 m .57806 .25003 L .58066 .25103 L p
1 g
F P
s
P
p
.002 w
.30478 .43906 m .31674 .50164 L .31475 .49705 L p
1 g
F P
s
P
p
.002 w
.31475 .49705 m .3027 .43406 L .30478 .43906 L p
1 g
F P
s
P
p
.002 w
.45077 .24048 m .39037 .26738 L .39188 .26602 L p
1 g
F P
s
P
p
.002 w
.39188 .26602 m .45098 .23971 L .45077 .24048 L p
1 g
F P
s
P
p
.002 w
.58066 .25103 m .51673 .23483 L .5155 .23418 L p
1 g
F P
s
P
p
.002 w
.45098 .23971 m .5155 .23418 L .51673 .23483 L p
1 g
F P
s
P
p
.002 w
.51673 .23483 m .45077 .24048 L .45098 .23971 L p
1 g
F P
s
P
p
.002 w
.69328 .46852 m .69444 .40501 L .69472 .39982 L p
1 g
F P
s
P
p
.002 w
.67471 .33866 m .69472 .39982 L .69444 .40501 L p
1 g
F P
s
P
p
.002 w
.57874 .6114 m .51744 .627 L .51775 .62539 L p
1 g
F P
s
P
p
.002 w
.45684 .62104 m .51775 .62539 L .51744 .627 L p
1 g
F P
s
P
p
.002 w
.51744 .627 m .45436 .62249 L .45684 .62104 L p
1 g
F P
s
P
p
.002 w
.51775 .62539 m .57693 .61033 L .57874 .6114 L p
1 g
F P
s
P
p
.002 w
.63197 .57727 m .57874 .6114 L .57693 .61033 L p
1 g
F P
s
P
p
.002 w
.31416 .37554 m .30478 .43906 L .3027 .43406 L p
1 g
F P
s
P
p
.002 w
.3027 .43406 m .31213 .37012 L .31416 .37554 L p
1 g
F P
s
P
p
.002 w
.40047 .59763 m .45684 .62104 L .45436 .62249 L p
1 g
F P
s
P
p
.002 w
.45436 .62249 m .39596 .59825 L .40047 .59763 L p
1 g
F P
s
P
p
.002 w
.57693 .61033 m .62833 .57738 L .63197 .57727 L p
1 g
F P
s
P
p
.002 w
.67159 .528 m .63197 .57727 L .62833 .57738 L p
1 g
F P
s
P
p
.002 w
.69444 .40501 m .67455 .34425 L .67471 .33866 L p
1 g
F P
s
P
p
.002 w
.63533 .28708 m .67471 .33866 L .67455 .34425 L p
1 g
F P
s
P
p
.002 w
.35455 .55742 m .40047 .59763 L .39596 .59825 L p
1 g
F P
s
P
p
.002 w
.39596 .59825 m .34836 .5566 L .35455 .55742 L p
1 g
F P
s
P
p
.002 w
.62833 .57738 m .66656 .52981 L .67159 .528 L p
1 g
F P
s
P
p
.002 w
.69328 .46852 m .67159 .528 L .66656 .52981 L p
1 g
F P
s
P
p
.002 w
.34425 .31815 m .31416 .37554 L .31213 .37012 L p
1 g
F P
s
P
p
.002 w
.31213 .37012 m .34239 .31235 L .34425 .31815 L p
1 g
F P
s
P
p
.002 w
.32407 .5044 m .35455 .55742 L .34836 .5566 L p
1 g
F P
s
P
p
.002 w
.34836 .5566 m .31674 .50164 L .32407 .5044 L p
1 g
F P
s
P
p
.002 w
.67455 .34425 m .6354 .29302 L .63533 .28708 L p
1 g
F P
s
P
p
.002 w
.58066 .25103 m .63533 .28708 L .6354 .29302 L p
1 g
F P
s
P
p
.002 w
.39194 .27347 m .34425 .31815 L .34239 .31235 L p
1 g
F P
s
P
p
.002 w
.34239 .31235 m .39037 .26738 L .39194 .27347 L p
1 g
F P
s
P
p
.002 w
.66656 .52981 m .68746 .47242 L .69328 .46852 L p
1 g
F P
s
P
p
.002 w
.69444 .40501 m .69328 .46852 L .68746 .47242 L p
1 g
F P
s
P
p
.002 w
.6354 .29302 m .58107 .25722 L .58066 .25103 L p
1 g
F P
s
P
p
.002 w
.51673 .23483 m .58066 .25103 L .58107 .25722 L p
1 g
F P
s
P
p
.002 w
.31257 .44403 m .32407 .5044 L .31674 .50164 L p
1 g
F P
s
P
p
.002 w
.31674 .50164 m .30478 .43906 L .31257 .44403 L p
1 g
F P
s
P
p
.002 w
.45197 .24675 m .39194 .27347 L .39037 .26738 L p
1 g
F P
s
P
p
.002 w
.39037 .26738 m .45077 .24048 L .45197 .24675 L p
1 g
F P
s
P
p
.002 w
.58107 .25722 m .51752 .24113 L .51673 .23483 L p
1 g
F P
s
P
p
.002 w
.45077 .24048 m .51673 .23483 L .51752 .24113 L p
1 g
F P
s
P
p
.002 w
.51752 .24113 m .45197 .24675 L .45077 .24048 L p
1 g
F P
s
P
p
.002 w
.68746 .47242 m .68854 .41116 L .69444 .40501 L p
1 g
F P
s
P
p
.002 w
.67455 .34425 m .69444 .40501 L .68854 .41116 L p
1 g
F P
s
P
p
.002 w
.57693 .61033 m .51775 .62539 L .51756 .61809 L p
1 g
F P
s
P
p
.002 w
.46068 .61402 m .51756 .61809 L .51775 .62539 L p
1 g
F P
s
P
p
.002 w
.51775 .62539 m .45684 .62104 L .46068 .61402 L p
1 g
F P
s
P
p
.002 w
.51756 .61809 m .57283 .60403 L .57693 .61033 L p
1 g
F P
s
P
p
.002 w
.62833 .57738 m .57693 .61033 L .57283 .60403 L p
1 g
F P
s
P
p
.002 w
.32168 .38279 m .31257 .44403 L .30478 .43906 L p
1 g
F P
s
P
p
.002 w
.30478 .43906 m .31416 .37554 L .32168 .38279 L p
1 g
F P
s
P
p
.002 w
.40807 .59214 m .46068 .61402 L .45684 .62104 L p
1 g
F P
s
P
p
.002 w
.45684 .62104 m .40047 .59763 L .40807 .59214 L p
1 g
F P
s
P
p
.004 w
.43686 .62412 m
.43908 .6173 L
s
P
p
.002 w
.57283 .60403 m .62081 .57324 L .62833 .57738 L p
1 g
F P
s
P
p
.002 w
.66656 .52981 m .62833 .57738 L .62081 .57324 L p
1 g
F P
s
P
p
.002 w
.68854 .41116 m .66932 .35258 L .67455 .34425 L p
1 g
F P
s
P
p
.002 w
.6354 .29302 m .67455 .34425 L .66932 .35258 L p
1 g
F P
s
P
p
.002 w
.36524 .55459 m .40807 .59214 L .40047 .59763 L p
1 g
F P
s
P
p
.002 w
.40047 .59763 m .35455 .55742 L .36524 .55459 L p
1 g
F P
s
P
p
.002 w
.62081 .57324 m .65647 .52882 L .66656 .52981 L p
1 g
F P
s
P
p
.002 w
.68746 .47242 m .66656 .52981 L .65647 .52882 L p
1 g
F P
s
P
p
.002 w
.35073 .32748 m .32168 .38279 L .31416 .37554 L p
1 g
F P
s
P
p
.002 w
.31416 .37554 m .34425 .31815 L .35073 .32748 L p
1 g
F P
s
P
p
.002 w
.33686 .5051 m .36524 .55459 L .35455 .55742 L p
1 g
F P
s
P
p
.002 w
.35455 .55742 m .32407 .5044 L .33686 .5051 L p
1 g
F P
s
P
p
.002 w
.66932 .35258 m .63153 .30322 L .6354 .29302 L p
1 g
F P
s
P
p
.002 w
.58107 .25722 m .6354 .29302 L .63153 .30322 L p
1 g
F P
s
P
p
.002 w
.65647 .52882 m .67592 .47526 L .68746 .47242 L p
1 g
F P
s
P
p
.002 w
.68854 .41116 m .68746 .47242 L .67592 .47526 L p
1 g
F P
s
P
p
.002 w
.39674 .28443 m .35073 .32748 L .34425 .31815 L p
1 g
F P
s
P
p
.002 w
.34425 .31815 m .39194 .27347 L .39674 .28443 L p
1 g
F P
s
P
p
.002 w
.63153 .30322 m .57912 .26874 L .58107 .25722 L p
1 g
F P
s
P
p
.002 w
.51752 .24113 m .58107 .25722 L .57912 .26874 L p
1 g
F P
s
P
p
.002 w
.32622 .44881 m .33686 .5051 L .32407 .5044 L p
1 g
F P
s
P
p
.002 w
.32407 .5044 m .31257 .44403 L .32622 .44881 L p
1 g
F P
s
P
p
.002 w
.45463 .25868 m .39674 .28443 L .39194 .27347 L p
1 g
F P
s
P
p
.002 w
.39194 .27347 m .45197 .24675 L .45463 .25868 L p
1 g
F P
s
P
p
.002 w
.57912 .26874 m .51784 .25325 L .51752 .24113 L p
1 g
F P
s
P
p
.002 w
.45197 .24675 m .51752 .24113 L .51784 .25325 L p
1 g
F P
s
P
p
.002 w
.51784 .25325 m .45463 .25868 L .45197 .24675 L p
1 g
F P
s
P
p
.002 w
.67592 .47526 m .67686 .41813 L .68854 .41116 L p
1 g
F P
s
P
p
.002 w
.66932 .35258 m .68854 .41116 L .67686 .41813 L p
1 g
F P
s
P
p
.002 w
.57283 .60403 m .51756 .61809 L .51684 .60496 L p
1 g
F P
s
P
p
.002 w
.46584 .60129 m .51684 .60496 L .51756 .61809 L p
1 g
F P
s
P
p
.002 w
.51756 .61809 m .46068 .61402 L .46584 .60129 L p
1 g
F P
s
P
p
.002 w
.51684 .60496 m .56641 .59234 L .57283 .60403 L p
1 g
F P
s
P
p
.002 w
.62081 .57324 m .57283 .60403 L .56641 .59234 L p
1 g
F P
s
P
p
.002 w
.33478 .39176 m .32622 .44881 L .31257 .44403 L p
1 g
F P
s
P
p
.002 w
.31257 .44403 m .32168 .38279 L .33478 .39176 L p
1 g
F P
s
P
p
.002 w
.41869 .58165 m .46584 .60129 L .46068 .61402 L p
1 g
F P
s
P
p
.002 w
.46068 .61402 m .40807 .59214 L .41869 .58165 L p
1 g
F P
s
P
p
.004 w
.44111 .61108 m
.44328 .60443 L
s
P
p
.004 w
.43908 .6173 m
.44111 .61108 L
s
P
p
.004 w
.44688 .59339 m
.5 .43051 L
s
P
p
.004 w
.44328 .60443 m
.44372 .60309 L
s
P
p
.002 w
.56641 .59234 m .60941 .56472 L .62081 .57324 L p
1 g
F P
s
P
p
.002 w
.65647 .52882 m .62081 .57324 L .60941 .56472 L p
1 g
F P
s
P
p
.002 w
.67686 .41813 m .65887 .36357 L .66932 .35258 L p
1 g
F P
s
P
p
.002 w
.63153 .30322 m .66932 .35258 L .65887 .36357 L p
1 g
F P
s
P
p
.002 w
.38037 .54795 m .41869 .58165 L .40807 .59214 L p
1 g
F P
s
P
p
.002 w
.40807 .59214 m .36524 .55459 L .38037 .54795 L p
1 g
F P
s
P
p
.002 w
.60941 .56472 m .64133 .52488 L .65647 .52882 L p
1 g
F P
s
P
p
.002 w
.67592 .47526 m .65647 .52882 L .64133 .52488 L p
1 g
F P
s
P
p
.002 w
.36192 .34026 m .33478 .39176 L .32168 .38279 L p
1 g
F P
s
P
p
.002 w
.32168 .38279 m .35073 .32748 L .36192 .34026 L p
1 g
F P
s
P
p
.002 w
.35504 .50361 m .38037 .54795 L .36524 .55459 L p
1 g
F P
s
P
p
.002 w
.36524 .55459 m .33686 .5051 L .35504 .50361 L p
1 g
F P
s
P
p
.002 w
.65887 .36357 m .6236 .31761 L .63153 .30322 L p
1 g
F P
s
P
p
.002 w
.57912 .26874 m .63153 .30322 L .6236 .31761 L p
1 g
F P
s
P
p
.002 w
.64133 .52488 m .65869 .47689 L .67592 .47526 L p
1 g
F P
s
P
p
.002 w
.67686 .41813 m .67592 .47526 L .65869 .47689 L p
1 g
F P
s
P
p
.002 w
.40482 .3002 m .36192 .34026 L .35073 .32748 L p
1 g
F P
s
P
p
.002 w
.35073 .32748 m .39674 .28443 L .40482 .3002 L p
1 g
F P
s
P
p
.002 w
.6236 .31761 m .57473 .28555 L .57912 .26874 L p
1 g
F P
s
P
p
.002 w
.51784 .25325 m .57912 .26874 L .57473 .28555 L p
1 g
F P
s
P
p
.002 w
.34561 .45323 m .35504 .50361 L .33686 .5051 L p
1 g
F P
s
P
p
.002 w
.33686 .5051 m .32622 .44881 L .34561 .45323 L p
1 g
F P
s
P
p
.002 w
.45876 .27623 m .40482 .3002 L .39674 .28443 L p
1 g
F P
s
P
p
.002 w
.39674 .28443 m .45463 .25868 L .45876 .27623 L p
1 g
F P
s
P
p
.002 w
.57473 .28555 m .51764 .27116 L .51784 .25325 L p
1 g
F P
s
P
p
.002 w
.45463 .25868 m .51784 .25325 L .51764 .27116 L p
1 g
F P
s
P
p
.002 w
.51764 .27116 m .45876 .27623 L .45463 .25868 L p
1 g
F P
s
P
p
.002 w
.65869 .47689 m .65944 .42576 L .67686 .41813 L p
1 g
F P
s
P
p
.002 w
.65887 .36357 m .67686 .41813 L .65944 .42576 L p
1 g
F P
s
P
p
.002 w
.56641 .59234 m .51684 .60496 L .51559 .58608 L p
1 g
F P
s
P
p
.002 w
.47223 .58294 m .51559 .58608 L .51684 .60496 L p
1 g
F P
s
P
p
.002 w
.51684 .60496 m .46584 .60129 L .47223 .58294 L p
1 g
F P
s
P
p
.002 w
.51559 .58608 m .55774 .57534 L .56641 .59234 L p
1 g
F P
s
P
p
.002 w
.60941 .56472 m .56641 .59234 L .55774 .57534 L p
1 g
F P
s
P
p
.002 w
.35337 .40223 m .34561 .45323 L .32622 .44881 L p
1 g
F P
s
P
p
.002 w
.32622 .44881 m .33478 .39176 L .35337 .40223 L p
1 g
F P
s
P
p
.002 w
.43218 .5662 m .47223 .58294 L .46584 .60129 L p
1 g
F P
s
P
p
.002 w
.46584 .60129 m .41869 .58165 L .43218 .5662 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.55774 .57534 m .59428 .55183 L .60941 .56472 L p
1 g
F P
s
P
p
.002 w
.64133 .52488 m .60941 .56472 L .59428 .55183 L p
1 g
F P
s
P
p
.002 w
.65944 .42576 m .64325 .37698 L .65887 .36357 L p
1 g
F P
s
P
p
.002 w
.6236 .31761 m .65887 .36357 L .64325 .37698 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.39967 .53753 m .43218 .5662 L .41869 .58165 L p
1 g
F P
s
P
p
.002 w
.41869 .58165 m .38037 .54795 L .39967 .53753 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.59428 .55183 m .62136 .51794 L .64133 .52488 L p
1 g
F P
s
P
p
.002 w
.65869 .47689 m .64133 .52488 L .62136 .51794 L p
1 g
F P
s
P
p
.002 w
.3777 .35624 m .35337 .40223 L .33478 .39176 L p
1 g
F P
s
P
p
.002 w
.33478 .39176 m .36192 .34026 L .3777 .35624 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37825 .49985 m .39967 .53753 L .38037 .54795 L p
1 g
F P
s
P
p
.002 w
.38037 .54795 m .35504 .50361 L .37825 .49985 L p
1 g
F P
s
P
p
.002 w
.64325 .37698 m .61164 .33595 L .6236 .31761 L p
1 g
F P
s
P
p
.002 w
.57473 .28555 m .6236 .31761 L .61164 .33595 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.62136 .51794 m .63602 .47717 L .65869 .47689 L p
1 g
F P
s
P
p
.002 w
.65944 .42576 m .65869 .47689 L .63602 .47717 L p
1 g
F P
s
P
p
.002 w
.41608 .32048 m .3777 .35624 L .36192 .34026 L p
1 g
F P
s
P
p
.002 w
.36192 .34026 m .40482 .3002 L .41608 .32048 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.61164 .33595 m .56792 .30737 L .57473 .28555 L p
1 g
F P
s
P
p
.002 w
.51764 .27116 m .57473 .28555 L .56792 .30737 L p
1 g
F P
s
P
p
.002 w
.37037 .45711 m .37825 .49985 L .35504 .50361 L p
1 g
F P
s
P
p
.002 w
.35504 .50361 m .34561 .45323 L .37037 .45711 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.46429 .2991 m .41608 .32048 L .40482 .3002 L p
1 g
F P
s
P
p
.002 w
.40482 .3002 m .45876 .27623 L .46429 .2991 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.56792 .30737 m .51689 .29456 L .51764 .27116 L p
1 g
F P
s
P
p
.002 w
.45876 .27623 m .51764 .27116 L .51689 .29456 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51689 .29456 m .46429 .2991 L .45876 .27623 L p
1 g
F P
s
P
p
.002 w
.63602 .47717 m .63655 .43379 L .65944 .42576 L p
1 g
F P
s
P
p
.002 w
.64325 .37698 m .65944 .42576 L .63655 .43379 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58057 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58057 L .51376 .58 L 1 g
F
P
p
.51559 .58608 m .50879 .58101 L .51094 .58057 L 1 g
F
P
p
.002 w
.51513 .57973 m .5152 .58065 L p
.51094 .58057 L 1 g
F P
s
P
p
.002 w
.5152 .58065 m .51559 .58608 L p
.51094 .58057 L 1 g
F P
s
P
p
.002 w
.51094 .58057 m .51079 .57862 L p
.50183 .58041 L 1 g
F P
s
P
p
.53128 .57265 m .51376 .58 L .52245 .57718 L 1 g
F
P
p
.51376 .58 m .51098 .58117 L .51513 .57973 L 1 g
F
P
p
.51376 .58 m .51513 .57973 L .52245 .57718 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58019 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .58019 L .50183 .58041 L 1 g
F
P
p
.002 w
.47223 .58294 m .47421 .57666 L p
.49549 .58171 L 1 g
F P
s
P
p
.002 w
.49207 .58438 m .47223 .58294 L p
.50879 .58101 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.47223 .58294 m .46606 .57348 L .46834 .57437 L 1 g
F
P
p
.002 w
.47421 .57666 m .47377 .57806 L p
.46834 .57437 L 1 g
F P
s
P
p
.002 w
.47377 .57806 m .47223 .58294 L p
.46834 .57437 L 1 g
F P
s
P
p
.002 w
.46834 .57437 m .46872 .57265 L p
.46165 .56983 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .57437 L p
1 g
F P
s
P
p
.002 w
.47223 .58294 m .43218 .5662 L .43577 .56169 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45098 .56258 L p
1 g
F P
s
P
p
.002 w
.43577 .56169 m .44064 .55556 L p
.45159 .56328 L 1 g
F P
s
P
p
.46606 .57348 m .45764 .5702 L .45159 .56328 L 1 g
F
P
p
.45764 .5702 m .43577 .56169 L .45159 .56328 L 1 g
F
P
p
.002 w
.45098 .56258 m .45146 .56129 L p
.44479 .55549 L 1 g
F P
s
P
p
.46872 .57265 m .45098 .56258 L .46165 .56983 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4385 .54707 L p
1 g
F P
s
P
p
.43218 .5662 m .42294 .52466 L .4385 .54707 L 1 g
F
P
p
.002 w
.44265 .55304 m .44116 .55491 L p
.4385 .54707 L 1 g
F P
s
P
p
.002 w
.44116 .55491 m .43218 .5662 L p
.4385 .54707 L 1 g
F P
s
P
p
.002 w
.4385 .54707 m .43925 .54566 L p
.43551 .53826 L 1 g
F P
s
P
p
.45146 .56129 m .4385 .54707 L .4412 .55096 L 1 g
F
P
p
.45146 .56129 m .4381 .54784 L .44479 .55549 L 1 g
F
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44818 .54609 m .44265 .55304 L p
.43839 .54674 L 1 g
F P
s
P
p
.002 w
.42267 .52349 m .43386 .53339 L p
.43839 .54674 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43253 .52869 L p
1 g
F P
s
P
p
.002 w
.42267 .52349 m .42975 .51878 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43386 .53339 m .43232 .53203 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43232 .53203 m .42267 .52349 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43253 .52869 m .43346 .52734 L p
.43317 .51888 L 1 g
F P
s
P
p
.43925 .54566 m .43253 .52869 L .43316 .53092 L 1 g
F
P
p
.43925 .54566 m .43235 .52896 L .43551 .53826 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43386 .53339 m .43253 .52869 L .44868 .50619 L 1 g
F
P
p
.002 w
.42975 .51878 m .43332 .5164 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43402 .50925 L p
1 g
F P
s
P
p
.42267 .52349 m .43601 .4888 L .43402 .50925 L 1 g
F
P
p
.002 w
.43332 .5164 m .4294 .51901 L p
.43402 .50925 L 1 g
F P
s
P
p
.002 w
.4294 .51901 m .42267 .52349 L p
.43402 .50925 L 1 g
F P
s
P
p
.002 w
.43402 .50925 m .43485 .50826 L p
.43827 .50027 L 1 g
F P
s
P
p
.43346 .52734 m .43402 .50925 L .43372 .51236 L 1 g
F
P
p
.43346 .52734 m .43377 .50955 L .43317 .51888 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44868 .50619 m .43332 .5164 L p
.4343 .50865 L 1 g
F P
s
P
p
.002 w
.43719 .48572 m .44151 .49342 L p
.4343 .50865 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44248 .49147 L p
1 g
F P
s
P
p
.002 w
.43719 .48572 m .44674 .48289 L p
.44248 .49147 L 1 g
F P
s
P
p
.002 w
.44151 .49342 m .44114 .49276 L p
.44248 .49147 L 1 g
F P
s
P
p
.002 w
.44114 .49276 m .43719 .48572 L p
.44248 .49147 L 1 g
F P
s
P
p
.002 w
.44248 .49147 m .44238 .49157 L p
.44194 .49254 L 1 g
F P
s
P
p
.43485 .50826 m .44248 .49147 L .44194 .49254 L 1 g
F
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44248 .49147 m .44339 .4905 L p
.45037 .48381 L 1 g
F P
s
P
p
.43485 .50826 m .44238 .49157 L .43827 .50027 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44151 .49342 m .44248 .49147 L .47095 .47573 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45767 .47672 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47095 .47573 m .45332 .48095 L p
.45767 .47672 L 1 g
F P
s
P
p
.002 w
.45767 .47672 m .45826 .47608 L p
.47017 .47086 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52066 .49683 m .50892 .49983 L .506 .46492 L p
1 g
F P
s
P
p
.002 w
.53827 .4808 m .5308 .49025 L .5067 .46502 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53827 .4808 m .50777 .46517 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47684 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56604 .50932 L p
1 g
F P
s
P
p
.56739 .51224 m .56604 .50932 L .569 .49559 L 1 g
F
P
p
.002 w
.56312 .503 m .56534 .50021 L p
.56604 .50932 L 1 g
F P
s
P
p
.002 w
.56534 .50021 m .569 .49559 L p
.56604 .50932 L 1 g
F P
s
P
p
.002 w
.56604 .50932 m .56515 .50826 L p
.56676 .51871 L 1 g
F P
s
P
p
.55661 .4905 m .56604 .50932 L .56312 .503 L 1 g
F
P
p
.002 w
.569 .49559 m .56312 .503 L p
.55879 .49417 L 1 g
F P
s
P
p
.56278 .50231 m .56312 .503 L .56295 .50263 L 1 g
F
P
p
.55661 .4905 m .56312 .503 L .56278 .50231 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55742 .49136 m .55661 .4905 L p
.56278 .50231 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55742 .49136 L p
1 g
F P
s
P
p
.56057 .49441 m .55879 .49417 L .55742 .49136 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55742 .49136 L p
1 g
F P
s
P
p
.56278 .50231 m .56713 .51061 L .55742 .49136 L 1 g
F
P
p
.54174 .47608 m .55742 .49136 L .55466 .48869 L 1 g
F
P
p
.002 w
.55466 .48869 m .53827 .4808 L p
.54516 .47948 L 1 g
F P
s
P
p
.55033 .48449 m .55466 .48869 L .55071 .48487 L 1 g
F
P
p
.54174 .47608 m .55466 .48869 L .55033 .48449 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.57683 .47344 m .569 .49559 L .55466 .48869 L p
1 g
F P
s
P
p
.002 w
.5308 .49025 m .53827 .4808 L .55466 .48869 L p
1 g
F P
s
P
p
.002 w
.55466 .48869 m .55656 .4896 L p
.55563 .48963 L 1 g
F P
s
P
p
.55563 .48963 m .5308 .49025 L .55466 .48869 L 1 g
F
P
p
.55879 .49417 m .5308 .49025 L .55656 .4896 L 1 g
F
P
p
.002 w
.53827 .4808 m .54004 .47574 L p
.54244 .47684 L 1 g
F P
s
P
p
.54516 .47948 m .53827 .4808 L .54244 .47684 L 1 g
F
P
p
.002 w
.54253 .47695 m .54244 .47684 L p
.55071 .48487 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54174 .47608 L p
.55033 .48449 L 1 g
F P
s
P
p
.55033 .48449 m .55071 .48487 L .54244 .47684 L 1 g
F
P
p
.54729 .47908 m .54244 .47684 L .54223 .46947 L 1 g
F
P
p
.52214 .46667 m .54244 .47684 L .54106 .47621 L 1 g
F
P
p
.52214 .46667 m .54254 .47695 L .5338 .47271 L 1 g
F
P
p
.002 w
.54004 .47574 m .54036 .47482 L p
.54244 .47684 L 1 g
F P
s
P
p
.002 w
.54036 .47482 m .54223 .46947 L p
.54244 .47684 L 1 g
F P
s
P
p
.54729 .47908 m .54516 .47948 L .54244 .47684 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54253 .47695 L p
1 g
F P
s
P
p
.55071 .48487 m .55834 .49233 L .54253 .47695 L 1 g
F
P
p
.57683 .47344 m .55466 .48869 L .54516 .47948 L 1 g
F
P
p
.002 w
.55742 .49136 m .55834 .49233 L p
.55071 .48487 L 1 g
F P
s
P
p
.002 w
.55656 .4896 m .569 .49559 L p
.56057 .49441 L 1 g
F P
s
P
p
.56057 .49441 m .55742 .49136 L .55656 .4896 L 1 g
F
P
p
.002 w
.55436 .51406 m .5308 .49025 L p
.55879 .49417 L 1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56312 .503 m .55436 .51406 L p
.55879 .49417 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.57576 .5348 m .56769 .53325 L .56747 .5287 L 1 g
F
P
p
.002 w
.56737 .52667 m .56793 .52721 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56793 .52721 m .57576 .5348 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56654 .52734 L p
.56454 .53832 L 1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .56737 .52667 L 1 g
F
P
p
.59701 .5081 m .56737 .52667 L .56627 .51239 L 1 g
F
P
p
.56676 .51871 m .56737 .52667 L .56709 .52086 L 1 g
F
P
p
.56515 .50826 m .56737 .52667 L .56676 .51871 L 1 g
F
P
p
.002 w
.59701 .5081 m .57576 .5348 L .56737 .52667 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56737 .52667 m .55436 .51406 L p
.56627 .51239 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56153 .54712 L p
1 g
F P
s
P
p
.55931 .55294 m .56153 .54712 L .57576 .5348 L 1 g
F
P
p
.002 w
.56312 .54295 m .56619 .54097 L p
.56153 .54712 L 1 g
F P
s
P
p
.002 w
.56619 .54097 m .57576 .5348 L p
.56153 .54712 L 1 g
F P
s
P
p
.002 w
.57576 .5348 m .59428 .55183 L p
.55931 .55294 L 1 g
F P
s
P
p
.002 w
.56153 .54712 m .56075 .54566 L p
.5557 .55482 L 1 g
F P
s
P
p
.56654 .52734 m .56153 .54712 L .56231 .54508 L 1 g
F
P
p
.56654 .52734 m .56173 .54751 L .56454 .53832 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .563 L p
1 g
F P
s
P
p
.55774 .57534 m .54211 .57052 L .54918 .563 L 1 g
F
P
p
.002 w
.55085 .56121 m .55113 .56178 L p
.54918 .563 L 1 g
F P
s
P
p
.002 w
.55113 .56178 m .55774 .57534 L p
.54918 .563 L 1 g
F P
s
P
p
.002 w
.54918 .563 m .54854 .56129 L p
.54211 .56742 L 1 g
F P
s
P
p
.56075 .54566 m .54918 .563 L .55013 .56198 L 1 g
F
P
p
.56075 .54566 m .54928 .56329 L .5557 .55482 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53157 .57401 L p
1 g
F P
s
P
p
.54854 .56129 m .53157 .57401 L .54211 .56742 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.54918 .563 m .51383 .5618 L .55085 .56121 L 1 g
F
P
p
.54211 .57052 m .53879 .5695 L .54918 .563 L 1 g
F
P
p
.53879 .5695 m .51383 .5618 L .54918 .563 L 1 g
F
P
p
.002 w
.51559 .58608 m .49207 .58438 L p
.50879 .58101 L 1 g
F P
s
P
p
.002 w
.55774 .57534 m .51559 .58608 L .51513 .57973 L p
1 g
F P
s
P
p
.55774 .57534 m .51513 .57973 L .54183 .57044 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51513 .57973 m .51383 .5618 L p
.54183 .57044 L 1 g
F P
s
P
p
.002 w
.53157 .57401 m .5322 .57686 L p
.54211 .56742 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .563 L p
1 g
F P
s
P
p
.54211 .56742 m .5322 .57686 L .54918 .563 L 1 g
F
P
p
.002 w
.54918 .563 m .54928 .56329 L p
.55013 .56198 L 1 g
F P
s
P
p
.002 w
.51383 .5618 m .54702 .55334 L .55085 .56121 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54702 .55334 m .56312 .54295 L p
.56153 .54712 L 1 g
F P
s
P
p
.55931 .55294 m .55706 .55302 L .56153 .54712 L 1 g
F
P
p
.55706 .55302 m .54702 .55334 L .56153 .54712 L 1 g
F
P
p
.002 w
.59428 .55183 m .55774 .57534 L .54702 .55334 L p
1 g
F P
s
P
p
.002 w
.54928 .56329 m .54998 .56518 L p
.5557 .55482 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56153 .54712 L p
1 g
F P
s
P
p
.5557 .55482 m .54998 .56518 L .56153 .54712 L 1 g
F
P
p
.002 w
.56153 .54712 m .56173 .54751 L p
.56231 .54508 L 1 g
F P
s
P
p
.56747 .5287 m .53452 .52689 L .56737 .52667 L 1 g
F
P
p
.56769 .53325 m .56617 .53296 L .56747 .5287 L 1 g
F
P
p
.56617 .53296 m .53452 .52689 L .56747 .5287 L 1 g
F
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.57576 .5348 m .54702 .55334 L .53452 .52689 L p
1 g
F P
s
P
p
.002 w
.56173 .54751 m .56257 .5491 L p
.56454 .53832 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56747 .5287 L p
1 g
F P
s
P
p
.56454 .53832 m .56257 .5491 L .56747 .5287 L 1 g
F
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.56709 .52086 L 1 g
F P
s
P
p
.002 w
.53452 .52689 m .55436 .51406 L .56737 .52667 L p
1 g
F P
s
P
p
.002 w
.55436 .51406 m .56312 .503 L p
.56739 .51224 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56604 .50932 L p
1 g
F P
s
P
p
.56676 .51871 m .56854 .53025 L .56604 .50932 L 1 g
F
P
p
.002 w
.56604 .50932 m .56713 .51061 L p
.56295 .50263 L 1 g
F P
s
P
p
.002 w
.569 .49559 m .59701 .5081 L p
.56739 .51224 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54254 .47695 L p
.54106 .47621 L 1 g
F P
s
P
p
.002 w
.54223 .46947 m .57683 .47344 L p
.54729 .47908 L 1 g
F P
s
P
p
.002 w
.54004 .47574 m .53827 .4808 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.5338 .47271 L 1 g
F P
s
P
p
.5338 .47271 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.54223 .46947 m .54208 .46989 L p
.52132 .46664 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.50594 .46424 m .52077 .46638 L p
.52132 .46664 L 1 g
F P
s
P
p
.002 w
.52077 .46638 m .54223 .46947 L p
.52132 .46664 L 1 g
F P
s
P
p
.002 w
.54208 .46989 m .54004 .47574 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.54254 .47695 m .54302 .47747 L p
.5338 .47271 L 1 g
F P
s
P
p
.002 w
.52245 .46719 m .52247 .46722 L p
.52174 .46709 L 1 g
F P
s
P
p
.5 .4634 m .52245 .46719 L .52174 .46709 L 1 g
F
P
p
.5 .4634 m .52247 .46722 L .52106 .46702 L 1 g
F
P
p
.5 .4634 m .5225 .46727 L .52053 .46699 L 1 g
F
P
p
.5 .4634 m .52255 .46734 L .51495 .46623 L 1 g
F
P
p
.51497 .46628 m .52277 .46771 L .5204 .46732 L 1 g
F
P
p
.5 .4634 m .51604 .46644 L .51497 .46628 L 1 g
F
P
p
.51604 .46644 m .52277 .46771 L .51497 .46628 L 1 g
F
P
p
.002 w
.50892 .49983 m .49685 .49893 L .50577 .46489 L p
1 g
F P
s
P
p
.002 w
.506 .46492 m .50892 .49983 L p
.50577 .46489 L 1 g
F P
s
P
p
.002 w
.50777 .46517 m .53827 .4808 L p
.5067 .46502 L 1 g
F P
s
P
p
.002 w
.5308 .49025 m .52066 .49683 L .50627 .46496 L p
1 g
F P
s
P
p
.002 w
.5067 .46502 m .5308 .49025 L p
.50627 .46496 L 1 g
F P
s
P
p
.002 w
.50627 .46496 m .52066 .49683 L p
.506 .46492 L 1 g
F P
s
P
p
.47011 .47089 m .47752 .46723 L .5034 .4645 L 1 g
F
P
p
.47011 .47089 m .5034 .4645 L .50398 .4646 L 1 g
F
P
p
.002 w
.49841 .46417 m .50157 .4642 L p
.47752 .46723 L 1 g
F P
s
P
p
.47752 .46723 m .50157 .4642 L .5034 .4645 L 1 g
F
P
p
.5 .4634 m .51617 .46651 L .50016 .46397 L 1 g
F
P
p
.002 w
.5 .46394 m .5 .4634 L p
.50016 .46397 L 1 g
F P
s
P
p
.51617 .46651 m .50553 .46485 L .5 .46394 L 1 g
F
P
p
.002 w
.50553 .46485 m .48574 .49422 L p
.50519 .4648 L 1 g
F P
s
P
p
.002 w
.47678 .4862 m .47095 .47573 L .50455 .46469 L p
1 g
F P
s
P
p
.002 w
.50455 .46469 m .50594 .46424 L .50519 .4648 L p
1 g
F P
s
P
p
.002 w
.50519 .4648 m .47678 .4862 L p
.50455 .46469 L 1 g
F P
s
P
p
.50519 .4648 m .50519 .4648 L .50494 .46476 L 1 g
F
P
p
.50553 .46485 m .50538 .46483 L .50519 .4648 L 1 g
F
P
p
.50538 .46483 m .50519 .4648 L .50519 .4648 L 1 g
F
P
p
.50553 .46485 m .50494 .46476 L .5 .46394 L 1 g
F
P
p
.002 w
.48574 .49422 m .47678 .4862 L .50519 .4648 L p
1 g
F P
s
P
p
.002 w
.50519 .4648 m .50594 .46424 L .50553 .46485 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46394 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46394 L .49841 .46417 L 1 g
F
P
p
.4893 .46551 m .49841 .46417 L .48945 .46549 L 1 g
F
P
p
.47786 .46667 m .49841 .46417 L .4893 .46551 L 1 g
F
P
p
.002 w
.47752 .46723 m .47786 .46667 L p
.4893 .46551 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47737 .46748 L p
1 g
F P
s
P
p
.002 w
.47737 .46748 m .47718 .46778 L p
.47022 .47084 L 1 g
F P
s
P
p
.45826 .47608 m .47737 .46748 L .47022 .47084 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.43719 .48572 m .46918 .46554 L .45767 .47672 L 1 g
F
P
p
.44339 .4905 m .45767 .47672 L .45677 .4776 L 1 g
F
P
p
.44339 .4905 m .45762 .47678 L .45037 .48381 L 1 g
F
P
p
.002 w
.45332 .48095 m .44072 .48467 L p
.45767 .47672 L 1 g
F P
s
P
p
.002 w
.44072 .48467 m .43719 .48572 L p
.45767 .47672 L 1 g
F P
s
P
p
.002 w
.4689 .46393 m .48396 .46406 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.47011 .47089 m .46967 .46838 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.46967 .46838 m .4689 .46393 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.50157 .4642 m .4689 .46393 L .46972 .4589 L p
1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .46442 L p
.48945 .46549 L 1 g
F P
s
P
p
.002 w
.50594 .46424 m .50157 .4642 L p
.50066 .46384 L 1 g
F P
s
P
p
.002 w
.47085 .45208 m .50357 .46341 L p
.50066 .46384 L 1 g
F P
s
P
p
.002 w
.50357 .46341 m .50594 .46424 L p
.50066 .46384 L 1 g
F P
s
P
p
.002 w
.46972 .4589 m .47085 .45208 L p
.50157 .4642 L 1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .46394 L p
.50016 .46397 L 1 g
F P
s
P
p
.002 w
.49685 .49893 m .48574 .49422 L .50553 .46485 L p
1 g
F P
s
P
p
.002 w
.50577 .46489 m .49685 .49893 L p
.50553 .46485 L 1 g
F P
s
P
p
.51617 .46651 m .5204 .46732 L .50519 .4648 L 1 g
F
P
p
.002 w
.50553 .46485 m .50594 .46424 L .50577 .46489 L p
1 g
F P
s
P
p
.002 w
.50594 .46424 m .47095 .47573 L .47011 .47089 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46394 L p
1 g
F P
s
P
p
.5204 .46732 m .52282 .46778 L .5 .46394 L 1 g
F
P
p
.002 w
.50157 .4642 m .50594 .46424 L p
.5034 .4645 L 1 g
F P
s
P
p
.002 w
.50577 .46489 m .50594 .46424 L .506 .46492 L p
1 g
F P
s
P
p
.002 w
.50777 .46517 m .50594 .46424 L p
.54208 .46989 L 1 g
F P
s
P
p
.002 w
.5067 .46502 m .50594 .46424 L .50777 .46517 L p
1 g
F P
s
P
p
.002 w
.52247 .46722 m .5225 .46727 L p
.52106 .46702 L 1 g
F P
s
P
p
.002 w
.5225 .46727 m .52255 .46734 L p
.52053 .46699 L 1 g
F P
s
P
p
.002 w
.50627 .46496 m .50594 .46424 L .5067 .46502 L p
1 g
F P
s
P
p
.002 w
.506 .46492 m .50594 .46424 L .50627 .46496 L p
1 g
F P
s
P
p
.002 w
.52255 .46734 m .52277 .46771 L p
.51495 .46623 L 1 g
F P
s
P
p
.002 w
.52277 .46771 m .52282 .46778 L p
.5204 .46732 L 1 g
F P
s
P
p
.50398 .4646 m .5034 .4645 L .50594 .46424 L 1 g
F
P
p
.002 w
.48396 .46406 m .49841 .46417 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46723 L p
1 g
F P
s
P
p
.4893 .46551 m .5 .46442 L .47752 .46723 L 1 g
F
P
p
.47017 .47086 m .47022 .47084 L .47011 .47089 L 1 g
F
P
p
.47017 .47086 m .47011 .47089 L .45767 .47672 L 1 g
F
P
p
.002 w
.46918 .46554 m .47011 .47089 L p
.45767 .47672 L 1 g
F P
s
P
p
.002 w
.47011 .47089 m .47095 .47573 L p
.45767 .47672 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45767 .47672 L p
1 g
F P
s
P
p
.47022 .47084 m .47718 .46778 L .45767 .47672 L 1 g
F
P
p
.002 w
.45767 .47672 m .45762 .47678 L p
.45677 .4776 L 1 g
F P
s
P
p
.002 w
.4689 .46393 m .46918 .46554 L p
.43719 .48572 L 1 g
F P
s
P
p
.002 w
.44674 .48289 m .45332 .48095 L p
.44248 .49147 L 1 g
F P
s
P
p
.002 w
.45332 .48095 m .47095 .47573 L p
.44248 .49147 L 1 g
F P
s
P
p
.002 w
.45762 .47678 m .45698 .47747 L p
.45037 .48381 L 1 g
F P
s
P
p
.002 w
.44238 .49157 m .44166 .49233 L p
.43827 .50027 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44248 .49147 L p
1 g
F P
s
P
p
.45037 .48381 m .45698 .47747 L .44248 .49147 L 1 g
F
P
p
.002 w
.44868 .50619 m .44151 .49342 L p
.47095 .47573 L 1 g
F P
s
P
p
.002 w
.44151 .49342 m .44868 .50619 L p
.4343 .50865 L 1 g
F P
s
P
p
.43601 .4888 m .43719 .48572 L .43332 .5164 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43402 .50925 L p
1 g
F P
s
P
p
.43827 .50027 m .44166 .49233 L .43402 .50925 L 1 g
F
P
p
.002 w
.43402 .50925 m .43377 .50955 L p
.43372 .51236 L 1 g
F P
s
P
p
.002 w
.43332 .5164 m .44868 .50619 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43377 .50955 m .43287 .51061 L p
.43317 .51888 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43253 .52869 L p
1 g
F P
s
P
p
.43317 .51888 m .43287 .51061 L .43253 .52869 L 1 g
F
P
p
.002 w
.43253 .52869 m .43235 .52896 L p
.43316 .53092 L 1 g
F P
s
P
p
.002 w
.44818 .54609 m .43386 .53339 L p
.44868 .50619 L 1 g
F P
s
P
p
.002 w
.43386 .53339 m .44818 .54609 L p
.43839 .54674 L 1 g
F P
s
P
p
.002 w
.43235 .52896 m .43146 .53025 L p
.43551 .53826 L 1 g
F P
s
P
p
.42294 .52466 m .42267 .52349 L .44265 .55304 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4385 .54707 L p
1 g
F P
s
P
p
.43551 .53826 m .43146 .53025 L .4385 .54707 L 1 g
F
P
p
.002 w
.4385 .54707 m .4381 .54784 L p
.4412 .55096 L 1 g
F P
s
P
p
.46528 .57229 m .45098 .56258 L .44818 .54609 L 1 g
F
P
p
.002 w
.44064 .55556 m .44265 .55304 L p
.45098 .56258 L 1 g
F P
s
P
p
.002 w
.44265 .55304 m .44818 .54609 L p
.45098 .56258 L 1 g
F P
s
P
p
.002 w
.4381 .54784 m .43743 .5491 L p
.44479 .55549 L 1 g
F P
s
P
p
.46606 .57348 m .44064 .55556 L .46528 .57229 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45098 .56258 L p
1 g
F P
s
P
p
.44479 .55549 m .43743 .5491 L .45098 .56258 L 1 g
F
P
p
.002 w
.45098 .56258 m .45002 .56518 L p
.46165 .56983 L 1 g
F P
s
P
p
.47223 .58294 m .43577 .56169 L .46606 .57348 L 1 g
F
P
p
.47892 .57778 m .47659 .57758 L .48909 .58019 L 1 g
F
P
p
.47659 .57758 m .4678 .57686 L .47939 .57867 L 1 g
F
P
p
.47659 .57758 m .47939 .57867 L .48909 .58019 L 1 g
F
P
p
.002 w
.46834 .57437 m .4678 .57686 L p
.47659 .57758 L 1 g
F P
s
P
p
.48921 .57862 m .46834 .57437 L .47659 .57758 L 1 g
F
P
p
.46606 .57348 m .44818 .54609 L .47421 .57666 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .57437 L p
1 g
F P
s
P
p
.46165 .56983 m .45002 .56518 L .46834 .57437 L 1 g
F
P
p
.002 w
.44818 .54609 m .47969 .5593 L .47421 .57666 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48893 .58239 L p
1 g
F P
s
P
p
.002 w
.48893 .58239 m .48909 .58019 L p
.47939 .57867 L 1 g
F P
s
P
p
.47939 .57867 m .4678 .57686 L .48893 .58239 L 1 g
F
P
p
.002 w
.48909 .58019 m .48921 .57862 L p
.47892 .57778 L 1 g
F P
s
P
p
.50879 .58101 m .49549 .58171 L .47969 .5593 L 1 g
F
P
p
.002 w
.47421 .57666 m .47969 .5593 L p
.49549 .58171 L 1 g
F P
s
P
p
.002 w
.51098 .58117 m .51111 .583 L p
.51902 .57894 L 1 g
F P
s
P
p
.52245 .57718 m .51513 .57973 L .51902 .57894 L 1 g
F
P
p
.51513 .57973 m .51098 .58117 L .51902 .57894 L 1 g
F
P
p
.002 w
.48909 .58019 m .48889 .583 L p
.50183 .58041 L 1 g
F P
s
P
p
.51094 .58057 m .47969 .5593 L .51513 .57973 L 1 g
F
P
p
.50879 .58101 m .50814 .58052 L .51094 .58057 L 1 g
F
P
p
.50814 .58052 m .47969 .5593 L .51094 .58057 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58057 L p
1 g
F P
s
P
p
.50183 .58041 m .48889 .583 L .51094 .58057 L 1 g
F
P
p
.002 w
.47969 .5593 m .51383 .5618 L .51513 .57973 L p
1 g
F P
s
P
p
.002 w
.51094 .58057 m .51098 .58117 L p
.51376 .58 L 1 g
F P
s
P
p
.002 w
.37704 .41391 m .37037 .45711 L .34561 .45323 L p
1 g
F P
s
P
p
.002 w
.34561 .45323 m .35337 .40223 L .37704 .41391 L p
1 g
F P
s
P
p
.002 w
.62136 .51794 m .59428 .55183 L .57576 .5348 L p
1 g
F P
s
P
p
.002 w
.63655 .43379 m .62272 .39248 L .64325 .37698 L p
1 g
F P
s
P
p
.002 w
.61164 .33595 m .64325 .37698 L .62272 .39248 L p
1 g
F P
s
P
p
.002 w
.43218 .5662 m .39967 .53753 L .42267 .52349 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.57576 .5348 m .59701 .5081 L .62136 .51794 L p
1 g
F P
s
P
p
.002 w
.63602 .47717 m .62136 .51794 L .59701 .5081 L p
1 g
F P
s
P
p
.002 w
.39773 .375 m .37704 .41391 L .35337 .40223 L p
1 g
F P
s
P
p
.002 w
.35337 .40223 m .3777 .35624 L .39773 .375 L p
1 g
F P
s
P
p
.002 w
.40593 .49384 m .42267 .52349 L .39967 .53753 L p
1 g
F P
s
P
p
.002 w
.39967 .53753 m .37825 .49985 L .40593 .49384 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.62272 .39248 m .59587 .35779 L .61164 .33595 L p
1 g
F P
s
P
p
.002 w
.56792 .30737 m .61164 .33595 L .59587 .35779 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59701 .5081 m .60846 .47603 L .63602 .47717 L p
1 g
F P
s
P
p
.002 w
.63655 .43379 m .63602 .47717 L .60846 .47603 L p
1 g
F P
s
P
p
.002 w
.43027 .34479 m .39773 .375 L .3777 .35624 L p
1 g
F P
s
P
p
.002 w
.3777 .35624 m .41608 .32048 L .43027 .34479 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59587 .35779 m .5588 .33365 L .56792 .30737 L p
1 g
F P
s
P
p
.002 w
.51689 .29456 m .56792 .30737 L .5588 .33365 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.39983 .46028 m .40593 .49384 L .37825 .49985 L p
1 g
F P
s
P
p
.002 w
.37825 .49985 m .37037 .45711 L .39983 .46028 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.47108 .32672 m .43027 .34479 L .41608 .32048 L p
1 g
F P
s
P
p
.002 w
.41608 .32048 m .46429 .2991 L .47108 .32672 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.5588 .33365 m .5156 .32287 L .51689 .29456 L p
1 g
F P
s
P
p
.002 w
.46429 .2991 m .51689 .29456 L .5156 .32287 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60846 .47603 m .60878 .44196 L .63655 .43379 L p
1 g
F P
s
P
p
.002 w
.62272 .39248 m .63655 .43379 L .60878 .44196 L p
1 g
F P
s
P
p
.002 w
.5156 .32287 m .47108 .32672 L .46429 .2991 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.40517 .42642 m .39983 .46028 L .37037 .45711 L p
1 g
F P
s
P
p
.002 w
.37037 .45711 m .37704 .41391 L .40517 .42642 L p
1 g
F P
s
P
p
.002 w
.54702 .55334 m .51383 .5618 L .51158 .53274 L p
1 g
F P
s
P
p
.002 w
.48799 .531 m .51158 .53274 L .51383 .5618 L p
1 g
F P
s
P
p
.002 w
.51383 .5618 m .47969 .5593 L .48799 .531 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51158 .53274 m .53452 .52689 L .54702 .55334 L p
1 g
F P
s
P
p
.002 w
.46624 .52183 m .48799 .531 L .47969 .5593 L p
1 g
F P
s
P
p
.002 w
.47969 .5593 m .44818 .54609 L .46624 .52183 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60878 .44196 m .59784 .40959 L .62272 .39248 L p
1 g
F P
s
P
p
.002 w
.59587 .35779 m .62272 .39248 L .59784 .40959 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.44868 .50619 m .46624 .52183 L .44818 .54609 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.60846 .47603 m .59701 .5081 L .569 .49559 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42146 .39597 m .40517 .42642 L .37704 .41391 L p
1 g
F P
s
P
p
.002 w
.37704 .41391 m .39773 .375 L .42146 .39597 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42267 .52349 m .40593 .49384 L .43719 .48572 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.59784 .40959 m .57671 .38245 L .59587 .35779 L p
1 g
F P
s
P
p
.002 w
.5588 .33365 m .59587 .35779 L .57671 .38245 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.569 .49559 m .57683 .47344 L .60846 .47603 L p
1 g
F P
s
P
p
.002 w
.60878 .44196 m .60846 .47603 L .57683 .47344 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44698 .37235 m .42146 .39597 L .39773 .375 L p
1 g
F P
s
P
p
.002 w
.39773 .375 m .43027 .34479 L .44698 .37235 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43307 .46259 m .43719 .48572 L .40593 .49384 L p
1 g
F P
s
P
p
.002 w
.40593 .49384 m .39983 .46028 L .43307 .46259 L p
1 g
F P
s
P
p
.002 w
.57671 .38245 m .54763 .36361 L .5588 .33365 L p
1 g
F P
s
P
p
.002 w
.5156 .32287 m .5588 .33365 L .54763 .36361 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.47894 .35823 m .44698 .37235 L .43027 .34479 L p
1 g
F P
s
P
p
.002 w
.43027 .34479 m .47108 .32672 L .47894 .35823 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57683 .47344 m .57698 .44997 L .60878 .44196 L p
1 g
F P
s
P
p
.002 w
.59784 .40959 m .60878 .44196 L .57698 .44997 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.54763 .36361 m .51379 .35521 L .5156 .32287 L p
1 g
F P
s
P
p
.002 w
.47108 .32672 m .5156 .32287 L .51379 .35521 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51379 .35521 m .47894 .35823 L .47108 .32672 L p
1 g
F P
s
P
p
.002 w
.43682 .4393 m .43307 .46259 L .39983 .46028 L p
1 g
F P
s
P
p
.002 w
.39983 .46028 m .40517 .42642 L .43682 .4393 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.53452 .52689 m .51158 .53274 L .50892 .49983 L p
1 g
F P
s
P
p
.002 w
.49685 .49893 m .50892 .49983 L .51158 .53274 L p
1 g
F P
s
P
p
.002 w
.51158 .53274 m .48799 .531 L .49685 .49893 L p
1 g
F P
s
P
p
.002 w
.50892 .49983 m .52066 .49683 L .53452 .52689 L p
1 g
F P
s
P
p
.002 w
.55436 .51406 m .53452 .52689 L .52066 .49683 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.48574 .49422 m .49685 .49893 L .48799 .531 L p
1 g
F P
s
P
p
.002 w
.48799 .531 m .46624 .52183 L .48574 .49422 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57698 .44997 m .56937 .42771 L .59784 .40959 L p
1 g
F P
s
P
p
.002 w
.57671 .38245 m .59784 .40959 L .56937 .42771 L p
1 g
F P
s
P
p
.002 w
.52066 .49683 m .5308 .49025 L .55436 .51406 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47678 .4862 m .48574 .49422 L .46624 .52183 L p
1 g
F P
s
P
p
.002 w
.46624 .52183 m .44868 .50619 L .47678 .4862 L p
1 g
F P
s
P
p
.002 w
.44807 .41841 m .43682 .4393 L .40517 .42642 L p
1 g
F P
s
P
p
.002 w
.40517 .42642 m .42146 .39597 L .44807 .41841 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47095 .47573 m .47678 .4862 L .44868 .50619 L p
1 g
F P
s
P
p
.002 w
.56937 .42771 m .55479 .40909 L .57671 .38245 L p
1 g
F P
s
P
p
.002 w
.54763 .36361 m .57671 .38245 L .55479 .40909 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57698 .44997 m .57683 .47344 L .54223 .46947 L p
1 g
F P
s
P
p
.002 w
.46564 .40222 m .44807 .41841 L .42146 .39597 L p
1 g
F P
s
P
p
.002 w
.42146 .39597 m .44698 .37235 L .46564 .40222 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.43719 .48572 m .43307 .46259 L .4689 .46393 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55479 .40909 m .53478 .39619 L .54763 .36361 L p
1 g
F P
s
P
p
.002 w
.51379 .35521 m .54763 .36361 L .53478 .39619 L p
1 g
F P
s
P
p
.002 w
.54223 .46947 m .54226 .45749 L .57698 .44997 L p
1 g
F P
s
P
p
.002 w
.56937 .42771 m .57698 .44997 L .54226 .45749 L p
1 g
F P
s
P
p
.002 w
.4876 .39254 m .46564 .40222 L .44698 .37235 L p
1 g
F P
s
P
p
.002 w
.44698 .37235 m .47894 .35823 L .4876 .39254 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.53478 .39619 m .51152 .39045 L .51379 .35521 L p
1 g
F P
s
P
p
.002 w
.47894 .35823 m .51379 .35521 L .51152 .39045 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51152 .39045 m .4876 .39254 L .47894 .35823 L p
1 g
F P
s
P
p
.002 w
.47085 .45208 m .4689 .46393 L .43307 .46259 L p
1 g
F P
s
P
p
.002 w
.43307 .46259 m .43682 .4393 L .47085 .45208 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54226 .45749 m .53835 .44616 L .56937 .42771 L p
1 g
F P
s
P
p
.002 w
.55479 .40909 m .56937 .42771 L .53835 .44616 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.4766 .44146 m .47085 .45208 L .43682 .4393 L p
1 g
F P
s
P
p
.002 w
.43682 .4393 m .44807 .41841 L .4766 .44146 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.53835 .44616 m .53089 .43671 L .55479 .40909 L p
1 g
F P
s
P
p
.002 w
.53478 .39619 m .55479 .40909 L .53089 .43671 L p
1 g
F P
s
P
p
.002 w
.54226 .45749 m .54223 .46947 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48555 .43325 m .4766 .44146 L .44807 .41841 L p
1 g
F P
s
P
p
.002 w
.44807 .41841 m .46564 .40222 L .48555 .43325 L p
1 g
F P
s
P
p
.002 w
.53835 .44616 m .54226 .45749 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.53089 .43671 m .5207 .43018 L .53478 .39619 L p
1 g
F P
s
P
p
.002 w
.51152 .39045 m .53478 .39619 L .5207 .43018 L p
1 g
F P
s
P
p
.002 w
.49671 .42834 m .48555 .43325 L .46564 .40222 L p
1 g
F P
s
P
p
.002 w
.46564 .40222 m .4876 .39254 L .49671 .42834 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.5207 .43018 m .50887 .42728 L .51152 .39045 L p
1 g
F P
s
P
p
.002 w
.4876 .39254 m .51152 .39045 L .50887 .42728 L p
1 g
F P
s
P
p
.002 w
.53089 .43671 m .53835 .44616 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.50887 .42728 m .49671 .42834 L .4876 .39254 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47085 .45208 m .4766 .44146 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5207 .43018 m .53089 .43671 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.50887 .42728 m .5207 .43018 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.49671 .42834 m .50887 .42728 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.48555 .43325 m .49671 .42834 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.4766 .44146 m .48555 .43325 L .50594 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.50594 .46424 m
.50963 .48518 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .41164 .70145 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .50963 .48518 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.17907)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.17907)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49447 .47668 m .51863 .46433 L .50181 .44146 L p
1 g
F P
s
P
p
.002 w
.50181 .44146 m .48537 .44984 L .49447 .47668 L p
1 g
F P
s
P
p
.002 w
.51483 .42833 m .50181 .44146 L .51863 .46433 L p
1 g
F P
s
P
p
.002 w
.48537 .44984 m .50181 .44146 L .48499 .41837 L p
1 g
F P
s
P
p
.002 w
.50181 .44146 m .51483 .42833 L .49159 .41171 L p
1 g
F P
s
P
p
.002 w
.49159 .41171 m .48499 .41837 L .50181 .44146 L p
1 g
F P
s
P
p
.002 w
.51863 .46433 m .53777 .44504 L .51483 .42833 L p
1 g
F P
s
P
p
.002 w
.52305 .41184 m .51483 .42833 L .53777 .44504 L p
1 g
F P
s
P
p
.002 w
.51483 .42833 m .52305 .41184 L .49574 .40334 L p
1 g
F P
s
P
p
.002 w
.49574 .40334 m .49159 .41171 L .51483 .42833 L p
1 g
F P
s
P
p
.002 w
.48499 .41837 m .47664 .42261 L .48537 .44984 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .47664 .42261 L .48499 .41837 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .48499 .41837 L .49159 .41171 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .49159 .41171 L .49574 .40334 L closepath p
1 g
F P
s
P
p
.002 w
.46779 .48079 m .49447 .47668 L .48537 .44984 L p
1 g
F P
s
P
p
.002 w
.48537 .44984 m .46722 .45258 L .46779 .48079 L p
1 g
F P
s
P
p
.002 w
.46722 .45258 m .48537 .44984 L .47664 .42261 L p
1 g
F P
s
P
p
.002 w
.47664 .42261 m .46744 .42397 L .46722 .45258 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .46744 .42397 L .47664 .42261 L closepath p
1 g
F P
s
P
p
.002 w
.49699 .39415 m .49574 .40334 L .52305 .41184 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .49574 .40334 L .49699 .39415 L closepath p
1 g
F P
s
P
p
.002 w
.53777 .44504 m .54991 .42082 L .52305 .41184 L p
1 g
F P
s
P
p
.002 w
.52559 .39371 m .52305 .41184 L .54991 .42082 L p
1 g
F P
s
P
p
.002 w
.52305 .41184 m .52559 .39371 L .49699 .39415 L p
1 g
F P
s
P
p
.002 w
.44929 .44935 m .46722 .45258 L .46744 .42397 L p
1 g
F P
s
P
p
.002 w
.46744 .42397 m .45837 .4223 L .44929 .44935 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .45837 .4223 L .46744 .42397 L closepath p
1 g
F P
s
P
p
.002 w
.4952 .38513 m .49699 .39415 L .52559 .39371 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .49699 .39415 L .4952 .38513 L closepath p
1 g
F P
s
P
p
.002 w
.50379 .50266 m .53514 .48657 L .51863 .46433 L p
1 g
F P
s
P
p
.002 w
.51863 .46433 m .49447 .47668 L .50379 .50266 L p
1 g
F P
s
P
p
.002 w
.53777 .44504 m .51863 .46433 L .53514 .48657 L p
1 g
F P
s
P
p
.002 w
.44136 .47616 m .46779 .48079 L .46722 .45258 L p
1 g
F P
s
P
p
.002 w
.46722 .45258 m .44929 .44935 L .44136 .47616 L p
1 g
F P
s
P
p
.002 w
.53514 .48657 m .55999 .46155 L .53777 .44504 L p
1 g
F P
s
P
p
.002 w
.54991 .42082 m .53777 .44504 L .55999 .46155 L p
1 g
F P
s
P
p
.002 w
.43348 .44047 m .44929 .44935 L .45837 .4223 L p
1 g
F P
s
P
p
.002 w
.45837 .4223 m .45041 .41777 L .43348 .44047 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .45041 .41777 L .45837 .4223 L closepath p
1 g
F P
s
P
p
.002 w
.54991 .42082 m .55373 .39415 L .52559 .39371 L p
1 g
F P
s
P
p
.002 w
.52214 .37586 m .52559 .39371 L .55373 .39415 L p
1 g
F P
s
P
p
.002 w
.52559 .39371 m .52214 .37586 L .4952 .38513 L p
1 g
F P
s
P
p
.002 w
.49055 .37725 m .4952 .38513 L .52214 .37586 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .4952 .38513 L .49055 .37725 L closepath p
1 g
F P
s
P
p
.002 w
.46915 .50809 m .50379 .50266 L .49447 .47668 L p
1 g
F P
s
P
p
.002 w
.49447 .47668 m .46779 .48079 L .46915 .50809 L p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .49055 .37725 L .48353 .37136 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .48353 .37136 L .47489 .36813 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .47489 .36813 L .46556 .3679 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .46556 .3679 L .45658 .37073 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .45658 .37073 L .44892 .3763 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .44892 .3763 L .44343 .38401 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .44343 .38401 L .44071 .393 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .44071 .393 L .44106 .40228 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .44106 .40228 L .44442 .41085 L closepath p
1 g
F P
s
P
p
.002 w
.46846 .39548 m .44442 .41085 L .45041 .41777 L closepath p
1 g
F P
s
P
p
.002 w
.55999 .46155 m .57581 .43012 L .54991 .42082 L p
1 g
F P
s
P
p
.002 w
.55373 .39415 m .54991 .42082 L .57581 .43012 L p
1 g
F P
s
P
p
.002 w
.42154 .42682 m .43348 .44047 L .45041 .41777 L p
1 g
F P
s
P
p
.002 w
.45041 .41777 m .44442 .41085 L .42154 .42682 L p
1 g
F P
s
P
p
.002 w
.52214 .37586 m .51301 .36021 L .49055 .37725 L p
1 g
F P
s
P
p
.002 w
.48353 .37136 m .49055 .37725 L .51301 .36021 L p
1 g
F P
s
P
p
.002 w
.41801 .46317 m .44136 .47616 L .44929 .44935 L p
1 g
F P
s
P
p
.002 w
.44929 .44935 m .43348 .44047 L .41801 .46317 L p
1 g
F P
s
P
p
.002 w
.4148 .40985 m .42154 .42682 L .44442 .41085 L p
1 g
F P
s
P
p
.002 w
.44442 .41085 m .44106 .40228 L .4148 .40985 L p
1 g
F P
s
P
p
.002 w
.55373 .39415 m .54876 .36784 L .52214 .37586 L p
1 g
F P
s
P
p
.002 w
.51301 .36021 m .52214 .37586 L .54876 .36784 L p
1 g
F P
s
P
p
.002 w
.43478 .5022 m .46915 .50809 L .46779 .48079 L p
1 g
F P
s
P
p
.002 w
.46779 .48079 m .44136 .47616 L .43478 .5022 L p
1 g
F P
s
P
p
.002 w
.51301 .36021 m .49914 .34847 L .48353 .37136 L p
1 g
F P
s
P
p
.002 w
.47489 .36813 m .48353 .37136 L .49914 .34847 L p
1 g
F P
s
P
p
.002 w
.57581 .43012 m .58089 .3955 L .55373 .39415 L p
1 g
F P
s
P
p
.002 w
.54876 .36784 m .55373 .39415 L .58089 .3955 L p
1 g
F P
s
P
p
.002 w
.41404 .3914 m .4148 .40985 L .44106 .40228 L p
1 g
F P
s
P
p
.002 w
.44106 .40228 m .44071 .393 L .41404 .3914 L p
1 g
F P
s
P
p
.002 w
.51317 .52726 m .55103 .50777 L .53514 .48657 L p
1 g
F P
s
P
p
.002 w
.53514 .48657 m .50379 .50266 L .51317 .52726 L p
1 g
F P
s
P
p
.002 w
.55999 .46155 m .53514 .48657 L .55103 .50777 L p
1 g
F P
s
P
p
.002 w
.49914 .34847 m .48201 .34196 L .47489 .36813 L p
1 g
F P
s
P
p
.002 w
.46556 .3679 m .47489 .36813 L .48201 .34196 L p
1 g
F P
s
P
p
.002 w
.40027 .44311 m .41801 .46317 L .43348 .44047 L p
1 g
F P
s
P
p
.002 w
.43348 .44047 m .42154 .42682 L .40027 .44311 L p
1 g
F P
s
P
p
.002 w
.55103 .50777 m .58107 .47753 L .55999 .46155 L p
1 g
F P
s
P
p
.002 w
.57581 .43012 m .55999 .46155 L .58107 .47753 L p
1 g
F P
s
P
p
.002 w
.4194 .3735 m .41404 .3914 L .44071 .393 L p
1 g
F P
s
P
p
.002 w
.44071 .393 m .44343 .38401 L .4194 .3735 L p
1 g
F P
s
P
p
.002 w
.48201 .34196 m .46347 .34146 L .46556 .3679 L p
1 g
F P
s
P
p
.002 w
.45658 .37073 m .46556 .3679 L .46347 .34146 L p
1 g
F P
s
P
p
.002 w
.54876 .36784 m .53541 .34469 L .51301 .36021 L p
1 g
F P
s
P
p
.002 w
.49914 .34847 m .51301 .36021 L .53541 .34469 L p
1 g
F P
s
P
p
.002 w
.4713 .53394 m .51317 .52726 L .50379 .50266 L p
1 g
F P
s
P
p
.002 w
.50379 .50266 m .46915 .50809 L .4713 .53394 L p
1 g
F P
s
P
p
.002 w
.43031 .35814 m .4194 .3735 L .44343 .38401 L p
1 g
F P
s
P
p
.002 w
.44343 .38401 m .44892 .3763 L .43031 .35814 L p
1 g
F P
s
P
p
.002 w
.46347 .34146 m .44557 .34705 L .45658 .37073 L p
1 g
F P
s
P
p
.002 w
.44892 .3763 m .45658 .37073 L .44557 .34705 L p
1 g
F P
s
P
p
.002 w
.4043 .48544 m .43478 .5022 L .44136 .47616 L p
1 g
F P
s
P
p
.002 w
.44136 .47616 m .41801 .46317 L .4043 .48544 L p
1 g
F P
s
P
p
.002 w
.44557 .34705 m .43031 .35814 L .44892 .3763 L p
1 g
F P
s
P
p
.002 w
.58107 .47753 m .60026 .43958 L .57581 .43012 L p
1 g
F P
s
P
p
.002 w
.58089 .3955 m .57581 .43012 L .60026 .43958 L p
1 g
F P
s
P
p
.002 w
.39018 .41806 m .40027 .44311 L .42154 .42682 L p
1 g
F P
s
P
p
.002 w
.42154 .42682 m .4148 .40985 L .39018 .41806 L p
1 g
F P
s
P
p
.002 w
.58089 .3955 m .57457 .36125 L .54876 .36784 L p
1 g
F P
s
P
p
.002 w
.53541 .34469 m .54876 .36784 L .57457 .36125 L p
1 g
F P
s
P
p
.002 w
.53541 .34469 m .51502 .32725 L .49914 .34847 L p
1 g
F P
s
P
p
.002 w
.48201 .34196 m .49914 .34847 L .51502 .32725 L p
1 g
F P
s
P
p
.002 w
.42968 .52697 m .4713 .53394 L .46915 .50809 L p
1 g
F P
s
P
p
.002 w
.46915 .50809 m .43478 .5022 L .42968 .52697 L p
1 g
F P
s
P
p
.002 w
.38896 .39074 m .39018 .41806 L .4148 .40985 L p
1 g
F P
s
P
p
.002 w
.4148 .40985 m .41404 .3914 L .38896 .39074 L p
1 g
F P
s
P
p
.002 w
.60026 .43958 m .60654 .39773 L .58089 .3955 L p
1 g
F P
s
P
p
.002 w
.57457 .36125 m .58089 .3955 L .60654 .39773 L p
1 g
F P
s
P
p
.002 w
.38106 .45941 m .4043 .48544 L .41801 .46317 L p
1 g
F P
s
P
p
.002 w
.41801 .46317 m .40027 .44311 L .38106 .45941 L p
1 g
F P
s
P
p
.002 w
.51502 .32725 m .48971 .31752 L .48201 .34196 L p
1 g
F P
s
P
p
.002 w
.46347 .34146 m .48201 .34196 L .48971 .31752 L p
1 g
F P
s
P
p
.002 w
.52242 .54998 m .56598 .52749 L .55103 .50777 L p
1 g
F P
s
P
p
.002 w
.55103 .50777 m .51317 .52726 L .52242 .54998 L p
1 g
F P
s
P
p
.002 w
.58107 .47753 m .55103 .50777 L .56598 .52749 L p
1 g
F P
s
P
p
.002 w
.57457 .36125 m .55734 .33102 L .53541 .34469 L p
1 g
F P
s
P
p
.002 w
.51502 .32725 m .53541 .34469 L .55734 .33102 L p
1 g
F P
s
P
p
.002 w
.56598 .52749 m .60058 .49269 L .58107 .47753 L p
1 g
F P
s
P
p
.002 w
.60026 .43958 m .58107 .47753 L .60058 .49269 L p
1 g
F P
s
P
p
.002 w
.39685 .36418 m .38896 .39074 L .41404 .3914 L p
1 g
F P
s
P
p
.002 w
.41404 .3914 m .4194 .3735 L .39685 .36418 L p
1 g
F P
s
P
p
.002 w
.48971 .31752 m .46224 .31668 L .46347 .34146 L p
1 g
F P
s
P
p
.002 w
.44557 .34705 m .46347 .34146 L .46224 .31668 L p
1 g
F P
s
P
p
.002 w
.39268 .50683 m .42968 .52697 L .43478 .5022 L p
1 g
F P
s
P
p
.002 w
.43478 .5022 m .4043 .48544 L .39268 .50683 L p
1 g
F P
s
P
p
.002 w
.47422 .5578 m .52242 .54998 L .51317 .52726 L p
1 g
F P
s
P
p
.002 w
.51317 .52726 m .4713 .53394 L .47422 .5578 L p
1 g
F P
s
P
p
.002 w
.41302 .34137 m .39685 .36418 L .4194 .3735 L p
1 g
F P
s
P
p
.002 w
.4194 .3735 m .43031 .35814 L .41302 .34137 L p
1 g
F P
s
P
p
.002 w
.46224 .31668 m .43567 .32493 L .44557 .34705 L p
1 g
F P
s
P
p
.002 w
.43031 .35814 m .44557 .34705 L .43567 .32493 L p
1 g
F P
s
P
p
.002 w
.43567 .32493 m .41302 .34137 L .43031 .35814 L p
1 g
F P
s
P
p
.002 w
.36776 .42678 m .38106 .45941 L .40027 .44311 L p
1 g
F P
s
P
p
.002 w
.40027 .44311 m .39018 .41806 L .36776 .42678 L p
1 g
F P
s
P
p
.002 w
.60058 .49269 m .62274 .44903 L .60026 .43958 L p
1 g
F P
s
P
p
.002 w
.60654 .39773 m .60026 .43958 L .62274 .44903 L p
1 g
F P
s
P
p
.002 w
.60654 .39773 m .59906 .35625 L .57457 .36125 L p
1 g
F P
s
P
p
.002 w
.55734 .33102 m .57457 .36125 L .59906 .35625 L p
1 g
F P
s
P
p
.002 w
.55734 .33102 m .53085 .30816 L .51502 .32725 L p
1 g
F P
s
P
p
.002 w
.48971 .31752 m .51502 .32725 L .53085 .30816 L p
1 g
F P
s
P
p
.002 w
.42623 .54994 m .47422 .5578 L .4713 .53394 L p
1 g
F P
s
P
p
.002 w
.4713 .53394 m .42968 .52697 L .42623 .54994 L p
1 g
F P
s
P
p
.002 w
.36437 .47539 m .39268 .50683 L .4043 .48544 L p
1 g
F P
s
P
p
.002 w
.4043 .48544 m .38106 .45941 L .36437 .47539 L p
1 g
F P
s
P
p
.002 w
.36605 .39107 m .36776 .42678 L .39018 .41806 L p
1 g
F P
s
P
p
.002 w
.39018 .41806 m .38896 .39074 L .36605 .39107 L p
1 g
F P
s
P
p
.002 w
.62274 .44903 m .63011 .40084 L .60654 .39773 L p
1 g
F P
s
P
p
.002 w
.59906 .35625 m .60654 .39773 L .63011 .40084 L p
1 g
F P
s
P
p
.002 w
.53085 .30816 m .49785 .29532 L .48971 .31752 L p
1 g
F P
s
P
p
.002 w
.46224 .31668 m .48971 .31752 L .49785 .29532 L p
1 g
F P
s
P
p
.002 w
.59906 .35625 m .57834 .31953 L .55734 .33102 L p
1 g
F P
s
P
p
.002 w
.53085 .30816 m .55734 .33102 L .57834 .31953 L p
1 g
F P
s
P
p
.002 w
.53135 .57029 m .57966 .54529 L .56598 .52749 L p
1 g
F P
s
P
p
.002 w
.56598 .52749 m .52242 .54998 L .53135 .57029 L p
1 g
F P
s
P
p
.002 w
.60058 .49269 m .56598 .52749 L .57966 .54529 L p
1 g
F P
s
P
p
.002 w
.37629 .35628 m .36605 .39107 L .38896 .39074 L p
1 g
F P
s
P
p
.002 w
.38896 .39074 m .39685 .36418 L .37629 .35628 L p
1 g
F P
s
P
p
.002 w
.57966 .54529 m .61806 .50668 L .60058 .49269 L p
1 g
F P
s
P
p
.002 w
.62274 .44903 m .60058 .49269 L .61806 .50668 L p
1 g
F P
s
P
p
.002 w
.38347 .52688 m .42623 .54994 L .42968 .52697 L p
1 g
F P
s
P
p
.002 w
.42968 .52697 m .39268 .50683 L .38347 .52688 L p
1 g
F P
s
P
p
.002 w
.49785 .29532 m .46193 .29412 L .46224 .31668 L p
1 g
F P
s
P
p
.002 w
.43567 .32493 m .46224 .31668 L .46193 .29412 L p
1 g
F P
s
P
p
.002 w
.47787 .57909 m .53135 .57029 L .52242 .54998 L p
1 g
F P
s
P
p
.002 w
.52242 .54998 m .47422 .5578 L .47787 .57909 L p
1 g
F P
s
P
p
.002 w
.34807 .43583 m .36437 .47539 L .38106 .45941 L p
1 g
F P
s
P
p
.002 w
.38106 .45941 m .36776 .42678 L .34807 .43583 L p
1 g
F P
s
P
p
.002 w
.39745 .32639 m .37629 .35628 L .39685 .36418 L p
1 g
F P
s
P
p
.002 w
.39685 .36418 m .41302 .34137 L .39745 .32639 L p
1 g
F P
s
P
p
.002 w
.46193 .29412 m .42713 .30486 L .43567 .32493 L p
1 g
F P
s
P
p
.002 w
.41302 .34137 m .43567 .32493 L .42713 .30486 L p
1 g
F P
s
P
p
.002 w
.63011 .40084 m .62167 .35299 L .59906 .35625 L p
1 g
F P
s
P
p
.002 w
.57834 .31953 m .59906 .35625 L .62167 .35299 L p
1 g
F P
s
P
p
.002 w
.61806 .50668 m .64274 .45826 L .62274 .44903 L p
1 g
F P
s
P
p
.002 w
.63011 .40084 m .62274 .44903 L .64274 .45826 L p
1 g
F P
s
P
p
.002 w
.42713 .30486 m .39745 .32639 L .41302 .34137 L p
1 g
F P
s
P
p
.002 w
.57834 .31953 m .54632 .29166 L .53085 .30816 L p
1 g
F P
s
P
p
.002 w
.49785 .29532 m .53085 .30816 L .54632 .29166 L p
1 g
F P
s
P
p
.002 w
.42456 .57053 m .47787 .57909 L .47422 .5578 L p
1 g
F P
s
P
p
.002 w
.47422 .5578 m .42623 .54994 L .42456 .57053 L p
1 g
F P
s
P
p
.002 w
.35065 .4907 m .38347 .52688 L .39268 .50683 L p
1 g
F P
s
P
p
.002 w
.39268 .50683 m .36437 .47539 L .35065 .4907 L p
1 g
F P
s
P
p
.002 w
.34586 .39242 m .34807 .43583 L .36776 .42678 L p
1 g
F P
s
P
p
.002 w
.36776 .42678 m .36605 .39107 L .34586 .39242 L p
1 g
F P
s
P
p
.002 w
.64274 .45826 m .65106 .40479 L .63011 .40084 L p
1 g
F P
s
P
p
.002 w
.62167 .35299 m .63011 .40084 L .65106 .40479 L p
1 g
F P
s
P
p
.002 w
.54632 .29166 m .50629 .27593 L .49785 .29532 L p
1 g
F P
s
P
p
.002 w
.46193 .29412 m .49785 .29532 L .50629 .27593 L p
1 g
F P
s
P
p
.002 w
.62167 .35299 m .59794 .31054 L .57834 .31953 L p
1 g
F P
s
P
p
.002 w
.54632 .29166 m .57834 .31953 L .59794 .31054 L p
1 g
F P
s
P
p
.002 w
.35825 .35004 m .34586 .39242 L .36605 .39107 L p
1 g
F P
s
P
p
.002 w
.36605 .39107 m .37629 .35628 L .35825 .35004 L p
1 g
F P
s
P
p
.002 w
.53976 .58767 m .59173 .56071 L .57966 .54529 L p
1 g
F P
s
P
p
.002 w
.57966 .54529 m .53135 .57029 L .53976 .58767 L p
1 g
F P
s
P
p
.002 w
.61806 .50668 m .57966 .54529 L .59173 .56071 L p
1 g
F P
s
P
p
.002 w
.37697 .54507 m .42456 .57053 L .42623 .54994 L p
1 g
F P
s
P
p
.002 w
.42623 .54994 m .38347 .52688 L .37697 .54507 L p
1 g
F P
s
P
p
.002 w
.59173 .56071 m .63308 .51915 L .61806 .50668 L p
1 g
F P
s
P
p
.002 w
.64274 .45826 m .61806 .50668 L .63308 .51915 L p
1 g
F P
s
P
p
.002 w
.50629 .27593 m .46259 .27436 L .46193 .29412 L p
1 g
F P
s
P
p
.002 w
.42713 .30486 m .46193 .29412 L .46259 .27436 L p
1 g
F P
s
P
p
.002 w
.33166 .44504 m .35065 .4907 L .36437 .47539 L p
1 g
F P
s
P
p
.002 w
.36437 .47539 m .34807 .43583 L .33166 .44504 L p
1 g
F P
s
P
p
.002 w
.48221 .59725 m .53976 .58767 L .53135 .57029 L p
1 g
F P
s
P
p
.002 w
.53135 .57029 m .47787 .57909 L .48221 .59725 L p
1 g
F P
s
P
p
.002 w
.65106 .40479 m .64185 .35163 L .62167 .35299 L p
1 g
F P
s
P
p
.002 w
.59794 .31054 m .62167 .35299 L .64185 .35163 L p
1 g
F P
s
P
p
.002 w
.384 .3136 m .35825 .35004 L .37629 .35628 L p
1 g
F P
s
P
p
.002 w
.37629 .35628 m .39745 .32639 L .384 .3136 L p
1 g
F P
s
P
p
.002 w
.46259 .27436 m .42019 .28737 L .42713 .30486 L p
1 g
F P
s
P
p
.002 w
.39745 .32639 m .42713 .30486 L .42019 .28737 L p
1 g
F P
s
P
p
.002 w
.63308 .51915 m .65971 .46708 L .64274 .45826 L p
1 g
F P
s
P
p
.002 w
.65106 .40479 m .64274 .45826 L .65971 .46708 L p
1 g
F P
s
P
p
.002 w
.42019 .28737 m .384 .3136 L .39745 .32639 L p
1 g
F P
s
P
p
.002 w
.59794 .31054 m .56108 .27822 L .54632 .29166 L p
1 g
F P
s
P
p
.002 w
.50629 .27593 m .54632 .29166 L .56108 .27822 L p
1 g
F P
s
P
p
.002 w
.4248 .58818 m .48221 .59725 L .47787 .57909 L p
1 g
F P
s
P
p
.002 w
.47787 .57909 m .42456 .57053 L .4248 .58818 L p
1 g
F P
s
P
p
.002 w
.34036 .50497 m .37697 .54507 L .38347 .52688 L p
1 g
F P
s
P
p
.002 w
.38347 .52688 m .35065 .4907 L .34036 .50497 L p
1 g
F P
s
P
p
.002 w
.32898 .3948 m .33166 .44504 L .34807 .43583 L p
1 g
F P
s
P
p
.002 w
.34807 .43583 m .34586 .39242 L .32898 .3948 L p
1 g
F P
s
P
p
.002 w
.65971 .46708 m .66879 .40954 L .65106 .40479 L p
1 g
F P
s
P
p
.002 w
.64185 .35163 m .65106 .40479 L .66879 .40954 L p
1 g
F P
s
P
p
.002 w
.56108 .27822 m .51484 .25989 L .50629 .27593 L p
1 g
F P
s
P
p
.002 w
.46259 .27436 m .50629 .27593 L .51484 .25989 L p
1 g
F P
s
P
p
.002 w
.64185 .35163 m .61564 .30437 L .59794 .31054 L p
1 g
F P
s
P
p
.002 w
.56108 .27822 m .59794 .31054 L .61564 .30437 L p
1 g
F P
s
P
p
.002 w
.34327 .34567 m .32898 .3948 L .34586 .39242 L p
1 g
F P
s
P
p
.002 w
.34586 .39242 m .35825 .35004 L .34327 .34567 L p
1 g
F P
s
P
p
.002 w
.37348 .56091 m .4248 .58818 L .42456 .57053 L p
1 g
F P
s
P
p
.002 w
.42456 .57053 m .37697 .54507 L .37348 .56091 L p
1 g
F P
s
P
p
.002 w
.54743 .60156 m .60185 .57328 L .59173 .56071 L p
1 g
F P
s
P
p
.002 w
.59173 .56071 m .53976 .58767 L .54743 .60156 L p
1 g
F P
s
P
p
.002 w
.63308 .51915 m .59173 .56071 L .60185 .57328 L p
1 g
F P
s
P
p
.002 w
.60185 .57328 m .64516 .52977 L .63308 .51915 L p
1 g
F P
s
P
p
.002 w
.65971 .46708 m .63308 .51915 L .64516 .52977 L p
1 g
F P
s
P
p
.002 w
.51484 .25989 m .46425 .25797 L .46259 .27436 L p
1 g
F P
s
P
p
.002 w
.42019 .28737 m .46259 .27436 L .46425 .25797 L p
1 g
F P
s
P
p
.002 w
.31908 .45421 m .34036 .50497 L .35065 .4907 L p
1 g
F P
s
P
p
.002 w
.35065 .4907 m .33166 .44504 L .31908 .45421 L p
1 g
F P
s
P
p
.002 w
.48719 .61169 m .54743 .60156 L .53976 .58767 L p
1 g
F P
s
P
p
.002 w
.53976 .58767 m .48221 .59725 L .48719 .61169 L p
1 g
F P
s
P
p
.002 w
.66879 .40954 m .65904 .35228 L .64185 .35163 L p
1 g
F P
s
P
p
.002 w
.61564 .30437 m .64185 .35163 L .65904 .35228 L p
1 g
F P
s
P
p
.002 w
.3731 .3034 m .34327 .34567 L .35825 .35004 L p
1 g
F P
s
P
p
.002 w
.35825 .35004 m .384 .3136 L .3731 .3034 L p
1 g
F P
s
P
p
.002 w
.64516 .52977 m .67311 .47526 L .65971 .46708 L p
1 g
F P
s
P
p
.002 w
.66879 .40954 m .65971 .46708 L .67311 .47526 L p
1 g
F P
s
P
p
.002 w
.46425 .25797 m .41508 .27299 L .42019 .28737 L p
1 g
F P
s
P
p
.002 w
.384 .3136 m .42019 .28737 L .41508 .27299 L p
1 g
F P
s
P
p
.002 w
.61564 .30437 m .57476 .2683 L .56108 .27822 L p
1 g
F P
s
P
p
.002 w
.51484 .25989 m .56108 .27822 L .57476 .2683 L p
1 g
F P
s
P
p
.002 w
.41508 .27299 m .3731 .3034 L .384 .3136 L p
1 g
F P
s
P
p
.002 w
.42705 .60231 m .48719 .61169 L .48221 .59725 L p
1 g
F P
s
P
p
.002 w
.48221 .59725 m .4248 .58818 L .42705 .60231 L p
1 g
F P
s
P
p
.002 w
.33392 .51781 m .37348 .56091 L .37697 .54507 L p
1 g
F P
s
P
p
.002 w
.37697 .54507 m .34036 .50497 L .33392 .51781 L p
1 g
F P
s
P
p
.002 w
.31599 .39823 m .31908 .45421 L .33166 .44504 L p
1 g
F P
s
P
p
.002 w
.33166 .44504 m .32898 .3948 L .31599 .39823 L p
1 g
F P
s
P
p
.002 w
.67311 .47526 m .68272 .41502 L .66879 .40954 L p
1 g
F P
s
P
p
.002 w
.65904 .35228 m .66879 .40954 L .68272 .41502 L p
1 g
F P
s
P
p
.002 w
.65904 .35228 m .63095 .30131 L .61564 .30437 L p
1 g
F P
s
P
p
.002 w
.57476 .2683 m .61564 .30437 L .63095 .30131 L p
1 g
F P
s
P
p
.002 w
.57476 .2683 m .52333 .24776 L .51484 .25989 L p
1 g
F P
s
P
p
.002 w
.46425 .25797 m .51484 .25989 L .52333 .24776 L p
1 g
F P
s
P
p
.002 w
.37325 .57387 m .42705 .60231 L .4248 .58818 L p
1 g
F P
s
P
p
.002 w
.4248 .58818 m .37348 .56091 L .37325 .57387 L p
1 g
F P
s
P
p
.002 w
.33187 .3434 m .31599 .39823 L .32898 .3948 L p
1 g
F P
s
P
p
.002 w
.32898 .3948 m .34327 .34567 L .33187 .3434 L p
1 g
F P
s
P
p
.002 w
.55415 .61144 m .60965 .58255 L .60185 .57328 L p
1 g
F P
s
P
p
.002 w
.60185 .57328 m .54743 .60156 L .55415 .61144 L p
1 g
F P
s
P
p
.002 w
.64516 .52977 m .60185 .57328 L .60965 .58255 L p
1 g
F P
s
P
p
.002 w
.60965 .58255 m .65385 .53816 L .64516 .52977 L p
1 g
F P
s
P
p
.002 w
.67311 .47526 m .64516 .52977 L .65385 .53816 L p
1 g
F P
s
P
p
.002 w
.31087 .46311 m .33392 .51781 L .34036 .50497 L p
1 g
F P
s
P
p
.002 w
.34036 .50497 m .31908 .45421 L .31087 .46311 L p
1 g
F P
s
P
p
.002 w
.52333 .24776 m .46693 .24553 L .46425 .25797 L p
1 g
F P
s
P
p
.002 w
.41508 .27299 m .46425 .25797 L .46693 .24553 L p
1 g
F P
s
P
p
.002 w
.68272 .41502 m .67264 .35504 L .65904 .35228 L p
1 g
F P
s
P
p
.002 w
.63095 .30131 m .65904 .35228 L .67264 .35504 L p
1 g
F P
s
P
p
.002 w
.4927 .62185 m .55415 .61144 L .54743 .60156 L p
1 g
F P
s
P
p
.002 w
.54743 .60156 m .48719 .61169 L .4927 .62185 L p
1 g
F P
s
P
p
.002 w
.36516 .2962 m .33187 .3434 L .34327 .34567 L p
1 g
F P
s
P
p
.002 w
.34327 .34567 m .3731 .3034 L .36516 .2962 L p
1 g
F P
s
P
p
.002 w
.63095 .30131 m .58698 .26232 L .57476 .2683 L p
1 g
F P
s
P
p
.002 w
.52333 .24776 m .57476 .2683 L .58698 .26232 L p
1 g
F P
s
P
p
.002 w
.65385 .53816 m .68241 .48257 L .67311 .47526 L p
1 g
F P
s
P
p
.002 w
.68272 .41502 m .67311 .47526 L .68241 .48257 L p
1 g
F P
s
P
p
.002 w
.46693 .24553 m .41204 .26225 L .41508 .27299 L p
1 g
F P
s
P
p
.002 w
.3731 .3034 m .41508 .27299 L .41204 .26225 L p
1 g
F P
s
P
p
.002 w
.41204 .26225 m .36516 .2962 L .3731 .3034 L p
1 g
F P
s
P
p
.002 w
.43137 .61237 m .4927 .62185 L .48719 .61169 L p
1 g
F P
s
P
p
.002 w
.48719 .61169 m .42705 .60231 L .43137 .61237 L p
1 g
F P
s
P
p
.002 w
.33174 .52879 m .37325 .57387 L .37348 .56091 L p
1 g
F P
s
P
p
.002 w
.37348 .56091 m .33392 .51781 L .33174 .52879 L p
1 g
F P
s
P
p
.002 w
.30746 .40268 m .31087 .46311 L .31908 .45421 L p
1 g
F P
s
P
p
.002 w
.31908 .45421 m .31599 .39823 L .30746 .40268 L p
1 g
F P
s
P
p
.002 w
.68241 .48257 m .6923 .42114 L .68272 .41502 L p
1 g
F P
s
P
p
.002 w
.67264 .35504 m .68272 .41502 L .6923 .42114 L p
1 g
F P
s
P
p
.002 w
.67264 .35504 m .64333 .3016 L .63095 .30131 L p
1 g
F P
s
P
p
.002 w
.58698 .26232 m .63095 .30131 L .64333 .3016 L p
1 g
F P
s
P
p
.002 w
.58698 .26232 m .53153 .24008 L .52333 .24776 L p
1 g
F P
s
P
p
.002 w
.46693 .24553 m .52333 .24776 L .53153 .24008 L p
1 g
F P
s
P
p
.002 w
.37649 .58344 m .43137 .61237 L .42705 .60231 L p
1 g
F P
s
P
p
.002 w
.42705 .60231 m .37325 .57387 L .37649 .58344 L p
1 g
F P
s
P
p
.002 w
.32458 .34341 m .30746 .40268 L .31599 .39823 L p
1 g
F P
s
P
p
.002 w
.31599 .39823 m .33187 .3434 L .32458 .34341 L p
1 g
F P
s
P
p
.002 w
.55967 .61681 m .61481 .58808 L .60965 .58255 L p
1 g
F P
s
P
p
.002 w
.60965 .58255 m .55415 .61144 L .55967 .61681 L p
1 g
F P
s
P
p
.002 w
.65385 .53816 m .60965 .58255 L .61481 .58808 L p
1 g
F P
s
P
p
.002 w
.30751 .47148 m .33174 .52879 L .33392 .51781 L p
1 g
F P
s
P
p
.002 w
.33392 .51781 m .31087 .46311 L .30751 .47148 L p
1 g
F P
s
P
p
.002 w
.61481 .58808 m .65873 .54398 L .65385 .53816 L p
1 g
F P
s
P
p
.002 w
.68241 .48257 m .65385 .53816 L .65873 .54398 L p
1 g
F P
s
P
p
.002 w
.53153 .24008 m .47062 .2376 L .46693 .24553 L p
1 g
F P
s
P
p
.002 w
.41204 .26225 m .46693 .24553 L .47062 .2376 L p
1 g
F P
s
P
p
.002 w
.6923 .42114 m .6821 .35997 L .67264 .35504 L p
1 g
F P
s
P
p
.002 w
.64333 .3016 m .67264 .35504 L .6821 .35997 L p
1 g
F P
s
P
p
.002 w
.49866 .62718 m .55967 .61681 L .55415 .61144 L p
1 g
F P
s
P
p
.002 w
.55415 .61144 m .4927 .62185 L .49866 .62718 L p
1 g
F P
s
P
p
.002 w
.64333 .3016 m .59732 .26069 L .58698 .26232 L p
1 g
F P
s
P
p
.002 w
.53153 .24008 m .58698 .26232 L .59732 .26069 L p
1 g
F P
s
P
p
.002 w
.36057 .29235 m .32458 .34341 L .33187 .3434 L p
1 g
F P
s
P
p
.002 w
.33187 .3434 m .36516 .2962 L .36057 .29235 L p
1 g
F P
s
P
p
.002 w
.65873 .54398 m .68713 .48876 L .68241 .48257 L p
1 g
F P
s
P
p
.002 w
.6923 .42114 m .68241 .48257 L .68713 .48876 L p
1 g
F P
s
P
p
.002 w
.47062 .2376 m .41127 .25565 L .41204 .26225 L p
1 g
F P
s
P
p
.002 w
.36516 .2962 m .41204 .26225 L .41127 .25565 L p
1 g
F P
s
P
p
.002 w
.41127 .25565 m .36057 .29235 L .36516 .2962 L p
1 g
F P
s
P
p
.002 w
.33413 .53751 m .37649 .58344 L .37325 .57387 L p
1 g
F P
s
P
p
.002 w
.37325 .57387 m .33174 .52879 L .33413 .53751 L p
1 g
F P
s
P
p
.002 w
.43778 .61781 m .49866 .62718 L .4927 .62185 L p
1 g
F P
s
P
p
.002 w
.4927 .62185 m .43137 .61237 L .43778 .61781 L p
1 g
F P
s
P
p
.002 w
.3039 .40809 m .30751 .47148 L .31087 .46311 L p
1 g
F P
s
P
p
.002 w
.31087 .46311 m .30746 .40268 L .3039 .40809 L p
1 g
F P
s
P
p
.002 w
.68713 .48876 m .69698 .42778 L .6923 .42114 L p
1 g
F P
s
P
p
.002 w
.6821 .35997 m .6923 .42114 L .69698 .42778 L p
1 g
F P
s
P
p
.002 w
.6821 .35997 m .65228 .30546 L .64333 .3016 L p
1 g
F P
s
P
p
.002 w
.59732 .26069 m .64333 .3016 L .65228 .30546 L p
1 g
F P
s
P
p
.002 w
.59732 .26069 m .5392 .23731 L .53153 .24008 L p
1 g
F P
s
P
p
.002 w
.47062 .2376 m .53153 .24008 L .5392 .23731 L p
1 g
F P
s
P
p
.002 w
.38333 .58913 m .43778 .61781 L .43137 .61237 L p
1 g
F P
s
P
p
.002 w
.43137 .61237 m .37649 .58344 L .38333 .58913 L p
1 g
F P
s
P
p
.002 w
.32186 .34585 m .3039 .40809 L .30746 .40268 L p
1 g
F P
s
P
p
.002 w
.30746 .40268 m .32458 .34341 L .32186 .34585 L p
1 g
F P
s
P
p
.002 w
.30941 .47907 m .33413 .53751 L .33174 .52879 L p
1 g
F P
s
P
p
.002 w
.33174 .52879 m .30751 .47148 L .30941 .47907 L p
1 g
F P
s
P
p
.002 w
.56377 .61722 m .617 .58948 L .61481 .58808 L p
1 g
F P
s
P
p
.002 w
.61481 .58808 m .55967 .61681 L .56377 .61722 L p
1 g
F P
s
P
p
.002 w
.65873 .54398 m .61481 .58808 L .617 .58948 L p
1 g
F P
s
P
p
.002 w
.617 .58948 m .65941 .54689 L .65873 .54398 L p
1 g
F P
s
P
p
.002 w
.68713 .48876 m .65873 .54398 L .65941 .54689 L p
1 g
F P
s
P
p
.002 w
.5392 .23731 m .47528 .23469 L .47062 .2376 L p
1 g
F P
s
P
p
.002 w
.41127 .25565 m .47062 .2376 L .47528 .23469 L p
1 g
F P
s
P
p
.002 w
.69698 .42778 m .6869 .36708 L .6821 .35997 L p
1 g
F P
s
P
p
.002 w
.65228 .30546 m .6821 .35997 L .6869 .36708 L p
1 g
F P
s
P
p
.002 w
.50491 .62723 m .56377 .61722 L .55967 .61681 L p
1 g
F P
s
P
p
.002 w
.55967 .61681 m .49866 .62718 L .50491 .62723 L p
1 g
F P
s
P
p
.004 w
.37393 .60654 m
.38247 .59462 L
s
P
p
.004 w
.36831 .61438 m
.37393 .60654 L
s
P
p
.004 w
.34088 .65268 m
.36831 .61438 L
s
P
p
.002 w
.65228 .30546 m .6054 .26373 L .59732 .26069 L p
1 g
F P
s
P
p
.002 w
.5392 .23731 m .59732 .26069 L .6054 .26373 L p
1 g
F P
s
P
p
.002 w
.35967 .29221 m .32186 .34585 L .32458 .34341 L p
1 g
F P
s
P
p
.002 w
.32458 .34341 m .36057 .29235 L .35967 .29221 L p
1 g
F P
s
P
p
.002 w
.65941 .54689 m .68682 .49361 L .68713 .48876 L p
1 g
F P
s
P
p
.002 w
.69698 .42778 m .68713 .48876 L .68682 .49361 L p
1 g
F P
s
P
p
.002 w
.47528 .23469 m .41295 .25364 L .41127 .25565 L p
1 g
F P
s
P
p
.002 w
.36057 .29235 m .41127 .25565 L .41295 .25364 L p
1 g
F P
s
P
p
.002 w
.41295 .25364 m .35967 .29221 L .36057 .29235 L p
1 g
F P
s
P
p
.002 w
.34133 .54358 m .38333 .58913 L .37649 .58344 L p
1 g
F P
s
P
p
.002 w
.37649 .58344 m .33413 .53751 L .34133 .54358 L p
1 g
F P
s
P
p
.002 w
.44622 .61819 m .50491 .62723 L .49866 .62718 L p
1 g
F P
s
P
p
.002 w
.49866 .62718 m .43778 .61781 L .44622 .61819 L p
1 g
F P
s
P
p
.002 w
.30573 .41437 m .30941 .47907 L .30751 .47148 L p
1 g
F P
s
P
p
.002 w
.30751 .47148 m .3039 .40809 L .30573 .41437 L p
1 g
F P
s
P
p
.002 w
.68682 .49361 m .69634 .43479 L .69698 .42778 L p
1 g
F P
s
P
p
.002 w
.6869 .36708 m .69698 .42778 L .69634 .43479 L p
1 g
F P
s
P
p
.002 w
.6869 .36708 m .65733 .31301 L .65228 .30546 L p
1 g
F P
s
P
p
.002 w
.6054 .26373 m .65228 .30546 L .65733 .31301 L p
1 g
F P
s
P
p
.002 w
.6054 .26373 m .54611 .23987 L .5392 .23731 L p
1 g
F P
s
P
p
.002 w
.47528 .23469 m .5392 .23731 L .54611 .23987 L p
1 g
F P
s
P
p
.002 w
.39379 .59053 m .44622 .61819 L .43778 .61781 L p
1 g
F P
s
P
p
.002 w
.43778 .61781 m .38333 .58913 L .39379 .59053 L p
1 g
F P
s
P
p
.002 w
.32411 .35082 m .30573 .41437 L .3039 .40809 L p
1 g
F P
s
P
p
.002 w
.3039 .40809 m .32186 .34585 L .32411 .35082 L p
1 g
F P
s
P
p
.002 w
.31685 .4856 m .34133 .54358 L .33413 .53751 L p
1 g
F P
s
P
p
.002 w
.33413 .53751 m .30941 .47907 L .31685 .4856 L p
1 g
F P
s
P
p
.002 w
.56624 .61233 m .61596 .58643 L .617 .58948 L p
1 g
F P
s
P
p
.002 w
.617 .58948 m .56377 .61722 L .56624 .61233 L p
1 g
F P
s
P
p
.002 w
.65941 .54689 m .617 .58948 L .61596 .58643 L p
1 g
F P
s
P
p
.002 w
.54611 .23987 m .48086 .23722 L .47528 .23469 L p
1 g
F P
s
P
p
.002 w
.41295 .25364 m .47528 .23469 L .48086 .23722 L p
1 g
F P
s
P
p
.002 w
.61596 .58643 m .65558 .54664 L .65941 .54689 L p
1 g
F P
s
P
p
.002 w
.68682 .49361 m .65941 .54689 L .65558 .54664 L p
1 g
F P
s
P
p
.002 w
.69634 .43479 m .6866 .37629 L .6869 .36708 L p
1 g
F P
s
P
p
.002 w
.65733 .31301 m .6869 .36708 L .6866 .37629 L p
1 g
F P
s
P
p
.002 w
.65733 .31301 m .61082 .27164 L .6054 .26373 L p
1 g
F P
s
P
p
.002 w
.54611 .23987 m .6054 .26373 L .61082 .27164 L p
1 g
F P
s
P
p
.002 w
.51129 .62165 m .56624 .61233 L .56377 .61722 L p
1 g
F P
s
P
p
.002 w
.56377 .61722 m .50491 .62723 L .51129 .62165 L p
1 g
F P
s
P
p
.002 w
.36275 .29601 m .32411 .35082 L .32186 .34585 L p
1 g
F P
s
P
p
.002 w
.32186 .34585 m .35967 .29221 L .36275 .29601 L p
1 g
F P
s
P
p
.002 w
.65558 .54664 m .68118 .49686 L .68682 .49361 L p
1 g
F P
s
P
p
.002 w
.69634 .43479 m .68682 .49361 L .68118 .49686 L p
1 g
F P
s
P
p
.002 w
.48086 .23722 m .41719 .25659 L .41295 .25364 L p
1 g
F P
s
P
p
.002 w
.35967 .29221 m .41295 .25364 L .41719 .25659 L p
1 g
F P
s
P
p
.002 w
.41719 .25659 m .36275 .29601 L .35967 .29221 L p
1 g
F P
s
P
p
.002 w
.35342 .54663 m .39379 .59053 L .38333 .58913 L p
1 g
F P
s
P
p
.002 w
.38333 .58913 m .34133 .54358 L .35342 .54663 L p
1 g
F P
s
P
p
.002 w
.45657 .61317 m .51129 .62165 L .50491 .62723 L p
1 g
F P
s
P
p
.002 w
.50491 .62723 m .44622 .61819 L .45657 .61317 L p
1 g
F P
s
P
p
.002 w
.31327 .42139 m .31685 .4856 L .30941 .47907 L p
1 g
F P
s
P
p
.002 w
.30941 .47907 m .30573 .41437 L .31327 .42139 L p
1 g
F P
s
P
p
.002 w
.68118 .49686 m .69002 .44197 L .69634 .43479 L p
1 g
F P
s
P
p
.002 w
.6866 .37629 m .69634 .43479 L .69002 .44197 L p
1 g
F P
s
P
p
.002 w
.6866 .37629 m .65808 .32424 L .65733 .31301 L p
1 g
F P
s
P
p
.002 w
.61082 .27164 m .65733 .31301 L .65808 .32424 L p
1 g
F P
s
P
p
.002 w
.61082 .27164 m .55199 .24803 L .54611 .23987 L p
1 g
F P
s
P
p
.002 w
.48086 .23722 m .54611 .23987 L .55199 .24803 L p
1 g
F P
s
P
p
.002 w
.40779 .58732 m .45657 .61317 L .44622 .61819 L p
1 g
F P
s
P
p
.002 w
.44622 .61819 m .39379 .59053 L .40779 .58732 L p
1 g
F P
s
P
p
.002 w
.33157 .35832 m .31327 .42139 L .30573 .41437 L p
1 g
F P
s
P
p
.002 w
.30573 .41437 m .32411 .35082 L .33157 .35832 L p
1 g
F P
s
P
p
.002 w
.32996 .49078 m .35342 .54663 L .34133 .54358 L p
1 g
F P
s
P
p
.002 w
.34133 .54358 m .31685 .4856 L .32996 .49078 L p
1 g
F P
s
P
p
.002 w
.69002 .44197 m .68088 .38746 L .6866 .37629 L p
1 g
F P
s
P
p
.002 w
.65808 .32424 m .6866 .37629 L .68088 .38746 L p
1 g
F P
s
P
p
.002 w
.56689 .60194 m .61152 .57871 L .61596 .58643 L p
1 g
F P
s
P
p
.002 w
.61596 .58643 m .56624 .61233 L .56689 .60194 L p
1 g
F P
s
P
p
.002 w
.65558 .54664 m .61596 .58643 L .61152 .57871 L p
1 g
F P
s
P
p
.002 w
.55199 .24803 m .48723 .24546 L .48086 .23722 L p
1 g
F P
s
P
p
.002 w
.41719 .25659 m .48086 .23722 L .48723 .24546 L p
1 g
F P
s
P
p
.002 w
.61152 .57871 m .64708 .543 L .65558 .54664 L p
1 g
F P
s
P
p
.002 w
.68118 .49686 m .65558 .54664 L .64708 .543 L p
1 g
F P
s
P
p
.002 w
.65808 .32424 m .61326 .28449 L .61082 .27164 L p
1 g
F P
s
P
p
.002 w
.55199 .24803 m .61082 .27164 L .61326 .28449 L p
1 g
F P
s
P
p
.002 w
.51761 .61024 m .56689 .60194 L .56624 .61233 L p
1 g
F P
s
P
p
.002 w
.56624 .61233 m .51129 .62165 L .51761 .61024 L p
1 g
F P
s
P
p
.002 w
.36997 .3039 m .33157 .35832 L .32411 .35082 L p
1 g
F P
s
P
p
.002 w
.32411 .35082 m .36275 .29601 L .36997 .3039 L p
1 g
F P
s
P
p
.002 w
.64708 .543 m .67001 .49833 L .68118 .49686 L p
1 g
F P
s
P
p
.002 w
.69002 .44197 m .68118 .49686 L .67001 .49833 L p
1 g
F P
s
P
p
.002 w
.48723 .24546 m .42403 .26474 L .41719 .25659 L p
1 g
F P
s
P
p
.002 w
.36275 .29601 m .41719 .25659 L .42403 .26474 L p
1 g
F P
s
P
p
.002 w
.42403 .26474 m .36997 .3039 L .36275 .29601 L p
1 g
F P
s
P
p
.002 w
.37032 .54638 m .40779 .58732 L .39379 .59053 L p
1 g
F P
s
P
p
.002 w
.39379 .59053 m .35342 .54663 L .37032 .54638 L p
1 g
F P
s
P
p
.004 w
.38247 .59462 m
.3869 .58842 L
s
P
p
.002 w
.46863 .60256 m .51761 .61024 L .51129 .62165 L p
1 g
F P
s
P
p
.002 w
.51129 .62165 m .45657 .61317 L .46863 .60256 L p
1 g
F P
s
P
p
.002 w
.32663 .42897 m .32996 .49078 L .31685 .4856 L p
1 g
F P
s
P
p
.002 w
.31685 .4856 m .31327 .42139 L .32663 .42897 L p
1 g
F P
s
P
p
.002 w
.68088 .38746 m .65423 .33906 L .65808 .32424 L p
1 g
F P
s
P
p
.002 w
.61326 .28449 m .65808 .32424 L .65423 .33906 L p
1 g
F P
s
P
p
.002 w
.67001 .49833 m .67787 .44912 L .69002 .44197 L p
1 g
F P
s
P
p
.002 w
.68088 .38746 m .69002 .44197 L .67787 .44912 L p
1 g
F P
s
P
p
.002 w
.61326 .28449 m .55659 .26187 L .55199 .24803 L p
1 g
F P
s
P
p
.002 w
.48723 .24546 m .55199 .24803 L .55659 .26187 L p
1 g
F P
s
P
p
.002 w
.42507 .57933 m .46863 .60256 L .45657 .61317 L p
1 g
F P
s
P
p
.002 w
.45657 .61317 m .40779 .58732 L .42507 .57933 L p
1 g
F P
s
P
p
.002 w
.34865 .49438 m .37032 .54638 L .35342 .54663 L p
1 g
F P
s
P
p
.002 w
.35342 .54663 m .32996 .49078 L .34865 .49438 L p
1 g
F P
s
P
p
.002 w
.34433 .36827 m .32663 .42897 L .31327 .42139 L p
1 g
F P
s
P
p
.002 w
.31327 .42139 m .33157 .35832 L .34433 .36827 L p
1 g
F P
s
P
p
.002 w
.67787 .44912 m .66958 .40035 L .68088 .38746 L p
1 g
F P
s
P
p
.002 w
.65423 .33906 m .68088 .38746 L .66958 .40035 L p
1 g
F P
s
P
p
.002 w
.55659 .26187 m .49424 .25951 L .48723 .24546 L p
1 g
F P
s
P
p
.002 w
.42403 .26474 m .48723 .24546 L .49424 .25951 L p
1 g
F P
s
P
p
.002 w
.56558 .58604 m .60359 .56629 L .61152 .57871 L p
1 g
F P
s
P
p
.002 w
.61152 .57871 m .56689 .60194 L .56558 .58604 L p
1 g
F P
s
P
p
.002 w
.64708 .543 m .61152 .57871 L .60359 .56629 L p
1 g
F P
s
P
p
.002 w
.60359 .56629 m .63387 .53587 L .64708 .543 L p
1 g
F P
s
P
p
.002 w
.67001 .49833 m .64708 .543 L .63387 .53587 L p
1 g
F P
s
P
p
.002 w
.65423 .33906 m .61243 .30218 L .61326 .28449 L p
1 g
F P
s
P
p
.002 w
.55659 .26187 m .61326 .28449 L .61243 .30218 L p
1 g
F P
s
P
p
.002 w
.52366 .59303 m .56558 .58604 L .56689 .60194 L p
1 g
F P
s
P
p
.002 w
.56689 .60194 m .51761 .61024 L .52366 .59303 L p
1 g
F P
s
P
p
.002 w
.38135 .31589 m .34433 .36827 L .33157 .35832 L p
1 g
F P
s
P
p
.002 w
.33157 .35832 m .36997 .3039 L .38135 .31589 L p
1 g
F P
s
P
p
.002 w
.63387 .53587 m .65334 .49784 L .67001 .49833 L p
1 g
F P
s
P
p
.002 w
.67787 .44912 m .67001 .49833 L .65334 .49784 L p
1 g
F P
s
P
p
.002 w
.49424 .25951 m .4334 .27815 L .42403 .26474 L p
1 g
F P
s
P
p
.002 w
.36997 .3039 m .42403 .26474 L .4334 .27815 L p
1 g
F P
s
P
p
.002 w
.39173 .54264 m .42507 .57933 L .40779 .58732 L p
1 g
F P
s
P
p
.002 w
.40779 .58732 m .37032 .54638 L .39173 .54264 L p
1 g
F P
s
P
p
.004 w
.39462 .57765 m
.39855 .57216 L
s
P
p
.004 w
.40737 .55985 m
.5 .43051 L
s
P
p
.004 w
.39855 .57216 m
.39934 .57106 L
s
P
p
.004 w
.3869 .58842 m
.39462 .57765 L
s
P
p
.002 w
.4334 .27815 m .38135 .31589 L .36997 .3039 L p
1 g
F P
s
P
p
.002 w
.48208 .58639 m .52366 .59303 L .51761 .61024 L p
1 g
F P
s
P
p
.002 w
.51761 .61024 m .46863 .60256 L .48208 .58639 L p
1 g
F P
s
P
p
.002 w
.3457 .43689 m .34865 .49438 L .32996 .49078 L p
1 g
F P
s
P
p
.002 w
.32996 .49078 m .32663 .42897 L .3457 .43689 L p
1 g
F P
s
P
p
.002 w
.66958 .40035 m .64564 .35716 L .65423 .33906 L p
1 g
F P
s
P
p
.002 w
.61243 .30218 m .65423 .33906 L .64564 .35716 L p
1 g
F P
s
P
p
.002 w
.65334 .49784 m .65994 .456 L .67787 .44912 L p
1 g
F P
s
P
p
.002 w
.66958 .40035 m .67787 .44912 L .65994 .456 L p
1 g
F P
s
P
p
.002 w
.61243 .30218 m .55967 .2813 L .55659 .26187 L p
1 g
F P
s
P
p
.002 w
.49424 .25951 m .55659 .26187 L .55967 .2813 L p
1 g
F P
s
P
p
.002 w
.44522 .56656 m .48208 .58639 L .46863 .60256 L p
1 g
F P
s
P
p
.002 w
.46863 .60256 m .42507 .57933 L .44522 .56656 L p
1 g
F P
s
P
p
.002 w
.37257 .49616 m .39173 .54264 L .37032 .54638 L p
1 g
F P
s
P
p
.002 w
.37032 .54638 m .34865 .49438 L .37257 .49616 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.36228 .38047 m .3457 .43689 L .32663 .42897 L p
1 g
F P
s
P
p
.002 w
.32663 .42897 m .34433 .36827 L .36228 .38047 L p
1 g
F P
s
P
p
.002 w
.65994 .456 m .65278 .41463 L .66958 .40035 L p
1 g
F P
s
P
p
.002 w
.64564 .35716 m .66958 .40035 L .65278 .41463 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.55967 .2813 m .50169 .27924 L .49424 .25951 L p
1 g
F P
s
P
p
.002 w
.4334 .27815 m .49424 .25951 L .50169 .27924 L p
1 g
F P
s
P
p
.002 w
.56225 .56484 m .59224 .54931 L .60359 .56629 L p
1 g
F P
s
P
p
.002 w
.60359 .56629 m .56558 .58604 L .56225 .56484 L p
1 g
F P
s
P
p
.002 w
.63387 .53587 m .60359 .56629 L .59224 .54931 L p
1 g
F P
s
P
p
.002 w
.64564 .35716 m .6082 .32438 L .61243 .30218 L p
1 g
F P
s
P
p
.002 w
.55967 .2813 m .61243 .30218 L .6082 .32438 L p
1 g
F P
s
P
p
.002 w
.59224 .54931 m .61611 .5253 L .63387 .53587 L p
1 g
F P
s
P
p
.002 w
.65334 .49784 m .63387 .53587 L .61611 .5253 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .5746 L p
1 g
F P
s
P
p
.002 w
.56225 .56484 m .56558 .58604 L p
.53477 .57269 L 1 g
F P
s
P
p
.002 w
.54202 .56817 m .56225 .56484 L p
.53477 .57269 L 1 g
F P
s
P
p
.54854 .56129 m .5317 .5746 L .54 .56943 L 1 g
F
P
p
.002 w
.56558 .58604 m .52366 .59303 L .5278 .57605 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58002 L p
1 g
F P
s
P
p
.002 w
.5278 .57605 m .52366 .59303 L p
.51105 .57998 L 1 g
F P
s
P
p
.53128 .57265 m .5109 .58002 L .52056 .57775 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48208 .58639 m .48595 .58066 L p
.49963 .58251 L 1 g
F P
s
P
p
.002 w
.48595 .58066 m .48634 .58008 L p
.48906 .58058 L 1 g
F P
s
P
p
.49963 .58251 m .48595 .58066 L .48906 .58058 L 1 g
F
P
p
.002 w
.5109 .58002 m .51079 .57862 L p
.50276 .58023 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58058 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58058 L .50276 .58023 L 1 g
F
P
p
.51105 .57998 m .51088 .58002 L .49653 .56494 L 1 g
F
P
p
.51088 .58002 m .49963 .58251 L .49924 .58032 L 1 g
F
P
p
.51088 .58002 m .49924 .58032 L .49653 .56494 L 1 g
F
P
p
.002 w
.48906 .58058 m .48921 .57862 L p
.47957 .57783 L 1 g
F P
s
P
p
.002 w
.48634 .58008 m .48208 .58639 L p
.47864 .57752 L 1 g
F P
s
P
p
.002 w
.48208 .58639 m .44522 .56656 L .44537 .56645 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.48208 .58639 m .44537 .56645 L .4684 .57411 L 1 g
F
P
p
.48013 .58134 m .4684 .57411 L .47864 .57752 L 1 g
F
P
p
.48208 .58639 m .4684 .57411 L .48013 .58134 L 1 g
F
P
p
.002 w
.4684 .57411 m .46872 .57265 L p
.46108 .5696 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4684 .57411 L p
1 g
F P
s
P
p
.002 w
.4684 .57411 m .4678 .57686 L p
.47957 .57783 L 1 g
F P
s
P
p
.48921 .57862 m .4684 .57411 L .47957 .57783 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45074 .56322 L p
1 g
F P
s
P
p
.002 w
.44537 .56645 m .45008 .56281 L p
.45074 .56322 L 1 g
F P
s
P
p
.4684 .57411 m .45755 .5705 L .45074 .56322 L 1 g
F
P
p
.45755 .5705 m .44537 .56645 L .45074 .56322 L 1 g
F
P
p
.002 w
.45074 .56322 m .45146 .56129 L p
.44539 .55602 L 1 g
F P
s
P
p
.002 w
.45024 .56269 m .44522 .56656 L p
.44537 .55598 L 1 g
F P
s
P
p
.002 w
.44522 .56656 m .41714 .53537 L .42756 .53148 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.44522 .56656 m .42756 .53148 L .43866 .54676 L 1 g
F
P
p
.44523 .56592 m .43866 .54676 L .44537 .55598 L 1 g
F
P
p
.44522 .56656 m .43866 .54676 L .44523 .56592 L 1 g
F
P
p
.002 w
.43866 .54676 m .43925 .54566 L p
.43626 .53974 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43866 .54676 L p
1 g
F P
s
P
p
.002 w
.43866 .54676 m .43743 .5491 L p
.44539 .55602 L 1 g
F P
s
P
p
.45146 .56129 m .43866 .54676 L .44539 .55602 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43255 .52867 L p
1 g
F P
s
P
p
.43925 .54566 m .43255 .52867 L .43269 .52925 L 1 g
F
P
p
.41714 .53537 m .42765 .50851 L .43255 .52867 L 1 g
F
P
p
.002 w
.43276 .52954 m .43247 .52965 L p
.43255 .52867 L 1 g
F P
s
P
p
.002 w
.43247 .52965 m .41714 .53537 L p
.43255 .52867 L 1 g
F P
s
P
p
.002 w
.43255 .52867 m .43346 .52734 L p
.43321 .52015 L 1 g
F P
s
P
p
.43925 .54566 m .43269 .52925 L .43626 .53974 L 1 g
F
P
p
.43269 .52925 m .43249 .52875 L .43276 .52954 L 1 g
F
P
p
.43269 .52925 m .43276 .52954 L .43626 .53974 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43406 .5092 L p
1 g
F P
s
P
p
.42765 .50851 m .43342 .49378 L .43309 .51129 L 1 g
F
P
p
.4304 .51714 m .43309 .51129 L .43285 .52483 L 1 g
F
P
p
.42765 .50851 m .43309 .51129 L .4304 .51714 L 1 g
F
P
p
.002 w
.43406 .5092 m .43485 .50826 L p
.43851 .4997 L 1 g
F P
s
P
p
.002 w
.43702 .50278 m .43342 .49378 L .44187 .49276 L p
1 g
F P
s
P
p
.43851 .4997 m .4394 .49763 L .43702 .50278 L 1 g
F
P
p
.43851 .4997 m .43702 .50278 L .43406 .5092 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43346 .52734 m .43406 .5092 L .43321 .52015 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44579 .52468 m .43276 .52954 L p
.43309 .51129 L 1 g
F P
s
P
p
.002 w
.43342 .49378 m .43702 .50278 L p
.43309 .51129 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44256 .49138 L p
1 g
F P
s
P
p
.43342 .49378 m .44674 .48306 L .44256 .49138 L 1 g
F
P
p
.002 w
.44187 .49276 m .44103 .49286 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44103 .49286 m .43342 .49378 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44256 .49138 m .44201 .49196 L p
.44021 .49607 L 1 g
F P
s
P
p
.43485 .50826 m .44256 .49138 L .44021 .49607 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.46833 .48957 m .44187 .49276 L p
.45376 .48051 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45772 .47667 L p
1 g
F P
s
P
p
.44339 .4905 m .45772 .47667 L .44956 .48459 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45772 .47667 m .45826 .47608 L p
.46941 .47119 L 1 g
F P
s
P
p
.002 w
.47667 .46764 m .50422 .47166 L p
.46774 .47201 L 1 g
F P
s
P
p
.46941 .47119 m .47084 .47056 L .46774 .47201 L 1 g
F
P
p
.46941 .47119 m .46774 .47201 L .45772 .47667 L 1 g
F
P
p
.002 w
.46833 .48957 m .46774 .47201 L p
.50422 .47166 L 1 g
F P
s
P
p
.45376 .48051 m .45772 .47667 L .46833 .48957 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46722 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50422 .47166 m .47667 .46764 L p
.47988 .46687 L 1 g
F P
s
P
p
.002 w
.47753 .46722 m .47786 .46667 L p
.48891 .46555 L 1 g
F P
s
P
p
.47988 .46687 m .5 .46392 L .50422 .47166 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56031 .5033 m .54964 .50879 L .5408 .4761 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54247 .47687 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.56031 .5033 m .54106 .47622 L p
.54344 .47782 L 1 g
F P
s
P
p
.002 w
.59421 .51148 m .57768 .52811 L .56915 .51594 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56611 .50941 L p
1 g
F P
s
P
p
.55661 .4905 m .56611 .50941 L .56401 .50489 L 1 g
F
P
p
.59421 .51148 m .56915 .51594 L .56611 .50941 L 1 g
F
P
p
.56571 .50461 m .56611 .50941 L .56365 .50411 L 1 g
F
P
p
.59421 .51148 m .56611 .50941 L .56571 .50461 L 1 g
F
P
p
.002 w
.56611 .50941 m .56515 .50826 L p
.56685 .51926 L 1 g
F P
s
P
p
.002 w
.56632 .5119 m .57768 .52811 L p
.56695 .52072 L 1 g
F P
s
P
p
.56685 .51926 m .56706 .52062 L .56632 .5119 L 1 g
F
P
p
.56685 .51926 m .56632 .5119 L .56611 .50941 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56752 .52877 L p
1 g
F P
s
P
p
.002 w
.57768 .52811 m .56784 .53319 L p
.56752 .52877 L 1 g
F P
s
P
p
.56924 .5223 m .56752 .52877 L .56695 .52072 L 1 g
F
P
p
.57768 .52811 m .56752 .52877 L .56924 .5223 L 1 g
F
P
p
.002 w
.56752 .52877 m .56654 .52734 L p
.56441 .53899 L 1 g
F P
s
P
p
.002 w
.57768 .52811 m .59224 .54931 L p
.56376 .54088 L 1 g
F P
s
P
p
.002 w
.56611 .53409 m .57768 .52811 L p
.56376 .54088 L 1 g
F P
s
P
p
.002 w
.59224 .54931 m .56225 .56484 L .55972 .55255 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54916 .56297 L p
1 g
F P
s
P
p
.56075 .54566 m .54916 .56297 L .55363 .55743 L 1 g
F
P
p
.002 w
.55928 .55043 m .56225 .56484 L p
.55333 .5578 L 1 g
F P
s
P
p
.002 w
.56225 .56484 m .54542 .56761 L p
.54916 .56297 L 1 g
F P
s
P
p
.55474 .55891 m .54916 .56297 L .55333 .5578 L 1 g
F
P
p
.56225 .56484 m .54916 .56297 L .55474 .55891 L 1 g
F
P
p
.002 w
.54916 .56297 m .54854 .56129 L p
.53906 .57033 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54542 .56761 m .52921 .57028 L p
.55333 .5578 L 1 g
F P
s
P
p
.56558 .58604 m .5278 .57605 L .53573 .5731 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54916 .56297 L p
1 g
F P
s
P
p
.53906 .57033 m .5322 .57686 L .54916 .56297 L 1 g
F
P
p
.55561 .55498 m .54959 .56411 L .55403 .55785 L 1 g
F
P
p
.56075 .54566 m .55363 .55743 L .55561 .55498 L 1 g
F
P
p
.55363 .55743 m .54959 .56411 L .55561 .55498 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52921 .57028 m .53403 .54254 L p
.55333 .5578 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55972 .55255 m .55928 .55043 L p
.56157 .5472 L 1 g
F P
s
P
p
.59224 .54931 m .55972 .55255 L .56157 .5472 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56157 .5472 L p
1 g
F P
s
P
p
.002 w
.56157 .5472 m .56075 .54566 L p
.55403 .55785 L 1 g
F P
s
P
p
.55403 .55785 m .54998 .56518 L .56157 .5472 L 1 g
F
P
p
.56565 .54144 m .56157 .5472 L .56376 .54088 L 1 g
F
P
p
.59224 .54931 m .56157 .5472 L .56565 .54144 L 1 g
F
P
p
.002 w
.53403 .54254 m .5569 .53885 L .55928 .55043 L p
1 g
F P
s
P
p
.55333 .5578 m .53403 .54254 L .55928 .55043 L 1 g
F
P
p
.002 w
.54916 .56297 m .54959 .56411 L p
.55363 .55743 L 1 g
F P
s
P
p
.002 w
.54959 .56411 m .54998 .56518 L p
.55403 .55785 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56376 .54088 m .56157 .5472 L .5569 .53885 L 1 g
F
P
p
.002 w
.55928 .55043 m .5569 .53885 L p
.56157 .5472 L 1 g
F P
s
P
p
.56515 .50826 m .56752 .52877 L .56726 .52505 L 1 g
F
P
p
.56515 .50826 m .56777 .52913 L .56706 .52062 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56752 .52877 m .5569 .53885 L .56695 .52072 L 1 g
F
P
p
.002 w
.56784 .53319 m .56611 .53409 L p
.56752 .52877 L 1 g
F P
s
P
p
.56441 .53899 m .56611 .53409 L .56752 .52877 L 1 g
F
P
p
.002 w
.56611 .53409 m .5569 .53885 L p
.56752 .52877 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56781 .52919 L p
1 g
F P
s
P
p
.002 w
.56781 .52919 m .56752 .52877 L p
.56651 .53295 L 1 g
F P
s
P
p
.56651 .53295 m .56257 .5491 L .56781 .52919 L 1 g
F
P
p
.56441 .53899 m .56355 .54373 L .56611 .53409 L 1 g
F
P
p
.002 w
.5569 .53885 m .56611 .53409 L p
.56376 .54088 L 1 g
F P
s
P
p
.56355 .54373 m .56257 .5491 L .56752 .52877 L 1 g
F
P
p
.002 w
.56752 .52877 m .56777 .52913 L p
.56726 .52505 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.5569 .53885 m .54964 .50879 L p
.56695 .52072 L 1 g
F P
s
P
p
.55661 .4905 m .56401 .50489 L .56304 .5028 L 1 g
F
P
p
.002 w
.56879 .49477 m .59421 .51148 L p
.56365 .50411 L 1 g
F P
s
P
p
.55661 .4905 m .56304 .5028 L .56233 .50127 L 1 g
F
P
p
.002 w
.56494 .49865 m .56233 .50127 L p
.55744 .49138 L 1 g
F P
s
P
p
.002 w
.55801 .49198 m .55744 .49138 L p
.56233 .50127 L 1 g
F P
s
P
p
.002 w
.55744 .49138 m .55661 .4905 L p
.56233 .50127 L 1 g
F P
s
P
p
.55744 .49138 m .56031 .5033 L .54344 .47782 L 1 g
F
P
p
.002 w
.56233 .50127 m .56031 .5033 L p
.55744 .49138 L 1 g
F P
s
P
p
.002 w
.56031 .5033 m .56233 .50127 L p
.56365 .50411 L 1 g
F P
s
P
p
.002 w
.56233 .50127 m .56879 .49477 L p
.56365 .50411 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55801 .49198 L p
1 g
F P
s
P
p
.56304 .5028 m .56713 .51061 L .55801 .49198 L 1 g
F
P
p
.56304 .5028 m .56669 .51009 L .56385 .50435 L 1 g
F
P
p
.56401 .50489 m .56669 .51009 L .56304 .5028 L 1 g
F
P
p
.56365 .50411 m .56611 .50941 L .56031 .5033 L 1 g
F
P
p
.002 w
.56915 .51594 m .56632 .5119 L p
.56611 .50941 L 1 g
F P
s
P
p
.002 w
.56632 .5119 m .56031 .5033 L p
.56611 .50941 L 1 g
F P
s
P
p
.002 w
.56777 .52913 m .56854 .53025 L p
.56706 .52062 L 1 g
F P
s
P
p
.002 w
.54964 .50879 m .56031 .5033 L .56632 .5119 L p
1 g
F P
s
P
p
.56695 .52072 m .54964 .50879 L .56632 .5119 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .50941 L p
1 g
F P
s
P
p
.56706 .52062 m .56854 .53025 L .56611 .50941 L 1 g
F
P
p
.002 w
.56611 .50941 m .56669 .51009 L p
.56401 .50489 L 1 g
F P
s
P
p
.002 w
.56669 .51009 m .56713 .51061 L p
.56385 .50435 L 1 g
F P
s
P
p
.002 w
.56879 .49477 m .56494 .49865 L p
.55744 .49138 L 1 g
F P
s
P
p
.002 w
.54373 .47801 m .55661 .4905 L .55744 .49138 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .54373 .47801 L p
.55744 .49138 L 1 g
F P
s
P
p
.54174 .47608 m .55744 .49138 L .55702 .49097 L 1 g
F
P
p
.55042 .48458 m .55747 .49141 L .55056 .48472 L 1 g
F
P
p
.54174 .47608 m .55702 .49097 L .55042 .48458 L 1 g
F
P
p
.55702 .49097 m .55747 .49141 L .55042 .48458 L 1 g
F
P
p
.002 w
.54231 .4768 m .54258 .47699 L p
.54106 .47622 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54344 .47782 m .54106 .47622 L .54258 .47699 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54247 .47687 L p
1 g
F P
s
P
p
.002 w
.54247 .47687 m .54174 .47608 L p
.55056 .48472 L 1 g
F P
s
P
p
.55056 .48472 m .55834 .49233 L .54247 .47687 L 1 g
F
P
p
.002 w
.57116 .49008 m .56879 .49477 L .54258 .47699 L p
1 g
F P
s
P
p
.002 w
.54258 .47699 m .54231 .4768 L p
.54247 .47687 L 1 g
F P
s
P
p
.57116 .49008 m .54258 .47699 L .54247 .47687 L 1 g
F
P
p
.002 w
.54258 .47699 m .56879 .49477 L p
.54344 .47782 L 1 g
F P
s
P
p
.55433 .4851 m .55744 .49138 L .54344 .47782 L 1 g
F
P
p
.56879 .49477 m .55744 .49138 L .55433 .4851 L 1 g
F
P
p
.002 w
.55744 .49138 m .55747 .49141 L p
.55702 .49097 L 1 g
F P
s
P
p
.002 w
.55747 .49141 m .55834 .49233 L p
.55056 .48472 L 1 g
F P
s
P
p
.002 w
.57418 .48409 m .57116 .49008 L p
.5418 .47622 L 1 g
F P
s
P
p
.002 w
.54069 .4757 m .54145 .47589 L p
.5418 .47622 L 1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54145 .47589 m .57418 .48409 L p
.5418 .47622 L 1 g
F P
s
P
p
.52214 .46667 m .54247 .47688 L .54138 .47637 L 1 g
F
P
p
.002 w
.54231 .4768 m .54069 .4757 L p
.57116 .49008 L 1 g
F P
s
P
p
.002 w
.54247 .47687 m .54247 .47687 L p
.54246 .47687 L 1 g
F P
s
P
p
.52214 .46667 m .54247 .47687 L .54246 .47687 L 1 g
F
P
p
.002 w
.54247 .47687 m .54247 .47688 L p
.5424 .47684 L 1 g
F P
s
P
p
.52214 .46667 m .54247 .47687 L .5424 .47684 L 1 g
F
P
p
.002 w
.54106 .47622 m .56031 .5033 L p
.5408 .4761 L 1 g
F P
s
P
p
.52214 .46667 m .54143 .4764 L .5339 .47276 L 1 g
F
P
p
.002 w
.5408 .4761 m .54964 .50879 L p
.54066 .47604 L 1 g
F P
s
P
p
.002 w
.53792 .51065 m .52639 .50866 L .54056 .47599 L p
1 g
F P
s
P
p
.002 w
.54056 .47599 m .54069 .4757 L .54066 .47604 L p
1 g
F P
s
P
p
.002 w
.54066 .47604 m .53792 .51065 L p
.54056 .47599 L 1 g
F P
s
P
p
.002 w
.52639 .50866 m .5163 .50302 L .54047 .47595 L p
1 g
F P
s
P
p
.002 w
.54047 .47595 m .54069 .4757 L .54056 .47599 L p
1 g
F P
s
P
p
.002 w
.54056 .47599 m .52639 .50866 L p
.54047 .47595 L 1 g
F P
s
P
p
.002 w
.5163 .50302 m .50874 .49431 L .54035 .47589 L p
1 g
F P
s
P
p
.002 w
.54035 .47589 m .54069 .4757 L .54047 .47595 L p
1 g
F P
s
P
p
.002 w
.54047 .47595 m .5163 .50302 L p
.54035 .47589 L 1 g
F P
s
P
p
.54056 .47599 m .54255 .47696 L .54042 .47593 L 1 g
F
P
p
.54061 .47601 m .54067 .47605 L .54056 .47599 L 1 g
F
P
p
.54067 .47605 m .54255 .47696 L .54056 .47599 L 1 g
F
P
p
.54066 .47604 m .54069 .47605 L .54061 .47601 L 1 g
F
P
p
.54069 .47605 m .54255 .47696 L .54061 .47601 L 1 g
F
P
p
.54143 .4764 m .54152 .47644 L .54066 .47604 L 1 g
F
P
p
.54152 .47644 m .54255 .47696 L .54066 .47604 L 1 g
F
P
p
.002 w
.50874 .49431 m .50456 .48346 L .54018 .47581 L p
1 g
F P
s
P
p
.002 w
.54018 .47581 m .54069 .4757 L .54035 .47589 L p
1 g
F P
s
P
p
.002 w
.54035 .47589 m .50874 .49431 L p
.54018 .47581 L 1 g
F P
s
P
p
.54143 .4764 m .54051 .47597 L .5339 .47276 L 1 g
F
P
p
.002 w
.50456 .48346 m .50422 .47166 L .53973 .47559 L p
1 g
F P
s
P
p
.002 w
.53973 .47559 m .54069 .4757 L .54018 .47581 L p
1 g
F P
s
P
p
.002 w
.54018 .47581 m .50456 .48346 L p
.53973 .47559 L 1 g
F P
s
P
p
.54018 .47581 m .54042 .47593 L .54002 .47573 L 1 g
F
P
p
.54051 .47597 m .54047 .47595 L .54018 .47581 L 1 g
F
P
p
.54047 .47595 m .54042 .47593 L .54018 .47581 L 1 g
F
P
p
.54051 .47597 m .54002 .47573 L .5339 .47276 L 1 g
F
P
p
.002 w
.54964 .50879 m .53792 .51065 L .54066 .47604 L p
1 g
F P
s
P
p
.002 w
.54066 .47604 m .54069 .4757 L .5408 .4761 L p
1 g
F P
s
P
p
.002 w
.54106 .47622 m .54069 .4757 L .54231 .4768 L p
1 g
F P
s
P
p
.002 w
.5408 .4761 m .54069 .4757 L .54106 .47622 L p
1 g
F P
s
P
p
.002 w
.54247 .47688 m .54255 .47696 L p
.54138 .47637 L 1 g
F P
s
P
p
.002 w
.50422 .47166 m .5063 .46497 L p
.53863 .47506 L 1 g
F P
s
P
p
.002 w
.53973 .47559 m .50422 .47166 L p
.53863 .47506 L 1 g
F P
s
P
p
.002 w
.52246 .46719 m .52214 .46667 L p
.5339 .47276 L 1 g
F P
s
P
p
.002 w
.52275 .46723 m .54069 .4757 L p
.53863 .47506 L 1 g
F P
s
P
p
.5063 .46497 m .52246 .46719 L .53863 .47506 L 1 g
F
P
p
.52246 .46719 m .52275 .46723 L .53863 .47506 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52246 .46719 L p
1 g
F P
s
P
p
.5339 .47276 m .54302 .47747 L .52246 .46719 L 1 g
F
P
p
.002 w
.54255 .47696 m .54302 .47747 L p
.5339 .47276 L 1 g
F P
s
P
p
.002 w
.54069 .4757 m .53973 .47559 L p
.53863 .47506 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .46719 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .46719 L .52244 .46719 L 1 g
F
P
p
.5 .4634 m .52246 .46719 L .51377 .46601 L 1 g
F
P
p
.5 .4634 m .52277 .46771 L .52033 .46731 L 1 g
F
P
p
.002 w
.5063 .46497 m .50422 .47166 L p
.5 .46392 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .4634 L p
.52033 .46731 L 1 g
F P
s
P
p
.52033 .46731 m .52282 .46778 L .5 .46392 L 1 g
F
P
p
.002 w
.50779 .46018 m .50695 .46289 L p
.5 .46392 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .46442 L p
.48891 .46555 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46392 L .48891 .46555 L 1 g
F
P
p
.47988 .46687 m .4954 .46315 L .5 .46392 L 1 g
F
P
p
.4954 .46315 m .50779 .46018 L .5 .46392 L 1 g
F
P
p
.002 w
.5063 .46497 m .50779 .46018 L .52275 .46723 L p
1 g
F P
s
P
p
.002 w
.52246 .46719 m .52246 .46719 L p
.52244 .46719 L 1 g
F P
s
P
p
.002 w
.52246 .46719 m .52277 .46771 L p
.51377 .46601 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.50779 .46018 m .51489 .4503 L .53359 .46871 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53359 .46871 m .54069 .4757 L .52275 .46723 L p
1 g
F P
s
P
p
.002 w
.52275 .46723 m .50779 .46018 L p
.53359 .46871 L 1 g
F P
s
P
p
.002 w
.50695 .46289 m .5063 .46497 L p
.5 .46392 L 1 g
F P
s
P
p
.002 w
.52277 .46771 m .52282 .46778 L p
.52033 .46731 L 1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.48461 .46371 m .50779 .46018 L .47667 .46764 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47753 .46722 L p
1 g
F P
s
P
p
.48891 .46555 m .5 .46442 L .47753 .46722 L 1 g
F
P
p
.002 w
.47753 .46722 m .47733 .46754 L p
.4726 .46966 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46722 L .4726 .46966 L 1 g
F
P
p
.002 w
.47667 .46764 m .46755 .46631 L p
.48461 .46371 L 1 g
F P
s
P
p
.45826 .47608 m .47733 .46754 L .47084 .47056 L 1 g
F
P
p
.002 w
.46757 .46711 m .46774 .47201 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.46774 .47201 m .46833 .48957 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.47733 .46754 m .47718 .46778 L p
.47084 .47056 L 1 g
F P
s
P
p
.002 w
.46774 .47201 m .46755 .46631 L .47667 .46764 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45772 .47667 L p
1 g
F P
s
P
p
.47084 .47056 m .47718 .46778 L .45772 .47667 L 1 g
F
P
p
.002 w
.46755 .46631 m .46757 .46711 L p
.45772 .47667 L 1 g
F P
s
P
p
.45376 .48051 m .4573 .47686 L .45772 .47667 L 1 g
F
P
p
.4573 .47686 m .46755 .46631 L .45772 .47667 L 1 g
F
P
p
.002 w
.44256 .49138 m .44339 .4905 L p
.44956 .48459 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.44674 .48306 m .46755 .46631 L .44187 .49276 L 1 g
F
P
p
.002 w
.45772 .47667 m .45698 .47747 L p
.44956 .48459 L 1 g
F P
s
P
p
.002 w
.44201 .49196 m .44166 .49233 L p
.4394 .49763 L 1 g
F P
s
P
p
.43485 .50826 m .44201 .49196 L .4394 .49763 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.44956 .48459 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.43702 .50278 m .44579 .52468 L p
.43309 .51129 L 1 g
F P
s
P
p
.002 w
.44579 .52468 m .43702 .50278 L p
.46833 .48957 L 1 g
F P
s
P
p
.002 w
.44187 .49276 m .46833 .48957 L p
.43702 .50278 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43406 .5092 L p
1 g
F P
s
P
p
.4394 .49763 m .44166 .49233 L .43406 .5092 L 1 g
F
P
p
.002 w
.43406 .5092 m .43287 .51061 L p
.43321 .52015 L 1 g
F P
s
P
p
.43255 .52867 m .43285 .52483 L .43276 .52954 L 1 g
F
P
p
.42765 .50851 m .43285 .52483 L .43255 .52867 L 1 g
F
P
p
.002 w
.42756 .53148 m .43276 .52954 L p
.43866 .54676 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43255 .52867 L p
1 g
F P
s
P
p
.43321 .52015 m .43287 .51061 L .43255 .52867 L 1 g
F
P
p
.002 w
.43255 .52867 m .43249 .52875 L p
.43269 .52925 L 1 g
F P
s
P
p
.002 w
.43249 .52875 m .43146 .53025 L p
.43626 .53974 L 1 g
F P
s
P
p
.44537 .55598 m .43866 .54676 L .44579 .52468 L 1 g
F
P
p
.002 w
.43276 .52954 m .44579 .52468 L p
.43866 .54676 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43866 .54676 L p
1 g
F P
s
P
p
.43626 .53974 m .43146 .53025 L .43866 .54676 L 1 g
F
P
p
.46872 .57265 m .45074 .56322 L .46108 .5696 L 1 g
F
P
p
.4684 .57411 m .45074 .56322 L .46766 .54924 L 1 g
F
P
p
.002 w
.45008 .56281 m .45024 .56269 L p
.45074 .56322 L 1 g
F P
s
P
p
.44539 .55602 m .45024 .56269 L .45074 .56322 L 1 g
F
P
p
.002 w
.45024 .56269 m .46766 .54924 L p
.45074 .56322 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4507 .56333 L p
1 g
F P
s
P
p
.002 w
.4507 .56333 m .45074 .56322 L p
.45025 .56271 L 1 g
F P
s
P
p
.45025 .56271 m .43743 .5491 L .4507 .56333 L 1 g
F
P
p
.44539 .55602 m .43794 .54954 L .45024 .56269 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44579 .52468 m .46766 .54924 L .45024 .56269 L p
1 g
F P
s
P
p
.44537 .55598 m .44579 .52468 L .45024 .56269 L 1 g
F
P
p
.43794 .54954 m .43743 .5491 L .45074 .56322 L 1 g
F
P
p
.002 w
.45074 .56322 m .45002 .56518 L p
.46108 .5696 L 1 g
F P
s
P
p
.47864 .57752 m .4684 .57411 L .46766 .54924 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4684 .57411 L p
1 g
F P
s
P
p
.46108 .5696 m .45002 .56518 L .4684 .57411 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58098 L p
1 g
F P
s
P
p
.002 w
.48903 .58098 m .48906 .58058 L p
.48647 .58012 L 1 g
F P
s
P
p
.48647 .58012 m .4678 .57686 L .48903 .58098 L 1 g
F
P
p
.47957 .57783 m .46948 .577 L .48634 .58008 L 1 g
F
P
p
.47957 .57783 m .48634 .58008 L .48906 .58058 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46766 .54924 m .49653 .56494 L .48634 .58008 L p
1 g
F P
s
P
p
.47864 .57752 m .46766 .54924 L .48634 .58008 L 1 g
F
P
p
.002 w
.48634 .58008 m .49653 .56494 L p
.49963 .58251 L 1 g
F P
s
P
p
.002 w
.48906 .58058 m .48889 .583 L p
.50276 .58023 L 1 g
F P
s
P
p
.002 w
.52366 .59303 m .48308 .58655 L p
.51105 .57998 L 1 g
F P
s
P
p
.002 w
.48308 .58655 m .48208 .58639 L p
.51105 .57998 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58002 L p
1 g
F P
s
P
p
.50276 .58023 m .48889 .583 L .5109 .58002 L 1 g
F
P
p
.46948 .577 m .4678 .57686 L .48906 .58058 L 1 g
F
P
p
.52201 .57741 m .51106 .58226 L .51642 .58027 L 1 g
F
P
p
.53128 .57265 m .52056 .57775 L .52201 .57741 L 1 g
F
P
p
.52056 .57775 m .51106 .58226 L .52201 .57741 L 1 g
F
P
p
.002 w
.5109 .58002 m .51106 .58226 L p
.52056 .57775 L 1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.49653 .56494 m .52921 .57028 L .5278 .57605 L p
1 g
F P
s
P
p
.51105 .57998 m .49653 .56494 L .5278 .57605 L 1 g
F
P
p
.002 w
.5278 .57605 m .52921 .57028 L p
.53573 .5731 L 1 g
F P
s
P
p
.002 w
.51106 .58226 m .51111 .583 L p
.51642 .58027 L 1 g
F P
s
P
p
.002 w
.5317 .5746 m .5322 .57686 L p
.54 .56943 L 1 g
F P
s
P
p
.002 w
.52921 .57028 m .54202 .56817 L p
.53477 .57269 L 1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.39675 .33179 m .36228 .38047 L .34433 .36827 L p
1 g
F P
s
P
p
.002 w
.34433 .36827 m .38135 .31589 L .39675 .33179 L p
1 g
F P
s
P
p
.002 w
.61611 .5253 m .63143 .4953 L .65334 .49784 L p
1 g
F P
s
P
p
.002 w
.65994 .456 m .65334 .49784 L .63143 .4953 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.41714 .53537 m .44522 .56656 L .42507 .57933 L p
1 g
F P
s
P
p
.002 w
.42507 .57933 m .39173 .54264 L .41714 .53537 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.50169 .27924 m .44514 .29667 L .4334 .27815 L p
1 g
F P
s
P
p
.002 w
.38135 .31589 m .4334 .27815 L .44514 .29667 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44514 .29667 m .39675 .33179 L .38135 .31589 L p
1 g
F P
s
P
p
.002 w
.37012 .44488 m .37257 .49616 L .34865 .49438 L p
1 g
F P
s
P
p
.002 w
.34865 .49438 m .3457 .43689 L .37012 .44488 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.65278 .41463 m .63234 .37811 L .64564 .35716 L p
1 g
F P
s
P
p
.002 w
.6082 .32438 m .64564 .35716 L .63234 .37811 L p
1 g
F P
s
P
p
.002 w
.63143 .4953 m .63653 .46234 L .65994 .456 L p
1 g
F P
s
P
p
.002 w
.65278 .41463 m .65994 .456 L .63653 .46234 L p
1 g
F P
s
P
p
.002 w
.6082 .32438 m .56105 .30592 L .55967 .2813 L p
1 g
F P
s
P
p
.002 w
.50169 .27924 m .55967 .2813 L .56105 .30592 L p
1 g
F P
s
P
p
.002 w
.40112 .49599 m .41714 .53537 L .39173 .54264 L p
1 g
F P
s
P
p
.002 w
.39173 .54264 m .37257 .49616 L .40112 .49599 L p
1 g
F P
s
P
p
.002 w
.38503 .3946 m .37012 .44488 L .3457 .43689 L p
1 g
F P
s
P
p
.002 w
.3457 .43689 m .36228 .38047 L .38503 .3946 L p
1 g
F P
s
P
p
.002 w
.63653 .46234 m .63077 .42984 L .65278 .41463 L p
1 g
F P
s
P
p
.002 w
.63234 .37811 m .65278 .41463 L .63077 .42984 L p
1 g
F P
s
P
p
.002 w
.63234 .37811 m .60053 .35051 L .6082 .32438 L p
1 g
F P
s
P
p
.002 w
.56105 .30592 m .6082 .32438 L .60053 .35051 L p
1 g
F P
s
P
p
.002 w
.56105 .30592 m .50933 .30425 L .50169 .27924 L p
1 g
F P
s
P
p
.002 w
.44514 .29667 m .50169 .27924 L .50933 .30425 L p
1 g
F P
s
P
p
.002 w
.61611 .5253 m .59224 .54931 L .57768 .52811 L p
1 g
F P
s
P
p
.002 w
.57768 .52811 m .59421 .51148 L .61611 .5253 L p
1 g
F P
s
P
p
.002 w
.63143 .4953 m .61611 .5253 L .59421 .51148 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.41581 .35123 m .38503 .3946 L .36228 .38047 L p
1 g
F P
s
P
p
.002 w
.36228 .38047 m .39675 .33179 L .41581 .35123 L p
1 g
F P
s
P
p
.002 w
.59421 .51148 m .60478 .49069 L .63143 .4953 L p
1 g
F P
s
P
p
.002 w
.63653 .46234 m .63143 .4953 L .60478 .49069 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.50933 .30425 m .45894 .3199 L .44514 .29667 L p
1 g
F P
s
P
p
.002 w
.39675 .33179 m .44514 .29667 L .45894 .3199 L p
1 g
F P
s
P
p
.002 w
.39923 .45265 m .40112 .49599 L .37257 .49616 L p
1 g
F P
s
P
p
.002 w
.37257 .49616 m .37012 .44488 L .39923 .45265 L p
1 g
F P
s
P
p
.002 w
.45894 .3199 m .41581 .35123 L .39675 .33179 L p
1 g
F P
s
P
p
.002 w
.51148 .53876 m .53403 .54254 L .52921 .57028 L p
1 g
F P
s
P
p
.002 w
.52921 .57028 m .49653 .56494 L .51148 .53876 L p
1 g
F P
s
P
p
.002 w
.63077 .42984 m .61459 .40128 L .63234 .37811 L p
1 g
F P
s
P
p
.002 w
.60053 .35051 m .63234 .37811 L .61459 .40128 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60478 .49069 m .60823 .46789 L .63653 .46234 L p
1 g
F P
s
P
p
.002 w
.63077 .42984 m .63653 .46234 L .60823 .46789 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60053 .35051 m .5606 .33509 L .56105 .30592 L p
1 g
F P
s
P
p
.002 w
.50933 .30425 m .56105 .30592 L .5606 .33509 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.49165 .52783 m .51148 .53876 L .49653 .56494 L p
1 g
F P
s
P
p
.002 w
.49653 .56494 m .46766 .54924 L .49165 .52783 L p
1 g
F P
s
P
p
.002 w
.41714 .53537 m .40112 .49599 L .43342 .49378 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60823 .46789 m .60415 .44549 L .63077 .42984 L p
1 g
F P
s
P
p
.002 w
.61459 .40128 m .63077 .42984 L .60415 .44549 L p
1 g
F P
s
P
p
.002 w
.41195 .41022 m .39923 .45265 L .37012 .44488 L p
1 g
F P
s
P
p
.002 w
.37012 .44488 m .38503 .3946 L .41195 .41022 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61459 .40128 m .58955 .37979 L .60053 .35051 L p
1 g
F P
s
P
p
.002 w
.5606 .33509 m .60053 .35051 L .58955 .37979 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5606 .33509 m .5169 .33385 L .50933 .30425 L p
1 g
F P
s
P
p
.002 w
.45894 .3199 m .50933 .30425 L .5169 .33385 L p
1 g
F P
s
P
p
.002 w
.60478 .49069 m .59421 .51148 L .56879 .49477 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4767 .51084 m .49165 .52783 L .46766 .54924 L p
1 g
F P
s
P
p
.002 w
.46766 .54924 m .44579 .52468 L .4767 .51084 L p
1 g
F P
s
P
p
.002 w
.53792 .51065 m .54964 .50879 L .5569 .53885 L p
1 g
F P
s
P
p
.002 w
.5569 .53885 m .53403 .54254 L .53792 .51065 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.56879 .49477 m .57418 .48409 L .60478 .49069 L p
1 g
F P
s
P
p
.002 w
.60823 .46789 m .60478 .49069 L .57418 .48409 L p
1 g
F P
s
P
p
.002 w
.43798 .37364 m .41195 .41022 L .38503 .3946 L p
1 g
F P
s
P
p
.002 w
.38503 .3946 m .41581 .35123 L .43798 .37364 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.4321 .45989 m .43342 .49378 L .40112 .49599 L p
1 g
F P
s
P
p
.002 w
.40112 .49599 m .39923 .45265 L .4321 .45989 L p
1 g
F P
s
P
p
.002 w
.60415 .44549 m .59289 .42587 L .61459 .40128 L p
1 g
F P
s
P
p
.002 w
.58955 .37979 m .61459 .40128 L .59289 .42587 L p
1 g
F P
s
P
p
.002 w
.5169 .33385 m .47438 .34716 L .45894 .3199 L p
1 g
F P
s
P
p
.002 w
.41581 .35123 m .45894 .3199 L .47438 .34716 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.52639 .50866 m .53792 .51065 L .53403 .54254 L p
1 g
F P
s
P
p
.002 w
.53403 .54254 m .51148 .53876 L .52639 .50866 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47438 .34716 m .43798 .37364 L .41581 .35123 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57418 .48409 m .57591 .47241 L .60823 .46789 L p
1 g
F P
s
P
p
.002 w
.60415 .44549 m .60823 .46789 L .57591 .47241 L p
1 g
F P
s
P
p
.002 w
.58955 .37979 m .55825 .3679 L .5606 .33509 L p
1 g
F P
s
P
p
.002 w
.5169 .33385 m .5606 .33509 L .55825 .3679 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.5163 .50302 m .52639 .50866 L .51148 .53876 L p
1 g
F P
s
P
p
.002 w
.51148 .53876 m .49165 .52783 L .5163 .50302 L p
1 g
F P
s
P
p
.002 w
.46833 .48957 m .4767 .51084 L .44579 .52468 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57591 .47241 m .57376 .46097 L .60415 .44549 L p
1 g
F P
s
P
p
.002 w
.59289 .42587 m .60415 .44549 L .57376 .46097 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.44214 .42678 m .4321 .45989 L .39923 .45265 L p
1 g
F P
s
P
p
.002 w
.39923 .45265 m .41195 .41022 L .44214 .42678 L p
1 g
F P
s
P
p
.002 w
.59289 .42587 m .57558 .41121 L .58955 .37979 L p
1 g
F P
s
P
p
.002 w
.55825 .3679 m .58955 .37979 L .57558 .41121 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55825 .3679 m .52409 .36707 L .5169 .33385 L p
1 g
F P
s
P
p
.002 w
.47438 .34716 m .5169 .33385 L .52409 .36707 L p
1 g
F P
s
P
p
.002 w
.50874 .49431 m .5163 .50302 L .49165 .52783 L p
1 g
F P
s
P
p
.002 w
.49165 .52783 m .4767 .51084 L .50874 .49431 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57376 .46097 m .56795 .451 L .59289 .42587 L p
1 g
F P
s
P
p
.002 w
.57558 .41121 m .59289 .42587 L .56795 .451 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43342 .49378 m .4321 .45989 L .46755 .46631 L p
1 g
F P
s
P
p
.002 w
.57591 .47241 m .57418 .48409 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.46251 .39824 m .44214 .42678 L .41195 .41022 L p
1 g
F P
s
P
p
.002 w
.41195 .41022 m .43798 .37364 L .46251 .39824 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52409 .36707 m .49091 .37756 L .47438 .34716 L p
1 g
F P
s
P
p
.002 w
.43798 .37364 m .47438 .34716 L .49091 .37756 L p
1 g
F P
s
P
p
.002 w
.57376 .46097 m .57591 .47241 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.57558 .41121 m .55405 .40317 L .55825 .3679 L p
1 g
F P
s
P
p
.002 w
.52409 .36707 m .55825 .3679 L .55405 .40317 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49091 .37756 m .46251 .39824 L .43798 .37364 L p
1 g
F P
s
P
p
.002 w
.50456 .48346 m .50874 .49431 L .4767 .51084 L p
1 g
F P
s
P
p
.002 w
.4767 .51084 m .46833 .48957 L .50456 .48346 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56795 .451 m .57376 .46097 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56795 .451 m .55909 .4436 L .57558 .41121 L p
1 g
F P
s
P
p
.002 w
.55405 .40317 m .57558 .41121 L .55909 .4436 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47451 .44365 m .46755 .46631 L .4321 .45989 L p
1 g
F P
s
P
p
.002 w
.4321 .45989 m .44214 .42678 L .47451 .44365 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55909 .4436 m .56795 .451 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55405 .40317 m .53062 .40271 L .52409 .36707 L p
1 g
F P
s
P
p
.002 w
.49091 .37756 m .52409 .36707 L .53062 .40271 L p
1 g
F P
s
P
p
.002 w
.50422 .47166 m .50456 .48346 L .46833 .48957 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54812 .43958 m .55909 .4436 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.53623 .4394 m .54812 .43958 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.52473 .44311 m .53623 .4394 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.002 w
.51489 .4503 m .52473 .44311 L .54069 .4757 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51665 .44901 L
s
P
p
.002 w
.55909 .4436 m .54812 .43958 L .55405 .40317 L p
1 g
F P
s
P
p
.002 w
.53062 .40271 m .55405 .40317 L .54812 .43958 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.48848 .42413 m .47451 .44365 L .44214 .42678 L p
1 g
F P
s
P
p
.002 w
.44214 .42678 m .46251 .39824 L .48848 .42413 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.004 w
.54069 .4757 m
.542 .47716 L
s
P
p
.002 w
.53062 .40271 m .50792 .40996 L .49091 .37756 L p
1 g
F P
s
P
p
.002 w
.46251 .39824 m .49091 .37756 L .50792 .40996 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50792 .40996 m .48848 .42413 L .46251 .39824 L p
1 g
F P
s
P
p
.002 w
.54812 .43958 m .53623 .4394 L .53062 .40271 L p
1 g
F P
s
P
p
.002 w
.46755 .46631 m .47451 .44365 L .50779 .46018 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50792 .40996 m .53062 .40271 L .53623 .4394 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53623 .4394 m .52473 .44311 L .50792 .40996 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51489 .4503 m .50779 .46018 L .47451 .44365 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47451 .44365 m .48848 .42413 L .51489 .4503 L p
1 g
F P
s
P
p
.002 w
.52473 .44311 m .51489 .4503 L .48848 .42413 L p
1 g
F P
s
P
p
.002 w
.48848 .42413 m .50792 .40996 L .52473 .44311 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.542 .47716 m
.5658 .50359 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .34088 .65268 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .5658 .50359 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.184496)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.184496)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50495 .47348 m .53251 .45179 L .51193 .43223 L p
1 g
F P
s
P
p
.002 w
.51193 .43223 m .49062 .44898 L .50495 .47348 L p
1 g
F P
s
P
p
.002 w
.5273 .41003 m .51193 .43223 L .53251 .45179 L p
1 g
F P
s
P
p
.002 w
.49062 .44898 m .51193 .43223 L .49111 .41267 L p
1 g
F P
s
P
p
.002 w
.51193 .43223 m .5273 .41003 L .50156 .3975 L p
1 g
F P
s
P
p
.002 w
.50156 .3975 m .49111 .41267 L .51193 .43223 L p
1 g
F P
s
P
p
.002 w
.49111 .41267 m .47656 .42409 L .49062 .44898 L p
1 g
F P
s
P
p
.002 w
.47656 .42409 m .49111 .41267 L .47041 .39346 L p
1 g
F P
s
P
p
.002 w
.49111 .41267 m .50156 .3975 L .47572 .38573 L p
1 g
F P
s
P
p
.002 w
.47572 .38573 m .47041 .39346 L .49111 .41267 L p
1 g
F P
s
P
p
.002 w
.4725 .486 m .50495 .47348 L .49062 .44898 L p
1 g
F P
s
P
p
.002 w
.49062 .44898 m .46553 .45857 L .4725 .486 L p
1 g
F P
s
P
p
.002 w
.46553 .45857 m .49062 .44898 L .47656 .42409 L p
1 g
F P
s
P
p
.002 w
.47656 .42409 m .45942 .43058 L .46553 .45857 L p
1 g
F P
s
P
p
.002 w
.45942 .43058 m .47656 .42409 L .46301 .39927 L p
1 g
F P
s
P
p
.002 w
.47041 .39346 m .46301 .39927 L .47656 .42409 L p
1 g
F P
s
P
p
.002 w
.50682 .38014 m .50156 .3975 L .5273 .41003 L p
1 g
F P
s
P
p
.002 w
.50156 .3975 m .50682 .38014 L .47835 .3769 L p
1 g
F P
s
P
p
.002 w
.47835 .3769 m .47572 .38573 L .50156 .3975 L p
1 g
F P
s
P
p
.002 w
.53251 .45179 m .55246 .4231 L .5273 .41003 L p
1 g
F P
s
P
p
.002 w
.53513 .38459 m .5273 .41003 L .55246 .4231 L p
1 g
F P
s
P
p
.002 w
.5273 .41003 m .53513 .38459 L .50682 .38014 L p
1 g
F P
s
P
p
.002 w
.51928 .49716 m .55247 .471 L .53251 .45179 L p
1 g
F P
s
P
p
.002 w
.53251 .45179 m .50495 .47348 L .51928 .49716 L p
1 g
F P
s
P
p
.002 w
.55246 .4231 m .53251 .45179 L .55247 .471 L p
1 g
F P
s
P
p
.002 w
.43917 .45996 m .46553 .45857 L .45942 .43058 L p
1 g
F P
s
P
p
.002 w
.45942 .43058 m .44146 .43143 L .43917 .45996 L p
1 g
F P
s
P
p
.002 w
.44146 .43143 m .45942 .43058 L .45429 .40254 L p
1 g
F P
s
P
p
.002 w
.46301 .39927 m .45429 .40254 L .45942 .43058 L p
1 g
F P
s
P
p
.002 w
.48022 .51237 m .51928 .49716 L .50495 .47348 L p
1 g
F P
s
P
p
.002 w
.50495 .47348 m .4725 .486 L .48022 .51237 L p
1 g
F P
s
P
p
.002 w
.43836 .488 m .4725 .486 L .46553 .45857 L p
1 g
F P
s
P
p
.002 w
.46553 .45857 m .43917 .45996 L .43836 .488 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .46301 .39927 L .47041 .39346 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .47041 .39346 L .47572 .38573 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .45429 .40254 L .46301 .39927 L closepath p
1 g
F P
s
P
p
.002 w
.5063 .36238 m .50682 .38014 L .53513 .38459 L p
1 g
F P
s
P
p
.002 w
.50682 .38014 m .5063 .36238 L .47802 .3679 L p
1 g
F P
s
P
p
.002 w
.47802 .3679 m .47835 .3769 L .50682 .38014 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .47572 .38573 L .47835 .3769 L closepath p
1 g
F P
s
P
p
.002 w
.55247 .471 m .57658 .43647 L .55246 .4231 L p
1 g
F P
s
P
p
.002 w
.56276 .3902 m .55246 .4231 L .57658 .43647 L p
1 g
F P
s
P
p
.002 w
.55246 .4231 m .56276 .3902 L .53513 .38459 L p
1 g
F P
s
P
p
.002 w
.45429 .40254 m .44517 .40292 L .44146 .43143 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .44517 .40292 L .45429 .40254 L closepath p
1 g
F P
s
P
p
.002 w
.53454 .35851 m .53513 .38459 L .56276 .3902 L p
1 g
F P
s
P
p
.002 w
.53513 .38459 m .53454 .35851 L .5063 .36238 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .47835 .3769 L .47802 .3679 L closepath p
1 g
F P
s
P
p
.002 w
.41427 .45289 m .43917 .45996 L .44146 .43143 L p
1 g
F P
s
P
p
.002 w
.44146 .43143 m .42456 .42649 L .41427 .45289 L p
1 g
F P
s
P
p
.002 w
.42456 .42649 m .44146 .43143 L .44517 .40292 L p
1 g
F P
s
P
p
.002 w
.44517 .40292 m .43662 .40035 L .42456 .42649 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .43662 .40035 L .44517 .40292 L closepath p
1 g
F P
s
P
p
.002 w
.43905 .51499 m .48022 .51237 L .4725 .486 L p
1 g
F P
s
P
p
.002 w
.4725 .486 m .43836 .488 L .43905 .51499 L p
1 g
F P
s
P
p
.002 w
.53336 .51955 m .57144 .4895 L .55247 .471 L p
1 g
F P
s
P
p
.002 w
.55247 .471 m .51928 .49716 L .53336 .51955 L p
1 g
F P
s
P
p
.002 w
.57658 .43647 m .55247 .471 L .57144 .4895 L p
1 g
F P
s
P
p
.002 w
.47475 .35969 m .47802 .3679 L .5063 .36238 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .47802 .3679 L .47475 .35969 L closepath p
1 g
F P
s
P
p
.002 w
.40597 .47905 m .43836 .488 L .43917 .45996 L p
1 g
F P
s
P
p
.002 w
.43917 .45996 m .41427 .45289 L .40597 .47905 L p
1 g
F P
s
P
p
.002 w
.49997 .34611 m .5063 .36238 L .53454 .35851 L p
1 g
F P
s
P
p
.002 w
.5063 .36238 m .49997 .34611 L .47475 .35969 L p
1 g
F P
s
P
p
.002 w
.48855 .53715 m .53336 .51955 L .51928 .49716 L p
1 g
F P
s
P
p
.002 w
.51928 .49716 m .48022 .51237 L .48855 .53715 L p
1 g
F P
s
P
p
.002 w
.41053 .41621 m .42456 .42649 L .43662 .40035 L p
1 g
F P
s
P
p
.002 w
.43662 .40035 m .42957 .39509 L .41053 .41621 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .42957 .39509 L .43662 .40035 L closepath p
1 g
F P
s
P
p
.002 w
.57658 .43647 m .58918 .39686 L .56276 .3902 L p
1 g
F P
s
P
p
.002 w
.56221 .35636 m .56276 .3902 L .58918 .39686 L p
1 g
F P
s
P
p
.002 w
.56276 .3902 m .56221 .35636 L .53454 .35851 L p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .47475 .35969 L .46886 .35317 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .46886 .35317 L .46099 .34906 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .46099 .34906 L .45197 .34782 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .45197 .34782 L .44279 .34962 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .44279 .34962 L .43447 .35427 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .43447 .35427 L .42794 .36125 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .42794 .36125 L .42391 .36978 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .42391 .36978 L .42283 .37894 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .42283 .37894 L .4248 .38769 L closepath p
1 g
F P
s
P
p
.002 w
.45023 .37495 m .4248 .38769 L .42957 .39509 L closepath p
1 g
F P
s
P
p
.002 w
.46886 .35317 m .47475 .35969 L .49997 .34611 L p
1 g
F P
s
P
p
.002 w
.39348 .43792 m .41427 .45289 L .42456 .42649 L p
1 g
F P
s
P
p
.002 w
.42456 .42649 m .41053 .41621 L .39348 .43792 L p
1 g
F P
s
P
p
.002 w
.57144 .4895 m .5992 .44991 L .57658 .43647 L p
1 g
F P
s
P
p
.002 w
.58918 .39686 m .57658 .43647 L .5992 .44991 L p
1 g
F P
s
P
p
.002 w
.40094 .40162 m .41053 .41621 L .42957 .39509 L p
1 g
F P
s
P
p
.002 w
.42957 .39509 m .4248 .38769 L .40094 .40162 L p
1 g
F P
s
P
p
.002 w
.52542 .33449 m .53454 .35851 L .56221 .35636 L p
1 g
F P
s
P
p
.002 w
.53454 .35851 m .52542 .33449 L .49997 .34611 L p
1 g
F P
s
P
p
.002 w
.49997 .34611 m .48843 .3331 L .46886 .35317 L p
1 g
F P
s
P
p
.002 w
.46099 .34906 m .46886 .35317 L .48843 .3331 L p
1 g
F P
s
P
p
.002 w
.44127 .5404 m .48855 .53715 L .48022 .51237 L p
1 g
F P
s
P
p
.002 w
.48022 .51237 m .43905 .51499 L .44127 .5404 L p
1 g
F P
s
P
p
.002 w
.39987 .50445 m .43905 .51499 L .43836 .488 L p
1 g
F P
s
P
p
.002 w
.43836 .488 m .40597 .47905 L .39987 .50445 L p
1 g
F P
s
P
p
.002 w
.48843 .3331 m .49997 .34611 L .52542 .33449 L p
1 g
F P
s
P
p
.002 w
.39691 .38426 m .40094 .40162 L .4248 .38769 L p
1 g
F P
s
P
p
.002 w
.4248 .38769 m .42283 .37894 L .39691 .38426 L p
1 g
F P
s
P
p
.002 w
.3788 .45981 m .40597 .47905 L .41427 .45289 L p
1 g
F P
s
P
p
.002 w
.41427 .45289 m .39348 .43792 L .3788 .45981 L p
1 g
F P
s
P
p
.002 w
.48843 .3331 m .47286 .32482 L .46099 .34906 L p
1 g
F P
s
P
p
.002 w
.45197 .34782 m .46099 .34906 L .47286 .32482 L p
1 g
F P
s
P
p
.002 w
.37915 .4165 m .39348 .43792 L .41053 .41621 L p
1 g
F P
s
P
p
.002 w
.41053 .41621 m .40094 .40162 L .37915 .4165 L p
1 g
F P
s
P
p
.002 w
.5469 .5402 m .58903 .50692 L .57144 .4895 L p
1 g
F P
s
P
p
.002 w
.57144 .4895 m .53336 .51955 L .5469 .5402 L p
1 g
F P
s
P
p
.002 w
.5992 .44991 m .57144 .4895 L .58903 .50692 L p
1 g
F P
s
P
p
.002 w
.39897 .36602 m .39691 .38426 L .42283 .37894 L p
1 g
F P
s
P
p
.002 w
.42283 .37894 m .42391 .36978 L .39897 .36602 L p
1 g
F P
s
P
p
.002 w
.49736 .55981 m .5469 .5402 L .53336 .51955 L p
1 g
F P
s
P
p
.002 w
.53336 .51955 m .48855 .53715 L .49736 .55981 L p
1 g
F P
s
P
p
.002 w
.5992 .44991 m .61386 .40448 L .58918 .39686 L p
1 g
F P
s
P
p
.002 w
.58877 .35602 m .58918 .39686 L .61386 .40448 L p
1 g
F P
s
P
p
.002 w
.58918 .39686 m .58877 .35602 L .56221 .35636 L p
1 g
F P
s
P
p
.002 w
.47286 .32482 m .45493 .32225 L .45197 .34782 L p
1 g
F P
s
P
p
.002 w
.44279 .34962 m .45197 .34782 L .45493 .32225 L p
1 g
F P
s
P
p
.002 w
.55061 .32507 m .56221 .35636 L .58877 .35602 L p
1 g
F P
s
P
p
.002 w
.56221 .35636 m .55061 .32507 L .52542 .33449 L p
1 g
F P
s
P
p
.002 w
.40695 .34896 m .39897 .36602 L .42391 .36978 L p
1 g
F P
s
P
p
.002 w
.42391 .36978 m .42794 .36125 L .40695 .34896 L p
1 g
F P
s
P
p
.002 w
.52542 .33449 m .50856 .31516 L .48843 .3331 L p
1 g
F P
s
P
p
.002 w
.47286 .32482 m .48843 .3331 L .50856 .31516 L p
1 g
F P
s
P
p
.002 w
.45493 .32225 m .43662 .32577 L .44279 .34962 L p
1 g
F P
s
P
p
.002 w
.43447 .35427 m .44279 .34962 L .43662 .32577 L p
1 g
F P
s
P
p
.002 w
.50856 .31516 m .52542 .33449 L .55061 .32507 L p
1 g
F P
s
P
p
.002 w
.41999 .33501 m .40695 .34896 L .42794 .36125 L p
1 g
F P
s
P
p
.002 w
.42794 .36125 m .43447 .35427 L .41999 .33501 L p
1 g
F P
s
P
p
.002 w
.43662 .32577 m .41999 .33501 L .43447 .35427 L p
1 g
F P
s
P
p
.002 w
.58903 .50692 m .61983 .46316 L .5992 .44991 L p
1 g
F P
s
P
p
.002 w
.61386 .40448 m .5992 .44991 L .61983 .46316 L p
1 g
F P
s
P
p
.002 w
.37302 .39085 m .37915 .4165 L .40094 .40162 L p
1 g
F P
s
P
p
.002 w
.40094 .40162 m .39691 .38426 L .37302 .39085 L p
1 g
F P
s
P
p
.002 w
.39616 .52858 m .44127 .5404 L .43905 .51499 L p
1 g
F P
s
P
p
.002 w
.43905 .51499 m .39987 .50445 L .39616 .52858 L p
1 g
F P
s
P
p
.002 w
.36685 .48144 m .39987 .50445 L .40597 .47905 L p
1 g
F P
s
P
p
.002 w
.40597 .47905 m .3788 .45981 L .36685 .48144 L p
1 g
F P
s
P
p
.002 w
.35993 .43206 m .3788 .45981 L .39348 .43792 L p
1 g
F P
s
P
p
.002 w
.39348 .43792 m .37915 .4165 L .35993 .43206 L p
1 g
F P
s
P
p
.002 w
.44503 .56365 m .49736 .55981 L .48855 .53715 L p
1 g
F P
s
P
p
.002 w
.48855 .53715 m .44127 .5404 L .44503 .56365 L p
1 g
F P
s
P
p
.002 w
.50856 .31516 m .48564 .30275 L .47286 .32482 L p
1 g
F P
s
P
p
.002 w
.45493 .32225 m .47286 .32482 L .48564 .30275 L p
1 g
F P
s
P
p
.002 w
.37595 .36379 m .37302 .39085 L .39691 .38426 L p
1 g
F P
s
P
p
.002 w
.39691 .38426 m .39897 .36602 L .37595 .36379 L p
1 g
F P
s
P
p
.002 w
.55061 .32507 m .52888 .29975 L .50856 .31516 L p
1 g
F P
s
P
p
.002 w
.48564 .30275 m .50856 .31516 L .52888 .29975 L p
1 g
F P
s
P
p
.002 w
.61386 .40448 m .61367 .35754 L .58877 .35602 L p
1 g
F P
s
P
p
.002 w
.57504 .31812 m .58877 .35602 L .61367 .35754 L p
1 g
F P
s
P
p
.002 w
.58877 .35602 m .57504 .31812 L .55061 .32507 L p
1 g
F P
s
P
p
.002 w
.61983 .46316 m .63625 .41293 L .61386 .40448 L p
1 g
F P
s
P
p
.002 w
.61367 .35754 m .61386 .40448 L .63625 .41293 L p
1 g
F P
s
P
p
.002 w
.52888 .29975 m .55061 .32507 L .57504 .31812 L p
1 g
F P
s
P
p
.002 w
.48564 .30275 m .45909 .2988 L .45493 .32225 L p
1 g
F P
s
P
p
.002 w
.43662 .32577 m .45493 .32225 L .45909 .2988 L p
1 g
F P
s
P
p
.002 w
.55961 .55862 m .60484 .52288 L .58903 .50692 L p
1 g
F P
s
P
p
.002 w
.58903 .50692 m .5469 .5402 L .55961 .55862 L p
1 g
F P
s
P
p
.002 w
.61983 .46316 m .58903 .50692 L .60484 .52288 L p
1 g
F P
s
P
p
.002 w
.50647 .57982 m .55961 .55862 L .5469 .5402 L p
1 g
F P
s
P
p
.002 w
.5469 .5402 m .49736 .55981 L .50647 .57982 L p
1 g
F P
s
P
p
.002 w
.38775 .3384 m .37595 .36379 L .39897 .36602 L p
1 g
F P
s
P
p
.002 w
.39897 .36602 m .40695 .34896 L .38775 .3384 L p
1 g
F P
s
P
p
.002 w
.35172 .39863 m .35993 .43206 L .37915 .4165 L p
1 g
F P
s
P
p
.002 w
.37915 .4165 m .37302 .39085 L .35172 .39863 L p
1 g
F P
s
P
p
.002 w
.45909 .2988 m .43188 .30392 L .43662 .32577 L p
1 g
F P
s
P
p
.002 w
.41999 .33501 m .43662 .32577 L .43188 .30392 L p
1 g
F P
s
P
p
.002 w
.40713 .31764 m .38775 .3384 L .40695 .34896 L p
1 g
F P
s
P
p
.002 w
.40695 .34896 m .41999 .33501 L .40713 .31764 L p
1 g
F P
s
P
p
.002 w
.60484 .52288 m .63799 .47593 L .61983 .46316 L p
1 g
F P
s
P
p
.002 w
.63625 .41293 m .61983 .46316 L .63799 .47593 L p
1 g
F P
s
P
p
.002 w
.35798 .50236 m .39616 .52858 L .39987 .50445 L p
1 g
F P
s
P
p
.002 w
.39987 .50445 m .36685 .48144 L .35798 .50236 L p
1 g
F P
s
P
p
.002 w
.43188 .30392 m .40713 .31764 L .41999 .33501 L p
1 g
F P
s
P
p
.002 w
.39501 .55085 m .44503 .56365 L .44127 .5404 L p
1 g
F P
s
P
p
.002 w
.44127 .5404 m .39616 .52858 L .39501 .55085 L p
1 g
F P
s
P
p
.002 w
.34377 .44799 m .36685 .48144 L .3788 .45981 L p
1 g
F P
s
P
p
.002 w
.3788 .45981 m .35993 .43206 L .34377 .44799 L p
1 g
F P
s
P
p
.002 w
.52888 .29975 m .4991 .28337 L .48564 .30275 L p
1 g
F P
s
P
p
.002 w
.45909 .2988 m .48564 .30275 L .4991 .28337 L p
1 g
F P
s
P
p
.002 w
.45031 .58418 m .50647 .57982 L .49736 .55981 L p
1 g
F P
s
P
p
.002 w
.49736 .55981 m .44503 .56365 L .45031 .58418 L p
1 g
F P
s
P
p
.002 w
.3554 .3632 m .35172 .39863 L .37302 .39085 L p
1 g
F P
s
P
p
.002 w
.37302 .39085 m .37595 .36379 L .3554 .3632 L p
1 g
F P
s
P
p
.002 w
.57504 .31812 m .54896 .28729 L .52888 .29975 L p
1 g
F P
s
P
p
.002 w
.4991 .28337 m .52888 .29975 L .54896 .28729 L p
1 g
F P
s
P
p
.002 w
.63625 .41293 m .63633 .36096 L .61367 .35754 L p
1 g
F P
s
P
p
.002 w
.59817 .31384 m .61367 .35754 L .63633 .36096 L p
1 g
F P
s
P
p
.002 w
.61367 .35754 m .59817 .31384 L .57504 .31812 L p
1 g
F P
s
P
p
.002 w
.54896 .28729 m .57504 .31812 L .59817 .31384 L p
1 g
F P
s
P
p
.002 w
.63799 .47593 m .65581 .42206 L .63625 .41293 L p
1 g
F P
s
P
p
.002 w
.63633 .36096 m .63625 .41293 L .65581 .42206 L p
1 g
F P
s
P
p
.002 w
.4991 .28337 m .46442 .27803 L .45909 .2988 L p
1 g
F P
s
P
p
.002 w
.43188 .30392 m .45909 .2988 L .46442 .27803 L p
1 g
F P
s
P
p
.002 w
.5712 .57435 m .61846 .53696 L .60484 .52288 L p
1 g
F P
s
P
p
.002 w
.60484 .52288 m .55961 .55862 L .5712 .57435 L p
1 g
F P
s
P
p
.002 w
.63799 .47593 m .60484 .52288 L .61846 .53696 L p
1 g
F P
s
P
p
.002 w
.33359 .40748 m .34377 .44799 L .35993 .43206 L p
1 g
F P
s
P
p
.002 w
.35993 .43206 m .35172 .39863 L .33359 .40748 L p
1 g
F P
s
P
p
.002 w
.3708 .32987 m .3554 .3632 L .37595 .36379 L p
1 g
F P
s
P
p
.002 w
.37595 .36379 m .38775 .3384 L .3708 .32987 L p
1 g
F P
s
P
p
.002 w
.51572 .59662 m .5712 .57435 L .55961 .55862 L p
1 g
F P
s
P
p
.002 w
.55961 .55862 m .50647 .57982 L .51572 .59662 L p
1 g
F P
s
P
p
.002 w
.33116 .46397 m .35798 .50236 L .36685 .48144 L p
1 g
F P
s
P
p
.002 w
.36685 .48144 m .34377 .44799 L .33116 .46397 L p
1 g
F P
s
P
p
.002 w
.35254 .52205 m .39501 .55085 L .39616 .52858 L p
1 g
F P
s
P
p
.002 w
.39616 .52858 m .35798 .50236 L .35254 .52205 L p
1 g
F P
s
P
p
.002 w
.46442 .27803 m .42874 .28464 L .43188 .30392 L p
1 g
F P
s
P
p
.002 w
.40713 .31764 m .43188 .30392 L .42874 .28464 L p
1 g
F P
s
P
p
.002 w
.39655 .5707 m .45031 .58418 L .44503 .56365 L p
1 g
F P
s
P
p
.002 w
.44503 .56365 m .39501 .55085 L .39655 .5707 L p
1 g
F P
s
P
p
.002 w
.39625 .3026 m .3708 .32987 L .38775 .3384 L p
1 g
F P
s
P
p
.002 w
.38775 .3384 m .40713 .31764 L .39625 .3026 L p
1 g
F P
s
P
p
.002 w
.61846 .53696 m .65318 .48795 L .63799 .47593 L p
1 g
F P
s
P
p
.002 w
.65581 .42206 m .63799 .47593 L .65318 .48795 L p
1 g
F P
s
P
p
.002 w
.42874 .28464 m .39625 .3026 L .40713 .31764 L p
1 g
F P
s
P
p
.002 w
.54896 .28729 m .51298 .2672 L .4991 .28337 L p
1 g
F P
s
P
p
.002 w
.46442 .27803 m .4991 .28337 L .51298 .2672 L p
1 g
F P
s
P
p
.002 w
.45707 .60138 m .51572 .59662 L .50647 .57982 L p
1 g
F P
s
P
p
.002 w
.50647 .57982 m .45031 .58418 L .45707 .60138 L p
1 g
F P
s
P
p
.002 w
.59817 .31384 m .56837 .27816 L .54896 .28729 L p
1 g
F P
s
P
p
.002 w
.51298 .2672 m .54896 .28729 L .56837 .27816 L p
1 g
F P
s
P
p
.002 w
.33792 .36435 m .33359 .40748 L .35172 .39863 L p
1 g
F P
s
P
p
.002 w
.35172 .39863 m .3554 .3632 L .33792 .36435 L p
1 g
F P
s
P
p
.002 w
.63633 .36096 m .61945 .31246 L .59817 .31384 L p
1 g
F P
s
P
p
.002 w
.56837 .27816 m .59817 .31384 L .61945 .31246 L p
1 g
F P
s
P
p
.002 w
.65581 .42206 m .65616 .36628 L .63633 .36096 L p
1 g
F P
s
P
p
.002 w
.61945 .31246 m .63633 .36096 L .65616 .36628 L p
1 g
F P
s
P
p
.002 w
.65318 .48795 m .67197 .43172 L .65581 .42206 L p
1 g
F P
s
P
p
.002 w
.65616 .36628 m .65581 .42206 L .67197 .43172 L p
1 g
F P
s
P
p
.002 w
.51298 .2672 m .47086 .26054 L .46442 .27803 L p
1 g
F P
s
P
p
.002 w
.42874 .28464 m .46442 .27803 L .47086 .26054 L p
1 g
F P
s
P
p
.002 w
.3192 .41724 m .33116 .46397 L .34377 .44799 L p
1 g
F P
s
P
p
.002 w
.34377 .44799 m .33359 .40748 L .3192 .41724 L p
1 g
F P
s
P
p
.002 w
.32258 .47962 m .35254 .52205 L .35798 .50236 L p
1 g
F P
s
P
p
.002 w
.35798 .50236 m .33116 .46397 L .32258 .47962 L p
1 g
F P
s
P
p
.002 w
.58134 .58689 m .62948 .54878 L .61846 .53696 L p
1 g
F P
s
P
p
.002 w
.61846 .53696 m .5712 .57435 L .58134 .58689 L p
1 g
F P
s
P
p
.002 w
.65318 .48795 m .61846 .53696 L .62948 .54878 L p
1 g
F P
s
P
p
.002 w
.35663 .32366 m .33792 .36435 L .3554 .3632 L p
1 g
F P
s
P
p
.002 w
.3554 .3632 m .3708 .32987 L .35663 .32366 L p
1 g
F P
s
P
p
.002 w
.35081 .54001 m .39655 .5707 L .39501 .55085 L p
1 g
F P
s
P
p
.002 w
.39501 .55085 m .35254 .52205 L .35081 .54001 L p
1 g
F P
s
P
p
.002 w
.52488 .60967 m .58134 .58689 L .5712 .57435 L p
1 g
F P
s
P
p
.002 w
.5712 .57435 m .51572 .59662 L .52488 .60967 L p
1 g
F P
s
P
p
.002 w
.40089 .58754 m .45707 .60138 L .45031 .58418 L p
1 g
F P
s
P
p
.002 w
.45031 .58418 m .39655 .5707 L .40089 .58754 L p
1 g
F P
s
P
p
.002 w
.47086 .26054 m .42736 .26848 L .42874 .28464 L p
1 g
F P
s
P
p
.002 w
.39625 .3026 m .42874 .28464 L .42736 .26848 L p
1 g
F P
s
P
p
.002 w
.62948 .54878 m .66491 .4989 L .65318 .48795 L p
1 g
F P
s
P
p
.002 w
.67197 .43172 m .65318 .48795 L .66491 .4989 L p
1 g
F P
s
P
p
.002 w
.38767 .29036 m .35663 .32366 L .3708 .32987 L p
1 g
F P
s
P
p
.002 w
.3708 .32987 m .39625 .3026 L .38767 .29036 L p
1 g
F P
s
P
p
.002 w
.56837 .27816 m .52699 .25477 L .51298 .2672 L p
1 g
F P
s
P
p
.002 w
.47086 .26054 m .51298 .2672 L .52699 .25477 L p
1 g
F P
s
P
p
.002 w
.42736 .26848 m .38767 .29036 L .39625 .3026 L p
1 g
F P
s
P
p
.002 w
.46522 .61467 m .52488 .60967 L .51572 .59662 L p
1 g
F P
s
P
p
.002 w
.51572 .59662 m .45707 .60138 L .46522 .61467 L p
1 g
F P
s
P
p
.002 w
.61945 .31246 m .58664 .27272 L .56837 .27816 L p
1 g
F P
s
P
p
.002 w
.52699 .25477 m .56837 .27816 L .58664 .27272 L p
1 g
F P
s
P
p
.002 w
.65616 .36628 m .6383 .31413 L .61945 .31246 L p
1 g
F P
s
P
p
.002 w
.58664 .27272 m .61945 .31246 L .6383 .31413 L p
1 g
F P
s
P
p
.002 w
.32408 .3673 m .3192 .41724 L .33359 .40748 L p
1 g
F P
s
P
p
.002 w
.33359 .40748 m .33792 .36435 L .32408 .3673 L p
1 g
F P
s
P
p
.002 w
.67197 .43172 m .67256 .37348 L .65616 .36628 L p
1 g
F P
s
P
p
.002 w
.6383 .31413 m .65616 .36628 L .67256 .37348 L p
1 g
F P
s
P
p
.002 w
.66491 .4989 m .68417 .44171 L .67197 .43172 L p
1 g
F P
s
P
p
.002 w
.67256 .37348 m .67197 .43172 L .68417 .44171 L p
1 g
F P
s
P
p
.002 w
.30912 .42773 m .32258 .47962 L .33116 .46397 L p
1 g
F P
s
P
p
.002 w
.33116 .46397 m .3192 .41724 L .30912 .42773 L p
1 g
F P
s
P
p
.002 w
.52699 .25477 m .4783 .2469 L .47086 .26054 L p
1 g
F P
s
P
p
.002 w
.42736 .26848 m .47086 .26054 L .4783 .2469 L p
1 g
F P
s
P
p
.002 w
.31846 .49454 m .35081 .54001 L .35254 .52205 L p
1 g
F P
s
P
p
.002 w
.35254 .52205 m .32258 .47962 L .31846 .49454 L p
1 g
F P
s
P
p
.002 w
.35305 .55568 m .40089 .58754 L .39655 .5707 L p
1 g
F P
s
P
p
.002 w
.39655 .5707 m .35081 .54001 L .35305 .55568 L p
1 g
F P
s
P
p
.002 w
.34572 .32007 m .32408 .3673 L .33792 .36435 L p
1 g
F P
s
P
p
.002 w
.33792 .36435 m .35663 .32366 L .34572 .32007 L p
1 g
F P
s
P
p
.002 w
.58972 .59575 m .63749 .55792 L .62948 .54878 L p
1 g
F P
s
P
p
.002 w
.62948 .54878 m .58134 .58689 L .58972 .59575 L p
1 g
F P
s
P
p
.002 w
.66491 .4989 m .62948 .54878 L .63749 .55792 L p
1 g
F P
s
P
p
.002 w
.40808 .60078 m .46522 .61467 L .45707 .60138 L p
1 g
F P
s
P
p
.002 w
.45707 .60138 m .40089 .58754 L .40808 .60078 L p
1 g
F P
s
P
p
.002 w
.53374 .61842 m .58972 .59575 L .58134 .58689 L p
1 g
F P
s
P
p
.002 w
.58134 .58689 m .52488 .60967 L .53374 .61842 L p
1 g
F P
s
P
p
.002 w
.4783 .2469 m .42786 .256 L .42736 .26848 L p
1 g
F P
s
P
p
.002 w
.38767 .29036 m .42736 .26848 L .42786 .256 L p
1 g
F P
s
P
p
.002 w
.58664 .27272 m .54079 .24657 L .52699 .25477 L p
1 g
F P
s
P
p
.002 w
.4783 .2469 m .52699 .25477 L .54079 .24657 L p
1 g
F P
s
P
p
.002 w
.63749 .55792 m .67269 .50845 L .66491 .4989 L p
1 g
F P
s
P
p
.002 w
.68417 .44171 m .66491 .4989 L .67269 .50845 L p
1 g
F P
s
P
p
.002 w
.38176 .28137 m .34572 .32007 L .35663 .32366 L p
1 g
F P
s
P
p
.002 w
.35663 .32366 m .38767 .29036 L .38176 .28137 L p
1 g
F P
s
P
p
.002 w
.42786 .256 m .38176 .28137 L .38767 .29036 L p
1 g
F P
s
P
p
.002 w
.6383 .31413 m .60325 .27131 L .58664 .27272 L p
1 g
F P
s
P
p
.002 w
.54079 .24657 m .58664 .27272 L .60325 .27131 L p
1 g
F P
s
P
p
.002 w
.67256 .37348 m .65413 .31899 L .6383 .31413 L p
1 g
F P
s
P
p
.002 w
.60325 .27131 m .6383 .31413 L .65413 .31899 L p
1 g
F P
s
P
p
.002 w
.47464 .62349 m .53374 .61842 L .52488 .60967 L p
1 g
F P
s
P
p
.002 w
.52488 .60967 m .46522 .61467 L .47464 .62349 L p
1 g
F P
s
P
p
.002 w
.31445 .37208 m .30912 .42773 L .3192 .41724 L p
1 g
F P
s
P
p
.002 w
.3192 .41724 m .32408 .3673 L .31445 .37208 L p
1 g
F P
s
P
p
.002 w
.68417 .44171 m .68494 .38248 L .67256 .37348 L p
1 g
F P
s
P
p
.002 w
.65413 .31899 m .67256 .37348 L .68494 .38248 L p
1 g
F P
s
P
p
.002 w
.30385 .43872 m .31846 .49454 L .32258 .47962 L p
1 g
F P
s
P
p
.002 w
.32258 .47962 m .30912 .42773 L .30385 .43872 L p
1 g
F P
s
P
p
.002 w
.67269 .50845 m .69188 .45178 L .68417 .44171 L p
1 g
F P
s
P
p
.002 w
.68494 .38248 m .68417 .44171 L .69188 .45178 L p
1 g
F P
s
P
p
.002 w
.54079 .24657 m .48662 .23768 L .4783 .2469 L p
1 g
F P
s
P
p
.002 w
.42786 .256 m .4783 .2469 L .48662 .23768 L p
1 g
F P
s
P
p
.002 w
.31916 .50829 m .35305 .55568 L .35081 .54001 L p
1 g
F P
s
P
p
.002 w
.35081 .54001 m .31846 .49454 L .31916 .50829 L p
1 g
F P
s
P
p
.002 w
.35942 .56853 m .40808 .60078 L .40089 .58754 L p
1 g
F P
s
P
p
.002 w
.40089 .58754 m .35305 .55568 L .35942 .56853 L p
1 g
F P
s
P
p
.002 w
.33856 .31933 m .31445 .37208 L .32408 .3673 L p
1 g
F P
s
P
p
.002 w
.32408 .3673 m .34572 .32007 L .33856 .31933 L p
1 g
F P
s
P
p
.002 w
.41809 .60984 m .47464 .62349 L .46522 .61467 L p
1 g
F P
s
P
p
.002 w
.46522 .61467 m .40808 .60078 L .41809 .60984 L p
1 g
F P
s
P
p
.002 w
.59602 .60049 m .6421 .56398 L .63749 .55792 L p
1 g
F P
s
P
p
.002 w
.63749 .55792 m .58972 .59575 L .59602 .60049 L p
1 g
F P
s
P
p
.002 w
.67269 .50845 m .63749 .55792 L .6421 .56398 L p
1 g
F P
s
P
p
.002 w
.54205 .62239 m .59602 .60049 L .58972 .59575 L p
1 g
F P
s
P
p
.002 w
.58972 .59575 m .53374 .61842 L .54205 .62239 L p
1 g
F P
s
P
p
.002 w
.60325 .27131 m .55402 .24305 L .54079 .24657 L p
1 g
F P
s
P
p
.002 w
.48662 .23768 m .54079 .24657 L .55402 .24305 L p
1 g
F P
s
P
p
.002 w
.48662 .23768 m .43035 .24776 L .42786 .256 L p
1 g
F P
s
P
p
.002 w
.38176 .28137 m .42786 .256 L .43035 .24776 L p
1 g
F P
s
P
p
.002 w
.6421 .56398 m .67608 .51627 L .67269 .50845 L p
1 g
F P
s
P
p
.002 w
.69188 .45178 m .67269 .50845 L .67608 .51627 L p
1 g
F P
s
P
p
.002 w
.37884 .27609 m .33856 .31933 L .34572 .32007 L p
1 g
F P
s
P
p
.002 w
.34572 .32007 m .38176 .28137 L .37884 .27609 L p
1 g
F P
s
P
p
.002 w
.65413 .31899 m .61768 .27418 L .60325 .27131 L p
1 g
F P
s
P
p
.002 w
.55402 .24305 m .60325 .27131 L .61768 .27418 L p
1 g
F P
s
P
p
.002 w
.68494 .38248 m .66638 .32707 L .65413 .31899 L p
1 g
F P
s
P
p
.002 w
.61768 .27418 m .65413 .31899 L .66638 .32707 L p
1 g
F P
s
P
p
.002 w
.43035 .24776 m .37884 .27609 L .38176 .28137 L p
1 g
F P
s
P
p
.002 w
.30955 .37869 m .30385 .43872 L .30912 .42773 L p
1 g
F P
s
P
p
.002 w
.30912 .42773 m .31445 .37208 L .30955 .37869 L p
1 g
F P
s
P
p
.002 w
.48516 .62733 m .54205 .62239 L .53374 .61842 L p
1 g
F P
s
P
p
.002 w
.53374 .61842 m .47464 .62349 L .48516 .62733 L p
1 g
F P
s
P
p
.002 w
.69188 .45178 m .69276 .39316 L .68494 .38248 L p
1 g
F P
s
P
p
.002 w
.66638 .32707 m .68494 .38248 L .69276 .39316 L p
1 g
F P
s
P
p
.002 w
.30384 .44994 m .31916 .50829 L .31846 .49454 L p
1 g
F P
s
P
p
.002 w
.31846 .49454 m .30385 .43872 L .30384 .44994 L p
1 g
F P
s
P
p
.002 w
.32497 .52042 m .35942 .56853 L .35305 .55568 L p
1 g
F P
s
P
p
.002 w
.35305 .55568 m .31916 .50829 L .32497 .52042 L p
1 g
F P
s
P
p
.002 w
.67608 .51627 m .69463 .4617 L .69188 .45178 L p
1 g
F P
s
P
p
.002 w
.69276 .39316 m .69188 .45178 L .69463 .4617 L p
1 g
F P
s
P
p
.002 w
.55402 .24305 m .49567 .23339 L .48662 .23768 L p
1 g
F P
s
P
p
.002 w
.43035 .24776 m .48662 .23768 L .49567 .23339 L p
1 g
F P
s
P
p
.002 w
.36999 .57801 m .41809 .60984 L .40808 .60078 L p
1 g
F P
s
P
p
.002 w
.40808 .60078 m .35942 .56853 L .36999 .57801 L p
1 g
F P
s
P
p
.002 w
.33559 .32167 m .30955 .37869 L .31445 .37208 L p
1 g
F P
s
P
p
.002 w
.31445 .37208 m .33856 .31933 L .33559 .32167 L p
1 g
F P
s
P
p
.002 w
.43081 .61423 m .48516 .62733 L .47464 .62349 L p
1 g
F P
s
P
p
.002 w
.47464 .62349 m .41809 .60984 L .43081 .61423 L p
1 g
F P
s
P
p
.002 w
.59991 .60071 m .64297 .5666 L .6421 .56398 L p
1 g
F P
s
P
p
.002 w
.6421 .56398 m .59602 .60049 L .59991 .60071 L p
1 g
F P
s
P
p
.002 w
.67608 .51627 m .6421 .56398 L .64297 .5666 L p
1 g
F P
s
P
p
.002 w
.61768 .27418 m .5663 .24459 L .55402 .24305 L p
1 g
F P
s
P
p
.002 w
.49567 .23339 m .55402 .24305 L .5663 .24459 L p
1 g
F P
s
P
p
.002 w
.54954 .62117 m .59991 .60071 L .59602 .60049 L p
1 g
F P
s
P
p
.002 w
.59602 .60049 m .54205 .62239 L .54954 .62117 L p
1 g
F P
s
P
p
.002 w
.49567 .23339 m .43488 .24425 L .43035 .24776 L p
1 g
F P
s
P
p
.002 w
.37884 .27609 m .43035 .24776 L .43488 .24425 L p
1 g
F P
s
P
p
.004 w
.3069 .57728 m
.31664 .56988 L
s
P
p
.004 w
.30167 .58126 m
.3069 .57728 L
s
P
p
.002 w
.66638 .32707 m .62943 .28152 L .61768 .27418 L p
1 g
F P
s
P
p
.002 w
.5663 .24459 m .61768 .27418 L .62943 .28152 L p
1 g
F P
s
P
p
.002 w
.64297 .5666 m .67471 .52205 L .67608 .51627 L p
1 g
F P
s
P
p
.002 w
.69463 .4617 m .67608 .51627 L .67471 .52205 L p
1 g
F P
s
P
p
.002 w
.69276 .39316 m .67447 .33836 L .66638 .32707 L p
1 g
F P
s
P
p
.002 w
.62943 .28152 m .66638 .32707 L .67447 .33836 L p
1 g
F P
s
P
p
.002 w
.37917 .27488 m .33559 .32167 L .33856 .31933 L p
1 g
F P
s
P
p
.002 w
.33856 .31933 m .37884 .27609 L .37917 .27488 L p
1 g
F P
s
P
p
.002 w
.43488 .24425 m .37917 .27488 L .37884 .27609 L p
1 g
F P
s
P
p
.002 w
.30983 .38705 m .30384 .44994 L .30385 .43872 L p
1 g
F P
s
P
p
.002 w
.30385 .43872 m .30955 .37869 L .30983 .38705 L p
1 g
F P
s
P
p
.002 w
.69463 .4617 m .69551 .40532 L .69276 .39316 L p
1 g
F P
s
P
p
.002 w
.67447 .33836 m .69276 .39316 L .69551 .40532 L p
1 g
F P
s
P
p
.002 w
.49653 .62576 m .54954 .62117 L .54205 .62239 L p
1 g
F P
s
P
p
.002 w
.54205 .62239 m .48516 .62733 L .49653 .62576 L p
1 g
F P
s
P
p
.002 w
.30943 .46107 m .32497 .52042 L .31916 .50829 L p
1 g
F P
s
P
p
.002 w
.31916 .50829 m .30384 .44994 L .30943 .46107 L p
1 g
F P
s
P
p
.002 w
.33601 .53047 m .36999 .57801 L .35942 .56853 L p
1 g
F P
s
P
p
.002 w
.35942 .56853 m .32497 .52042 L .33601 .53047 L p
1 g
F P
s
P
p
.002 w
.67471 .52205 m .69201 .47115 L .69463 .4617 L p
1 g
F P
s
P
p
.002 w
.69551 .40532 m .69463 .4617 L .69201 .47115 L p
1 g
F P
s
P
p
.002 w
.38471 .58365 m .43081 .61423 L .41809 .60984 L p
1 g
F P
s
P
p
.002 w
.41809 .60984 m .36999 .57801 L .38471 .58365 L p
1 g
F P
s
P
p
.002 w
.5663 .24459 m .50522 .23447 L .49567 .23339 L p
1 g
F P
s
P
p
.002 w
.43488 .24425 m .49567 .23339 L .50522 .23447 L p
1 g
F P
s
P
p
.002 w
.44603 .61353 m .49653 .62576 L .48516 .62733 L p
1 g
F P
s
P
p
.002 w
.48516 .62733 m .43081 .61423 L .44603 .61353 L p
1 g
F P
s
P
p
.002 w
.33719 .32722 m .30983 .38705 L .30955 .37869 L p
1 g
F P
s
P
p
.002 w
.30955 .37869 m .33559 .32167 L .33719 .32722 L p
1 g
F P
s
P
p
.002 w
.62943 .28152 m .5772 .25146 L .5663 .24459 L p
1 g
F P
s
P
p
.002 w
.50522 .23447 m .5663 .24459 L .5772 .25146 L p
1 g
F P
s
P
p
.002 w
.60114 .59611 m .63982 .56547 L .64297 .5666 L p
1 g
F P
s
P
p
.002 w
.64297 .5666 m .59991 .60071 L .60114 .59611 L p
1 g
F P
s
P
p
.002 w
.67471 .52205 m .64297 .5666 L .63982 .56547 L p
1 g
F P
s
P
p
.002 w
.55594 .61444 m .60114 .59611 L .59991 .60071 L p
1 g
F P
s
P
p
.002 w
.59991 .60071 m .54954 .62117 L .55594 .61444 L p
1 g
F P
s
P
p
.002 w
.67447 .33836 m .63797 .29338 L .62943 .28152 L p
1 g
F P
s
P
p
.002 w
.5772 .25146 m .62943 .28152 L .63797 .29338 L p
1 g
F P
s
P
p
.002 w
.50522 .23447 m .44147 .24589 L .43488 .24425 L p
1 g
F P
s
P
p
.002 w
.37917 .27488 m .43488 .24425 L .44147 .24589 L p
1 g
F P
s
P
p
.002 w
.69551 .40532 m .67794 .35273 L .67447 .33836 L p
1 g
F P
s
P
p
.002 w
.63797 .29338 m .67447 .33836 L .67794 .35273 L p
1 g
F P
s
P
p
.002 w
.63982 .56547 m .6683 .52547 L .67471 .52205 L p
1 g
F P
s
P
p
.002 w
.69201 .47115 m .67471 .52205 L .6683 .52547 L p
1 g
F P
s
P
p
.002 w
.38297 .27808 m .33719 .32722 L .33559 .32167 L p
1 g
F P
s
P
p
.002 w
.33559 .32167 m .37917 .27488 L .38297 .27808 L p
1 g
F P
s
P
p
.002 w
.69201 .47115 m .69281 .41869 L .69551 .40532 L p
1 g
F P
s
P
p
.002 w
.67794 .35273 m .69551 .40532 L .69281 .41869 L p
1 g
F P
s
P
p
.002 w
.31561 .39702 m .30943 .46107 L .30384 .44994 L p
1 g
F P
s
P
p
.002 w
.30384 .44994 m .30983 .38705 L .31561 .39702 L p
1 g
F P
s
P
p
.002 w
.44147 .24589 m .38297 .27808 L .37917 .27488 L p
1 g
F P
s
P
p
.002 w
.50847 .61849 m .55594 .61444 L .54954 .62117 L p
1 g
F P
s
P
p
.002 w
.54954 .62117 m .49653 .62576 L .50847 .61849 L p
1 g
F P
s
P
p
.002 w
.32079 .47177 m .33601 .53047 L .32497 .52042 L p
1 g
F P
s
P
p
.002 w
.32497 .52042 m .30943 .46107 L .32079 .47177 L p
1 g
F P
s
P
p
.002 w
.35227 .53799 m .38471 .58365 L .36999 .57801 L p
1 g
F P
s
P
p
.002 w
.36999 .57801 m .33601 .53047 L .35227 .53799 L p
1 g
F P
s
P
p
.004 w
.31664 .56988 m
.33661 .5547 L
s
P
p
.002 w
.40335 .58505 m .44603 .61353 L .43081 .61423 L p
1 g
F P
s
P
p
.002 w
.43081 .61423 m .38471 .58365 L .40335 .58505 L p
1 g
F P
s
P
p
.002 w
.6683 .52547 m .68377 .47984 L .69201 .47115 L p
1 g
F P
s
P
p
.002 w
.69281 .41869 m .69201 .47115 L .68377 .47984 L p
1 g
F P
s
P
p
.002 w
.5772 .25146 m .51502 .24123 L .50522 .23447 L p
1 g
F P
s
P
p
.002 w
.44147 .24589 m .50522 .23447 L .51502 .24123 L p
1 g
F P
s
P
p
.002 w
.46342 .60745 m .50847 .61849 L .49653 .62576 L p
1 g
F P
s
P
p
.002 w
.49653 .62576 m .44603 .61353 L .46342 .60745 L p
1 g
F P
s
P
p
.002 w
.3436 .33602 m .31561 .39702 L .30983 .38705 L p
1 g
F P
s
P
p
.002 w
.30983 .38705 m .33719 .32722 L .3436 .33602 L p
1 g
F P
s
P
p
.002 w
.63797 .29338 m .58632 .26378 L .5772 .25146 L p
1 g
F P
s
P
p
.002 w
.51502 .24123 m .5772 .25146 L .58632 .26378 L p
1 g
F P
s
P
p
.002 w
.67794 .35273 m .64286 .30968 L .63797 .29338 L p
1 g
F P
s
P
p
.002 w
.58632 .26378 m .63797 .29338 L .64286 .30968 L p
1 g
F P
s
P
p
.002 w
.59949 .58649 m .63247 .56038 L .63982 .56547 L p
1 g
F P
s
P
p
.002 w
.63982 .56547 m .60114 .59611 L .59949 .58649 L p
1 g
F P
s
P
p
.002 w
.6683 .52547 m .63982 .56547 L .63247 .56038 L p
1 g
F P
s
P
p
.002 w
.69281 .41869 m .67639 .36991 L .67794 .35273 L p
1 g
F P
s
P
p
.002 w
.64286 .30968 m .67794 .35273 L .67639 .36991 L p
1 g
F P
s
P
p
.002 w
.56098 .60206 m .59949 .58649 L .60114 .59611 L p
1 g
F P
s
P
p
.002 w
.60114 .59611 m .55594 .61444 L .56098 .60206 L p
1 g
F P
s
P
p
.002 w
.51502 .24123 m .45005 .25296 L .44147 .24589 L p
1 g
F P
s
P
p
.002 w
.38297 .27808 m .44147 .24589 L .45005 .25296 L p
1 g
F P
s
P
p
.002 w
.63247 .56038 m .65672 .52627 L .6683 .52547 L p
1 g
F P
s
P
p
.002 w
.68377 .47984 m .6683 .52547 L .65672 .52627 L p
1 g
F P
s
P
p
.002 w
.68377 .47984 m .68439 .43294 L .69281 .41869 L p
1 g
F P
s
P
p
.002 w
.67639 .36991 m .69281 .41869 L .68439 .43294 L p
1 g
F P
s
P
p
.002 w
.32707 .40839 m .32079 .47177 L .30943 .46107 L p
1 g
F P
s
P
p
.002 w
.30943 .46107 m .31561 .39702 L .32707 .40839 L p
1 g
F P
s
P
p
.002 w
.39035 .28586 m .3436 .33602 L .33719 .32722 L p
1 g
F P
s
P
p
.002 w
.33719 .32722 m .38297 .27808 L .39035 .28586 L p
1 g
F P
s
P
p
.002 w
.52064 .60541 m .56098 .60206 L .55594 .61444 L p
1 g
F P
s
P
p
.002 w
.55594 .61444 m .50847 .61849 L .52064 .60541 L p
1 g
F P
s
P
p
.002 w
.45005 .25296 m .39035 .28586 L .38297 .27808 L p
1 g
F P
s
P
p
.002 w
.33789 .48166 m .35227 .53799 L .33601 .53047 L p
1 g
F P
s
P
p
.002 w
.33601 .53047 m .32079 .47177 L .33789 .48166 L p
1 g
F P
s
P
p
.002 w
.37349 .54261 m .40335 .58505 L .38471 .58365 L p
1 g
F P
s
P
p
.002 w
.38471 .58365 m .35227 .53799 L .37349 .54261 L p
1 g
F P
s
P
p
.002 w
.42553 .58191 m .46342 .60745 L .44603 .61353 L p
1 g
F P
s
P
p
.002 w
.44603 .61353 m .40335 .58505 L .42553 .58191 L p
1 g
F P
s
P
p
.002 w
.65672 .52627 m .66981 .48744 L .68377 .47984 L p
1 g
F P
s
P
p
.002 w
.68439 .43294 m .68377 .47984 L .66981 .48744 L p
1 g
F P
s
P
p
.002 w
.58632 .26378 m .52478 .25382 L .51502 .24123 L p
1 g
F P
s
P
p
.002 w
.45005 .25296 m .51502 .24123 L .52478 .25382 L p
1 g
F P
s
P
p
.002 w
.48252 .59589 m .52064 .60541 L .50847 .61849 L p
1 g
F P
s
P
p
.002 w
.50847 .61849 m .46342 .60745 L .48252 .59589 L p
1 g
F P
s
P
p
.002 w
.64286 .30968 m .59325 .28148 L .58632 .26378 L p
1 g
F P
s
P
p
.002 w
.52478 .25382 m .58632 .26378 L .59325 .28148 L p
1 g
F P
s
P
p
.002 w
.35491 .34799 m .32707 .40839 L .31561 .39702 L p
1 g
F P
s
P
p
.002 w
.31561 .39702 m .3436 .33602 L .35491 .34799 L p
1 g
F P
s
P
p
.002 w
.67639 .36991 m .64372 .33014 L .64286 .30968 L p
1 g
F P
s
P
p
.002 w
.59325 .28148 m .64286 .30968 L .64372 .33014 L p
1 g
F P
s
P
p
.002 w
.68439 .43294 m .66959 .38951 L .67639 .36991 L p
1 g
F P
s
P
p
.002 w
.64372 .33014 m .67639 .36991 L .66959 .38951 L p
1 g
F P
s
P
p
.002 w
.59482 .57186 m .62089 .55123 L .63247 .56038 L p
1 g
F P
s
P
p
.002 w
.63247 .56038 m .59949 .58649 L .59482 .57186 L p
1 g
F P
s
P
p
.002 w
.65672 .52627 m .63247 .56038 L .62089 .55123 L p
1 g
F P
s
P
p
.002 w
.5644 .5841 m .59482 .57186 L .59949 .58649 L p
1 g
F P
s
P
p
.002 w
.59949 .58649 m .56098 .60206 L .5644 .5841 L p
1 g
F P
s
P
p
.002 w
.52478 .25382 m .46045 .26559 L .45005 .25296 L p
1 g
F P
s
P
p
.002 w
.39035 .28586 m .45005 .25296 L .46045 .26559 L p
1 g
F P
s
P
p
.002 w
.66981 .48744 m .6702 .44766 L .68439 .43294 L p
1 g
F P
s
P
p
.002 w
.66959 .38951 m .68439 .43294 L .6702 .44766 L p
1 g
F P
s
P
p
.002 w
.34415 .42085 m .33789 .48166 L .32079 .47177 L p
1 g
F P
s
P
p
.002 w
.32079 .47177 m .32707 .40839 L .34415 .42085 L p
1 g
F P
s
P
p
.002 w
.62089 .55123 m .64002 .52426 L .65672 .52627 L p
1 g
F P
s
P
p
.002 w
.66981 .48744 m .65672 .52627 L .64002 .52426 L p
1 g
F P
s
P
p
.002 w
.4013 .29827 m .35491 .34799 L .3436 .33602 L p
1 g
F P
s
P
p
.002 w
.3436 .33602 m .39035 .28586 L .4013 .29827 L p
1 g
F P
s
P
p
.002 w
.36046 .49035 m .37349 .54261 L .35227 .53799 L p
1 g
F P
s
P
p
.004 w
.33661 .5547 m
.35452 .54109 L
s
P
p
.002 w
.35227 .53799 m .33789 .48166 L .36046 .49035 L p
1 g
F P
s
P
p
.002 w
.39922 .544 m .42553 .58191 L .40335 .58505 L p
1 g
F P
s
P
p
.002 w
.40335 .58505 m .37349 .54261 L .39922 .544 L p
1 g
F P
s
P
p
.002 w
.53263 .58662 m .5644 .5841 L .56098 .60206 L p
1 g
F P
s
P
p
.002 w
.56098 .60206 m .52064 .60541 L .53263 .58662 L p
1 g
F P
s
P
p
.002 w
.46045 .26559 m .4013 .29827 L .39035 .28586 L p
1 g
F P
s
P
p
.002 w
.45066 .57411 m .48252 .59589 L .46342 .60745 L p
1 g
F P
s
P
p
.002 w
.46342 .60745 m .42553 .58191 L .45066 .57411 L p
1 g
F P
s
P
p
.002 w
.64002 .52426 m .65026 .49362 L .66981 .48744 L p
1 g
F P
s
P
p
.002 w
.6702 .44766 m .66981 .48744 L .65026 .49362 L p
1 g
F P
s
P
p
.002 w
.59325 .28148 m .53418 .27215 L .52478 .25382 L p
1 g
F P
s
P
p
.002 w
.46045 .26559 m .52478 .25382 L .53418 .27215 L p
1 g
F P
s
P
p
.002 w
.53263 .58662 m .52064 .60541 L p
.50491 .58216 L 1 g
F P
s
P
p
.50491 .58216 m .50418 .58108 L .50722 .58167 L 1 g
F
P
p
.50491 .58216 m .50722 .58167 L .53263 .58662 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .57437 L p
1 g
F P
s
P
p
.002 w
.54099 .5689 m .53958 .5719 L p
.53813 .57058 L 1 g
F P
s
P
p
.002 w
.53958 .5719 m .53263 .58662 L p
.52908 .57518 L 1 g
F P
s
P
p
.54854 .56129 m .53166 .57437 L .53985 .56957 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58083 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58083 L .51142 .58068 L 1 g
F
P
p
.002 w
.53263 .58662 m .51051 .58096 L p
.51095 .58083 L 1 g
F P
s
P
p
.5303 .5791 m .51095 .58083 L .52908 .57518 L 1 g
F
P
p
.53263 .58662 m .51095 .58083 L .5303 .5791 L 1 g
F
P
p
.51079 .57862 m .49853 .58107 L .51023 .58089 L 1 g
F
P
p
.49853 .58107 m .5001 .5812 L .51023 .58089 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.48252 .59589 m .48034 .57953 L .48909 .58027 L 1 g
F
P
p
.002 w
.5001 .5812 m .49804 .58292 L p
.48909 .58027 L 1 g
F P
s
P
p
.002 w
.49804 .58292 m .48252 .59589 L p
.48909 .58027 L 1 g
F P
s
P
p
.002 w
.48909 .58027 m .48921 .57862 L p
.48131 .57797 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58027 L p
1 g
F P
s
P
p
.002 w
.48909 .58027 m .48889 .583 L p
.49853 .58107 L 1 g
F P
s
P
p
.51079 .57862 m .48909 .58027 L .49853 .58107 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46839 .57415 L p
1 g
F P
s
P
p
.48034 .57953 m .48008 .57761 L .48909 .58027 L 1 g
F
P
p
.48921 .57862 m .46839 .57415 L .48131 .57797 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48252 .59589 m .45066 .57411 L .46037 .56971 L p
1 g
F P
s
P
p
.002 w
.46839 .57415 m .46872 .57265 L p
.45923 .56886 L 1 g
F P
s
P
p
.002 w
.46037 .56971 m .45066 .57411 L p
.45332 .56448 L 1 g
F P
s
P
p
.45923 .56886 m .45785 .56831 L .46037 .56971 L 1 g
F
P
p
.45923 .56886 m .46037 .56971 L .46839 .57415 L 1 g
F
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45093 .56271 L p
1 g
F P
s
P
p
.002 w
.45066 .57411 m .43465 .55065 L p
.45093 .56271 L 1 g
F P
s
P
p
.45307 .5654 m .45093 .56271 L .45332 .56448 L 1 g
F
P
p
.45066 .57411 m .45093 .56271 L .45307 .5654 L 1 g
F
P
p
.002 w
.45093 .56271 m .45146 .56129 L p
.4461 .55663 L 1 g
F P
s
P
p
.46872 .57265 m .45093 .56271 L .45923 .56886 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4385 .54707 L p
1 g
F P
s
P
p
.45146 .56129 m .4385 .54707 L .4461 .55663 L 1 g
F
P
p
.45332 .56448 m .44971 .56118 L .46108 .53647 L 1 g
F
P
p
.002 w
.42873 .54197 m .43376 .54112 L p
.4385 .54707 L 1 g
F P
s
P
p
.44075 .55297 m .42873 .54197 L .4385 .54707 L 1 g
F
P
p
.002 w
.4385 .54707 m .43925 .54566 L p
.43531 .53787 L 1 g
F P
s
P
p
.002 w
.43608 .54072 m .42873 .54197 L p
.43429 .53408 L 1 g
F P
s
P
p
.43531 .53787 m .43401 .53529 L .43608 .54072 L 1 g
F
P
p
.43531 .53787 m .43608 .54072 L .4385 .54707 L 1 g
F
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.44971 .56118 m .4385 .54707 L .46108 .53647 L 1 g
F
P
p
.002 w
.43376 .54112 m .43608 .54072 L p
.4385 .54707 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43275 .52837 L p
1 g
F P
s
P
p
.42873 .54197 m .426 .50327 L .43275 .52837 L 1 g
F
P
p
.43215 .53711 m .43275 .52837 L .43429 .53408 L 1 g
F
P
p
.42873 .54197 m .43275 .52837 L .43215 .53711 L 1 g
F
P
p
.002 w
.43275 .52837 m .43346 .52734 L p
.43325 .52118 L 1 g
F P
s
P
p
.43925 .54566 m .43275 .52837 L .43483 .5361 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.43429 .53408 m .43275 .52837 L .45422 .50578 L 1 g
F
P
p
.002 w
.426 .50327 m .43442 .50402 L p
.43407 .50919 L 1 g
F P
s
P
p
.42998 .51806 m .426 .50327 L .43407 .50919 L 1 g
F
P
p
.002 w
.43407 .50919 m .43485 .50826 L p
.43802 .50085 L 1 g
F P
s
P
p
.41956 .5027 m .44766 .48124 L .4428 .49113 L 1 g
F
P
p
.002 w
.43637 .5042 m .42989 .50362 L p
.4428 .49113 L 1 g
F P
s
P
p
.002 w
.42989 .50362 m .41956 .5027 L p
.4428 .49113 L 1 g
F P
s
P
p
.43802 .50085 m .43637 .5042 L .43407 .50919 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43407 .50919 L p
1 g
F P
s
P
p
.43346 .52734 m .43407 .50919 L .43325 .52118 L 1 g
F
P
p
.43275 .52837 m .43407 .50919 L .45422 .50578 L 1 g
F
P
p
.002 w
.43442 .50402 m .43637 .5042 L p
.43407 .50919 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44203 .49195 L p
1 g
F P
s
P
p
.43485 .50826 m .44203 .49195 L .43931 .49783 L 1 g
F
P
p
.002 w
.43637 .5042 m .45422 .50578 L p
.43407 .50919 L 1 g
F P
s
P
p
.002 w
.44203 .49195 m .44166 .49233 L p
.43931 .49783 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45422 .50578 m .43637 .5042 L p
.45171 .4825 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45756 .47684 L p
1 g
F P
s
P
p
.44339 .4905 m .45756 .47684 L .44923 .48491 L 1 g
F
P
p
.002 w
.45841 .47303 m .45797 .47645 L p
.45171 .4825 L 1 g
F P
s
P
p
.002 w
.45422 .50578 m .45794 .47667 L p
.49368 .48419 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47123 .47023 m .4998 .46397 L .46272 .4744 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46716 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.51444 .46606 m .52849 .47011 L .50702 .46504 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54246 .47687 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56612 .50942 L p
1 g
F P
s
P
p
.002 w
.5634 .50356 m .56321 .50107 L p
.56597 .50749 L 1 g
F P
s
P
p
.57526 .52908 m .56612 .50942 L .56597 .50749 L 1 g
F
P
p
.56612 .50942 m .5634 .50356 L .56597 .50749 L 1 g
F
P
p
.002 w
.56612 .50942 m .56515 .50826 L p
.56692 .51973 L 1 g
F P
s
P
p
.55661 .4905 m .56612 .50942 L .5641 .50505 L 1 g
F
P
p
.002 w
.56286 .50239 m .56321 .50107 L .5634 .50356 L p
1 g
F P
s
P
p
.56311 .50294 m .56669 .51009 L .56387 .50439 L 1 g
F
P
p
.55661 .4905 m .56412 .50511 L .56311 .50294 L 1 g
F
P
p
.56412 .50511 m .56669 .51009 L .56311 .50294 L 1 g
F
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56156 .54719 L p
1 g
F P
s
P
p
.566 .56085 m .56092 .549 L .56156 .54719 L 1 g
F
P
p
.002 w
.56566 .53563 m .56574 .54157 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.56574 .54157 m .566 .56085 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.56156 .54719 m .56075 .54566 L p
.55515 .55581 L 1 g
F P
s
P
p
.56654 .52734 m .56156 .54719 L .56432 .53943 L 1 g
F
P
p
.56654 .52734 m .56255 .54906 L .56265 .54867 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54931 .56335 L p
1 g
F P
s
P
p
.002 w
.566 .56085 m .5644 .5841 L p
.54709 .56575 L 1 g
F P
s
P
p
.54709 .56575 m .54931 .56335 L .566 .56085 L 1 g
F
P
p
.002 w
.55054 .562 m .55141 .56194 L p
.54931 .56335 L 1 g
F P
s
P
p
.002 w
.55141 .56194 m .566 .56085 L p
.54931 .56335 L 1 g
F P
s
P
p
.002 w
.54931 .56335 m .54854 .56129 L p
.53952 .56988 L 1 g
F P
s
P
p
.56075 .54566 m .54931 .56335 L .55054 .562 L 1 g
F
P
p
.002 w
.566 .56085 m .55054 .562 L p
.56066 .5484 L 1 g
F P
s
P
p
.55515 .55581 m .55054 .562 L .55351 .55878 L 1 g
F
P
p
.56075 .54566 m .55054 .562 L .55515 .55581 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54402 .56249 m .55435 .53367 L p
.56066 .5484 L 1 g
F P
s
P
p
.002 w
.55054 .562 m .54402 .56249 L p
.56066 .5484 L 1 g
F P
s
P
p
.002 w
.54402 .56249 m .55054 .562 L p
.54709 .56575 L 1 g
F P
s
P
p
.53128 .57265 m .51142 .58068 L .52214 .57734 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51023 .58089 m .53263 .58662 L p
.50418 .58108 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.52908 .57518 m .52346 .55707 L .53813 .57058 L 1 g
F
P
p
.53166 .57437 m .53813 .57058 L .53958 .5719 L 1 g
F
P
p
.52908 .57518 m .53813 .57058 L .53166 .57437 L 1 g
F
P
p
.002 w
.5644 .5841 m .53263 .58662 L .54402 .56249 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54951 .56391 L p
1 g
F P
s
P
p
.002 w
.54951 .56391 m .54931 .56335 L p
.54595 .566 L 1 g
F P
s
P
p
.54595 .566 m .5322 .57686 L .54951 .56391 L 1 g
F
P
p
.53952 .56988 m .5322 .57686 L .54931 .56335 L 1 g
F
P
p
.002 w
.54931 .56335 m .54998 .56518 L p
.55351 .55878 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.57526 .52908 m .56787 .53201 L p
.57029 .51839 L 1 g
F P
s
P
p
.002 w
.56787 .53201 m .56674 .53245 L p
.56763 .52893 L 1 g
F P
s
P
p
.56787 .53201 m .56763 .52893 L .57029 .51839 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56763 .52893 L p
1 g
F P
s
P
p
.56515 .50826 m .56763 .52893 L .56692 .51973 L 1 g
F
P
p
.002 w
.5765 .52859 m .58712 .55241 L p
.56636 .53356 L 1 g
F P
s
P
p
.002 w
.56674 .53245 m .5765 .52859 L p
.56636 .53356 L 1 g
F P
s
P
p
.002 w
.56763 .52893 m .56654 .52734 L p
.56428 .53973 L 1 g
F P
s
P
p
.002 w
.58712 .55241 m .566 .56085 L .56566 .53563 L p
1 g
F P
s
P
p
.58712 .55241 m .56566 .53563 L .56636 .53356 L 1 g
F
P
p
.56428 .53973 m .56265 .54867 L .56674 .53245 L 1 g
F
P
p
.56428 .53973 m .56674 .53245 L .56763 .52893 L 1 g
F
P
p
.002 w
.56566 .53563 m .56563 .53289 L p
.56636 .53356 L 1 g
F P
s
P
p
.002 w
.56563 .53289 m .56674 .53245 L p
.56636 .53356 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56783 .52922 L p
1 g
F P
s
P
p
.002 w
.56783 .52922 m .56763 .52893 L p
.56676 .53239 L 1 g
F P
s
P
p
.56676 .53239 m .56257 .5491 L .56783 .52922 L 1 g
F
P
p
.56265 .54867 m .56257 .5491 L .56763 .52893 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56563 .53289 m .5634 .50356 L p
.57029 .51839 L 1 g
F P
s
P
p
.002 w
.56674 .53245 m .56563 .53289 L p
.57029 .51839 L 1 g
F P
s
P
p
.002 w
.56763 .52893 m .56854 .53025 L p
.56692 .51973 L 1 g
F P
s
P
p
.56092 .549 m .55435 .53367 L .56566 .53563 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56156 .54719 L p
1 g
F P
s
P
p
.55515 .55581 m .54998 .56518 L .56156 .54719 L 1 g
F
P
p
.002 w
.56156 .54719 m .56255 .54906 L p
.56432 .53943 L 1 g
F P
s
P
p
.002 w
.55435 .53367 m .56563 .53289 L .56566 .53563 L p
1 g
F P
s
P
p
.002 w
.56255 .54906 m .56257 .5491 L p
.56265 .54867 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56044 .49744 m .56321 .50107 L p
.56103 .49863 L 1 g
F P
s
P
p
.002 w
.56321 .50107 m .56179 .50018 L p
.56103 .49863 L 1 g
F P
s
P
p
.002 w
.56265 .50194 m .56321 .50107 L .56286 .50239 L p
1 g
F P
s
P
p
.002 w
.55311 .4682 m .56321 .50107 L .56044 .49744 L p
1 g
F P
s
P
p
.55661 .4905 m .56318 .50307 L .55805 .49262 L 1 g
F
P
p
.002 w
.55744 .49138 m .55661 .4905 L p
.55805 .49262 L 1 g
F P
s
P
p
.56318 .50307 m .56251 .50166 L .55745 .49139 L 1 g
F
P
p
.56251 .50166 m .5624 .50143 L .55745 .49139 L 1 g
F
P
p
.5624 .50143 m .56222 .50105 L .55745 .49139 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.52962 .51566 m .52745 .50496 L .56228 .50117 L p
1 g
F P
s
P
p
.002 w
.56228 .50117 m .56321 .50107 L .5624 .50143 L p
1 g
F P
s
P
p
.002 w
.5624 .50143 m .52962 .51566 L p
.56228 .50117 L 1 g
F P
s
P
p
.5624 .50143 m .56228 .50118 L .56222 .50105 L 1 g
F
P
p
.002 w
.56179 .50018 m .56321 .50107 L .56211 .50083 L p
1 g
F P
s
P
p
.56228 .50118 m .56221 .50103 L .56179 .50018 L 1 g
F
P
p
.56228 .50118 m .56179 .50018 L .55745 .49139 L 1 g
F
P
p
.002 w
.52907 .49366 m .53433 .483 L .56179 .50018 L p
1 g
F P
s
P
p
.002 w
.56211 .50083 m .52907 .49366 L p
.56179 .50018 L 1 g
F P
s
P
p
.002 w
.52745 .50496 m .52907 .49366 L .56211 .50083 L p
1 g
F P
s
P
p
.002 w
.56211 .50083 m .56321 .50107 L .56228 .50117 L p
1 g
F P
s
P
p
.002 w
.56228 .50117 m .52745 .50496 L p
.56211 .50083 L 1 g
F P
s
P
p
.56234 .50131 m .56229 .50118 L .56221 .50103 L 1 g
F
P
p
.002 w
.5624 .50143 m .56321 .50107 L .56251 .50166 L p
1 g
F P
s
P
p
.56251 .50166 m .5624 .50143 L .56234 .50131 L 1 g
F
P
p
.5624 .50143 m .56229 .50118 L .56234 .50131 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53531 .5246 m .52962 .51566 L .5624 .50143 L p
1 g
F P
s
P
p
.002 w
.56251 .50166 m .53531 .5246 L p
.5624 .50143 L 1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55744 .49138 L p
1 g
F P
s
P
p
.002 w
.56044 .49744 m .55112 .48526 L p
.55744 .49138 L 1 g
F P
s
P
p
.002 w
.54755 .47139 m .55311 .4682 L p
.5594 .49328 L 1 g
F P
s
P
p
.55744 .49138 m .5594 .49328 L .56044 .49744 L 1 g
F
P
p
.54755 .47139 m .5594 .49328 L .55744 .49138 L 1 g
F
P
p
.002 w
.55745 .49139 m .55744 .49138 L p
.55805 .49262 L 1 g
F P
s
P
p
.002 w
.56251 .50166 m .56321 .50107 L .56265 .50194 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55794 .49191 L p
1 g
F P
s
P
p
.002 w
.55794 .49191 m .55745 .49139 L p
.56107 .49859 L 1 g
F P
s
P
p
.56107 .49859 m .56713 .51061 L .55794 .49191 L 1 g
F
P
p
.56387 .50439 m .56713 .51061 L .55745 .49139 L 1 g
F
P
p
.54083 .47612 m .54246 .47687 L .56044 .49744 L 1 g
F
P
p
.002 w
.54246 .47687 m .54174 .47608 L p
.55047 .48463 L 1 g
F P
s
P
p
.54174 .47608 m .55744 .49138 L .55048 .48464 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54593 .47847 m .55112 .48526 L p
.54246 .47687 L 1 g
F P
s
P
p
.002 w
.55112 .48526 m .56044 .49744 L p
.54246 .47687 L 1 g
F P
s
P
p
.002 w
.54247 .47688 m .54246 .47687 L p
.55048 .48464 L 1 g
F P
s
P
p
.55047 .48463 m .55048 .48464 L .54246 .47687 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54247 .47688 L p
1 g
F P
s
P
p
.55048 .48464 m .55834 .49233 L .54247 .47688 L 1 g
F
P
p
.002 w
.55744 .49138 m .55834 .49233 L p
.55048 .48464 L 1 g
F P
s
P
p
.002 w
.54265 .47419 m .54755 .47139 L p
.55744 .49138 L 1 g
F P
s
P
p
.002 w
.55112 .48526 m .54265 .47419 L p
.55744 .49138 L 1 g
F P
s
P
p
.56318 .50307 m .56387 .50439 L .56229 .50118 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54387 .53081 m .53531 .5246 L .56251 .50166 L p
1 g
F P
s
P
p
.002 w
.56265 .50194 m .54387 .53081 L p
.56251 .50166 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55435 .53367 m .54387 .53081 L .56265 .50194 L p
1 g
F P
s
P
p
.002 w
.56286 .50239 m .55435 .53367 L p
.56265 .50194 L 1 g
F P
s
P
p
.002 w
.53433 .483 m .54083 .47612 L p
.56103 .49863 L 1 g
F P
s
P
p
.002 w
.56179 .50018 m .53433 .483 L p
.56103 .49863 L 1 g
F P
s
P
p
.002 w
.56563 .53289 m .55435 .53367 L .56286 .50239 L p
1 g
F P
s
P
p
.002 w
.5634 .50356 m .56563 .53289 L p
.56286 .50239 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56612 .50942 L p
1 g
F P
s
P
p
.56692 .51973 m .56854 .53025 L .56612 .50942 L 1 g
F
P
p
.002 w
.56612 .50942 m .56669 .51009 L p
.5641 .50505 L 1 g
F P
s
P
p
.002 w
.56321 .50107 m .5765 .52859 L .57526 .52908 L p
1 g
F P
s
P
p
.54083 .47612 m .56044 .49744 L .56103 .49863 L 1 g
F
P
p
.002 w
.56669 .51009 m .56713 .51061 L p
.56387 .50439 L 1 g
F P
s
P
p
.002 w
.54246 .47687 m .54253 .47694 L p
.54152 .47643 L 1 g
F P
s
P
p
.52214 .46667 m .54246 .47687 L .54152 .47643 L 1 g
F
P
p
.52214 .46667 m .54253 .47694 L .53339 .47249 L 1 g
F
P
p
.002 w
.54083 .47612 m .54265 .47419 L .54593 .47847 L p
1 g
F P
s
P
p
.52849 .47011 m .53042 .47105 L .50702 .46504 L 1 g
F
P
p
.002 w
.53433 .483 m .50702 .46504 L p
.53042 .47105 L 1 g
F P
s
P
p
.002 w
.54083 .47612 m .53433 .483 L p
.53042 .47105 L 1 g
F P
s
P
p
.002 w
.52243 .46716 m .52214 .46667 L p
.53339 .47249 L 1 g
F P
s
P
p
.5 .4634 m .52243 .46716 L .51236 .46578 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50399 .46305 m .52047 .44557 L .53897 .46943 L p
1 g
F P
s
P
p
.002 w
.53897 .46943 m .54265 .47419 L p
.51444 .46606 L 1 g
F P
s
P
p
.50399 .46305 m .53897 .46943 L .51444 .46606 L 1 g
F
P
p
.4998 .46397 m .5 .46394 L .46272 .4744 L 1 g
F
P
p
.5 .4634 m .51236 .46578 L .50702 .46504 L 1 g
F
P
p
.002 w
.50702 .46504 m .53433 .483 L p
.50329 .46451 L 1 g
F P
s
P
p
.50385 .46459 m .50702 .46504 L .50396 .46462 L 1 g
F
P
p
.5 .4634 m .50702 .46504 L .50385 .46459 L 1 g
F
P
p
.002 w
.49368 .48419 m .50329 .46451 L p
.53433 .483 L 1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .4634 L p
.50396 .46462 L 1 g
F P
s
P
p
.002 w
.50329 .46451 m .50399 .46305 L .50702 .46504 L p
1 g
F P
s
P
p
.5 .46394 m .50155 .46372 L .50047 .46402 L 1 g
F
P
p
.5 .46394 m .50047 .46402 L .46272 .4744 L 1 g
F
P
p
.002 w
.49368 .48419 m .46272 .4744 L p
.50047 .46402 L 1 g
F P
s
P
p
.002 w
.50399 .46305 m .50329 .46451 L p
.50047 .46402 L 1 g
F P
s
P
p
.002 w
.50329 .46451 m .49368 .48419 L p
.50047 .46402 L 1 g
F P
s
P
p
.51236 .46578 m .52282 .46778 L .51494 .4665 L 1 g
F
P
p
.50396 .46462 m .51494 .4665 L .5 .46408 L 1 g
F
P
p
.51236 .46578 m .51494 .4665 L .50396 .46462 L 1 g
F
P
p
.002 w
.5 .46408 m .5 .46394 L p
.50396 .46462 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46408 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46716 L p
1 g
F P
s
P
p
.53339 .47249 m .54302 .47747 L .52243 .46716 L 1 g
F
P
p
.002 w
.54265 .47419 m .54083 .47612 L p
.53042 .47105 L 1 g
F P
s
P
p
.52849 .47011 m .54265 .47419 L .53042 .47105 L 1 g
F
P
p
.002 w
.54253 .47694 m .54302 .47747 L p
.53339 .47249 L 1 g
F P
s
P
p
.002 w
.52243 .46716 m .52282 .46778 L p
.51236 .46578 L 1 g
F P
s
P
p
.002 w
.50702 .46504 m .50399 .46305 L p
.51444 .46606 L 1 g
F P
s
P
p
.4998 .46397 m .50399 .46305 L .50155 .46372 L 1 g
F
P
p
.002 w
.4776 .4671 m .47786 .46667 L p
.48795 .46564 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.45841 .47303 m .47339 .44199 L .49646 .45787 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46394 L p
1 g
F P
s
P
p
.47123 .47023 m .4776 .4671 L .4998 .46397 L 1 g
F
P
p
.002 w
.5 .46394 m .5 .46442 L p
.48795 .46564 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46394 L .48795 .46564 L 1 g
F
P
p
.002 w
.49646 .45787 m .50399 .46305 L p
.4998 .46397 L 1 g
F P
s
P
p
.4776 .4671 m .49646 .45787 L .4998 .46397 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .4671 L p
1 g
F P
s
P
p
.45826 .47608 m .4776 .4671 L .46797 .47182 L 1 g
F
P
p
.45841 .47303 m .49646 .45787 L .47123 .47023 L 1 g
F
P
p
.002 w
.4776 .4671 m .47718 .46778 L p
.46797 .47182 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .4671 L p
1 g
F P
s
P
p
.48795 .46564 m .5 .46442 L .4776 .4671 L 1 g
F
P
p
.46548 .47304 m .46994 .47096 L .46618 .47275 L 1 g
F
P
p
.45826 .47608 m .46797 .47182 L .46548 .47304 L 1 g
F
P
p
.46797 .47182 m .46994 .47096 L .46548 .47304 L 1 g
F
P
p
.002 w
.46272 .4744 m .49368 .48419 L p
.45794 .47667 L 1 g
F P
s
P
p
.002 w
.45756 .47684 m .45826 .47608 L p
.4715 .47051 L 1 g
F P
s
P
p
.002 w
.46272 .4744 m .45841 .47303 L p
.47123 .47023 L 1 g
F P
s
P
p
.002 w
.45794 .47667 m .45841 .47303 L .46272 .4744 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .4715 .47051 L p
.46618 .47275 L 1 g
F P
s
P
p
.46994 .47096 m .47718 .46778 L .46618 .47275 L 1 g
F
P
p
.45171 .4825 m .45756 .47684 L .45422 .50578 L 1 g
F
P
p
.002 w
.45794 .47667 m .45422 .50578 L p
.45756 .47684 L 1 g
F P
s
P
p
.002 w
.4715 .47051 m .45698 .47747 L .45756 .47684 L p
1 g
F P
s
P
p
.002 w
.45797 .47645 m .45794 .47667 L p
.45756 .47684 L 1 g
F P
s
P
p
.002 w
.4428 .49113 m .44339 .4905 L p
.44923 .48491 L 1 g
F P
s
P
p
.44766 .48124 m .45841 .47303 L .43637 .5042 L 1 g
F
P
p
.002 w
.45756 .47684 m .45698 .47747 L p
.44923 .48491 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4428 .49113 L p
1 g
F P
s
P
p
.44923 .48491 m .45698 .47747 L .4428 .49113 L 1 g
F
P
p
.43802 .50085 m .43931 .49783 L .43637 .5042 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43407 .50919 L p
1 g
F P
s
P
p
.43931 .49783 m .44166 .49233 L .43407 .50919 L 1 g
F
P
p
.43275 .52837 m .42998 .51806 L .43407 .50919 L 1 g
F
P
p
.002 w
.43407 .50919 m .43287 .51061 L p
.43325 .52118 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43275 .52837 L p
1 g
F P
s
P
p
.43325 .52118 m .43287 .51061 L .43275 .52837 L 1 g
F
P
p
.002 w
.43275 .52837 m .43186 .52966 L p
.43483 .5361 L 1 g
F P
s
P
p
.002 w
.42873 .54197 m .41956 .5027 L .426 .50327 L p
1 g
F P
s
P
p
.43925 .54566 m .43186 .52966 L .43401 .53529 L 1 g
F
P
p
.002 w
.43608 .54072 m .46108 .53647 L p
.4385 .54707 L 1 g
F P
s
P
p
.002 w
.43186 .52966 m .43146 .53025 L p
.43401 .53529 L 1 g
F P
s
P
p
.002 w
.45422 .50578 m .46108 .53647 L .43608 .54072 L p
1 g
F P
s
P
p
.43429 .53408 m .45422 .50578 L .43608 .54072 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4385 .54707 L p
1 g
F P
s
P
p
.43401 .53529 m .43146 .53025 L .4385 .54707 L 1 g
F
P
p
.44971 .56118 m .44075 .55297 L .4385 .54707 L 1 g
F
P
p
.002 w
.4385 .54707 m .43743 .5491 L p
.4461 .55663 L 1 g
F P
s
P
p
.002 w
.43465 .55065 m .42873 .54197 L p
.45332 .56448 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45093 .56271 L p
1 g
F P
s
P
p
.4461 .55663 m .43743 .5491 L .45093 .56271 L 1 g
F
P
p
.002 w
.45093 .56271 m .45002 .56518 L p
.45923 .56886 L 1 g
F P
s
P
p
.002 w
.46108 .53647 m .47797 .56173 L .46037 .56971 L p
1 g
F P
s
P
p
.45332 .56448 m .46108 .53647 L .46037 .56971 L 1 g
F
P
p
.002 w
.46037 .56971 m .47797 .56173 L p
.48052 .58087 L 1 g
F P
s
P
p
.48252 .59589 m .46037 .56971 L .48052 .58087 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46839 .57415 L p
1 g
F P
s
P
p
.45785 .56831 m .45002 .56518 L .46839 .57415 L 1 g
F
P
p
.002 w
.46839 .57415 m .4678 .57686 L p
.48131 .57797 L 1 g
F P
s
P
p
.48909 .58027 m .47797 .56173 L .5001 .5812 L 1 g
F
P
p
.48008 .57761 m .47797 .56173 L .48909 .58027 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58027 L p
1 g
F P
s
P
p
.48131 .57797 m .4678 .57686 L .48909 .58027 L 1 g
F
P
p
.002 w
.47797 .56173 m .50276 .57898 L .5001 .5812 L p
1 g
F P
s
P
p
.49853 .58107 m .49746 .58128 L .5001 .5812 L 1 g
F
P
p
.002 w
.51095 .58083 m .51079 .57862 L p
.51023 .58089 L 1 g
F P
s
P
p
.51095 .58083 m .50276 .57898 L .52908 .57518 L 1 g
F
P
p
.002 w
.51051 .58096 m .51023 .58089 L p
.51095 .58083 L 1 g
F P
s
P
p
.002 w
.51023 .58089 m .50276 .57898 L p
.51095 .58083 L 1 g
F P
s
P
p
.002 w
.52064 .60541 m .48252 .59589 L .50276 .57898 L p
1 g
F P
s
P
p
.51023 .58089 m .48889 .583 L .51096 .58087 L 1 g
F
P
p
.49746 .58128 m .49072 .58263 L .51023 .58089 L 1 g
F
P
p
.49072 .58263 m .48889 .583 L .51023 .58089 L 1 g
F
P
p
.002 w
.51096 .58087 m .51095 .58083 L p
.51023 .58089 L 1 g
F P
s
P
p
.52214 .57734 m .51096 .58087 L .51836 .57928 L 1 g
F
P
p
.51142 .58068 m .51096 .58087 L .52214 .57734 L 1 g
F
P
p
.002 w
.50276 .57898 m .52346 .55707 L p
.52908 .57518 L 1 g
F P
s
P
p
.002 w
.53166 .57437 m .5322 .57686 L p
.53985 .56957 L 1 g
F P
s
P
p
.002 w
.52346 .55707 m .54402 .56249 L .54099 .5689 L p
1 g
F P
s
P
p
.53813 .57058 m .52346 .55707 L .54099 .5689 L 1 g
F
P
p
.002 w
.51095 .58083 m .51096 .58087 L p
.51142 .58068 L 1 g
F P
s
P
p
.002 w
.51096 .58087 m .51111 .583 L p
.51836 .57928 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58087 L p
1 g
F P
s
P
p
.002 w
.50276 .57898 m .51023 .58089 L p
.50418 .58108 L 1 g
F P
s
P
p
.002 w
.64372 .33014 m .59763 .30426 L .59325 .28148 L p
1 g
F P
s
P
p
.002 w
.53418 .27215 m .59325 .28148 L .59763 .30426 L p
1 g
F P
s
P
p
.002 w
.66959 .38951 m .64032 .3543 L .64372 .33014 L p
1 g
F P
s
P
p
.002 w
.59763 .30426 m .64372 .33014 L .64032 .3543 L p
1 g
F P
s
P
p
.002 w
.6702 .44766 m .65748 .41101 L .66959 .38951 L p
1 g
F P
s
P
p
.002 w
.64032 .3543 m .66959 .38951 L .65748 .41101 L p
1 g
F P
s
P
p
.002 w
.37104 .3629 m .34415 .42085 L .32707 .40839 L p
1 g
F P
s
P
p
.002 w
.32707 .40839 m .35491 .34799 L .37104 .3629 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51689 .44937 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.65026 .49362 m .65041 .46236 L .6702 .44766 L p
1 g
F P
s
P
p
.002 w
.65748 .41101 m .6702 .44766 L .65041 .46236 L p
1 g
F P
s
P
p
.002 w
.58712 .55241 m .60523 .53809 L .62089 .55123 L p
1 g
F P
s
P
p
.002 w
.62089 .55123 m .59482 .57186 L .58712 .55241 L p
1 g
F P
s
P
p
.002 w
.64002 .52426 m .62089 .55123 L .60523 .53809 L p
1 g
F P
s
P
p
.002 w
.566 .56085 m .58712 .55241 L .59482 .57186 L p
1 g
F P
s
P
p
.002 w
.59482 .57186 m .5644 .5841 L .566 .56085 L p
1 g
F P
s
P
p
.002 w
.36653 .43402 m .36046 .49035 L .33789 .48166 L p
1 g
F P
s
P
p
.002 w
.33789 .48166 m .34415 .42085 L .36653 .43402 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.53418 .27215 m .47244 .28365 L .46045 .26559 L p
1 g
F P
s
P
p
.002 w
.4013 .29827 m .46045 .26559 L .47244 .28365 L p
1 g
F P
s
P
p
.004 w
.47943 .44615 m
.5 .43051 L
s
P
p
.002 w
.38795 .49747 m .39922 .544 L .37349 .54261 L p
1 g
F P
s
P
p
.004 w
.39168 .51285 m
.46672 .45581 L
s
P
p
.002 w
.37349 .54261 m .36046 .49035 L .38795 .49747 L p
1 g
F P
s
P
p
.004 w
.3652 .53297 m
.37476 .5257 L
s
P
p
.004 w
.37476 .5257 m
.37575 .52495 L
s
P
p
.004 w
.35452 .54109 m
.3652 .53297 L
s
P
p
.002 w
.42873 .54197 m .45066 .57411 L .42553 .58191 L p
1 g
F P
s
P
p
.002 w
.42553 .58191 m .39922 .544 L .42873 .54197 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.60523 .53809 m .61848 .51936 L .64002 .52426 L p
1 g
F P
s
P
p
.002 w
.65026 .49362 m .64002 .52426 L .61848 .51936 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.41565 .31514 m .37104 .3629 L .35491 .34799 L p
1 g
F P
s
P
p
.002 w
.35491 .34799 m .4013 .29827 L .41565 .31514 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47244 .28365 m .41565 .31514 L .4013 .29827 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.61848 .51936 m .62549 .49811 L .65026 .49362 L p
1 g
F P
s
P
p
.002 w
.65041 .46236 m .65026 .49362 L .62549 .49811 L p
1 g
F P
s
P
p
.002 w
.59763 .30426 m .54285 .29591 L .53418 .27215 L p
1 g
F P
s
P
p
.002 w
.47244 .28365 m .53418 .27215 L .54285 .29591 L p
1 g
F P
s
P
p
.002 w
.65748 .41101 m .63256 .38149 L .64032 .3543 L p
1 g
F P
s
P
p
.002 w
.59919 .33157 m .64032 .3543 L .63256 .38149 L p
1 g
F P
s
P
p
.002 w
.64032 .3543 m .59919 .33157 L .59763 .30426 L p
1 g
F P
s
P
p
.002 w
.54285 .29591 m .59763 .30426 L .59919 .33157 L p
1 g
F P
s
P
p
.002 w
.65041 .46236 m .64024 .43372 L .65748 .41101 L p
1 g
F P
s
P
p
.002 w
.63256 .38149 m .65748 .41101 L .64024 .43372 L p
1 g
F P
s
P
p
.002 w
.39164 .38036 m .36653 .43402 L .34415 .42085 L p
1 g
F P
s
P
p
.002 w
.34415 .42085 m .37104 .3629 L .39164 .38036 L p
1 g
F P
s
P
p
.002 w
.62549 .49811 m .62547 .47652 L .65041 .46236 L p
1 g
F P
s
P
p
.002 w
.64024 .43372 m .65041 .46236 L .62547 .47652 L p
1 g
F P
s
P
p
.002 w
.39365 .44744 m .38795 .49747 L .36046 .49035 L p
1 g
F P
s
P
p
.002 w
.36046 .49035 m .36653 .43402 L .39365 .44744 L p
1 g
F P
s
P
p
.002 w
.41956 .5027 m .42873 .54197 L .39922 .544 L p
1 g
F P
s
P
p
.002 w
.39922 .544 m .38795 .49747 L .41956 .5027 L p
1 g
F P
s
P
p
.002 w
.5765 .52859 m .58582 .52122 L .60523 .53809 L p
1 g
F P
s
P
p
.002 w
.60523 .53809 m .58712 .55241 L .5765 .52859 L p
1 g
F P
s
P
p
.002 w
.61848 .51936 m .60523 .53809 L .58582 .52122 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.54285 .29591 m .48565 .3068 L .47244 .28365 L p
1 g
F P
s
P
p
.002 w
.41565 .31514 m .47244 .28365 L .48565 .3068 L p
1 g
F P
s
P
p
.002 w
.50653 .54506 m .52346 .55707 L .50276 .57898 L p
1 g
F P
s
P
p
.002 w
.50276 .57898 m .47797 .56173 L .50653 .54506 L p
1 g
F P
s
P
p
.002 w
.58582 .52122 m .59262 .51157 L .61848 .51936 L p
1 g
F P
s
P
p
.002 w
.62549 .49811 m .61848 .51936 L .59262 .51157 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.43304 .33609 m .39164 .38036 L .37104 .3629 L p
1 g
F P
s
P
p
.002 w
.37104 .3629 m .41565 .31514 L .43304 .33609 L p
1 g
F P
s
P
p
.002 w
.48565 .3068 m .43304 .33609 L .41565 .31514 L p
1 g
F P
s
P
p
.002 w
.59262 .51157 m .59617 .50065 L .62549 .49811 L p
1 g
F P
s
P
p
.002 w
.62547 .47652 m .62549 .49811 L .59617 .50065 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.64024 .43372 m .62056 .41083 L .63256 .38149 L p
1 g
F P
s
P
p
.002 w
.59775 .36262 m .63256 .38149 L .62056 .41083 L p
1 g
F P
s
P
p
.002 w
.63256 .38149 m .59775 .36262 L .59919 .33157 L p
1 g
F P
s
P
p
.002 w
.59919 .33157 m .55046 .32447 L .54285 .29591 L p
1 g
F P
s
P
p
.002 w
.48565 .3068 m .54285 .29591 L .55046 .32447 L p
1 g
F P
s
P
p
.002 w
.62547 .47652 m .6183 .45687 L .64024 .43372 L p
1 g
F P
s
P
p
.002 w
.62056 .41083 m .64024 .43372 L .6183 .45687 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.55046 .32447 m .59919 .33157 L .59775 .36262 L p
1 g
F P
s
P
p
.002 w
.54387 .53081 m .55435 .53367 L .54402 .56249 L p
1 g
F P
s
P
p
.002 w
.54402 .56249 m .52346 .55707 L .54387 .53081 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.59617 .50065 m .59608 .4896 L .62547 .47652 L p
1 g
F P
s
P
p
.002 w
.6183 .45687 m .62547 .47652 L .59608 .4896 L p
1 g
F P
s
P
p
.002 w
.41613 .39983 m .39365 .44744 L .36653 .43402 L p
1 g
F P
s
P
p
.002 w
.36653 .43402 m .39164 .38036 L .41613 .39983 L p
1 g
F P
s
P
p
.002 w
.49514 .52761 m .50653 .54506 L .47797 .56173 L p
1 g
F P
s
P
p
.002 w
.47797 .56173 m .46108 .53647 L .49514 .52761 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42464 .46062 m .41956 .5027 L .38795 .49747 L p
1 g
F P
s
P
p
.002 w
.38795 .49747 m .39365 .44744 L .42464 .46062 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.53531 .5246 m .54387 .53081 L .52346 .55707 L p
1 g
F P
s
P
p
.002 w
.52346 .55707 m .50653 .54506 L .53531 .5246 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58582 .52122 m .5765 .52859 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.59262 .51157 m .58582 .52122 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.55046 .32447 m .49967 .33439 L .48565 .3068 L p
1 g
F P
s
P
p
.002 w
.43304 .33609 m .48565 .3068 L .49967 .33439 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59617 .50065 m .59262 .51157 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.6183 .45687 m .60463 .4413 L .62056 .41083 L p
1 g
F P
s
P
p
.002 w
.59326 .39637 m .62056 .41083 L .60463 .4413 L p
1 g
F P
s
P
p
.002 w
.62056 .41083 m .59326 .39637 L .59775 .36262 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.59608 .4896 m .59232 .47961 L .6183 .45687 L p
1 g
F P
s
P
p
.002 w
.60463 .4413 m .6183 .45687 L .59232 .47961 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.45296 .36052 m .41613 .39983 L .39164 .38036 L p
1 g
F P
s
P
p
.002 w
.39164 .38036 m .43304 .33609 L .45296 .36052 L p
1 g
F P
s
P
p
.002 w
.59608 .4896 m .59617 .50065 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.55667 .35695 m .59775 .36262 L .59326 .39637 L p
1 g
F P
s
P
p
.002 w
.59775 .36262 m .55667 .35695 L .55046 .32447 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.49967 .33439 m .55046 .32447 L .55667 .35695 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.49967 .33439 m .45296 .36052 L .43304 .33609 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52962 .51566 m .53531 .5246 L .50653 .54506 L p
1 g
F P
s
P
p
.002 w
.50653 .54506 m .49514 .52761 L .52962 .51566 L p
1 g
F P
s
P
p
.002 w
.49064 .50655 m .49514 .52761 L .46108 .53647 L p
1 g
F P
s
P
p
.002 w
.46108 .53647 m .45422 .50578 L .49064 .50655 L p
1 g
F P
s
P
p
.002 w
.59232 .47961 m .59608 .4896 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.41956 .5027 m .42464 .46062 L .45841 .47303 L p
1 g
F P
s
P
p
.002 w
.44372 .42063 m .42464 .46062 L .39365 .44744 L p
1 g
F P
s
P
p
.002 w
.39365 .44744 m .41613 .39983 L .44372 .42063 L p
1 g
F P
s
P
p
.002 w
.59232 .47961 m .58528 .47177 L .60463 .4413 L p
1 g
F P
s
P
p
.002 w
.58582 .43159 m .60463 .4413 L .58528 .47177 L p
1 g
F P
s
P
p
.002 w
.60463 .4413 m .58582 .43159 L .59326 .39637 L p
1 g
F P
s
P
p
.002 w
.58528 .47177 m .59232 .47961 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56121 .39221 m .59326 .39637 L .58582 .43159 L p
1 g
F P
s
P
p
.002 w
.59326 .39637 m .56121 .39221 L .55667 .35695 L p
1 g
F P
s
P
p
.002 w
.52745 .50496 m .52962 .51566 L .49514 .52761 L p
1 g
F P
s
P
p
.002 w
.49514 .52761 m .49064 .50655 L .52745 .50496 L p
1 g
F P
s
P
p
.002 w
.55667 .35695 m .51397 .36552 L .49967 .33439 L p
1 g
F P
s
P
p
.002 w
.45296 .36052 m .49967 .33439 L .51397 .36552 L p
1 g
F P
s
P
p
.002 w
.57567 .46694 m .58528 .47177 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.56455 .4657 m .57567 .46694 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.55311 .4682 m .56455 .4657 L .56321 .50107 L closepath p
1 g
F P
s
P
p
.002 w
.58528 .47177 m .57567 .46694 L .58582 .43159 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.51397 .36552 m .55667 .35695 L .56121 .39221 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47473 .3876 m .44372 .42063 L .41613 .39983 L p
1 g
F P
s
P
p
.002 w
.41613 .39983 m .45296 .36052 L .47473 .3876 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.004 w
.56321 .50107 m
.56359 .50149 L
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.004 w
.56429 .50228 m
.56523 .50333 L
s
P
p
.002 w
.49368 .48419 m .49064 .50655 L .45422 .50578 L p
1 g
F P
s
P
p
.002 w
.56387 .42894 m .58582 .43159 L .57567 .46694 L p
1 g
F P
s
P
p
.002 w
.58582 .43159 m .56387 .42894 L .56121 .39221 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51397 .36552 m .47473 .3876 L .45296 .36052 L p
1 g
F P
s
P
p
.002 w
.57567 .46694 m .56455 .4657 L .56387 .42894 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47339 .44199 m .45841 .47303 L .42464 .46062 L p
1 g
F P
s
P
p
.002 w
.42464 .46062 m .44372 .42063 L .47339 .44199 L p
1 g
F P
s
P
p
.002 w
.52907 .49366 m .52745 .50496 L .49064 .50655 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49064 .50655 m .49368 .48419 L .52907 .49366 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.004 w
.56523 .50333 m
.56544 .50355 L
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56455 .4657 m .55311 .4682 L .54123 .43375 L p
1 g
F P
s
P
p
.002 w
.54123 .43375 m .56387 .42894 L .56455 .4657 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52801 .39908 m .56121 .39221 L .56387 .42894 L p
1 g
F P
s
P
p
.002 w
.56121 .39221 m .52801 .39908 L .51397 .36552 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.53433 .483 m .52907 .49366 L .49368 .48419 L p
1 g
F P
s
P
p
.002 w
.47473 .3876 m .51397 .36552 L .52801 .39908 L p
1 g
F P
s
P
p
.002 w
.55311 .4682 m .54265 .47419 L .52047 .44557 L p
1 g
F P
s
P
p
.002 w
.52047 .44557 m .54123 .43375 L .55311 .4682 L p
1 g
F P
s
P
p
.002 w
.56387 .42894 m .54123 .43375 L .52801 .39908 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.004 w
.56615 .50435 m
.5673 .50563 L
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.004 w
.56802 .50643 m
.56962 .50823 L
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49753 .41632 m .47339 .44199 L .44372 .42063 L p
1 g
F P
s
P
p
.002 w
.44372 .42063 m .47473 .3876 L .49753 .41632 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52801 .39908 m .49753 .41632 L .47473 .3876 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49753 .41632 m .52801 .39908 L .54123 .43375 L p
1 g
F P
s
P
p
.002 w
.54123 .43375 m .52047 .44557 L .49753 .41632 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52047 .44557 m .50399 .46305 L .47339 .44199 L p
1 g
F P
s
P
p
.002 w
.47339 .44199 m .49753 .41632 L .52047 .44557 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.004 w
.5699 .50853 m
.57107 .50984 L
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.004 w
.57179 .51065 m
.57297 .51196 L
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.004 w
.5737 .51278 m
.57489 .5141 L
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.004 w
.57563 .51493 m
.57682 .51626 L
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.57756 .51709 m
.57877 .51843 L
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.004 w
.57952 .51927 m
.58073 .52062 L
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.5827 .52283 m
.60169 .54402 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .30167 .58126 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60169 .54402 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.189922)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.189922)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49543 .47869 m .53186 .45775 L .51468 .4352 L p
1 g
F P
s
P
p
.002 w
.51468 .4352 m .48435 .45261 L .49543 .47869 L p
1 g
F P
s
P
p
.002 w
.53902 .41037 m .51468 .4352 L .53186 .45775 L p
1 g
F P
s
P
p
.002 w
.48435 .45261 m .51468 .4352 L .4972 .4126 L p
1 g
F P
s
P
p
.002 w
.51468 .4352 m .53902 .41037 L .516 .39331 L p
1 g
F P
s
P
p
.002 w
.516 .39331 m .4972 .4126 L .51468 .4352 L p
1 g
F P
s
P
p
.002 w
.4972 .4126 m .47368 .42607 L .48435 .45261 L p
1 g
F P
s
P
p
.002 w
.47368 .42607 m .4972 .4126 L .47972 .39035 L p
1 g
F P
s
P
p
.002 w
.4972 .4126 m .516 .39331 L .49254 .37712 L p
1 g
F P
s
P
p
.002 w
.49254 .37712 m .47972 .39035 L .4972 .4126 L p
1 g
F P
s
P
p
.002 w
.45091 .46089 m .48435 .45261 L .47368 .42607 L p
1 g
F P
s
P
p
.002 w
.47368 .42607 m .44776 .43238 L .45091 .46089 L p
1 g
F P
s
P
p
.002 w
.44776 .43238 m .47368 .42607 L .46361 .39956 L p
1 g
F P
s
P
p
.002 w
.47972 .39035 m .46361 .39956 L .47368 .42607 L p
1 g
F P
s
P
p
.002 w
.45528 .48882 m .49543 .47869 L .48435 .45261 L p
1 g
F P
s
P
p
.002 w
.48435 .45261 m .45091 .46089 L .45528 .48882 L p
1 g
F P
s
P
p
.002 w
.52817 .37007 m .516 .39331 L .53902 .41037 L p
1 g
F P
s
P
p
.002 w
.516 .39331 m .52817 .37007 L .50076 .36119 L p
1 g
F P
s
P
p
.002 w
.50076 .36119 m .49254 .37712 L .516 .39331 L p
1 g
F P
s
P
p
.002 w
.50673 .50385 m .54843 .47984 L .53186 .45775 L p
1 g
F P
s
P
p
.002 w
.53186 .45775 m .49543 .47869 L .50673 .50385 L p
1 g
F P
s
P
p
.002 w
.56119 .42798 m .53186 .45775 L .54843 .47984 L p
1 g
F P
s
P
p
.002 w
.53186 .45775 m .56119 .42798 L .53902 .41037 L p
1 g
F P
s
P
p
.002 w
.55493 .38044 m .53902 .41037 L .56119 .42798 L p
1 g
F P
s
P
p
.002 w
.53902 .41037 m .55493 .38044 L .52817 .37007 L p
1 g
F P
s
P
p
.002 w
.46361 .39956 m .47972 .39035 L .46256 .36887 L p
1 g
F P
s
P
p
.002 w
.47972 .39035 m .49254 .37712 L .46908 .3621 L p
1 g
F P
s
P
p
.002 w
.46908 .3621 m .46256 .36887 L .47972 .39035 L p
1 g
F P
s
P
p
.002 w
.46361 .39956 m .44587 .4038 L .44776 .43238 L p
1 g
F P
s
P
p
.002 w
.44587 .4038 m .46361 .39956 L .45434 .37356 L p
1 g
F P
s
P
p
.002 w
.46256 .36887 m .45434 .37356 L .46361 .39956 L p
1 g
F P
s
P
p
.002 w
.4608 .51564 m .50673 .50385 L .49543 .47869 L p
1 g
F P
s
P
p
.002 w
.49543 .47869 m .45528 .48882 L .4608 .51564 L p
1 g
F P
s
P
p
.002 w
.41759 .4591 m .45091 .46089 L .44776 .43238 L p
1 g
F P
s
P
p
.002 w
.44776 .43238 m .422 .4308 L .41759 .4591 L p
1 g
F P
s
P
p
.002 w
.422 .4308 m .44776 .43238 L .44587 .4038 L p
1 g
F P
s
P
p
.002 w
.49254 .37712 m .50076 .36119 L .47322 .35397 L p
1 g
F P
s
P
p
.002 w
.47322 .35397 m .46908 .3621 L .49254 .37712 L p
1 g
F P
s
P
p
.002 w
.41518 .48697 m .45528 .48882 L .45091 .46089 L p
1 g
F P
s
P
p
.002 w
.45091 .46089 m .41759 .4591 L .41518 .48697 L p
1 g
F P
s
P
p
.002 w
.44587 .4038 m .42829 .40259 L .422 .4308 L p
1 g
F P
s
P
p
.002 w
.42829 .40259 m .44587 .4038 L .44529 .37568 L p
1 g
F P
s
P
p
.002 w
.45434 .37356 m .44529 .37568 L .44587 .4038 L p
1 g
F P
s
P
p
.002 w
.54843 .47984 m .58209 .44585 L .56119 .42798 L p
1 g
F P
s
P
p
.002 w
.58055 .39211 m .56119 .42798 L .58209 .44585 L p
1 g
F P
s
P
p
.002 w
.56119 .42798 m .58055 .39211 L .55493 .38044 L p
1 g
F P
s
P
p
.002 w
.53238 .34518 m .52817 .37007 L .55493 .38044 L p
1 g
F P
s
P
p
.002 w
.52817 .37007 m .53238 .34518 L .50348 .34419 L p
1 g
F P
s
P
p
.002 w
.50348 .34419 m .50076 .36119 L .52817 .37007 L p
1 g
F P
s
P
p
.002 w
.51804 .5276 m .56405 .50106 L .54843 .47984 L p
1 g
F P
s
P
p
.002 w
.54843 .47984 m .50673 .50385 L .51804 .5276 L p
1 g
F P
s
P
p
.002 w
.58209 .44585 m .54843 .47984 L .56405 .50106 L p
1 g
F P
s
P
p
.002 w
.50076 .36119 m .50348 .34419 L .47452 .34532 L p
1 g
F P
s
P
p
.002 w
.47452 .34532 m .47322 .35397 L .50076 .36119 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .45434 .37356 L .46256 .36887 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .46256 .36887 L .46908 .3621 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .44529 .37568 L .45434 .37356 L closepath p
1 g
F P
s
P
p
.002 w
.41483 .51384 m .4608 .51564 L .45528 .48882 L p
1 g
F P
s
P
p
.002 w
.45528 .48882 m .41518 .48697 L .41483 .51384 L p
1 g
F P
s
P
p
.002 w
.46738 .54081 m .51804 .5276 L .50673 .50385 L p
1 g
F P
s
P
p
.002 w
.50673 .50385 m .4608 .51564 L .46738 .54081 L p
1 g
F P
s
P
p
.002 w
.56067 .34827 m .55493 .38044 L .58055 .39211 L p
1 g
F P
s
P
p
.002 w
.55493 .38044 m .56067 .34827 L .53238 .34518 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .46908 .3621 L .47322 .35397 L closepath p
1 g
F P
s
P
p
.002 w
.39905 .42134 m .422 .4308 L .42829 .40259 L p
1 g
F P
s
P
p
.002 w
.42829 .40259 m .41272 .39599 L .39905 .42134 L p
1 g
F P
s
P
p
.002 w
.41272 .39599 m .42829 .40259 L .43636 .375 L p
1 g
F P
s
P
p
.002 w
.44529 .37568 m .43636 .375 L .42829 .40259 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .43636 .375 L .44529 .37568 L closepath p
1 g
F P
s
P
p
.002 w
.38775 .44716 m .41759 .4591 L .422 .4308 L p
1 g
F P
s
P
p
.002 w
.422 .4308 m .39905 .42134 L .38775 .44716 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .47322 .35397 L .47452 .34532 L closepath p
1 g
F P
s
P
p
.002 w
.56405 .50106 m .60131 .46362 L .58209 .44585 L p
1 g
F P
s
P
p
.002 w
.60451 .40488 m .58209 .44585 L .60131 .46362 L p
1 g
F P
s
P
p
.002 w
.58209 .44585 m .60451 .40488 L .58055 .39211 L p
1 g
F P
s
P
p
.002 w
.43636 .375 m .42849 .37157 L .41272 .39599 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .42849 .37157 L .43636 .375 L closepath p
1 g
F P
s
P
p
.002 w
.50031 .32789 m .50348 .34419 L .53238 .34518 L p
1 g
F P
s
P
p
.002 w
.50348 .34419 m .50031 .32789 L .47281 .33708 L p
1 g
F P
s
P
p
.002 w
.47281 .33708 m .47452 .34532 L .50348 .34419 L p
1 g
F P
s
P
p
.002 w
.37909 .47294 m .41518 .48697 L .41759 .4591 L p
1 g
F P
s
P
p
.002 w
.41759 .4591 m .38775 .44716 L .37909 .47294 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .47452 .34532 L .47281 .33708 L closepath p
1 g
F P
s
P
p
.002 w
.5878 .35344 m .58055 .39211 L .60451 .40488 L p
1 g
F P
s
P
p
.002 w
.58055 .39211 m .5878 .35344 L .56067 .34827 L p
1 g
F P
s
P
p
.002 w
.52799 .32117 m .53238 .34518 L .56067 .34827 L p
1 g
F P
s
P
p
.002 w
.53238 .34518 m .52799 .32117 L .50031 .32789 L p
1 g
F P
s
P
p
.002 w
.40085 .38459 m .41272 .39599 L .42849 .37157 L p
1 g
F P
s
P
p
.002 w
.42849 .37157 m .42255 .36573 L .40085 .38459 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .42255 .36573 L .42849 .37157 L closepath p
1 g
F P
s
P
p
.002 w
.41662 .53917 m .46738 .54081 L .4608 .51564 L p
1 g
F P
s
P
p
.002 w
.4608 .51564 m .41483 .51384 L .41662 .53917 L p
1 g
F P
s
P
p
.002 w
.38138 .4048 m .39905 .42134 L .41272 .39599 L p
1 g
F P
s
P
p
.002 w
.41272 .39599 m .40085 .38459 L .38138 .4048 L p
1 g
F P
s
P
p
.002 w
.52915 .54944 m .57842 .52098 L .56405 .50106 L p
1 g
F P
s
P
p
.002 w
.56405 .50106 m .51804 .5276 L .52915 .54944 L p
1 g
F P
s
P
p
.002 w
.60131 .46362 m .56405 .50106 L .57842 .52098 L p
1 g
F P
s
P
p
.002 w
.46827 .33014 m .47281 .33708 L .50031 .32789 L p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .47281 .33708 L .46827 .33014 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .41919 .35809 L .42255 .36573 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .46827 .33014 L .46134 .32526 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .46134 .32526 L .45277 .32301 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .45277 .32301 L .4435 .32365 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .4435 .32365 L .43455 .32714 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .43455 .32714 L .42693 .33308 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .42693 .33308 L .42149 .34081 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .42149 .34081 L .41881 .34947 L closepath p
1 g
F P
s
P
p
.002 w
.44605 .34855 m .41881 .34947 L .41919 .35809 L closepath p
1 g
F P
s
P
p
.002 w
.47493 .56379 m .52915 .54944 L .51804 .5276 L p
1 g
F P
s
P
p
.002 w
.51804 .5276 m .46738 .54081 L .47493 .56379 L p
1 g
F P
s
P
p
.002 w
.39402 .36955 m .40085 .38459 L .42255 .36573 L p
1 g
F P
s
P
p
.002 w
.42255 .36573 m .41919 .35809 L .39402 .36955 L p
1 g
F P
s
P
p
.002 w
.36459 .42596 m .38775 .44716 L .39905 .42134 L p
1 g
F P
s
P
p
.002 w
.39905 .42134 m .38138 .4048 L .36459 .42596 L p
1 g
F P
s
P
p
.002 w
.37331 .49814 m .41483 .51384 L .41518 .48697 L p
1 g
F P
s
P
p
.002 w
.41518 .48697 m .37909 .47294 L .37331 .49814 L p
1 g
F P
s
P
p
.002 w
.55533 .31709 m .56067 .34827 L .5878 .35344 L p
1 g
F P
s
P
p
.002 w
.56067 .34827 m .55533 .31709 L .52799 .32117 L p
1 g
F P
s
P
p
.002 w
.49148 .31404 m .50031 .32789 L .52799 .32117 L p
1 g
F P
s
P
p
.002 w
.50031 .32789 m .49148 .31404 L .46827 .33014 L p
1 g
F P
s
P
p
.002 w
.46134 .32526 m .46827 .33014 L .49148 .31404 L p
1 g
F P
s
P
p
.002 w
.57842 .52098 m .61843 .48097 L .60131 .46362 L p
1 g
F P
s
P
p
.002 w
.62631 .41853 m .60131 .46362 L .61843 .48097 L p
1 g
F P
s
P
p
.002 w
.60131 .46362 m .62631 .41853 L .60451 .40488 L p
1 g
F P
s
P
p
.002 w
.6132 .36064 m .60451 .40488 L .62631 .41853 L p
1 g
F P
s
P
p
.002 w
.60451 .40488 m .6132 .36064 L .5878 .35344 L p
1 g
F P
s
P
p
.002 w
.39311 .35243 m .39402 .36955 L .41919 .35809 L p
1 g
F P
s
P
p
.002 w
.41919 .35809 m .41881 .34947 L .39311 .35243 L p
1 g
F P
s
P
p
.002 w
.37108 .38273 m .38138 .4048 L .40085 .38459 L p
1 g
F P
s
P
p
.002 w
.40085 .38459 m .39402 .36955 L .37108 .38273 L p
1 g
F P
s
P
p
.002 w
.49148 .31404 m .47784 .30422 L .46134 .32526 L p
1 g
F P
s
P
p
.002 w
.45277 .32301 m .46134 .32526 L .47784 .30422 L p
1 g
F P
s
P
p
.002 w
.51524 .30063 m .52799 .32117 L .55533 .31709 L p
1 g
F P
s
P
p
.002 w
.52799 .32117 m .51524 .30063 L .49148 .31404 L p
1 g
F P
s
P
p
.002 w
.3509 .44767 m .37909 .47294 L .38775 .44716 L p
1 g
F P
s
P
p
.002 w
.38775 .44716 m .36459 .42596 L .3509 .44767 L p
1 g
F P
s
P
p
.002 w
.39832 .33514 m .39311 .35243 L .41881 .34947 L p
1 g
F P
s
P
p
.002 w
.41881 .34947 m .42149 .34081 L .39832 .33514 L p
1 g
F P
s
P
p
.002 w
.42057 .56236 m .47493 .56379 L .46738 .54081 L p
1 g
F P
s
P
p
.002 w
.46738 .54081 m .41662 .53917 L .42057 .56236 L p
1 g
F P
s
P
p
.002 w
.47784 .30422 m .49148 .31404 L .51524 .30063 L p
1 g
F P
s
P
p
.002 w
.58176 .3158 m .5878 .35344 L .6132 .36064 L p
1 g
F P
s
P
p
.002 w
.5878 .35344 m .58176 .3158 L .55533 .31709 L p
1 g
F P
s
P
p
.002 w
.47784 .30422 m .46083 .29961 L .45277 .32301 L p
1 g
F P
s
P
p
.002 w
.4435 .32365 m .45277 .32301 L .46083 .29961 L p
1 g
F P
s
P
p
.002 w
.37064 .52223 m .41662 .53917 L .41483 .51384 L p
1 g
F P
s
P
p
.002 w
.41483 .51384 m .37331 .49814 L .37064 .52223 L p
1 g
F P
s
P
p
.002 w
.40915 .31965 m .39832 .33514 L .42149 .34081 L p
1 g
F P
s
P
p
.002 w
.42149 .34081 m .42693 .33308 L .40915 .31965 L p
1 g
F P
s
P
p
.002 w
.53982 .56887 m .59119 .53915 L .57842 .52098 L p
1 g
F P
s
P
p
.002 w
.57842 .52098 m .52915 .54944 L .53982 .56887 L p
1 g
F P
s
P
p
.002 w
.61843 .48097 m .57842 .52098 L .59119 .53915 L p
1 g
F P
s
P
p
.002 w
.46083 .29961 m .44231 .3008 L .4435 .32365 L p
1 g
F P
s
P
p
.002 w
.43455 .32714 m .4435 .32365 L .44231 .3008 L p
1 g
F P
s
P
p
.002 w
.3509 .39743 m .36459 .42596 L .38138 .4048 L p
1 g
F P
s
P
p
.002 w
.38138 .4048 m .37108 .38273 L .3509 .39743 L p
1 g
F P
s
P
p
.002 w
.42439 .30774 m .40915 .31965 L .42693 .33308 L p
1 g
F P
s
P
p
.002 w
.42693 .33308 m .43455 .32714 L .42439 .30774 L p
1 g
F P
s
P
p
.002 w
.3695 .35745 m .37108 .38273 L .39402 .36955 L p
1 g
F P
s
P
p
.002 w
.39402 .36955 m .39311 .35243 L .3695 .35745 L p
1 g
F P
s
P
p
.002 w
.44231 .3008 m .42439 .30774 L .43455 .32714 L p
1 g
F P
s
P
p
.002 w
.48333 .58401 m .53982 .56887 L .52915 .54944 L p
1 g
F P
s
P
p
.002 w
.52915 .54944 m .47493 .56379 L .48333 .58401 L p
1 g
F P
s
P
p
.002 w
.53907 .29025 m .55533 .31709 L .58176 .3158 L p
1 g
F P
s
P
p
.002 w
.55533 .31709 m .53907 .29025 L .51524 .30063 L p
1 g
F P
s
P
p
.002 w
.61843 .48097 m .64544 .43281 L .62631 .41853 L p
1 g
F P
s
P
p
.002 w
.63629 .36976 m .62631 .41853 L .64544 .43281 L p
1 g
F P
s
P
p
.002 w
.62631 .41853 m .63629 .36976 L .6132 .36064 L p
1 g
F P
s
P
p
.002 w
.3407 .46948 m .37331 .49814 L .37909 .47294 L p
1 g
F P
s
P
p
.002 w
.37909 .47294 m .3509 .44767 L .3407 .46948 L p
1 g
F P
s
P
p
.002 w
.51524 .30063 m .49525 .28594 L .47784 .30422 L p
1 g
F P
s
P
p
.002 w
.46083 .29961 m .47784 .30422 L .49525 .28594 L p
1 g
F P
s
P
p
.002 w
.59119 .53915 m .63301 .49751 L .61843 .48097 L p
1 g
F P
s
P
p
.002 w
.64544 .43281 m .61843 .48097 L .63301 .49751 L p
1 g
F P
s
P
p
.002 w
.49525 .28594 m .51524 .30063 L .53907 .29025 L p
1 g
F P
s
P
p
.002 w
.37709 .33175 m .3695 .35745 L .39311 .35243 L p
1 g
F P
s
P
p
.002 w
.39311 .35243 m .39832 .33514 L .37709 .33175 L p
1 g
F P
s
P
p
.002 w
.6067 .31741 m .6132 .36064 L .63629 .36976 L p
1 g
F P
s
P
p
.002 w
.6132 .36064 m .6067 .31741 L .58176 .3158 L p
1 g
F P
s
P
p
.002 w
.33404 .41337 m .3509 .44767 L .36459 .42596 L p
1 g
F P
s
P
p
.002 w
.36459 .42596 m .3509 .39743 L .33404 .41337 L p
1 g
F P
s
P
p
.002 w
.4267 .58283 m .48333 .58401 L .47493 .56379 L p
1 g
F P
s
P
p
.002 w
.47493 .56379 m .42057 .56236 L .4267 .58283 L p
1 g
F P
s
P
p
.002 w
.49525 .28594 m .4701 .27892 L .46083 .29961 L p
1 g
F P
s
P
p
.002 w
.44231 .3008 m .46083 .29961 L .4701 .27892 L p
1 g
F P
s
P
p
.002 w
.37125 .54461 m .42057 .56236 L .41662 .53917 L p
1 g
F P
s
P
p
.002 w
.41662 .53917 m .37064 .52223 L .37125 .54461 L p
1 g
F P
s
P
p
.002 w
.34859 .36449 m .3509 .39743 L .37108 .38273 L p
1 g
F P
s
P
p
.002 w
.37108 .38273 m .3695 .35745 L .34859 .36449 L p
1 g
F P
s
P
p
.002 w
.39313 .30864 m .37709 .33175 L .39832 .33514 L p
1 g
F P
s
P
p
.002 w
.39832 .33514 m .40915 .31965 L .39313 .30864 L p
1 g
F P
s
P
p
.002 w
.56247 .28321 m .58176 .3158 L .6067 .31741 L p
1 g
F P
s
P
p
.002 w
.58176 .3158 m .56247 .28321 L .53907 .29025 L p
1 g
F P
s
P
p
.002 w
.5498 .58536 m .60204 .55511 L .59119 .53915 L p
1 g
F P
s
P
p
.002 w
.59119 .53915 m .53982 .56887 L .5498 .58536 L p
1 g
F P
s
P
p
.002 w
.63301 .49751 m .59119 .53915 L .60204 .55511 L p
1 g
F P
s
P
p
.002 w
.4701 .27892 m .44256 .28058 L .44231 .3008 L p
1 g
F P
s
P
p
.002 w
.42439 .30774 m .44231 .3008 L .44256 .28058 L p
1 g
F P
s
P
p
.002 w
.41585 .29087 m .39313 .30864 L .40915 .31965 L p
1 g
F P
s
P
p
.002 w
.40915 .31965 m .42439 .30774 L .41585 .29087 L p
1 g
F P
s
P
p
.002 w
.33437 .4909 m .37064 .52223 L .37331 .49814 L p
1 g
F P
s
P
p
.002 w
.37331 .49814 m .3407 .46948 L .33437 .4909 L p
1 g
F P
s
P
p
.002 w
.49244 .60091 m .5498 .58536 L .53982 .56887 L p
1 g
F P
s
P
p
.002 w
.53982 .56887 m .48333 .58401 L .49244 .60091 L p
1 g
F P
s
P
p
.002 w
.44256 .28058 m .41585 .29087 L .42439 .30774 L p
1 g
F P
s
P
p
.002 w
.53907 .29025 m .51323 .27089 L .49525 .28594 L p
1 g
F P
s
P
p
.002 w
.4701 .27892 m .49525 .28594 L .51323 .27089 L p
1 g
F P
s
P
p
.002 w
.63301 .49751 m .66139 .44744 L .64544 .43281 L p
1 g
F P
s
P
p
.002 w
.65649 .38069 m .64544 .43281 L .66139 .44744 L p
1 g
F P
s
P
p
.002 w
.64544 .43281 m .65649 .38069 L .63629 .36976 L p
1 g
F P
s
P
p
.002 w
.51323 .27089 m .53907 .29025 L .56247 .28321 L p
1 g
F P
s
P
p
.002 w
.60204 .55511 m .64462 .51285 L .63301 .49751 L p
1 g
F P
s
P
p
.002 w
.66139 .44744 m .63301 .49751 L .64462 .51285 L p
1 g
F P
s
P
p
.002 w
.62953 .32198 m .63629 .36976 L .65649 .38069 L p
1 g
F P
s
P
p
.002 w
.63629 .36976 m .62953 .32198 L .6067 .31741 L p
1 g
F P
s
P
p
.002 w
.35835 .33082 m .34859 .36449 L .3695 .35745 L p
1 g
F P
s
P
p
.002 w
.3695 .35745 m .37709 .33175 L .35835 .33082 L p
1 g
F P
s
P
p
.002 w
.32101 .43025 m .3407 .46948 L .3509 .44767 L p
1 g
F P
s
P
p
.002 w
.3509 .44767 m .33404 .41337 L .32101 .43025 L p
1 g
F P
s
P
p
.002 w
.33097 .37348 m .33404 .41337 L .3509 .39743 L p
1 g
F P
s
P
p
.002 w
.3509 .39743 m .34859 .36449 L .33097 .37348 L p
1 g
F P
s
P
p
.002 w
.37527 .5647 m .4267 .58283 L .42057 .56236 L p
1 g
F P
s
P
p
.002 w
.42057 .56236 m .37125 .54461 L .37527 .5647 L p
1 g
F P
s
P
p
.002 w
.43496 .59997 m .49244 .60091 L .48333 .58401 L p
1 g
F P
s
P
p
.002 w
.48333 .58401 m .4267 .58283 L .43496 .59997 L p
1 g
F P
s
P
p
.002 w
.51323 .27089 m .48043 .26151 L .4701 .27892 L p
1 g
F P
s
P
p
.002 w
.44256 .28058 m .4701 .27892 L .48043 .26151 L p
1 g
F P
s
P
p
.002 w
.58489 .2798 m .6067 .31741 L .62953 .32198 L p
1 g
F P
s
P
p
.002 w
.6067 .31741 m .58489 .2798 L .56247 .28321 L p
1 g
F P
s
P
p
.002 w
.37933 .30042 m .35835 .33082 L .37709 .33175 L p
1 g
F P
s
P
p
.002 w
.37709 .33175 m .39313 .30864 L .37933 .30042 L p
1 g
F P
s
P
p
.002 w
.33223 .5114 m .37125 .54461 L .37064 .52223 L p
1 g
F P
s
P
p
.002 w
.37064 .52223 m .33437 .4909 L .33223 .5114 L p
1 g
F P
s
P
p
.002 w
.53141 .25954 m .56247 .28321 L .58489 .2798 L p
1 g
F P
s
P
p
.002 w
.56247 .28321 m .53141 .25954 L .51323 .27089 L p
1 g
F P
s
P
p
.002 w
.48043 .26151 m .51323 .27089 L .53141 .25954 L p
1 g
F P
s
P
p
.002 w
.48043 .26151 m .44432 .26357 L .44256 .28058 L p
1 g
F P
s
P
p
.002 w
.41585 .29087 m .44256 .28058 L .44432 .26357 L p
1 g
F P
s
P
p
.002 w
.55885 .5984 m .6106 .56839 L .60204 .55511 L p
1 g
F P
s
P
p
.002 w
.60204 .55511 m .5498 .58536 L .55885 .5984 L p
1 g
F P
s
P
p
.002 w
.64462 .51285 m .60204 .55511 L .6106 .56839 L p
1 g
F P
s
P
p
.002 w
.40919 .27704 m .37933 .30042 L .39313 .30864 L p
1 g
F P
s
P
p
.002 w
.39313 .30864 m .41585 .29087 L .40919 .27704 L p
1 g
F P
s
P
p
.002 w
.64462 .51285 m .67364 .46211 L .66139 .44744 L p
1 g
F P
s
P
p
.002 w
.67322 .39327 m .66139 .44744 L .67364 .46211 L p
1 g
F P
s
P
p
.002 w
.66139 .44744 m .67322 .39327 L .65649 .38069 L p
1 g
F P
s
P
p
.002 w
.50208 .61393 m .55885 .5984 L .5498 .58536 L p
1 g
F P
s
P
p
.002 w
.5498 .58536 m .49244 .60091 L .50208 .61393 L p
1 g
F P
s
P
p
.002 w
.44432 .26357 m .40919 .27704 L .41585 .29087 L p
1 g
F P
s
P
p
.002 w
.31232 .44769 m .33437 .4909 L .3407 .46948 L p
1 g
F P
s
P
p
.002 w
.3407 .46948 m .32101 .43025 L .31232 .44769 L p
1 g
F P
s
P
p
.002 w
.64966 .32955 m .65649 .38069 L .67322 .39327 L p
1 g
F P
s
P
p
.002 w
.65649 .38069 m .64966 .32955 L .62953 .32198 L p
1 g
F P
s
P
p
.002 w
.34267 .33249 m .33097 .37348 L .34859 .36449 L p
1 g
F P
s
P
p
.002 w
.34859 .36449 m .35835 .33082 L .34267 .33249 L p
1 g
F P
s
P
p
.002 w
.6106 .56839 m .65286 .52658 L .64462 .51285 L p
1 g
F P
s
P
p
.002 w
.67364 .46211 m .64462 .51285 L .65286 .52658 L p
1 g
F P
s
P
p
.002 w
.31723 .38432 m .32101 .43025 L .33404 .41337 L p
1 g
F P
s
P
p
.002 w
.33404 .41337 m .33097 .37348 L .31723 .38432 L p
1 g
F P
s
P
p
.002 w
.60578 .28027 m .62953 .32198 L .64966 .32955 L p
1 g
F P
s
P
p
.002 w
.62953 .32198 m .60578 .28027 L .58489 .2798 L p
1 g
F P
s
P
p
.002 w
.38279 .58187 m .43496 .59997 L .4267 .58283 L p
1 g
F P
s
P
p
.002 w
.4267 .58283 m .37527 .5647 L .38279 .58187 L p
1 g
F P
s
P
p
.002 w
.53141 .25954 m .49164 .24796 L .48043 .26151 L p
1 g
F P
s
P
p
.002 w
.44432 .26357 m .48043 .26151 L .49164 .24796 L p
1 g
F P
s
P
p
.002 w
.44527 .6132 m .50208 .61393 L .49244 .60091 L p
1 g
F P
s
P
p
.002 w
.49244 .60091 m .43496 .59997 L .44527 .6132 L p
1 g
F P
s
P
p
.002 w
.33455 .53043 m .37527 .5647 L .37125 .54461 L p
1 g
F P
s
P
p
.002 w
.37125 .54461 m .33223 .5114 L .33455 .53043 L p
1 g
F P
s
P
p
.002 w
.54935 .25234 m .58489 .2798 L .60578 .28027 L p
1 g
F P
s
P
p
.002 w
.58489 .2798 m .54935 .25234 L .53141 .25954 L p
1 g
F P
s
P
p
.002 w
.36821 .29535 m .34267 .33249 L .35835 .33082 L p
1 g
F P
s
P
p
.002 w
.35835 .33082 m .37933 .30042 L .36821 .29535 L p
1 g
F P
s
P
p
.002 w
.49164 .24796 m .53141 .25954 L .54935 .25234 L p
1 g
F P
s
P
p
.002 w
.49164 .24796 m .44763 .25034 L .44432 .26357 L p
1 g
F P
s
P
p
.002 w
.40919 .27704 m .44432 .26357 L .44763 .25034 L p
1 g
F P
s
P
p
.002 w
.30842 .4653 m .33223 .5114 L .33437 .4909 L p
1 g
F P
s
P
p
.002 w
.33437 .4909 m .31232 .44769 L .30842 .4653 L p
1 g
F P
s
P
p
.002 w
.65286 .52658 m .68173 .47648 L .67364 .46211 L p
1 g
F P
s
P
p
.002 w
.68591 .40726 m .67364 .46211 L .68173 .47648 L p
1 g
F P
s
P
p
.002 w
.67364 .46211 m .68591 .40726 L .67322 .39327 L p
1 g
F P
s
P
p
.002 w
.56668 .60748 m .61656 .57853 L .6106 .56839 L p
1 g
F P
s
P
p
.002 w
.6106 .56839 m .55885 .5984 L .56668 .60748 L p
1 g
F P
s
P
p
.002 w
.65286 .52658 m .6106 .56839 L .61656 .57853 L p
1 g
F P
s
P
p
.002 w
.66645 .34007 m .67322 .39327 L .68591 .40726 L p
1 g
F P
s
P
p
.002 w
.67322 .39327 m .66645 .34007 L .64966 .32955 L p
1 g
F P
s
P
p
.002 w
.4047 .26676 m .36821 .29535 L .37933 .30042 L p
1 g
F P
s
P
p
.002 w
.37933 .30042 m .40919 .27704 L .4047 .26676 L p
1 g
F P
s
P
p
.002 w
.51204 .62252 m .56668 .60748 L .55885 .5984 L p
1 g
F P
s
P
p
.002 w
.55885 .5984 m .50208 .61393 L .51204 .62252 L p
1 g
F P
s
P
p
.002 w
.44763 .25034 m .4047 .26676 L .40919 .27704 L p
1 g
F P
s
P
p
.002 w
.33063 .33687 m .31723 .38432 L .33097 .37348 L p
1 g
F P
s
P
p
.002 w
.33097 .37348 m .34267 .33249 L .33063 .33687 L p
1 g
F P
s
P
p
.002 w
.30794 .39683 m .31232 .44769 L .32101 .43025 L p
1 g
F P
s
P
p
.002 w
.32101 .43025 m .31723 .38432 L .30794 .39683 L p
1 g
F P
s
P
p
.002 w
.62454 .2848 m .64966 .32955 L .66645 .34007 L p
1 g
F P
s
P
p
.002 w
.64966 .32955 m .62454 .2848 L .60578 .28027 L p
1 g
F P
s
P
p
.002 w
.61656 .57853 m .65733 .53829 L .65286 .52658 L p
1 g
F P
s
P
p
.002 w
.68173 .47648 m .65286 .52658 L .65733 .53829 L p
1 g
F P
s
P
p
.002 w
.3938 .59554 m .44527 .6132 L .43496 .59997 L p
1 g
F P
s
P
p
.002 w
.43496 .59997 m .38279 .58187 L .3938 .59554 L p
1 g
F P
s
P
p
.002 w
.54935 .25234 m .50351 .23879 L .49164 .24796 L p
1 g
F P
s
P
p
.002 w
.44763 .25034 m .49164 .24796 L .50351 .23879 L p
1 g
F P
s
P
p
.002 w
.34151 .54739 m .38279 .58187 L .37527 .5647 L p
1 g
F P
s
P
p
.002 w
.37527 .5647 m .33455 .53043 L .34151 .54739 L p
1 g
F P
s
P
p
.002 w
.45747 .62194 m .51204 .62252 L .50208 .61393 L p
1 g
F P
s
P
p
.002 w
.50208 .61393 m .44527 .6132 L .45747 .62194 L p
1 g
F P
s
P
p
.002 w
.56662 .24969 m .60578 .28027 L .62454 .2848 L p
1 g
F P
s
P
p
.002 w
.60578 .28027 m .56662 .24969 L .54935 .25234 L p
1 g
F P
s
P
p
.002 w
.50351 .23879 m .54935 .25234 L .56662 .24969 L p
1 g
F P
s
P
p
.002 w
.36021 .29374 m .33063 .33687 L .34267 .33249 L p
1 g
F P
s
P
p
.002 w
.34267 .33249 m .36821 .29535 L .36021 .29374 L p
1 g
F P
s
P
p
.002 w
.30967 .4826 m .33455 .53043 L .33223 .5114 L p
1 g
F P
s
P
p
.002 w
.33223 .5114 m .30842 .4653 L .30967 .4826 L p
1 g
F P
s
P
p
.002 w
.68173 .47648 m .69403 .42239 L .68591 .40726 L p
1 g
F P
s
P
p
.002 w
.67931 .35342 m .68591 .40726 L .69403 .42239 L p
1 g
F P
s
P
p
.002 w
.68591 .40726 m .67931 .35342 L .66645 .34007 L p
1 g
F P
s
P
p
.002 w
.65733 .53829 m .68519 .49016 L .68173 .47648 L p
1 g
F P
s
P
p
.002 w
.69403 .42239 m .68173 .47648 L .68519 .49016 L p
1 g
F P
s
P
p
.002 w
.50351 .23879 m .45251 .24146 L .44763 .25034 L p
1 g
F P
s
P
p
.002 w
.4047 .26676 m .44763 .25034 L .45251 .24146 L p
1 g
F P
s
P
p
.002 w
.57303 .6121 m .6196 .58507 L .61656 .57853 L p
1 g
F P
s
P
p
.002 w
.61656 .57853 m .56668 .60748 L .57303 .6121 L p
1 g
F P
s
P
p
.002 w
.65733 .53829 m .61656 .57853 L .6196 .58507 L p
1 g
F P
s
P
p
.002 w
.30361 .41076 m .30842 .4653 L .31232 .44769 L p
1 g
F P
s
P
p
.002 w
.31232 .44769 m .30794 .39683 L .30361 .41076 L p
1 g
F P
s
P
p
.002 w
.32276 .34403 m .30794 .39683 L .31723 .38432 L p
1 g
F P
s
P
p
.002 w
.31723 .38432 m .33063 .33687 L .32276 .34403 L p
1 g
F P
s
P
p
.002 w
.40262 .26051 m .36021 .29374 L .36821 .29535 L p
1 g
F P
s
P
p
.002 w
.36821 .29535 m .4047 .26676 L .40262 .26051 L p
1 g
F P
s
P
p
.002 w
.52208 .62618 m .57303 .6121 L .56668 .60748 L p
1 g
F P
s
P
p
.002 w
.56668 .60748 m .51204 .62252 L .52208 .62618 L p
1 g
F P
s
P
p
.002 w
.64056 .29348 m .66645 .34007 L .67931 .35342 L p
1 g
F P
s
P
p
.002 w
.66645 .34007 m .64056 .29348 L .62454 .2848 L p
1 g
F P
s
P
p
.002 w
.45251 .24146 m .40262 .26051 L .4047 .26676 L p
1 g
F P
s
P
p
.002 w
.6196 .58507 m .65767 .54753 L .65733 .53829 L p
1 g
F P
s
P
p
.002 w
.68519 .49016 m .65733 .53829 L .65767 .54753 L p
1 g
F P
s
P
p
.002 w
.40817 .60511 m .45747 .62194 L .44527 .6132 L p
1 g
F P
s
P
p
.002 w
.44527 .6132 m .3938 .59554 L .40817 .60511 L p
1 g
F P
s
P
p
.002 w
.35316 .5617 m .3938 .59554 L .38279 .58187 L p
1 g
F P
s
P
p
.002 w
.38279 .58187 m .34151 .54739 L .35316 .5617 L p
1 g
F P
s
P
p
.002 w
.5827 .2519 m .62454 .2848 L .64056 .29348 L p
1 g
F P
s
P
p
.002 w
.62454 .2848 m .5827 .2519 L .56662 .24969 L p
1 g
F P
s
P
p
.002 w
.56662 .24969 m .51575 .23452 L .50351 .23879 L p
1 g
F P
s
P
p
.002 w
.45251 .24146 m .50351 .23879 L .51575 .23452 L p
1 g
F P
s
P
p
.002 w
.47135 .62569 m .52208 .62618 L .51204 .62252 L p
1 g
F P
s
P
p
.002 w
.51204 .62252 m .45747 .62194 L .47135 .62569 L p
1 g
F P
s
P
p
.002 w
.51575 .23452 m .56662 .24969 L .5827 .2519 L p
1 g
F P
s
P
p
.002 w
.31634 .49909 m .34151 .54739 L .33455 .53043 L p
1 g
F P
s
P
p
.002 w
.33455 .53043 m .30967 .4826 L .31634 .49909 L p
1 g
F P
s
P
p
.002 w
.35575 .29588 m .32276 .34403 L .33063 .33687 L p
1 g
F P
s
P
p
.002 w
.33063 .33687 m .36021 .29374 L .35575 .29588 L p
1 g
F P
s
P
p
.002 w
.68519 .49016 m .6971 .43833 L .69403 .42239 L p
1 g
F P
s
P
p
.002 w
.68767 .3694 m .69403 .42239 L .6971 .43833 L p
1 g
F P
s
P
p
.002 w
.69403 .42239 m .68767 .3694 L .67931 .35342 L p
1 g
F P
s
P
p
.002 w
.65767 .54753 m .68367 .50274 L .68519 .49016 L p
1 g
F P
s
P
p
.002 w
.6971 .43833 m .68519 .49016 L .68367 .50274 L p
1 g
F P
s
P
p
.002 w
.30466 .42581 m .30967 .4826 L .30842 .4653 L p
1 g
F P
s
P
p
.002 w
.30842 .4653 m .30361 .41076 L .30466 .42581 L p
1 g
F P
s
P
p
.002 w
.51575 .23452 m .45891 .23745 L .45251 .24146 L p
1 g
F P
s
P
p
.002 w
.40262 .26051 m .45251 .24146 L .45891 .23745 L p
1 g
F P
s
P
p
.002 w
.31955 .35393 m .30361 .41076 L .30794 .39683 L p
1 g
F P
s
P
p
.002 w
.30794 .39683 m .32276 .34403 L .31955 .35393 L p
1 g
F P
s
P
p
.002 w
.67931 .35342 m .65326 .3063 L .64056 .29348 L p
1 g
F P
s
P
p
.002 w
.65326 .3063 m .67931 .35342 L .68767 .3694 L p
1 g
F P
s
P
p
.002 w
.57761 .61187 m .61944 .58759 L .6196 .58507 L p
1 g
F P
s
P
p
.002 w
.6196 .58507 m .57303 .6121 L .57761 .61187 L p
1 g
F P
s
P
p
.002 w
.65767 .54753 m .6196 .58507 L .61944 .58759 L p
1 g
F P
s
P
p
.002 w
.40316 .25873 m .35575 .29588 L .36021 .29374 L p
1 g
F P
s
P
p
.002 w
.36021 .29374 m .40262 .26051 L .40316 .25873 L p
1 g
F P
s
P
p
.004 w
.30593 .49984 m
.30919 .49867 L
s
P
p
.004 w
.30387 .50057 m
.30593 .49984 L
s
P
p
.002 w
.53193 .6245 m .57761 .61187 L .57303 .6121 L p
1 g
F P
s
P
p
.002 w
.57303 .6121 m .52208 .62618 L .53193 .6245 L p
1 g
F P
s
P
p
.002 w
.45891 .23745 m .40316 .25873 L .40262 .26051 L p
1 g
F P
s
P
p
.002 w
.4257 .61009 m .47135 .62569 L .45747 .62194 L p
1 g
F P
s
P
p
.002 w
.45747 .62194 m .40817 .60511 L .4257 .61009 L p
1 g
F P
s
P
p
.002 w
.36942 .5728 m .40817 .60511 L .3938 .59554 L p
1 g
F P
s
P
p
.002 w
.3938 .59554 m .35316 .5617 L .36942 .5728 L p
1 g
F P
s
P
p
.002 w
.64056 .29348 m .5971 .25921 L .5827 .2519 L p
1 g
F P
s
P
p
.002 w
.5971 .25921 m .64056 .29348 L .65326 .3063 L p
1 g
F P
s
P
p
.002 w
.61944 .58759 m .65362 .5539 L .65767 .54753 L p
1 g
F P
s
P
p
.002 w
.68367 .50274 m .65767 .54753 L .65362 .5539 L p
1 g
F P
s
P
p
.002 w
.5827 .2519 m .52806 .23556 L .51575 .23452 L p
1 g
F P
s
P
p
.002 w
.45891 .23745 m .51575 .23452 L .52806 .23556 L p
1 g
F P
s
P
p
.002 w
.52806 .23556 m .5827 .2519 L .5971 .25921 L p
1 g
F P
s
P
p
.002 w
.48659 .62404 m .53193 .6245 L .52208 .62618 L p
1 g
F P
s
P
p
.002 w
.52208 .62618 m .47135 .62569 L .48659 .62404 L p
1 g
F P
s
P
p
.002 w
.32852 .51422 m .35316 .5617 L .34151 .54739 L p
1 g
F P
s
P
p
.002 w
.34151 .54739 m .31634 .49909 L .32852 .51422 L p
1 g
F P
s
P
p
.002 w
.35521 .30195 m .31955 .35393 L .32276 .34403 L p
1 g
F P
s
P
p
.002 w
.32276 .34403 m .35575 .29588 L .35521 .30195 L p
1 g
F P
s
P
p
.002 w
.68367 .50274 m .69474 .45466 L .6971 .43833 L p
1 g
F P
s
P
p
.002 w
.6971 .43833 m .69105 .38769 L .68767 .3694 L p
1 g
F P
s
P
p
.002 w
.69105 .38769 m .6971 .43833 L .69474 .45466 L p
1 g
F P
s
P
p
.002 w
.31137 .44158 m .31634 .49909 L .30967 .4826 L p
1 g
F P
s
P
p
.002 w
.30967 .4826 m .30466 .42581 L .31137 .44158 L p
1 g
F P
s
P
p
.002 w
.65362 .5539 m .67689 .5138 L .68367 .50274 L p
1 g
F P
s
P
p
.002 w
.69474 .45466 m .68367 .50274 L .67689 .5138 L p
1 g
F P
s
P
p
.002 w
.66207 .32311 m .68767 .3694 L .69105 .38769 L p
1 g
F P
s
P
p
.002 w
.68767 .3694 m .66207 .32311 L .65326 .3063 L p
1 g
F P
s
P
p
.002 w
.3214 .36644 m .30466 .42581 L .30361 .41076 L p
1 g
F P
s
P
p
.002 w
.30361 .41076 m .31955 .35393 L .3214 .36644 L p
1 g
F P
s
P
p
.002 w
.52806 .23556 m .46675 .23874 L .45891 .23745 L p
1 g
F P
s
P
p
.002 w
.40316 .25873 m .45891 .23745 L .46675 .23874 L p
1 g
F P
s
P
p
.002 w
.58019 .60646 m .61588 .58575 L .61944 .58759 L p
1 g
F P
s
P
p
.002 w
.61944 .58759 m .57761 .61187 L .58019 .60646 L p
1 g
F P
s
P
p
.002 w
.65362 .5539 m .61944 .58759 L .61588 .58575 L p
1 g
F P
s
P
p
.002 w
.40649 .26177 m .35521 .30195 L .35575 .29588 L p
1 g
F P
s
P
p
.002 w
.35575 .29588 m .40316 .25873 L .40649 .26177 L p
1 g
F P
s
P
p
.002 w
.39005 .58015 m .4257 .61009 L .40817 .60511 L p
1 g
F P
s
P
p
.002 w
.40817 .60511 m .36942 .5728 L .39005 .58015 L p
1 g
F P
s
P
p
.002 w
.60927 .27168 m .65326 .3063 L .66207 .32311 L p
1 g
F P
s
P
p
.002 w
.65326 .3063 m .60927 .27168 L .5971 .25921 L p
1 g
F P
s
P
p
.002 w
.54128 .61719 m .58019 .60646 L .57761 .61187 L p
1 g
F P
s
P
p
.002 w
.57761 .61187 m .53193 .6245 L .54128 .61719 L p
1 g
F P
s
P
p
.002 w
.44601 .61007 m .48659 .62404 L .47135 .62569 L p
1 g
F P
s
P
p
.002 w
.47135 .62569 m .4257 .61009 L .44601 .61007 L p
1 g
F P
s
P
p
.002 w
.46675 .23874 m .40649 .26177 L .40316 .25873 L p
1 g
F P
s
P
p
.002 w
.61588 .58575 m .64501 .55702 L .65362 .5539 L p
1 g
F P
s
P
p
.002 w
.67689 .5138 m .65362 .5539 L .64501 .55702 L p
1 g
F P
s
P
p
.002 w
.5971 .25921 m .54007 .24221 L .52806 .23556 L p
1 g
F P
s
P
p
.002 w
.46675 .23874 m .52806 .23556 L .54007 .24221 L p
1 g
F P
s
P
p
.002 w
.34613 .52744 m .36942 .5728 L .35316 .5617 L p
1 g
F P
s
P
p
.002 w
.35316 .5617 m .32852 .51422 L .34613 .52744 L p
1 g
F P
s
P
p
.002 w
.54007 .24221 m .5971 .25921 L .60927 .27168 L p
1 g
F P
s
P
p
.002 w
.50281 .61672 m .54128 .61719 L .53193 .6245 L p
1 g
F P
s
P
p
.002 w
.53193 .6245 m .48659 .62404 L .50281 .61672 L p
1 g
F P
s
P
p
.002 w
.67689 .5138 m .6867 .47092 L .69474 .45466 L p
1 g
F P
s
P
p
.002 w
.68906 .40788 m .69474 .45466 L .6867 .47092 L p
1 g
F P
s
P
p
.002 w
.69474 .45466 m .68906 .40788 L .69105 .38769 L p
1 g
F P
s
P
p
.002 w
.32387 .45761 m .32852 .51422 L .31634 .49909 L p
1 g
F P
s
P
p
.002 w
.31634 .49909 m .31137 .44158 L .32387 .45761 L p
1 g
F P
s
P
p
.002 w
.35885 .31201 m .3214 .36644 L .31955 .35393 L p
1 g
F P
s
P
p
.002 w
.31955 .35393 m .35521 .30195 L .35885 .31201 L p
1 g
F P
s
P
p
.002 w
.66653 .34364 m .69105 .38769 L .68906 .40788 L p
1 g
F P
s
P
p
.002 w
.69105 .38769 m .66653 .34364 L .66207 .32311 L p
1 g
F P
s
P
p
.002 w
.64501 .55702 m .66474 .52291 L .67689 .5138 L p
1 g
F P
s
P
p
.002 w
.6867 .47092 m .67689 .5138 L .66474 .52291 L p
1 g
F P
s
P
p
.002 w
.32856 .38134 m .31137 .44158 L .30466 .42581 L p
1 g
F P
s
P
p
.002 w
.30466 .42581 m .3214 .36644 L .32856 .38134 L p
1 g
F P
s
P
p
.002 w
.54007 .24221 m .4759 .24564 L .46675 .23874 L p
1 g
F P
s
P
p
.002 w
.40649 .26177 m .46675 .23874 L .4759 .24564 L p
1 g
F P
s
P
p
.002 w
.61873 .28924 m .66207 .32311 L .66653 .34364 L p
1 g
F P
s
P
p
.002 w
.66207 .32311 m .61873 .28924 L .60927 .27168 L p
1 g
F P
s
P
p
.002 w
.41458 .58335 m .44601 .61007 L .4257 .61009 L p
1 g
F P
s
P
p
.002 w
.4257 .61009 m .39005 .58015 L .41458 .58335 L p
1 g
F P
s
P
p
.002 w
.46861 .60476 m .50281 .61672 L .48659 .62404 L p
1 g
F P
s
P
p
.002 w
.48659 .62404 m .44601 .61007 L .46861 .60476 L p
1 g
F P
s
P
p
.002 w
.58055 .5957 m .60879 .57932 L .61588 .58575 L p
1 g
F P
s
P
p
.002 w
.61588 .58575 m .58019 .60646 L .58055 .5957 L p
1 g
F P
s
P
p
.002 w
.64501 .55702 m .61588 .58575 L .60879 .57932 L p
1 g
F P
s
P
p
.002 w
.41269 .26986 m .35885 .31201 L .35521 .30195 L p
1 g
F P
s
P
p
.002 w
.35521 .30195 m .40649 .26177 L .41269 .26986 L p
1 g
F P
s
P
p
.002 w
.54981 .60413 m .58055 .5957 L .58019 .60646 L p
1 g
F P
s
P
p
.002 w
.58019 .60646 m .54128 .61719 L .54981 .60413 L p
1 g
F P
s
P
p
.002 w
.36887 .53822 m .39005 .58015 L .36942 .5728 L p
1 g
F P
s
P
p
.002 w
.36942 .5728 m .34613 .52744 L .36887 .53822 L p
1 g
F P
s
P
p
.002 w
.4759 .24564 m .41269 .26986 L .40649 .26177 L p
1 g
F P
s
P
p
.002 w
.55139 .25461 m .60927 .27168 L .61873 .28924 L p
1 g
F P
s
P
p
.002 w
.60927 .27168 m .55139 .25461 L .54007 .24221 L p
1 g
F P
s
P
p
.002 w
.4759 .24564 m .54007 .24221 L .55139 .25461 L p
1 g
F P
s
P
p
.002 w
.60879 .57932 m .6318 .55658 L .64501 .55702 L p
1 g
F P
s
P
p
.002 w
.66474 .52291 m .64501 .55702 L .6318 .55658 L p
1 g
F P
s
P
p
.002 w
.51955 .60365 m .54981 .60413 L .54128 .61719 L p
1 g
F P
s
P
p
.002 w
.54128 .61719 m .50281 .61672 L .51955 .60365 L p
1 g
F P
s
P
p
.002 w
.66474 .52291 m .67292 .48659 L .6867 .47092 L p
1 g
F P
s
P
p
.002 w
.68149 .42942 m .6867 .47092 L .67292 .48659 L p
1 g
F P
s
P
p
.002 w
.6867 .47092 m .68149 .42942 L .68906 .40788 L p
1 g
F P
s
P
p
.002 w
.34205 .47339 m .34613 .52744 L .32852 .51422 L p
1 g
F P
s
P
p
.002 w
.32852 .51422 m .32387 .45761 L .34205 .47339 L p
1 g
F P
s
P
p
.004 w
.30919 .49867 m
.33925 .48794 L
s
P
p
.002 w
.66624 .3674 m .68906 .40788 L .68149 .42942 L p
1 g
F P
s
P
p
.002 w
.68906 .40788 m .66624 .3674 L .66653 .34364 L p
1 g
F P
s
P
p
.002 w
.36682 .326 m .32856 .38134 L .3214 .36644 L p
1 g
F P
s
P
p
.002 w
.3214 .36644 m .35885 .31201 L .36682 .326 L p
1 g
F P
s
P
p
.002 w
.3411 .39826 m .32387 .45761 L .31137 .44158 L p
1 g
F P
s
P
p
.002 w
.31137 .44158 m .32856 .38134 L .3411 .39826 L p
1 g
F P
s
P
p
.002 w
.6318 .55658 m .64729 .52965 L .66474 .52291 L p
1 g
F P
s
P
p
.002 w
.67292 .48659 m .66474 .52291 L .64729 .52965 L p
1 g
F P
s
P
p
.002 w
.62501 .31157 m .66653 .34364 L .66624 .3674 L p
1 g
F P
s
P
p
.002 w
.66653 .34364 m .62501 .31157 L .61873 .28924 L p
1 g
F P
s
P
p
.002 w
.44237 .58207 m .46861 .60476 L .44601 .61007 L p
1 g
F P
s
P
p
.002 w
.44601 .61007 m .41458 .58335 L .44237 .58207 L p
1 g
F P
s
P
p
.002 w
.55139 .25461 m .48612 .25828 L .4759 .24564 L p
1 g
F P
s
P
p
.002 w
.41269 .26986 m .4759 .24564 L .48612 .25828 L p
1 g
F P
s
P
p
.002 w
.49284 .5941 m .51955 .60365 L .50281 .61672 L p
1 g
F P
s
P
p
.002 w
.50281 .61672 m .46861 .60476 L .49284 .5941 L p
1 g
F P
s
P
p
.002 w
.3962 .54607 m .41458 .58335 L .39005 .58015 L p
1 g
F P
s
P
p
.002 w
.39005 .58015 m .36887 .53822 L .3962 .54607 L p
1 g
F P
s
P
p
.002 w
.56161 .27269 m .61873 .28924 L .62501 .31157 L p
1 g
F P
s
P
p
.002 w
.61873 .28924 m .56161 .27269 L .55139 .25461 L p
1 g
F P
s
P
p
.002 w
.57853 .5796 m .59818 .56821 L .60879 .57932 L p
1 g
F P
s
P
p
.002 w
.60879 .57932 m .58055 .5957 L .57853 .5796 L p
1 g
F P
s
P
p
.002 w
.6318 .55658 m .60879 .57932 L .59818 .56821 L p
1 g
F P
s
P
p
.002 w
.42174 .28305 m .36682 .326 L .35885 .31201 L p
1 g
F P
s
P
p
.002 w
.35885 .31201 m .41269 .26986 L .42174 .28305 L p
1 g
F P
s
P
p
.002 w
.55717 .5854 m .57853 .5796 L .58055 .5957 L p
1 g
F P
s
P
p
.002 w
.58055 .5957 m .54981 .60413 L .55717 .5854 L p
1 g
F P
s
P
p
.002 w
.48612 .25828 m .55139 .25461 L .56161 .27269 L p
1 g
F P
s
P
p
.002 w
.48612 .25828 m .42174 .28305 L .41269 .26986 L p
1 g
F P
s
P
p
.002 w
.59818 .56821 m .61416 .55238 L .6318 .55658 L p
1 g
F P
s
P
p
.002 w
.64729 .52965 m .6318 .55658 L .61416 .55238 L p
1 g
F P
s
P
p
.002 w
.36554 .48834 m .36887 .53822 L .34613 .52744 L p
1 g
F P
s
P
p
.002 w
.34613 .52744 m .34205 .47339 L .36554 .48834 L p
1 g
F P
s
P
p
.002 w
.64729 .52965 m .65355 .50114 L .67292 .48659 L p
1 g
F P
s
P
p
.002 w
.66829 .45168 m .67292 .48659 L .65355 .50114 L p
1 g
F P
s
P
p
.002 w
.67292 .48659 m .66829 .45168 L .68149 .42942 L p
1 g
F P
s
P
p
.002 w
.661 .39376 m .68149 .42942 L .66829 .45168 L p
1 g
F P
s
P
p
.002 w
.68149 .42942 m .661 .39376 L .66624 .3674 L p
1 g
F P
s
P
p
.002 w
.53625 .58496 m .55717 .5854 L .54981 .60413 L p
1 g
F P
s
P
p
.002 w
.54981 .60413 m .51955 .60365 L .53625 .58496 L p
1 g
F P
s
P
p
.002 w
.3791 .34367 m .3411 .39826 L .32856 .38134 L p
1 g
F P
s
P
p
.002 w
.32856 .38134 m .36682 .326 L .3791 .34367 L p
1 g
F P
s
P
p
.002 w
.35888 .41672 m .34205 .47339 L .32387 .45761 L p
1 g
F P
s
P
p
.002 w
.32387 .45761 m .3411 .39826 L .35888 .41672 L p
1 g
F P
s
P
p
.002 w
.62773 .33816 m .66624 .3674 L .661 .39376 L p
1 g
F P
s
P
p
.002 w
.66624 .3674 m .62773 .33816 L .62501 .31157 L p
1 g
F P
s
P
p
.002 w
.61416 .55238 m .62481 .53368 L .64729 .52965 L p
1 g
F P
s
P
p
.002 w
.65355 .50114 m .64729 .52965 L .62481 .53368 L p
1 g
F P
s
P
p
.002 w
.49284 .5941 m .46861 .60476 L p
.47255 .57654 L 1 g
F P
s
P
p
.002 w
.47322 .57674 m .49284 .5941 L p
.47255 .57654 L 1 g
F P
s
P
p
.002 w
.46861 .60476 m .44237 .58207 L .47188 .57633 L p
1 g
F P
s
P
p
.48921 .57862 m .46978 .57545 L .47322 .57674 L 1 g
F
P
p
.46978 .57545 m .47188 .57633 L .47322 .57674 L 1 g
F
P
p
.44237 .58207 m .45128 .56765 L .46825 .5748 L 1 g
F
P
p
.002 w
.47188 .57633 m .47073 .57656 L p
.46825 .5748 L 1 g
F P
s
P
p
.002 w
.47073 .57656 m .44237 .58207 L p
.46825 .5748 L 1 g
F P
s
P
p
.002 w
.46825 .5748 m .46872 .57265 L p
.46071 .56945 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46825 .5748 L p
1 g
F P
s
P
p
.002 w
.46825 .5748 m .46817 .57518 L p
.46978 .57545 L 1 g
F P
s
P
p
.48921 .57862 m .46825 .5748 L .46978 .57545 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45099 .56255 L p
1 g
F P
s
P
p
.45128 .56765 m .45338 .56425 L .46825 .5748 L 1 g
F
P
p
.46872 .57265 m .45099 .56255 L .46071 .56945 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44237 .58207 m .42732 .5506 L .44113 .55099 L p
1 g
F P
s
P
p
.002 w
.45099 .56255 m .45146 .56129 L p
.44548 .5561 L 1 g
F P
s
P
p
.44237 .58207 m .44113 .55099 L .45299 .56489 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43849 .54709 L p
1 g
F P
s
P
p
.42732 .5506 m .43594 .54332 L .43849 .54709 L 1 g
F
P
p
.002 w
.44113 .55099 m .43967 .55095 L p
.43849 .54709 L 1 g
F P
s
P
p
.002 w
.43967 .55095 m .42732 .5506 L p
.43849 .54709 L 1 g
F P
s
P
p
.002 w
.43849 .54709 m .43925 .54566 L p
.43621 .53965 L 1 g
F P
s
P
p
.45146 .56129 m .43849 .54709 L .4433 .5542 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43849 .54709 m .46035 .5227 L .44113 .55099 L 1 g
F
P
p
.43594 .54332 m .43705 .54239 L .43849 .54709 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43275 .52837 L p
1 g
F P
s
P
p
.43925 .54566 m .43275 .52837 L .43621 .53965 L 1 g
F
P
p
.43705 .54239 m .46035 .5227 L .43849 .54709 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42732 .5506 m .42569 .51351 L .43333 .51554 L p
1 g
F P
s
P
p
.002 w
.43275 .52837 m .43346 .52734 L p
.43317 .51904 L 1 g
F P
s
P
p
.42732 .5506 m .43333 .51554 L .43193 .54671 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43401 .50926 L p
1 g
F P
s
P
p
.002 w
.43333 .51554 m .43124 .51498 L p
.43397 .50969 L 1 g
F P
s
P
p
.002 w
.43124 .51498 m .42569 .51351 L p
.43376 .50978 L 1 g
F P
s
P
p
.43376 .50978 m .43397 .50969 L .43124 .51498 L 1 g
F
P
p
.002 w
.43401 .50926 m .43485 .50826 L p
.43752 .50201 L 1 g
F P
s
P
p
.43346 .52734 m .43401 .50926 L .43312 .51748 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.42569 .51351 m .43825 .47493 L .44801 .48036 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44279 .49114 L p
1 g
F P
s
P
p
.43485 .50826 m .44279 .49114 L .43752 .50201 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43376 .50978 m .44279 .49114 L .47041 .49283 L 1 g
F
P
p
.002 w
.45177 .48246 m .47041 .49283 L p
.44279 .49114 L 1 g
F P
s
P
p
.42569 .51351 m .44801 .48036 L .43376 .50978 L 1 g
F
P
p
.002 w
.44279 .49114 m .44166 .49233 L p
.43752 .50201 L 1 g
F P
s
P
p
.002 w
.4905 .46548 m .47041 .49283 L .45177 .48246 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45779 .47659 m .4905 .46548 L .45177 .48246 L 1 g
F
P
p
.002 w
.45779 .47659 m .45826 .47608 L p
.46536 .47297 L 1 g
F P
s
P
p
.47522 .46825 m .4905 .46548 L .45779 .47659 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .46711 L p
1 g
F P
s
P
p
.45826 .47608 m .4776 .46711 L .46536 .47297 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.43825 .47493 m .4405 .47183 L p
.4905 .46548 L 1 g
F P
s
P
p
.002 w
.4776 .46711 m .47786 .46667 L p
.49168 .46526 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46713 L p
1 g
F P
s
P
p
.5 .46388 m .52058 .46686 L .53618 .47568 L 1 g
F
P
p
.5 .4634 m .52241 .46713 L .51006 .46534 L 1 g
F
P
p
.002 w
.5348 .47323 m .53618 .47568 L p
.52058 .46686 L 1 g
F P
s
P
p
.51181 .4619 m .52241 .46713 L .52058 .46686 L 1 g
F
P
p
.52241 .46713 m .5348 .47323 L .52058 .46686 L 1 g
F
P
p
.49054 .46546 m .5 .46388 L .53618 .47568 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51006 .46534 L 1 g
F P
s
P
p
.51006 .46534 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.002 w
.52241 .46713 m .52282 .46778 L p
.51006 .46534 L 1 g
F P
s
P
p
.5 .46388 m .51181 .4619 L .52058 .46686 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5424 .4768 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56114 .48546 m .56367 .50105 L p
.56071 .498 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56612 .50942 L p
1 g
F P
s
P
p
.002 w
.56413 .50511 m .56367 .50105 L p
.56593 .50695 L 1 g
F P
s
P
p
.56593 .50695 m .57046 .51875 L .56612 .50942 L 1 g
F
P
p
.56593 .50695 m .56612 .50942 L .56413 .50511 L 1 g
F
P
p
.002 w
.56612 .50942 m .56515 .50826 L p
.56692 .51976 L 1 g
F P
s
P
p
.55661 .4905 m .56612 .50942 L .56413 .50511 L 1 g
F
P
p
.002 w
.56246 .50155 m .56367 .50105 L .56413 .50511 L p
1 g
F P
s
P
p
.56403 .5049 m .56413 .50511 L .56403 .5049 L 1 g
F
P
p
.55661 .4905 m .56413 .50511 L .56403 .5049 L 1 g
F
P
p
.55661 .4905 m .56672 .51013 L .56393 .50451 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54726 L p
1 g
F P
s
P
p
.002 w
.56307 .56134 m .55675 .56117 L p
.56207 .54661 L 1 g
F P
s
P
p
.002 w
.5672 .53258 m .56595 .54129 L p
.56207 .54661 L 1 g
F P
s
P
p
.002 w
.56595 .54129 m .56307 .56134 L p
.56207 .54661 L 1 g
F P
s
P
p
.002 w
.5616 .54726 m .56075 .54566 L p
.55445 .55708 L 1 g
F P
s
P
p
.56654 .52734 m .5616 .54726 L .56434 .53941 L 1 g
F
P
p
.002 w
.55675 .56117 m .55234 .56105 L .55431 .55728 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54932 .56339 L p
1 g
F P
s
P
p
.002 w
.55172 .56081 m .55234 .56105 L p
.5512 .5622 L 1 g
F P
s
P
p
.53879 .5747 m .54932 .56339 L .5512 .5622 L 1 g
F
P
p
.54932 .56339 m .55172 .56081 L .5512 .5622 L 1 g
F
P
p
.002 w
.55234 .56105 m .53625 .58496 L p
.53879 .5747 L 1 g
F P
s
P
p
.002 w
.54932 .56339 m .54854 .56129 L p
.54042 .56903 L 1 g
F P
s
P
p
.56075 .54566 m .54932 .56339 L .55076 .56184 L 1 g
F
P
p
.56075 .54566 m .54966 .56362 L .55445 .55708 L 1 g
F
P
p
.54966 .56362 m .5495 .56388 L .55431 .55728 L 1 g
F
P
p
.54966 .56362 m .55431 .55728 L .55445 .55708 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56644 .53337 m .5672 .53258 L .56575 .53536 L p
1 g
F P
s
P
p
.002 w
.56575 .53536 m .5672 .53258 L p
.55675 .56117 L 1 g
F P
s
P
p
.56654 .52734 m .56432 .53947 L .56644 .53337 L 1 g
F
P
p
.56654 .52734 m .56644 .53337 L .56662 .53284 L 1 g
F
P
p
.56654 .52734 m .56662 .53284 L .56665 .53273 L 1 g
F
P
p
.56654 .52734 m .56665 .53274 L .56667 .53265 L 1 g
F
P
p
.56654 .52734 m .56667 .53266 L .5667 .53257 L 1 g
F
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53249 .5424 m .53246 .53241 L .56669 .53258 L p
1 g
F P
s
P
p
.002 w
.56669 .53258 m .5672 .53258 L .56665 .53274 L p
1 g
F P
s
P
p
.002 w
.56665 .53274 m .53249 .5424 L p
.56669 .53258 L 1 g
F P
s
P
p
.002 w
.56665 .53274 m .5672 .53258 L .56658 .53295 L p
1 g
F P
s
P
p
.56665 .53273 m .56662 .53284 L .56665 .53274 L 1 g
F
P
p
.56667 .53265 m .56665 .53274 L .56667 .53266 L 1 g
F
P
p
.56654 .52734 m .5667 .53259 L .5667 .53258 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56763 .52893 L p
1 g
F P
s
P
p
.002 w
.57046 .51875 m .56774 .53029 L p
.56764 .52907 L 1 g
F P
s
P
p
.56515 .50826 m .56763 .52893 L .56692 .51976 L 1 g
F
P
p
.002 w
.56763 .52893 m .56654 .52734 L p
.56705 .53125 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56705 .53125 m .56413 .50511 L p
.57028 .51838 L 1 g
F P
s
P
p
.57028 .51838 m .57046 .51875 L .56705 .53125 L 1 g
F
P
p
.002 w
.58514 .502 m .56783 .53151 L p
.57463 .50111 L 1 g
F P
s
P
p
.002 w
.56783 .53151 m .5672 .53258 L .56774 .53029 L p
1 g
F P
s
P
p
.002 w
.56774 .53029 m .57492 .49982 L p
.56783 .53151 L 1 g
F P
s
P
p
.002 w
.5672 .53258 m .56705 .53125 L p
.56764 .52907 L 1 g
F P
s
P
p
.002 w
.56774 .53029 m .5672 .53258 L p
.56764 .52907 L 1 g
F P
s
P
p
.002 w
.56674 .53243 m .5672 .53258 L .56669 .53258 L p
1 g
F P
s
P
p
.002 w
.56679 .53225 m .5672 .53258 L .56674 .53243 L p
1 g
F P
s
P
p
.002 w
.56686 .53197 m .5672 .53258 L .56679 .53225 L p
1 g
F P
s
P
p
.002 w
.56658 .53295 m .5672 .53258 L .56644 .53337 L p
1 g
F P
s
P
p
.002 w
.5672 .53258 m .56686 .53197 L p
.56701 .53139 L 1 g
F P
s
P
p
.56654 .52734 m .5667 .53259 L .56705 .53125 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.55251 .48147 m .56114 .48546 L .56082 .49466 L 1 g
F
P
p
.55741 .49135 m .56082 .49466 L .56071 .498 L 1 g
F
P
p
.55251 .48147 m .56082 .49466 L .55741 .49135 L 1 g
F
P
p
.002 w
.55741 .49135 m .55661 .4905 L p
.56393 .50451 L 1 g
F P
s
P
p
.002 w
.53618 .47568 m .53819 .47486 L p
.56071 .498 L 1 g
F P
s
P
p
.56099 .49858 m .56071 .498 L .56367 .50105 L 1 g
F
P
p
.53618 .47568 m .56071 .498 L .56099 .49858 L 1 g
F
P
p
.002 w
.56367 .50105 m .55266 .50558 L .53618 .47568 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55741 .49135 L p
1 g
F P
s
P
p
.56393 .50451 m .56713 .51061 L .55741 .49135 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49135 L p
1 g
F P
s
P
p
.54174 .47608 m .55741 .49135 L .5499 .48408 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.53819 .47486 m .5424 .4768 L .56071 .498 L 1 g
F
P
p
.002 w
.5424 .4768 m .54174 .47608 L p
.5499 .48408 L 1 g
F P
s
P
p
.5424 .4768 m .55251 .48147 L .55741 .49135 L 1 g
F
P
p
.5424 .4768 m .55741 .49135 L .56071 .498 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5424 .4768 L p
1 g
F P
s
P
p
.5499 .48408 m .55834 .49233 L .5424 .4768 L 1 g
F
P
p
.002 w
.55741 .49135 m .55834 .49233 L p
.5499 .48408 L 1 g
F P
s
P
p
.002 w
.56413 .50511 m .56705 .53125 L p
.56246 .50155 L 1 g
F P
s
P
p
.002 w
.56705 .53125 m .5672 .53258 L p
.56701 .53139 L 1 g
F P
s
P
p
.56246 .50155 m .56705 .53125 L .56701 .53139 L 1 g
F
P
p
.5667 .53259 m .56257 .5491 L .56786 .52926 L 1 g
F
P
p
.56432 .53947 m .56281 .54777 L .5667 .53259 L 1 g
F
P
p
.56281 .54777 m .56257 .5491 L .5667 .53259 L 1 g
F
P
p
.002 w
.58421 .55253 m .57407 .55839 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.59243 .54435 m .58421 .55253 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.57407 .55839 m .56307 .56134 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.59786 .53472 m .59243 .54435 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.5999 .52463 m .59786 .53472 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.59832 .51515 m .5999 .52463 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.59323 .50732 m .59832 .51515 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.58514 .502 m .59323 .50732 L .5672 .53258 L closepath p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56786 .52926 L p
.56258 .54905 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56257 .54909 L p
.56258 .54905 L 1 g
F P
s
P
p
.002 w
.56257 .54909 m .56854 .53025 L p
.56258 .54905 L 1 g
F P
s
P
p
.002 w
.57492 .49982 m .57495 .49983 L p
.57463 .50111 L 1 g
F P
s
P
p
.002 w
.57495 .49983 m .58514 .502 L p
.57463 .50111 L 1 g
F P
s
P
p
.002 w
.56763 .52893 m .56764 .52894 L p
.56692 .51976 L 1 g
F P
s
P
p
.002 w
.56764 .52894 m .56854 .53025 L p
.56698 .52014 L 1 g
F P
s
P
p
.56692 .51976 m .56764 .52894 L .56698 .52014 L 1 g
F
P
p
.002 w
.56764 .52894 m .56763 .52893 L p
.56705 .53125 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.53246 .53241 m .53614 .5222 L .56674 .53243 L p
1 g
F P
s
P
p
.002 w
.56669 .53258 m .53246 .53241 L p
.56674 .53243 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53614 .5222 m .54312 .5129 L .56679 .53225 L p
1 g
F P
s
P
p
.002 w
.56674 .53243 m .53614 .5222 L p
.56679 .53225 L 1 g
F P
s
P
p
.5667 .53257 m .56667 .53266 L .5667 .53259 L 1 g
F
P
p
.5667 .53258 m .5667 .53259 L .5667 .53258 L 1 g
F
P
p
.002 w
.54312 .5129 m .55266 .50558 L .56686 .53197 L p
1 g
F P
s
P
p
.002 w
.56679 .53225 m .54312 .5129 L p
.56686 .53197 L 1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.53616 .55107 m .53249 .5424 L .56665 .53274 L p
1 g
F P
s
P
p
.002 w
.56658 .53295 m .53616 .55107 L p
.56665 .53274 L 1 g
F P
s
P
p
.5667 .53258 m .56658 .53295 L .5667 .53259 L 1 g
F
P
p
.56658 .53295 m .56644 .53337 L .56652 .53312 L 1 g
F
P
p
.56658 .53295 m .56652 .53312 L .5667 .53259 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54303 .55751 m .53616 .55107 L .56658 .53295 L p
1 g
F P
s
P
p
.002 w
.56644 .53337 m .54303 .55751 L p
.56658 .53295 L 1 g
F P
s
P
p
.002 w
.55266 .50558 m .56246 .50155 L p
.56701 .53139 L 1 g
F P
s
P
p
.002 w
.56686 .53197 m .55266 .50558 L p
.56701 .53139 L 1 g
F P
s
P
p
.002 w
.56786 .52926 m .56764 .52894 L p
.5667 .53259 L 1 g
F P
s
P
p
.002 w
.54303 .55751 m .56644 .53337 L p
.55431 .55728 L 1 g
F P
s
P
p
.002 w
.56575 .53536 m .55431 .55728 L p
.56644 .53337 L 1 g
F P
s
P
p
.002 w
.55431 .55728 m .55234 .56105 L .55172 .56081 L p
1 g
F P
s
P
p
.002 w
.55172 .56081 m .54303 .55751 L p
.55431 .55728 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57456 L p
1 g
F P
s
P
p
.54854 .56129 m .5317 .57456 L .54042 .56903 L 1 g
F
P
p
.002 w
.54303 .55751 m .55172 .56081 L p
.54932 .56339 L 1 g
F P
s
P
p
.53879 .5747 m .54015 .5692 L .54932 .56339 L 1 g
F
P
p
.54015 .5692 m .54303 .55751 L .54932 .56339 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58076 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58076 L .51196 .58056 L 1 g
F
P
p
.49284 .5941 m .49713 .58343 L .51095 .58076 L 1 g
F
P
p
.002 w
.51526 .57992 m .51386 .58081 L p
.51095 .58076 L 1 g
F P
s
P
p
.002 w
.51386 .58081 m .49284 .5941 L p
.51095 .58076 L 1 g
F P
s
P
p
.002 w
.51095 .58076 m .51079 .57862 L p
.50097 .58058 L 1 g
F P
s
P
p
.53128 .57265 m .51196 .58056 L .51557 .57985 L 1 g
F
P
p
.51196 .58056 m .51096 .58097 L .51526 .57992 L 1 g
F
P
p
.51196 .58056 m .51526 .57992 L .51557 .57985 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58038 L p
1 g
F P
s
P
p
.49713 .58343 m .4983 .58054 L .51095 .58076 L 1 g
F
P
p
.51079 .57862 m .48908 .58038 L .50097 .58058 L 1 g
F
P
p
.48921 .57862 m .47322 .57674 L .47705 .57762 L 1 g
F
P
p
.002 w
.49284 .5941 m .47322 .57674 L p
.49758 .58232 L 1 g
F P
s
P
p
.002 w
.48899 .58162 m .48921 .57862 L p
.47569 .57751 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.47259 .57619 m .50423 .56577 L p
.49758 .58232 L 1 g
F P
s
P
p
.002 w
.47322 .57674 m .47259 .57619 L p
.49758 .58232 L 1 g
F P
s
P
p
.002 w
.48908 .58038 m .48889 .583 L p
.50097 .58058 L 1 g
F P
s
P
p
.51095 .58076 m .50423 .56577 L .51526 .57992 L 1 g
F
P
p
.4983 .58054 m .50423 .56577 L .51095 .58076 L 1 g
F
P
p
.002 w
.51955 .60365 m .49284 .5941 L .51386 .58081 L p
1 g
F P
s
P
p
.002 w
.51386 .58081 m .51526 .57992 L p
.51809 .58057 L 1 g
F P
s
P
p
.51809 .58057 m .51526 .57992 L .51801 .57925 L 1 g
F
P
p
.51955 .60365 m .51386 .58081 L .51809 .58057 L 1 g
F
P
p
.002 w
.53625 .58496 m .51955 .60365 L p
.51801 .57925 L 1 g
F P
s
P
p
.002 w
.51965 .57885 m .53625 .58496 L p
.51801 .57925 L 1 g
F P
s
P
p
.51877 .57907 m .51103 .58192 L .51814 .57939 L 1 g
F
P
p
.53128 .57265 m .51557 .57985 L .51877 .57907 L 1 g
F
P
p
.51557 .57985 m .51103 .58192 L .51877 .57907 L 1 g
F
P
p
.002 w
.51526 .57992 m .51794 .57823 L p
.51801 .57925 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58097 L p
1 g
F P
s
P
p
.002 w
.51096 .58097 m .51095 .58076 L p
.50625 .58123 L 1 g
F P
s
P
p
.50625 .58123 m .48889 .583 L .51096 .58097 L 1 g
F
P
p
.50097 .58058 m .48889 .583 L .51095 .58076 L 1 g
F
P
p
.002 w
.50423 .56577 m .51794 .57823 L .51526 .57992 L p
1 g
F P
s
P
p
.002 w
.51095 .58076 m .51096 .58097 L p
.51196 .58056 L 1 g
F P
s
P
p
.002 w
.51096 .58097 m .51103 .58192 L p
.51557 .57985 L 1 g
F P
s
P
p
.002 w
.53625 .58496 m .51965 .57885 L p
.53951 .57177 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51794 .57823 m .51965 .57885 L p
.51801 .57925 L 1 g
F P
s
P
p
.002 w
.51794 .57823 m .54303 .55751 L p
.53951 .57177 L 1 g
F P
s
P
p
.002 w
.51965 .57885 m .51794 .57823 L p
.53951 .57177 L 1 g
F P
s
P
p
.002 w
.51103 .58192 m .51111 .583 L p
.51814 .57939 L 1 g
F P
s
P
p
.002 w
.5317 .57456 m .5322 .57686 L p
.54042 .56903 L 1 g
F P
s
P
p
.002 w
.55717 .5854 m .53625 .58496 L .55184 .56179 L p
1 g
F P
s
P
p
.002 w
.55184 .56179 m .55234 .56105 L p
.55241 .56141 L 1 g
F P
s
P
p
.55717 .5854 m .55184 .56179 L .55241 .56141 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54935 .56347 L p
1 g
F P
s
P
p
.002 w
.54935 .56347 m .54932 .56339 L p
.54843 .56409 L 1 g
F P
s
P
p
.54843 .56409 m .5322 .57686 L .54935 .56347 L 1 g
F
P
p
.54042 .56903 m .5322 .57686 L .54932 .56339 L 1 g
F
P
p
.002 w
.54932 .56339 m .5495 .56388 L p
.55076 .56184 L 1 g
F P
s
P
p
.002 w
.55431 .55728 m .56575 .53536 L p
.5616 .54726 L 1 g
F P
s
P
p
.55675 .56117 m .55431 .55728 L .5616 .54726 L 1 g
F
P
p
.002 w
.5495 .56388 m .54998 .56518 L p
.55445 .55708 L 1 g
F P
s
P
p
.002 w
.55234 .56105 m .56307 .56134 L .55717 .5854 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5616 .54726 L p
1 g
F P
s
P
p
.55445 .55708 m .54998 .56518 L .5616 .54726 L 1 g
F
P
p
.002 w
.5616 .54726 m .56257 .5491 L p
.56434 .53941 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56612 .50942 L p
1 g
F P
s
P
p
.56692 .51976 m .56854 .53025 L .56612 .50942 L 1 g
F
P
p
.002 w
.56612 .50942 m .56672 .51013 L p
.56403 .5049 L 1 g
F P
s
P
p
.002 w
.56367 .50105 m .57492 .49982 L .57046 .51875 L p
1 g
F P
s
P
p
.002 w
.56672 .51013 m .56713 .51061 L p
.56393 .50451 L 1 g
F P
s
P
p
.002 w
.5424 .4768 m .54268 .47711 L p
.53888 .47518 L 1 g
F P
s
P
p
.52214 .46667 m .5424 .4768 L .53888 .47518 L 1 g
F
P
p
.002 w
.53819 .47486 m .53618 .47568 L .5348 .47323 L p
1 g
F P
s
P
p
.53486 .47326 m .54268 .47711 L .53489 .47327 L 1 g
F
P
p
.52214 .46667 m .53937 .47543 L .53486 .47326 L 1 g
F
P
p
.53937 .47543 m .54268 .47711 L .53486 .47326 L 1 g
F
P
p
.002 w
.5581 .46674 m .53819 .47486 L p
.51836 .44398 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.5348 .47323 m .51836 .44398 L p
.53819 .47486 L 1 g
F P
s
P
p
.002 w
.53819 .47486 m .5581 .46674 L .56114 .48546 L p
1 g
F P
s
P
p
.002 w
.52701 .45937 m .5348 .47323 L p
.51181 .4619 L 1 g
F P
s
P
p
.002 w
.54268 .47711 m .54302 .47747 L p
.53489 .47327 L 1 g
F P
s
P
p
.49168 .46526 m .4905 .46546 L .4776 .46711 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.51836 .44398 m .49054 .46546 L p
.46396 .43951 L 1 g
F P
s
P
p
.002 w
.49054 .46546 m .4905 .46548 L .49048 .46546 L p
1 g
F P
s
P
p
.002 w
.49048 .46546 m .46396 .43951 L p
.49054 .46546 L 1 g
F P
s
P
p
.49054 .46546 m .49351 .46508 L .4905 .46546 L 1 g
F
P
p
.49168 .46526 m .492 .46523 L .49054 .46546 L 1 g
F
P
p
.492 .46523 m .49351 .46508 L .49054 .46546 L 1 g
F
P
p
.002 w
.4905 .46548 m .49054 .46546 L p
.53618 .47568 L 1 g
F P
s
P
p
.002 w
.49054 .46546 m .51836 .44398 L .52701 .45937 L p
1 g
F P
s
P
p
.002 w
.4405 .47183 m .46396 .43951 L .49048 .46546 L p
1 g
F P
s
P
p
.002 w
.49048 .46546 m .4905 .46548 L p
.4405 .47183 L 1 g
F P
s
P
p
.002 w
.47041 .49283 m .4905 .46548 L .51724 .49026 L p
1 g
F P
s
P
p
.002 w
.53618 .47568 m .51724 .49026 L .4905 .46548 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .46711 L p
1 g
F P
s
P
p
.49351 .46508 m .5 .46442 L .4776 .46711 L 1 g
F
P
p
.002 w
.4776 .46711 m .47718 .46778 L p
.46536 .47297 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45779 .47659 L p
1 g
F P
s
P
p
.002 w
.45779 .47659 m .45698 .47747 L p
.45077 .48343 L 1 g
F P
s
P
p
.44339 .4905 m .45779 .47659 L .45077 .48343 L 1 g
F
P
p
.43825 .47493 m .46434 .47021 L .45779 .47659 L 1 g
F
P
p
.002 w
.45177 .48246 m .44889 .48085 L p
.45779 .47659 L 1 g
F P
s
P
p
.002 w
.44889 .48085 m .43825 .47493 L p
.45779 .47659 L 1 g
F P
s
P
p
.46434 .47021 m .47522 .46825 L .45779 .47659 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45779 .47659 L p
1 g
F P
s
P
p
.46536 .47297 m .47718 .46778 L .45779 .47659 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44207 .4919 L p
1 g
F P
s
P
p
.002 w
.44207 .4919 m .44279 .49114 L p
.44835 .48578 L 1 g
F P
s
P
p
.44835 .48578 m .45698 .47747 L .44207 .4919 L 1 g
F
P
p
.002 w
.44279 .49114 m .44339 .4905 L p
.44997 .4842 L 1 g
F P
s
P
p
.44997 .4842 m .45698 .47747 L .44279 .49114 L 1 g
F
P
p
.002 w
.44801 .48036 m .45177 .48246 L p
.44279 .49114 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43401 .50926 L p
1 g
F P
s
P
p
.43752 .50201 m .44166 .49233 L .43401 .50926 L 1 g
F
P
p
.002 w
.43401 .50926 m .43287 .51061 L p
.43312 .51748 L 1 g
F P
s
P
p
.002 w
.47041 .49283 m .46035 .5227 L .43333 .51554 L p
1 g
F P
s
P
p
.43397 .50969 m .47041 .49283 L .43333 .51554 L 1 g
F
P
p
.002 w
.43333 .51554 m .46035 .5227 L p
.43193 .54671 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43275 .52837 L p
1 g
F P
s
P
p
.43317 .51904 m .43287 .51061 L .43275 .52837 L 1 g
F
P
p
.002 w
.43275 .52837 m .43146 .53025 L p
.43621 .53965 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43849 .54709 L p
1 g
F P
s
P
p
.43621 .53965 m .43146 .53025 L .43849 .54709 L 1 g
F
P
p
.002 w
.43849 .54709 m .43743 .5491 L p
.4433 .5542 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.46035 .5227 m .46123 .55155 L .44113 .55099 L p
1 g
F P
s
P
p
.002 w
.44113 .55099 m .46123 .55155 L p
.45299 .56489 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45099 .56255 L p
1 g
F P
s
P
p
.44548 .5561 m .43743 .5491 L .45099 .56255 L 1 g
F
P
p
.002 w
.45099 .56255 m .45002 .56518 L p
.46071 .56945 L 1 g
F P
s
P
p
.46825 .5748 m .46123 .55155 L .47188 .57633 L 1 g
F
P
p
.45338 .56425 m .46123 .55155 L .46825 .5748 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46825 .5748 L p
1 g
F P
s
P
p
.46071 .56945 m .45002 .56518 L .46825 .5748 L 1 g
F
P
p
.002 w
.46123 .55155 m .47259 .57619 L .47188 .57633 L p
1 g
F P
s
P
p
.46978 .57545 m .46817 .57518 L .47188 .57633 L 1 g
F
P
p
.47705 .57762 m .47322 .57674 L .47569 .57751 L 1 g
F
P
p
.002 w
.47188 .57633 m .47259 .57619 L p
.47255 .57654 L 1 g
F P
s
P
p
.46861 .60476 m .47188 .57633 L .47255 .57654 L 1 g
F
P
p
.002 w
.46817 .57518 m .4678 .57686 L p
.47569 .57751 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58162 L p
1 g
F P
s
P
p
.47569 .57751 m .4678 .57686 L .48899 .58162 L 1 g
F
P
p
.002 w
.47259 .57619 m .47322 .57674 L p
.47255 .57654 L 1 g
F P
s
P
p
.002 w
.42732 .5506 m .44237 .58207 L .41458 .58335 L p
1 g
F P
s
P
p
.002 w
.41458 .58335 m .3962 .54607 L .42732 .5506 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.56161 .27269 m .49715 .27657 L .48612 .25828 L p
1 g
F P
s
P
p
.002 w
.42174 .28305 m .48612 .25828 L .49715 .27657 L p
1 g
F P
s
P
p
.002 w
.57033 .29612 m .62501 .31157 L .62773 .33816 L p
1 g
F P
s
P
p
.002 w
.62501 .31157 m .57033 .29612 L .56161 .27269 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50832 .44315 L
s
P
p
.004 w
.5319 .47897 m
.55051 .50723 L
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.39372 .5019 m .3962 .54607 L .36887 .53822 L p
1 g
F P
s
P
p
.002 w
.36887 .53822 m .36554 .48834 L .39372 .5019 L p
1 g
F P
s
P
p
.002 w
.65355 .50114 m .64969 .47391 L .66829 .45168 L p
1 g
F P
s
P
p
.002 w
.65077 .42192 m .66829 .45168 L .64969 .47391 L p
1 g
F P
s
P
p
.002 w
.66829 .45168 m .65077 .42192 L .661 .39376 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49715 .27657 m .56161 .27269 L .57033 .29612 L p
1 g
F P
s
P
p
.002 w
.43349 .3012 m .3791 .34367 L .36682 .326 L p
1 g
F P
s
P
p
.002 w
.36682 .326 m .42174 .28305 L .43349 .3012 L p
1 g
F P
s
P
p
.002 w
.57407 .55839 m .58421 .55253 L .59818 .56821 L p
1 g
F P
s
P
p
.002 w
.59818 .56821 m .57853 .5796 L .57407 .55839 L p
1 g
F P
s
P
p
.004 w
.59516 .57506 m
.60738 .59363 L
s
P
p
.002 w
.61416 .55238 m .59818 .56821 L .58421 .55253 L p
1 g
F P
s
P
p
.002 w
.62481 .53368 m .62899 .51399 L .65355 .50114 L p
1 g
F P
s
P
p
.002 w
.64969 .47391 m .65355 .50114 L .62899 .51399 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.56307 .56134 m .57407 .55839 L .57853 .5796 L p
1 g
F P
s
P
p
.002 w
.57853 .5796 m .55717 .5854 L .56307 .56134 L p
1 g
F P
s
P
p
.002 w
.58421 .55253 m .59243 .54435 L .61416 .55238 L p
1 g
F P
s
P
p
.002 w
.62481 .53368 m .61416 .55238 L .59243 .54435 L p
1 g
F P
s
P
p
.002 w
.49715 .27657 m .43349 .3012 L .42174 .28305 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.62666 .36825 m .661 .39376 L .65077 .42192 L p
1 g
F P
s
P
p
.002 w
.661 .39376 m .62666 .36825 L .62773 .33816 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.38148 .43613 m .36554 .48834 L .34205 .47339 L p
1 g
F P
s
P
p
.004 w
.47278 .44023 m
.5 .43051 L
s
P
p
.002 w
.34205 .47339 m .35888 .41672 L .38148 .43613 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.39549 .36457 m .35888 .41672 L .3411 .39826 L p
1 g
F P
s
P
p
.002 w
.3411 .39826 m .3791 .34367 L .39549 .36457 L p
1 g
F P
s
P
p
.002 w
.59243 .54435 m .59786 .53472 L .62481 .53368 L p
1 g
F P
s
P
p
.002 w
.62899 .51399 m .62481 .53368 L .59786 .53472 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.57715 .32432 m .62773 .33816 L .62666 .36825 L p
1 g
F P
s
P
p
.002 w
.62773 .33816 m .57715 .32432 L .57033 .29612 L p
1 g
F P
s
P
p
.002 w
.62899 .51399 m .62613 .49534 L .64969 .47391 L p
1 g
F P
s
P
p
.002 w
.63575 .45093 m .64969 .47391 L .62613 .49534 L p
1 g
F P
s
P
p
.002 w
.64969 .47391 m .63575 .45093 L .65077 .42192 L p
1 g
F P
s
P
p
.002 w
.42569 .51351 m .42732 .5506 L .3962 .54607 L p
1 g
F P
s
P
p
.002 w
.3962 .54607 m .39372 .5019 L .42569 .51351 L p
1 g
F P
s
P
p
.002 w
.57033 .29612 m .50863 .30015 L .49715 .27657 L p
1 g
F P
s
P
p
.002 w
.43349 .3012 m .49715 .27657 L .50863 .30015 L p
1 g
F P
s
P
p
.002 w
.59786 .53472 m .5999 .52463 L .62899 .51399 L p
1 g
F P
s
P
p
.002 w
.62613 .49534 m .62899 .51399 L .5999 .52463 L p
1 g
F P
s
P
p
.002 w
.50863 .30015 m .57033 .29612 L .57715 .32432 L p
1 g
F P
s
P
p
.002 w
.62169 .40088 m .65077 .42192 L .63575 .45093 L p
1 g
F P
s
P
p
.002 w
.65077 .42192 m .62169 .40088 L .62666 .36825 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44767 .3239 m .39549 .36457 L .3791 .34367 L p
1 g
F P
s
P
p
.002 w
.3791 .34367 m .43349 .3012 L .44767 .3239 L p
1 g
F P
s
P
p
.002 w
.53616 .55107 m .54303 .55751 L .51794 .57823 L p
1 g
F P
s
P
p
.002 w
.51794 .57823 m .50423 .56577 L .53616 .55107 L p
1 g
F P
s
P
p
.002 w
.49672 .5488 m .50423 .56577 L .47259 .57619 L p
1 g
F P
s
P
p
.002 w
.47259 .57619 m .46123 .55155 L .49672 .5488 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.40824 .45578 m .39372 .5019 L .36554 .48834 L p
1 g
F P
s
P
p
.004 w
.40558 .46424 m
.46016 .44474 L
s
P
p
.002 w
.36554 .48834 m .38148 .43613 L .40824 .45578 L p
1 g
F P
s
P
p
.004 w
.33925 .48794 m
.36793 .47769 L
s
P
p
.004 w
.36793 .47769 m
.37747 .47428 L
s
P
p
.004 w
.37747 .47428 m
.37845 .47393 L
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.50863 .30015 m .44767 .3239 L .43349 .3012 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.5999 .52463 m .59832 .51515 L .62613 .49534 L p
1 g
F P
s
P
p
.002 w
.61636 .47975 m .62613 .49534 L .59832 .51515 L p
1 g
F P
s
P
p
.002 w
.62613 .49534 m .61636 .47975 L .63575 .45093 L p
1 g
F P
s
P
p
.002 w
.41556 .38807 m .38148 .43613 L .35888 .41672 L p
1 g
F P
s
P
p
.002 w
.35888 .41672 m .39549 .36457 L .41556 .38807 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.58175 .35644 m .62666 .36825 L .62169 .40088 L p
1 g
F P
s
P
p
.002 w
.62666 .36825 m .58175 .35644 L .57715 .32432 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.61291 .43488 m .63575 .45093 L .61636 .47975 L p
1 g
F P
s
P
p
.002 w
.63575 .45093 m .61291 .43488 L .62169 .40088 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.53249 .5424 m .53616 .55107 L .50423 .56577 L p
1 g
F P
s
P
p
.002 w
.50423 .56577 m .49672 .5488 L .53249 .5424 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.52015 .3284 m .57715 .32432 L .58175 .35644 L p
1 g
F P
s
P
p
.002 w
.57715 .32432 m .52015 .3284 L .50863 .30015 L p
1 g
F P
s
P
p
.002 w
.44767 .3239 m .50863 .30015 L .52015 .3284 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59832 .51515 m .59323 .50732 L .61636 .47975 L p
1 g
F P
s
P
p
.002 w
.43825 .47493 m .42569 .51351 L .39372 .5019 L p
1 g
F P
s
P
p
.002 w
.39372 .5019 m .40824 .45578 L .43825 .47493 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.49639 .52908 m .49672 .5488 L .46123 .55155 L p
1 g
F P
s
P
p
.002 w
.46123 .55155 m .46035 .5227 L .49639 .52908 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.60058 .46902 m .61636 .47975 L .59323 .50732 L p
1 g
F P
s
P
p
.002 w
.61636 .47975 m .60058 .46902 L .61291 .43488 L p
1 g
F P
s
P
p
.002 w
.58389 .39138 m .62169 .40088 L .61291 .43488 L p
1 g
F P
s
P
p
.002 w
.62169 .40088 m .58389 .39138 L .58175 .35644 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.46384 .35051 m .41556 .38807 L .39549 .36457 L p
1 g
F P
s
P
p
.002 w
.39549 .36457 m .44767 .3239 L .46384 .35051 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59323 .50732 m .58514 .502 L .60058 .46902 L p
1 g
F P
s
P
p
.002 w
.52015 .3284 m .46384 .35051 L .44767 .3239 L p
1 g
F P
s
P
p
.002 w
.43865 .41337 m .40824 .45578 L .38148 .43613 L p
1 g
F P
s
P
p
.002 w
.38148 .43613 m .41556 .38807 L .43865 .41337 L p
1 g
F P
s
P
p
.002 w
.53246 .53241 m .53249 .5424 L .49672 .5488 L p
1 g
F P
s
P
p
.002 w
.49672 .5488 m .49639 .52908 L .53246 .53241 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.58345 .42785 m .61291 .43488 L .60058 .46902 L p
1 g
F P
s
P
p
.002 w
.61291 .43488 m .58345 .42785 L .58389 .39138 L p
1 g
F P
s
P
p
.002 w
.58514 .502 m .57492 .49982 L .58042 .46447 L p
1 g
F P
s
P
p
.002 w
.58042 .46447 m .60058 .46902 L .58514 .502 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.53129 .36041 m .58175 .35644 L .58389 .39138 L p
1 g
F P
s
P
p
.002 w
.58175 .35644 m .53129 .36041 L .52015 .3284 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.60058 .46902 m .58042 .46447 L .58345 .42785 L p
1 g
F P
s
P
p
.002 w
.53614 .5222 m .53246 .53241 L .49639 .52908 L p
1 g
F P
s
P
p
.002 w
.46384 .35051 m .52015 .3284 L .53129 .36041 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57492 .49982 m .56367 .50105 L .5581 .46674 L p
1 g
F P
s
P
p
.002 w
.5581 .46674 m .58042 .46447 L .57492 .49982 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50346 .50879 m .49639 .52908 L .46035 .5227 L p
1 g
F P
s
P
p
.002 w
.46035 .5227 m .47041 .49283 L .50346 .50879 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49639 .52908 m .50346 .50879 L .53614 .5222 L p
1 g
F P
s
P
p
.002 w
.54312 .5129 m .53614 .5222 L .50346 .50879 L p
1 g
F P
s
P
p
.002 w
.46396 .43951 m .43825 .47493 L .40824 .45578 L p
1 g
F P
s
P
p
.002 w
.40824 .45578 m .43865 .41337 L .46396 .43951 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.48147 .38015 m .43865 .41337 L .41556 .38807 L p
1 g
F P
s
P
p
.002 w
.41556 .38807 m .46384 .35051 L .48147 .38015 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.55266 .50558 m .54312 .5129 L .51724 .49026 L p
1 g
F P
s
P
p
.002 w
.50346 .50879 m .51724 .49026 L .54312 .5129 L p
1 g
F P
s
P
p
.002 w
.54159 .39503 m .58389 .39138 L .58345 .42785 L p
1 g
F P
s
P
p
.002 w
.58389 .39138 m .54159 .39503 L .53129 .36041 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.51724 .49026 m .53618 .47568 L .55266 .50558 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53129 .36041 m .48147 .38015 L .46384 .35051 L p
1 g
F P
s
P
p
.002 w
.58042 .46447 m .5581 .46674 L .55064 .43094 L p
1 g
F P
s
P
p
.002 w
.55064 .43094 m .58345 .42785 L .58042 .46447 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.58345 .42785 m .55064 .43094 L .54159 .39503 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51724 .49026 m .50346 .50879 L .47041 .49283 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.48147 .38015 m .53129 .36041 L .54159 .39503 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.51836 .44398 m .55064 .43094 L .5581 .46674 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.49988 .41171 m .46396 .43951 L .43865 .41337 L p
1 g
F P
s
P
p
.002 w
.43865 .41337 m .48147 .38015 L .49988 .41171 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.49988 .41171 m .54159 .39503 L .55064 .43094 L p
1 g
F P
s
P
p
.002 w
.54159 .39503 m .49988 .41171 L .48147 .38015 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.55064 .43094 m .51836 .44398 L .49988 .41171 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.46396 .43951 m .49988 .41171 L .51836 .44398 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.59018 .5675 m
.59516 .57506 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .30387 .50057 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60738 .59363 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.195349)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.195349)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48256 .45828 m .52201 .44405 L .5091 .41857 L p
1 g
F P
s
P
p
.002 w
.5091 .41857 m .47619 .43042 L .48256 .45828 L p
1 g
F P
s
P
p
.002 w
.53763 .399 m .5091 .41857 L .52201 .44405 L p
1 g
F P
s
P
p
.002 w
.47619 .43042 m .5091 .41857 L .49595 .39335 L p
1 g
F P
s
P
p
.002 w
.5091 .41857 m .53763 .399 L .51805 .37808 L p
1 g
F P
s
P
p
.002 w
.51805 .37808 m .49595 .39335 L .5091 .41857 L p
1 g
F P
s
P
p
.002 w
.44154 .46207 m .48256 .45828 L .47619 .43042 L p
1 g
F P
s
P
p
.002 w
.47619 .43042 m .44198 .43342 L .44154 .46207 L p
1 g
F P
s
P
p
.002 w
.44198 .43342 m .47619 .43042 L .47038 .40254 L p
1 g
F P
s
P
p
.002 w
.49595 .39335 m .47038 .40254 L .47619 .43042 L p
1 g
F P
s
P
p
.002 w
.48938 .48561 m .53445 .46933 L .52201 .44405 L p
1 g
F P
s
P
p
.002 w
.52201 .44405 m .48256 .45828 L .48938 .48561 L p
1 g
F P
s
P
p
.002 w
.55631 .4207 m .52201 .44405 L .53445 .46933 L p
1 g
F P
s
P
p
.002 w
.52201 .44405 m .55631 .4207 L .53763 .399 L p
1 g
F P
s
P
p
.002 w
.44253 .49015 m .48938 .48561 L .48256 .45828 L p
1 g
F P
s
P
p
.002 w
.48256 .45828 m .44154 .46207 L .44253 .49015 L p
1 g
F P
s
P
p
.002 w
.47038 .40254 m .49595 .39335 L .4828 .36883 L p
1 g
F P
s
P
p
.002 w
.49595 .39335 m .51805 .37808 L .49791 .35831 L p
1 g
F P
s
P
p
.002 w
.49791 .35831 m .4828 .36883 L .49595 .39335 L p
1 g
F P
s
P
p
.002 w
.47038 .40254 m .44383 .40474 L .44198 .43342 L p
1 g
F P
s
P
p
.002 w
.44383 .40474 m .47038 .40254 L .46526 .37512 L p
1 g
F P
s
P
p
.002 w
.4828 .36883 m .46526 .37512 L .47038 .40254 L p
1 g
F P
s
P
p
.002 w
.55901 .37347 m .53763 .399 L .55631 .4207 L p
1 g
F P
s
P
p
.002 w
.53763 .399 m .55901 .37347 L .53447 .35816 L p
1 g
F P
s
P
p
.002 w
.53447 .35816 m .51805 .37808 L .53763 .399 L p
1 g
F P
s
P
p
.002 w
.49655 .5119 m .54619 .49394 L .53445 .46933 L p
1 g
F P
s
P
p
.002 w
.53445 .46933 m .48938 .48561 L .49655 .5119 L p
1 g
F P
s
P
p
.002 w
.57374 .44278 m .53445 .46933 L .54619 .49394 L p
1 g
F P
s
P
p
.002 w
.53445 .46933 m .57374 .44278 L .55631 .4207 L p
1 g
F P
s
P
p
.002 w
.51805 .37808 m .53447 .35816 L .50904 .3446 L p
1 g
F P
s
P
p
.002 w
.50904 .3446 m .49791 .35831 L .51805 .37808 L p
1 g
F P
s
P
p
.002 w
.44495 .51713 m .49655 .5119 L .48938 .48561 L p
1 g
F P
s
P
p
.002 w
.48938 .48561 m .44253 .49015 L .44495 .51713 L p
1 g
F P
s
P
p
.002 w
.58222 .39025 m .55631 .4207 L .57374 .44278 L p
1 g
F P
s
P
p
.002 w
.55631 .4207 m .58222 .39025 L .55901 .37347 L p
1 g
F P
s
P
p
.002 w
.40276 .45485 m .44154 .46207 L .44198 .43342 L p
1 g
F P
s
P
p
.002 w
.44198 .43342 m .40975 .42713 L .40276 .45485 L p
1 g
F P
s
P
p
.002 w
.40975 .42713 m .44198 .43342 L .44383 .40474 L p
1 g
F P
s
P
p
.002 w
.44383 .40474 m .4189 .39965 L .40975 .42713 L p
1 g
F P
s
P
p
.002 w
.4189 .39965 m .44383 .40474 L .44706 .37655 L p
1 g
F P
s
P
p
.002 w
.46526 .37512 m .44706 .37655 L .44383 .40474 L p
1 g
F P
s
P
p
.002 w
.46526 .37512 m .4828 .36883 L .46988 .34548 L p
1 g
F P
s
P
p
.002 w
.4828 .36883 m .49791 .35831 L .47758 .34008 L p
1 g
F P
s
P
p
.002 w
.47758 .34008 m .46988 .34548 L .4828 .36883 L p
1 g
F P
s
P
p
.002 w
.44706 .37655 m .46526 .37512 L .46092 .34869 L p
1 g
F P
s
P
p
.002 w
.46988 .34548 m .46092 .34869 L .46526 .37512 L p
1 g
F P
s
P
p
.002 w
.39811 .48227 m .44253 .49015 L .44154 .46207 L p
1 g
F P
s
P
p
.002 w
.44154 .46207 m .40276 .45485 L .39811 .48227 L p
1 g
F P
s
P
p
.002 w
.49791 .35831 m .50904 .3446 L .48321 .33305 L p
1 g
F P
s
P
p
.002 w
.48321 .33305 m .47758 .34008 L .49791 .35831 L p
1 g
F P
s
P
p
.002 w
.54619 .49394 m .58958 .46483 L .57374 .44278 L p
1 g
F P
s
P
p
.002 w
.60362 .40818 m .57374 .44278 L .58958 .46483 L p
1 g
F P
s
P
p
.002 w
.57374 .44278 m .60362 .40818 L .58222 .39025 L p
1 g
F P
s
P
p
.002 w
.44706 .37655 m .43004 .37292 L .4189 .39965 L p
1 g
F P
s
P
p
.002 w
.43004 .37292 m .44706 .37655 L .45162 .34938 L p
1 g
F P
s
P
p
.002 w
.46092 .34869 m .45162 .34938 L .44706 .37655 L p
1 g
F P
s
P
p
.002 w
.50392 .53664 m .55699 .51741 L .54619 .49394 L p
1 g
F P
s
P
p
.002 w
.54619 .49394 m .49655 .5119 L .50392 .53664 L p
1 g
F P
s
P
p
.002 w
.58958 .46483 m .54619 .49394 L .55699 .51741 L p
1 g
F P
s
P
p
.002 w
.54346 .33551 m .53447 .35816 L .55901 .37347 L p
1 g
F P
s
P
p
.002 w
.53447 .35816 m .54346 .33551 L .515 .32907 L p
1 g
F P
s
P
p
.002 w
.515 .32907 m .50904 .3446 L .53447 .35816 L p
1 g
F P
s
P
p
.002 w
.44878 .54246 m .50392 .53664 L .49655 .5119 L p
1 g
F P
s
P
p
.002 w
.49655 .5119 m .44495 .51713 L .44878 .54246 L p
1 g
F P
s
P
p
.002 w
.57097 .34433 m .55901 .37347 L .58222 .39025 L p
1 g
F P
s
P
p
.002 w
.55901 .37347 m .57097 .34433 L .54346 .33551 L p
1 g
F P
s
P
p
.002 w
.39594 .50883 m .44495 .51713 L .44253 .49015 L p
1 g
F P
s
P
p
.002 w
.44253 .49015 m .39811 .48227 L .39594 .50883 L p
1 g
F P
s
P
p
.002 w
.50904 .3446 m .515 .32907 L .48614 .32513 L p
1 g
F P
s
P
p
.002 w
.48614 .32513 m .48321 .33305 L .50904 .3446 L p
1 g
F P
s
P
p
.002 w
.38271 .41191 m .40975 .42713 L .4189 .39965 L p
1 g
F P
s
P
p
.002 w
.4189 .39965 m .39814 .38762 L .38271 .41191 L p
1 g
F P
s
P
p
.002 w
.39814 .38762 m .4189 .39965 L .43004 .37292 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .46092 .34869 L .46988 .34548 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .46988 .34548 L .47758 .34008 L closepath p
1 g
F P
s
P
p
.002 w
.37005 .43694 m .40276 .45485 L .40975 .42713 L p
1 g
F P
s
P
p
.002 w
.40975 .42713 m .38271 .41191 L .37005 .43694 L p
1 g
F P
s
P
p
.002 w
.43004 .37292 m .41598 .36454 L .39814 .38762 L p
1 g
F P
s
P
p
.002 w
.41598 .36454 m .43004 .37292 L .44297 .34746 L p
1 g
F P
s
P
p
.002 w
.45162 .34938 m .44297 .34746 L .43004 .37292 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .45162 .34938 L .46092 .34869 L closepath p
1 g
F P
s
P
p
.002 w
.59697 .35538 m .58222 .39025 L .60362 .40818 L p
1 g
F P
s
P
p
.002 w
.58222 .39025 m .59697 .35538 L .57097 .34433 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .47758 .34008 L .48321 .33305 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .44297 .34746 L .45162 .34938 L closepath p
1 g
F P
s
P
p
.002 w
.55699 .51741 m .60348 .48644 L .58958 .46483 L p
1 g
F P
s
P
p
.002 w
.62277 .42694 m .58958 .46483 L .60348 .48644 L p
1 g
F P
s
P
p
.002 w
.58958 .46483 m .62277 .42694 L .60362 .40818 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .48321 .33305 L .48614 .32513 L closepath p
1 g
F P
s
P
p
.002 w
.36046 .46221 m .39811 .48227 L .40276 .45485 L p
1 g
F P
s
P
p
.002 w
.40276 .45485 m .37005 .43694 L .36046 .46221 L p
1 g
F P
s
P
p
.002 w
.44297 .34746 m .43588 .34312 L .41598 .36454 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .43588 .34312 L .44297 .34746 L closepath p
1 g
F P
s
P
p
.002 w
.51506 .31331 m .515 .32907 L .54346 .33551 L p
1 g
F P
s
P
p
.002 w
.515 .32907 m .51506 .31331 L .48606 .31714 L p
1 g
F P
s
P
p
.002 w
.48606 .31714 m .48614 .32513 L .515 .32907 L p
1 g
F P
s
P
p
.002 w
.39635 .53399 m .44878 .54246 L .44495 .51713 L p
1 g
F P
s
P
p
.002 w
.44495 .51713 m .39594 .50883 L .39635 .53399 L p
1 g
F P
s
P
p
.002 w
.51137 .5593 m .56662 .53925 L .55699 .51741 L p
1 g
F P
s
P
p
.002 w
.55699 .51741 m .50392 .53664 L .51137 .5593 L p
1 g
F P
s
P
p
.002 w
.60348 .48644 m .55699 .51741 L .56662 .53925 L p
1 g
F P
s
P
p
.002 w
.54387 .31238 m .54346 .33551 L .57097 .34433 L p
1 g
F P
s
P
p
.002 w
.54346 .33551 m .54387 .31238 L .51506 .31331 L p
1 g
F P
s
P
p
.002 w
.62093 .36848 m .60362 .40818 L .62277 .42694 L p
1 g
F P
s
P
p
.002 w
.60362 .40818 m .62093 .36848 L .59697 .35538 L p
1 g
F P
s
P
p
.002 w
.45399 .56558 m .51137 .5593 L .50392 .53664 L p
1 g
F P
s
P
p
.002 w
.50392 .53664 m .44878 .54246 L .45399 .56558 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .48614 .32513 L .48606 .31714 L closepath p
1 g
F P
s
P
p
.002 w
.38384 .36969 m .39814 .38762 L .41598 .36454 L p
1 g
F P
s
P
p
.002 w
.41598 .36454 m .40643 .35219 L .38384 .36969 L p
1 g
F P
s
P
p
.002 w
.40643 .35219 m .41598 .36454 L .43588 .34312 L p
1 g
F P
s
P
p
.002 w
.43588 .34312 m .43114 .33679 L .40643 .35219 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .43114 .33679 L .43588 .34312 L closepath p
1 g
F P
s
P
p
.002 w
.36387 .38896 m .38271 .41191 L .39814 .38762 L p
1 g
F P
s
P
p
.002 w
.39814 .38762 m .38384 .36969 L .36387 .38896 L p
1 g
F P
s
P
p
.002 w
.57192 .3144 m .57097 .34433 L .59697 .35538 L p
1 g
F P
s
P
p
.002 w
.57097 .34433 m .57192 .3144 L .54387 .31238 L p
1 g
F P
s
P
p
.002 w
.48292 .30995 m .48606 .31714 L .51506 .31331 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .48606 .31714 L .48292 .30995 L closepath p
1 g
F P
s
P
p
.002 w
.35423 .48719 m .39594 .50883 L .39811 .48227 L p
1 g
F P
s
P
p
.002 w
.39811 .48227 m .36046 .46221 L .35423 .48719 L p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .43053 .32098 L .42927 .32914 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .42927 .32914 L .43114 .33679 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .48292 .30995 L .47704 .30435 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .47704 .30435 L .46903 .30099 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .46903 .30099 L .45976 .30025 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .45976 .30025 L .45027 .30223 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .45027 .30223 L .44163 .30673 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .44163 .30673 L .4348 .31322 L closepath p
1 g
F P
s
P
p
.002 w
.45746 .32377 m .4348 .31322 L .43053 .32098 L closepath p
1 g
F P
s
P
p
.002 w
.40251 .33711 m .40643 .35219 L .43114 .33679 L p
1 g
F P
s
P
p
.002 w
.43114 .33679 m .42927 .32914 L .40251 .33711 L p
1 g
F P
s
P
p
.002 w
.56662 .53925 m .61511 .50715 L .60348 .48644 L p
1 g
F P
s
P
p
.002 w
.63922 .44618 m .60348 .48644 L .61511 .50715 L p
1 g
F P
s
P
p
.002 w
.60348 .48644 m .63922 .44618 L .62277 .42694 L p
1 g
F P
s
P
p
.002 w
.50907 .29901 m .51506 .31331 L .54387 .31238 L p
1 g
F P
s
P
p
.002 w
.51506 .31331 m .50907 .29901 L .48292 .30995 L p
1 g
F P
s
P
p
.002 w
.34701 .40965 m .37005 .43694 L .38271 .41191 L p
1 g
F P
s
P
p
.002 w
.38271 .41191 m .36387 .38896 L .34701 .40965 L p
1 g
F P
s
P
p
.002 w
.47704 .30435 m .48292 .30995 L .50907 .29901 L p
1 g
F P
s
P
p
.002 w
.37777 .34759 m .38384 .36969 L .40643 .35219 L p
1 g
F P
s
P
p
.002 w
.40643 .35219 m .40251 .33711 L .37777 .34759 L p
1 g
F P
s
P
p
.002 w
.59861 .3194 m .59697 .35538 L .62093 .36848 L p
1 g
F P
s
P
p
.002 w
.59697 .35538 m .59861 .3194 L .57192 .3144 L p
1 g
F P
s
P
p
.002 w
.64228 .38341 m .62277 .42694 L .63922 .44618 L p
1 g
F P
s
P
p
.002 w
.62277 .42694 m .64228 .38341 L .62093 .36848 L p
1 g
F P
s
P
p
.002 w
.39943 .55714 m .45399 .56558 L .44878 .54246 L p
1 g
F P
s
P
p
.002 w
.44878 .54246 m .39635 .53399 L .39943 .55714 L p
1 g
F P
s
P
p
.002 w
.40481 .3209 m .40251 .33711 L .42927 .32914 L p
1 g
F P
s
P
p
.002 w
.42927 .32914 m .43053 .32098 L .40481 .3209 L p
1 g
F P
s
P
p
.002 w
.53538 .29122 m .54387 .31238 L .57192 .3144 L p
1 g
F P
s
P
p
.002 w
.54387 .31238 m .53538 .29122 L .50907 .29901 L p
1 g
F P
s
P
p
.002 w
.51874 .57934 m .57483 .55896 L .56662 .53925 L p
1 g
F P
s
P
p
.002 w
.56662 .53925 m .51137 .5593 L .51874 .57934 L p
1 g
F P
s
P
p
.002 w
.61511 .50715 m .56662 .53925 L .57483 .55896 L p
1 g
F P
s
P
p
.002 w
.50907 .29901 m .49755 .28777 L .47704 .30435 L p
1 g
F P
s
P
p
.002 w
.46903 .30099 m .47704 .30435 L .49755 .28777 L p
1 g
F P
s
P
p
.002 w
.46054 .58591 m .51874 .57934 L .51137 .5593 L p
1 g
F P
s
P
p
.002 w
.51137 .5593 m .45399 .56558 L .46054 .58591 L p
1 g
F P
s
P
p
.002 w
.4132 .30538 m .40481 .3209 L .43053 .32098 L p
1 g
F P
s
P
p
.002 w
.43053 .32098 m .4348 .31322 L .4132 .30538 L p
1 g
F P
s
P
p
.002 w
.33372 .43133 m .36046 .46221 L .37005 .43694 L p
1 g
F P
s
P
p
.002 w
.37005 .43694 m .34701 .40965 L .33372 .43133 L p
1 g
F P
s
P
p
.002 w
.35162 .51133 m .39635 .53399 L .39594 .50883 L p
1 g
F P
s
P
p
.002 w
.39594 .50883 m .35423 .48719 L .35162 .51133 L p
1 g
F P
s
P
p
.002 w
.35563 .36042 m .36387 .38896 L .38384 .36969 L p
1 g
F P
s
P
p
.002 w
.38384 .36969 m .37777 .34759 L .35563 .36042 L p
1 g
F P
s
P
p
.002 w
.49755 .28777 m .50907 .29901 L .53538 .29122 L p
1 g
F P
s
P
p
.002 w
.49755 .28777 m .48167 .28093 L .46903 .30099 L p
1 g
F P
s
P
p
.002 w
.45976 .30025 m .46903 .30099 L .48167 .28093 L p
1 g
F P
s
P
p
.002 w
.42682 .29233 m .4132 .30538 L .4348 .31322 L p
1 g
F P
s
P
p
.002 w
.4348 .31322 m .44163 .30673 L .42682 .29233 L p
1 g
F P
s
P
p
.002 w
.38091 .32363 m .37777 .34759 L .40251 .33711 L p
1 g
F P
s
P
p
.002 w
.40251 .33711 m .40481 .3209 L .38091 .32363 L p
1 g
F P
s
P
p
.002 w
.62331 .32736 m .62093 .36848 L .64228 .38341 L p
1 g
F P
s
P
p
.002 w
.62093 .36848 m .62331 .32736 L .59861 .3194 L p
1 g
F P
s
P
p
.002 w
.48167 .28093 m .46316 .27936 L .45976 .30025 L p
1 g
F P
s
P
p
.002 w
.45027 .30223 m .45976 .30025 L .46316 .27936 L p
1 g
F P
s
P
p
.002 w
.56129 .28684 m .57192 .3144 L .59861 .3194 L p
1 g
F P
s
P
p
.002 w
.57192 .3144 m .56129 .28684 L .53538 .29122 L p
1 g
F P
s
P
p
.002 w
.44414 .28331 m .42682 .29233 L .44163 .30673 L p
1 g
F P
s
P
p
.002 w
.44163 .30673 m .45027 .30223 L .44414 .28331 L p
1 g
F P
s
P
p
.002 w
.46316 .27936 m .44414 .28331 L .45027 .30223 L p
1 g
F P
s
P
p
.002 w
.57483 .55896 m .62414 .52651 L .61511 .50715 L p
1 g
F P
s
P
p
.002 w
.65253 .46551 m .61511 .50715 L .62414 .52651 L p
1 g
F P
s
P
p
.002 w
.61511 .50715 m .65253 .46551 L .63922 .44618 L p
1 g
F P
s
P
p
.002 w
.66048 .3999 m .63922 .44618 L .65253 .46551 L p
1 g
F P
s
P
p
.002 w
.63922 .44618 m .66048 .3999 L .64228 .38341 L p
1 g
F P
s
P
p
.002 w
.33668 .37539 m .34701 .40965 L .36387 .38896 L p
1 g
F P
s
P
p
.002 w
.36387 .38896 m .35563 .36042 L .33668 .37539 L p
1 g
F P
s
P
p
.002 w
.40523 .57769 m .46054 .58591 L .45399 .56558 L p
1 g
F P
s
P
p
.002 w
.45399 .56558 m .39943 .55714 L .40523 .57769 L p
1 g
F P
s
P
p
.002 w
.53538 .29122 m .51859 .27446 L .49755 .28777 L p
1 g
F P
s
P
p
.002 w
.48167 .28093 m .49755 .28777 L .51859 .27446 L p
1 g
F P
s
P
p
.002 w
.32443 .45355 m .35423 .48719 L .36046 .46221 L p
1 g
F P
s
P
p
.002 w
.36046 .46221 m .33372 .43133 L .32443 .45355 L p
1 g
F P
s
P
p
.002 w
.51859 .27446 m .53538 .29122 L .56129 .28684 L p
1 g
F P
s
P
p
.002 w
.39319 .30053 m .38091 .32363 L .40481 .3209 L p
1 g
F P
s
P
p
.002 w
.40481 .3209 m .4132 .30538 L .39319 .30053 L p
1 g
F P
s
P
p
.002 w
.35283 .53404 m .39943 .55714 L .39635 .53399 L p
1 g
F P
s
P
p
.002 w
.39635 .53399 m .35162 .51133 L .35283 .53404 L p
1 g
F P
s
P
p
.002 w
.35942 .32922 m .35563 .36042 L .37777 .34759 L p
1 g
F P
s
P
p
.002 w
.37777 .34759 m .38091 .32363 L .35942 .32922 L p
1 g
F P
s
P
p
.002 w
.58623 .28607 m .59861 .3194 L .62331 .32736 L p
1 g
F P
s
P
p
.002 w
.59861 .3194 m .58623 .28607 L .56129 .28684 L p
1 g
F P
s
P
p
.002 w
.52587 .59621 m .58139 .57601 L .57483 .55896 L p
1 g
F P
s
P
p
.002 w
.57483 .55896 m .51874 .57934 L .52587 .59621 L p
1 g
F P
s
P
p
.002 w
.62414 .52651 m .57483 .55896 L .58139 .57601 L p
1 g
F P
s
P
p
.002 w
.64542 .33818 m .64228 .38341 L .66048 .3999 L p
1 g
F P
s
P
p
.002 w
.64228 .38341 m .64542 .33818 L .62331 .32736 L p
1 g
F P
s
P
p
.002 w
.46834 .60286 m .52587 .59621 L .51874 .57934 L p
1 g
F P
s
P
p
.002 w
.51874 .57934 m .46054 .58591 L .46834 .60286 L p
1 g
F P
s
P
p
.002 w
.51859 .27446 m .49515 .26415 L .48167 .28093 L p
1 g
F P
s
P
p
.002 w
.46316 .27936 m .48167 .28093 L .49515 .26415 L p
1 g
F P
s
P
p
.002 w
.4134 .28103 m .39319 .30053 L .4132 .30538 L p
1 g
F P
s
P
p
.002 w
.4132 .30538 m .42682 .29233 L .4134 .28103 L p
1 g
F P
s
P
p
.002 w
.32149 .39225 m .33372 .43133 L .34701 .40965 L p
1 g
F P
s
P
p
.002 w
.34701 .40965 m .33668 .37539 L .32149 .39225 L p
1 g
F P
s
P
p
.002 w
.49515 .26415 m .46763 .2617 L .46316 .27936 L p
1 g
F P
s
P
p
.002 w
.44414 .28331 m .46316 .27936 L .46763 .2617 L p
1 g
F P
s
P
p
.002 w
.53971 .26483 m .56129 .28684 L .58623 .28607 L p
1 g
F P
s
P
p
.002 w
.56129 .28684 m .53971 .26483 L .51859 .27446 L p
1 g
F P
s
P
p
.002 w
.43924 .26754 m .4134 .28103 L .42682 .29233 L p
1 g
F P
s
P
p
.002 w
.42682 .29233 m .44414 .28331 L .43924 .26754 L p
1 g
F P
s
P
p
.002 w
.31954 .47581 m .35162 .51133 L .35423 .48719 L p
1 g
F P
s
P
p
.002 w
.35423 .48719 m .32443 .45355 L .31954 .47581 L p
1 g
F P
s
P
p
.002 w
.62414 .52651 m .66229 .4845 L .65253 .46551 L p
1 g
F P
s
P
p
.002 w
.675 .41766 m .65253 .46551 L .66229 .4845 L p
1 g
F P
s
P
p
.002 w
.65253 .46551 m .675 .41766 L .66048 .3999 L p
1 g
F P
s
P
p
.002 w
.58139 .57601 m .63024 .54401 L .62414 .52651 L p
1 g
F P
s
P
p
.002 w
.66229 .4845 m .62414 .52651 L .63024 .54401 L p
1 g
F P
s
P
p
.002 w
.49515 .26415 m .51859 .27446 L .53971 .26483 L p
1 g
F P
s
P
p
.002 w
.46763 .2617 m .43924 .26754 L .44414 .28331 L p
1 g
F P
s
P
p
.002 w
.3753 .29894 m .35942 .32922 L .38091 .32363 L p
1 g
F P
s
P
p
.002 w
.38091 .32363 m .39319 .30053 L .3753 .29894 L p
1 g
F P
s
P
p
.002 w
.41373 .59502 m .46834 .60286 L .46054 .58591 L p
1 g
F P
s
P
p
.002 w
.46054 .58591 m .40523 .57769 L .41373 .59502 L p
1 g
F P
s
P
p
.002 w
.34095 .33767 m .33668 .37539 L .35563 .36042 L p
1 g
F P
s
P
p
.002 w
.35563 .36042 m .35942 .32922 L .34095 .33767 L p
1 g
F P
s
P
p
.002 w
.60959 .28906 m .62331 .32736 L .64542 .33818 L p
1 g
F P
s
P
p
.002 w
.62331 .32736 m .60959 .28906 L .58623 .28607 L p
1 g
F P
s
P
p
.002 w
.35801 .55469 m .40523 .57769 L .39943 .55714 L p
1 g
F P
s
P
p
.002 w
.39943 .55714 m .35283 .53404 L .35801 .55469 L p
1 g
F P
s
P
p
.002 w
.66431 .35175 m .66048 .3999 L .675 .41766 L p
1 g
F P
s
P
p
.002 w
.66048 .3999 m .66431 .35175 L .64542 .33818 L p
1 g
F P
s
P
p
.002 w
.3106 .41066 m .32443 .45355 L .33372 .43133 L p
1 g
F P
s
P
p
.002 w
.33372 .43133 m .32149 .39225 L .3106 .41066 L p
1 g
F P
s
P
p
.002 w
.53971 .26483 m .50921 .25118 L .49515 .26415 L p
1 g
F P
s
P
p
.002 w
.46763 .2617 m .49515 .26415 L .50921 .25118 L p
1 g
F P
s
P
p
.002 w
.53259 .60934 m .58605 .58987 L .58139 .57601 L p
1 g
F P
s
P
p
.002 w
.58139 .57601 m .52587 .59621 L .53259 .60934 L p
1 g
F P
s
P
p
.002 w
.63024 .54401 m .58139 .57601 L .58605 .58987 L p
1 g
F P
s
P
p
.002 w
.47726 .61586 m .53259 .60934 L .52587 .59621 L p
1 g
F P
s
P
p
.002 w
.52587 .59621 m .46834 .60286 L .47726 .61586 L p
1 g
F P
s
P
p
.002 w
.56044 .25927 m .58623 .28607 L .60959 .28906 L p
1 g
F P
s
P
p
.002 w
.58623 .28607 m .56044 .25927 L .53971 .26483 L p
1 g
F P
s
P
p
.002 w
.40177 .27327 m .3753 .29894 L .39319 .30053 L p
1 g
F P
s
P
p
.002 w
.39319 .30053 m .4134 .28103 L .40177 .27327 L p
1 g
F P
s
P
p
.002 w
.31935 .49754 m .35283 .53404 L .35162 .51133 L p
1 g
F P
s
P
p
.002 w
.35162 .51133 m .31954 .47581 L .31935 .49754 L p
1 g
F P
s
P
p
.002 w
.50921 .25118 m .53971 .26483 L .56044 .25927 L p
1 g
F P
s
P
p
.002 w
.63024 .54401 m .66809 .50271 L .66229 .4845 L p
1 g
F P
s
P
p
.002 w
.68533 .4363 m .66229 .4845 L .66809 .50271 L p
1 g
F P
s
P
p
.002 w
.66229 .4845 m .68533 .4363 L .675 .41766 L p
1 g
F P
s
P
p
.002 w
.50921 .25118 m .47313 .24784 L .46763 .2617 L p
1 g
F P
s
P
p
.002 w
.43924 .26754 m .46763 .2617 L .47313 .24784 L p
1 g
F P
s
P
p
.002 w
.63073 .29592 m .64542 .33818 L .66431 .35175 L p
1 g
F P
s
P
p
.002 w
.64542 .33818 m .63073 .29592 L .60959 .28906 L p
1 g
F P
s
P
p
.002 w
.32612 .34891 m .32149 .39225 L .33668 .37539 L p
1 g
F P
s
P
p
.002 w
.33668 .37539 m .34095 .33767 L .32612 .34891 L p
1 g
F P
s
P
p
.002 w
.43577 .25548 m .40177 .27327 L .4134 .28103 L p
1 g
F P
s
P
p
.002 w
.4134 .28103 m .43924 .26754 L .43577 .25548 L p
1 g
F P
s
P
p
.002 w
.58605 .58987 m .63312 .55916 L .63024 .54401 L p
1 g
F P
s
P
p
.002 w
.66809 .50271 m .63024 .54401 L .63312 .55916 L p
1 g
F P
s
P
p
.002 w
.36008 .30081 m .34095 .33767 L .35942 .32922 L p
1 g
F P
s
P
p
.002 w
.35942 .32922 m .3753 .29894 L .36008 .30081 L p
1 g
F P
s
P
p
.002 w
.47313 .24784 m .43577 .25548 L .43924 .26754 L p
1 g
F P
s
P
p
.002 w
.36721 .57267 m .41373 .59502 L .40523 .57769 L p
1 g
F P
s
P
p
.002 w
.40523 .57769 m .35801 .55469 L .36721 .57267 L p
1 g
F P
s
P
p
.002 w
.42487 .60853 m .47726 .61586 L .46834 .60286 L p
1 g
F P
s
P
p
.002 w
.46834 .60286 m .41373 .59502 L .42487 .60853 L p
1 g
F P
s
P
p
.002 w
.67938 .36783 m .675 .41766 L .68533 .4363 L p
1 g
F P
s
P
p
.002 w
.675 .41766 m .67938 .36783 L .66431 .35175 L p
1 g
F P
s
P
p
.002 w
.30451 .43023 m .31954 .47581 L .32443 .45355 L p
1 g
F P
s
P
p
.002 w
.32443 .45355 m .3106 .41066 L .30451 .43023 L p
1 g
F P
s
P
p
.002 w
.58023 .25811 m .60959 .28906 L .63073 .29592 L p
1 g
F P
s
P
p
.002 w
.60959 .28906 m .58023 .25811 L .56044 .25927 L p
1 g
F P
s
P
p
.002 w
.56044 .25927 m .52353 .24253 L .50921 .25118 L p
1 g
F P
s
P
p
.002 w
.47313 .24784 m .50921 .25118 L .52353 .24253 L p
1 g
F P
s
P
p
.002 w
.32411 .51815 m .35801 .55469 L .35283 .53404 L p
1 g
F P
s
P
p
.002 w
.35283 .53404 m .31935 .49754 L .32411 .51815 L p
1 g
F P
s
P
p
.002 w
.5387 .61819 m .58859 .60002 L .58605 .58987 L p
1 g
F P
s
P
p
.002 w
.58605 .58987 m .53259 .60934 L .5387 .61819 L p
1 g
F P
s
P
p
.002 w
.63312 .55916 m .58605 .58987 L .58859 .60002 L p
1 g
F P
s
P
p
.002 w
.39231 .26944 m .36008 .30081 L .3753 .29894 L p
1 g
F P
s
P
p
.002 w
.3753 .29894 m .40177 .27327 L .39231 .26944 L p
1 g
F P
s
P
p
.002 w
.52353 .24253 m .56044 .25927 L .58023 .25811 L p
1 g
F P
s
P
p
.002 w
.48716 .62436 m .5387 .61819 L .53259 .60934 L p
1 g
F P
s
P
p
.002 w
.53259 .60934 m .47726 .61586 L .48716 .62436 L p
1 g
F P
s
P
p
.002 w
.64901 .30663 m .66431 .35175 L .67938 .36783 L p
1 g
F P
s
P
p
.002 w
.66431 .35175 m .64901 .30663 L .63073 .29592 L p
1 g
F P
s
P
p
.002 w
.31551 .3628 m .3106 .41066 L .32149 .39225 L p
1 g
F P
s
P
p
.002 w
.32149 .39225 m .32612 .34891 L .31551 .3628 L p
1 g
F P
s
P
p
.002 w
.63312 .55916 m .66958 .51964 L .66809 .50271 L p
1 g
F P
s
P
p
.002 w
.69102 .45541 m .66809 .50271 L .66958 .51964 L p
1 g
F P
s
P
p
.002 w
.66809 .50271 m .69102 .45541 L .68533 .4363 L p
1 g
F P
s
P
p
.002 w
.34808 .30631 m .32612 .34891 L .34095 .33767 L p
1 g
F P
s
P
p
.002 w
.34095 .33767 m .36008 .30081 L .34808 .30631 L p
1 g
F P
s
P
p
.002 w
.52353 .24253 m .47957 .23836 L .47313 .24784 L p
1 g
F P
s
P
p
.002 w
.43577 .25548 m .47313 .24784 L .47957 .23836 L p
1 g
F P
s
P
p
.002 w
.58859 .60002 m .63251 .57144 L .63312 .55916 L p
1 g
F P
s
P
p
.002 w
.66958 .51964 m .63312 .55916 L .63251 .57144 L p
1 g
F P
s
P
p
.002 w
.43389 .24767 m .39231 .26944 L .40177 .27327 L p
1 g
F P
s
P
p
.002 w
.40177 .27327 m .43577 .25548 L .43389 .24767 L p
1 g
F P
s
P
p
.002 w
.69006 .38615 m .68533 .4363 L .69102 .45541 L p
1 g
F P
s
P
p
.002 w
.68533 .4363 m .69006 .38615 L .67938 .36783 L p
1 g
F P
s
P
p
.002 w
.3804 .58735 m .42487 .60853 L .41373 .59502 L p
1 g
F P
s
P
p
.002 w
.41373 .59502 m .36721 .57267 L .3804 .58735 L p
1 g
F P
s
P
p
.002 w
.30363 .45049 m .31935 .49754 L .31954 .47581 L p
1 g
F P
s
P
p
.002 w
.31954 .47581 m .30451 .43023 L .30363 .45049 L p
1 g
F P
s
P
p
.002 w
.47957 .23836 m .43389 .24767 L .43577 .25548 L p
1 g
F P
s
P
p
.002 w
.4385 .61766 m .48716 .62436 L .47726 .61586 L p
1 g
F P
s
P
p
.002 w
.47726 .61586 m .42487 .60853 L .4385 .61766 L p
1 g
F P
s
P
p
.002 w
.59854 .26161 m .63073 .29592 L .64901 .30663 L p
1 g
F P
s
P
p
.002 w
.63073 .29592 m .59854 .26161 L .58023 .25811 L p
1 g
F P
s
P
p
.002 w
.33393 .53702 m .36721 .57267 L .35801 .55469 L p
1 g
F P
s
P
p
.002 w
.35801 .55469 m .32411 .51815 L .33393 .53702 L p
1 g
F P
s
P
p
.002 w
.58023 .25811 m .53777 .23867 L .52353 .24253 L p
1 g
F P
s
P
p
.002 w
.47957 .23836 m .52353 .24253 L .53777 .23867 L p
1 g
F P
s
P
p
.002 w
.66381 .32112 m .67938 .36783 L .69006 .38615 L p
1 g
F P
s
P
p
.002 w
.67938 .36783 m .66381 .32112 L .64901 .30663 L p
1 g
F P
s
P
p
.002 w
.53777 .23867 m .58023 .25811 L .59854 .26161 L p
1 g
F P
s
P
p
.002 w
.30966 .3791 m .30451 .43023 L .3106 .41066 L p
1 g
F P
s
P
p
.002 w
.3106 .41066 m .31551 .3628 L .30966 .3791 L p
1 g
F P
s
P
p
.002 w
.38543 .26989 m .34808 .30631 L .36008 .30081 L p
1 g
F P
s
P
p
.002 w
.36008 .30081 m .39231 .26944 L .38543 .26989 L p
1 g
F P
s
P
p
.002 w
.54402 .62228 m .58881 .60595 L .58859 .60002 L p
1 g
F P
s
P
p
.002 w
.58859 .60002 m .5387 .61819 L .54402 .62228 L p
1 g
F P
s
P
p
.002 w
.63251 .57144 m .58859 .60002 L .58881 .60595 L p
1 g
F P
s
P
p
.002 w
.63251 .57144 m .66648 .53477 L .66958 .51964 L p
1 g
F P
s
P
p
.002 w
.69166 .47451 m .66958 .51964 L .66648 .53477 L p
1 g
F P
s
P
p
.002 w
.66958 .51964 m .69166 .47451 L .69102 .45541 L p
1 g
F P
s
P
p
.002 w
.49782 .62784 m .54402 .62228 L .5387 .61819 L p
1 g
F P
s
P
p
.002 w
.5387 .61819 m .48716 .62436 L .49782 .62784 L p
1 g
F P
s
P
p
.002 w
.33983 .3155 m .31551 .3628 L .32612 .34891 L p
1 g
F P
s
P
p
.002 w
.32612 .34891 m .34808 .30631 L .33983 .3155 L p
1 g
F P
s
P
p
.002 w
.69584 .40631 m .69102 .45541 L .69166 .47451 L p
1 g
F P
s
P
p
.002 w
.69102 .45541 m .69584 .40631 L .69006 .38615 L p
1 g
F P
s
P
p
.002 w
.30826 .47089 m .32411 .51815 L .31935 .49754 L p
1 g
F P
s
P
p
.002 w
.31935 .49754 m .30363 .45049 L .30826 .47089 L p
1 g
F P
s
P
p
.002 w
.39742 .59814 m .4385 .61766 L .42487 .60853 L p
1 g
F P
s
P
p
.002 w
.42487 .60853 m .3804 .58735 L .39742 .59814 L p
1 g
F P
s
P
p
.002 w
.53777 .23867 m .48685 .23377 L .47957 .23836 L p
1 g
F P
s
P
p
.002 w
.43389 .24767 m .47957 .23836 L .48685 .23377 L p
1 g
F P
s
P
p
.002 w
.58881 .60595 m .62823 .58034 L .63251 .57144 L p
1 g
F P
s
P
p
.002 w
.66648 .53477 m .63251 .57144 L .62823 .58034 L p
1 g
F P
s
P
p
.002 w
.43376 .24458 m .38543 .26989 L .39231 .26944 L p
1 g
F P
s
P
p
.002 w
.39231 .26944 m .43389 .24767 L .43376 .24458 L p
1 g
F P
s
P
p
.002 w
.61478 .26993 m .64901 .30663 L .66381 .32112 L p
1 g
F P
s
P
p
.002 w
.64901 .30663 m .61478 .26993 L .59854 .26161 L p
1 g
F P
s
P
p
.002 w
.45438 .62188 m .49782 .62784 L .48716 .62436 L p
1 g
F P
s
P
p
.002 w
.48716 .62436 m .4385 .61766 L .45438 .62188 L p
1 g
F P
s
P
p
.002 w
.48685 .23377 m .43376 .24458 L .43389 .24767 L p
1 g
F P
s
P
p
.002 w
.34879 .5535 m .3804 .58735 L .36721 .57267 L p
1 g
F P
s
P
p
.002 w
.36721 .57267 m .33393 .53702 L .34879 .5535 L p
1 g
F P
s
P
p
.002 w
.69006 .38615 m .67453 .33916 L .66381 .32112 L p
1 g
F P
s
P
p
.002 w
.67453 .33916 m .69006 .38615 L .69584 .40631 L p
1 g
F P
s
P
p
.002 w
.30899 .39748 m .30363 .45049 L .30451 .43023 L p
1 g
F P
s
P
p
.002 w
.30451 .43023 m .30966 .3791 L .30899 .39748 L p
1 g
F P
s
P
p
.002 w
.59854 .26161 m .55153 .23998 L .53777 .23867 L p
1 g
F P
s
P
p
.002 w
.48685 .23377 m .53777 .23867 L .55153 .23998 L p
1 g
F P
s
P
p
.002 w
.55153 .23998 m .59854 .26161 L .61478 .26993 L p
1 g
F P
s
P
p
.002 w
.38148 .2749 m .33983 .3155 L .34808 .30631 L p
1 g
F P
s
P
p
.002 w
.34808 .30631 m .38543 .26989 L .38148 .2749 L p
1 g
F P
s
P
p
.002 w
.62823 .58034 m .65861 .54759 L .66648 .53477 L p
1 g
F P
s
P
p
.002 w
.66648 .53477 m .68697 .49308 L .69166 .47451 L p
1 g
F P
s
P
p
.002 w
.68697 .49308 m .66648 .53477 L .65861 .54759 L p
1 g
F P
s
P
p
.002 w
.31854 .49082 m .33393 .53702 L .32411 .51815 L p
1 g
F P
s
P
p
.002 w
.32411 .51815 m .30826 .47089 L .31854 .49082 L p
1 g
F P
s
P
p
.002 w
.3358 .32835 m .30966 .3791 L .31551 .3628 L p
1 g
F P
s
P
p
.002 w
.31551 .3628 m .33983 .3155 L .3358 .32835 L p
1 g
F P
s
P
p
.002 w
.54833 .62116 m .58655 .60723 L .58881 .60595 L p
1 g
F P
s
P
p
.002 w
.58881 .60595 m .54402 .62228 L .54833 .62116 L p
1 g
F P
s
P
p
.002 w
.62823 .58034 m .58881 .60595 L .58655 .60723 L p
1 g
F P
s
P
p
.002 w
.69166 .47451 m .69631 .42784 L .69584 .40631 L p
1 g
F P
s
P
p
.002 w
.69631 .42784 m .69166 .47451 L .68697 .49308 L p
1 g
F P
s
P
p
.002 w
.50898 .62589 m .54833 .62116 L .54402 .62228 L p
1 g
F P
s
P
p
.002 w
.54402 .62228 m .49782 .62784 L .50898 .62589 L p
1 g
F P
s
P
p
.002 w
.66381 .32112 m .62838 .28309 L .61478 .26993 L p
1 g
F P
s
P
p
.002 w
.62838 .28309 m .66381 .32112 L .67453 .33916 L p
1 g
F P
s
P
p
.002 w
.41796 .60452 m .45438 .62188 L .4385 .61766 L p
1 g
F P
s
P
p
.002 w
.4385 .61766 m .39742 .59814 L .41796 .60452 L p
1 g
F P
s
P
p
.002 w
.55153 .23998 m .49481 .23453 L .48685 .23377 L p
1 g
F P
s
P
p
.002 w
.43376 .24458 m .48685 .23377 L .49481 .23453 L p
1 g
F P
s
P
p
.002 w
.58655 .60723 m .62014 .5854 L .62823 .58034 L p
1 g
F P
s
P
p
.002 w
.65861 .54759 m .62823 .58034 L .62014 .5854 L p
1 g
F P
s
P
p
.002 w
.36848 .56697 m .39742 .59814 L .3804 .58735 L p
1 g
F P
s
P
p
.002 w
.3804 .58735 m .34879 .5535 L .36848 .56697 L p
1 g
F P
s
P
p
.002 w
.4355 .24662 m .38148 .2749 L .38543 .26989 L p
1 g
F P
s
P
p
.002 w
.38543 .26989 m .43376 .24458 L .4355 .24662 L p
1 g
F P
s
P
p
.002 w
.68064 .36042 m .69584 .40631 L .69631 .42784 L p
1 g
F P
s
P
p
.002 w
.69584 .40631 m .68064 .36042 L .67453 .33916 L p
1 g
F P
s
P
p
.002 w
.47218 .6208 m .50898 .62589 L .49782 .62784 L p
1 g
F P
s
P
p
.002 w
.49782 .62784 m .45438 .62188 L .47218 .6208 L p
1 g
F P
s
P
p
.002 w
.31384 .41749 m .30826 .47089 L .30363 .45049 L p
1 g
F P
s
P
p
.002 w
.30363 .45049 m .30899 .39748 L .31384 .41749 L p
1 g
F P
s
P
p
.002 w
.49481 .23453 m .4355 .24662 L .43376 .24458 L p
1 g
F P
s
P
p
.002 w
.56438 .24676 m .61478 .26993 L .62838 .28309 L p
1 g
F P
s
P
p
.002 w
.61478 .26993 m .56438 .24676 L .55153 .23998 L p
1 g
F P
s
P
p
.002 w
.49481 .23453 m .55153 .23998 L .56438 .24676 L p
1 g
F P
s
P
p
.002 w
.33443 .50963 m .34879 .5535 L .33393 .53702 L p
1 g
F P
s
P
p
.002 w
.33393 .53702 m .31854 .49082 L .33443 .50963 L p
1 g
F P
s
P
p
.002 w
.38077 .28462 m .3358 .32835 L .33983 .3155 L p
1 g
F P
s
P
p
.002 w
.33983 .3155 m .38148 .2749 L .38077 .28462 L p
1 g
F P
s
P
p
.002 w
.33638 .34468 m .30899 .39748 L .30966 .3791 L p
1 g
F P
s
P
p
.002 w
.30966 .3791 m .3358 .32835 L .33638 .34468 L p
1 g
F P
s
P
p
.002 w
.65861 .54759 m .6768 .51053 L .68697 .49308 L p
1 g
F P
s
P
p
.002 w
.69118 .45015 m .68697 .49308 L .6768 .51053 L p
1 g
F P
s
P
p
.002 w
.68697 .49308 m .69118 .45015 L .69631 .42784 L p
1 g
F P
s
P
p
.002 w
.62014 .5854 m .64592 .55758 L .65861 .54759 L p
1 g
F P
s
P
p
.002 w
.6768 .51053 m .65861 .54759 L .64592 .55758 L p
1 g
F P
s
P
p
.002 w
.63878 .30097 m .67453 .33916 L .68064 .36042 L p
1 g
F P
s
P
p
.002 w
.67453 .33916 m .63878 .30097 L .62838 .28309 L p
1 g
F P
s
P
p
.002 w
.55145 .61452 m .58171 .6035 L .58655 .60723 L p
1 g
F P
s
P
p
.002 w
.58655 .60723 m .54833 .62116 L .55145 .61452 L p
1 g
F P
s
P
p
.004 w
.57339 .61465 m
.58267 .63793 L
s
P
p
.002 w
.62014 .5854 m .58655 .60723 L .58171 .6035 L p
1 g
F P
s
P
p
.002 w
.44157 .60606 m .47218 .6208 L .45438 .62188 L p
1 g
F P
s
P
p
.002 w
.45438 .62188 m .41796 .60452 L .44157 .60606 L p
1 g
F P
s
P
p
.002 w
.52036 .61823 m .55145 .61452 L .54833 .62116 L p
1 g
F P
s
P
p
.002 w
.54833 .62116 m .50898 .62589 L .52036 .61823 L p
1 g
F P
s
P
p
.002 w
.39261 .57687 m .41796 .60452 L .39742 .59814 L p
1 g
F P
s
P
p
.002 w
.39742 .59814 m .36848 .56697 L .39261 .57687 L p
1 g
F P
s
P
p
.002 w
.68174 .38439 m .69631 .42784 L .69118 .45015 L p
1 g
F P
s
P
p
.002 w
.69631 .42784 m .68174 .38439 L .68064 .36042 L p
1 g
F P
s
P
p
.002 w
.56438 .24676 m .50327 .24097 L .49481 .23453 L p
1 g
F P
s
P
p
.002 w
.4355 .24662 m .49481 .23453 L .50327 .24097 L p
1 g
F P
s
P
p
.002 w
.58171 .6035 m .60826 .58622 L .62014 .5854 L p
1 g
F P
s
P
p
.002 w
.64592 .55758 m .62014 .5854 L .60826 .58622 L p
1 g
F P
s
P
p
.002 w
.32432 .43856 m .31854 .49082 L .30826 .47089 L p
1 g
F P
s
P
p
.002 w
.30826 .47089 m .31384 .41749 L .32432 .43856 L p
1 g
F P
s
P
p
.002 w
.43919 .25407 m .38077 .28462 L .38148 .2749 L p
1 g
F P
s
P
p
.002 w
.38148 .2749 m .4355 .24662 L .43919 .25407 L p
1 g
F P
s
P
p
.002 w
.49143 .61415 m .52036 .61823 L .50898 .62589 L p
1 g
F P
s
P
p
.002 w
.50898 .62589 m .47218 .6208 L .49143 .61415 L p
1 g
F P
s
P
p
.002 w
.57587 .25911 m .62838 .28309 L .63878 .30097 L p
1 g
F P
s
P
p
.002 w
.62838 .28309 m .57587 .25911 L .56438 .24676 L p
1 g
F P
s
P
p
.002 w
.35567 .52666 m .36848 .56697 L .34879 .5535 L p
1 g
F P
s
P
p
.002 w
.34879 .5535 m .33443 .50963 L .35567 .52666 L p
1 g
F P
s
P
p
.002 w
.50327 .24097 m .43919 .25407 L .4355 .24662 L p
1 g
F P
s
P
p
.002 w
.50327 .24097 m .56438 .24676 L .57587 .25911 L p
1 g
F P
s
P
p
.002 w
.64592 .55758 m .66116 .52627 L .6768 .51053 L p
1 g
F P
s
P
p
.002 w
.68034 .4726 m .6768 .51053 L .66116 .52627 L p
1 g
F P
s
P
p
.002 w
.6768 .51053 m .68034 .4726 L .69118 .45015 L p
1 g
F P
s
P
p
.002 w
.34182 .36416 m .31384 .41749 L .30899 .39748 L p
1 g
F P
s
P
p
.002 w
.30899 .39748 m .33638 .34468 L .34182 .36416 L p
1 g
F P
s
P
p
.002 w
.64547 .32323 m .68064 .36042 L .68174 .38439 L p
1 g
F P
s
P
p
.002 w
.68064 .36042 m .64547 .32323 L .63878 .30097 L p
1 g
F P
s
P
p
.002 w
.60826 .58622 m .6285 .56427 L .64592 .55758 L p
1 g
F P
s
P
p
.002 w
.66116 .52627 m .64592 .55758 L .6285 .56427 L p
1 g
F P
s
P
p
.002 w
.38355 .29904 m .33638 .34468 L .3358 .32835 L p
1 g
F P
s
P
p
.002 w
.3358 .32835 m .38077 .28462 L .38355 .29904 L p
1 g
F P
s
P
p
.002 w
.42057 .58272 m .44157 .60606 L .41796 .60452 L p
1 g
F P
s
P
p
.002 w
.41796 .60452 m .39261 .57687 L .42057 .58272 L p
1 g
F P
s
P
p
.002 w
.46761 .60248 m .49143 .61415 L .47218 .6208 L p
1 g
F P
s
P
p
.002 w
.47218 .6208 m .44157 .60606 L .46761 .60248 L p
1 g
F P
s
P
p
.002 w
.67754 .41043 m .69118 .45015 L .68034 .4726 L p
1 g
F P
s
P
p
.002 w
.69118 .45015 m .67754 .41043 L .68174 .38439 L p
1 g
F P
s
P
p
.002 w
.55319 .60222 m .57426 .59454 L .58171 .6035 L p
1 g
F P
s
P
p
.002 w
.58171 .6035 m .55145 .61452 L .55319 .60222 L p
1 g
F P
s
P
p
.002 w
.60826 .58622 m .58171 .6035 L .57426 .59454 L p
1 g
F P
s
P
p
.002 w
.34037 .46003 m .33443 .50963 L .31854 .49082 L p
1 g
F P
s
P
p
.002 w
.31854 .49082 m .32432 .43856 L .34037 .46003 L p
1 g
F P
s
P
p
.002 w
.53159 .60475 m .55319 .60222 L .55145 .61452 L p
1 g
F P
s
P
p
.002 w
.55145 .61452 m .52036 .61823 L .53159 .60475 L p
1 g
F P
s
P
p
.002 w
.58557 .27697 m .63878 .30097 L .64547 .32323 L p
1 g
F P
s
P
p
.002 w
.63878 .30097 m .58557 .27697 L .57587 .25911 L p
1 g
F P
s
P
p
.002 w
.57426 .59454 m .59271 .5825 L .60826 .58622 L p
1 g
F P
s
P
p
.002 w
.6285 .56427 m .60826 .58622 L .59271 .5825 L p
1 g
F P
s
P
p
.002 w
.57587 .25911 m .51198 .25323 L .50327 .24097 L p
1 g
F P
s
P
p
.002 w
.43919 .25407 m .50327 .24097 L .51198 .25323 L p
1 g
F P
s
P
p
.002 w
.38176 .54126 m .39261 .57687 L .36848 .56697 L p
1 g
F P
s
P
p
.002 w
.36848 .56697 m .35567 .52666 L .38176 .54126 L p
1 g
F P
s
P
p
.002 w
.51161 .60183 m .53159 .60475 L .52036 .61823 L p
1 g
F P
s
P
p
.002 w
.52036 .61823 m .49143 .61415 L .51161 .60183 L p
1 g
F P
s
P
p
.002 w
.44483 .26705 m .38355 .29904 L .38077 .28462 L p
1 g
F P
s
P
p
.002 w
.38077 .28462 m .43919 .25407 L .44483 .26705 L p
1 g
F P
s
P
p
.002 w
.64806 .34937 m .68174 .38439 L .67754 .41043 L p
1 g
F P
s
P
p
.002 w
.68174 .38439 m .64806 .34937 L .64547 .32323 L p
1 g
F P
s
P
p
.002 w
.6285 .56427 m .64029 .53971 L .66116 .52627 L p
1 g
F P
s
P
p
.002 w
.66388 .49446 m .66116 .52627 L .64029 .53971 L p
1 g
F P
s
P
p
.002 w
.66116 .52627 m .66388 .49446 L .68034 .4726 L p
1 g
F P
s
P
p
.002 w
.51198 .25323 m .57587 .25911 L .58557 .27697 L p
1 g
F P
s
P
p
.002 w
.51198 .25323 m .44483 .26705 L .43919 .25407 L p
1 g
F P
s
P
p
.002 w
.3522 .3863 m .32432 .43856 L .31384 .41749 L p
1 g
F P
s
P
p
.002 w
.31384 .41749 m .34182 .36416 L .3522 .3863 L p
1 g
F P
s
P
p
.002 w
.59271 .5825 m .60667 .56725 L .6285 .56427 L p
1 g
F P
s
P
p
.002 w
.64029 .53971 m .6285 .56427 L .60667 .56725 L p
1 g
F P
s
P
p
.002 w
.66796 .43777 m .68034 .4726 L .66388 .49446 L p
1 g
F P
s
P
p
.002 w
.68034 .4726 m .66796 .43777 L .67754 .41043 L p
1 g
F P
s
P
p
.002 w
.45154 .58415 m .46761 .60248 L .44157 .60606 L p
1 g
F P
s
P
p
.002 w
.44157 .60606 m .42057 .58272 L .45154 .58415 L p
1 g
F P
s
P
p
.002 w
.38992 .31795 m .34182 .36416 L .33638 .34468 L p
1 g
F P
s
P
p
.002 w
.33638 .34468 m .38355 .29904 L .38992 .31795 L p
1 g
F P
s
P
p
.002 w
.49533 .59367 m .51161 .60183 L .49143 .61415 L p
1 g
F P
s
P
p
.002 w
.49143 .61415 m .46761 .60248 L .49533 .59367 L p
1 g
F P
s
P
p
.002 w
.36166 .48118 m .35567 .52666 L .33443 .50963 L p
1 g
F P
s
P
p
.002 w
.33443 .50963 m .34037 .46003 L .36166 .48118 L p
1 g
F P
s
P
p
.002 w
.41195 .55282 m .42057 .58272 L .39261 .57687 L p
1 g
F P
s
P
p
.002 w
.39261 .57687 m .38176 .54126 L .41195 .55282 L p
1 g
F P
s
P
p
.002 w
.59304 .30002 m .64547 .32323 L .64806 .34937 L p
1 g
F P
s
P
p
.002 w
.64547 .32323 m .59304 .30002 L .58557 .27697 L p
1 g
F P
s
P
p
.002 w
.55342 .5843 m .56431 .58034 L .57426 .59454 L p
1 g
F P
s
P
p
.002 w
.57426 .59454 m .55319 .60222 L .55342 .5843 L p
1 g
F P
s
P
p
.002 w
.59271 .5825 m .57426 .59454 L .56431 .58034 L p
1 g
F P
s
P
p
.002 w
.54228 .58557 m .55342 .5843 L .55319 .60222 L p
1 g
F P
s
P
p
.002 w
.55319 .60222 m .53159 .60475 L .54228 .58557 L p
1 g
F P
s
P
p
.002 w
.64627 .37865 m .67754 .41043 L .66796 .43777 L p
1 g
F P
s
P
p
.002 w
.67754 .41043 m .64627 .37865 L .64806 .34937 L p
1 g
F P
s
P
p
.002 w
.56431 .58034 m .57381 .5741 L .59271 .5825 L p
1 g
F P
s
P
p
.002 w
.60667 .56725 m .59271 .5825 L .57381 .5741 L p
1 g
F P
s
P
p
.002 w
.60667 .56725 m .61465 .5503 L .64029 .53971 L p
1 g
F P
s
P
p
.002 w
.64214 .51497 m .64029 .53971 L .61465 .5503 L p
1 g
F P
s
P
p
.002 w
.64029 .53971 m .64214 .51497 L .66388 .49446 L p
1 g
F P
s
P
p
.002 w
.58557 .27697 m .52067 .27126 L .51198 .25323 L p
1 g
F P
s
P
p
.002 w
.44483 .26705 m .51198 .25323 L .52067 .27126 L p
1 g
F P
s
P
p
.002 w
.53204 .58401 m .54228 .58557 L .53159 .60475 L p
1 g
F P
s
P
p
.002 w
.53159 .60475 m .51161 .60183 L .53204 .58401 L p
1 g
F P
s
P
p
.002 w
.65314 .4655 m .66388 .49446 L .64214 .51497 L p
1 g
F P
s
P
p
.002 w
.66388 .49446 m .65314 .4655 L .66796 .43777 L p
1 g
F P
s
P
p
.002 w
.36738 .41044 m .34037 .46003 L .32432 .43856 L p
1 g
F P
s
P
p
.002 w
.32432 .43856 m .3522 .3863 L .36738 .41044 L p
1 g
F P
s
P
p
.002 w
.52067 .27126 m .58557 .27697 L .59304 .30002 L p
1 g
F P
s
P
p
.002 w
.45234 .28545 m .38992 .31795 L .38355 .29904 L p
1 g
F P
s
P
p
.002 w
.38355 .29904 m .44483 .26705 L .45234 .28545 L p
1 g
F P
s
P
p
.002 w
.48455 .58098 m .49533 .59367 L .46761 .60248 L p
1 g
F P
s
P
p
.002 w
.46761 .60248 m .45154 .58415 L .48455 .58098 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.57381 .5741 m .58094 .56623 L .60667 .56725 L p
1 g
F P
s
P
p
.002 w
.61465 .5503 m .60667 .56725 L .58094 .56623 L p
1 g
F P
s
P
p
.002 w
.38761 .50123 m .38176 .54126 L .35567 .52666 L p
1 g
F P
s
P
p
.002 w
.35567 .52666 m .36166 .48118 L .38761 .50123 L p
1 g
F P
s
P
p
.002 w
.52067 .27126 m .45234 .28545 L .44483 .26705 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.5238 .57975 m .53204 .58401 L .51161 .60183 L p
1 g
F P
s
P
p
.002 w
.51161 .60183 m .49533 .59367 L .5238 .57975 L p
1 g
F P
s
P
p
.002 w
.44528 .56085 m .45154 .58415 L .42057 .58272 L p
1 g
F P
s
P
p
.002 w
.42057 .58272 m .41195 .55282 L .44528 .56085 L p
1 g
F P
s
P
p
.002 w
.39986 .34094 m .3522 .3863 L .34182 .36416 L p
1 g
F P
s
P
p
.002 w
.34182 .36416 m .38992 .31795 L .39986 .34094 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.54055 .53225 L
s
P
p
.002 w
.59791 .32772 m .64806 .34937 L .64627 .37865 L p
1 g
F P
s
P
p
.002 w
.64806 .34937 m .59791 .32772 L .59304 .30002 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.64001 .41015 m .66796 .43777 L .65314 .4655 L p
1 g
F P
s
P
p
.002 w
.66796 .43777 m .64001 .41015 L .64627 .37865 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.58094 .56623 m .58492 .55754 L .61465 .5503 L p
1 g
F P
s
P
p
.002 w
.61567 .53336 m .61465 .5503 L .58492 .55754 L p
1 g
F P
s
P
p
.002 w
.61465 .5503 m .61567 .53336 L .64214 .51497 L p
1 g
F P
s
P
p
.002 w
.63343 .49266 m .64214 .51497 L .61567 .53336 L p
1 g
F P
s
P
p
.002 w
.64214 .51497 m .63343 .49266 L .65314 .4655 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52236 .58046 m .49533 .59367 L p
.50978 .58089 L 1 g
F P
s
P
p
.50978 .58089 m .51005 .58064 L .51094 .58063 L 1 g
F
P
p
.50978 .58089 m .51094 .58063 L .52236 .58046 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58063 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58063 L .51937 .57876 L 1 g
F
P
p
.002 w
.51094 .58063 m .51079 .57862 L p
.4999 .5808 L 1 g
F P
s
P
p
.53128 .57265 m .51937 .57876 L .52243 .57808 L 1 g
F
P
p
.53128 .57265 m .52243 .57808 L .52311 .57784 L 1 g
F
P
p
.002 w
.53095 .57502 m .5238 .57975 L .52243 .57808 L p
1 g
F P
s
P
p
.002 w
.53173 .57473 m .53128 .57265 L p
.52288 .57798 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .57473 L p
1 g
F P
s
P
p
.002 w
.55083 .56245 m .54408 .57021 L p
.54253 .57077 L 1 g
F P
s
P
p
.54253 .57077 m .53173 .57473 L .54933 .56342 L 1 g
F
P
p
.54253 .57077 m .54933 .56342 L .55083 .56245 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54933 .56342 L p
1 g
F P
s
P
p
.56075 .54566 m .54933 .56342 L .55066 .56199 L 1 g
F
P
p
.56075 .54566 m .55066 .56199 L .55134 .56124 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54726 L p
1 g
F P
s
P
p
.002 w
.57527 .53563 m .55972 .55266 L p
.56009 .55159 L 1 g
F P
s
P
p
.56654 .52734 m .5616 .54726 L .56434 .53939 L 1 g
F
P
p
.002 w
.55204 .56107 m .55302 .55903 L p
.56009 .55159 L 1 g
F P
s
P
p
.002 w
.57111 .53421 m .57527 .53563 L p
.56009 .55159 L 1 g
F P
s
P
p
.5616 .54726 m .56009 .55159 L .55302 .55903 L 1 g
F
P
p
.57111 .53421 m .56009 .55159 L .5616 .54726 L 1 g
F
P
p
.56654 .52734 m .56434 .53939 L .56667 .5327 L 1 g
F
P
p
.002 w
.57527 .53563 m .56792 .53312 L p
.5779 .50013 L 1 g
F P
s
P
p
.002 w
.56792 .53312 m .56667 .5327 L p
.56768 .52975 L 1 g
F P
s
P
p
.5779 .50013 m .56792 .53312 L .56768 .52975 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56763 .52892 L p
1 g
F P
s
P
p
.56515 .50826 m .56763 .52892 L .56756 .52789 L 1 g
F
P
p
.002 w
.56526 .4997 m .5779 .50013 L .57074 .51936 L p
1 g
F P
s
P
p
.002 w
.57074 .51936 m .56756 .52789 L p
.56604 .50932 L 1 g
F P
s
P
p
.56526 .4997 m .57074 .51936 L .56604 .50932 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56604 .50932 L p
1 g
F P
s
P
p
.55661 .4905 m .56604 .50932 L .56261 .50197 L 1 g
F
P
p
.56515 .50826 m .56756 .52789 L .56686 .51936 L 1 g
F
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56763 .52892 m .56654 .52734 L p
.56667 .5327 L 1 g
F P
s
P
p
.002 w
.56667 .5327 m .56586 .53243 L .56756 .52789 L p
1 g
F P
s
P
p
.002 w
.56756 .52789 m .56861 .52506 L p
.56763 .52892 L 1 g
F P
s
P
p
.56763 .52892 m .56667 .5327 L .56756 .52789 L 1 g
F
P
p
.002 w
.56861 .52506 m .5779 .50013 L p
.56667 .5327 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56629 .50962 L p
1 g
F P
s
P
p
.002 w
.56629 .50962 m .56515 .50826 L p
.56705 .52059 L 1 g
F P
s
P
p
.56705 .52059 m .56854 .53025 L .56629 .50962 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.55661 .4905 m .56261 .50197 L .56148 .49957 L 1 g
F
P
p
.002 w
.55571 .48786 m .5553 .46396 L p
.56059 .49443 L 1 g
F P
s
P
p
.56059 .49443 m .56148 .49957 L .55746 .4914 L 1 g
F
P
p
.56059 .49443 m .55746 .4914 L .55571 .48786 L 1 g
F
P
p
.002 w
.55746 .4914 m .55661 .4905 L p
.56148 .49957 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.002 w
.55787 .49183 m .55746 .4914 L p
.56148 .49957 L 1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55574 .48974 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55574 .48974 m .55591 .49938 L p
.53847 .47486 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54225 .47664 L p
1 g
F P
s
P
p
.52214 .46667 m .54225 .47664 L .53283 .4722 L 1 g
F
P
p
.53413 .46875 m .54225 .47664 L .53847 .47486 L 1 g
F
P
p
.54225 .47664 m .55574 .48974 L .53847 .47486 L 1 g
F
P
p
.002 w
.52144 .47163 m .5283 .47007 L p
.55591 .49938 L 1 g
F P
s
P
p
.52214 .46667 m .53283 .4722 L .5283 .47007 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5283 .47007 m .52144 .47163 L .51975 .46688 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46724 L p
1 g
F P
s
P
p
.5 .4634 m .52249 .46724 L .51975 .46688 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51975 .46688 m .52144 .47163 L p
.49483 .46452 L 1 g
F P
s
P
p
.5 .46373 m .51975 .46688 L .49483 .46452 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46373 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46373 L .48675 .46577 L 1 g
F
P
p
.002 w
.47755 .46718 m .47786 .46667 L p
.48675 .46577 L 1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.52144 .47163 m .49022 .48747 L .47615 .46788 L p
1 g
F P
s
P
p
.48703 .46244 m .52144 .47163 L .47615 .46788 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47752 .46723 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47615 .46788 m .49022 .48747 L p
.44757 .48652 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44252 .49143 L p
1 g
F P
s
P
p
.43485 .50826 m .44252 .49143 L .43757 .5019 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4342 .50903 L p
1 g
F P
s
P
p
.43346 .52734 m .4342 .50903 L .43321 .52019 L 1 g
F
P
p
.002 w
.44285 .49111 m .46544 .50952 L p
.43408 .51039 L 1 g
F P
s
P
p
.42251 .51071 m .43513 .49855 L .4342 .50903 L 1 g
F
P
p
.42251 .51071 m .4342 .50903 L .43355 .51041 L 1 g
F
P
p
.002 w
.4342 .50903 m .43485 .50826 L p
.43757 .5019 L 1 g
F P
s
P
p
.43513 .49855 m .44285 .49111 L .43408 .51039 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.41738 .51941 m .42251 .51071 L p
.43408 .51039 L 1 g
F P
s
P
p
.43358 .51608 m .43408 .51039 L .46544 .50952 L 1 g
F
P
p
.41738 .51941 m .43408 .51039 L .43358 .51608 L 1 g
F
P
p
.002 w
.41195 .55282 m .41738 .51941 L .43263 .52671 L p
1 g
F P
s
P
p
.43346 .52734 m .43321 .52019 L .43263 .52671 L 1 g
F
P
p
.002 w
.43259 .52861 m .43346 .52734 L p
.43263 .52671 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43227 .5433 m .43259 .52861 L .43672 .54121 L 1 g
F
P
p
.41195 .55282 m .43216 .5273 L .43227 .5433 L 1 g
F
P
p
.43216 .5273 m .43263 .52671 L .43259 .52861 L 1 g
F
P
p
.43216 .5273 m .43259 .52861 L .43227 .5433 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43259 .52861 L p
1 g
F P
s
P
p
.002 w
.43259 .52861 m .43146 .53025 L p
.43619 .53961 L 1 g
F P
s
P
p
.43925 .54566 m .43259 .52861 L .43619 .53961 L 1 g
F
P
p
.002 w
.43858 .54692 m .43925 .54566 L p
.43619 .53961 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44528 .56085 m .41195 .55282 L p
.43517 .54194 L 1 g
F P
s
P
p
.45146 .56129 m .44399 .55479 L .44588 .55755 L 1 g
F
P
p
.45146 .56129 m .44588 .55755 L .44762 .55972 L 1 g
F
P
p
.002 w
.44887 .56128 m .44528 .56085 L p
.44782 .55998 L 1 g
F P
s
P
p
.002 w
.45073 .56325 m .45146 .56129 L p
.44762 .55972 L 1 g
F P
s
P
p
.002 w
.44528 .56085 m .44588 .55755 L p
.44782 .55998 L 1 g
F P
s
P
p
.44762 .55972 m .44727 .55958 L .44887 .56128 L 1 g
F
P
p
.44762 .55972 m .44887 .56128 L .45073 .56325 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44588 .55755 m .44528 .56085 L p
.43517 .54194 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.44995 .53501 m .4841 .54743 L p
.44782 .55998 L 1 g
F P
s
P
p
.002 w
.44588 .55755 m .44995 .53501 L p
.44782 .55998 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45073 .56325 L p
1 g
F P
s
P
p
.46319 .57647 m .45073 .56325 L .46738 .57371 L 1 g
F
P
p
.45154 .58415 m .44897 .56215 L .46319 .57647 L 1 g
F
P
p
.44897 .56215 m .44887 .56128 L .45073 .56325 L 1 g
F
P
p
.44897 .56215 m .45073 .56325 L .46319 .57647 L 1 g
F
P
p
.002 w
.46836 .57432 m .46872 .57265 L p
.46041 .56933 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48455 .58098 m .45154 .58415 L p
.46712 .57388 L 1 g
F P
s
P
p
.48921 .57862 m .47787 .57769 L .4843 .57997 L 1 g
F
P
p
.48921 .57862 m .4843 .57997 L .48499 .58013 L 1 g
F
P
p
.002 w
.48904 .58096 m .48921 .57862 L p
.48499 .58013 L 1 g
F P
s
P
p
.002 w
.48455 .58098 m .4843 .57997 L p
.48586 .58033 L 1 g
F P
s
P
p
.48499 .58013 m .48487 .58017 L .48662 .5805 L 1 g
F
P
p
.48499 .58013 m .48662 .5805 L .48904 .58096 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58096 L p
1 g
F P
s
P
p
.50603 .5842 m .48904 .58096 L .51005 .58064 L 1 g
F
P
p
.49533 .59367 m .48662 .5805 L .50603 .5842 L 1 g
F
P
p
.002 w
.48904 .58096 m .48889 .583 L p
.4999 .5808 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58096 L .4999 .5808 L 1 g
F
P
p
.002 w
.48662 .5805 m .51845 .57322 L p
.51005 .58064 L 1 g
F P
s
P
p
.48904 .58096 m .48662 .5805 L .51005 .58064 L 1 g
F
P
p
.002 w
.51662 .56508 m .51845 .57322 L .48662 .5805 L p
1 g
F P
s
P
p
.002 w
.48662 .5805 m .48455 .58098 L p
.48586 .58033 L 1 g
F P
s
P
p
.48586 .58033 m .51662 .56508 L .48662 .5805 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.4843 .57997 m .48455 .58098 L p
.46712 .57388 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.48059 .565 m .51662 .56508 L p
.48586 .58033 L 1 g
F P
s
P
p
.002 w
.4843 .57997 m .48059 .565 L p
.48586 .58033 L 1 g
F P
s
P
p
.48499 .58013 m .4843 .57997 L .48487 .58017 L 1 g
F
P
p
.002 w
.49533 .59367 m .48455 .58098 L .48662 .5805 L p
1 g
F P
s
P
p
.002 w
.48899 .58163 m .48904 .58096 L p
.48487 .58017 L 1 g
F P
s
P
p
.002 w
.48059 .565 m .4843 .57997 L p
.46712 .57388 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58163 L p
1 g
F P
s
P
p
.47787 .57769 m .4678 .57686 L .48899 .58163 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46836 .57432 L p
1 g
F P
s
P
p
.46041 .56933 m .45002 .56518 L .46836 .57432 L 1 g
F
P
p
.002 w
.45073 .56325 m .45002 .56518 L p
.46041 .56933 L 1 g
F P
s
P
p
.46872 .57265 m .45073 .56325 L .46041 .56933 L 1 g
F
P
p
.002 w
.44887 .56128 m .48059 .565 L p
.46738 .57371 L 1 g
F P
s
P
p
.45073 .56325 m .44887 .56128 L .46738 .57371 L 1 g
F
P
p
.002 w
.4841 .54743 m .48059 .565 L .44887 .56128 L p
1 g
F P
s
P
p
.44782 .55998 m .4841 .54743 L .44887 .56128 L 1 g
F
P
p
.44762 .55972 m .44588 .55755 L .44727 .55958 L 1 g
F
P
p
.002 w
.45154 .58415 m .44528 .56085 L .44887 .56128 L p
1 g
F P
s
P
p
.002 w
.4504 .56415 m .45073 .56325 L p
.44727 .55958 L 1 g
F P
s
P
p
.002 w
.44995 .53501 m .44588 .55755 L p
.43517 .54194 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4504 .56415 L p
1 g
F P
s
P
p
.44399 .55479 m .43743 .5491 L .4504 .56415 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43858 .54692 L p
1 g
F P
s
P
p
.43619 .53961 m .43146 .53025 L .43858 .54692 L 1 g
F
P
p
.002 w
.43263 .52671 m .44995 .53501 L p
.43672 .54121 L 1 g
F P
s
P
p
.43259 .52861 m .43263 .52671 L .43672 .54121 L 1 g
F
P
p
.002 w
.43245 .52882 m .43259 .52861 L p
.43263 .52671 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.46544 .50952 m .44995 .53501 L .41738 .51941 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43245 .52882 L p
1 g
F P
s
P
p
.43321 .52019 m .43287 .51061 L .43245 .52882 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .4342 .50903 L p
1 g
F P
s
P
p
.43757 .5019 m .44166 .49233 L .4342 .50903 L 1 g
F
P
p
.43355 .51041 m .4342 .50903 L .43408 .51039 L 1 g
F
P
p
.002 w
.4342 .50903 m .43287 .51061 L p
.43321 .52019 L 1 g
F P
s
P
p
.002 w
.44252 .49143 m .44166 .49233 L p
.43757 .5019 L 1 g
F P
s
P
p
.002 w
.42251 .51071 m .43693 .48628 L .44272 .491 L p
1 g
F P
s
P
p
.002 w
.44272 .491 m .44285 .49111 L p
.44252 .49143 L 1 g
F P
s
P
p
.42251 .51071 m .44272 .491 L .44252 .49143 L 1 g
F
P
p
.44339 .4905 m .44937 .48477 L .44285 .49111 L 1 g
F
P
p
.002 w
.44249 .49146 m .44252 .49143 L p
.44285 .49111 L 1 g
F P
s
P
p
.002 w
.44252 .49143 m .44339 .4905 L p
.44285 .49111 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47656 L p
1 g
F P
s
P
p
.45782 .47656 m .47615 .46788 L .44757 .48652 L 1 g
F
P
p
.002 w
.45782 .47656 m .45698 .47747 L p
.44937 .48477 L 1 g
F P
s
P
p
.44339 .4905 m .45782 .47656 L .44937 .48477 L 1 g
F
P
p
.002 w
.43693 .48628 m .46875 .45756 L .47229 .4625 L p
1 g
F P
s
P
p
.45826 .47608 m .47752 .46723 L .466 .47268 L 1 g
F
P
p
.002 w
.45699 .47747 m .45826 .47608 L p
.47043 .47074 L 1 g
F P
s
P
p
.002 w
.47229 .4625 m .47615 .46788 L p
.45797 .47641 L 1 g
F P
s
P
p
.43693 .48628 m .47229 .4625 L .45797 .47641 L 1 g
F
P
p
.43725 .48629 m .45782 .47656 L .44757 .48652 L 1 g
F
P
p
.002 w
.49022 .48747 m .46544 .50952 L .43693 .48628 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44249 .49146 L p
1 g
F P
s
P
p
.44937 .48477 m .45698 .47747 L .44249 .49146 L 1 g
F
P
p
.002 w
.47752 .46723 m .47718 .46778 L p
.466 .47268 L 1 g
F P
s
P
p
.43693 .48628 m .47615 .46788 L .43725 .48629 L 1 g
F
P
p
.002 w
.47615 .46788 m .46875 .45756 L p
.48703 .46244 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45699 .47747 L p
1 g
F P
s
P
p
.47043 .47074 m .47718 .46778 L .45699 .47747 L 1 g
F
P
p
.002 w
.5 .46373 m .5 .46442 L p
.48675 .46577 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.46875 .45756 m .50136 .46352 L .47973 .46049 L 1 g
F
P
p
.5 .4634 m .51975 .46688 L .51011 .46534 L 1 g
F
P
p
.52249 .46724 m .5283 .47007 L .51975 .46688 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.50136 .46352 m .51975 .46688 L .5 .46373 L 1 g
F
P
p
.50136 .46352 m .5 .46373 L .47973 .46049 L 1 g
F
P
p
.47973 .46049 m .5 .46373 L .49483 .46452 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47755 .46718 L p
1 g
F P
s
P
p
.48675 .46577 m .5 .46442 L .47755 .46718 L 1 g
F
P
p
.51011 .46534 m .51975 .46688 L .5146 .46621 L 1 g
F
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46875 .45756 m .50911 .43697 L .51975 .46688 L p
1 g
F P
s
P
p
.002 w
.51975 .46688 m .51933 .46571 L p
.52249 .46724 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52282 .46778 L p
.5146 .46621 L 1 g
F P
s
P
p
.002 w
.52257 .46737 m .52249 .46724 L p
.5283 .47007 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52214 .46667 L p
.5283 .47007 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5553 .46396 m .5283 .47007 L p
.50911 .43697 L 1 g
F P
s
P
p
.002 w
.51933 .46571 m .50911 .43697 L p
.5283 .47007 L 1 g
F P
s
P
p
.002 w
.5283 .47007 m .53413 .46875 L p
.53847 .47486 L 1 g
F P
s
P
p
.5283 .47007 m .53847 .47486 L .55591 .49938 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52257 .46737 L p
1 g
F P
s
P
p
.53283 .4722 m .54302 .47747 L .52257 .46737 L 1 g
F
P
p
.002 w
.54225 .47664 m .54302 .47747 L p
.53283 .4722 L 1 g
F P
s
P
p
.54943 .48361 m .55574 .48974 L .5514 .48554 L 1 g
F
P
p
.54174 .47608 m .55574 .48974 L .54943 .48361 L 1 g
F
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56148 .49957 m .55591 .49938 L .55574 .48974 L p
1 g
F P
s
P
p
.002 w
.55574 .48974 m .55571 .48786 L p
.55746 .4914 L 1 g
F P
s
P
p
.55746 .4914 m .56148 .49957 L .55574 .48974 L 1 g
F
P
p
.002 w
.5779 .50013 m .56148 .49957 L p
.5553 .46396 L 1 g
F P
s
P
p
.002 w
.56148 .49957 m .56526 .4997 L p
.56541 .50797 L 1 g
F P
s
P
p
.002 w
.56756 .52789 m .56586 .53243 L p
.56526 .4997 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55787 .49183 L p
1 g
F P
s
P
p
.56261 .50197 m .56713 .51061 L .55787 .49183 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54265 .47707 L p
1 g
F P
s
P
p
.002 w
.54265 .47707 m .54174 .47608 L p
.5514 .48554 L 1 g
F P
s
P
p
.5514 .48554 m .55834 .49233 L .54265 .47707 L 1 g
F
P
p
.002 w
.53413 .46875 m .5553 .46396 L .55574 .48974 L p
1 g
F P
s
P
p
.002 w
.55746 .4914 m .55834 .49233 L p
.5514 .48554 L 1 g
F P
s
P
p
.002 w
.55591 .49938 m .56148 .49957 L p
.56586 .53243 L 1 g
F P
s
P
p
.56148 .49957 m .56541 .50797 L .56586 .53243 L 1 g
F
P
p
.002 w
.56604 .50932 m .56713 .51061 L p
.56261 .50197 L 1 g
F P
s
P
p
.56686 .51936 m .56756 .52789 L .56705 .52059 L 1 g
F
P
p
.002 w
.56763 .52892 m .56854 .53025 L p
.56705 .52059 L 1 g
F P
s
P
p
.002 w
.56786 .52927 m .56763 .52892 L p
.56667 .5327 L 1 g
F P
s
P
p
.56075 .54566 m .55134 .56124 L .55155 .561 L 1 g
F
P
p
.56075 .54566 m .55155 .561 L .5516 .56093 L 1 g
F
P
p
.56075 .54566 m .5516 .56094 L .55166 .56087 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.51855 .55621 m .52409 .54758 L .55164 .56088 L p
1 g
F P
s
P
p
.002 w
.55164 .56088 m .55204 .56107 L .55155 .561 L p
1 g
F P
s
P
p
.002 w
.55155 .561 m .51855 .55621 L p
.55164 .56088 L 1 g
F P
s
P
p
.5516 .56093 m .55155 .561 L .5516 .56094 L 1 g
F
P
p
.55166 .56087 m .5516 .56094 L .55164 .56089 L 1 g
F
P
p
.56075 .54566 m .55164 .56089 L .55171 .5608 L 1 g
F
P
p
.56075 .54566 m .55169 .56083 L .55178 .56072 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.52409 .54758 m .53266 .54017 L .55174 .56076 L p
1 g
F P
s
P
p
.002 w
.55174 .56076 m .55204 .56107 L .55164 .56088 L p
1 g
F P
s
P
p
.002 w
.55164 .56088 m .52409 .54758 L p
.55174 .56076 L 1 g
F P
s
P
p
.56075 .54566 m .55175 .56077 L .55185 .56063 L 1 g
F
P
p
.56075 .54566 m .55181 .5607 L .55448 .55704 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53266 .54017 m .54329 .53482 L .55188 .56059 L p
1 g
F P
s
P
p
.002 w
.55188 .56059 m .55204 .56107 L .55174 .56076 L p
1 g
F P
s
P
p
.002 w
.55174 .56076 m .53266 .54017 L p
.55188 .56059 L 1 g
F P
s
P
p
.55171 .5608 m .55164 .56089 L .55169 .56083 L 1 g
F
P
p
.55178 .56072 m .55169 .56083 L .55175 .56077 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54329 .53482 m .55479 .53214 L .55211 .56027 L p
1 g
F P
s
P
p
.002 w
.55211 .56027 m .55204 .56107 L .55188 .56059 L p
1 g
F P
s
P
p
.002 w
.55188 .56059 m .54329 .53482 L p
.55211 .56027 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55479 .53214 m .56586 .53243 L .55302 .55903 L p
1 g
F P
s
P
p
.002 w
.55302 .55903 m .55204 .56107 L .55211 .56027 L p
1 g
F P
s
P
p
.002 w
.55211 .56027 m .55479 .53214 L p
.55302 .55903 L 1 g
F P
s
P
p
.55185 .56063 m .55175 .56077 L .55181 .5607 L 1 g
F
P
p
.55448 .55704 m .55181 .5607 L .5536 .55862 L 1 g
F
P
p
.002 w
.55302 .55903 m .56586 .53243 L .56667 .5327 L p
1 g
F P
s
P
p
.002 w
.56667 .5327 m .57111 .53421 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.55972 .55266 m .55204 .56107 L p
.56009 .55159 L 1 g
F P
s
P
p
.002 w
.56431 .58034 m .55342 .5843 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.57381 .5741 m .56431 .58034 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.55342 .5843 m .54228 .58557 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.58094 .56623 m .57381 .5741 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.54228 .58557 m .53204 .58401 L .55083 .56245 L p
1 g
F P
s
P
p
.002 w
.55083 .56245 m .55204 .56107 L .55172 .56188 L p
1 g
F P
s
P
p
.002 w
.55172 .56188 m .54228 .58557 L p
.55083 .56245 L 1 g
F P
s
P
p
.002 w
.54408 .57021 m .53204 .58401 L p
.53095 .57502 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54934 .56343 L p
1 g
F P
s
P
p
.002 w
.54934 .56343 m .54854 .56129 L p
.53968 .56974 L 1 g
F P
s
P
p
.53968 .56974 m .5322 .57686 L .54934 .56343 L 1 g
F
P
p
.002 w
.58492 .55754 m .58094 .56623 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.5853 .54893 m .58492 .55754 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.58198 .54135 m .5853 .54893 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.57527 .53563 m .58198 .54135 L .55204 .56107 L closepath p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.56667 .5327 m .5616 .54726 L .55302 .55903 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56786 .52927 L p
1 g
F P
s
P
p
.56434 .53939 m .56257 .5491 L .56786 .52927 L 1 g
F
P
p
.002 w
.5616 .54726 m .56257 .5491 L p
.56434 .53939 L 1 g
F P
s
P
p
.5536 .55862 m .55181 .5607 L .5534 .55898 L 1 g
F
P
p
.55181 .5607 m .55134 .56124 L .5517 .56084 L 1 g
F
P
p
.55181 .5607 m .5517 .56084 L .5534 .55898 L 1 g
F
P
p
.54854 .56129 m .53173 .57473 L .54003 .5694 L 1 g
F
P
p
.002 w
.51662 .56508 m .51855 .55621 L .55155 .561 L p
1 g
F P
s
P
p
.002 w
.55155 .561 m .55204 .56107 L .55142 .56114 L p
1 g
F P
s
P
p
.002 w
.55142 .56114 m .51662 .56508 L p
.55155 .561 L 1 g
F P
s
P
p
.002 w
.51845 .57322 m .51662 .56508 L .55142 .56114 L p
1 g
F P
s
P
p
.002 w
.55142 .56114 m .55204 .56107 L .55122 .56137 L p
1 g
F P
s
P
p
.002 w
.55122 .56137 m .51845 .57322 L p
.55142 .56114 L 1 g
F P
s
P
p
.5534 .55898 m .55122 .56137 L .55335 .55907 L 1 g
F
P
p
.002 w
.55122 .56137 m .55204 .56107 L .55066 .56199 L p
1 g
F P
s
P
p
.55122 .56137 m .55066 .56199 L .55104 .56158 L 1 g
F
P
p
.55122 .56137 m .55104 .56158 L .55335 .55907 L 1 g
F
P
p
.002 w
.51845 .57322 m .55122 .56137 L p
.53095 .57502 L 1 g
F P
s
P
p
.002 w
.55066 .56199 m .53095 .57502 L p
.55122 .56137 L 1 g
F P
s
P
p
.002 w
.53095 .57502 m .55204 .56107 L .55083 .56245 L p
1 g
F P
s
P
p
.53173 .57473 m .53095 .57502 L .55083 .56245 L 1 g
F
P
p
.002 w
.54933 .56342 m .54998 .56518 L p
.55335 .55907 L 1 g
F P
s
P
p
.002 w
.53173 .57473 m .5322 .57686 L p
.54003 .5694 L 1 g
F P
s
P
p
.002 w
.52243 .57808 m .51845 .57322 L p
.53095 .57502 L 1 g
F P
s
P
p
.52311 .57784 m .52243 .57808 L .52288 .57798 L 1 g
F
P
p
.002 w
.53204 .58401 m .5238 .57975 L .53095 .57502 L p
1 g
F P
s
P
p
.002 w
.532 .57596 m .53173 .57473 L p
.52288 .57798 L 1 g
F P
s
P
p
.51005 .58064 m .51845 .57322 L .52122 .57835 L 1 g
F
P
p
.51094 .58063 m .52122 .57835 L .52236 .58046 L 1 g
F
P
p
.51005 .58064 m .52122 .57835 L .51094 .58063 L 1 g
F
P
p
.002 w
.51845 .57322 m .5238 .57975 L .52236 .58046 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .532 .57596 L p
1 g
F P
s
P
p
.51937 .57876 m .51111 .583 L .532 .57596 L 1 g
F
P
p
.002 w
.51094 .58063 m .51111 .583 L p
.51937 .57876 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58063 L p
1 g
F P
s
P
p
.4999 .5808 m .48889 .583 L .51094 .58063 L 1 g
F
P
p
.002 w
.387 .43577 m .36166 .48118 L .34037 .46003 L p
1 g
F P
s
P
p
.002 w
.34037 .46003 m .36738 .41044 L .387 .43577 L p
1 g
F P
s
P
p
.002 w
.41738 .51941 m .41195 .55282 L .38176 .54126 L p
1 g
F P
s
P
p
.002 w
.38176 .54126 m .38761 .50123 L .41738 .51941 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.59304 .30002 m .52903 .29474 L .52067 .27126 L p
1 g
F P
s
P
p
.002 w
.45234 .28545 m .52067 .27126 L .52903 .29474 L p
1 g
F P
s
P
p
.002 w
.52903 .29474 m .59304 .30002 L .59791 .32772 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.46157 .30891 m .39986 .34094 L .38992 .31795 L p
1 g
F P
s
P
p
.002 w
.38992 .31795 m .45234 .28545 L .46157 .30891 L p
1 g
F P
s
P
p
.002 w
.62938 .44279 m .65314 .4655 L .63343 .49266 L p
1 g
F P
s
P
p
.002 w
.65314 .4655 m .62938 .44279 L .64001 .41015 L p
1 g
F P
s
P
p
.002 w
.5999 .35924 m .64627 .37865 L .64001 .41015 L p
1 g
F P
s
P
p
.002 w
.64627 .37865 m .5999 .35924 L .59791 .32772 L p
1 g
F P
s
P
p
.002 w
.58492 .55754 m .5853 .54893 L .61567 .53336 L p
1 g
F P
s
P
p
.002 w
.60944 .51826 m .61567 .53336 L .5853 .54893 L p
1 g
F P
s
P
p
.002 w
.61567 .53336 m .60944 .51826 L .63343 .49266 L p
1 g
F P
s
P
p
.002 w
.41317 .36735 m .36738 .41044 L .3522 .3863 L p
1 g
F P
s
P
p
.002 w
.3522 .3863 m .39986 .34094 L .41317 .36735 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.52903 .29474 m .46157 .30891 L .45234 .28545 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.41046 .46138 m .38761 .50123 L .36166 .48118 L p
1 g
F P
s
P
p
.002 w
.36166 .48118 m .387 .43577 L .41046 .46138 L p
1 g
F P
s
P
p
.002 w
.61468 .47538 m .63343 .49266 L .60944 .51826 L p
1 g
F P
s
P
p
.002 w
.63343 .49266 m .61468 .47538 L .62938 .44279 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.5853 .54893 m .58198 .54135 L .60944 .51826 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.53673 .32307 m .59791 .32772 L .5999 .35924 L p
1 g
F P
s
P
p
.002 w
.59791 .32772 m .53673 .32307 L .52903 .29474 L p
1 g
F P
s
P
p
.002 w
.59885 .39352 m .64001 .41015 L .62938 .44279 L p
1 g
F P
s
P
p
.002 w
.64001 .41015 m .59885 .39352 L .5999 .35924 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59642 .50671 m .60944 .51826 L .58198 .54135 L p
1 g
F P
s
P
p
.002 w
.60944 .51826 m .59642 .50671 L .61468 .47538 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.004 w
.55365 .56512 m
.55366 .56516 L
s
P
p
.002 w
.46157 .30891 m .52903 .29474 L .53673 .32307 L p
1 g
F P
s
P
p
.002 w
.58198 .54135 m .57527 .53563 L .59642 .50671 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51855 .55621 m .51662 .56508 L .48059 .565 L p
1 g
F P
s
P
p
.002 w
.48059 .565 m .4841 .54743 L .51855 .55621 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.47225 .3368 m .41317 .36735 L .39986 .34094 L p
1 g
F P
s
P
p
.002 w
.39986 .34094 m .46157 .30891 L .47225 .3368 L p
1 g
F P
s
P
p
.002 w
.42948 .39631 m .387 .43577 L .36738 .41044 L p
1 g
F P
s
P
p
.002 w
.36738 .41044 m .41317 .36735 L .42948 .39631 L p
1 g
F P
s
P
p
.002 w
.43693 .48628 m .41738 .51941 L .38761 .50123 L p
1 g
F P
s
P
p
.002 w
.38761 .50123 m .41046 .46138 L .43693 .48628 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59473 .42934 m .62938 .44279 L .61468 .47538 L p
1 g
F P
s
P
p
.002 w
.62938 .44279 m .59473 .42934 L .59885 .39352 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5779 .50013 m .59642 .50671 L .57527 .53563 L p
1 g
F P
s
P
p
.002 w
.53673 .32307 m .47225 .3368 L .46157 .30891 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.52409 .54758 m .51855 .55621 L .4841 .54743 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58766 .46533 m .61468 .47538 L .59642 .50671 L p
1 g
F P
s
P
p
.002 w
.61468 .47538 m .58766 .46533 L .59473 .42934 L p
1 g
F P
s
P
p
.002 w
.59642 .50671 m .5779 .50013 L .58766 .46533 L p
1 g
F P
s
P
p
.002 w
.54347 .35538 m .5999 .35924 L .59885 .39352 L p
1 g
F P
s
P
p
.002 w
.5999 .35924 m .54347 .35538 L .53673 .32307 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.56586 .53243 m .55479 .53214 L .55591 .49938 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53266 .54017 m .52409 .54758 L .49487 .53021 L p
1 g
F P
s
P
p
.002 w
.4841 .54743 m .49487 .53021 L .52409 .54758 L p
1 g
F P
s
P
p
.002 w
.49487 .53021 m .4841 .54743 L .44995 .53501 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44995 .53501 m .46544 .50952 L .49487 .53021 L p
1 g
F P
s
P
p
.002 w
.55479 .53214 m .54329 .53482 L .53297 .50465 L p
1 g
F P
s
P
p
.002 w
.53297 .50465 m .55591 .49938 L .55479 .53214 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54329 .53482 m .53266 .54017 L .5118 .51535 L p
1 g
F P
s
P
p
.002 w
.49487 .53021 m .5118 .51535 L .53266 .54017 L p
1 g
F P
s
P
p
.002 w
.47225 .3368 m .53673 .32307 L .54347 .35538 L p
1 g
F P
s
P
p
.002 w
.44824 .42677 m .41046 .46138 L .387 .43577 L p
1 g
F P
s
P
p
.004 w
.44518 .42957 m
.5 .43051 L
s
P
p
.002 w
.387 .43577 m .42948 .39631 L .44824 .42677 L p
1 g
F P
s
P
p
.004 w
.34986 .42792 m
.39147 .42864 L
s
P
p
.004 w
.39147 .42864 m
.40708 .42891 L
s
P
p
.004 w
.40708 .42891 m
.40784 .42892 L
s
P
p
.002 w
.5118 .51535 m .53297 .50465 L .54329 .53482 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.48403 .36822 m .42948 .39631 L .41317 .36735 L p
1 g
F P
s
P
p
.002 w
.41317 .36735 m .47225 .3368 L .48403 .36822 L p
1 g
F P
s
P
p
.002 w
.54896 .39053 m .59885 .39352 L .59473 .42934 L p
1 g
F P
s
P
p
.002 w
.59885 .39352 m .54896 .39053 L .54347 .35538 L p
1 g
F P
s
P
p
.002 w
.5553 .46396 m .58766 .46533 L .5779 .50013 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5118 .51535 m .49487 .53021 L .46544 .50952 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54347 .35538 m .48403 .36822 L .47225 .3368 L p
1 g
F P
s
P
p
.002 w
.55296 .4272 m .59473 .42934 L .58766 .46533 L p
1 g
F P
s
P
p
.002 w
.59473 .42934 m .55296 .4272 L .54896 .39053 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.46875 .45756 m .43693 .48628 L .41046 .46138 L p
1 g
F P
s
P
p
.002 w
.41046 .46138 m .44824 .42677 L .46875 .45756 L p
1 g
F P
s
P
p
.002 w
.58766 .46533 m .5553 .46396 L .55296 .4272 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.55591 .49938 m .53297 .50465 L .52144 .47163 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.48403 .36822 m .54347 .35538 L .54896 .39053 L p
1 g
F P
s
P
p
.002 w
.46544 .50952 m .49022 .48747 L .5118 .51535 L p
1 g
F P
s
P
p
.002 w
.53297 .50465 m .5118 .51535 L .49022 .48747 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49022 .48747 m .52144 .47163 L .53297 .50465 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49648 .40205 m .44824 .42677 L .42948 .39631 L p
1 g
F P
s
P
p
.002 w
.42948 .39631 m .48403 .36822 L .49648 .40205 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50911 .43697 m .55296 .4272 L .5553 .46396 L p
1 g
F P
s
P
p
.002 w
.54896 .39053 m .49648 .40205 L .48403 .36822 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.49648 .40205 m .54896 .39053 L .55296 .4272 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.55296 .4272 m .50911 .43697 L .49648 .40205 L p
1 g
F P
s
P
p
.002 w
.50911 .43697 m .46875 .45756 L .44824 .42677 L p
1 g
F P
s
P
p
.002 w
.44824 .42677 m .49648 .40205 L .50911 .43697 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.56971 .6054 m
.57339 .61465 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .34986 .42792 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58267 .63793 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.200775)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.200775)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4811 .47114 m .52843 .46417 L .52138 .43667 L p
1 g
F P
s
P
p
.002 w
.52138 .43667 m .47991 .44278 L .4811 .47114 L p
1 g
F P
s
P
p
.002 w
.55959 .42113 m .52138 .43667 L .52843 .46417 L p
1 g
F P
s
P
p
.002 w
.47991 .44278 m .52138 .43667 L .51383 .4091 L p
1 g
F P
s
P
p
.002 w
.52138 .43667 m .55959 .42113 L .54567 .39599 L p
1 g
F P
s
P
p
.002 w
.54567 .39599 m .51383 .4091 L .52138 .43667 L p
1 g
F P
s
P
p
.002 w
.43426 .46691 m .4811 .47114 L .47991 .44278 L p
1 g
F P
s
P
p
.002 w
.47991 .44278 m .43889 .43889 L .43426 .46691 L p
1 g
F P
s
P
p
.002 w
.43889 .43889 m .47991 .44278 L .4792 .41419 L p
1 g
F P
s
P
p
.002 w
.51383 .4091 m .4792 .41419 L .47991 .44278 L p
1 g
F P
s
P
p
.002 w
.4792 .41419 m .51383 .4091 L .50592 .38194 L p
1 g
F P
s
P
p
.002 w
.51383 .4091 m .54567 .39599 L .53061 .37165 L p
1 g
F P
s
P
p
.002 w
.53061 .37165 m .50592 .38194 L .51383 .4091 L p
1 g
F P
s
P
p
.002 w
.4792 .41419 m .44498 .4108 L .43889 .43889 L p
1 g
F P
s
P
p
.002 w
.44498 .4108 m .4792 .41419 L .47899 .3859 L p
1 g
F P
s
P
p
.002 w
.50592 .38194 m .47899 .3859 L .4792 .41419 L p
1 g
F P
s
P
p
.002 w
.48277 .49876 m .53486 .49109 L .52843 .46417 L p
1 g
F P
s
P
p
.002 w
.52843 .46417 m .4811 .47114 L .48277 .49876 L p
1 g
F P
s
P
p
.002 w
.57213 .44662 m .52843 .46417 L .53486 .49109 L p
1 g
F P
s
P
p
.002 w
.52843 .46417 m .57213 .44662 L .55959 .42113 L p
1 g
F P
s
P
p
.002 w
.4312 .49434 m .48277 .49876 L .4811 .47114 L p
1 g
F P
s
P
p
.002 w
.4811 .47114 m .43426 .46691 L .4312 .49434 L p
1 g
F P
s
P
p
.002 w
.47899 .3859 m .50592 .38194 L .49778 .35569 L p
1 g
F P
s
P
p
.002 w
.50592 .38194 m .53061 .37165 L .5147 .34856 L p
1 g
F P
s
P
p
.002 w
.5147 .34856 m .49778 .35569 L .50592 .38194 L p
1 g
F P
s
P
p
.002 w
.47899 .3859 m .45241 .38314 L .44498 .4108 L p
1 g
F P
s
P
p
.002 w
.45241 .38314 m .47899 .3859 L .47929 .35841 L p
1 g
F P
s
P
p
.002 w
.49778 .35569 m .47929 .35841 L .47899 .3859 L p
1 g
F P
s
P
p
.002 w
.57165 .37598 m .54567 .39599 L .55959 .42113 L p
1 g
F P
s
P
p
.002 w
.54567 .39599 m .57165 .37598 L .55063 .35595 L p
1 g
F P
s
P
p
.002 w
.55063 .35595 m .53061 .37165 L .54567 .39599 L p
1 g
F P
s
P
p
.002 w
.4021 .42519 m .43889 .43889 L .44498 .4108 L p
1 g
F P
s
P
p
.002 w
.44498 .4108 m .41442 .3991 L .4021 .42519 L p
1 g
F P
s
P
p
.002 w
.41442 .3991 m .44498 .4108 L .45241 .38314 L p
1 g
F P
s
P
p
.002 w
.59097 .39741 m .55959 .42113 L .57213 .44662 L p
1 g
F P
s
P
p
.002 w
.55959 .42113 m .59097 .39741 L .57165 .37598 L p
1 g
F P
s
P
p
.002 w
.39211 .45163 m .43426 .46691 L .43889 .43889 L p
1 g
F P
s
P
p
.002 w
.43889 .43889 m .4021 .42519 L .39211 .45163 L p
1 g
F P
s
P
p
.002 w
.53061 .37165 m .55063 .35595 L .52831 .3377 L p
1 g
F P
s
P
p
.002 w
.52831 .3377 m .5147 .34856 L .53061 .37165 L p
1 g
F P
s
P
p
.002 w
.45241 .38314 m .42879 .37386 L .41442 .3991 L p
1 g
F P
s
P
p
.002 w
.42879 .37386 m .45241 .38314 L .46106 .35644 L p
1 g
F P
s
P
p
.002 w
.47929 .35841 m .46106 .35644 L .45241 .38314 L p
1 g
F P
s
P
p
.002 w
.48489 .52512 m .54052 .51692 L .53486 .49109 L p
1 g
F P
s
P
p
.002 w
.53486 .49109 m .48277 .49876 L .48489 .52512 L p
1 g
F P
s
P
p
.002 w
.58302 .47197 m .53486 .49109 L .54052 .51692 L p
1 g
F P
s
P
p
.002 w
.53486 .49109 m .58302 .47197 L .57213 .44662 L p
1 g
F P
s
P
p
.002 w
.4298 .52062 m .48489 .52512 L .48277 .49876 L p
1 g
F P
s
P
p
.002 w
.48277 .49876 m .4312 .49434 L .4298 .52062 L p
1 g
F P
s
P
p
.002 w
.6082 .41983 m .57213 .44662 L .58302 .47197 L p
1 g
F P
s
P
p
.002 w
.57213 .44662 m .6082 .41983 L .59097 .39741 L p
1 g
F P
s
P
p
.002 w
.47929 .35841 m .49778 .35569 L .48957 .33086 L p
1 g
F P
s
P
p
.002 w
.49778 .35569 m .5147 .34856 L .4982 .32718 L p
1 g
F P
s
P
p
.002 w
.4982 .32718 m .48957 .33086 L .49778 .35569 L p
1 g
F P
s
P
p
.002 w
.46106 .35644 m .47929 .35841 L .4801 .33225 L p
1 g
F P
s
P
p
.002 w
.48957 .33086 m .4801 .33225 L .47929 .35841 L p
1 g
F P
s
P
p
.002 w
.38467 .47791 m .4312 .49434 L .43426 .46691 L p
1 g
F P
s
P
p
.002 w
.43426 .46691 m .39211 .45163 L .38467 .47791 L p
1 g
F P
s
P
p
.002 w
.5147 .34856 m .52831 .3377 L .50509 .32159 L p
1 g
F P
s
P
p
.002 w
.50509 .32159 m .4982 .32718 L .5147 .34856 L p
1 g
F P
s
P
p
.002 w
.46106 .35644 m .44495 .34994 L .42879 .37386 L p
1 g
F P
s
P
p
.002 w
.44495 .34994 m .46106 .35644 L .47079 .3312 L p
1 g
F P
s
P
p
.002 w
.4801 .33225 m .47079 .3312 L .46106 .35644 L p
1 g
F P
s
P
p
.002 w
.58908 .35083 m .57165 .37598 L .59097 .39741 L p
1 g
F P
s
P
p
.002 w
.57165 .37598 m .58908 .35083 L .56387 .3363 L p
1 g
F P
s
P
p
.002 w
.56387 .3363 m .55063 .35595 L .57165 .37598 L p
1 g
F P
s
P
p
.002 w
.55063 .35595 m .56387 .3363 L .53716 .32417 L p
1 g
F P
s
P
p
.002 w
.53716 .32417 m .52831 .3377 L .55063 .35595 L p
1 g
F P
s
P
p
.002 w
.39061 .38 m .41442 .3991 L .42879 .37386 L p
1 g
F P
s
P
p
.002 w
.42879 .37386 m .41056 .35883 L .39061 .38 L p
1 g
F P
s
P
p
.002 w
.41056 .35883 m .42879 .37386 L .44495 .34994 L p
1 g
F P
s
P
p
.002 w
.37322 .40262 m .4021 .42519 L .41442 .3991 L p
1 g
F P
s
P
p
.002 w
.41442 .3991 m .39061 .38 L .37322 .40262 L p
1 g
F P
s
P
p
.002 w
.54052 .51692 m .59204 .49671 L .58302 .47197 L p
1 g
F P
s
P
p
.002 w
.62297 .44282 m .58302 .47197 L .59204 .49671 L p
1 g
F P
s
P
p
.002 w
.58302 .47197 m .62297 .44282 L .6082 .41983 L p
1 g
F P
s
P
p
.002 w
.37999 .50348 m .4298 .52062 L .4312 .49434 L p
1 g
F P
s
P
p
.002 w
.4312 .49434 m .38467 .47791 L .37999 .50348 L p
1 g
F P
s
P
p
.002 w
.48743 .54969 m .54529 .54115 L .54052 .51692 L p
1 g
F P
s
P
p
.002 w
.54052 .51692 m .48489 .52512 L .48743 .54969 L p
1 g
F P
s
P
p
.002 w
.59204 .49671 m .54052 .51692 L .54529 .54115 L p
1 g
F P
s
P
p
.002 w
.43012 .54523 m .48743 .54969 L .48489 .52512 L p
1 g
F P
s
P
p
.002 w
.48489 .52512 m .4298 .52062 L .43012 .54523 L p
1 g
F P
s
P
p
.002 w
.61229 .36747 m .59097 .39741 L .6082 .41983 L p
1 g
F P
s
P
p
.002 w
.59097 .39741 m .61229 .36747 L .58908 .35083 L p
1 g
F P
s
P
p
.002 w
.52831 .3377 m .53716 .32417 L .5095 .31465 L p
1 g
F P
s
P
p
.002 w
.5095 .31465 m .50509 .32159 L .52831 .3377 L p
1 g
F P
s
P
p
.002 w
.44495 .34994 m .43265 .33952 L .41056 .35883 L p
1 g
F P
s
P
p
.002 w
.43265 .33952 m .44495 .34994 L .46261 .32782 L p
1 g
F P
s
P
p
.002 w
.47079 .3312 m .46261 .32782 L .44495 .34994 L p
1 g
F P
s
P
p
.002 w
.35878 .42625 m .39211 .45163 L .4021 .42519 L p
1 g
F P
s
P
p
.002 w
.4021 .42519 m .37322 .40262 L .35878 .42625 L p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .4801 .33225 L .48957 .33086 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .48957 .33086 L .4982 .32718 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .47079 .3312 L .4801 .33225 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .4982 .32718 L .50509 .32159 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .46261 .32782 L .47079 .3312 L closepath p
1 g
F P
s
P
p
.002 w
.63299 .38592 m .6082 .41983 L .62297 .44282 L p
1 g
F P
s
P
p
.002 w
.6082 .41983 m .63299 .38592 L .61229 .36747 L p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .50509 .32159 L .5095 .31465 L closepath p
1 g
F P
s
P
p
.002 w
.46261 .32782 m .45642 .32245 L .43265 .33952 L p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .45642 .32245 L .46261 .32782 L closepath p
1 g
F P
s
P
p
.002 w
.34767 .45043 m .38467 .47791 L .39211 .45163 L p
1 g
F P
s
P
p
.002 w
.39211 .45163 m .35878 .42625 L .34767 .45043 L p
1 g
F P
s
P
p
.002 w
.54024 .30932 m .53716 .32417 L .56387 .3363 L p
1 g
F P
s
P
p
.002 w
.53716 .32417 m .54024 .30932 L .51094 .3071 L p
1 g
F P
s
P
p
.002 w
.51094 .3071 m .5095 .31465 L .53716 .32417 L p
1 g
F P
s
P
p
.002 w
.39977 .33941 m .41056 .35883 L .43265 .33952 L p
1 g
F P
s
P
p
.002 w
.43265 .33952 m .42551 .32617 L .39977 .33941 L p
1 g
F P
s
P
p
.002 w
.42551 .32617 m .43265 .33952 L .45642 .32245 L p
1 g
F P
s
P
p
.002 w
.54529 .54115 m .59894 .52034 L .59204 .49671 L p
1 g
F P
s
P
p
.002 w
.63492 .46593 m .59204 .49671 L .59894 .52034 L p
1 g
F P
s
P
p
.002 w
.59204 .49671 m .63492 .46593 L .62297 .44282 L p
1 g
F P
s
P
p
.002 w
.56874 .3146 m .56387 .3363 L .58908 .35083 L p
1 g
F P
s
P
p
.002 w
.56387 .3363 m .56874 .3146 L .54024 .30932 L p
1 g
F P
s
P
p
.002 w
.37826 .52781 m .43012 .54523 L .4298 .52062 L p
1 g
F P
s
P
p
.002 w
.4298 .52062 m .37999 .50348 L .37826 .52781 L p
1 g
F P
s
P
p
.002 w
.37626 .35512 m .39061 .38 L .41056 .35883 L p
1 g
F P
s
P
p
.002 w
.41056 .35883 m .39977 .33941 L .37626 .35512 L p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .5095 .31465 L .51094 .3071 L closepath p
1 g
F P
s
P
p
.002 w
.45642 .32245 m .45292 .31562 L .42551 .32617 L p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .45292 .31562 L .45642 .32245 L closepath p
1 g
F P
s
P
p
.002 w
.59583 .32287 m .58908 .35083 L .61229 .36747 L p
1 g
F P
s
P
p
.002 w
.58908 .35083 m .59583 .32287 L .56874 .3146 L p
1 g
F P
s
P
p
.002 w
.49035 .57189 m .54905 .56323 L .54529 .54115 L p
1 g
F P
s
P
p
.002 w
.54529 .54115 m .48743 .54969 L .49035 .57189 L p
1 g
F P
s
P
p
.002 w
.59894 .52034 m .54529 .54115 L .54905 .56323 L p
1 g
F P
s
P
p
.002 w
.43223 .56757 m .49035 .57189 L .48743 .54969 L p
1 g
F P
s
P
p
.002 w
.48743 .54969 m .43012 .54523 L .43223 .56757 L p
1 g
F P
s
P
p
.002 w
.35552 .373 m .37322 .40262 L .39061 .38 L p
1 g
F P
s
P
p
.002 w
.39061 .38 m .37626 .35512 L .35552 .373 L p
1 g
F P
s
P
p
.002 w
.65067 .40585 m .62297 .44282 L .63492 .46593 L p
1 g
F P
s
P
p
.002 w
.62297 .44282 m .65067 .40585 L .63299 .38592 L p
1 g
F P
s
P
p
.002 w
.5092 .29975 m .51094 .3071 L .54024 .30932 L p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .51094 .3071 L .5092 .29975 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .46097 .29406 L .45529 .30061 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .45529 .30061 L .45252 .30807 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .45252 .30807 L .45292 .31562 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .5092 .29975 L .50445 .29339 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .50445 .29339 L .49716 .28875 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .49716 .28875 L .48813 .28636 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .48813 .28636 L .47836 .28651 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .47836 .28651 L .46896 .28918 L closepath p
1 g
F P
s
P
p
.002 w
.48143 .30796 m .46896 .28918 L .46097 .29406 L closepath p
1 g
F P
s
P
p
.002 w
.42446 .31126 m .42551 .32617 L .45292 .31562 L p
1 g
F P
s
P
p
.002 w
.45292 .31562 m .45252 .30807 L .42446 .31126 L p
1 g
F P
s
P
p
.002 w
.34025 .47464 m .37999 .50348 L .38467 .47791 L p
1 g
F P
s
P
p
.002 w
.38467 .47791 m .34767 .45043 L .34025 .47464 L p
1 g
F P
s
P
p
.002 w
.53706 .29474 m .54024 .30932 L .56874 .3146 L p
1 g
F P
s
P
p
.002 w
.54024 .30932 m .53706 .29474 L .5092 .29975 L p
1 g
F P
s
P
p
.002 w
.39787 .31754 m .39977 .33941 L .42551 .32617 L p
1 g
F P
s
P
p
.002 w
.42551 .32617 m .42446 .31126 L .39787 .31754 L p
1 g
F P
s
P
p
.002 w
.62091 .33401 m .61229 .36747 L .63299 .38592 L p
1 g
F P
s
P
p
.002 w
.61229 .36747 m .62091 .33401 L .59583 .32287 L p
1 g
F P
s
P
p
.002 w
.33809 .39273 m .35878 .42625 L .37322 .40262 L p
1 g
F P
s
P
p
.002 w
.37322 .40262 m .35552 .373 L .33809 .39273 L p
1 g
F P
s
P
p
.002 w
.50445 .29339 m .5092 .29975 L .53706 .29474 L p
1 g
F P
s
P
p
.002 w
.42975 .29641 m .42446 .31126 L .45252 .30807 L p
1 g
F P
s
P
p
.002 w
.45252 .30807 m .45529 .30061 L .42975 .29641 L p
1 g
F P
s
P
p
.002 w
.54905 .56323 m .60352 .54231 L .59894 .52034 L p
1 g
F P
s
P
p
.002 w
.64371 .48869 m .59894 .52034 L .60352 .54231 L p
1 g
F P
s
P
p
.002 w
.59894 .52034 m .64371 .48869 L .63492 .46593 L p
1 g
F P
s
P
p
.002 w
.37964 .55029 m .43223 .56757 L .43012 .54523 L p
1 g
F P
s
P
p
.002 w
.43012 .54523 m .37826 .52781 L .37964 .55029 L p
1 g
F P
s
P
p
.002 w
.56441 .29309 m .56874 .3146 L .59583 .32287 L p
1 g
F P
s
P
p
.002 w
.56874 .3146 m .56441 .29309 L .53706 .29474 L p
1 g
F P
s
P
p
.002 w
.37337 .32685 m .37626 .35512 L .39977 .33941 L p
1 g
F P
s
P
p
.002 w
.39977 .33941 m .39787 .31754 L .37337 .32685 L p
1 g
F P
s
P
p
.002 w
.53706 .29474 m .5278 .28202 L .50445 .29339 L p
1 g
F P
s
P
p
.002 w
.49716 .28875 m .50445 .29339 L .5278 .28202 L p
1 g
F P
s
P
p
.002 w
.44096 .28328 m .42975 .29641 L .45529 .30061 L p
1 g
F P
s
P
p
.002 w
.45529 .30061 m .46097 .29406 L .44096 .28328 L p
1 g
F P
s
P
p
.002 w
.66487 .42685 m .63492 .46593 L .64371 .48869 L p
1 g
F P
s
P
p
.002 w
.63492 .46593 m .66487 .42685 L .65067 .40585 L p
1 g
F P
s
P
p
.002 w
.64337 .34786 m .63299 .38592 L .65067 .40585 L p
1 g
F P
s
P
p
.002 w
.63299 .38592 m .64337 .34786 L .62091 .33401 L p
1 g
F P
s
P
p
.002 w
.3368 .49833 m .37826 .52781 L .37999 .50348 L p
1 g
F P
s
P
p
.002 w
.37999 .50348 m .34025 .47464 L .3368 .49833 L p
1 g
F P
s
P
p
.002 w
.5278 .28202 m .53706 .29474 L .56441 .29309 L p
1 g
F P
s
P
p
.002 w
.40541 .29556 m .39787 .31754 L .42446 .31126 L p
1 g
F P
s
P
p
.002 w
.42446 .31126 m .42975 .29641 L .40541 .29556 L p
1 g
F P
s
P
p
.002 w
.32448 .41391 m .34767 .45043 L .35878 .42625 L p
1 g
F P
s
P
p
.002 w
.35878 .42625 m .33809 .39273 L .32448 .41391 L p
1 g
F P
s
P
p
.002 w
.49361 .59118 m .55167 .58261 L .54905 .56323 L p
1 g
F P
s
P
p
.002 w
.54905 .56323 m .49035 .57189 L .49361 .59118 L p
1 g
F P
s
P
p
.002 w
.60352 .54231 m .54905 .56323 L .55167 .58261 L p
1 g
F P
s
P
p
.002 w
.43617 .58708 m .49361 .59118 L .49035 .57189 L p
1 g
F P
s
P
p
.002 w
.49035 .57189 m .43223 .56757 L .43617 .58708 L p
1 g
F P
s
P
p
.002 w
.5278 .28202 m .51338 .27266 L .49716 .28875 L p
1 g
F P
s
P
p
.002 w
.48813 .28636 m .49716 .28875 L .51338 .27266 L p
1 g
F P
s
P
p
.002 w
.45689 .27343 m .44096 .28328 L .46097 .29406 L p
1 g
F P
s
P
p
.002 w
.46097 .29406 m .46896 .28918 L .45689 .27343 L p
1 g
F P
s
P
p
.002 w
.59065 .29495 m .59583 .32287 L .62091 .33401 L p
1 g
F P
s
P
p
.002 w
.59583 .32287 m .59065 .29495 L .56441 .29309 L p
1 g
F P
s
P
p
.002 w
.51338 .27266 m .49534 .26779 L .48813 .28636 L p
1 g
F P
s
P
p
.002 w
.47836 .28651 m .48813 .28636 L .49534 .26779 L p
1 g
F P
s
P
p
.002 w
.47575 .26805 m .45689 .27343 L .46896 .28918 L p
1 g
F P
s
P
p
.002 w
.46896 .28918 m .47836 .28651 L .47575 .26805 L p
1 g
F P
s
P
p
.002 w
.35158 .33909 m .35552 .373 L .37626 .35512 L p
1 g
F P
s
P
p
.002 w
.37626 .35512 m .37337 .32685 L .35158 .33909 L p
1 g
F P
s
P
p
.002 w
.49534 .26779 m .47575 .26805 L .47836 .28651 L p
1 g
F P
s
P
p
.002 w
.56441 .29309 m .55101 .27419 L .5278 .28202 L p
1 g
F P
s
P
p
.002 w
.51338 .27266 m .5278 .28202 L .55101 .27419 L p
1 g
F P
s
P
p
.002 w
.42185 .27599 m .40541 .29556 L .42975 .29641 L p
1 g
F P
s
P
p
.002 w
.42975 .29641 m .44096 .28328 L .42185 .27599 L p
1 g
F P
s
P
p
.002 w
.55101 .27419 m .56441 .29309 L .59065 .29495 L p
1 g
F P
s
P
p
.002 w
.38285 .29821 m .37337 .32685 L .39787 .31754 L p
1 g
F P
s
P
p
.002 w
.39787 .31754 m .40541 .29556 L .38285 .29821 L p
1 g
F P
s
P
p
.002 w
.55167 .58261 m .60556 .56208 L .60352 .54231 L p
1 g
F P
s
P
p
.002 w
.64903 .51057 m .60352 .54231 L .60556 .56208 L p
1 g
F P
s
P
p
.002 w
.60352 .54231 m .64903 .51057 L .64371 .48869 L p
1 g
F P
s
P
p
.002 w
.66263 .36419 m .65067 .40585 L .66487 .42685 L p
1 g
F P
s
P
p
.002 w
.65067 .40585 m .66263 .36419 L .64337 .34786 L p
1 g
F P
s
P
p
.002 w
.38423 .57033 m .43617 .58708 L .43223 .56757 L p
1 g
F P
s
P
p
.002 w
.43223 .56757 m .37964 .55029 L .38423 .57033 L p
1 g
F P
s
P
p
.002 w
.31514 .4361 m .34025 .47464 L .34767 .45043 L p
1 g
F P
s
P
p
.002 w
.34767 .45043 m .32448 .41391 L .31514 .4361 L p
1 g
F P
s
P
p
.002 w
.61516 .30038 m .62091 .33401 L .64337 .34786 L p
1 g
F P
s
P
p
.002 w
.62091 .33401 m .61516 .30038 L .59065 .29495 L p
1 g
F P
s
P
p
.002 w
.67514 .4485 m .64371 .48869 L .64903 .51057 L p
1 g
F P
s
P
p
.002 w
.64371 .48869 m .67514 .4485 L .66487 .42685 L p
1 g
F P
s
P
p
.002 w
.33312 .35407 m .33809 .39273 L .35552 .373 L p
1 g
F P
s
P
p
.002 w
.35552 .373 m .35158 .33909 L .33312 .35407 L p
1 g
F P
s
P
p
.002 w
.33758 .52091 m .37964 .55029 L .37826 .52781 L p
1 g
F P
s
P
p
.002 w
.37826 .52781 m .3368 .49833 L .33758 .52091 L p
1 g
F P
s
P
p
.002 w
.55101 .27419 m .52975 .26016 L .51338 .27266 L p
1 g
F P
s
P
p
.002 w
.49534 .26779 m .51338 .27266 L .52975 .26016 L p
1 g
F P
s
P
p
.002 w
.44551 .26124 m .42185 .27599 L .44096 .28328 L p
1 g
F P
s
P
p
.002 w
.44096 .28328 m .45689 .27343 L .44551 .26124 L p
1 g
F P
s
P
p
.002 w
.49715 .60695 m .55303 .5987 L .55167 .58261 L p
1 g
F P
s
P
p
.002 w
.55167 .58261 m .49361 .59118 L .49715 .60695 L p
1 g
F P
s
P
p
.002 w
.60556 .56208 m .55167 .58261 L .55303 .5987 L p
1 g
F P
s
P
p
.002 w
.44192 .60315 m .49715 .60695 L .49361 .59118 L p
1 g
F P
s
P
p
.002 w
.49361 .59118 m .43617 .58708 L .44192 .60315 L p
1 g
F P
s
P
p
.002 w
.52975 .26016 m .50292 .25282 L .49534 .26779 L p
1 g
F P
s
P
p
.002 w
.47575 .26805 m .49534 .26779 L .50292 .25282 L p
1 g
F P
s
P
p
.002 w
.47367 .25318 m .44551 .26124 L .45689 .27343 L p
1 g
F P
s
P
p
.002 w
.45689 .27343 m .47575 .26805 L .47367 .25318 L p
1 g
F P
s
P
p
.002 w
.57353 .27023 m .59065 .29495 L .61516 .30038 L p
1 g
F P
s
P
p
.002 w
.59065 .29495 m .57353 .27023 L .55101 .27419 L p
1 g
F P
s
P
p
.002 w
.36269 .30446 m .35158 .33909 L .37337 .32685 L p
1 g
F P
s
P
p
.002 w
.37337 .32685 m .38285 .29821 L .36269 .30446 L p
1 g
F P
s
P
p
.002 w
.50292 .25282 m .47367 .25318 L .47575 .26805 L p
1 g
F P
s
P
p
.002 w
.52975 .26016 m .55101 .27419 L .57353 .27023 L p
1 g
F P
s
P
p
.002 w
.40416 .27254 m .38285 .29821 L .40541 .29556 L p
1 g
F P
s
P
p
.002 w
.40541 .29556 m .42185 .27599 L .40416 .27254 L p
1 g
F P
s
P
p
.002 w
.67809 .38271 m .66487 .42685 L .67514 .4485 L p
1 g
F P
s
P
p
.002 w
.66487 .42685 m .67809 .38271 L .66263 .36419 L p
1 g
F P
s
P
p
.002 w
.63728 .30939 m .64337 .34786 L .66263 .36419 L p
1 g
F P
s
P
p
.002 w
.64337 .34786 m .63728 .30939 L .61516 .30038 L p
1 g
F P
s
P
p
.002 w
.3105 .45879 m .3368 .49833 L .34025 .47464 L p
1 g
F P
s
P
p
.002 w
.34025 .47464 m .31514 .4361 L .3105 .45879 L p
1 g
F P
s
P
p
.002 w
.31859 .37154 m .32448 .41391 L .33809 .39273 L p
1 g
F P
s
P
p
.002 w
.33809 .39273 m .33312 .35407 L .31859 .37154 L p
1 g
F P
s
P
p
.002 w
.55303 .5987 m .60489 .5791 L .60556 .56208 L p
1 g
F P
s
P
p
.002 w
.6506 .53104 m .60556 .56208 L .60489 .5791 L p
1 g
F P
s
P
p
.002 w
.60556 .56208 m .6506 .53104 L .64903 .51057 L p
1 g
F P
s
P
p
.002 w
.39208 .58731 m .44192 .60315 L .43617 .58708 L p
1 g
F P
s
P
p
.002 w
.43617 .58708 m .38423 .57033 L .39208 .58731 L p
1 g
F P
s
P
p
.002 w
.68107 .4703 m .64903 .51057 L .6506 .53104 L p
1 g
F P
s
P
p
.002 w
.64903 .51057 m .68107 .4703 L .67514 .4485 L p
1 g
F P
s
P
p
.002 w
.34276 .54177 m .38423 .57033 L .37964 .55029 L p
1 g
F P
s
P
p
.002 w
.37964 .55029 m .33758 .52091 L .34276 .54177 L p
1 g
F P
s
P
p
.002 w
.57353 .27023 m .5459 .25175 L .52975 .26016 L p
1 g
F P
s
P
p
.002 w
.50292 .25282 m .52975 .26016 L .5459 .25175 L p
1 g
F P
s
P
p
.002 w
.43515 .25309 m .40416 .27254 L .42185 .27599 L p
1 g
F P
s
P
p
.002 w
.42185 .27599 m .44551 .26124 L .43515 .25309 L p
1 g
F P
s
P
p
.002 w
.59479 .27039 m .61516 .30038 L .63728 .30939 L p
1 g
F P
s
P
p
.002 w
.61516 .30038 m .59479 .27039 L .57353 .27023 L p
1 g
F P
s
P
p
.002 w
.34556 .31432 m .33312 .35407 L .35158 .33909 L p
1 g
F P
s
P
p
.002 w
.35158 .33909 m .36269 .30446 L .34556 .31432 L p
1 g
F P
s
P
p
.002 w
.65638 .32191 m .66263 .36419 L .67809 .38271 L p
1 g
F P
s
P
p
.002 w
.66263 .36419 m .65638 .32191 L .63728 .30939 L p
1 g
F P
s
P
p
.002 w
.68923 .40306 m .67514 .4485 L .68107 .4703 L p
1 g
F P
s
P
p
.002 w
.67514 .4485 m .68923 .40306 L .67809 .38271 L p
1 g
F P
s
P
p
.002 w
.30854 .39118 m .31514 .4361 L .32448 .41391 L p
1 g
F P
s
P
p
.002 w
.32448 .41391 m .31859 .37154 L .30854 .39118 L p
1 g
F P
s
P
p
.002 w
.5459 .25175 m .57353 .27023 L .59479 .27039 L p
1 g
F P
s
P
p
.002 w
.50092 .61865 m .55304 .61096 L .55303 .5987 L p
1 g
F P
s
P
p
.002 w
.55303 .5987 m .49715 .60695 L .50092 .61865 L p
1 g
F P
s
P
p
.002 w
.60489 .5791 m .55303 .5987 L .55304 .61096 L p
1 g
F P
s
P
p
.002 w
.44945 .6152 m .50092 .61865 L .49715 .60695 L p
1 g
F P
s
P
p
.002 w
.49715 .60695 m .44192 .60315 L .44945 .6152 L p
1 g
F P
s
P
p
.002 w
.38838 .27322 m .36269 .30446 L .38285 .29821 L p
1 g
F P
s
P
p
.002 w
.38285 .29821 m .40416 .27254 L .38838 .27322 L p
1 g
F P
s
P
p
.002 w
.31089 .48141 m .33758 .52091 L .3368 .49833 L p
1 g
F P
s
P
p
.002 w
.3368 .49833 m .3105 .45879 L .31089 .48141 L p
1 g
F P
s
P
p
.002 w
.5459 .25175 m .51073 .24201 L .50292 .25282 L p
1 g
F P
s
P
p
.002 w
.47367 .25318 m .50292 .25282 L .51073 .24201 L p
1 g
F P
s
P
p
.002 w
.47221 .24245 m .43515 .25309 L .44551 .26124 L p
1 g
F P
s
P
p
.002 w
.44551 .26124 m .47367 .25318 L .47221 .24245 L p
1 g
F P
s
P
p
.002 w
.51073 .24201 m .47221 .24245 L .47367 .25318 L p
1 g
F P
s
P
p
.002 w
.60489 .5791 m .64819 .54953 L .6506 .53104 L p
1 g
F P
s
P
p
.002 w
.6823 .49172 m .6506 .53104 L .64819 .54953 L p
1 g
F P
s
P
p
.002 w
.6506 .53104 m .6823 .49172 L .68107 .4703 L p
1 g
F P
s
P
p
.002 w
.35243 .56028 m .39208 .58731 L .38423 .57033 L p
1 g
F P
s
P
p
.002 w
.38423 .57033 m .34276 .54177 L .35243 .56028 L p
1 g
F P
s
P
p
.002 w
.55304 .61096 m .60138 .59277 L .60489 .5791 L p
1 g
F P
s
P
p
.002 w
.64819 .54953 m .60489 .5791 L .60138 .59277 L p
1 g
F P
s
P
p
.002 w
.40317 .60064 m .44945 .6152 L .44192 .60315 L p
1 g
F P
s
P
p
.002 w
.44192 .60315 m .39208 .58731 L .40317 .60064 L p
1 g
F P
s
P
p
.002 w
.61422 .27489 m .63728 .30939 L .65638 .32191 L p
1 g
F P
s
P
p
.002 w
.63728 .30939 m .61422 .27489 L .59479 .27039 L p
1 g
F P
s
P
p
.002 w
.33207 .32773 m .31859 .37154 L .33312 .35407 L p
1 g
F P
s
P
p
.002 w
.33312 .35407 m .34556 .31432 L .33207 .32773 L p
1 g
F P
s
P
p
.002 w
.67182 .33779 m .67809 .38271 L .68923 .40306 L p
1 g
F P
s
P
p
.002 w
.67809 .38271 m .67182 .33779 L .65638 .32191 L p
1 g
F P
s
P
p
.002 w
.59479 .27039 m .56141 .24784 L .5459 .25175 L p
1 g
F P
s
P
p
.002 w
.51073 .24201 m .5459 .25175 L .56141 .24784 L p
1 g
F P
s
P
p
.002 w
.42613 .24944 m .38838 .27322 L .40416 .27254 L p
1 g
F P
s
P
p
.002 w
.40416 .27254 m .43515 .25309 L .42613 .24944 L p
1 g
F P
s
P
p
.002 w
.30346 .41254 m .3105 .45879 L .31514 .4361 L p
1 g
F P
s
P
p
.002 w
.31514 .4361 m .30854 .39118 L .30346 .41254 L p
1 g
F P
s
P
p
.002 w
.69555 .42478 m .68107 .4703 L .6823 .49172 L p
1 g
F P
s
P
p
.002 w
.68107 .4703 m .69555 .42478 L .68923 .40306 L p
1 g
F P
s
P
p
.002 w
.31654 .50334 m .34276 .54177 L .33758 .52091 L p
1 g
F P
s
P
p
.002 w
.33758 .52091 m .31089 .48141 L .31654 .50334 L p
1 g
F P
s
P
p
.002 w
.56141 .24784 m .59479 .27039 L .61422 .27489 L p
1 g
F P
s
P
p
.002 w
.37506 .27826 m .34556 .31432 L .36269 .30446 L p
1 g
F P
s
P
p
.002 w
.36269 .30446 m .38838 .27322 L .37506 .27826 L p
1 g
F P
s
P
p
.002 w
.50481 .62572 m .5516 .61881 L .55304 .61096 L p
1 g
F P
s
P
p
.002 w
.55304 .61096 m .50092 .61865 L .50481 .62572 L p
1 g
F P
s
P
p
.002 w
.60138 .59277 m .55304 .61096 L .5516 .61881 L p
1 g
F P
s
P
p
.002 w
.45868 .62268 m .50481 .62572 L .50092 .61865 L p
1 g
F P
s
P
p
.002 w
.50092 .61865 m .44945 .6152 L .45868 .62268 L p
1 g
F P
s
P
p
.002 w
.56141 .24784 m .51856 .23589 L .51073 .24201 L p
1 g
F P
s
P
p
.002 w
.47221 .24245 m .51073 .24201 L .51856 .23589 L p
1 g
F P
s
P
p
.002 w
.47145 .2364 m .42613 .24944 L .43515 .25309 L p
1 g
F P
s
P
p
.002 w
.43515 .25309 m .47221 .24245 L .47145 .2364 L p
1 g
F P
s
P
p
.002 w
.60138 .59277 m .64165 .56545 L .64819 .54953 L p
1 g
F P
s
P
p
.002 w
.67859 .51218 m .64819 .54953 L .64165 .56545 L p
1 g
F P
s
P
p
.002 w
.64819 .54953 m .67859 .51218 L .6823 .49172 L p
1 g
F P
s
P
p
.002 w
.51856 .23589 m .47145 .2364 L .47221 .24245 L p
1 g
F P
s
P
p
.002 w
.36654 .5758 m .40317 .60064 L .39208 .58731 L p
1 g
F P
s
P
p
.002 w
.39208 .58731 m .35243 .56028 L .36654 .5758 L p
1 g
F P
s
P
p
.002 w
.63119 .28382 m .65638 .32191 L .67182 .33779 L p
1 g
F P
s
P
p
.002 w
.65638 .32191 m .63119 .28382 L .61422 .27489 L p
1 g
F P
s
P
p
.002 w
.32279 .3445 m .30854 .39118 L .31859 .37154 L p
1 g
F P
s
P
p
.002 w
.31859 .37154 m .33207 .32773 L .32279 .3445 L p
1 g
F P
s
P
p
.002 w
.68301 .35674 m .68923 .40306 L .69555 .42478 L p
1 g
F P
s
P
p
.002 w
.68923 .40306 m .68301 .35674 L .67182 .33779 L p
1 g
F P
s
P
p
.002 w
.5516 .61881 m .59495 .60256 L .60138 .59277 L p
1 g
F P
s
P
p
.002 w
.64165 .56545 m .60138 .59277 L .59495 .60256 L p
1 g
F P
s
P
p
.002 w
.41736 .60975 m .45868 .62268 L .44945 .6152 L p
1 g
F P
s
P
p
.002 w
.44945 .6152 m .40317 .60064 L .41736 .60975 L p
1 g
F P
s
P
p
.002 w
.30375 .43511 m .31089 .48141 L .3105 .45879 L p
1 g
F P
s
P
p
.002 w
.3105 .45879 m .30346 .41254 L .30375 .43511 L p
1 g
F P
s
P
p
.002 w
.69665 .44736 m .6823 .49172 L .67859 .51218 L p
1 g
F P
s
P
p
.002 w
.6823 .49172 m .69665 .44736 L .69555 .42478 L p
1 g
F P
s
P
p
.002 w
.32754 .52391 m .35243 .56028 L .34276 .54177 L p
1 g
F P
s
P
p
.002 w
.34276 .54177 m .31654 .50334 L .32754 .52391 L p
1 g
F P
s
P
p
.002 w
.61422 .27489 m .57585 .2488 L .56141 .24784 L p
1 g
F P
s
P
p
.002 w
.51856 .23589 m .56141 .24784 L .57585 .2488 L p
1 g
F P
s
P
p
.002 w
.41878 .25068 m .37506 .27826 L .38838 .27322 L p
1 g
F P
s
P
p
.002 w
.38838 .27322 m .42613 .24944 L .41878 .25068 L p
1 g
F P
s
P
p
.002 w
.57585 .2488 m .61422 .27489 L .63119 .28382 L p
1 g
F P
s
P
p
.002 w
.3647 .28777 m .33207 .32773 L .34556 .31432 L p
1 g
F P
s
P
p
.002 w
.34556 .31432 m .37506 .27826 L .3647 .28777 L p
1 g
F P
s
P
p
.002 w
.50874 .62767 m .54866 .62178 L .5516 .61881 L p
1 g
F P
s
P
p
.002 w
.5516 .61881 m .50481 .62572 L .50874 .62767 L p
1 g
F P
s
P
p
.002 w
.59495 .60256 m .5516 .61881 L .54866 .62178 L p
1 g
F P
s
P
p
.002 w
.67182 .33779 m .6451 .29717 L .63119 .28382 L p
1 g
F P
s
P
p
.002 w
.6451 .29717 m .67182 .33779 L .68301 .35674 L p
1 g
F P
s
P
p
.002 w
.46945 .62509 m .50874 .62767 L .50481 .62572 L p
1 g
F P
s
P
p
.002 w
.50481 .62572 m .45868 .62268 L .46945 .62509 L p
1 g
F P
s
P
p
.002 w
.31823 .36432 m .30346 .41254 L .30854 .39118 L p
1 g
F P
s
P
p
.002 w
.30854 .39118 m .32279 .3445 L .31823 .36432 L p
1 g
F P
s
P
p
.002 w
.57585 .2488 m .52622 .23492 L .51856 .23589 L p
1 g
F P
s
P
p
.002 w
.47145 .2364 m .51856 .23589 L .52622 .23492 L p
1 g
F P
s
P
p
.002 w
.47146 .23551 m .41878 .25068 L .42613 .24944 L p
1 g
F P
s
P
p
.002 w
.42613 .24944 m .47145 .2364 L .47146 .23551 L p
1 g
F P
s
P
p
.002 w
.69555 .42478 m .68942 .37838 L .68301 .35674 L p
1 g
F P
s
P
p
.002 w
.68942 .37838 m .69555 .42478 L .69665 .44736 L p
1 g
F P
s
P
p
.002 w
.59495 .60256 m .63092 .57822 L .64165 .56545 L p
1 g
F P
s
P
p
.002 w
.64165 .56545 m .66977 .53107 L .67859 .51218 L p
1 g
F P
s
P
p
.002 w
.66977 .53107 m .64165 .56545 L .63092 .57822 L p
1 g
F P
s
P
p
.004 w
.53159 .639 m
.53554 .6651 L
s
P
p
.002 w
.38491 .58772 m .41736 .60975 L .40317 .60064 L p
1 g
F P
s
P
p
.002 w
.40317 .60064 m .36654 .5758 L .38491 .58772 L p
1 g
F P
s
P
p
.002 w
.30966 .45827 m .31654 .50334 L .31089 .48141 L p
1 g
F P
s
P
p
.002 w
.31089 .48141 m .30375 .43511 L .30966 .45827 L p
1 g
F P
s
P
p
.002 w
.52622 .23492 m .47146 .23551 L .47145 .2364 L p
1 g
F P
s
P
p
.002 w
.67859 .51218 m .69225 .47018 L .69665 .44736 L p
1 g
F P
s
P
p
.002 w
.69225 .47018 m .67859 .51218 L .66977 .53107 L p
1 g
F P
s
P
p
.002 w
.34381 .54245 m .36654 .5758 L .35243 .56028 L p
1 g
F P
s
P
p
.002 w
.35243 .56028 m .32754 .52391 L .34381 .54245 L p
1 g
F P
s
P
p
.002 w
.54866 .62178 m .58559 .60794 L .59495 .60256 L p
1 g
F P
s
P
p
.002 w
.63092 .57822 m .59495 .60256 L .58559 .60794 L p
1 g
F P
s
P
p
.002 w
.43444 .61412 m .46945 .62509 L .45868 .62268 L p
1 g
F P
s
P
p
.002 w
.45868 .62268 m .41736 .60975 L .43444 .61412 L p
1 g
F P
s
P
p
.002 w
.63119 .28382 m .58873 .2549 L .57585 .2488 L p
1 g
F P
s
P
p
.002 w
.58873 .2549 m .63119 .28382 L .6451 .29717 L p
1 g
F P
s
P
p
.002 w
.35781 .30174 m .32279 .3445 L .33207 .32773 L p
1 g
F P
s
P
p
.002 w
.33207 .32773 m .3647 .28777 L .35781 .30174 L p
1 g
F P
s
P
p
.002 w
.52622 .23492 m .57585 .2488 L .58873 .2549 L p
1 g
F P
s
P
p
.002 w
.41341 .25708 m .3647 .28777 L .37506 .27826 L p
1 g
F P
s
P
p
.002 w
.37506 .27826 m .41878 .25068 L .41341 .25708 L p
1 g
F P
s
P
p
.002 w
.65538 .3148 m .68301 .35674 L .68942 .37838 L p
1 g
F P
s
P
p
.002 w
.68301 .35674 m .65538 .3148 L .6451 .29717 L p
1 g
F P
s
P
p
.002 w
.31877 .38675 m .30375 .43511 L .30346 .41254 L p
1 g
F P
s
P
p
.002 w
.30346 .41254 m .31823 .36432 L .31877 .38675 L p
1 g
F P
s
P
p
.002 w
.69063 .4022 m .69665 .44736 L .69225 .47018 L p
1 g
F P
s
P
p
.002 w
.69665 .44736 m .69063 .4022 L .68942 .37838 L p
1 g
F P
s
P
p
.002 w
.32126 .48132 m .32754 .52391 L .31654 .50334 L p
1 g
F P
s
P
p
.002 w
.31654 .50334 m .30966 .45827 L .32126 .48132 L p
1 g
F P
s
P
p
.002 w
.58559 .60794 m .61608 .58731 L .63092 .57822 L p
1 g
F P
s
P
p
.002 w
.65585 .54775 m .63092 .57822 L .61608 .58731 L p
1 g
F P
s
P
p
.002 w
.63092 .57822 m .65585 .54775 L .66977 .53107 L p
1 g
F P
s
P
p
.002 w
.4072 .59552 m .43444 .61412 L .41736 .60975 L p
1 g
F P
s
P
p
.002 w
.41736 .60975 m .38491 .58772 L .4072 .59552 L p
1 g
F P
s
P
p
.002 w
.5126 .62411 m .54421 .61944 L .54866 .62178 L p
1 g
F P
s
P
p
.002 w
.54866 .62178 m .50874 .62767 L .5126 .62411 L p
1 g
F P
s
P
p
.002 w
.58559 .60794 m .54866 .62178 L .54421 .61944 L p
1 g
F P
s
P
p
.002 w
.48155 .62205 m .5126 .62411 L .50874 .62767 L p
1 g
F P
s
P
p
.002 w
.50874 .62767 m .46945 .62509 L .48155 .62205 L p
1 g
F P
s
P
p
.002 w
.58873 .2549 m .53346 .23948 L .52622 .23492 L p
1 g
F P
s
P
p
.002 w
.47146 .23551 m .52622 .23492 L .53346 .23948 L p
1 g
F P
s
P
p
.002 w
.47228 .24016 m .41341 .25708 L .41878 .25068 L p
1 g
F P
s
P
p
.002 w
.41878 .25068 m .47146 .23551 L .47228 .24016 L p
1 g
F P
s
P
p
.002 w
.68222 .49257 m .66977 .53107 L .65585 .54775 L p
1 g
F P
s
P
p
.002 w
.66977 .53107 m .68222 .49257 L .69225 .47018 L p
1 g
F P
s
P
p
.002 w
.36507 .55829 m .38491 .58772 L .36654 .5758 L p
1 g
F P
s
P
p
.002 w
.36654 .5758 m .34381 .54245 L .36507 .55829 L p
1 g
F P
s
P
p
.002 w
.53346 .23948 m .47228 .24016 L .47146 .23551 L p
1 g
F P
s
P
p
.002 w
.59959 .26626 m .6451 .29717 L .65538 .3148 L p
1 g
F P
s
P
p
.002 w
.6451 .29717 m .59959 .26626 L .58873 .2549 L p
1 g
F P
s
P
p
.002 w
.54421 .61944 m .5734 .60848 L .58559 .60794 L p
1 g
F P
s
P
p
.002 w
.61608 .58731 m .58559 .60794 L .5734 .60848 L p
1 g
F P
s
P
p
.002 w
.35479 .32001 m .31823 .36432 L .32279 .3445 L p
1 g
F P
s
P
p
.002 w
.32279 .3445 m .35781 .30174 L .35479 .32001 L p
1 g
F P
s
P
p
.002 w
.45404 .61336 m .48155 .62205 L .46945 .62509 L p
1 g
F P
s
P
p
.002 w
.46945 .62509 m .43444 .61412 L .45404 .61336 L p
1 g
F P
s
P
p
.002 w
.53346 .23948 m .58873 .2549 L .59959 .26626 L p
1 g
F P
s
P
p
.002 w
.41033 .26879 m .35781 .30174 L .3647 .28777 L p
1 g
F P
s
P
p
.002 w
.3647 .28777 m .41341 .25708 L .41033 .26879 L p
1 g
F P
s
P
p
.002 w
.66152 .33638 m .68942 .37838 L .69063 .4022 L p
1 g
F P
s
P
p
.002 w
.68942 .37838 m .66152 .33638 L .65538 .3148 L p
1 g
F P
s
P
p
.002 w
.32466 .41117 m .30966 .45827 L .30375 .43511 L p
1 g
F P
s
P
p
.002 w
.30375 .43511 m .31877 .38675 L .32466 .41117 L p
1 g
F P
s
P
p
.002 w
.68636 .42757 m .69225 .47018 L .68222 .49257 L p
1 g
F P
s
P
p
.002 w
.69225 .47018 m .68636 .42757 L .69063 .4022 L p
1 g
F P
s
P
p
.002 w
.33843 .50351 m .34381 .54245 L .32754 .52391 L p
1 g
F P
s
P
p
.002 w
.32754 .52391 m .32126 .48132 L .33843 .50351 L p
1 g
F P
s
P
p
.002 w
.5734 .60848 m .59734 .59221 L .61608 .58731 L p
1 g
F P
s
P
p
.002 w
.63698 .56161 m .61608 .58731 L .59734 .59221 L p
1 g
F P
s
P
p
.002 w
.61608 .58731 m .63698 .56161 L .65585 .54775 L p
1 g
F P
s
P
p
.002 w
.66663 .51382 m .65585 .54775 L .63698 .56161 L p
1 g
F P
s
P
p
.002 w
.65585 .54775 m .66663 .51382 L .68222 .49257 L p
1 g
F P
s
P
p
.002 w
.43288 .59873 m .45404 .61336 L .43444 .61412 L p
1 g
F P
s
P
p
.002 w
.43444 .61412 m .4072 .59552 L .43288 .59873 L p
1 g
F P
s
P
p
.002 w
.39086 .57079 m .4072 .59552 L .38491 .58772 L p
1 g
F P
s
P
p
.002 w
.38491 .58772 m .36507 .55829 L .39086 .57079 L p
1 g
F P
s
P
p
.002 w
.51626 .61476 m .53828 .61151 L .54421 .61944 L p
1 g
F P
s
P
p
.002 w
.54421 .61944 m .5126 .62411 L .51626 .61476 L p
1 g
F P
s
P
p
.002 w
.5734 .60848 m .54421 .61944 L .53828 .61151 L p
1 g
F P
s
P
p
.002 w
.49467 .6133 m .51626 .61476 L .5126 .62411 L p
1 g
F P
s
P
p
.002 w
.5126 .62411 m .48155 .62205 L .49467 .6133 L p
1 g
F P
s
P
p
.002 w
.59959 .26626 m .54004 .24977 L .53346 .23948 L p
1 g
F P
s
P
p
.002 w
.47228 .24016 m .53346 .23948 L .54004 .24977 L p
1 g
F P
s
P
p
.002 w
.47395 .25056 m .41033 .26879 L .41341 .25708 L p
1 g
F P
s
P
p
.002 w
.41341 .25708 m .47228 .24016 L .47395 .25056 L p
1 g
F P
s
P
p
.002 w
.60797 .28285 m .65538 .3148 L .66152 .33638 L p
1 g
F P
s
P
p
.002 w
.65538 .3148 m .60797 .28285 L .59959 .26626 L p
1 g
F P
s
P
p
.002 w
.35597 .34222 m .31877 .38675 L .31823 .36432 L p
1 g
F P
s
P
p
.002 w
.31823 .36432 m .35479 .32001 L .35597 .34222 L p
1 g
F P
s
P
p
.002 w
.66312 .36141 m .69063 .4022 L .68636 .42757 L p
1 g
F P
s
P
p
.002 w
.69063 .4022 m .66312 .36141 L .66152 .33638 L p
1 g
F P
s
P
p
.002 w
.53828 .61151 m .55857 .60386 L .5734 .60848 L p
1 g
F P
s
P
p
.002 w
.59734 .59221 m .5734 .60848 L .55857 .60386 L p
1 g
F P
s
P
p
.002 w
.6765 .45372 m .68222 .49257 L .66663 .51382 L p
1 g
F P
s
P
p
.002 w
.68222 .49257 m .6765 .45372 L .68636 .42757 L p
1 g
F P
s
P
p
.002 w
.47568 .60722 m .49467 .6133 L .48155 .62205 L p
1 g
F P
s
P
p
.002 w
.48155 .62205 m .45404 .61336 L .47568 .60722 L p
1 g
F P
s
P
p
.002 w
.54004 .24977 m .47395 .25056 L .47228 .24016 L p
1 g
F P
s
P
p
.002 w
.33594 .43687 m .32126 .48132 L .30966 .45827 L p
1 g
F P
s
P
p
.002 w
.30966 .45827 m .32466 .41117 L .33594 .43687 L p
1 g
F P
s
P
p
.002 w
.36081 .52407 m .36507 .55829 L .34381 .54245 L p
1 g
F P
s
P
p
.002 w
.34381 .54245 m .33843 .50351 L .36081 .52407 L p
1 g
F P
s
P
p
.002 w
.54004 .24977 m .59959 .26626 L .60797 .28285 L p
1 g
F P
s
P
p
.002 w
.40978 .28576 m .35479 .32001 L .35781 .30174 L p
1 g
F P
s
P
p
.002 w
.35781 .30174 m .41033 .26879 L .40978 .28576 L p
1 g
F P
s
P
p
.002 w
.59734 .59221 m .61353 .57206 L .63698 .56161 L p
1 g
F P
s
P
p
.002 w
.64573 .53319 m .63698 .56161 L .61353 .57206 L p
1 g
F P
s
P
p
.002 w
.63698 .56161 m .64573 .53319 L .66663 .51382 L p
1 g
F P
s
P
p
.002 w
.42048 .57941 m .43288 .59873 L .4072 .59552 L p
1 g
F P
s
P
p
.002 w
.4072 .59552 m .39086 .57079 L .42048 .57941 L p
1 g
F P
s
P
p
.002 w
.55857 .60386 m .57508 .59254 L .59734 .59221 L p
1 g
F P
s
P
p
.002 w
.61353 .57206 m .59734 .59221 L .57508 .59254 L p
1 g
F P
s
P
p
.002 w
.46125 .59705 m .47568 .60722 L .45404 .61336 L p
1 g
F P
s
P
p
.002 w
.45404 .61336 m .43288 .59873 L .46125 .59705 L p
1 g
F P
s
P
p
.002 w
.61346 .3044 m .66152 .33638 L .66312 .36141 L p
1 g
F P
s
P
p
.002 w
.66152 .33638 m .61346 .3044 L .60797 .28285 L p
1 g
F P
s
P
p
.002 w
.36151 .36779 m .32466 .41117 L .31877 .38675 L p
1 g
F P
s
P
p
.002 w
.31877 .38675 m .35597 .34222 L .36151 .36779 L p
1 g
F P
s
P
p
.002 w
.6599 .38922 m .68636 .42757 L .6765 .45372 L p
1 g
F P
s
P
p
.002 w
.68636 .42757 m .6599 .38922 L .66312 .36141 L p
1 g
F P
s
P
p
.002 w
.66116 .47981 m .66663 .51382 L .64573 .53319 L p
1 g
F P
s
P
p
.002 w
.66663 .51382 m .66116 .47981 L .6765 .45372 L p
1 g
F P
s
P
p
.002 w
.38779 .54223 m .39086 .57079 L .36507 .55829 L p
1 g
F P
s
P
p
.002 w
.36507 .55829 m .36081 .52407 L .38779 .54223 L p
1 g
F P
s
P
p
.002 w
.35243 .46301 m .33843 .50351 L .32126 .48132 L p
1 g
F P
s
P
p
.002 w
.32126 .48132 m .33594 .43687 L .35243 .46301 L p
1 g
F P
s
P
p
.002 w
.60797 .28285 m .5457 .26582 L .54004 .24977 L p
1 g
F P
s
P
p
.002 w
.47395 .25056 m .54004 .24977 L .5457 .26582 L p
1 g
F P
s
P
p
.002 w
.51959 .59957 m .53097 .59789 L .53828 .61151 L p
1 g
F P
s
P
p
.002 w
.53828 .61151 m .51626 .61476 L .51959 .59957 L p
1 g
F P
s
P
p
.002 w
.55857 .60386 m .53828 .61151 L .53097 .59789 L p
1 g
F P
s
P
p
.002 w
.50845 .59879 m .51959 .59957 L .51626 .61476 L p
1 g
F P
s
P
p
.002 w
.51626 .61476 m .49467 .6133 L .50845 .59879 L p
1 g
F P
s
P
p
.002 w
.47646 .26674 m .40978 .28576 L .41033 .26879 L p
1 g
F P
s
P
p
.002 w
.41033 .26879 m .47395 .25056 L .47646 .26674 L p
1 g
F P
s
P
p
.002 w
.53097 .59789 m .54143 .59392 L .55857 .60386 L p
1 g
F P
s
P
p
.002 w
.57508 .59254 m .55857 .60386 L .54143 .59392 L p
1 g
F P
s
P
p
.002 w
.5457 .26582 m .60797 .28285 L .61346 .3044 L p
1 g
F P
s
P
p
.002 w
.49873 .59561 m .50845 .59879 L .49467 .6133 L p
1 g
F P
s
P
p
.002 w
.49467 .6133 m .47568 .60722 L .49873 .59561 L p
1 g
F P
s
P
p
.002 w
.41193 .30772 m .35597 .34222 L .35479 .32001 L p
1 g
F P
s
P
p
.002 w
.35479 .32001 m .40978 .28576 L .41193 .30772 L p
1 g
F P
s
P
p
.002 w
.5457 .26582 m .47646 .26674 L .47395 .25056 L p
1 g
F P
s
P
p
.002 w
.57508 .59254 m .58607 .57863 L .61353 .57206 L p
1 g
F P
s
P
p
.002 w
.62003 .54997 m .61353 .57206 L .58607 .57863 L p
1 g
F P
s
P
p
.002 w
.61353 .57206 m .62003 .54997 L .64573 .53319 L p
1 g
F P
s
P
p
.002 w
.45301 .58375 m .46125 .59705 L .43288 .59873 L p
1 g
F P
s
P
p
.002 w
.43288 .59873 m .42048 .57941 L .45301 .58375 L p
1 g
F P
s
P
p
.002 w
.54143 .59392 m .54987 .58807 L .57508 .59254 L p
1 g
F P
s
P
p
.002 w
.58607 .57863 m .57508 .59254 L .54987 .58807 L p
1 g
F P
s
P
p
.002 w
.49144 .59035 m .49873 .59561 L .47568 .60722 L p
1 g
F P
s
P
p
.002 w
.47568 .60722 m .46125 .59705 L .49144 .59035 L p
1 g
F P
s
P
p
.002 w
.64071 .50494 m .64573 .53319 L .62003 .54997 L p
1 g
F P
s
P
p
.002 w
.64573 .53319 m .64071 .50494 L .66116 .47981 L p
1 g
F P
s
P
p
.002 w
.6518 .41894 m .6765 .45372 L .66116 .47981 L p
1 g
F P
s
P
p
.002 w
.6765 .45372 m .6518 .41894 L .6599 .38922 L p
1 g
F P
s
P
p
.002 w
.41855 .55729 m .42048 .57941 L .39086 .57079 L p
1 g
F P
s
P
p
.002 w
.39086 .57079 m .38779 .54223 L .41855 .55729 L p
1 g
F P
s
P
p
.002 w
.37371 .48865 m .36081 .52407 L .33843 .50351 L p
1 g
F P
s
P
p
.002 w
.33843 .50351 m .35243 .46301 L .37371 .48865 L p
1 g
F P
s
P
p
.002 w
.6157 .33044 m .66312 .36141 L .6599 .38922 L p
1 g
F P
s
P
p
.002 w
.66312 .36141 m .6157 .33044 L .61346 .3044 L p
1 g
F P
s
P
p
.002 w
.37143 .39597 m .33594 .43687 L .32466 .41117 L p
1 g
F P
s
P
p
.002 w
.32466 .41117 m .36151 .36779 L .37143 .39597 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5175 .54603 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54987 .58807 m .55539 .58092 L .58607 .57863 L p
1 g
F P
s
P
p
.002 w
.59026 .5635 m .58607 .57863 L .55539 .58092 L p
1 g
F P
s
P
p
.002 w
.58607 .57863 m .59026 .5635 L .62003 .54997 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.4874 .58354 m .49144 .59035 L .46125 .59705 L p
1 g
F P
s
P
p
.002 w
.46125 .59705 m .45301 .58375 L .4874 .58354 L p
1 g
F P
s
P
p
.002 w
.61346 .3044 m .55019 .28743 L .5457 .26582 L p
1 g
F P
s
P
p
.002 w
.47646 .26674 m .5457 .26582 L .55019 .28743 L p
1 g
F P
s
P
p
.002 w
.47977 .28848 m .41193 .30772 L .40978 .28576 L p
1 g
F P
s
P
p
.002 w
.40978 .28576 m .47646 .26674 L .47977 .28848 L p
1 g
F P
s
P
p
.002 w
.53097 .59789 m .51959 .59957 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.54143 .59392 m .53097 .59789 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.51959 .59957 m .50845 .59879 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.55019 .28743 m .61346 .3044 L .6157 .33044 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.61571 .52821 m .62003 .54997 L .59026 .5635 L p
1 g
F P
s
P
p
.002 w
.62003 .54997 m .61571 .52821 L .64071 .50494 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.41684 .33413 m .36151 .36779 L .35597 .34222 L p
1 g
F P
s
P
p
.002 w
.35597 .34222 m .41193 .30772 L .41684 .33413 L p
1 g
F P
s
P
p
.002 w
.45204 .56865 m .45301 .58375 L .42048 .57941 L p
1 g
F P
s
P
p
.002 w
.42048 .57941 m .41855 .55729 L .45204 .56865 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.54987 .58807 m .54143 .59392 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.63893 .44959 m .66116 .47981 L .64071 .50494 L p
1 g
F P
s
P
p
.002 w
.66116 .47981 m .63893 .44959 L .6518 .41894 L p
1 g
F P
s
P
p
.002 w
.50845 .59879 m .49873 .59561 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.39912 .51285 m .38779 .54223 L .36081 .52407 L p
1 g
F P
s
P
p
.002 w
.36081 .52407 m .37371 .48865 L .39912 .51285 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.55019 .28743 m .47977 .28848 L .47646 .26674 L p
1 g
F P
s
P
p
.002 w
.55539 .58092 m .54987 .58807 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.61449 .36024 m .6599 .38922 L .6518 .41894 L p
1 g
F P
s
P
p
.002 w
.6599 .38922 m .61449 .36024 L .6157 .33044 L p
1 g
F P
s
P
p
.002 w
.49873 .59561 m .49144 .59035 L .51741 .58061 L p
1 g
F P
s
P
p
.002 w
.49144 .59035 m .4874 .58354 L .50727 .58081 L p
1 g
F P
s
P
p
.002 w
.51095 .58073 m .51079 .57862 L p
.49923 .58093 L 1 g
F P
s
P
p
.002 w
.4874 .58354 m .48731 .58112 L p
.48903 .58109 L 1 g
F P
s
P
p
.002 w
.50727 .58081 m .49569 .5824 L p
.48903 .58109 L 1 g
F P
s
P
p
.002 w
.49569 .5824 m .4874 .58354 L p
.48903 .58109 L 1 g
F P
s
P
p
.002 w
.4874 .58354 m .45301 .58375 L p
.47849 .57787 L 1 g
F P
s
P
p
.48921 .57862 m .47796 .5777 L .47826 .5778 L 1 g
F
P
p
.002 w
.48729 .58075 m .4874 .58354 L p
.47849 .57787 L 1 g
F P
s
P
p
.002 w
.48903 .58109 m .48921 .57862 L p
.47826 .5778 L 1 g
F P
s
P
p
.002 w
.45301 .58375 m .45208 .56923 L p
.46831 .57454 L 1 g
F P
s
P
p
.47524 .57862 m .46831 .57454 L .47849 .57787 L 1 g
F
P
p
.45301 .58375 m .46831 .57454 L .47524 .57862 L 1 g
F
P
p
.002 w
.46831 .57454 m .46872 .57265 L p
.45823 .56846 L 1 g
F P
s
P
p
.002 w
.46171 .57065 m .45204 .56865 L p
.45843 .56858 L 1 g
F P
s
P
p
.45823 .56846 m .46171 .57065 L .46831 .57454 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45204 .56865 m .45344 .56544 L p
.45843 .56858 L 1 g
F P
s
P
p
.47826 .5778 m .48729 .58075 L .48903 .58109 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.47849 .57787 m .46741 .57401 L .4871 .57589 L 1 g
F
P
p
.002 w
.45204 .56865 m .46171 .57065 L p
.46741 .57401 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45073 .56326 L p
1 g
F P
s
P
p
.44061 .55514 m .45073 .56326 L .45204 .56865 L 1 g
F
P
p
.002 w
.45344 .56544 m .45305 .56634 L p
.45073 .56326 L 1 g
F P
s
P
p
.002 w
.45305 .56634 m .45204 .56865 L p
.45073 .56326 L 1 g
F P
s
P
p
.002 w
.45073 .56326 m .45146 .56129 L p
.445 .55568 L 1 g
F P
s
P
p
.46872 .57265 m .45073 .56326 L .45339 .5654 L 1 g
F
P
p
.46872 .57265 m .45045 .56401 L .4575 .56817 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45868 .55338 m .45344 .56544 L p
.45073 .56326 L 1 g
F P
s
P
p
.44061 .55514 m .44432 .55478 L .45073 .56326 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4385 .54707 L p
1 g
F P
s
P
p
.45146 .56129 m .4385 .54707 L .445 .55568 L 1 g
F
P
p
.44432 .55478 m .45868 .55338 L .45073 .56326 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.41855 .55729 m .42779 .5347 L .4357 .53948 L p
1 g
F P
s
P
p
.002 w
.4385 .54707 m .43925 .54566 L p
.43504 .53733 L 1 g
F P
s
P
p
.002 w
.4357 .53948 m .42779 .5347 L p
.43446 .53544 L 1 g
F P
s
P
p
.43504 .53733 m .43454 .53634 L .4357 .53948 L 1 g
F
P
p
.43504 .53733 m .4357 .53948 L .4385 .54707 L 1 g
F
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43247 .52878 L p
1 g
F P
s
P
p
.42892 .51373 m .43247 .52878 L .42779 .5347 L 1 g
F
P
p
.002 w
.43268 .52967 m .43237 .52999 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43237 .52999 m .42779 .5347 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43247 .52878 m .43346 .52734 L p
.4332 .51996 L 1 g
F P
s
P
p
.43925 .54566 m .43247 .52878 L .43268 .52967 L 1 g
F
P
p
.002 w
.42779 .5347 m .43268 .52967 L p
.43446 .53544 L 1 g
F P
s
P
p
.43504 .53733 m .43268 .52967 L .434 .53528 L 1 g
F
P
p
.43925 .54566 m .43268 .52967 L .43504 .53733 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44761 .51428 m .47237 .53967 L p
.43446 .53544 L 1 g
F P
s
P
p
.002 w
.43268 .52967 m .44761 .51428 L p
.43446 .53544 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44761 .51428 m .43268 .52967 L p
.43247 .52878 L 1 g
F P
s
P
p
.42892 .51373 m .43371 .51387 L .43247 .52878 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4341 .50915 L p
1 g
F P
s
P
p
.43346 .52734 m .4341 .50915 L .4332 .51996 L 1 g
F
P
p
.43371 .51387 m .44761 .51428 L .43247 .52878 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.39912 .51285 m .4243 .48611 L .43743 .50198 L p
1 g
F P
s
P
p
.002 w
.4341 .50915 m .43485 .50826 L p
.4382 .50042 L 1 g
F P
s
P
p
.4243 .48611 m .44305 .49062 L .4428 .49113 L 1 g
F
P
p
.002 w
.43743 .50198 m .43484 .49884 L p
.4428 .49113 L 1 g
F P
s
P
p
.002 w
.43484 .49884 m .4243 .48611 L p
.4428 .49113 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4428 .49113 L p
1 g
F P
s
P
p
.002 w
.4428 .49113 m .44166 .49233 L p
.4382 .50042 L 1 g
F P
s
P
p
.43485 .50826 m .4428 .49113 L .4382 .50042 L 1 g
F
P
p
.002 w
.4428 .49113 m .44339 .4905 L p
.44832 .48578 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46082 .46546 m .46342 .47114 L p
.44305 .49062 L 1 g
F P
s
P
p
.44327 .49068 m .45775 .47664 L .47598 .49855 L 1 g
F
P
p
.002 w
.46451 .47351 m .47598 .49855 L p
.45775 .47664 L 1 g
F P
s
P
p
.002 w
.50958 .48956 m .47598 .49855 L .46451 .47351 L p
1 g
F P
s
P
p
.47083 .47041 m .50958 .48956 L .46451 .47351 L 1 g
F
P
p
.002 w
.45775 .47664 m .45826 .47608 L p
.46776 .47191 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47083 .47041 m .47762 .46708 L .50958 .48956 L 1 g
F
P
p
.002 w
.47762 .46708 m .47786 .46667 L p
.48644 .4658 L 1 g
F P
s
P
p
.47762 .46708 m .5 .46383 L .50958 .48956 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52235 .46703 L p
1 g
F P
s
P
p
.51917 .4666 m .54431 .48848 L .50597 .46482 L 1 g
F
P
p
.5 .4634 m .52235 .46703 L .51239 .46568 L 1 g
F
P
p
.002 w
.50434 .45369 m .54934 .45242 L .54684 .47033 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56603 .5093 L p
1 g
F P
s
P
p
.002 w
.57108 .50455 m .56725 .51186 L p
.56603 .5093 L 1 g
F P
s
P
p
.55745 .49139 m .56497 .49866 L .56603 .5093 L 1 g
F
P
p
.56497 .49866 m .57108 .50455 L .56603 .5093 L 1 g
F
P
p
.002 w
.56603 .5093 m .56515 .50826 L p
.56688 .51947 L 1 g
F P
s
P
p
.57588 .49537 m .56775 .53135 L .56757 .52884 L 1 g
F
P
p
.002 w
.56643 .51343 m .57585 .49543 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.57585 .49543 m .57588 .49537 L p
.56757 .52884 L 1 g
F P
s
P
p
.002 w
.57637 .53602 m .56775 .53135 L p
.57588 .49537 L 1 g
F P
s
P
p
.002 w
.55552 .56579 m .55144 .56111 L p
.57637 .53602 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54933 .56341 L p
1 g
F P
s
P
p
.002 w
.55552 .56579 m .54244 .5709 L p
.54933 .56341 L 1 g
F P
s
P
p
.002 w
.55144 .56111 m .55197 .56171 L p
.54933 .56341 L 1 g
F P
s
P
p
.002 w
.55197 .56171 m .55552 .56579 L p
.54933 .56341 L 1 g
F P
s
P
p
.002 w
.54933 .56341 m .54854 .56129 L p
.54007 .56936 L 1 g
F P
s
P
p
.56075 .54566 m .54933 .56341 L .55048 .56216 L 1 g
F
P
p
.56075 .54566 m .54947 .56378 L .55454 .55691 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .57472 L p
1 g
F P
s
P
p
.002 w
.54244 .5709 m .53028 .57566 L p
.53163 .57479 L 1 g
F P
s
P
p
.54854 .56129 m .53173 .57472 L .54007 .56936 L 1 g
F
P
p
.002 w
.53173 .57472 m .53128 .57265 L p
.51913 .57888 L 1 g
F P
s
P
p
.002 w
.52053 .57856 m .52245 .57872 L .51591 .57962 L p
1 g
F P
s
P
p
.002 w
.52245 .57872 m .51741 .58061 L p
.51095 .58073 L 1 g
F P
s
P
p
.49923 .58093 m .50727 .58081 L .51095 .58073 L 1 g
F
P
p
.002 w
.51591 .57962 m .52245 .57872 L p
.51095 .58073 L 1 g
F P
s
P
p
.002 w
.51741 .58061 m .49144 .59035 L p
.50527 .58201 L 1 g
F P
s
P
p
.50527 .58201 m .50727 .58081 L .51095 .58073 L 1 g
F
P
p
.50527 .58201 m .51095 .58073 L .51741 .58061 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58073 L p
1 g
F P
s
P
p
.002 w
.51095 .58073 m .51106 .58224 L p
.51719 .57933 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58073 L .51719 .57933 L 1 g
F
P
p
.002 w
.51106 .58224 m .51111 .583 L p
.51633 .58032 L 1 g
F P
s
P
p
.53128 .57265 m .51675 .57954 L .51894 .57898 L 1 g
F
P
p
.51913 .57888 m .52053 .57856 L .53173 .57472 L 1 g
F
P
p
.002 w
.52179 .57826 m .52245 .57872 L .52138 .57836 L p
1 g
F P
s
P
p
.52053 .57856 m .52161 .57831 L .53173 .57472 L 1 g
F
P
p
.52161 .57831 m .5221 .57817 L .53173 .57472 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49763 .56139 m .50739 .55617 L .52209 .57817 L p
1 g
F P
s
P
p
.002 w
.52209 .57817 m .52245 .57872 L .52179 .57826 L p
1 g
F P
s
P
p
.002 w
.52179 .57826 m .49763 .56139 L p
.52209 .57817 L 1 g
F P
s
P
p
.52161 .57831 m .52195 .57822 L .5221 .57817 L 1 g
F
P
p
.002 w
.52236 .57809 m .52245 .57872 L .52209 .57817 L p
1 g
F P
s
P
p
.52195 .57822 m .52209 .57819 L .52239 .57809 L 1 g
F
P
p
.52195 .57822 m .52239 .57809 L .53173 .57472 L 1 g
F
P
p
.52209 .57819 m .52288 .57792 L .53173 .57472 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.5188 .55318 m .53058 .55275 L .52268 .57799 L p
1 g
F P
s
P
p
.002 w
.52268 .57799 m .52245 .57872 L .52236 .57809 L p
1 g
F P
s
P
p
.002 w
.52236 .57809 m .5188 .55318 L p
.52268 .57799 L 1 g
F P
s
P
p
.52223 .57816 m .52431 .57742 L .53173 .57472 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53058 .55275 m .54138 .55493 L .52316 .57783 L p
1 g
F P
s
P
p
.002 w
.52316 .57783 m .52245 .57872 L .52268 .57799 L p
1 g
F P
s
P
p
.002 w
.52268 .57799 m .53058 .55275 L p
.52316 .57783 L 1 g
F P
s
P
p
.52209 .57819 m .52223 .57816 L .52288 .57792 L 1 g
F
P
p
.52223 .57816 m .52237 .57813 L .52431 .57742 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54138 .55493 m .55001 .55945 L .52431 .57742 L p
1 g
F P
s
P
p
.002 w
.52431 .57742 m .52245 .57872 L .52316 .57783 L p
1 g
F P
s
P
p
.002 w
.52316 .57783 m .54138 .55493 L p
.52431 .57742 L 1 g
F P
s
P
p
.002 w
.50739 .55617 m .5188 .55318 L .52236 .57809 L p
1 g
F P
s
P
p
.002 w
.52209 .57817 m .50739 .55617 L p
.52236 .57809 L 1 g
F P
s
P
p
.52179 .57826 m .52223 .57818 L .52237 .57813 L 1 g
F
P
p
.002 w
.52138 .57836 m .52245 .57872 L .52053 .57856 L p
1 g
F P
s
P
p
.52053 .57856 m .52161 .57832 L .52179 .57826 L 1 g
F
P
p
.52161 .57832 m .52223 .57818 L .52179 .57826 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4871 .57589 m .49062 .56822 L .52138 .57836 L p
1 g
F P
s
P
p
.002 w
.52053 .57856 m .4871 .57589 L p
.52138 .57836 L 1 g
F P
s
P
p
.002 w
.49062 .56822 m .49763 .56139 L .52179 .57826 L p
1 g
F P
s
P
p
.002 w
.52138 .57836 m .49062 .56822 L p
.52179 .57826 L 1 g
F P
s
P
p
.51894 .57898 m .51106 .58224 L .51633 .58032 L 1 g
F
P
p
.51675 .57954 m .51106 .58224 L .51894 .57898 L 1 g
F
P
p
.002 w
.55001 .55945 m .55144 .56111 L p
.525 .57717 L 1 g
F P
s
P
p
.002 w
.52245 .57872 m .52431 .57742 L p
.525 .57717 L 1 g
F P
s
P
p
.002 w
.52431 .57742 m .55001 .55945 L p
.525 .57717 L 1 g
F P
s
P
p
.002 w
.50727 .58081 m .51591 .57962 L p
.51095 .58073 L 1 g
F P
s
P
p
.51913 .57888 m .5191 .5789 L .52223 .57818 L 1 g
F
P
p
.5191 .5789 m .51633 .58032 L .5221 .57822 L 1 g
F
P
p
.5191 .5789 m .5221 .57822 L .52223 .57818 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.4871 .57589 m .52053 .57856 L p
.50727 .58081 L 1 g
F P
s
P
p
.002 w
.51591 .57962 m .50727 .58081 L p
.52053 .57856 L 1 g
F P
s
P
p
.55144 .56111 m .54254 .5708 L .525 .57717 L 1 g
F
P
p
.54254 .5708 m .54244 .5709 L .525 .57717 L 1 g
F
P
p
.002 w
.55736 .57322 m .52645 .57809 L p
.55076 .5678 L 1 g
F P
s
P
p
.002 w
.52645 .57809 m .52245 .57872 L .53028 .57566 L p
1 g
F P
s
P
p
.002 w
.53028 .57566 m .55552 .56579 L p
.52645 .57809 L 1 g
F P
s
P
p
.525 .57717 m .53163 .57479 L .52245 .57872 L 1 g
F
P
p
.002 w
.53028 .57566 m .52245 .57872 L p
.53163 .57479 L 1 g
F P
s
P
p
.002 w
.51741 .58061 m .52245 .57872 L .5199 .58053 L p
1 g
F P
s
P
p
.002 w
.5199 .58053 m .49873 .59561 L p
.51741 .58061 L 1 g
F P
s
P
p
.002 w
.55736 .57322 m .55539 .58092 L .52245 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53173 .57473 L p
1 g
F P
s
P
p
.002 w
.53173 .57473 m .53173 .57472 L p
.53143 .57484 L 1 g
F P
s
P
p
.53143 .57484 m .51111 .583 L .53173 .57473 L 1 g
F
P
p
.002 w
.55552 .56579 m .55558 .56605 L p
.55076 .5678 L 1 g
F P
s
P
p
.002 w
.55558 .56605 m .55736 .57322 L p
.55076 .5678 L 1 g
F P
s
P
p
.002 w
.53173 .57472 m .53173 .57473 L p
.54007 .56936 L 1 g
F P
s
P
p
.002 w
.53173 .57473 m .5322 .57686 L p
.53983 .5696 L 1 g
F P
s
P
p
.54007 .56936 m .53173 .57473 L .53983 .5696 L 1 g
F
P
p
.51633 .58032 m .51111 .583 L .53173 .57472 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54933 .56341 L p
1 g
F P
s
P
p
.54007 .56936 m .5322 .57686 L .54933 .56341 L 1 g
F
P
p
.002 w
.54933 .56341 m .54947 .56378 L p
.55048 .56216 L 1 g
F P
s
P
p
.002 w
.55775 .55257 m .56066 .54999 L p
.55144 .56111 L 1 g
F P
s
P
p
.002 w
.56066 .54999 m .57637 .53602 L p
.5596 .5529 L 1 g
F P
s
P
p
.5596 .5529 m .55144 .56111 L .56066 .54999 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56158 .54723 L p
1 g
F P
s
P
p
.56654 .52734 m .56158 .54723 L .56185 .54645 L 1 g
F
P
p
.002 w
.57637 .53602 m .56066 .54999 L p
.56158 .54723 L 1 g
F P
s
P
p
.002 w
.56158 .54723 m .56075 .54566 L p
.55423 .55748 L 1 g
F P
s
P
p
.002 w
.56704 .53096 m .57152 .53339 L p
.56158 .54723 L 1 g
F P
s
P
p
.002 w
.57152 .53339 m .57637 .53602 L p
.56158 .54723 L 1 g
F P
s
P
p
.56449 .53857 m .56163 .54732 L .56415 .54041 L 1 g
F
P
p
.56654 .52734 m .56185 .54645 L .56449 .53857 L 1 g
F
P
p
.56185 .54645 m .56163 .54732 L .56449 .53857 L 1 g
F
P
p
.002 w
.56757 .52884 m .56654 .52734 L p
.56449 .53857 L 1 g
F P
s
P
p
.56449 .53857 m .56264 .54872 L .56704 .53096 L 1 g
F
P
p
.56449 .53857 m .56704 .53096 L .56757 .52884 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56066 .54999 m .55001 .55945 L p
.56704 .53096 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56158 .54723 L p
1 g
F P
s
P
p
.55423 .55748 m .54998 .56518 L .56158 .54723 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55942 .52684 m .56704 .53096 L p
.55001 .55945 L 1 g
F P
s
P
p
.002 w
.56158 .54723 m .56163 .54732 L p
.56185 .54645 L 1 g
F P
s
P
p
.002 w
.56163 .54732 m .56257 .5491 L p
.56415 .54041 L 1 g
F P
s
P
p
.002 w
.55144 .56111 m .55001 .55945 L .55775 .55257 L p
1 g
F P
s
P
p
.002 w
.54947 .56378 m .54998 .56518 L p
.55454 .55691 L 1 g
F P
s
P
p
.56688 .51947 m .56643 .51343 L .56603 .5093 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56802 .5295 L p
1 g
F P
s
P
p
.56515 .50826 m .56802 .5295 L .56731 .52224 L 1 g
F
P
p
.55661 .4905 m .56603 .5093 L .56152 .49989 L 1 g
F
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55745 .49139 L p
1 g
F P
s
P
p
.002 w
.55745 .49139 m .55661 .4905 L p
.56569 .50788 L 1 g
F P
s
P
p
.56569 .50788 m .56713 .51061 L .55745 .49139 L 1 g
F
P
p
.002 w
.57588 .49537 m .55743 .49134 L p
.54934 .45242 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55745 .49139 L p
1 g
F P
s
P
p
.002 w
.55739 .49134 m .54431 .48848 L .54552 .47983 L p
1 g
F P
s
P
p
.55745 .49139 m .56603 .5093 L .55942 .52684 L 1 g
F
P
p
.55739 .49134 m .55745 .49139 L .55942 .52684 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54431 .48848 m .55739 .49134 L p
.55942 .52684 L 1 g
F P
s
P
p
.55212 .48624 m .55739 .49134 L .55834 .49233 L 1 g
F
P
p
.002 w
.55745 .49139 m .55745 .49139 L p
.55739 .49134 L 1 g
F P
s
P
p
.002 w
.55745 .49139 m .55834 .49233 L p
.55739 .49134 L 1 g
F P
s
P
p
.54174 .47608 m .55745 .49139 L .55212 .48624 L 1 g
F
P
p
.002 w
.55743 .49134 m .55739 .49134 L p
.54686 .47022 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54552 .47983 m .54431 .48848 L p
.53682 .47403 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54229 .47669 L p
1 g
F P
s
P
p
.52214 .46667 m .54229 .47669 L .52974 .47061 L 1 g
F
P
p
.534 .4686 m .54229 .47669 L .53682 .47403 L 1 g
F
P
p
.54229 .47669 m .54552 .47983 L .53682 .47403 L 1 g
F
P
p
.51917 .4666 m .52235 .46703 L .54431 .48848 L 1 g
F
P
p
.002 w
.52235 .46703 m .52214 .46667 L p
.52974 .47061 L 1 g
F P
s
P
p
.52235 .46703 m .534 .4686 L .53682 .47403 L 1 g
F
P
p
.52235 .46703 m .53682 .47403 L .54431 .48848 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52235 .46703 L p
1 g
F P
s
P
p
.52974 .47061 m .54302 .47747 L .52235 .46703 L 1 g
F
P
p
.002 w
.54229 .47669 m .54302 .47747 L p
.52974 .47061 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54229 .47669 L p
1 g
F P
s
P
p
.002 w
.54229 .47669 m .54174 .47608 L p
.55627 .49031 L 1 g
F P
s
P
p
.55627 .49031 m .55834 .49233 L .54229 .47669 L 1 g
F
P
p
.002 w
.54684 .47033 m .54552 .47983 L p
.534 .4686 L 1 g
F P
s
P
p
.002 w
.54552 .47983 m .54686 .47022 L p
.55739 .49134 L 1 g
F P
s
P
p
.002 w
.54686 .47022 m .54934 .45242 L p
.55743 .49134 L 1 g
F P
s
P
p
.002 w
.56725 .51186 m .56643 .51343 L p
.56603 .5093 L 1 g
F P
s
P
p
.002 w
.56643 .51343 m .55942 .52684 L p
.56603 .5093 L 1 g
F P
s
P
p
.002 w
.56802 .5295 m .56854 .53025 L p
.56731 .52224 L 1 g
F P
s
P
p
.002 w
.56775 .53135 m .55942 .52684 L .56643 .51343 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56757 .52884 L p
1 g
F P
s
P
p
.56264 .54872 m .56257 .5491 L .56757 .52884 L 1 g
F
P
p
.56688 .51947 m .56731 .52224 L .56643 .51343 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56603 .5093 L p
1 g
F P
s
P
p
.56731 .52224 m .56854 .53025 L .56603 .5093 L 1 g
F
P
p
.002 w
.56603 .5093 m .56713 .51061 L p
.56152 .49989 L 1 g
F P
s
P
p
.002 w
.55739 .49134 m .57588 .49537 L .57108 .50455 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.50434 .45369 m .54684 .47033 L .51917 .4666 L 1 g
F
P
p
.51067 .46545 m .52269 .46758 L .51601 .46648 L 1 g
F
P
p
.5 .4634 m .51239 .46568 L .51067 .46545 L 1 g
F
P
p
.51239 .46568 m .52269 .46758 L .51067 .46545 L 1 g
F
P
p
.002 w
.52235 .46703 m .52269 .46758 L p
.51239 .46568 L 1 g
F P
s
P
p
.002 w
.54431 .48848 m .50958 .48956 L .50597 .46482 L p
1 g
F P
s
P
p
.002 w
.50597 .46482 m .50958 .48956 L p
.5 .46383 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46383 L p
1 g
F P
s
P
p
.002 w
.5 .46383 m .5 .4634 L p
.51601 .46648 L 1 g
F P
s
P
p
.51601 .46648 m .52282 .46778 L .5 .46383 L 1 g
F
P
p
.002 w
.50438 .45394 m .5057 .46301 L p
.5 .46383 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46383 L p
1 g
F P
s
P
p
.002 w
.5 .46383 m .5 .46442 L p
.48644 .4658 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46383 L .48644 .4658 L 1 g
F
P
p
.47762 .46708 m .4882 .46188 L .5 .46383 L 1 g
F
P
p
.4882 .46188 m .50438 .45394 L .5 .46383 L 1 g
F
P
p
.002 w
.50597 .46482 m .50434 .45369 L p
.51917 .4666 L 1 g
F P
s
P
p
.002 w
.5057 .46301 m .50597 .46482 L p
.5 .46383 L 1 g
F P
s
P
p
.002 w
.52269 .46758 m .52282 .46778 L p
.51601 .46648 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47762 .46708 L p
1 g
F P
s
P
p
.48644 .4658 m .5 .46442 L .47762 .46708 L 1 g
F
P
p
.46776 .47191 m .47148 .47028 L .46451 .47351 L 1 g
F
P
p
.46776 .47191 m .46451 .47351 L .45775 .47664 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46082 .46546 m .50434 .45369 L .50438 .45394 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4773 .46759 L p
1 g
F P
s
P
p
.002 w
.4773 .46759 m .47718 .46778 L p
.47148 .47028 L 1 g
F P
s
P
p
.45826 .47608 m .4773 .46759 L .47148 .47028 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45698 .47747 L p
1 g
F P
s
P
p
.44305 .49062 m .4576 .47671 L .44327 .49068 L 1 g
F
P
p
.4576 .47671 m .46342 .47114 L .45775 .47664 L 1 g
F
P
p
.4576 .47671 m .45775 .47664 L .44327 .49068 L 1 g
F
P
p
.46082 .46546 m .50438 .45394 L .47083 .47041 L 1 g
F
P
p
.002 w
.46451 .47351 m .46082 .46546 L p
.47083 .47041 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45743 .47698 L p
1 g
F P
s
P
p
.002 w
.45743 .47698 m .45775 .47664 L p
.46313 .47419 L 1 g
F P
s
P
p
.46313 .47419 m .47718 .46778 L .45743 .47698 L 1 g
F
P
p
.47148 .47028 m .47718 .46778 L .45775 .47664 L 1 g
F
P
p
.002 w
.46342 .47114 m .46451 .47351 L p
.45775 .47664 L 1 g
F P
s
P
p
.002 w
.4243 .48611 m .45344 .46963 L p
.44305 .49062 L 1 g
F P
s
P
p
.002 w
.45344 .46963 m .46082 .46546 L p
.44305 .49062 L 1 g
F P
s
P
p
.4382 .50042 m .43743 .50198 L .4341 .50915 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.44305 .49062 m .47598 .49855 L .43743 .50198 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4428 .49113 L p
1 g
F P
s
P
p
.44832 .48578 m .45698 .47747 L .4428 .49113 L 1 g
F
P
p
.4382 .50042 m .43876 .49913 L .43743 .50198 L 1 g
F
P
p
.002 w
.47598 .49855 m .44761 .51428 L .43743 .50198 L p
1 g
F P
s
P
p
.002 w
.43743 .50198 m .44761 .51428 L p
.43194 .51381 L 1 g
F P
s
P
p
.39912 .51285 m .43743 .50198 L .43194 .51381 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .4341 .50915 L p
1 g
F P
s
P
p
.43876 .49913 m .44166 .49233 L .4341 .50915 L 1 g
F
P
p
.002 w
.4341 .50915 m .43287 .51061 L p
.4332 .51996 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43247 .52878 L p
1 g
F P
s
P
p
.4332 .51996 m .43287 .51061 L .43247 .52878 L 1 g
F
P
p
.002 w
.43247 .52878 m .43146 .53025 L p
.434 .53528 L 1 g
F P
s
P
p
.002 w
.42779 .5347 m .39912 .51285 L p
.42892 .51373 L 1 g
F P
s
P
p
.002 w
.47237 .53967 m .45868 .55338 L .4357 .53948 L p
1 g
F P
s
P
p
.43446 .53544 m .47237 .53967 L .4357 .53948 L 1 g
F
P
p
.002 w
.4357 .53948 m .45868 .55338 L p
.44146 .55506 L 1 g
F P
s
P
p
.41855 .55729 m .4357 .53948 L .44146 .55506 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4385 .54707 L p
1 g
F P
s
P
p
.43454 .53634 m .43146 .53025 L .4385 .54707 L 1 g
F
P
p
.002 w
.4385 .54707 m .43743 .5491 L p
.445 .55568 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45073 .56326 L p
1 g
F P
s
P
p
.445 .55568 m .43743 .5491 L .45073 .56326 L 1 g
F
P
p
.002 w
.45073 .56326 m .45045 .56401 L p
.45339 .5654 L 1 g
F P
s
P
p
.002 w
.45204 .56865 m .41855 .55729 L p
.44061 .55514 L 1 g
F P
s
P
p
.002 w
.46171 .57065 m .4871 .57589 L p
.46741 .57401 L 1 g
F P
s
P
p
.002 w
.45045 .56401 m .45002 .56518 L p
.4575 .56817 L 1 g
F P
s
P
p
.002 w
.45868 .55338 m .49062 .56822 L p
.45843 .56858 L 1 g
F P
s
P
p
.002 w
.45344 .56544 m .45868 .55338 L p
.45843 .56858 L 1 g
F P
s
P
p
.002 w
.45208 .56923 m .45204 .56865 L p
.47849 .57787 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46826 .57477 L p
1 g
F P
s
P
p
.002 w
.46826 .57477 m .46831 .57454 L p
.46606 .57339 L 1 g
F P
s
P
p
.46606 .57339 m .45002 .56518 L .46826 .57477 L 1 g
F
P
p
.45823 .56846 m .4575 .56817 L .46171 .57065 L 1 g
F
P
p
.002 w
.49062 .56822 m .4871 .57589 L .46171 .57065 L p
1 g
F P
s
P
p
.45843 .56858 m .49062 .56822 L .46171 .57065 L 1 g
F
P
p
.4575 .56817 m .45002 .56518 L .46831 .57454 L 1 g
F
P
p
.47826 .5778 m .46847 .57706 L .48729 .58075 L 1 g
F
P
p
.002 w
.4871 .57589 m .48729 .58075 L p
.47849 .57787 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .46847 .57706 L p
.47826 .5778 L 1 g
F P
s
P
p
.47796 .5777 m .4678 .57686 L .47826 .5778 L 1 g
F
P
p
.002 w
.48731 .58112 m .4871 .57589 L p
.50727 .58081 L 1 g
F P
s
P
p
.002 w
.46847 .57706 m .48889 .583 L .48903 .58109 L p
1 g
F P
s
P
p
.49923 .58093 m .49905 .58097 L .50727 .58081 L 1 g
F
P
p
.002 w
.51095 .5808 m .51095 .58073 L p
.49792 .58119 L 1 g
F P
s
P
p
.49905 .58097 m .49792 .58119 L .51095 .58073 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .5808 L p
1 g
F P
s
P
p
.49792 .58119 m .48889 .583 L .51095 .5808 L 1 g
F
P
p
.002 w
.38551 .42581 m .35243 .46301 L .33594 .43687 L p
1 g
F P
s
P
p
.002 w
.33594 .43687 m .37143 .39597 L .38551 .42581 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55539 .58092 m .55736 .57322 L .59026 .5635 L p
1 g
F P
s
P
p
.002 w
.58698 .54875 m .59026 .5635 L .55736 .57322 L p
1 g
F P
s
P
p
.002 w
.59026 .5635 m .58698 .54875 L .61571 .52821 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.62166 .48006 m .64071 .50494 L .61571 .52821 L p
1 g
F P
s
P
p
.002 w
.64071 .50494 m .62166 .48006 L .63893 .44959 L p
1 g
F P
s
P
p
.002 w
.42779 .5347 m .41855 .55729 L .38779 .54223 L p
1 g
F P
s
P
p
.002 w
.38779 .54223 m .39912 .51285 L .42779 .5347 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55736 .57322 m .55552 .56579 L .58698 .54875 L p
1 g
F P
s
P
p
.002 w
.5533 .31409 m .6157 .33044 L .61449 .36024 L p
1 g
F P
s
P
p
.002 w
.6157 .33044 m .5533 .31409 L .55019 .28743 L p
1 g
F P
s
P
p
.002 w
.60973 .39283 m .6518 .41894 L .63893 .44959 L p
1 g
F P
s
P
p
.002 w
.6518 .41894 m .60973 .39283 L .61449 .36024 L p
1 g
F P
s
P
p
.002 w
.42444 .36422 m .37143 .39597 L .36151 .36779 L p
1 g
F P
s
P
p
.002 w
.36151 .36779 m .41684 .33413 L .42444 .36422 L p
1 g
F P
s
P
p
.002 w
.47977 .28848 m .55019 .28743 L .5533 .31409 L p
1 g
F P
s
P
p
.002 w
.60056 .50923 m .61571 .52821 L .58698 .54875 L p
1 g
F P
s
P
p
.002 w
.61571 .52821 m .60056 .50923 L .62166 .48006 L p
1 g
F P
s
P
p
.002 w
.48382 .31529 m .41684 .33413 L .41193 .30772 L p
1 g
F P
s
P
p
.002 w
.41193 .30772 m .47977 .28848 L .48382 .31529 L p
1 g
F P
s
P
p
.002 w
.40334 .45624 m .37371 .48865 L .35243 .46301 L p
1 g
F P
s
P
p
.002 w
.35243 .46301 m .38551 .42581 L .40334 .45624 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.57637 .53602 m .58698 .54875 L .55552 .56579 L p
1 g
F P
s
P
p
.002 w
.58698 .54875 m .57637 .53602 L .60056 .50923 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.5533 .31409 m .48382 .31529 L .47977 .28848 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60152 .42707 m .63893 .44959 L .62166 .48006 L p
1 g
F P
s
P
p
.002 w
.63893 .44959 m .60152 .42707 L .60973 .39283 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.4243 .48611 m .39912 .51285 L .37371 .48865 L p
1 g
F P
s
P
p
.002 w
.37371 .48865 m .40334 .45624 L .4243 .48611 L p
1 g
F P
s
P
p
.002 w
.55001 .55945 m .54138 .55493 L .55942 .52684 L p
1 g
F P
s
P
p
.002 w
.49763 .56139 m .49062 .56822 L .45868 .55338 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.55484 .34506 m .61449 .36024 L .60973 .39283 L p
1 g
F P
s
P
p
.002 w
.61449 .36024 m .55484 .34506 L .5533 .31409 L p
1 g
F P
s
P
p
.002 w
.43455 .39696 m .38551 .42581 L .37143 .39597 L p
1 g
F P
s
P
p
.002 w
.37143 .39597 m .42444 .36422 L .43455 .39696 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59009 .46169 m .62166 .48006 L .60056 .50923 L p
1 g
F P
s
P
p
.002 w
.62166 .48006 m .59009 .46169 L .60152 .42707 L p
1 g
F P
s
P
p
.002 w
.54138 .55493 m .53058 .55275 L .53796 .52234 L p
1 g
F P
s
P
p
.002 w
.53796 .52234 m .55942 .52684 L .54138 .55493 L p
1 g
F P
s
P
p
.002 w
.45868 .55338 m .47237 .53967 L .49763 .56139 L p
1 g
F P
s
P
p
.002 w
.50739 .55617 m .49763 .56139 L .47237 .53967 L p
1 g
F P
s
P
p
.002 w
.57588 .49537 m .60056 .50923 L .57637 .53602 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48382 .31529 m .5533 .31409 L .55484 .34506 L p
1 g
F P
s
P
p
.002 w
.60056 .50923 m .57588 .49537 L .59009 .46169 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48847 .34636 m .42444 .36422 L .41684 .33413 L p
1 g
F P
s
P
p
.002 w
.41684 .33413 m .48382 .31529 L .48847 .34636 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.53058 .55275 m .5188 .55318 L .51446 .52313 L p
1 g
F P
s
P
p
.002 w
.51446 .52313 m .53796 .52234 L .53058 .55275 L p
1 g
F P
s
P
p
.002 w
.5188 .55318 m .50739 .55617 L .4917 .52916 L p
1 g
F P
s
P
p
.002 w
.47237 .53967 m .4917 .52916 L .50739 .55617 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4917 .52916 m .51446 .52313 L .5188 .55318 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55484 .34506 m .48847 .34636 L .48382 .31529 L p
1 g
F P
s
P
p
.002 w
.5547 .37929 m .60973 .39283 L .60152 .42707 L p
1 g
F P
s
P
p
.002 w
.60973 .39283 m .5547 .37929 L .55484 .34506 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44683 .43115 m .40334 .45624 L .38551 .42581 L p
1 g
F P
s
P
p
.002 w
.38551 .42581 m .43455 .39696 L .44683 .43115 L p
1 g
F P
s
P
p
.002 w
.55942 .52684 m .53796 .52234 L .54431 .48848 L p
1 g
F P
s
P
p
.002 w
.4917 .52916 m .47237 .53967 L .44761 .51428 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.55285 .41555 m .60152 .42707 L .59009 .46169 L p
1 g
F P
s
P
p
.002 w
.60152 .42707 m .55285 .41555 L .5547 .37929 L p
1 g
F P
s
P
p
.002 w
.48847 .34636 m .55484 .34506 L .5547 .37929 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.49357 .38066 m .43455 .39696 L .42444 .36422 L p
1 g
F P
s
P
p
.002 w
.42444 .36422 m .48847 .34636 L .49357 .38066 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46082 .46546 m .4243 .48611 L .40334 .45624 L p
1 g
F P
s
P
p
.002 w
.40334 .45624 m .44683 .43115 L .46082 .46546 L p
1 g
F P
s
P
p
.002 w
.54934 .45242 m .59009 .46169 L .57588 .49537 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53796 .52234 m .51446 .52313 L .50958 .48956 L p
1 g
F P
s
P
p
.002 w
.50958 .48956 m .54431 .48848 L .53796 .52234 L p
1 g
F P
s
P
p
.002 w
.51446 .52313 m .4917 .52916 L .47598 .49855 L p
1 g
F P
s
P
p
.002 w
.44761 .51428 m .47598 .49855 L .4917 .52916 L p
1 g
F P
s
P
p
.002 w
.59009 .46169 m .54934 .45242 L .55285 .41555 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47598 .49855 m .50958 .48956 L .51446 .52313 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5547 .37929 m .49357 .38066 L .48847 .34636 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.52998 .6284 m
.53159 .639 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49357 .38066 m .5547 .37929 L .55285 .41555 L p
1 g
F P
s
P
p
.002 w
.49893 .41691 m .44683 .43115 L .43455 .39696 L p
1 g
F P
s
P
p
.004 w
.48604 .42043 m
.5 .43051 L
s
P
p
.002 w
.43455 .39696 m .49357 .38066 L .49893 .41691 L p
1 g
F P
s
P
p
.004 w
.43152 .38105 m
.45648 .39908 L
s
P
p
.004 w
.45648 .39908 m
.45822 .40034 L
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49893 .41691 m .55285 .41555 L .54934 .45242 L p
1 g
F P
s
P
p
.002 w
.55285 .41555 m .49893 .41691 L .49357 .38066 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54934 .45242 m .50434 .45369 L .49893 .41691 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50434 .45369 m .46082 .46546 L .44683 .43115 L p
1 g
F P
s
P
p
.002 w
.44683 .43115 m .49893 .41691 L .50434 .45369 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .43152 .38105 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .53554 .6651 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.206202)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.206202)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.43261 .45148 m .47772 .46534 L .48255 .43735 L p
1 g
F P
s
P
p
.002 w
.48255 .43735 m .44308 .42505 L .43261 .45148 L p
1 g
F P
s
P
p
.002 w
.52438 .44005 m .48255 .43735 L .47772 .46534 L p
1 g
F P
s
P
p
.002 w
.44308 .42505 m .48255 .43735 L .4878 .40926 L p
1 g
F P
s
P
p
.002 w
.48255 .43735 m .52438 .44005 L .52274 .41149 L p
1 g
F P
s
P
p
.002 w
.52274 .41149 m .4878 .40926 L .48255 .43735 L p
1 g
F P
s
P
p
.002 w
.4878 .40926 m .45489 .39886 L .44308 .42505 L p
1 g
F P
s
P
p
.002 w
.45489 .39886 m .4878 .40926 L .49337 .38157 L p
1 g
F P
s
P
p
.002 w
.4878 .40926 m .52274 .41149 L .52054 .38329 L p
1 g
F P
s
P
p
.002 w
.52054 .38329 m .49337 .38157 L .4878 .40926 L p
1 g
F P
s
P
p
.002 w
.47772 .46534 m .52544 .46844 L .52438 .44005 L p
1 g
F P
s
P
p
.002 w
.56482 .43287 m .52438 .44005 L .52544 .46844 L p
1 g
F P
s
P
p
.002 w
.52438 .44005 m .56482 .43287 L .55646 .40534 L p
1 g
F P
s
P
p
.002 w
.55646 .40534 m .52274 .41149 L .52438 .44005 L p
1 g
F P
s
P
p
.002 w
.52274 .41149 m .55646 .40534 L .54672 .37838 L p
1 g
F P
s
P
p
.002 w
.54672 .37838 m .52054 .38329 L .52274 .41149 L p
1 g
F P
s
P
p
.002 w
.42369 .47766 m .47338 .49272 L .47772 .46534 L p
1 g
F P
s
P
p
.002 w
.47772 .46534 m .43261 .45148 L .42369 .47766 L p
1 g
F P
s
P
p
.002 w
.52544 .46844 m .47772 .46534 L .47338 .49272 L p
1 g
F P
s
P
p
.002 w
.47338 .49272 m .52589 .49615 L .52544 .46844 L p
1 g
F P
s
P
p
.002 w
.57163 .46047 m .52544 .46844 L .52589 .49615 L p
1 g
F P
s
P
p
.002 w
.52544 .46844 m .57163 .46047 L .56482 .43287 L p
1 g
F P
s
P
p
.002 w
.49337 .38157 m .46782 .37338 L .45489 .39886 L p
1 g
F P
s
P
p
.002 w
.46782 .37338 m .49337 .38157 L .49916 .35478 L p
1 g
F P
s
P
p
.002 w
.49337 .38157 m .52054 .38329 L .51782 .35595 L p
1 g
F P
s
P
p
.002 w
.51782 .35595 m .49916 .35478 L .49337 .38157 L p
1 g
F P
s
P
p
.002 w
.52054 .38329 m .54672 .37838 L .53576 .3525 L p
1 g
F P
s
P
p
.002 w
.53576 .3525 m .51782 .35595 L .52054 .38329 L p
1 g
F P
s
P
p
.002 w
.40961 .4041 m .44308 .42505 L .45489 .39886 L p
1 g
F P
s
P
p
.002 w
.45489 .39886 m .42713 .38116 L .40961 .4041 L p
1 g
F P
s
P
p
.002 w
.42713 .38116 m .45489 .39886 L .46782 .37338 L p
1 g
F P
s
P
p
.002 w
.39419 .42788 m .43261 .45148 L .44308 .42505 L p
1 g
F P
s
P
p
.002 w
.44308 .42505 m .40961 .4041 L .39419 .42788 L p
1 g
F P
s
P
p
.002 w
.58575 .39123 m .55646 .40534 L .56482 .43287 L p
1 g
F P
s
P
p
.002 w
.55646 .40534 m .58575 .39123 L .56933 .36723 L p
1 g
F P
s
P
p
.002 w
.56933 .36723 m .54672 .37838 L .55646 .40534 L p
1 g
F P
s
P
p
.002 w
.60011 .41628 m .56482 .43287 L .57163 .46047 L p
1 g
F P
s
P
p
.002 w
.56482 .43287 m .60011 .41628 L .58575 .39123 L p
1 g
F P
s
P
p
.002 w
.46782 .37338 m .4464 .35946 L .42713 .38116 L p
1 g
F P
s
P
p
.002 w
.4464 .35946 m .46782 .37338 L .48165 .34909 L p
1 g
F P
s
P
p
.002 w
.49916 .35478 m .48165 .34909 L .46782 .37338 L p
1 g
F P
s
P
p
.002 w
.41651 .50309 m .46963 .51898 L .47338 .49272 L p
1 g
F P
s
P
p
.002 w
.47338 .49272 m .42369 .47766 L .41651 .50309 L p
1 g
F P
s
P
p
.002 w
.52589 .49615 m .47338 .49272 L .46963 .51898 L p
1 g
F P
s
P
p
.002 w
.54672 .37838 m .56933 .36723 L .55116 .34473 L p
1 g
F P
s
P
p
.002 w
.55116 .34473 m .53576 .3525 L .54672 .37838 L p
1 g
F P
s
P
p
.002 w
.46963 .51898 m .5257 .52266 L .52589 .49615 L p
1 g
F P
s
P
p
.002 w
.57675 .48762 m .52589 .49615 L .5257 .52266 L p
1 g
F P
s
P
p
.002 w
.52589 .49615 m .57675 .48762 L .57163 .46047 L p
1 g
F P
s
P
p
.002 w
.38119 .45203 m .42369 .47766 L .43261 .45148 L p
1 g
F P
s
P
p
.002 w
.43261 .45148 m .39419 .42788 L .38119 .45203 L p
1 g
F P
s
P
p
.002 w
.48165 .34909 m .49916 .35478 L .50506 .32941 L p
1 g
F P
s
P
p
.002 w
.49916 .35478 m .51782 .35595 L .51461 .33001 L p
1 g
F P
s
P
p
.002 w
.51461 .33001 m .50506 .32941 L .49916 .35478 L p
1 g
F P
s
P
p
.002 w
.51782 .35595 m .53576 .3525 L .52377 .3282 L p
1 g
F P
s
P
p
.002 w
.52377 .3282 m .51461 .33001 L .51782 .35595 L p
1 g
F P
s
P
p
.002 w
.61211 .44189 m .57163 .46047 L .57675 .48762 L p
1 g
F P
s
P
p
.002 w
.57163 .46047 m .61211 .44189 L .60011 .41628 L p
1 g
F P
s
P
p
.002 w
.48165 .34909 m .46706 .33944 L .4464 .35946 L p
1 g
F P
s
P
p
.002 w
.46706 .33944 m .48165 .34909 L .49612 .32647 L p
1 g
F P
s
P
p
.002 w
.50506 .32941 m .49612 .32647 L .48165 .34909 L p
1 g
F P
s
P
p
.002 w
.53576 .3525 m .55116 .34473 L .53159 .32417 L p
1 g
F P
s
P
p
.002 w
.53159 .32417 m .52377 .3282 L .53576 .3525 L p
1 g
F P
s
P
p
.002 w
.38552 .37619 m .40961 .4041 L .42713 .38116 L p
1 g
F P
s
P
p
.002 w
.42713 .38116 m .40737 .35766 L .38552 .37619 L p
1 g
F P
s
P
p
.002 w
.40737 .35766 m .42713 .38116 L .4464 .35946 L p
1 g
F P
s
P
p
.002 w
.4464 .35946 m .43133 .34107 L .40737 .35766 L p
1 g
F P
s
P
p
.002 w
.43133 .34107 m .4464 .35946 L .46706 .33944 L p
1 g
F P
s
P
p
.002 w
.37095 .47608 m .41651 .50309 L .42369 .47766 L p
1 g
F P
s
P
p
.002 w
.42369 .47766 m .38119 .45203 L .37095 .47608 L p
1 g
F P
s
P
p
.002 w
.41127 .52725 m .46656 .54358 L .46963 .51898 L p
1 g
F P
s
P
p
.002 w
.46963 .51898 m .41651 .50309 L .41127 .52725 L p
1 g
F P
s
P
p
.002 w
.5257 .52266 m .46963 .51898 L .46656 .54358 L p
1 g
F P
s
P
p
.002 w
.58602 .3508 m .56933 .36723 L .58575 .39123 L p
1 g
F P
s
P
p
.002 w
.56933 .36723 m .58602 .3508 L .5624 .33336 L p
1 g
F P
s
P
p
.002 w
.5624 .33336 m .55116 .34473 L .56933 .36723 L p
1 g
F P
s
P
p
.002 w
.36627 .39633 m .39419 .42788 L .40961 .4041 L p
1 g
F P
s
P
p
.002 w
.40961 .4041 m .38552 .37619 L .36627 .39633 L p
1 g
F P
s
P
p
.002 w
.6076 .3703 m .58575 .39123 L .60011 .41628 L p
1 g
F P
s
P
p
.002 w
.58575 .39123 m .6076 .3703 L .58602 .3508 L p
1 g
F P
s
P
p
.002 w
.46656 .54358 m .52488 .54743 L .5257 .52266 L p
1 g
F P
s
P
p
.002 w
.58006 .5138 m .5257 .52266 L .52488 .54743 L p
1 g
F P
s
P
p
.002 w
.5257 .52266 m .58006 .5138 L .57675 .48762 L p
1 g
F P
s
P
p
.002 w
.62148 .46757 m .57675 .48762 L .58006 .5138 L p
1 g
F P
s
P
p
.002 w
.57675 .48762 m .62148 .46757 L .61211 .44189 L p
1 g
F P
s
P
p
.002 w
.46706 .33944 m .45693 .32675 L .43133 .34107 L p
1 g
F P
s
P
p
.002 w
.45693 .32675 m .46706 .33944 L .48872 .32149 L p
1 g
F P
s
P
p
.002 w
.49612 .32647 m .48872 .32149 L .46706 .33944 L p
1 g
F P
s
P
p
.002 w
.55116 .34473 m .5624 .33336 L .53722 .31832 L p
1 g
F P
s
P
p
.002 w
.53722 .31832 m .53159 .32417 L .55116 .34473 L p
1 g
F P
s
P
p
.002 w
.62669 .3915 m .60011 .41628 L .61211 .44189 L p
1 g
F P
s
P
p
.002 w
.60011 .41628 m .62669 .3915 L .6076 .3703 L p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .49612 .32647 L .50506 .32941 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .50506 .32941 L .51461 .33001 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .51461 .33001 L .52377 .3282 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .48872 .32149 L .49612 .32647 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .52377 .3282 L .53159 .32417 L closepath p
1 g
F P
s
P
p
.002 w
.35008 .41769 m .38119 .45203 L .39419 .42788 L p
1 g
F P
s
P
p
.002 w
.39419 .42788 m .36627 .39633 L .35008 .41769 L p
1 g
F P
s
P
p
.002 w
.48872 .32149 m .48365 .31497 L .45693 .32675 L p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .48365 .31497 L .48872 .32149 L closepath p
1 g
F P
s
P
p
.002 w
.36375 .49953 m .41127 .52725 L .41651 .50309 L p
1 g
F P
s
P
p
.002 w
.41651 .50309 m .37095 .47608 L .36375 .49953 L p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .53159 .32417 L .53722 .31832 L closepath p
1 g
F P
s
P
p
.002 w
.42437 .31996 m .43133 .34107 L .45693 .32675 L p
1 g
F P
s
P
p
.002 w
.45693 .32675 m .45242 .31228 L .42437 .31996 L p
1 g
F P
s
P
p
.002 w
.45242 .31228 m .45693 .32675 L .48365 .31497 L p
1 g
F P
s
P
p
.002 w
.64285 .41398 m .61211 .44189 L .62148 .46757 L p
1 g
F P
s
P
p
.002 w
.61211 .44189 m .64285 .41398 L .62669 .3915 L p
1 g
F P
s
P
p
.002 w
.39792 .3305 m .40737 .35766 L .43133 .34107 L p
1 g
F P
s
P
p
.002 w
.43133 .34107 m .42437 .31996 L .39792 .3305 L p
1 g
F P
s
P
p
.002 w
.5682 .31951 m .5624 .33336 L .58602 .3508 L p
1 g
F P
s
P
p
.002 w
.5624 .33336 m .5682 .31951 L .54004 .31125 L p
1 g
F P
s
P
p
.002 w
.54004 .31125 m .53722 .31832 L .5624 .33336 L p
1 g
F P
s
P
p
.002 w
.52488 .54743 m .58143 .53845 L .58006 .5138 L p
1 g
F P
s
P
p
.002 w
.62797 .4928 m .58006 .5138 L .58143 .53845 L p
1 g
F P
s
P
p
.002 w
.58006 .5138 m .62797 .4928 L .62148 .46757 L p
1 g
F P
s
P
p
.002 w
.48365 .31497 m .48149 .3076 L .45242 .31228 L p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .48149 .3076 L .48365 .31497 L closepath p
1 g
F P
s
P
p
.002 w
.59487 .33062 m .58602 .3508 L .6076 .3703 L p
1 g
F P
s
P
p
.002 w
.58602 .3508 m .59487 .33062 L .5682 .31951 L p
1 g
F P
s
P
p
.002 w
.37368 .34376 m .38552 .37619 L .40737 .35766 L p
1 g
F P
s
P
p
.002 w
.40737 .35766 m .39792 .3305 L .37368 .34376 L p
1 g
F P
s
P
p
.002 w
.40814 .5496 m .46425 .56597 L .46656 .54358 L p
1 g
F P
s
P
p
.002 w
.46656 .54358 m .41127 .52725 L .40814 .5496 L p
1 g
F P
s
P
p
.002 w
.52488 .54743 m .46656 .54358 L .46425 .56597 L p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .53722 .31832 L .54004 .31125 L closepath p
1 g
F P
s
P
p
.002 w
.46425 .56597 m .5234 .5699 L .52488 .54743 L p
1 g
F P
s
P
p
.002 w
.58143 .53845 m .52488 .54743 L .5234 .5699 L p
1 g
F P
s
P
p
.002 w
.33739 .43984 m .37095 .47608 L .38119 .45203 L p
1 g
F P
s
P
p
.002 w
.38119 .45203 m .35008 .41769 L .33739 .43984 L p
1 g
F P
s
P
p
.002 w
.61947 .34441 m .6076 .3703 L .62669 .3915 L p
1 g
F P
s
P
p
.002 w
.6076 .3703 m .61947 .34441 L .59487 .33062 L p
1 g
F P
s
P
p
.002 w
.45415 .29755 m .45242 .31228 L .48149 .3076 L p
1 g
F P
s
P
p
.002 w
.48149 .3076 m .48249 .30016 L .45415 .29755 L p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .48249 .30016 L .48149 .3076 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .50214 .28512 L .49339 .28825 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .49339 .28825 L .4866 .29346 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .4866 .29346 L .48249 .30016 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .54004 .31125 L .5397 .30372 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .5397 .30372 L .53621 .29654 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .53621 .29654 L .52992 .29051 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .52992 .29051 L .52149 .28632 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .52149 .28632 L .51187 .28445 L closepath p
1 g
F P
s
P
p
.002 w
.51097 .30599 m .51187 .28445 L .50214 .28512 L closepath p
1 g
F P
s
P
p
.002 w
.5397 .30372 m .54004 .31125 L .5682 .31951 L p
1 g
F P
s
P
p
.002 w
.35221 .3595 m .36627 .39633 L .38552 .37619 L p
1 g
F P
s
P
p
.002 w
.38552 .37619 m .37368 .34376 L .35221 .3595 L p
1 g
F P
s
P
p
.002 w
.65566 .4373 m .62148 .46757 L .62797 .4928 L p
1 g
F P
s
P
p
.002 w
.62148 .46757 m .65566 .4373 L .64285 .41398 L p
1 g
F P
s
P
p
.002 w
.42655 .29828 m .42437 .31996 L .45242 .31228 L p
1 g
F P
s
P
p
.002 w
.45242 .31228 m .45415 .29755 L .42655 .29828 L p
1 g
F P
s
P
p
.002 w
.56779 .30461 m .5682 .31951 L .59487 .33062 L p
1 g
F P
s
P
p
.002 w
.5682 .31951 m .56779 .30461 L .5397 .30372 L p
1 g
F P
s
P
p
.002 w
.35987 .52184 m .40814 .5496 L .41127 .52725 L p
1 g
F P
s
P
p
.002 w
.41127 .52725 m .36375 .49953 L .35987 .52184 L p
1 g
F P
s
P
p
.002 w
.4621 .28416 m .45415 .29755 L .48249 .30016 L p
1 g
F P
s
P
p
.002 w
.48249 .30016 m .4866 .29346 L .4621 .28416 L p
1 g
F P
s
P
p
.002 w
.64143 .36062 m .62669 .3915 L .64285 .41398 L p
1 g
F P
s
P
p
.002 w
.62669 .3915 m .64143 .36062 L .61947 .34441 L p
1 g
F P
s
P
p
.002 w
.53621 .29654 m .5397 .30372 L .56779 .30461 L p
1 g
F P
s
P
p
.002 w
.40031 .30241 m .39792 .3305 L .42437 .31996 L p
1 g
F P
s
P
p
.002 w
.42437 .31996 m .42655 .29828 L .40031 .30241 L p
1 g
F P
s
P
p
.002 w
.5234 .5699 m .58076 .56102 L .58143 .53845 L p
1 g
F P
s
P
p
.002 w
.63134 .51704 m .58143 .53845 L .58076 .56102 L p
1 g
F P
s
P
p
.002 w
.58143 .53845 m .63134 .51704 L .62797 .4928 L p
1 g
F P
s
P
p
.002 w
.32861 .46232 m .36375 .49953 L .37095 .47608 L p
1 g
F P
s
P
p
.002 w
.37095 .47608 m .33739 .43984 L .32861 .46232 L p
1 g
F P
s
P
p
.002 w
.47552 .27367 m .4621 .28416 L .4866 .29346 L p
1 g
F P
s
P
p
.002 w
.4866 .29346 m .49339 .28825 L .47552 .27367 L p
1 g
F P
s
P
p
.002 w
.59462 .30873 m .59487 .33062 L .61947 .34441 L p
1 g
F P
s
P
p
.002 w
.59487 .33062 m .59462 .30873 L .56779 .30461 L p
1 g
F P
s
P
p
.002 w
.3341 .37745 m .35008 .41769 L .36627 .39633 L p
1 g
F P
s
P
p
.002 w
.36627 .39633 m .35221 .3595 L .3341 .37745 L p
1 g
F P
s
P
p
.002 w
.56779 .30461 m .56106 .2903 L .53621 .29654 L p
1 g
F P
s
P
p
.002 w
.52992 .29051 m .53621 .29654 L .56106 .2903 L p
1 g
F P
s
P
p
.002 w
.40728 .56957 m .46278 .5856 L .46425 .56597 L p
1 g
F P
s
P
p
.002 w
.46425 .56597 m .40814 .5496 L .40728 .56957 L p
1 g
F P
s
P
p
.002 w
.5234 .5699 m .46425 .56597 L .46278 .5856 L p
1 g
F P
s
P
p
.002 w
.438 .27842 m .42655 .29828 L .45415 .29755 L p
1 g
F P
s
P
p
.002 w
.45415 .29755 m .4621 .28416 L .438 .27842 L p
1 g
F P
s
P
p
.002 w
.46278 .5856 m .52128 .5895 L .5234 .5699 L p
1 g
F P
s
P
p
.002 w
.58076 .56102 m .5234 .5699 L .52128 .5895 L p
1 g
F P
s
P
p
.002 w
.66474 .46096 m .62797 .4928 L .63134 .51704 L p
1 g
F P
s
P
p
.002 w
.62797 .4928 m .66474 .46096 L .65566 .4373 L p
1 g
F P
s
P
p
.002 w
.49298 .26734 m .47552 .27367 L .49339 .28825 L p
1 g
F P
s
P
p
.002 w
.49339 .28825 m .50214 .28512 L .49298 .26734 L p
1 g
F P
s
P
p
.002 w
.37605 .30998 m .37368 .34376 L .39792 .3305 L p
1 g
F P
s
P
p
.002 w
.39792 .3305 m .40031 .30241 L .37605 .30998 L p
1 g
F P
s
P
p
.002 w
.56106 .2903 m .56779 .30461 L .59462 .30873 L p
1 g
F P
s
P
p
.002 w
.56106 .2903 m .54862 .27819 L .52992 .29051 L p
1 g
F P
s
P
p
.002 w
.52149 .28632 m .52992 .29051 L .54862 .27819 L p
1 g
F P
s
P
p
.002 w
.66018 .37898 m .64285 .41398 L .65566 .4373 L p
1 g
F P
s
P
p
.002 w
.64285 .41398 m .66018 .37898 L .64143 .36062 L p
1 g
F P
s
P
p
.002 w
.5125 .26597 m .49298 .26734 L .50214 .28512 L p
1 g
F P
s
P
p
.002 w
.50214 .28512 m .51187 .28445 L .5125 .26597 L p
1 g
F P
s
P
p
.002 w
.54862 .27819 m .53179 .26974 L .52149 .28632 L p
1 g
F P
s
P
p
.002 w
.51187 .28445 m .52149 .28632 L .53179 .26974 L p
1 g
F P
s
P
p
.002 w
.53179 .26974 m .5125 .26597 L .51187 .28445 L p
1 g
F P
s
P
p
.002 w
.61958 .31608 m .61947 .34441 L .64143 .36062 L p
1 g
F P
s
P
p
.002 w
.61947 .34441 m .61958 .31608 L .59462 .30873 L p
1 g
F P
s
P
p
.002 w
.35954 .54245 m .40728 .56957 L .40814 .5496 L p
1 g
F P
s
P
p
.002 w
.40814 .5496 m .35987 .52184 L .35954 .54245 L p
1 g
F P
s
P
p
.002 w
.3199 .39727 m .33739 .43984 L .35008 .41769 L p
1 g
F P
s
P
p
.002 w
.35008 .41769 m .3341 .37745 L .3199 .39727 L p
1 g
F P
s
P
p
.002 w
.45774 .26273 m .438 .27842 L .4621 .28416 L p
1 g
F P
s
P
p
.002 w
.4621 .28416 m .47552 .27367 L .45774 .26273 L p
1 g
F P
s
P
p
.002 w
.41487 .27648 m .40031 .30241 L .42655 .29828 L p
1 g
F P
s
P
p
.002 w
.42655 .29828 m .438 .27842 L .41487 .27648 L p
1 g
F P
s
P
p
.002 w
.32411 .4846 m .35987 .52184 L .36375 .49953 L p
1 g
F P
s
P
p
.002 w
.36375 .49953 m .32861 .46232 L .32411 .4846 L p
1 g
F P
s
P
p
.002 w
.59462 .30873 m .58496 .28751 L .56106 .2903 L p
1 g
F P
s
P
p
.002 w
.54862 .27819 m .56106 .2903 L .58496 .28751 L p
1 g
F P
s
P
p
.002 w
.35443 .32092 m .35221 .3595 L .37368 .34376 L p
1 g
F P
s
P
p
.002 w
.37368 .34376 m .37605 .30998 L .35443 .32092 L p
1 g
F P
s
P
p
.002 w
.52128 .5895 m .57798 .58091 L .58076 .56102 L p
1 g
F P
s
P
p
.002 w
.63139 .5397 m .58076 .56102 L .57798 .58091 L p
1 g
F P
s
P
p
.002 w
.58076 .56102 m .63139 .5397 L .63134 .51704 L p
1 g
F P
s
P
p
.002 w
.58496 .28751 m .59462 .30873 L .61958 .31608 L p
1 g
F P
s
P
p
.002 w
.6752 .39913 m .65566 .4373 L .66474 .46096 L p
1 g
F P
s
P
p
.002 w
.65566 .4373 m .6752 .39913 L .66018 .37898 L p
1 g
F P
s
P
p
.002 w
.66974 .48445 m .63134 .51704 L .63139 .5397 L p
1 g
F P
s
P
p
.002 w
.63134 .51704 m .66974 .48445 L .66474 .46096 L p
1 g
F P
s
P
p
.002 w
.64203 .32659 m .64143 .36062 L .66018 .37898 L p
1 g
F P
s
P
p
.002 w
.64143 .36062 m .64203 .32659 L .61958 .31608 L p
1 g
F P
s
P
p
.002 w
.48368 .2532 m .45774 .26273 L .47552 .27367 L p
1 g
F P
s
P
p
.002 w
.47552 .27367 m .49298 .26734 L .48368 .2532 L p
1 g
F P
s
P
p
.002 w
.40884 .58659 m .46223 .60189 L .46278 .5856 L p
1 g
F P
s
P
p
.002 w
.46278 .5856 m .40728 .56957 L .40884 .58659 L p
1 g
F P
s
P
p
.002 w
.52128 .5895 m .46278 .5856 L .46223 .60189 L p
1 g
F P
s
P
p
.002 w
.58496 .28751 m .56665 .26944 L .54862 .27819 L p
1 g
F P
s
P
p
.002 w
.53179 .26974 m .54862 .27819 L .56665 .26944 L p
1 g
F P
s
P
p
.002 w
.46223 .60189 m .51853 .60566 L .52128 .5895 L p
1 g
F P
s
P
p
.002 w
.57798 .58091 m .52128 .5895 L .51853 .60566 L p
1 g
F P
s
P
p
.002 w
.39328 .27858 m .37605 .30998 L .40031 .30241 L p
1 g
F P
s
P
p
.002 w
.40031 .30241 m .41487 .27648 L .39328 .27858 L p
1 g
F P
s
P
p
.002 w
.31011 .41854 m .32861 .46232 L .33739 .43984 L p
1 g
F P
s
P
p
.002 w
.33739 .43984 m .3199 .39727 L .31011 .41854 L p
1 g
F P
s
P
p
.002 w
.51282 .25111 m .48368 .2532 L .49298 .26734 L p
1 g
F P
s
P
p
.002 w
.49298 .26734 m .5125 .26597 L .51282 .25111 L p
1 g
F P
s
P
p
.002 w
.56665 .26944 m .54163 .25677 L .53179 .26974 L p
1 g
F P
s
P
p
.002 w
.5125 .26597 m .53179 .26974 L .54163 .25677 L p
1 g
F P
s
P
p
.002 w
.33607 .3351 m .3341 .37745 L .35221 .3595 L p
1 g
F P
s
P
p
.002 w
.35221 .3595 m .35443 .32092 L .33607 .3351 L p
1 g
F P
s
P
p
.002 w
.44047 .25586 m .41487 .27648 L .438 .27842 L p
1 g
F P
s
P
p
.002 w
.438 .27842 m .45774 .26273 L .44047 .25586 L p
1 g
F P
s
P
p
.002 w
.54163 .25677 m .51282 .25111 L .5125 .26597 L p
1 g
F P
s
P
p
.002 w
.60732 .28839 m .61958 .31608 L .64203 .32659 L p
1 g
F P
s
P
p
.002 w
.61958 .31608 m .60732 .28839 L .58496 .28751 L p
1 g
F P
s
P
p
.002 w
.56665 .26944 m .58496 .28751 L .60732 .28839 L p
1 g
F P
s
P
p
.002 w
.36296 .56079 m .40884 .58659 L .40728 .56957 L p
1 g
F P
s
P
p
.002 w
.40728 .56957 m .35954 .54245 L .36296 .56079 L p
1 g
F P
s
P
p
.002 w
.32419 .50614 m .35954 .54245 L .35987 .52184 L p
1 g
F P
s
P
p
.002 w
.35987 .52184 m .32411 .4846 L .32419 .50614 L p
1 g
F P
s
P
p
.002 w
.68597 .42065 m .66474 .46096 L .66974 .48445 L p
1 g
F P
s
P
p
.002 w
.66474 .46096 m .68597 .42065 L .6752 .39913 L p
1 g
F P
s
P
p
.002 w
.66133 .34014 m .66018 .37898 L .6752 .39913 L p
1 g
F P
s
P
p
.002 w
.66018 .37898 m .66133 .34014 L .64203 .32659 L p
1 g
F P
s
P
p
.002 w
.51853 .60566 m .57304 .59755 L .57798 .58091 L p
1 g
F P
s
P
p
.002 w
.62799 .5602 m .57798 .58091 L .57304 .59755 L p
1 g
F P
s
P
p
.002 w
.57798 .58091 m .62799 .5602 L .63139 .5397 L p
1 g
F P
s
P
p
.002 w
.67038 .5072 m .63139 .5397 L .62799 .5602 L p
1 g
F P
s
P
p
.002 w
.63139 .5397 m .67038 .5072 L .66974 .48445 L p
1 g
F P
s
P
p
.002 w
.37386 .28483 m .35443 .32092 L .37605 .30998 L p
1 g
F P
s
P
p
.002 w
.37605 .30998 m .39328 .27858 L .37386 .28483 L p
1 g
F P
s
P
p
.002 w
.47446 .24325 m .44047 .25586 L .45774 .26273 L p
1 g
F P
s
P
p
.002 w
.45774 .26273 m .48368 .2532 L .47446 .24325 L p
1 g
F P
s
P
p
.002 w
.3216 .35232 m .3199 .39727 L .3341 .37745 L p
1 g
F P
s
P
p
.002 w
.3341 .37745 m .33607 .3351 L .3216 .35232 L p
1 g
F P
s
P
p
.002 w
.60732 .28839 m .58355 .26466 L .56665 .26944 L p
1 g
F P
s
P
p
.002 w
.54163 .25677 m .56665 .26944 L .58355 .26466 L p
1 g
F P
s
P
p
.002 w
.30519 .44079 m .32411 .4846 L .32861 .46232 L p
1 g
F P
s
P
p
.002 w
.32861 .46232 m .31011 .41854 L .30519 .44079 L p
1 g
F P
s
P
p
.002 w
.41289 .60008 m .46267 .61425 L .46223 .60189 L p
1 g
F P
s
P
p
.002 w
.46223 .60189 m .40884 .58659 L .41289 .60008 L p
1 g
F P
s
P
p
.002 w
.51853 .60566 m .46223 .60189 L .46267 .61425 L p
1 g
F P
s
P
p
.002 w
.62753 .29309 m .64203 .32659 L .66133 .34014 L p
1 g
F P
s
P
p
.002 w
.64203 .32659 m .62753 .29309 L .60732 .28839 L p
1 g
F P
s
P
p
.002 w
.42417 .25344 m .39328 .27858 L .41487 .27648 L p
1 g
F P
s
P
p
.002 w
.41487 .27648 m .44047 .25586 L .42417 .25344 L p
1 g
F P
s
P
p
.002 w
.46267 .61425 m .51518 .61778 L .51853 .60566 L p
1 g
F P
s
P
p
.002 w
.57304 .59755 m .51853 .60566 L .51518 .61778 L p
1 g
F P
s
P
p
.002 w
.67688 .35653 m .6752 .39913 L .68597 .42065 L p
1 g
F P
s
P
p
.002 w
.6752 .39913 m .67688 .35653 L .66133 .34014 L p
1 g
F P
s
P
p
.002 w
.51281 .24046 m .47446 .24325 L .48368 .2532 L p
1 g
F P
s
P
p
.002 w
.48368 .2532 m .51282 .25111 L .51281 .24046 L p
1 g
F P
s
P
p
.002 w
.58355 .26466 m .60732 .28839 L .62753 .29309 L p
1 g
F P
s
P
p
.002 w
.69204 .44307 m .66974 .48445 L .67038 .5072 L p
1 g
F P
s
P
p
.002 w
.66974 .48445 m .69204 .44307 L .68597 .42065 L p
1 g
F P
s
P
p
.002 w
.58355 .26466 m .55075 .24793 L .54163 .25677 L p
1 g
F P
s
P
p
.002 w
.51282 .25111 m .54163 .25677 L .55075 .24793 L p
1 g
F P
s
P
p
.002 w
.32908 .52632 m .36296 .56079 L .35954 .54245 L p
1 g
F P
s
P
p
.002 w
.35954 .54245 m .32419 .50614 L .32908 .52632 L p
1 g
F P
s
P
p
.002 w
.55075 .24793 m .51281 .24046 L .51282 .25111 L p
1 g
F P
s
P
p
.002 w
.37023 .57626 m .41289 .60008 L .40884 .58659 L p
1 g
F P
s
P
p
.002 w
.40884 .58659 m .36296 .56079 L .37023 .57626 L p
1 g
F P
s
P
p
.002 w
.57304 .59755 m .62103 .57792 L .62799 .5602 L p
1 g
F P
s
P
p
.002 w
.66644 .52858 m .62799 .5602 L .62103 .57792 L p
1 g
F P
s
P
p
.002 w
.62799 .5602 m .66644 .52858 L .67038 .5072 L p
1 g
F P
s
P
p
.002 w
.35722 .29531 m .33607 .3351 L .35443 .32092 L p
1 g
F P
s
P
p
.002 w
.35443 .32092 m .37386 .28483 L .35722 .29531 L p
1 g
F P
s
P
p
.002 w
.51518 .61778 m .56596 .61033 L .57304 .59755 L p
1 g
F P
s
P
p
.002 w
.62103 .57792 m .57304 .59755 L .56596 .61033 L p
1 g
F P
s
P
p
.002 w
.3116 .37224 m .31011 .41854 L .3199 .39727 L p
1 g
F P
s
P
p
.002 w
.3199 .39727 m .3216 .35232 L .3116 .37224 L p
1 g
F P
s
P
p
.002 w
.3055 .46346 m .32419 .50614 L .32411 .4846 L p
1 g
F P
s
P
p
.002 w
.32411 .4846 m .30519 .44079 L .3055 .46346 L p
1 g
F P
s
P
p
.002 w
.46555 .238 m .42417 .25344 L .44047 .25586 L p
1 g
F P
s
P
p
.002 w
.44047 .25586 m .47446 .24325 L .46555 .238 L p
1 g
F P
s
P
p
.002 w
.64499 .30166 m .66133 .34014 L .67688 .35653 L p
1 g
F P
s
P
p
.002 w
.66133 .34014 m .64499 .30166 L .62753 .29309 L p
1 g
F P
s
P
p
.002 w
.40932 .25579 m .37386 .28483 L .39328 .27858 L p
1 g
F P
s
P
p
.002 w
.39328 .27858 m .42417 .25344 L .40932 .25579 L p
1 g
F P
s
P
p
.002 w
.62753 .29309 m .59883 .26418 L .58355 .26466 L p
1 g
F P
s
P
p
.002 w
.55075 .24793 m .58355 .26466 L .59883 .26418 L p
1 g
F P
s
P
p
.002 w
.68809 .37547 m .68597 .42065 L .69204 .44307 L p
1 g
F P
s
P
p
.002 w
.68597 .42065 m .68809 .37547 L .67688 .35653 L p
1 g
F P
s
P
p
.002 w
.69304 .46584 m .67038 .5072 L .66644 .52858 L p
1 g
F P
s
P
p
.002 w
.67038 .5072 m .69304 .46584 L .69204 .44307 L p
1 g
F P
s
P
p
.002 w
.59883 .26418 m .62753 .29309 L .64499 .30166 L p
1 g
F P
s
P
p
.002 w
.4195 .60948 m .46414 .62215 L .46267 .61425 L p
1 g
F P
s
P
p
.002 w
.46267 .61425 m .41289 .60008 L .4195 .60948 L p
1 g
F P
s
P
p
.002 w
.51518 .61778 m .46267 .61425 L .46414 .62215 L p
1 g
F P
s
P
p
.002 w
.46414 .62215 m .51127 .62531 L .51518 .61778 L p
1 g
F P
s
P
p
.002 w
.56596 .61033 m .51518 .61778 L .51127 .62531 L p
1 g
F P
s
P
p
.002 w
.51245 .23456 m .46555 .238 L .47446 .24325 L p
1 g
F P
s
P
p
.002 w
.47446 .24325 m .51281 .24046 L .51245 .23456 L p
1 g
F P
s
P
p
.002 w
.33888 .54453 m .37023 .57626 L .36296 .56079 L p
1 g
F P
s
P
p
.002 w
.36296 .56079 m .32908 .52632 L .33888 .54453 L p
1 g
F P
s
P
p
.002 w
.59883 .26418 m .55886 .24371 L .55075 .24793 L p
1 g
F P
s
P
p
.002 w
.51281 .24046 m .55075 .24793 L .55886 .24371 L p
1 g
F P
s
P
p
.002 w
.34398 .30993 m .3216 .35232 L .33607 .3351 L p
1 g
F P
s
P
p
.002 w
.33607 .3351 m .35722 .29531 L .34398 .30993 L p
1 g
F P
s
P
p
.002 w
.30655 .39444 m .30519 .44079 L .31011 .41854 L p
1 g
F P
s
P
p
.002 w
.31011 .41854 m .3116 .37224 L .30655 .39444 L p
1 g
F P
s
P
p
.002 w
.55886 .24371 m .51245 .23456 L .51281 .24046 L p
1 g
F P
s
P
p
.002 w
.38138 .58827 m .4195 .60948 L .41289 .60008 L p
1 g
F P
s
P
p
.002 w
.41289 .60008 m .37023 .57626 L .38138 .58827 L p
1 g
F P
s
P
p
.002 w
.56596 .61033 m .61052 .59227 L .62103 .57792 L p
1 g
F P
s
P
p
.002 w
.65779 .54798 m .62103 .57792 L .61052 .59227 L p
1 g
F P
s
P
p
.002 w
.62103 .57792 m .65779 .54798 L .66644 .52858 L p
1 g
F P
s
P
p
.002 w
.31128 .48593 m .32908 .52632 L .32419 .50614 L p
1 g
F P
s
P
p
.002 w
.32419 .50614 m .3055 .46346 L .31128 .48593 L p
1 g
F P
s
P
p
.002 w
.51127 .62531 m .55678 .61869 L .56596 .61033 L p
1 g
F P
s
P
p
.002 w
.61052 .59227 m .56596 .61033 L .55678 .61869 L p
1 g
F P
s
P
p
.002 w
.65908 .3141 m .67688 .35653 L .68809 .37547 L p
1 g
F P
s
P
p
.002 w
.67688 .35653 m .65908 .3141 L .64499 .30166 L p
1 g
F P
s
P
p
.002 w
.69444 .39655 m .69204 .44307 L .69304 .46584 L p
1 g
F P
s
P
p
.002 w
.69204 .44307 m .69444 .39655 L .68809 .37547 L p
1 g
F P
s
P
p
.002 w
.45722 .23788 m .40932 .25579 L .42417 .25344 L p
1 g
F P
s
P
p
.002 w
.42417 .25344 m .46555 .238 L .45722 .23788 L p
1 g
F P
s
P
p
.002 w
.39643 .26313 m .35722 .29531 L .37386 .28483 L p
1 g
F P
s
P
p
.002 w
.37386 .28483 m .40932 .25579 L .39643 .26313 L p
1 g
F P
s
P
p
.002 w
.68871 .48835 m .66644 .52858 L .65779 .54798 L p
1 g
F P
s
P
p
.002 w
.66644 .52858 m .68871 .48835 L .69304 .46584 L p
1 g
F P
s
P
p
.002 w
.64499 .30166 m .61199 .26827 L .59883 .26418 L p
1 g
F P
s
P
p
.002 w
.55886 .24371 m .59883 .26418 L .61199 .26827 L p
1 g
F P
s
P
p
.002 w
.61199 .26827 m .64499 .30166 L .65908 .3141 L p
1 g
F P
s
P
p
.002 w
.33471 .32849 m .3116 .37224 L .3216 .35232 L p
1 g
F P
s
P
p
.002 w
.3216 .35232 m .34398 .30993 L .33471 .32849 L p
1 g
F P
s
P
p
.002 w
.42863 .61428 m .46667 .62506 L .46414 .62215 L p
1 g
F P
s
P
p
.002 w
.46414 .62215 m .4195 .60948 L .42863 .61428 L p
1 g
F P
s
P
p
.002 w
.51127 .62531 m .46414 .62215 L .46667 .62506 L p
1 g
F P
s
P
p
.002 w
.30685 .41837 m .3055 .46346 L .30519 .44079 L p
1 g
F P
s
P
p
.002 w
.30519 .44079 m .30655 .39444 L .30685 .41837 L p
1 g
F P
s
P
p
.002 w
.46667 .62506 m .50688 .62776 L .51127 .62531 L p
1 g
F P
s
P
p
.002 w
.55678 .61869 m .51127 .62531 L .50688 .62776 L p
1 g
F P
s
P
p
.002 w
.35357 .56015 m .38138 .58827 L .37023 .57626 L p
1 g
F P
s
P
p
.002 w
.37023 .57626 m .33888 .54453 L .35357 .56015 L p
1 g
F P
s
P
p
.002 w
.51172 .23387 m .45722 .23788 L .46555 .238 L p
1 g
F P
s
P
p
.002 w
.46555 .238 m .51245 .23456 L .51172 .23387 L p
1 g
F P
s
P
p
.004 w
.47904 .66843 m
.48137 .64199 L
s
P
p
.002 w
.61199 .26827 m .56568 .24452 L .55886 .24371 L p
1 g
F P
s
P
p
.002 w
.51245 .23456 m .55886 .24371 L .56568 .24452 L p
1 g
F P
s
P
p
.002 w
.55678 .61869 m .59654 .60265 L .61052 .59227 L p
1 g
F P
s
P
p
.002 w
.61052 .59227 m .64446 .56475 L .65779 .54798 L p
1 g
F P
s
P
p
.002 w
.64446 .56475 m .61052 .59227 L .59654 .60265 L p
1 g
F P
s
P
p
.002 w
.32261 .50751 m .33888 .54453 L .32908 .52632 L p
1 g
F P
s
P
p
.002 w
.32908 .52632 m .31128 .48593 L .32261 .50751 L p
1 g
F P
s
P
p
.002 w
.68809 .37547 m .66921 .33025 L .65908 .3141 L p
1 g
F P
s
P
p
.002 w
.66921 .33025 m .68809 .37547 L .69444 .39655 L p
1 g
F P
s
P
p
.002 w
.3963 .59629 m .42863 .61428 L .4195 .60948 L p
1 g
F P
s
P
p
.002 w
.4195 .60948 m .38138 .58827 L .3963 .59629 L p
1 g
F P
s
P
p
.002 w
.69304 .46584 m .69552 .41927 L .69444 .39655 L p
1 g
F P
s
P
p
.002 w
.69552 .41927 m .69304 .46584 L .68871 .48835 L p
1 g
F P
s
P
p
.002 w
.56568 .24452 m .51172 .23387 L .51245 .23456 L p
1 g
F P
s
P
p
.002 w
.50688 .62776 m .54562 .62214 L .55678 .61869 L p
1 g
F P
s
P
p
.002 w
.59654 .60265 m .55678 .61869 L .54562 .62214 L p
1 g
F P
s
P
p
.002 w
.38598 .27555 m .34398 .30993 L .35722 .29531 L p
1 g
F P
s
P
p
.002 w
.35722 .29531 m .39643 .26313 L .38598 .27555 L p
1 g
F P
s
P
p
.002 w
.65779 .54798 m .67892 .50993 L .68871 .48835 L p
1 g
F P
s
P
p
.002 w
.67892 .50993 m .65779 .54798 L .64446 .56475 L p
1 g
F P
s
P
p
.002 w
.44975 .24323 m .39643 .26313 L .40932 .25579 L p
1 g
F P
s
P
p
.002 w
.40932 .25579 m .45722 .23788 L .44975 .24323 L p
1 g
F P
s
P
p
.002 w
.65908 .3141 m .62254 .27708 L .61199 .26827 L p
1 g
F P
s
P
p
.002 w
.62254 .27708 m .65908 .3141 L .66921 .33025 L p
1 g
F P
s
P
p
.002 w
.56568 .24452 m .61199 .26827 L .62254 .27708 L p
1 g
F P
s
P
p
.002 w
.32989 .35063 m .30655 .39444 L .3116 .37224 L p
1 g
F P
s
P
p
.002 w
.3116 .37224 m .33471 .32849 L .32989 .35063 L p
1 g
F P
s
P
p
.002 w
.31274 .44337 m .31128 .48593 L .3055 .46346 L p
1 g
F P
s
P
p
.002 w
.3055 .46346 m .30685 .41837 L .31274 .44337 L p
1 g
F P
s
P
p
.002 w
.37296 .57256 m .3963 .59629 L .38138 .58827 L p
1 g
F P
s
P
p
.002 w
.38138 .58827 m .35357 .56015 L .37296 .57256 L p
1 g
F P
s
P
p
.002 w
.67487 .34985 m .69444 .39655 L .69552 .41927 L p
1 g
F P
s
P
p
.002 w
.69444 .39655 m .67487 .34985 L .66921 .33025 L p
1 g
F P
s
P
p
.002 w
.33941 .52751 m .35357 .56015 L .33888 .54453 L p
1 g
F P
s
P
p
.002 w
.33888 .54453 m .32261 .50751 L .33941 .52751 L p
1 g
F P
s
P
p
.002 w
.44019 .61404 m .47026 .62258 L .46667 .62506 L p
1 g
F P
s
P
p
.002 w
.46667 .62506 m .42863 .61428 L .44019 .61404 L p
1 g
F P
s
P
p
.002 w
.50688 .62776 m .46667 .62506 L .47026 .62258 L p
1 g
F P
s
P
p
.002 w
.69103 .44304 m .68871 .48835 L .67892 .50993 L p
1 g
F P
s
P
p
.002 w
.68871 .48835 m .69103 .44304 L .69552 .41927 L p
1 g
F P
s
P
p
.002 w
.47026 .62258 m .5021 .62472 L .50688 .62776 L p
1 g
F P
s
P
p
.002 w
.54562 .62214 m .50688 .62776 L .5021 .62472 L p
1 g
F P
s
P
p
.002 w
.54562 .62214 m .5793 .60854 L .59654 .60265 L p
1 g
F P
s
P
p
.002 w
.62657 .57828 m .59654 .60265 L .5793 .60854 L p
1 g
F P
s
P
p
.002 w
.59654 .60265 m .62657 .57828 L .64446 .56475 L p
1 g
F P
s
P
p
.002 w
.51063 .23878 m .44975 .24323 L .45722 .23788 L p
1 g
F P
s
P
p
.002 w
.45722 .23788 m .51172 .23387 L .51063 .23878 L p
1 g
F P
s
P
p
.002 w
.62254 .27708 m .57093 .25066 L .56568 .24452 L p
1 g
F P
s
P
p
.002 w
.51172 .23387 m .56568 .24452 L .57093 .25066 L p
1 g
F P
s
P
p
.002 w
.66371 .52989 m .64446 .56475 L .62657 .57828 L p
1 g
F P
s
P
p
.002 w
.64446 .56475 m .66371 .52989 L .67892 .50993 L p
1 g
F P
s
P
p
.002 w
.37845 .29295 m .33471 .32849 L .34398 .30993 L p
1 g
F P
s
P
p
.002 w
.34398 .30993 m .38598 .27555 L .37845 .29295 L p
1 g
F P
s
P
p
.002 w
.41478 .59984 m .44019 .61404 L .42863 .61428 L p
1 g
F P
s
P
p
.002 w
.42863 .61428 m .3963 .59629 L .41478 .59984 L p
1 g
F P
s
P
p
.002 w
.57093 .25066 m .51063 .23878 L .51172 .23387 L p
1 g
F P
s
P
p
.002 w
.5021 .62472 m .53271 .62025 L .54562 .62214 L p
1 g
F P
s
P
p
.002 w
.5793 .60854 m .54562 .62214 L .53271 .62025 L p
1 g
F P
s
P
p
.002 w
.44342 .25424 m .38598 .27555 L .39643 .26313 L p
1 g
F P
s
P
p
.002 w
.39643 .26313 m .44975 .24323 L .44342 .25424 L p
1 g
F P
s
P
p
.002 w
.32991 .37581 m .30685 .41837 L .30655 .39444 L p
1 g
F P
s
P
p
.002 w
.30655 .39444 m .32989 .35063 L .32991 .37581 L p
1 g
F P
s
P
p
.002 w
.32428 .46869 m .32261 .50751 L .31128 .48593 L p
1 g
F P
s
P
p
.002 w
.31128 .48593 m .31274 .44337 L .32428 .46869 L p
1 g
F P
s
P
p
.002 w
.63 .29066 m .66921 .33025 L .67487 .34985 L p
1 g
F P
s
P
p
.002 w
.66921 .33025 m .63 .29066 L .62254 .27708 L p
1 g
F P
s
P
p
.002 w
.57093 .25066 m .62254 .27708 L .63 .29066 L p
1 g
F P
s
P
p
.002 w
.67566 .37246 m .69552 .41927 L .69103 .44304 L p
1 g
F P
s
P
p
.002 w
.69552 .41927 m .67566 .37246 L .67487 .34985 L p
1 g
F P
s
P
p
.002 w
.68085 .46715 m .67892 .50993 L .66371 .52989 L p
1 g
F P
s
P
p
.002 w
.67892 .50993 m .68085 .46715 L .69103 .44304 L p
1 g
F P
s
P
p
.002 w
.36135 .54521 m .37296 .57256 L .35357 .56015 L p
1 g
F P
s
P
p
.002 w
.35357 .56015 m .33941 .52751 L .36135 .54521 L p
1 g
F P
s
P
p
.002 w
.39665 .58123 m .41478 .59984 L .3963 .59629 L p
1 g
F P
s
P
p
.002 w
.3963 .59629 m .37296 .57256 L .39665 .58123 L p
1 g
F P
s
P
p
.002 w
.53271 .62025 m .55914 .60951 L .5793 .60854 L p
1 g
F P
s
P
p
.002 w
.60447 .58798 m .5793 .60854 L .55914 .60951 L p
1 g
F P
s
P
p
.002 w
.5793 .60854 m .60447 .58798 L .62657 .57828 L p
1 g
F P
s
P
p
.002 w
.64331 .54753 m .62657 .57828 L .60447 .58798 L p
1 g
F P
s
P
p
.002 w
.62657 .57828 m .64331 .54753 L .66371 .52989 L p
1 g
F P
s
P
p
.002 w
.45395 .60845 m .47486 .61442 L .47026 .62258 L p
1 g
F P
s
P
p
.002 w
.47026 .62258 m .44019 .61404 L .45395 .60845 L p
1 g
F P
s
P
p
.002 w
.5021 .62472 m .47026 .62258 L .47486 .61442 L p
1 g
F P
s
P
p
.002 w
.37425 .31504 m .32989 .35063 L .33471 .32849 L p
1 g
F P
s
P
p
.002 w
.33471 .32849 m .37845 .29295 L .37425 .31504 L p
1 g
F P
s
P
p
.002 w
.47486 .61442 m .49705 .61591 L .5021 .62472 L p
1 g
F P
s
P
p
.002 w
.53271 .62025 m .5021 .62472 L .49705 .61591 L p
1 g
F P
s
P
p
.002 w
.50918 .24951 m .44342 .25424 L .44975 .24323 L p
1 g
F P
s
P
p
.002 w
.44975 .24323 m .51063 .23878 L .50918 .24951 L p
1 g
F P
s
P
p
.002 w
.33498 .40334 m .31274 .44337 L .30685 .41837 L p
1 g
F P
s
P
p
.002 w
.30685 .41837 m .32991 .37581 L .33498 .40334 L p
1 g
F P
s
P
p
.002 w
.34129 .49349 m .33941 .52751 L .32261 .50751 L p
1 g
F P
s
P
p
.002 w
.32261 .50751 m .32428 .46869 L .34129 .49349 L p
1 g
F P
s
P
p
.002 w
.63 .29066 m .57434 .2623 L .57093 .25066 L p
1 g
F P
s
P
p
.002 w
.51063 .23878 m .57093 .25066 L .57434 .2623 L p
1 g
F P
s
P
p
.002 w
.43641 .59857 m .45395 .60845 L .44019 .61404 L p
1 g
F P
s
P
p
.002 w
.44019 .61404 m .41478 .59984 L .43641 .59857 L p
1 g
F P
s
P
p
.002 w
.63394 .30884 m .67487 .34985 L .67566 .37246 L p
1 g
F P
s
P
p
.002 w
.67487 .34985 m .63394 .30884 L .63 .29066 L p
1 g
F P
s
P
p
.002 w
.49705 .61591 m .51832 .61277 L .53271 .62025 L p
1 g
F P
s
P
p
.002 w
.55914 .60951 m .53271 .62025 L .51832 .61277 L p
1 g
F P
s
P
p
.002 w
.43851 .27091 m .37845 .29295 L .38598 .27555 L p
1 g
F P
s
P
p
.002 w
.38598 .27555 m .44342 .25424 L .43851 .27091 L p
1 g
F P
s
P
p
.002 w
.57434 .2623 m .50918 .24951 L .51063 .23878 L p
1 g
F P
s
P
p
.002 w
.66508 .49084 m .66371 .52989 L .64331 .54753 L p
1 g
F P
s
P
p
.002 w
.66371 .52989 m .66508 .49084 L .68085 .46715 L p
1 g
F P
s
P
p
.002 w
.67129 .3975 m .69103 .44304 L .68085 .46715 L p
1 g
F P
s
P
p
.002 w
.69103 .44304 m .67129 .3975 L .67566 .37246 L p
1 g
F P
s
P
p
.002 w
.57434 .2623 m .63 .29066 L .63394 .30884 L p
1 g
F P
s
P
p
.002 w
.38791 .55993 m .39665 .58123 L .37296 .57256 L p
1 g
F P
s
P
p
.002 w
.37296 .57256 m .36135 .54521 L .38791 .55993 L p
1 g
F P
s
P
p
.002 w
.42407 .58569 m .43641 .59857 L .41478 .59984 L p
1 g
F P
s
P
p
.002 w
.41478 .59984 m .39665 .58123 L .42407 .58569 L p
1 g
F P
s
P
p
.002 w
.55914 .60951 m .57865 .59336 L .60447 .58798 L p
1 g
F P
s
P
p
.002 w
.61817 .56219 m .60447 .58798 L .57865 .59336 L p
1 g
F P
s
P
p
.002 w
.60447 .58798 m .61817 .56219 L .64331 .54753 L p
1 g
F P
s
P
p
.002 w
.51832 .61277 m .53655 .60527 L .55914 .60951 L p
1 g
F P
s
P
p
.002 w
.57865 .59336 m .55914 .60951 L .53655 .60527 L p
1 g
F P
s
P
p
.002 w
.37369 .3413 m .32991 .37581 L .32989 .35063 L p
1 g
F P
s
P
p
.002 w
.32989 .35063 m .37425 .31504 L .37369 .3413 L p
1 g
F P
s
P
p
.002 w
.34512 .43235 m .32428 .46869 L .31274 .44337 L p
1 g
F P
s
P
p
.002 w
.31274 .44337 m .33498 .40334 L .34512 .43235 L p
1 g
F P
s
P
p
.002 w
.36338 .51691 m .36135 .54521 L .33941 .52751 L p
1 g
F P
s
P
p
.002 w
.33941 .52751 m .34129 .49349 L .36338 .51691 L p
1 g
F P
s
P
p
.002 w
.46962 .59738 m .48041 .60048 L .47486 .61442 L p
1 g
F P
s
P
p
.002 w
.47486 .61442 m .45395 .60845 L .46962 .59738 L p
1 g
F P
s
P
p
.002 w
.49705 .61591 m .47486 .61442 L .48041 .60048 L p
1 g
F P
s
P
p
.002 w
.48041 .60048 m .49188 .60125 L .49705 .61591 L p
1 g
F P
s
P
p
.002 w
.51832 .61277 m .49705 .61591 L .49188 .60125 L p
1 g
F P
s
P
p
.002 w
.5074 .26606 m .43851 .27091 L .44342 .25424 L p
1 g
F P
s
P
p
.002 w
.44342 .25424 m .50918 .24951 L .5074 .26606 L p
1 g
F P
s
P
p
.002 w
.64403 .51328 m .64331 .54753 L .61817 .56219 L p
1 g
F P
s
P
p
.002 w
.64331 .54753 m .64403 .51328 L .66508 .49084 L p
1 g
F P
s
P
p
.002 w
.63405 .33129 m .67566 .37246 L .67129 .3975 L p
1 g
F P
s
P
p
.002 w
.67566 .37246 m .63405 .33129 L .63394 .30884 L p
1 g
F P
s
P
p
.002 w
.66168 .42423 m .68085 .46715 L .66508 .49084 L p
1 g
F P
s
P
p
.002 w
.68085 .46715 m .66168 .42423 L .67129 .3975 L p
1 g
F P
s
P
p
.002 w
.63394 .30884 m .57568 .27939 L .57434 .2623 L p
1 g
F P
s
P
p
.002 w
.50918 .24951 m .57434 .2623 L .57568 .27939 L p
1 g
F P
s
P
p
.002 w
.46064 .59225 m .46962 .59738 L .45395 .60845 L p
1 g
F P
s
P
p
.002 w
.45395 .60845 m .43641 .59857 L .46064 .59225 L p
1 g
F P
s
P
p
.002 w
.43527 .293 m .37425 .31504 L .37845 .29295 L p
1 g
F P
s
P
p
.002 w
.37845 .29295 m .43851 .27091 L .43527 .293 L p
1 g
F P
s
P
p
.002 w
.49188 .60125 m .50284 .5996 L .51832 .61277 L p
1 g
F P
s
P
p
.002 w
.53655 .60527 m .51832 .61277 L .50284 .5996 L p
1 g
F P
s
P
p
.002 w
.41834 .57108 m .42407 .58569 L .39665 .58123 L p
1 g
F P
s
P
p
.002 w
.39665 .58123 m .38791 .55993 L .41834 .57108 L p
1 g
F P
s
P
p
.002 w
.57568 .27939 m .5074 .26606 L .50918 .24951 L p
1 g
F P
s
P
p
.002 w
.57568 .27939 m .63394 .30884 L .63405 .33129 L p
1 g
F P
s
P
p
.002 w
.53655 .60527 m .54982 .59408 L .57865 .59336 L p
1 g
F P
s
P
p
.002 w
.58898 .57327 m .57865 .59336 L .54982 .59408 L p
1 g
F P
s
P
p
.002 w
.57865 .59336 m .58898 .57327 L .61817 .56219 L p
1 g
F P
s
P
p
.002 w
.38992 .5381 m .38791 .55993 L .36135 .54521 L p
1 g
F P
s
P
p
.002 w
.36135 .54521 m .36338 .51691 L .38992 .5381 L p
1 g
F P
s
P
p
.002 w
.36015 .46186 m .34129 .49349 L .32428 .46869 L p
1 g
F P
s
P
p
.002 w
.32428 .46869 m .34512 .43235 L .36015 .46186 L p
1 g
F P
s
P
p
.002 w
.45442 .58562 m .46064 .59225 L .43641 .59857 L p
1 g
F P
s
P
p
.002 w
.43641 .59857 m .42407 .58569 L .45442 .58562 L p
1 g
F P
s
P
p
.002 w
.37696 .37098 m .33498 .40334 L .32991 .37581 L p
1 g
F P
s
P
p
.002 w
.32991 .37581 m .37369 .3413 L .37696 .37098 L p
1 g
F P
s
P
p
.002 w
.50284 .5996 m .51216 .59569 L .53655 .60527 L p
1 g
F P
s
P
p
.002 w
.54982 .59408 m .53655 .60527 L .51216 .59569 L p
1 g
F P
s
P
p
.002 w
.61828 .53366 m .61817 .56219 L .58898 .57327 L p
1 g
F P
s
P
p
.002 w
.61817 .56219 m .61828 .53366 L .64403 .51328 L p
1 g
F P
s
P
p
.002 w
.64697 .45179 m .66508 .49084 L .64403 .51328 L p
1 g
F P
s
P
p
.002 w
.66508 .49084 m .64697 .45179 L .66168 .42423 L p
1 g
F P
s
P
p
.002 w
.63012 .35744 m .67129 .3975 L .66168 .42423 L p
1 g
F P
s
P
p
.002 w
.67129 .3975 m .63012 .35744 L .63405 .33129 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.48964 .54813 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45166 .57817 m .45442 .58562 L .42407 .58569 L p
1 g
F P
s
P
p
.002 w
.42407 .58569 m .41834 .57108 L .45166 .57817 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.42004 .55625 m .41834 .57108 L .38791 .55993 L p
1 g
F P
s
P
p
.002 w
.38791 .55993 m .38992 .5381 L .42004 .55625 L p
1 g
F P
s
P
p
.002 w
.48041 .60048 m .46962 .59738 L .48675 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.49188 .60125 m .48041 .60048 L .48675 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.50533 .2882 m .43527 .293 L .43851 .27091 L p
1 g
F P
s
P
p
.002 w
.43851 .27091 m .5074 .26606 L .50533 .2882 L p
1 g
F P
s
P
p
.002 w
.51216 .59569 m .51885 .58992 L .54982 .59408 L p
1 g
F P
s
P
p
.002 w
.55662 .58027 m .54982 .59408 L .51885 .58992 L p
1 g
F P
s
P
p
.002 w
.54982 .59408 m .55662 .58027 L .58898 .57327 L p
1 g
F P
s
P
p
.002 w
.50284 .5996 m .49188 .60125 L .48675 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.37964 .49082 m .36338 .51691 L .34129 .49349 L p
1 g
F P
s
P
p
.002 w
.34129 .49349 m .36015 .46186 L .37964 .49082 L p
1 g
F P
s
P
p
.002 w
.4339 .31998 m .37369 .3413 L .37425 .31504 L p
1 g
F P
s
P
p
.002 w
.37425 .31504 m .43527 .293 L .4339 .31998 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.46962 .59738 m .46064 .59225 L .48675 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.51216 .59569 m .50284 .5996 L .48696 .58113 L p
1 g
F P
s
P
p
.002 w
.48716 .58113 m .51216 .59569 L p
.48696 .58113 L 1 g
F P
s
P
p
.002 w
.51885 .58992 m .51216 .59569 L .48716 .58113 L p
1 g
F P
s
P
p
.002 w
.48716 .58113 m .48675 .58089 L .4876 .58113 L p
1 g
F P
s
P
p
.002 w
.4876 .58113 m .51885 .58992 L p
.48716 .58113 L 1 g
F P
s
P
p
.002 w
.45166 .57817 m .45271 .57069 L .47074 .57609 L p
1 g
F P
s
P
p
.002 w
.47074 .57609 m .48675 .58089 L .47769 .58019 L p
1 g
F P
s
P
p
.002 w
.47769 .58019 m .45166 .57817 L p
.47074 .57609 L 1 g
F P
s
P
p
.002 w
.46829 .57462 m .46872 .57265 L p
.45753 .56818 L 1 g
F P
s
P
p
.002 w
.48675 .58089 m .47074 .57609 L p
.46961 .57505 L 1 g
F P
s
P
p
.002 w
.48584 .58036 m .48675 .58089 L p
.46961 .57505 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .47012 .57753 L p
.47868 .57802 L 1 g
F P
s
P
p
.48921 .57862 m .47759 .57767 L .47868 .57802 L 1 g
F
P
p
.47759 .57767 m .4678 .57686 L .47868 .57802 L 1 g
F
P
p
.002 w
.48903 .58111 m .48921 .57862 L p
.4785 .57801 L 1 g
F P
s
P
p
.4785 .57801 m .47807 .57799 L .48124 .57889 L 1 g
F
P
p
.4785 .57801 m .48124 .57889 L .48903 .58111 L 1 g
F
P
p
.47807 .57799 m .48664 .58061 L .48903 .58111 L 1 g
F
P
p
.002 w
.48676 .58065 m .48675 .58089 L .48664 .58061 L p
1 g
F P
s
P
p
.48664 .58061 m .4867 .58064 L .48672 .58064 L 1 g
F
P
p
.48664 .58061 m .48672 .58064 L .48903 .58111 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46829 .57462 L p
1 g
F P
s
P
p
.002 w
.47074 .57609 m .45271 .57069 L .45338 .56975 L p
1 g
F P
s
P
p
.45338 .56975 m .46829 .57462 L .47074 .57609 L 1 g
F
P
p
.48921 .57862 m .46829 .57462 L .47759 .57767 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45338 .56975 m .45542 .56691 L p
.46829 .57462 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45072 .56327 L p
1 g
F P
s
P
p
.002 w
.45271 .57069 m .42004 .55625 L p
.44954 .56235 L 1 g
F P
s
P
p
.44954 .56235 m .45072 .56327 L .45271 .57069 L 1 g
F
P
p
.002 w
.45542 .56691 m .45454 .56814 L p
.45072 .56327 L 1 g
F P
s
P
p
.002 w
.45454 .56814 m .45271 .57069 L p
.45072 .56327 L 1 g
F P
s
P
p
.002 w
.45072 .56327 m .45146 .56129 L p
.44429 .55506 L 1 g
F P
s
P
p
.46872 .57265 m .45072 .56327 L .45653 .56778 L 1 g
F
P
p
.002 w
.45751 .564 m .45542 .56691 L p
.44954 .56235 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.42004 .55625 m .42922 .54284 L .43953 .55055 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43837 .54731 L p
1 g
F P
s
P
p
.45146 .56129 m .43837 .54731 L .43907 .54824 L 1 g
F
P
p
.002 w
.43837 .54731 m .43925 .54566 L p
.43485 .53696 L 1 g
F P
s
P
p
.4325 .52816 m .43261 .52858 L .42922 .54284 L 1 g
F
P
p
.002 w
.43535 .53881 m .43183 .54112 L p
.43261 .52858 L 1 g
F P
s
P
p
.002 w
.43183 .54112 m .42922 .54284 L p
.43261 .52858 L 1 g
F P
s
P
p
.002 w
.42922 .54284 m .40294 .51815 L p
.4325 .52816 L 1 g
F P
s
P
p
.002 w
.43261 .52858 m .43346 .52734 L p
.43318 .5193 L 1 g
F P
s
P
p
.43485 .53696 m .43535 .53881 L .43837 .54731 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43261 .52858 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43394 .50935 L p
1 g
F P
s
P
p
.43346 .52734 m .43394 .50935 L .43375 .51144 L 1 g
F
P
p
.42594 .50249 m .43412 .50736 L .43394 .50935 L 1 g
F
P
p
.002 w
.43349 .51431 m .43239 .51259 L p
.43394 .50935 L 1 g
F P
s
P
p
.002 w
.43239 .51259 m .42594 .50249 L p
.43394 .50935 L 1 g
F P
s
P
p
.002 w
.43394 .50935 m .43485 .50826 L p
.43839 .49998 L 1 g
F P
s
P
p
.43346 .52734 m .43375 .51144 L .43318 .5193 L 1 g
F
P
p
.43375 .51144 m .43378 .50953 L .43349 .51431 L 1 g
F
P
p
.43375 .51144 m .43349 .51431 L .43318 .5193 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42594 .50249 m .40899 .47014 L p
.4446 .48738 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44269 .49125 L p
1 g
F P
s
P
p
.43485 .50826 m .44269 .49125 L .44097 .49472 L 1 g
F
P
p
.4446 .48738 m .44269 .49125 L .42594 .50249 L 1 g
F
P
p
.002 w
.43911 .49847 m .43344 .5002 L p
.44269 .49125 L 1 g
F P
s
P
p
.002 w
.43344 .5002 m .42594 .50249 L p
.44269 .49125 L 1 g
F P
s
P
p
.43485 .50826 m .4424 .49155 L .43839 .49998 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44269 .49125 m .44339 .4905 L p
.4499 .48427 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45651 .49315 m .43911 .49847 L p
.44269 .49125 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45775 .47664 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45775 .47664 m .49108 .49144 L .45365 .48063 L 1 g
F
P
p
.002 w
.45775 .47664 m .45826 .47608 L p
.46538 .47296 L 1 g
F P
s
P
p
.46683 .47226 m .49108 .49144 L .45775 .47664 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47764 .46704 L p
1 g
F P
s
P
p
.45826 .47608 m .47764 .46704 L .46538 .47296 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49264 .46504 m .49108 .49144 L p
.46275 .46903 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46383 L p
1 g
F P
s
P
p
.002 w
.52539 .49765 m .49108 .49144 L .49264 .46504 L p
1 g
F P
s
P
p
.49971 .46387 m .52539 .49765 L .49264 .46504 L 1 g
F
P
p
.47786 .46667 m .5 .46383 L .49059 .46538 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46708 L p
1 g
F P
s
P
p
.5 .4634 m .52239 .46708 L .50909 .46515 L 1 g
F
P
p
.002 w
.53427 .47292 m .52539 .49765 L p
.50617 .46472 L 1 g
F P
s
P
p
.002 w
.5 .46383 m .5 .4634 L p
.50909 .46515 L 1 g
F P
s
P
p
.50159 .45687 m .52239 .46708 L .50617 .46472 L 1 g
F
P
p
.52239 .46708 m .53427 .47292 L .50617 .46472 L 1 g
F
P
p
.49963 .46377 m .50617 .46472 L .52539 .49765 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46383 L p
1 g
F P
s
P
p
.50909 .46515 m .52282 .46778 L .5 .46383 L 1 g
F
P
p
.002 w
.52239 .46708 m .52282 .46778 L p
.50909 .46515 L 1 g
F P
s
P
p
.002 w
.49321 .45533 m .50159 .45687 L p
.50617 .46472 L 1 g
F P
s
P
p
.49321 .45533 m .50617 .46472 L .49963 .46377 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54222 .47661 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.54222 .47661 m .55522 .51095 L .53427 .47292 L 1 g
F
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54258 .47677 m .54269 .47706 L .54222 .47661 L 1 g
F
P
p
.54269 .47706 m .55522 .51095 L .54222 .47661 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50922 L p
1 g
F P
s
P
p
.57612 .48099 m .57444 .52736 L .56595 .50922 L 1 g
F
P
p
.002 w
.56213 .50104 m .56485 .49714 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.56485 .49714 m .57612 .48099 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.56595 .50922 m .56515 .50826 L p
.5669 .51964 L 1 g
F P
s
P
p
.55661 .4905 m .56595 .50922 L .56221 .5012 L 1 g
F
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52866 L p
1 g
F P
s
P
p
.002 w
.57705 .52959 m .56785 .53622 L p
.56744 .52866 L 1 g
F P
s
P
p
.002 w
.56703 .52103 m .56916 .52285 L p
.56744 .52866 L 1 g
F P
s
P
p
.002 w
.56916 .52285 m .57705 .52959 L p
.56744 .52866 L 1 g
F P
s
P
p
.002 w
.56744 .52866 m .56654 .52734 L p
.56447 .5387 L 1 g
F P
s
P
p
.57705 .52959 m .55546 .5643 L .56151 .5471 L 1 g
F
P
p
.002 w
.56448 .53866 m .57097 .53398 L p
.56151 .5471 L 1 g
F P
s
P
p
.002 w
.57097 .53398 m .57705 .52959 L p
.56151 .5471 L 1 g
F P
s
P
p
.002 w
.56151 .5471 m .56075 .54566 L p
.55488 .55629 L 1 g
F P
s
P
p
.56447 .5387 m .56448 .53866 L .56744 .52866 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56324 L p
1 g
F P
s
P
p
.002 w
.55601 .56526 m .54455 .5686 L p
.54926 .56324 L 1 g
F P
s
P
p
.002 w
.55269 .55935 m .55335 .56053 L p
.54926 .56324 L 1 g
F P
s
P
p
.002 w
.55335 .56053 m .55601 .56526 L p
.54926 .56324 L 1 g
F P
s
P
p
.002 w
.54926 .56324 m .54854 .56129 L p
.54013 .56931 L 1 g
F P
s
P
p
.56075 .54566 m .54926 .56324 L .55118 .56106 L 1 g
F
P
p
.56075 .54566 m .54947 .5638 L .55488 .55629 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57466 L p
1 g
F P
s
P
p
.002 w
.53857 .57034 m .55601 .56526 L p
.54986 .56806 L 1 g
F P
s
P
p
.54986 .56806 m .52201 .58077 L .53172 .57466 L 1 g
F
P
p
.54986 .56806 m .53172 .57466 L .53857 .57034 L 1 g
F
P
p
.002 w
.52214 .58287 m .52201 .58077 L p
.55601 .56526 L 1 g
F P
s
P
p
.002 w
.53172 .57466 m .53128 .57265 L p
.5192 .57885 L 1 g
F P
s
P
p
.002 w
.52214 .58287 m .50564 .58194 L p
.51095 .58073 L 1 g
F P
s
P
p
.002 w
.52184 .57824 m .52199 .58054 L p
.51095 .58073 L 1 g
F P
s
P
p
.002 w
.52199 .58054 m .52214 .58287 L p
.51095 .58073 L 1 g
F P
s
P
p
.002 w
.51095 .58073 m .51079 .57862 L p
.49922 .58093 L 1 g
F P
s
P
p
.5192 .57885 m .52184 .57824 L .53172 .57466 L 1 g
F
P
p
.002 w
.48687 .58068 m .48675 .58089 L .48676 .58065 L p
1 g
F P
s
P
p
.002 w
.48643 .58055 m .48675 .58089 L .48584 .58036 L p
1 g
F P
s
P
p
.002 w
.48664 .58061 m .48675 .58089 L .48643 .58055 L p
1 g
F P
s
P
p
.47072 .57757 m .48836 .58098 L .48903 .58111 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58111 L p
1 g
F P
s
P
p
.51079 .57862 m .48903 .58111 L .48915 .5811 L 1 g
F
P
p
.51079 .57862 m .48913 .58111 L .49922 .58093 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51105 .58216 L p
1 g
F P
s
P
p
.53128 .57265 m .51105 .58216 L .51683 .58006 L 1 g
F
P
p
.54854 .56129 m .53172 .57466 L .53309 .57379 L 1 g
F
P
p
.54854 .56129 m .53176 .57486 L .54013 .56931 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52165 .57527 m .53857 .57034 L p
.53172 .57466 L 1 g
F P
s
P
p
.002 w
.52201 .58077 m .52184 .57824 L p
.53172 .57466 L 1 g
F P
s
P
p
.002 w
.52184 .57824 m .52165 .57527 L p
.53172 .57466 L 1 g
F P
s
P
p
.002 w
.52214 .58287 m .52021 .58699 L p
.4897 .58123 L 1 g
F P
s
P
p
.002 w
.49029 .58109 m .52214 .58287 L p
.4876 .58113 L 1 g
F P
s
P
p
.002 w
.51105 .58216 m .51111 .583 L p
.51683 .58006 L 1 g
F P
s
P
p
.52184 .57824 m .51095 .58073 L .48836 .58098 L 1 g
F
P
p
.002 w
.50564 .58194 m .49029 .58109 L p
.51095 .58073 L 1 g
F P
s
P
p
.002 w
.49029 .58109 m .48836 .58098 L p
.51095 .58073 L 1 g
F P
s
P
p
.49922 .58093 m .48902 .58112 L .49857 .58106 L 1 g
F
P
p
.48913 .58111 m .48902 .58112 L .49922 .58093 L 1 g
F
P
p
.002 w
.51099 .58135 m .51095 .58073 L p
.49776 .58123 L 1 g
F P
s
P
p
.49922 .58093 m .49776 .58123 L .51095 .58073 L 1 g
F
P
p
.5192 .57885 m .51683 .58006 L .52184 .57824 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.52165 .57527 m .52184 .57824 L p
.48836 .58098 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57466 L p
1 g
F P
s
P
p
.51683 .58006 m .51111 .583 L .53172 .57466 L 1 g
F
P
p
.002 w
.53172 .57466 m .53176 .57486 L p
.53309 .57379 L 1 g
F P
s
P
p
.55269 .55935 m .54926 .56324 L .52165 .57527 L 1 g
F
P
p
.002 w
.54455 .5686 m .53857 .57034 L p
.54926 .56324 L 1 g
F P
s
P
p
.002 w
.53857 .57034 m .52165 .57527 L p
.54926 .56324 L 1 g
F P
s
P
p
.002 w
.53176 .57486 m .5322 .57686 L p
.54013 .56931 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54926 .56324 L p
1 g
F P
s
P
p
.54013 .56931 m .5322 .57686 L .54926 .56324 L 1 g
F
P
p
.002 w
.54926 .56324 m .54947 .5638 L p
.55118 .56106 L 1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54782 .55068 m .55269 .55935 L p
.52165 .57527 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56181 .54766 L p
1 g
F P
s
P
p
.56654 .52734 m .56181 .54766 L .56446 .53872 L 1 g
F
P
p
.56515 .50826 m .56744 .52866 L .56724 .52492 L 1 g
F
P
p
.56515 .50826 m .56777 .52913 L .5669 .51964 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56703 .52103 m .56744 .52866 L .54782 .55068 L 1 g
F
P
p
.002 w
.56785 .53622 m .56448 .53866 L p
.56744 .52866 L 1 g
F P
s
P
p
.002 w
.56448 .53866 m .54782 .55068 L p
.56744 .52866 L 1 g
F P
s
P
p
.002 w
.56181 .54766 m .56257 .5491 L p
.56446 .53872 L 1 g
F P
s
P
p
.002 w
.54782 .55068 m .56448 .53866 L p
.56151 .5471 L 1 g
F P
s
P
p
.002 w
.55546 .5643 m .55269 .55935 L p
.56151 .5471 L 1 g
F P
s
P
p
.002 w
.55269 .55935 m .54782 .55068 L p
.56151 .5471 L 1 g
F P
s
P
p
.002 w
.54947 .5638 m .54998 .56518 L p
.55488 .55629 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56151 .5471 L p
1 g
F P
s
P
p
.55488 .55629 m .54998 .56518 L .56151 .5471 L 1 g
F
P
p
.56447 .5387 m .56446 .53872 L .56448 .53866 L 1 g
F
P
p
.002 w
.55601 .56526 m .55546 .5643 L p
.57705 .52959 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56744 .52866 L p
1 g
F P
s
P
p
.56446 .53872 m .56257 .5491 L .56744 .52866 L 1 g
F
P
p
.002 w
.56744 .52866 m .56777 .52913 L p
.56724 .52492 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55522 .51095 m .56703 .52103 L p
.54782 .55068 L 1 g
F P
s
P
p
.002 w
.54517 .46689 m .57612 .48099 L .56427 .49798 L p
1 g
F P
s
P
p
.002 w
.56427 .49798 m .56213 .50104 L p
.55721 .49114 L 1 g
F P
s
P
p
.54517 .46689 m .56427 .49798 L .55721 .49114 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55721 .49114 L p
1 g
F P
s
P
p
.002 w
.55721 .49114 m .55661 .4905 L p
.5623 .50138 L 1 g
F P
s
P
p
.5623 .50138 m .56713 .51061 L .55721 .49114 L 1 g
F
P
p
.002 w
.54222 .47661 m .54174 .47608 L p
.54785 .48206 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55721 .49114 L p
1 g
F P
s
P
p
.54174 .47608 m .55721 .49114 L .54785 .48206 L 1 g
F
P
p
.002 w
.53767 .46347 m .54517 .46689 L p
.54799 .47928 L 1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54258 .47677 m .54799 .47928 L .55522 .51095 L 1 g
F
P
p
.53767 .46347 m .54799 .47928 L .54258 .47677 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55522 .51095 m .52539 .49765 L .53427 .47292 L p
1 g
F P
s
P
p
.002 w
.54259 .47701 m .54302 .47747 L p
.53373 .47267 L 1 g
F P
s
P
p
.53315 .47237 m .53427 .47292 L .53373 .47267 L 1 g
F
P
p
.53427 .47292 m .54259 .47701 L .53373 .47267 L 1 g
F
P
p
.002 w
.56213 .50104 m .55522 .51095 L p
.54517 .46689 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54222 .47661 L p
1 g
F P
s
P
p
.54785 .48206 m .55834 .49233 L .54222 .47661 L 1 g
F
P
p
.002 w
.55522 .51095 m .56213 .50104 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.57444 .52736 m .56703 .52103 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.56703 .52103 m .55522 .51095 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.56777 .52913 m .56854 .53025 L p
.5669 .51964 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50922 L p
1 g
F P
s
P
p
.5669 .51964 m .56854 .53025 L .56595 .50922 L 1 g
F
P
p
.002 w
.56595 .50922 m .56713 .51061 L p
.56221 .5012 L 1 g
F P
s
P
p
.002 w
.57705 .52959 m .57444 .52736 L p
.57612 .48099 L 1 g
F P
s
P
p
.002 w
.55721 .49114 m .55834 .49233 L p
.54785 .48206 L 1 g
F P
s
P
p
.002 w
.54222 .47661 m .54259 .47701 L p
.53708 .47422 L 1 g
F P
s
P
p
.52214 .46667 m .54222 .47661 L .53708 .47422 L 1 g
F
P
p
.52214 .46667 m .54259 .47701 L .53315 .47237 L 1 g
F
P
p
.002 w
.53427 .47292 m .53767 .46347 L p
.54258 .47677 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.50159 .45687 m .53767 .46347 L .53427 .47292 L p
1 g
F P
s
P
p
.002 w
.5 .46383 m .5 .46442 L p
.49059 .46538 L 1 g
F P
s
P
p
.002 w
.49264 .46504 m .49321 .45533 L p
.49971 .46387 L 1 g
F P
s
P
p
.002 w
.44842 .4577 m .49321 .45533 L .49264 .46504 L p
1 g
F P
s
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48859 .46558 L 1 g
F P
s
P
p
.44842 .4577 m .49264 .46504 L .46275 .46903 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48859 .46558 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47764 .46704 m .47718 .46778 L p
.46538 .47296 L 1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.44842 .4577 m .4643 .47026 L .45775 .47664 L 1 g
F
P
p
.44339 .4905 m .45775 .47664 L .45534 .47899 L 1 g
F
P
p
.44339 .4905 m .45755 .47686 L .4499 .48427 L 1 g
F
P
p
.002 w
.45365 .48063 m .45324 .47882 L p
.45775 .47664 L 1 g
F P
s
P
p
.002 w
.45324 .47882 m .44842 .4577 L p
.45775 .47664 L 1 g
F P
s
P
p
.4643 .47026 m .46683 .47226 L .45775 .47664 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45775 .47664 L p
1 g
F P
s
P
p
.46538 .47296 m .47718 .46778 L .45775 .47664 L 1 g
F
P
p
.002 w
.45775 .47664 m .45755 .47686 L p
.45534 .47899 L 1 g
F P
s
P
p
.002 w
.49108 .49144 m .45651 .49315 L .45365 .48063 L p
1 g
F P
s
P
p
.4446 .48738 m .44599 .48805 L .44269 .49125 L 1 g
F
P
p
.44599 .48805 m .45651 .49315 L .44269 .49125 L 1 g
F
P
p
.002 w
.40899 .47014 m .44842 .4577 L .45651 .49315 L p
1 g
F P
s
P
p
.002 w
.45755 .47686 m .45698 .47747 L p
.4499 .48427 L 1 g
F P
s
P
p
.002 w
.44269 .49125 m .4424 .49155 L p
.44097 .49472 L 1 g
F P
s
P
p
.002 w
.42594 .50249 m .45651 .49315 L .46586 .52627 L p
1 g
F P
s
P
p
.002 w
.4424 .49155 m .44166 .49233 L p
.43839 .49998 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44269 .49125 L p
1 g
F P
s
P
p
.4499 .48427 m .45698 .47747 L .44269 .49125 L 1 g
F
P
p
.43394 .50935 m .46586 .52627 L .43349 .51431 L 1 g
F
P
p
.43412 .50736 m .43471 .50771 L .43394 .50935 L 1 g
F
P
p
.43471 .50771 m .46586 .52627 L .43394 .50935 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43394 .50935 L p
1 g
F P
s
P
p
.43839 .49998 m .44166 .49233 L .43394 .50935 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.46586 .52627 m .44505 .53242 L .43349 .51431 L p
1 g
F P
s
P
p
.002 w
.43394 .50935 m .43378 .50953 L p
.43375 .51144 L 1 g
F P
s
P
p
.002 w
.42594 .50249 m .43349 .51431 L p
.4325 .52816 L 1 g
F P
s
P
p
.4325 .52816 m .43349 .51431 L .43263 .52821 L 1 g
F
P
p
.002 w
.43378 .50953 m .43287 .51061 L p
.43318 .5193 L 1 g
F P
s
P
p
.002 w
.43349 .51431 m .44505 .53242 L p
.43263 .52821 L 1 g
F P
s
P
p
.002 w
.40294 .51815 m .42567 .50267 L p
.4325 .52816 L 1 g
F P
s
P
p
.002 w
.42567 .50267 m .42594 .50249 L p
.4325 .52816 L 1 g
F P
s
P
p
.002 w
.43261 .52858 m .43201 .52945 L p
.43408 .53407 L 1 g
F P
s
P
p
.43925 .54566 m .43261 .52858 L .43408 .53407 L 1 g
F
P
p
.002 w
.43201 .52945 m .43146 .53025 L p
.4343 .53587 L 1 g
F P
s
P
p
.43925 .54566 m .43201 .52945 L .4343 .53587 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44505 .53242 m .46559 .55885 L p
.43819 .54679 L 1 g
F P
s
P
p
.002 w
.42922 .54284 m .43535 .53881 L p
.43819 .54679 L 1 g
F P
s
P
p
.002 w
.43535 .53881 m .44505 .53242 L p
.43819 .54679 L 1 g
F P
s
P
p
.002 w
.44505 .53242 m .43535 .53881 L p
.4325 .52816 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43261 .52858 L p
1 g
F P
s
P
p
.43318 .5193 m .43287 .51061 L .43261 .52858 L 1 g
F
P
p
.43485 .53696 m .4343 .53587 L .43535 .53881 L 1 g
F
P
p
.43837 .54731 m .44123 .55109 L .43953 .55055 L 1 g
F
P
p
.002 w
.44249 .55277 m .43953 .55055 L p
.44123 .55109 L 1 g
F P
s
P
p
.45146 .56129 m .43907 .54824 L .44429 .55506 L 1 g
F
P
p
.43788 .54665 m .43837 .54731 L .43953 .55055 L 1 g
F
P
p
.43907 .54824 m .43831 .54743 L .44249 .55277 L 1 g
F
P
p
.43907 .54824 m .44249 .55277 L .44429 .55506 L 1 g
F
P
p
.002 w
.43953 .55055 m .42922 .54284 L p
.43788 .54665 L 1 g
F P
s
P
p
.43788 .54665 m .43819 .54679 L .43837 .54731 L 1 g
F
P
p
.43819 .54679 m .46559 .55885 L .44123 .55109 L 1 g
F
P
p
.43819 .54679 m .44123 .55109 L .43837 .54731 L 1 g
F
P
p
.002 w
.43953 .55055 m .44249 .55277 L p
.44051 .55307 L 1 g
F P
s
P
p
.42004 .55625 m .43953 .55055 L .44051 .55307 L 1 g
F
P
p
.42004 .55625 m .44249 .55277 L .45009 .56246 L 1 g
F
P
p
.002 w
.43831 .54743 m .43743 .5491 L p
.44409 .55489 L 1 g
F P
s
P
p
.44429 .55506 m .44249 .55277 L .44409 .55489 L 1 g
F
P
p
.44249 .55277 m .43831 .54743 L .44409 .55489 L 1 g
F
P
p
.002 w
.43837 .54731 m .43831 .54743 L p
.43907 .54824 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46559 .55885 m .45751 .564 L .44249 .55277 L p
1 g
F P
s
P
p
.44123 .55109 m .46559 .55885 L .44249 .55277 L 1 g
F
P
p
.002 w
.43831 .54743 m .43837 .54731 L p
.43207 .53146 L 1 g
F P
s
P
p
.4343 .53587 m .43207 .53146 L .43837 .54731 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43831 .54743 L p
1 g
F P
s
P
p
.43207 .53146 m .43146 .53025 L .43831 .54743 L 1 g
F
P
p
.002 w
.44249 .55277 m .45751 .564 L p
.45009 .56246 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45072 .56327 L p
1 g
F P
s
P
p
.44429 .55506 m .43743 .5491 L .45072 .56327 L 1 g
F
P
p
.002 w
.45072 .56327 m .45002 .56518 L p
.45653 .56778 L 1 g
F P
s
P
p
.002 w
.45542 .56691 m .45751 .564 L p
.47074 .57609 L 1 g
F P
s
P
p
.002 w
.46829 .57462 m .4678 .57686 L p
.47759 .57767 L 1 g
F P
s
P
p
.002 w
.47608 .55584 m .4878 .55533 L .48676 .58065 L p
1 g
F P
s
P
p
.002 w
.48664 .58061 m .47608 .55584 L p
.48676 .58065 L 1 g
F P
s
P
p
.4867 .58064 m .4868 .58066 L .48903 .58111 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4878 .55533 m .49944 .55738 L .48687 .58068 L p
1 g
F P
s
P
p
.002 w
.48676 .58065 m .4878 .55533 L p
.48687 .58068 L 1 g
F P
s
P
p
.4867 .58064 m .48676 .58065 L .4868 .58066 L 1 g
F
P
p
.48676 .58065 m .48682 .58067 L .48689 .58068 L 1 g
F
P
p
.48676 .58065 m .48689 .58068 L .48903 .58111 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.49944 .55738 m .50967 .56177 L .48697 .5807 L p
1 g
F P
s
P
p
.002 w
.48697 .5807 m .48675 .58089 L .48687 .58068 L p
1 g
F P
s
P
p
.002 w
.48687 .58068 m .49944 .55738 L p
.48697 .5807 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.50967 .56177 m .51735 .56797 L .48712 .58074 L p
1 g
F P
s
P
p
.002 w
.48712 .58074 m .48675 .58089 L .48697 .5807 L p
1 g
F P
s
P
p
.002 w
.48697 .5807 m .50967 .56177 L p
.48712 .58074 L 1 g
F P
s
P
p
.48682 .58067 m .48687 .58069 L .48702 .58072 L 1 g
F
P
p
.48682 .58067 m .48702 .58072 L .48903 .58111 L 1 g
F
P
p
.48687 .58069 m .48689 .58069 L .48714 .58074 L 1 g
F
P
p
.48687 .58069 m .48714 .58074 L .48903 .58111 L 1 g
F
P
p
.002 w
.51735 .56797 m .52165 .57527 L .48737 .58079 L p
1 g
F P
s
P
p
.002 w
.48737 .58079 m .48675 .58089 L .48712 .58074 L p
1 g
F P
s
P
p
.002 w
.48712 .58074 m .51735 .56797 L p
.48737 .58079 L 1 g
F P
s
P
p
.002 w
.45751 .564 m .46559 .55885 L .48643 .58055 L p
1 g
F P
s
P
p
.002 w
.48584 .58036 m .45751 .564 L p
.48643 .58055 L 1 g
F P
s
P
p
.002 w
.46559 .55885 m .47608 .55584 L .48664 .58061 L p
1 g
F P
s
P
p
.002 w
.48643 .58055 m .46559 .55885 L p
.48664 .58061 L 1 g
F P
s
P
p
.47807 .57799 m .47072 .57757 L .48689 .58069 L 1 g
F
P
p
.47072 .57757 m .47012 .57753 L .48836 .58098 L 1 g
F
P
p
.002 w
.48836 .58098 m .48675 .58089 L .48737 .58079 L p
1 g
F P
s
P
p
.002 w
.48737 .58079 m .52165 .57527 L p
.48836 .58098 L 1 g
F P
s
P
p
.002 w
.45751 .564 m .48584 .58036 L p
.46961 .57505 L 1 g
F P
s
P
p
.002 w
.46828 .57465 m .46829 .57462 L p
.45684 .56791 L 1 g
F P
s
P
p
.45753 .56818 m .45684 .56791 L .46829 .57462 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46828 .57465 L p
1 g
F P
s
P
p
.45684 .56791 m .45002 .56518 L .46828 .57465 L 1 g
F
P
p
.002 w
.51885 .58992 m .4876 .58113 L p
.4897 .58123 L 1 g
F P
s
P
p
.002 w
.4876 .58113 m .48675 .58089 L .49029 .58109 L p
1 g
F P
s
P
p
.002 w
.48696 .58113 m .48675 .58089 L .48716 .58113 L p
1 g
F P
s
P
p
.002 w
.46064 .59225 m .45442 .58562 L .48675 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.45442 .58562 m .45166 .57817 L .48675 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.47012 .57753 m .48889 .583 L .48903 .58111 L p
1 g
F P
s
P
p
.002 w
.52021 .58699 m .51885 .58992 L p
.4897 .58123 L 1 g
F P
s
P
p
.002 w
.48903 .58111 m .48902 .58112 L p
.48915 .5811 L 1 g
F P
s
P
p
.002 w
.48902 .58112 m .48889 .583 L p
.49857 .58106 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51099 .58135 L p
1 g
F P
s
P
p
.49776 .58123 m .48889 .583 L .51099 .58135 L 1 g
F
P
p
.002 w
.63405 .33129 m .57479 .30166 L .57568 .27939 L p
1 g
F P
s
P
p
.002 w
.5074 .26606 m .57568 .27939 L .57479 .30166 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.5886 .55121 m .58898 .57327 L .55662 .58027 L p
1 g
F P
s
P
p
.002 w
.58898 .57327 m .5886 .55121 L .61828 .53366 L p
1 g
F P
s
P
p
.002 w
.38407 .40312 m .34512 .43235 L .33498 .40334 L p
1 g
F P
s
P
p
.002 w
.33498 .40334 m .37696 .37098 L .38407 .40312 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.57479 .30166 m .63405 .33129 L .63012 .35744 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.62753 .4792 m .64403 .51328 L .61828 .53366 L p
1 g
F P
s
P
p
.002 w
.64403 .51328 m .62753 .4792 L .64697 .45179 L p
1 g
F P
s
P
p
.002 w
.57479 .30166 m .50533 .2882 L .5074 .26606 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45271 .57069 m .45166 .57817 L .41834 .57108 L p
1 g
F P
s
P
p
.002 w
.41834 .57108 m .42004 .55625 L .45271 .57069 L p
1 g
F P
s
P
p
.002 w
.62211 .38653 m .66168 .42423 L .64697 .45179 L p
1 g
F P
s
P
p
.002 w
.66168 .42423 m .62211 .38653 L .63012 .35744 L p
1 g
F P
s
P
p
.002 w
.40294 .51815 m .38992 .5381 L .36338 .51691 L p
1 g
F P
s
P
p
.002 w
.36338 .51691 m .37964 .49082 L .40294 .51815 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51885 .58992 m .52214 .58287 L .55662 .58027 L p
1 g
F P
s
P
p
.002 w
.55601 .56526 m .55662 .58027 L .52214 .58287 L p
1 g
F P
s
P
p
.002 w
.55662 .58027 m .55601 .56526 L .5886 .55121 L p
1 g
F P
s
P
p
.002 w
.60395 .50546 m .61828 .53366 L .5886 .55121 L p
1 g
F P
s
P
p
.002 w
.61828 .53366 m .60395 .50546 L .62753 .4792 L p
1 g
F P
s
P
p
.002 w
.39486 .43659 m .36015 .46186 L .34512 .43235 L p
1 g
F P
s
P
p
.002 w
.34512 .43235 m .38407 .40312 L .39486 .43659 L p
1 g
F P
s
P
p
.002 w
.43454 .35108 m .37696 .37098 L .37369 .3413 L p
1 g
F P
s
P
p
.002 w
.37369 .3413 m .4339 .31998 L .43454 .35108 L p
1 g
F P
s
P
p
.002 w
.42922 .54284 m .42004 .55625 L .38992 .5381 L p
1 g
F P
s
P
p
.002 w
.38992 .5381 m .40294 .51815 L .42922 .54284 L p
1 g
F P
s
P
p
.002 w
.50302 .31543 m .4339 .31998 L .43527 .293 L p
1 g
F P
s
P
p
.002 w
.43527 .293 m .50533 .2882 L .50302 .31543 L p
1 g
F P
s
P
p
.002 w
.57705 .52959 m .5886 .55121 L .55601 .56526 L p
1 g
F P
s
P
p
.002 w
.5886 .55121 m .57705 .52959 L .60395 .50546 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.57158 .32859 m .63012 .35744 L .62211 .38653 L p
1 g
F P
s
P
p
.002 w
.63012 .35744 m .57158 .32859 L .57479 .30166 L p
1 g
F P
s
P
p
.002 w
.50533 .2882 m .57479 .30166 L .57158 .32859 L p
1 g
F P
s
P
p
.002 w
.61018 .41757 m .64697 .45179 L .62753 .4792 L p
1 g
F P
s
P
p
.002 w
.64697 .45179 m .61018 .41757 L .62211 .38653 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.52165 .57527 m .51735 .56797 L .54782 .55068 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40899 .47014 m .37964 .49082 L .36015 .46186 L p
1 g
F P
s
P
p
.002 w
.36015 .46186 m .39486 .43659 L .40899 .47014 L p
1 g
F P
s
P
p
.002 w
.57158 .32859 m .50302 .31543 L .50533 .2882 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51735 .56797 m .50967 .56177 L .53278 .5382 L p
1 g
F P
s
P
p
.002 w
.53278 .5382 m .54782 .55068 L .51735 .56797 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43722 .38526 m .38407 .40312 L .37696 .37098 L p
1 g
F P
s
P
p
.002 w
.37696 .37098 m .43454 .35108 L .43722 .38526 L p
1 g
F P
s
P
p
.002 w
.59467 .44946 m .62753 .4792 L .60395 .50546 L p
1 g
F P
s
P
p
.002 w
.62753 .4792 m .59467 .44946 L .61018 .41757 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42594 .50249 m .40294 .51815 L .37964 .49082 L p
1 g
F P
s
P
p
.002 w
.37964 .49082 m .40899 .47014 L .42594 .50249 L p
1 g
F P
s
P
p
.002 w
.47608 .55584 m .46559 .55885 L .44505 .53242 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.50967 .56177 m .49944 .55738 L .51248 .52933 L p
1 g
F P
s
P
p
.002 w
.51248 .52933 m .53278 .5382 L .50967 .56177 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.56607 .35937 m .62211 .38653 L .61018 .41757 L p
1 g
F P
s
P
p
.002 w
.62211 .38653 m .56607 .35937 L .57158 .32859 L p
1 g
F P
s
P
p
.002 w
.54782 .55068 m .53278 .5382 L .55522 .51095 L p
1 g
F P
s
P
p
.002 w
.50057 .34693 m .43454 .35108 L .4339 .31998 L p
1 g
F P
s
P
p
.002 w
.4339 .31998 m .50302 .31543 L .50057 .34693 L p
1 g
F P
s
P
p
.002 w
.57612 .48099 m .60395 .50546 L .57705 .52959 L p
1 g
F P
s
P
p
.002 w
.60395 .50546 m .57612 .48099 L .59467 .44946 L p
1 g
F P
s
P
p
.002 w
.44505 .53242 m .46586 .52627 L .47608 .55584 L p
1 g
F P
s
P
p
.002 w
.4878 .55533 m .47608 .55584 L .46586 .52627 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.49944 .55738 m .4878 .55533 L .48926 .52518 L p
1 g
F P
s
P
p
.002 w
.48926 .52518 m .51248 .52933 L .49944 .55738 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.46586 .52627 m .48926 .52518 L .4878 .55533 L p
1 g
F P
s
P
p
.002 w
.50302 .31543 m .57158 .32859 L .56607 .35937 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4419 .42126 m .39486 .43659 L .38407 .40312 L p
1 g
F P
s
P
p
.002 w
.38407 .40312 m .43722 .38526 L .4419 .42126 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.56607 .35937 m .50057 .34693 L .50302 .31543 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53278 .5382 m .51248 .52933 L .52539 .49765 L p
1 g
F P
s
P
p
.002 w
.52539 .49765 m .55522 .51095 L .53278 .5382 L p
1 g
F P
s
P
p
.002 w
.5584 .39296 m .61018 .41757 L .59467 .44946 L p
1 g
F P
s
P
p
.002 w
.61018 .41757 m .5584 .39296 L .56607 .35937 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44842 .4577 m .40899 .47014 L .39486 .43659 L p
1 g
F P
s
P
p
.002 w
.39486 .43659 m .4419 .42126 L .44842 .4577 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49805 .38163 m .43722 .38526 L .43454 .35108 L p
1 g
F P
s
P
p
.002 w
.43454 .35108 m .50057 .34693 L .49805 .38163 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48926 .52518 m .46586 .52627 L .45651 .49315 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51248 .52933 m .48926 .52518 L .49108 .49144 L p
1 g
F P
s
P
p
.002 w
.49108 .49144 m .52539 .49765 L .51248 .52933 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50057 .34693 m .56607 .35937 L .5584 .39296 L p
1 g
F P
s
P
p
.002 w
.54882 .42812 m .59467 .44946 L .57612 .48099 L p
1 g
F P
s
P
p
.002 w
.59467 .44946 m .54882 .42812 L .5584 .39296 L p
1 g
F P
s
P
p
.002 w
.45651 .49315 m .49108 .49144 L .48926 .52518 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.004 w
.48137 .64199 m
.48226 .6319 L
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57612 .48099 m .53767 .46347 L .54882 .42812 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5584 .39296 m .49805 .38163 L .50057 .34693 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49556 .41824 m .4419 .42126 L .43722 .38526 L p
1 g
F P
s
P
p
.002 w
.43722 .38526 m .49805 .38163 L .49556 .41824 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49805 .38163 m .5584 .39296 L .54882 .42812 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51662 .39863 L
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49321 .45533 m .44842 .4577 L .4419 .42126 L p
1 g
F P
s
P
p
.002 w
.4419 .42126 m .49556 .41824 L .49321 .45533 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53767 .46347 m .49321 .45533 L .49556 .41824 L p
1 g
F P
s
P
p
.002 w
.49556 .41824 m .54882 .42812 L .53767 .46347 L p
1 g
F P
s
P
p
.002 w
.54882 .42812 m .49556 .41824 L .49805 .38163 L p
1 g
F P
s
P
p
.004 w
.5184 .39521 m
.51917 .39373 L
s
P
p
.004 w
.51917 .39373 m
.53019 .37258 L
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .53019 .37258 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .47904 .66843 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.211628)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.211628)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4471 .42269 m .48327 .44313 L .49413 .41669 L p
1 g
F P
s
P
p
.002 w
.49413 .41669 m .46401 .39955 L .4471 .42269 L p
1 g
F P
s
P
p
.002 w
.52786 .4259 m .49413 .41669 L .48327 .44313 L p
1 g
F P
s
P
p
.002 w
.46401 .39955 m .49413 .41669 L .50515 .39053 L p
1 g
F P
s
P
p
.002 w
.49413 .41669 m .52786 .4259 L .53136 .39767 L p
1 g
F P
s
P
p
.002 w
.53136 .39767 m .50515 .39053 L .49413 .41669 L p
1 g
F P
s
P
p
.002 w
.43138 .44615 m .47278 .46936 L .48327 .44313 L p
1 g
F P
s
P
p
.002 w
.48327 .44313 m .4471 .42269 L .43138 .44615 L p
1 g
F P
s
P
p
.002 w
.52369 .4542 m .48327 .44313 L .47278 .46936 L p
1 g
F P
s
P
p
.002 w
.48327 .44313 m .52369 .4542 L .52786 .4259 L p
1 g
F P
s
P
p
.002 w
.56206 .42629 m .52786 .4259 L .52369 .4542 L p
1 g
F P
s
P
p
.002 w
.52786 .4259 m .56206 .42629 L .55791 .39783 L p
1 g
F P
s
P
p
.002 w
.55791 .39783 m .53136 .39767 L .52786 .4259 L p
1 g
F P
s
P
p
.002 w
.47278 .46936 m .51893 .48205 L .52369 .4542 L p
1 g
F P
s
P
p
.002 w
.5647 .45487 m .52369 .4542 L .51893 .48205 L p
1 g
F P
s
P
p
.002 w
.52369 .4542 m .5647 .45487 L .56206 .42629 L p
1 g
F P
s
P
p
.002 w
.50515 .39053 m .4818 .37714 L .46401 .39955 L p
1 g
F P
s
P
p
.002 w
.4818 .37714 m .50515 .39053 L .51614 .36512 L p
1 g
F P
s
P
p
.002 w
.50515 .39053 m .53136 .39767 L .53413 .37 L p
1 g
F P
s
P
p
.002 w
.53413 .37 m .51614 .36512 L .50515 .39053 L p
1 g
F P
s
P
p
.002 w
.53136 .39767 m .55791 .39783 L .55232 .37002 L p
1 g
F P
s
P
p
.002 w
.55232 .37002 m .53413 .37 L .53136 .39767 L p
1 g
F P
s
P
p
.002 w
.41717 .46949 m .46284 .49491 L .47278 .46936 L p
1 g
F P
s
P
p
.002 w
.47278 .46936 m .43138 .44615 L .41717 .46949 L p
1 g
F P
s
P
p
.002 w
.51893 .48205 m .47278 .46936 L .46284 .49491 L p
1 g
F P
s
P
p
.002 w
.41855 .39463 m .4471 .42269 L .46401 .39955 L p
1 g
F P
s
P
p
.002 w
.46401 .39955 m .4404 .37599 L .41855 .39463 L p
1 g
F P
s
P
p
.002 w
.4404 .37599 m .46401 .39955 L .4818 .37714 L p
1 g
F P
s
P
p
.002 w
.39853 .41432 m .43138 .44615 L .4471 .42269 L p
1 g
F P
s
P
p
.002 w
.4471 .42269 m .41855 .39463 L .39853 .41432 L p
1 g
F P
s
P
p
.002 w
.46284 .49491 m .51365 .50893 L .51893 .48205 L p
1 g
F P
s
P
p
.002 w
.56577 .48305 m .51893 .48205 L .51365 .50893 L p
1 g
F P
s
P
p
.002 w
.51893 .48205 m .56577 .48305 L .5647 .45487 L p
1 g
F P
s
P
p
.002 w
.4818 .37714 m .46363 .35874 L .4404 .37599 L p
1 g
F P
s
P
p
.002 w
.46363 .35874 m .4818 .37714 L .50016 .35589 L p
1 g
F P
s
P
p
.002 w
.51614 .36512 m .50016 .35589 L .4818 .37714 L p
1 g
F P
s
P
p
.002 w
.59345 .41765 m .56206 .42629 L .5647 .45487 L p
1 g
F P
s
P
p
.002 w
.56206 .42629 m .59345 .41765 L .58217 .39091 L p
1 g
F P
s
P
p
.002 w
.58217 .39091 m .55791 .39783 L .56206 .42629 L p
1 g
F P
s
P
p
.002 w
.55791 .39783 m .58217 .39091 L .56887 .36514 L p
1 g
F P
s
P
p
.002 w
.56887 .36514 m .55232 .37002 L .55791 .39783 L p
1 g
F P
s
P
p
.002 w
.50016 .35589 m .51614 .36512 L .5269 .34094 L p
1 g
F P
s
P
p
.002 w
.51614 .36512 m .53413 .37 L .5361 .34342 L p
1 g
F P
s
P
p
.002 w
.5361 .34342 m .5269 .34094 L .51614 .36512 L p
1 g
F P
s
P
p
.002 w
.60249 .44485 m .5647 .45487 L .56577 .48305 L p
1 g
F P
s
P
p
.002 w
.5647 .45487 m .60249 .44485 L .59345 .41765 L p
1 g
F P
s
P
p
.002 w
.53413 .37 m .55232 .37002 L .54539 .34339 L p
1 g
F P
s
P
p
.002 w
.54539 .34339 m .5361 .34342 L .53413 .37 L p
1 g
F P
s
P
p
.002 w
.38073 .4347 m .41717 .46949 L .43138 .44615 L p
1 g
F P
s
P
p
.002 w
.43138 .44615 m .39853 .41432 L .38073 .4347 L p
1 g
F P
s
P
p
.002 w
.40476 .49228 m .45365 .5193 L .46284 .49491 L p
1 g
F P
s
P
p
.002 w
.46284 .49491 m .41717 .46949 L .40476 .49228 L p
1 g
F P
s
P
p
.002 w
.51365 .50893 m .46284 .49491 L .45365 .5193 L p
1 g
F P
s
P
p
.002 w
.50016 .35589 m .48781 .3432 L .46363 .35874 L p
1 g
F P
s
P
p
.002 w
.48781 .3432 m .50016 .35589 L .51875 .33619 L p
1 g
F P
s
P
p
.002 w
.5269 .34094 m .51875 .33619 L .50016 .35589 L p
1 g
F P
s
P
p
.002 w
.45365 .5193 m .50795 .53433 L .51365 .50893 L p
1 g
F P
s
P
p
.002 w
.56524 .51028 m .51365 .50893 L .50795 .53433 L p
1 g
F P
s
P
p
.002 w
.51365 .50893 m .56524 .51028 L .56577 .48305 L p
1 g
F P
s
P
p
.002 w
.55232 .37002 m .56887 .36514 L .55379 .34083 L p
1 g
F P
s
P
p
.002 w
.55379 .34083 m .54539 .34339 L .55232 .37002 L p
1 g
F P
s
P
p
.002 w
.42576 .34816 m .4404 .37599 L .46363 .35874 L p
1 g
F P
s
P
p
.002 w
.46363 .35874 m .45255 .33707 L .42576 .34816 L p
1 g
F P
s
P
p
.002 w
.45255 .33707 m .46363 .35874 L .48781 .3432 L p
1 g
F P
s
P
p
.002 w
.40059 .3614 m .41855 .39463 L .4404 .37599 L p
1 g
F P
s
P
p
.002 w
.4404 .37599 m .42576 .34816 L .40059 .3614 L p
1 g
F P
s
P
p
.002 w
.60907 .47198 m .56577 .48305 L .56524 .51028 L p
1 g
F P
s
P
p
.002 w
.56577 .48305 m .60907 .47198 L .60249 .44485 L p
1 g
F P
s
P
p
.002 w
.48781 .3432 m .48042 .32831 L .45255 .33707 L p
1 g
F P
s
P
p
.002 w
.48042 .32831 m .48781 .3432 L .5125 .32968 L p
1 g
F P
s
P
p
.002 w
.51875 .33619 m .5125 .32968 L .48781 .3432 L p
1 g
F P
s
P
p
.002 w
.37757 .37655 m .39853 .41432 L .41855 .39463 L p
1 g
F P
s
P
p
.002 w
.41855 .39463 m .40059 .3614 L .37757 .37655 L p
1 g
F P
s
P
p
.002 w
.60165 .37744 m .58217 .39091 L .59345 .41765 L p
1 g
F P
s
P
p
.002 w
.58217 .39091 m .60165 .37744 L .58203 .35577 L p
1 g
F P
s
P
p
.002 w
.58203 .35577 m .56887 .36514 L .58217 .39091 L p
1 g
F P
s
P
p
.002 w
.36559 .45537 m .40476 .49228 L .41717 .46949 L p
1 g
F P
s
P
p
.002 w
.41717 .46949 m .38073 .4347 L .36559 .45537 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .51875 .33619 L .5269 .34094 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .5269 .34094 L .5361 .34342 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .5361 .34342 L .54539 .34339 L closepath p
1 g
F P
s
P
p
.002 w
.61885 .40056 m .59345 .41765 L .60249 .44485 L p
1 g
F P
s
P
p
.002 w
.59345 .41765 m .61885 .40056 L .60165 .37744 L p
1 g
F P
s
P
p
.002 w
.56887 .36514 m .58203 .35577 L .56041 .33599 L p
1 g
F P
s
P
p
.002 w
.56041 .33599 m .55379 .34083 L .56887 .36514 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .5125 .32968 L .51875 .33619 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .54539 .34339 L .55379 .34083 L closepath p
1 g
F P
s
P
p
.002 w
.39446 .51404 m .44542 .54202 L .45365 .5193 L p
1 g
F P
s
P
p
.002 w
.45365 .5193 m .40476 .49228 L .39446 .51404 L p
1 g
F P
s
P
p
.002 w
.50795 .53433 m .45365 .5193 L .44542 .54202 L p
1 g
F P
s
P
p
.002 w
.5125 .32968 m .50882 .32207 L .48042 .32831 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .50882 .32207 L .5125 .32968 L closepath p
1 g
F P
s
P
p
.002 w
.35723 .39334 m .38073 .4347 L .39853 .41432 L p
1 g
F P
s
P
p
.002 w
.39853 .41432 m .37757 .37655 L .35723 .39334 L p
1 g
F P
s
P
p
.002 w
.50795 .53433 m .56308 .53603 L .56524 .51028 L p
1 g
F P
s
P
p
.002 w
.61304 .4985 m .56524 .51028 L .56308 .53603 L p
1 g
F P
s
P
p
.002 w
.56524 .51028 m .61304 .4985 L .60907 .47198 L p
1 g
F P
s
P
p
.002 w
.63328 .4247 m .60249 .44485 L .60907 .47198 L p
1 g
F P
s
P
p
.002 w
.60249 .44485 m .63328 .4247 L .61885 .40056 L p
1 g
F P
s
P
p
.002 w
.4499 .31426 m .45255 .33707 L .48042 .32831 L p
1 g
F P
s
P
p
.002 w
.48042 .32831 m .47884 .31275 L .4499 .31426 L p
1 g
F P
s
P
p
.002 w
.47884 .31275 m .48042 .32831 L .50882 .32207 L p
1 g
F P
s
P
p
.002 w
.44542 .54202 m .50192 .55771 L .50795 .53433 L p
1 g
F P
s
P
p
.002 w
.56308 .53603 m .50795 .53433 L .50192 .55771 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .55379 .34083 L .56041 .33599 L closepath p
1 g
F P
s
P
p
.002 w
.42191 .3187 m .42576 .34816 L .45255 .33707 L p
1 g
F P
s
P
p
.002 w
.45255 .33707 m .4499 .31426 L .42191 .3187 L p
1 g
F P
s
P
p
.002 w
.50882 .32207 m .50814 .31416 L .47884 .31275 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .50814 .31416 L .50882 .32207 L closepath p
1 g
F P
s
P
p
.002 w
.39547 .32605 m .40059 .3614 L .42576 .34816 L p
1 g
F P
s
P
p
.002 w
.42576 .34816 m .42191 .3187 L .39547 .32605 L p
1 g
F P
s
P
p
.002 w
.59035 .34282 m .58203 .35577 L .60165 .37744 L p
1 g
F P
s
P
p
.002 w
.58203 .35577 m .59035 .34282 L .56452 .32936 L p
1 g
F P
s
P
p
.002 w
.56452 .32936 m .56041 .33599 L .58203 .35577 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .56041 .33599 L .56452 .32936 L closepath p
1 g
F P
s
P
p
.002 w
.3535 .47591 m .39446 .51404 L .40476 .49228 L p
1 g
F P
s
P
p
.002 w
.40476 .49228 m .36559 .45537 L .3535 .47591 L p
1 g
F P
s
P
p
.002 w
.61415 .35861 m .60165 .37744 L .61885 .40056 L p
1 g
F P
s
P
p
.002 w
.60165 .37744 m .61415 .35861 L .59035 .34282 L p
1 g
F P
s
P
p
.002 w
.4834 .29815 m .47884 .31275 L .50814 .31416 L p
1 g
F P
s
P
p
.002 w
.50814 .31416 m .51056 .30681 L .4834 .29815 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .51056 .30681 L .50814 .31416 L closepath p
1 g
F P
s
P
p
.002 w
.64456 .44937 m .60907 .47198 L .61304 .4985 L p
1 g
F P
s
P
p
.002 w
.60907 .47198 m .64456 .44937 L .63328 .4247 L p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .54222 .29665 L .53261 .29542 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .53261 .29542 L .52349 .29687 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .52349 .29687 L .51586 .30082 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .51586 .30082 L .51056 .30681 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .56452 .32936 L .56565 .32164 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .56565 .32164 L .56362 .31367 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .56362 .31367 L .55864 .30632 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .55864 .30632 L .55123 .30042 L closepath p
1 g
F P
s
P
p
.002 w
.53721 .31847 m .55123 .30042 L .54222 .29665 L closepath p
1 g
F P
s
P
p
.002 w
.34008 .41147 m .36559 .45537 L .38073 .4347 L p
1 g
F P
s
P
p
.002 w
.38073 .4347 m .35723 .39334 L .34008 .41147 L p
1 g
F P
s
P
p
.002 w
.45627 .2927 m .4499 .31426 L .47884 .31275 L p
1 g
F P
s
P
p
.002 w
.47884 .31275 m .4834 .29815 L .45627 .2927 L p
1 g
F P
s
P
p
.002 w
.56565 .32164 m .56452 .32936 L .59035 .34282 L p
1 g
F P
s
P
p
.002 w
.37119 .33622 m .37757 .37655 L .40059 .3614 L p
1 g
F P
s
P
p
.002 w
.40059 .3614 m .39547 .32605 L .37119 .33622 L p
1 g
F P
s
P
p
.002 w
.6354 .37644 m .61885 .40056 L .63328 .4247 L p
1 g
F P
s
P
p
.002 w
.61885 .40056 m .6354 .37644 L .61415 .35861 L p
1 g
F P
s
P
p
.002 w
.50192 .55771 m .55927 .55972 L .56308 .53603 L p
1 g
F P
s
P
p
.002 w
.61422 .52386 m .56308 .53603 L .55927 .55972 L p
1 g
F P
s
P
p
.002 w
.56308 .53603 m .61422 .52386 L .61304 .4985 L p
1 g
F P
s
P
p
.002 w
.49373 .28614 m .4834 .29815 L .51056 .30681 L p
1 g
F P
s
P
p
.002 w
.51056 .30681 m .51586 .30082 L .49373 .28614 L p
1 g
F P
s
P
p
.002 w
.38655 .53429 m .43833 .56256 L .44542 .54202 L p
1 g
F P
s
P
p
.002 w
.44542 .54202 m .39446 .51404 L .38655 .53429 L p
1 g
F P
s
P
p
.002 w
.50192 .55771 m .44542 .54202 L .43833 .56256 L p
1 g
F P
s
P
p
.002 w
.5928 .3276 m .59035 .34282 L .61415 .35861 L p
1 g
F P
s
P
p
.002 w
.59035 .34282 m .5928 .3276 L .56565 .32164 L p
1 g
F P
s
P
p
.002 w
.42975 .29067 m .42191 .3187 L .4499 .31426 L p
1 g
F P
s
P
p
.002 w
.4499 .31426 m .45627 .2927 L .42975 .29067 L p
1 g
F P
s
P
p
.002 w
.56362 .31367 m .56565 .32164 L .5928 .3276 L p
1 g
F P
s
P
p
.002 w
.43833 .56256 m .49568 .57852 L .50192 .55771 L p
1 g
F P
s
P
p
.002 w
.55927 .55972 m .50192 .55771 L .49568 .57852 L p
1 g
F P
s
P
p
.002 w
.50882 .27814 m .49373 .28614 L .51586 .30082 L p
1 g
F P
s
P
p
.002 w
.51586 .30082 m .52349 .29687 L .50882 .27814 L p
1 g
F P
s
P
p
.002 w
.65238 .47407 m .61304 .4985 L .61422 .52386 L p
1 g
F P
s
P
p
.002 w
.61304 .4985 m .65238 .47407 L .64456 .44937 L p
1 g
F P
s
P
p
.002 w
.5928 .3276 m .58897 .31173 L .56362 .31367 L p
1 g
F P
s
P
p
.002 w
.55864 .30632 m .56362 .31367 L .58897 .31173 L p
1 g
F P
s
P
p
.002 w
.47127 .27482 m .45627 .2927 L .4834 .29815 L p
1 g
F P
s
P
p
.002 w
.4834 .29815 m .49373 .28614 L .47127 .27482 L p
1 g
F P
s
P
p
.002 w
.65358 .39598 m .63328 .4247 L .64456 .44937 L p
1 g
F P
s
P
p
.002 w
.63328 .4247 m .65358 .39598 L .6354 .37644 L p
1 g
F P
s
P
p
.002 w
.34968 .34907 m .35723 .39334 L .37757 .37655 L p
1 g
F P
s
P
p
.002 w
.37757 .37655 m .37119 .33622 L .34968 .34907 L p
1 g
F P
s
P
p
.002 w
.34484 .49587 m .38655 .53429 L .39446 .51404 L p
1 g
F P
s
P
p
.002 w
.39446 .51404 m .3535 .47591 L .34484 .49587 L p
1 g
F P
s
P
p
.002 w
.61808 .33627 m .61415 .35861 L .6354 .37644 L p
1 g
F P
s
P
p
.002 w
.61415 .35861 m .61808 .33627 L .5928 .3276 L p
1 g
F P
s
P
p
.002 w
.52703 .27515 m .50882 .27814 L .52349 .29687 L p
1 g
F P
s
P
p
.002 w
.52349 .29687 m .53261 .29542 L .52703 .27515 L p
1 g
F P
s
P
p
.002 w
.40444 .29221 m .39547 .32605 L .42191 .3187 L p
1 g
F P
s
P
p
.002 w
.42191 .3187 m .42975 .29067 L .40444 .29221 L p
1 g
F P
s
P
p
.002 w
.32664 .43059 m .3535 .47591 L .36559 .45537 L p
1 g
F P
s
P
p
.002 w
.36559 .45537 m .34008 .41147 L .32664 .43059 L p
1 g
F P
s
P
p
.002 w
.58897 .31173 m .57915 .29701 L .55864 .30632 L p
1 g
F P
s
P
p
.002 w
.55123 .30042 m .55864 .30632 L .57915 .29701 L p
1 g
F P
s
P
p
.002 w
.58897 .31173 m .5928 .3276 L .61808 .33627 L p
1 g
F P
s
P
p
.002 w
.5463 .27757 m .52703 .27515 L .53261 .29542 L p
1 g
F P
s
P
p
.002 w
.53261 .29542 m .54222 .29665 L .5463 .27757 L p
1 g
F P
s
P
p
.002 w
.57915 .29701 m .56437 .28515 L .55123 .30042 L p
1 g
F P
s
P
p
.002 w
.54222 .29665 m .55123 .30042 L .56437 .28515 L p
1 g
F P
s
P
p
.002 w
.56437 .28515 m .5463 .27757 L .54222 .29665 L p
1 g
F P
s
P
p
.002 w
.49568 .57852 m .55383 .58078 L .55927 .55972 L p
1 g
F P
s
P
p
.002 w
.6125 .54747 m .55927 .55972 L .55383 .58078 L p
1 g
F P
s
P
p
.002 w
.55927 .55972 m .6125 .54747 L .61422 .52386 L p
1 g
F P
s
P
p
.002 w
.4935 .2628 m .47127 .27482 L .49373 .28614 L p
1 g
F P
s
P
p
.002 w
.49373 .28614 m .50882 .27814 L .4935 .2628 L p
1 g
F P
s
P
p
.002 w
.44896 .26725 m .42975 .29067 L .45627 .2927 L p
1 g
F P
s
P
p
.002 w
.45627 .2927 m .47127 .27482 L .44896 .26725 L p
1 g
F P
s
P
p
.002 w
.38132 .55251 m .4326 .58036 L .43833 .56256 L p
1 g
F P
s
P
p
.002 w
.43833 .56256 m .38655 .53429 L .38132 .55251 L p
1 g
F P
s
P
p
.002 w
.49568 .57852 m .43833 .56256 L .4326 .58036 L p
1 g
F P
s
P
p
.002 w
.66819 .41685 m .64456 .44937 L .65238 .47407 L p
1 g
F P
s
P
p
.002 w
.64456 .44937 m .66819 .41685 L .65358 .39598 L p
1 g
F P
s
P
p
.002 w
.64088 .34756 m .6354 .37644 L .65358 .39598 L p
1 g
F P
s
P
p
.002 w
.6354 .37644 m .64088 .34756 L .61808 .33627 L p
1 g
F P
s
P
p
.002 w
.65644 .49824 m .61422 .52386 L .6125 .54747 L p
1 g
F P
s
P
p
.002 w
.61422 .52386 m .65644 .49824 L .65238 .47407 L p
1 g
F P
s
P
p
.002 w
.33154 .36441 m .34008 .41147 L .35723 .39334 L p
1 g
F P
s
P
p
.002 w
.35723 .39334 m .34968 .34907 L .33154 .36441 L p
1 g
F P
s
P
p
.002 w
.38098 .29741 m .37119 .33622 L .39547 .32605 L p
1 g
F P
s
P
p
.002 w
.39547 .32605 m .40444 .29221 L .38098 .29741 L p
1 g
F P
s
P
p
.002 w
.4326 .58036 m .48934 .59619 L .49568 .57852 L p
1 g
F P
s
P
p
.002 w
.55383 .58078 m .49568 .57852 L .48934 .59619 L p
1 g
F P
s
P
p
.002 w
.61808 .33627 m .61267 .31279 L .58897 .31173 L p
1 g
F P
s
P
p
.002 w
.57915 .29701 m .58897 .31173 L .61267 .31279 L p
1 g
F P
s
P
p
.002 w
.61267 .31279 m .61808 .33627 L .64088 .34756 L p
1 g
F P
s
P
p
.002 w
.52057 .25822 m .4935 .2628 L .50882 .27814 L p
1 g
F P
s
P
p
.002 w
.50882 .27814 m .52703 .27515 L .52057 .25822 L p
1 g
F P
s
P
p
.002 w
.31736 .45028 m .34484 .49587 L .3535 .47591 L p
1 g
F P
s
P
p
.002 w
.3535 .47591 m .32664 .43059 L .31736 .45028 L p
1 g
F P
s
P
p
.002 w
.33998 .51477 m .38132 .55251 L .38655 .53429 L p
1 g
F P
s
P
p
.002 w
.38655 .53429 m .34484 .49587 L .33998 .51477 L p
1 g
F P
s
P
p
.002 w
.61267 .31279 m .59825 .29087 L .57915 .29701 L p
1 g
F P
s
P
p
.002 w
.56437 .28515 m .57915 .29701 L .59825 .29087 L p
1 g
F P
s
P
p
.002 w
.42733 .26374 m .40444 .29221 L .42975 .29067 L p
1 g
F P
s
P
p
.002 w
.42975 .29067 m .44896 .26725 L .42733 .26374 L p
1 g
F P
s
P
p
.002 w
.66059 .3613 m .65358 .39598 L .66819 .41685 L p
1 g
F P
s
P
p
.002 w
.65358 .39598 m .66059 .3613 L .64088 .34756 L p
1 g
F P
s
P
p
.002 w
.54931 .26179 m .52057 .25822 L .52703 .27515 L p
1 g
F P
s
P
p
.002 w
.52703 .27515 m .5463 .27757 L .54931 .26179 L p
1 g
F P
s
P
p
.002 w
.47785 .25137 m .44896 .26725 L .47127 .27482 L p
1 g
F P
s
P
p
.002 w
.47127 .27482 m .4935 .2628 L .47785 .25137 L p
1 g
F P
s
P
p
.002 w
.67878 .43862 m .65238 .47407 L .65644 .49824 L p
1 g
F P
s
P
p
.002 w
.65238 .47407 m .67878 .43862 L .66819 .41685 L p
1 g
F P
s
P
p
.002 w
.59825 .29087 m .57629 .27313 L .56437 .28515 L p
1 g
F P
s
P
p
.002 w
.5463 .27757 m .56437 .28515 L .57629 .27313 L p
1 g
F P
s
P
p
.002 w
.48934 .59619 m .54682 .59862 L .55383 .58078 L p
1 g
F P
s
P
p
.002 w
.60779 .56872 m .55383 .58078 L .54682 .59862 L p
1 g
F P
s
P
p
.002 w
.55383 .58078 m .60779 .56872 L .6125 .54747 L p
1 g
F P
s
P
p
.002 w
.36 .30631 m .34968 .34907 L .37119 .33622 L p
1 g
F P
s
P
p
.002 w
.37119 .33622 m .38098 .29741 L .36 .30631 L p
1 g
F P
s
P
p
.002 w
.57629 .27313 m .54931 .26179 L .5463 .27757 L p
1 g
F P
s
P
p
.002 w
.31736 .38197 m .32664 .43059 L .34008 .41147 L p
1 g
F P
s
P
p
.002 w
.34008 .41147 m .33154 .36441 L .31736 .38197 L p
1 g
F P
s
P
p
.002 w
.6565 .52131 m .6125 .54747 L .60779 .56872 L p
1 g
F P
s
P
p
.002 w
.6125 .54747 m .6565 .52131 L .65644 .49824 L p
1 g
F P
s
P
p
.002 w
.64088 .34756 m .63413 .31696 L .61267 .31279 L p
1 g
F P
s
P
p
.002 w
.59825 .29087 m .61267 .31279 L .63413 .31696 L p
1 g
F P
s
P
p
.002 w
.63413 .31696 m .64088 .34756 L .66059 .3613 L p
1 g
F P
s
P
p
.002 w
.37904 .56818 m .42843 .59489 L .4326 .58036 L p
1 g
F P
s
P
p
.002 w
.4326 .58036 m .38132 .55251 L .37904 .56818 L p
1 g
F P
s
P
p
.002 w
.48934 .59619 m .4326 .58036 L .42843 .59489 L p
1 g
F P
s
P
p
.002 w
.42843 .59489 m .48305 .61016 L .48934 .59619 L p
1 g
F P
s
P
p
.002 w
.54682 .59862 m .48934 .59619 L .48305 .61016 L p
1 g
F P
s
P
p
.002 w
.51331 .24524 m .47785 .25137 L .4935 .2628 L p
1 g
F P
s
P
p
.002 w
.4935 .2628 m .52057 .25822 L .51331 .24524 L p
1 g
F P
s
P
p
.002 w
.40694 .26459 m .38098 .29741 L .40444 .29221 L p
1 g
F P
s
P
p
.002 w
.40444 .29221 m .42733 .26374 L .40694 .26459 L p
1 g
F P
s
P
p
.002 w
.31269 .47009 m .33998 .51477 L .34484 .49587 L p
1 g
F P
s
P
p
.002 w
.34484 .49587 m .31736 .45028 L .31269 .47009 L p
1 g
F P
s
P
p
.002 w
.67663 .37727 m .66819 .41685 L .67878 .43862 L p
1 g
F P
s
P
p
.002 w
.66819 .41685 m .67663 .37727 L .66059 .3613 L p
1 g
F P
s
P
p
.002 w
.33923 .5321 m .37904 .56818 L .38132 .55251 L p
1 g
F P
s
P
p
.002 w
.38132 .55251 m .33998 .51477 L .33923 .5321 L p
1 g
F P
s
P
p
.002 w
.68491 .4608 m .65644 .49824 L .6565 .52131 L p
1 g
F P
s
P
p
.002 w
.65644 .49824 m .68491 .4608 L .67878 .43862 L p
1 g
F P
s
P
p
.002 w
.63413 .31696 m .61543 .2882 L .59825 .29087 L p
1 g
F P
s
P
p
.002 w
.57629 .27313 m .59825 .29087 L .61543 .2882 L p
1 g
F P
s
P
p
.002 w
.34214 .31884 m .33154 .36441 L .34968 .34907 L p
1 g
F P
s
P
p
.002 w
.34968 .34907 m .36 .30631 L .34214 .31884 L p
1 g
F P
s
P
p
.002 w
.46223 .24431 m .42733 .26374 L .44896 .26725 L p
1 g
F P
s
P
p
.002 w
.44896 .26725 m .47785 .25137 L .46223 .24431 L p
1 g
F P
s
P
p
.002 w
.30769 .4014 m .31736 .45028 L .32664 .43059 L p
1 g
F P
s
P
p
.002 w
.32664 .43059 m .31736 .38197 L .30769 .4014 L p
1 g
F P
s
P
p
.002 w
.55114 .24988 m .51331 .24524 L .52057 .25822 L p
1 g
F P
s
P
p
.002 w
.52057 .25822 m .54931 .26179 L .55114 .24988 L p
1 g
F P
s
P
p
.002 w
.48305 .61016 m .53831 .61263 L .54682 .59862 L p
1 g
F P
s
P
p
.002 w
.60007 .58701 m .54682 .59862 L .53831 .61263 L p
1 g
F P
s
P
p
.002 w
.54682 .59862 m .60007 .58701 L .60779 .56872 L p
1 g
F P
s
P
p
.002 w
.65273 .32428 m .66059 .3613 L .67663 .37727 L p
1 g
F P
s
P
p
.002 w
.66059 .3613 m .65273 .32428 L .63413 .31696 L p
1 g
F P
s
P
p
.002 w
.61543 .2882 m .58664 .26483 L .57629 .27313 L p
1 g
F P
s
P
p
.002 w
.54931 .26179 m .57629 .27313 L .58664 .26483 L p
1 g
F P
s
P
p
.002 w
.65238 .54267 m .60779 .56872 L .60007 .58701 L p
1 g
F P
s
P
p
.002 w
.60779 .56872 m .65238 .54267 L .6565 .52131 L p
1 g
F P
s
P
p
.002 w
.61543 .2882 m .63413 .31696 L .65273 .32428 L p
1 g
F P
s
P
p
.002 w
.58664 .26483 m .55114 .24988 L .54931 .26179 L p
1 g
F P
s
P
p
.002 w
.38838 .26999 m .36 .30631 L .38098 .29741 L p
1 g
F P
s
P
p
.002 w
.38098 .29741 m .40694 .26459 L .38838 .26999 L p
1 g
F P
s
P
p
.002 w
.68843 .39518 m .67878 .43862 L .68491 .4608 L p
1 g
F P
s
P
p
.002 w
.67878 .43862 m .68843 .39518 L .67663 .37727 L p
1 g
F P
s
P
p
.002 w
.37992 .58076 m .42601 .60561 L .42843 .59489 L p
1 g
F P
s
P
p
.002 w
.42843 .59489 m .37904 .56818 L .37992 .58076 L p
1 g
F P
s
P
p
.002 w
.48305 .61016 m .42843 .59489 L .42601 .60561 L p
1 g
F P
s
P
p
.002 w
.42601 .60561 m .47696 .61988 L .48305 .61016 L p
1 g
F P
s
P
p
.002 w
.53831 .61263 m .48305 .61016 L .47696 .61988 L p
1 g
F P
s
P
p
.002 w
.5054 .23674 m .46223 .24431 L .47785 .25137 L p
1 g
F P
s
P
p
.002 w
.47785 .25137 m .51331 .24524 L .5054 .23674 L p
1 g
F P
s
P
p
.002 w
.31298 .4895 m .33923 .5321 L .33998 .51477 L p
1 g
F P
s
P
p
.002 w
.33998 .51477 m .31269 .47009 L .31298 .4895 L p
1 g
F P
s
P
p
.002 w
.68623 .48285 m .6565 .52131 L .65238 .54267 L p
1 g
F P
s
P
p
.002 w
.6565 .52131 m .68623 .48285 L .68491 .4608 L p
1 g
F P
s
P
p
.002 w
.32803 .33485 m .31736 .38197 L .33154 .36441 L p
1 g
F P
s
P
p
.002 w
.33154 .36441 m .34214 .31884 L .32803 .33485 L p
1 g
F P
s
P
p
.002 w
.44704 .24207 m .40694 .26459 L .42733 .26374 L p
1 g
F P
s
P
p
.002 w
.42733 .26374 m .46223 .24431 L .44704 .24207 L p
1 g
F P
s
P
p
.002 w
.65273 .32428 m .63016 .28925 L .61543 .2882 L p
1 g
F P
s
P
p
.002 w
.58664 .26483 m .61543 .2882 L .63016 .28925 L p
1 g
F P
s
P
p
.002 w
.34283 .54731 m .37992 .58076 L .37904 .56818 L p
1 g
F P
s
P
p
.002 w
.37904 .56818 m .33923 .5321 L .34283 .54731 L p
1 g
F P
s
P
p
.002 w
.303 .42229 m .31269 .47009 L .31736 .45028 L p
1 g
F P
s
P
p
.002 w
.31736 .45028 m .30769 .4014 L .303 .42229 L p
1 g
F P
s
P
p
.002 w
.66786 .33472 m .67663 .37727 L .68843 .39518 L p
1 g
F P
s
P
p
.002 w
.67663 .37727 m .66786 .33472 L .65273 .32428 L p
1 g
F P
s
P
p
.002 w
.55164 .24237 m .5054 .23674 L .51331 .24524 L p
1 g
F P
s
P
p
.002 w
.51331 .24524 m .55114 .24988 L .55164 .24237 L p
1 g
F P
s
P
p
.002 w
.53831 .61263 m .58938 .60171 L .60007 .58701 L p
1 g
F P
s
P
p
.002 w
.64398 .56168 m .60007 .58701 L .58938 .60171 L p
1 g
F P
s
P
p
.002 w
.60007 .58701 m .64398 .56168 L .65238 .54267 L p
1 g
F P
s
P
p
.002 w
.63016 .28925 m .65273 .32428 L .66786 .33472 L p
1 g
F P
s
P
p
.002 w
.47696 .61988 m .52843 .62227 L .53831 .61263 L p
1 g
F P
s
P
p
.002 w
.58938 .60171 m .53831 .61263 L .52843 .62227 L p
1 g
F P
s
P
p
.002 w
.63016 .28925 m .59507 .26068 L .58664 .26483 L p
1 g
F P
s
P
p
.002 w
.55114 .24988 m .58664 .26483 L .59507 .26068 L p
1 g
F P
s
P
p
.002 w
.37225 .28004 m .34214 .31884 L .36 .30631 L p
1 g
F P
s
P
p
.002 w
.36 .30631 m .38838 .26999 L .37225 .28004 L p
1 g
F P
s
P
p
.002 w
.69547 .41465 m .68491 .4608 L .68623 .48285 L p
1 g
F P
s
P
p
.002 w
.68491 .4608 m .69547 .41465 L .68843 .39518 L p
1 g
F P
s
P
p
.002 w
.59507 .26068 m .55164 .24237 L .55114 .24988 L p
1 g
F P
s
P
p
.002 w
.31825 .35407 m .30769 .4014 L .31736 .38197 L p
1 g
F P
s
P
p
.002 w
.31736 .38197 m .32803 .33485 L .31825 .35407 L p
1 g
F P
s
P
p
.002 w
.68248 .50418 m .65238 .54267 L .64398 .56168 L p
1 g
F P
s
P
p
.002 w
.65238 .54267 m .68248 .50418 L .68623 .48285 L p
1 g
F P
s
P
p
.002 w
.49701 .23324 m .44704 .24207 L .46223 .24431 L p
1 g
F P
s
P
p
.002 w
.46223 .24431 m .5054 .23674 L .49701 .23324 L p
1 g
F P
s
P
p
.002 w
.38414 .58974 m .4255 .612 L .42601 .60561 L p
1 g
F P
s
P
p
.002 w
.42601 .60561 m .37992 .58076 L .38414 .58974 L p
1 g
F P
s
P
p
.002 w
.47696 .61988 m .42601 .60561 L .4255 .612 L p
1 g
F P
s
P
p
.002 w
.31849 .50797 m .34283 .54731 L .33923 .5321 L p
1 g
F P
s
P
p
.002 w
.33923 .5321 m .31298 .4895 L .31849 .50797 L p
1 g
F P
s
P
p
.002 w
.43272 .24498 m .38838 .26999 L .40694 .26459 L p
1 g
F P
s
P
p
.002 w
.40694 .26459 m .44704 .24207 L .43272 .24498 L p
1 g
F P
s
P
p
.002 w
.4255 .612 m .47125 .62482 L .47696 .61988 L p
1 g
F P
s
P
p
.002 w
.52843 .62227 m .47696 .61988 L .47125 .62482 L p
1 g
F P
s
P
p
.002 w
.30368 .44409 m .31298 .4895 L .31269 .47009 L p
1 g
F P
s
P
p
.002 w
.31269 .47009 m .303 .42229 L .30368 .44409 L p
1 g
F P
s
P
p
.002 w
.67894 .34819 m .68843 .39518 L .69547 .41465 L p
1 g
F P
s
P
p
.002 w
.68843 .39518 m .67894 .34819 L .66786 .33472 L p
1 g
F P
s
P
p
.002 w
.66786 .33472 m .6419 .29423 L .63016 .28925 L p
1 g
F P
s
P
p
.002 w
.59507 .26068 m .63016 .28925 L .6419 .29423 L p
1 g
F P
s
P
p
.002 w
.35096 .55986 m .38414 .58974 L .37992 .58076 L p
1 g
F P
s
P
p
.002 w
.37992 .58076 m .34283 .54731 L .35096 .55986 L p
1 g
F P
s
P
p
.002 w
.52843 .62227 m .57583 .61226 L .58938 .60171 L p
1 g
F P
s
P
p
.002 w
.63132 .57772 m .58938 .60171 L .57583 .61226 L p
1 g
F P
s
P
p
.002 w
.58938 .60171 m .63132 .57772 L .64398 .56168 L p
1 g
F P
s
P
p
.002 w
.6419 .29423 m .66786 .33472 L .67894 .34819 L p
1 g
F P
s
P
p
.002 w
.35914 .2947 m .32803 .33485 L .34214 .31884 L p
1 g
F P
s
P
p
.002 w
.34214 .31884 m .37225 .28004 L .35914 .2947 L p
1 g
F P
s
P
p
.002 w
.69731 .43523 m .68623 .48285 L .68248 .50418 L p
1 g
F P
s
P
p
.002 w
.68623 .48285 m .69731 .43523 L .69547 .41465 L p
1 g
F P
s
P
p
.002 w
.55074 .23977 m .49701 .23324 L .5054 .23674 L p
1 g
F P
s
P
p
.002 w
.5054 .23674 m .55164 .24237 L .55074 .23977 L p
1 g
F P
s
P
p
.002 w
.47125 .62482 m .51735 .62701 L .52843 .62227 L p
1 g
F P
s
P
p
.002 w
.57583 .61226 m .52843 .62227 L .51735 .62701 L p
1 g
F P
s
P
p
.002 w
.31331 .3761 m .303 .42229 L .30769 .4014 L p
1 g
F P
s
P
p
.002 w
.30769 .4014 m .31825 .35407 L .31331 .3761 L p
1 g
F P
s
P
p
.002 w
.6419 .29423 m .60123 .26106 L .59507 .26068 L p
1 g
F P
s
P
p
.002 w
.55164 .24237 m .59507 .26068 L .60123 .26106 L p
1 g
F P
s
P
p
.002 w
.64398 .56168 m .67352 .52416 L .68248 .50418 L p
1 g
F P
s
P
p
.002 w
.67352 .52416 m .64398 .56168 L .63132 .57772 L p
1 g
F P
s
P
p
.002 w
.60123 .26106 m .55074 .23977 L .55164 .24237 L p
1 g
F P
s
P
p
.002 w
.41974 .25327 m .37225 .28004 L .38838 .26999 L p
1 g
F P
s
P
p
.002 w
.38838 .26999 m .43272 .24498 L .41974 .25327 L p
1 g
F P
s
P
p
.002 w
.48834 .23516 m .43272 .24498 L .44704 .24207 L p
1 g
F P
s
P
p
.002 w
.44704 .24207 m .49701 .23324 L .48834 .23516 L p
1 g
F P
s
P
p
.002 w
.32933 .5249 m .35096 .55986 L .34283 .54731 L p
1 g
F P
s
P
p
.002 w
.34283 .54731 m .31849 .50797 L .32933 .5249 L p
1 g
F P
s
P
p
.002 w
.30998 .46623 m .31849 .50797 L .31298 .4895 L p
1 g
F P
s
P
p
.002 w
.31298 .4895 m .30368 .44409 L .30998 .46623 L p
1 g
F P
s
P
p
.002 w
.69547 .41465 m .68541 .36447 L .67894 .34819 L p
1 g
F P
s
P
p
.002 w
.68541 .36447 m .69547 .41465 L .69731 .43523 L p
1 g
F P
s
P
p
.002 w
.3918 .59462 m .42705 .6136 L .4255 .612 L p
1 g
F P
s
P
p
.002 w
.4255 .612 m .38414 .58974 L .3918 .59462 L p
1 g
F P
s
P
p
.002 w
.47125 .62482 m .4255 .612 L .42705 .6136 L p
1 g
F P
s
P
p
.002 w
.42705 .6136 m .46608 .62454 L .47125 .62482 L p
1 g
F P
s
P
p
.002 w
.51735 .62701 m .47125 .62482 L .46608 .62454 L p
1 g
F P
s
P
p
.002 w
.67894 .34819 m .65016 .30323 L .6419 .29423 L p
1 g
F P
s
P
p
.002 w
.60123 .26106 m .6419 .29423 L .65016 .30323 L p
1 g
F P
s
P
p
.002 w
.34962 .31378 m .31825 .35407 L .32803 .33485 L p
1 g
F P
s
P
p
.002 w
.32803 .33485 m .35914 .2947 L .34962 .31378 L p
1 g
F P
s
P
p
.002 w
.68248 .50418 m .69364 .45638 L .69731 .43523 L p
1 g
F P
s
P
p
.002 w
.69364 .45638 m .68248 .50418 L .67352 .52416 L p
1 g
F P
s
P
p
.002 w
.36364 .56925 m .3918 .59462 L .38414 .58974 L p
1 g
F P
s
P
p
.002 w
.38414 .58974 m .35096 .55986 L .36364 .56925 L p
1 g
F P
s
P
p
.002 w
.51735 .62701 m .55964 .61811 L .57583 .61226 L p
1 g
F P
s
P
p
.002 w
.57583 .61226 m .61453 .59018 L .63132 .57772 L p
1 g
F P
s
P
p
.002 w
.61453 .59018 m .57583 .61226 L .55964 .61811 L p
1 g
F P
s
P
p
.002 w
.65016 .30323 m .67894 .34819 L .68541 .36447 L p
1 g
F P
s
P
p
.002 w
.31359 .4004 m .30368 .44409 L .303 .42229 L p
1 g
F P
s
P
p
.002 w
.303 .42229 m .31331 .3761 L .31359 .4004 L p
1 g
F P
s
P
p
.002 w
.46608 .62454 m .50533 .6264 L .51735 .62701 L p
1 g
F P
s
P
p
.002 w
.55964 .61811 m .51735 .62701 L .50533 .6264 L p
1 g
F P
s
P
p
.002 w
.65933 .54214 m .63132 .57772 L .61453 .59018 L p
1 g
F P
s
P
p
.002 w
.63132 .57772 m .65933 .54214 L .67352 .52416 L p
1 g
F P
s
P
p
.002 w
.54835 .24247 m .48834 .23516 L .49701 .23324 L p
1 g
F P
s
P
p
.002 w
.49701 .23324 m .55074 .23977 L .54835 .24247 L p
1 g
F P
s
P
p
.002 w
.65016 .30323 m .60479 .26626 L .60123 .26106 L p
1 g
F P
s
P
p
.002 w
.55074 .23977 m .60123 .26106 L .60479 .26626 L p
1 g
F P
s
P
p
.002 w
.40857 .26701 m .35914 .2947 L .37225 .28004 L p
1 g
F P
s
P
p
.002 w
.37225 .28004 m .41974 .25327 L .40857 .26701 L p
1 g
F P
s
P
p
.002 w
.60479 .26626 m .54835 .24247 L .55074 .23977 L p
1 g
F P
s
P
p
.002 w
.68683 .38324 m .69731 .43523 L .69364 .45638 L p
1 g
F P
s
P
p
.002 w
.69731 .43523 m .68683 .38324 L .68541 .36447 L p
1 g
F P
s
P
p
.002 w
.47963 .24279 m .41974 .25327 L .43272 .24498 L p
1 g
F P
s
P
p
.002 w
.43272 .24498 m .48834 .23516 L .47963 .24279 L p
1 g
F P
s
P
p
.002 w
.32197 .48803 m .32933 .5249 L .31849 .50797 L p
1 g
F P
s
P
p
.002 w
.31849 .50797 m .30998 .46623 L .32197 .48803 L p
1 g
F P
s
P
p
.002 w
.34546 .53971 m .36364 .56925 L .35096 .55986 L p
1 g
F P
s
P
p
.002 w
.35096 .55986 m .32933 .5249 L .34546 .53971 L p
1 g
F P
s
P
p
.002 w
.68428 .4775 m .67352 .52416 L .65933 .54214 L p
1 g
F P
s
P
p
.002 w
.67352 .52416 m .68428 .4775 L .69364 .45638 L p
1 g
F P
s
P
p
.002 w
.34417 .3369 m .31331 .3761 L .31825 .35407 L p
1 g
F P
s
P
p
.002 w
.31825 .35407 m .34962 .31378 L .34417 .3369 L p
1 g
F P
s
P
p
.002 w
.40289 .59501 m .43076 .61004 L .42705 .6136 L p
1 g
F P
s
P
p
.002 w
.42705 .6136 m .3918 .59462 L .40289 .59501 L p
1 g
F P
s
P
p
.002 w
.46608 .62454 m .42705 .6136 L .43076 .61004 L p
1 g
F P
s
P
p
.002 w
.43076 .61004 m .46166 .61869 L .46608 .62454 L p
1 g
F P
s
P
p
.002 w
.50533 .6264 m .46608 .62454 L .46166 .61869 L p
1 g
F P
s
P
p
.002 w
.50533 .6264 m .54113 .61882 L .55964 .61811 L p
1 g
F P
s
P
p
.002 w
.5939 .59849 m .55964 .61811 L .54113 .61882 L p
1 g
F P
s
P
p
.002 w
.55964 .61811 m .5939 .59849 L .61453 .59018 L p
1 g
F P
s
P
p
.002 w
.68541 .36447 m .65446 .31625 L .65016 .30323 L p
1 g
F P
s
P
p
.002 w
.60479 .26626 m .65016 .30323 L .65446 .31625 L p
1 g
F P
s
P
p
.002 w
.65446 .31625 m .68541 .36447 L .68683 .38324 L p
1 g
F P
s
P
p
.002 w
.31932 .4263 m .30998 .46623 L .30368 .44409 L p
1 g
F P
s
P
p
.002 w
.30368 .44409 m .31359 .4004 L .31932 .4263 L p
1 g
F P
s
P
p
.002 w
.38074 .57498 m .40289 .59501 L .3918 .59462 L p
1 g
F P
s
P
p
.002 w
.3918 .59462 m .36364 .56925 L .38074 .57498 L p
1 g
F P
s
P
p
.002 w
.6401 .55747 m .61453 .59018 L .5939 .59849 L p
1 g
F P
s
P
p
.002 w
.61453 .59018 m .6401 .55747 L .65933 .54214 L p
1 g
F P
s
P
p
.002 w
.46166 .61869 m .49266 .62013 L .50533 .6264 L p
1 g
F P
s
P
p
.002 w
.54113 .61882 m .50533 .6264 L .49266 .62013 L p
1 g
F P
s
P
p
.002 w
.54446 .25075 m .47963 .24279 L .48834 .23516 L p
1 g
F P
s
P
p
.002 w
.48834 .23516 m .54835 .24247 L .54446 .25075 L p
1 g
F P
s
P
p
.002 w
.39969 .28606 m .34962 .31378 L .35914 .2947 L p
1 g
F P
s
P
p
.002 w
.35914 .2947 m .40857 .26701 L .39969 .28606 L p
1 g
F P
s
P
p
.002 w
.68288 .40407 m .69364 .45638 L .68428 .4775 L p
1 g
F P
s
P
p
.002 w
.69364 .45638 m .68288 .40407 L .68683 .38324 L p
1 g
F P
s
P
p
.002 w
.33952 .50878 m .34546 .53971 L .32933 .5249 L p
1 g
F P
s
P
p
.002 w
.32933 .5249 m .32197 .48803 L .33952 .50878 L p
1 g
F P
s
P
p
.002 w
.65446 .31625 m .60548 .27644 L .60479 .26626 L p
1 g
F P
s
P
p
.002 w
.54835 .24247 m .60479 .26626 L .60548 .27644 L p
1 g
F P
s
P
p
.002 w
.47117 .25625 m .40857 .26701 L .41974 .25327 L p
1 g
F P
s
P
p
.002 w
.41974 .25327 m .47963 .24279 L .47117 .25625 L p
1 g
F P
s
P
p
.002 w
.66925 .4979 m .65933 .54214 L .6401 .55747 L p
1 g
F P
s
P
p
.002 w
.65933 .54214 m .66925 .4979 L .68428 .4775 L p
1 g
F P
s
P
p
.002 w
.36664 .5518 m .38074 .57498 L .36364 .56925 L p
1 g
F P
s
P
p
.002 w
.36364 .56925 m .34546 .53971 L .36664 .5518 L p
1 g
F P
s
P
p
.002 w
.34316 .36349 m .31359 .4004 L .31331 .3761 L p
1 g
F P
s
P
p
.002 w
.31331 .3761 m .34417 .3369 L .34316 .36349 L p
1 g
F P
s
P
p
.002 w
.60548 .27644 m .54446 .25075 L .54835 .24247 L p
1 g
F P
s
P
p
.002 w
.33056 .453 m .32197 .48803 L .30998 .46623 L p
1 g
F P
s
P
p
.002 w
.30998 .46623 m .31932 .4263 L .33056 .453 L p
1 g
F P
s
P
p
.002 w
.49266 .62013 m .52077 .6141 L .54113 .61882 L p
1 g
F P
s
P
p
.002 w
.56988 .60221 m .54113 .61882 L .52077 .6141 L p
1 g
F P
s
P
p
.002 w
.54113 .61882 m .56988 .60221 L .5939 .59849 L p
1 g
F P
s
P
p
.002 w
.65443 .33311 m .68683 .38324 L .68288 .40407 L p
1 g
F P
s
P
p
.002 w
.68683 .38324 m .65443 .33311 L .65446 .31625 L p
1 g
F P
s
P
p
.002 w
.61623 .56954 m .5939 .59849 L .56988 .60221 L p
1 g
F P
s
P
p
.002 w
.5939 .59849 m .61623 .56954 L .6401 .55747 L p
1 g
F P
s
P
p
.002 w
.41727 .5906 m .43665 .60108 L .43076 .61004 L p
1 g
F P
s
P
p
.002 w
.43076 .61004 m .40289 .59501 L .41727 .5906 L p
1 g
F P
s
P
p
.002 w
.46166 .61869 m .43076 .61004 L .43665 .60108 L p
1 g
F P
s
P
p
.002 w
.60548 .27644 m .65446 .31625 L .65443 .33311 L p
1 g
F P
s
P
p
.002 w
.43665 .60108 m .45817 .6071 L .46166 .61869 L p
1 g
F P
s
P
p
.002 w
.49266 .62013 m .46166 .61869 L .45817 .6071 L p
1 g
F P
s
P
p
.002 w
.40198 .57668 m .41727 .5906 L .40289 .59501 L p
1 g
F P
s
P
p
.002 w
.40289 .59501 m .38074 .57498 L .40198 .57668 L p
1 g
F P
s
P
p
.002 w
.3935 .31007 m .34417 .3369 L .34962 .31378 L p
1 g
F P
s
P
p
.002 w
.34962 .31378 m .39969 .28606 L .3935 .31007 L p
1 g
F P
s
P
p
.002 w
.6734 .42637 m .68428 .4775 L .66925 .4979 L p
1 g
F P
s
P
p
.002 w
.68428 .4775 m .6734 .42637 L .68288 .40407 L p
1 g
F P
s
P
p
.002 w
.45817 .6071 m .47971 .60806 L .49266 .62013 L p
1 g
F P
s
P
p
.002 w
.52077 .6141 m .49266 .62013 L .47971 .60806 L p
1 g
F P
s
P
p
.002 w
.36228 .52772 m .36664 .5518 L .34546 .53971 L p
1 g
F P
s
P
p
.002 w
.34546 .53971 m .33952 .50878 L .36228 .52772 L p
1 g
F P
s
P
p
.002 w
.6488 .51689 m .6401 .55747 L .61623 .56954 L p
1 g
F P
s
P
p
.002 w
.6401 .55747 m .6488 .51689 L .66925 .4979 L p
1 g
F P
s
P
p
.002 w
.34683 .3928 m .31932 .4263 L .31359 .4004 L p
1 g
F P
s
P
p
.002 w
.31359 .4004 m .34316 .36349 L .34683 .3928 L p
1 g
F P
s
P
p
.002 w
.53909 .2647 m .47117 .25625 L .47963 .24279 L p
1 g
F P
s
P
p
.002 w
.47963 .24279 m .54446 .25075 L .53909 .2647 L p
1 g
F P
s
P
p
.002 w
.3924 .56066 m .40198 .57668 L .38074 .57498 L p
1 g
F P
s
P
p
.002 w
.38074 .57498 m .36664 .5518 L .3924 .56066 L p
1 g
F P
s
P
p
.002 w
.46326 .27543 m .39969 .28606 L .40857 .26701 L p
1 g
F P
s
P
p
.002 w
.40857 .26701 m .47117 .25625 L .46326 .27543 L p
1 g
F P
s
P
p
.002 w
.3471 .47964 m .33952 .50878 L .32197 .48803 L p
1 g
F P
s
P
p
.002 w
.32197 .48803 m .33056 .453 L .3471 .47964 L p
1 g
F P
s
P
p
.002 w
.65443 .33311 m .60308 .29159 L .60548 .27644 L p
1 g
F P
s
P
p
.002 w
.54446 .25075 m .60548 .27644 L .60308 .29159 L p
1 g
F P
s
P
p
.002 w
.52077 .6141 m .54309 .60098 L .56988 .60221 L p
1 g
F P
s
P
p
.002 w
.58829 .57781 m .56988 .60221 L .54309 .60098 L p
1 g
F P
s
P
p
.002 w
.56988 .60221 m .58829 .57781 L .61623 .56954 L p
1 g
F P
s
P
p
.002 w
.60308 .29159 m .53909 .2647 L .54446 .25075 L p
1 g
F P
s
P
p
.002 w
.64982 .35349 m .68288 .40407 L .6734 .42637 L p
1 g
F P
s
P
p
.002 w
.68288 .40407 m .64982 .35349 L .65443 .33311 L p
1 g
F P
s
P
p
.002 w
.47971 .60806 m .4991 .60379 L .52077 .6141 L p
1 g
F P
s
P
p
.002 w
.54309 .60098 m .52077 .6141 L .4991 .60379 L p
1 g
F P
s
P
p
.002 w
.60308 .29159 m .65443 .33311 L .64982 .35349 L p
1 g
F P
s
P
p
.002 w
.65845 .44945 m .66925 .4979 L .6488 .51689 L p
1 g
F P
s
P
p
.002 w
.66925 .4979 m .65845 .44945 L .6734 .42637 L p
1 g
F P
s
P
p
.002 w
.43467 .58126 m .44467 .58669 L .43665 .60108 L p
1 g
F P
s
P
p
.002 w
.43665 .60108 m .41727 .5906 L .43467 .58126 L p
1 g
F P
s
P
p
.002 w
.45817 .6071 m .43665 .60108 L .44467 .58669 L p
1 g
F P
s
P
p
.002 w
.39036 .33842 m .34316 .36349 L .34417 .3369 L p
1 g
F P
s
P
p
.002 w
.34417 .3369 m .3935 .31007 L .39036 .33842 L p
1 g
F P
s
P
p
.002 w
.44467 .58669 m .45579 .58979 L .45817 .6071 L p
1 g
F P
s
P
p
.002 w
.47971 .60806 m .45817 .6071 L .45579 .58979 L p
1 g
F P
s
P
p
.002 w
.62341 .53376 m .61623 .56954 L .58829 .57781 L p
1 g
F P
s
P
p
.002 w
.61623 .56954 m .62341 .53376 L .6488 .51689 L p
1 g
F P
s
P
p
.002 w
.3552 .42387 m .33056 .453 L .31932 .4263 L p
1 g
F P
s
P
p
.002 w
.31932 .4263 m .34683 .3928 L .3552 .42387 L p
1 g
F P
s
P
p
.002 w
.38965 .54417 m .3924 .56066 L .36664 .5518 L p
1 g
F P
s
P
p
.002 w
.36664 .5518 m .36228 .52772 L .38965 .54417 L p
1 g
F P
s
P
p
.002 w
.42685 .57406 m .43467 .58126 L .41727 .5906 L p
1 g
F P
s
P
p
.002 w
.41727 .5906 m .40198 .57668 L .42685 .57406 L p
1 g
F P
s
P
p
.002 w
.45579 .58979 m .46689 .59025 L .47971 .60806 L p
1 g
F P
s
P
p
.002 w
.4991 .60379 m .47971 .60806 L .46689 .59025 L p
1 g
F P
s
P
p
.002 w
.36855 .50526 m .36228 .52772 L .33952 .50878 L p
1 g
F P
s
P
p
.002 w
.33952 .50878 m .3471 .47964 L .36855 .50526 L p
1 g
F P
s
P
p
.002 w
.53233 .28417 m .46326 .27543 L .47117 .25625 L p
1 g
F P
s
P
p
.002 w
.47117 .25625 m .53909 .2647 L .53233 .28417 L p
1 g
F P
s
P
p
.002 w
.42204 .56584 m .42685 .57406 L .40198 .57668 L p
1 g
F P
s
P
p
.002 w
.40198 .57668 m .3924 .56066 L .42204 .56584 L p
1 g
F P
s
P
p
.002 w
.45619 .29997 m .3935 .31007 L .39969 .28606 L p
1 g
F P
s
P
p
.002 w
.39969 .28606 m .46326 .27543 L .45619 .29997 L p
1 g
F P
s
P
p
.002 w
.4991 .60379 m .51432 .59465 L .54309 .60098 L p
1 g
F P
s
P
p
.002 w
.5571 .58187 m .54309 .60098 L .51432 .59465 L p
1 g
F P
s
P
p
.002 w
.54309 .60098 m .5571 .58187 L .58829 .57781 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.64055 .37687 m .6734 .42637 L .65845 .44945 L p
1 g
F P
s
P
p
.002 w
.6734 .42637 m .64055 .37687 L .64982 .35349 L p
1 g
F P
s
P
p
.002 w
.46689 .59025 m .47681 .588 L .4991 .60379 L p
1 g
F P
s
P
p
.002 w
.51432 .59465 m .4991 .60379 L .47681 .588 L p
1 g
F P
s
P
p
.002 w
.64982 .35349 m .59749 .31149 L .60308 .29159 L p
1 g
F P
s
P
p
.002 w
.53909 .2647 m .60308 .29159 L .59749 .31149 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.46466 .53691 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63834 .47255 m .6488 .51689 L .62341 .53376 L p
1 g
F P
s
P
p
.002 w
.6488 .51689 m .63834 .47255 L .65845 .44945 L p
1 g
F P
s
P
p
.002 w
.5938 .54784 m .58829 .57781 L .5571 .58187 L p
1 g
F P
s
P
p
.002 w
.58829 .57781 m .5938 .54784 L .62341 .53376 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.36812 .45565 m .3471 .47964 L .33056 .453 L p
1 g
F P
s
P
p
.002 w
.33056 .453 m .3552 .42387 L .36812 .45565 L p
1 g
F P
s
P
p
.002 w
.3905 .37025 m .34683 .3928 L .34316 .36349 L p
1 g
F P
s
P
p
.002 w
.34316 .36349 m .39036 .33842 L .3905 .37025 L p
1 g
F P
s
P
p
.002 w
.59749 .31149 m .53233 .28417 L .53909 .2647 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.42079 .55745 m .42204 .56584 L .3924 .56066 L p
1 g
F P
s
P
p
.002 w
.3924 .56066 m .38965 .54417 L .42079 .55745 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.39422 .52894 m .38965 .54417 L .36228 .52772 L p
1 g
F P
s
P
p
.002 w
.36228 .52772 m .36855 .50526 L .39422 .52894 L p
1 g
F P
s
P
p
.002 w
.59749 .31149 m .64982 .35349 L .64055 .37687 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44467 .58669 m .43467 .58126 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.45579 .58979 m .44467 .58669 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.46689 .59025 m .45579 .58979 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47681 .588 m .4845 .58324 L .51432 .59465 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58068 L p
1 g
F P
s
P
p
.002 w
.52366 .58145 m .51432 .59465 L .48982 .58528 L p
1 g
F P
s
P
p
.52366 .58145 m .48982 .58528 L .50306 .58239 L 1 g
F
P
p
.53128 .57265 m .51094 .58068 L .51387 .58004 L 1 g
F
P
p
.002 w
.52424 .5774 m .52366 .58145 L .51387 .58004 L p
1 g
F P
s
P
p
.51983 .57852 m .51387 .58004 L .5191 .5789 L 1 g
F
P
p
.53128 .57265 m .51387 .58004 L .51983 .57852 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.47681 .588 m .45966 .57177 L p
.47668 .57964 L 1 g
F P
s
P
p
.002 w
.46829 .57463 m .46872 .57265 L p
.45742 .56813 L 1 g
F P
s
P
p
.002 w
.46472 .5725 m .45465 .56703 L .45635 .5675 L p
1 g
F P
s
P
p
.45742 .56813 m .45736 .56811 L .46472 .5725 L 1 g
F
P
p
.45742 .56813 m .46472 .5725 L .46829 .57463 L 1 g
F
P
p
.002 w
.48636 .58051 m .4845 .58324 L .46918 .57492 L p
1 g
F P
s
P
p
.47841 .57792 m .47742 .57765 L .4782 .57791 L 1 g
F
P
p
.48921 .57862 m .47762 .57767 L .47841 .57792 L 1 g
F
P
p
.47762 .57767 m .47742 .57765 L .47841 .57792 L 1 g
F
P
p
.002 w
.46918 .57492 m .4845 .58324 L p
.45966 .57177 L 1 g
F P
s
P
p
.002 w
.48903 .58101 m .48921 .57862 L p
.46947 .57735 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4891 .57647 m .48636 .58051 L p
.46472 .5725 L 1 g
F P
s
P
p
.002 w
.46918 .57492 m .46472 .5725 L p
.48636 .58051 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.42079 .55745 m .42327 .54979 L .45275 .56598 L p
1 g
F P
s
P
p
.002 w
.45275 .56598 m .45465 .56703 L .45327 .56664 L p
1 g
F P
s
P
p
.002 w
.45327 .56664 m .42079 .55745 L p
.45275 .56598 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45069 .56335 L p
1 g
F P
s
P
p
.46872 .57265 m .45069 .56335 L .4507 .56335 L 1 g
F
P
p
.46872 .57265 m .45069 .56335 L .45322 .56532 L 1 g
F
P
p
.002 w
.45395 .56587 m .45465 .56703 L .45042 .56314 L p
1 g
F P
s
P
p
.45398 .5659 m .45322 .56532 L .45394 .56588 L 1 g
F
P
p
.46872 .57265 m .45322 .56532 L .45398 .5659 L 1 g
F
P
p
.46872 .57265 m .45394 .56588 L .45474 .56647 L 1 g
F
P
p
.002 w
.42928 .5437 m .43395 .54172 L p
.43834 .54738 L 1 g
F P
s
P
p
.44086 .55411 m .43834 .54738 L .44966 .56201 L 1 g
F
P
p
.42928 .5437 m .43834 .54738 L .44086 .55411 L 1 g
F
P
p
.002 w
.43834 .54738 m .43925 .54566 L p
.43474 .53674 L 1 g
F P
s
P
p
.002 w
.42928 .5437 m .40584 .5167 L p
.43497 .53758 L 1 g
F P
s
P
p
.002 w
.43589 .54089 m .42928 .5437 L p
.43497 .53758 L 1 g
F P
s
P
p
.43474 .53674 m .43589 .54089 L .43834 .54738 L 1 g
F
P
p
.002 w
.40584 .5167 m .42338 .50892 L .43202 .52697 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.40584 .5167 m .43202 .52697 L .43251 .52873 L 1 g
F
P
p
.43214 .53555 m .43251 .52873 L .43497 .53758 L 1 g
F
P
p
.40584 .5167 m .43251 .52873 L .43214 .53555 L 1 g
F
P
p
.002 w
.43251 .52873 m .43346 .52734 L p
.43317 .51896 L 1 g
F P
s
P
p
.002 w
.43254 .52806 m .42338 .50892 L p
.43308 .52021 L 1 g
F P
s
P
p
.43317 .51896 m .43254 .52806 L .43251 .52873 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42338 .50892 m .43393 .50778 L p
.43382 .50949 L 1 g
F P
s
P
p
.43034 .51702 m .43382 .50949 L .43308 .52021 L 1 g
F
P
p
.42338 .50892 m .43382 .50949 L .43034 .51702 L 1 g
F
P
p
.002 w
.43382 .50949 m .43485 .50826 L p
.43834 .5001 L 1 g
F P
s
P
p
.002 w
.42338 .50892 m .41075 .47517 L p
.4382 .50039 L 1 g
F P
s
P
p
.002 w
.43464 .50771 m .42338 .50892 L p
.4382 .50039 L 1 g
F P
s
P
p
.43834 .5001 m .43464 .50771 L .43382 .50949 L 1 g
F
P
p
.002 w
.41075 .47517 m .44248 .47147 L .44372 .48905 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.41075 .47517 m .44372 .48905 L .4426 .49134 L 1 g
F
P
p
.43565 .49805 m .4426 .49134 L .4382 .50039 L 1 g
F
P
p
.41075 .47517 m .4426 .49134 L .43565 .49805 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43382 .50949 L p
1 g
F P
s
P
p
.002 w
.43382 .50949 m .43287 .51061 L p
.43317 .51896 L 1 g
F P
s
P
p
.43346 .52734 m .43382 .50949 L .43317 .51896 L 1 g
F
P
p
.43382 .50949 m .44496 .5066 L .43308 .52021 L 1 g
F
P
p
.002 w
.43393 .50778 m .43464 .50771 L p
.43382 .50949 L 1 g
F P
s
P
p
.002 w
.44325 .49079 m .4418 .4922 L p
.43485 .50826 L 1 g
F P
s
P
p
.43485 .50826 m .4418 .4922 L .44074 .4945 L 1 g
F
P
p
.002 w
.43464 .50771 m .44496 .5066 L p
.43382 .50949 L 1 g
F P
s
P
p
.002 w
.4418 .4922 m .44166 .49233 L p
.44074 .4945 L 1 g
F P
s
P
p
.002 w
.44332 .49064 m .44339 .4905 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.4426 .49134 m .44339 .4905 L p
.44975 .4844 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.45054 .48364 m .4681 .51011 L .4438 .49018 L 1 g
F
P
p
.002 w
.47665 .47652 m .4681 .51011 L p
.45054 .48364 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45769 .47671 m .47665 .47652 L .45054 .48364 L 1 g
F
P
p
.002 w
.45769 .47671 m .45826 .47608 L p
.46784 .47188 L 1 g
F P
s
P
p
.002 w
.47665 .47652 m .46253 .47444 L p
.47135 .47018 L 1 g
F P
s
P
p
.46784 .47188 m .47039 .47076 L .46253 .47444 L 1 g
F
P
p
.46784 .47188 m .46253 .47444 L .45769 .47671 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.44177 .43475 m .48603 .44112 L .47935 .46633 L p
1 g
F P
s
P
p
.47135 .47018 m .47754 .4672 L .47665 .47652 L 1 g
F
P
p
.002 w
.47917 .46699 m .47665 .47652 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.50908 .48981 m .47665 .47652 L .47917 .46699 L p
1 g
F P
s
P
p
.49695 .4642 m .50908 .48981 L .47917 .46699 L 1 g
F
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.49667 .46476 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.48603 .44112 m .52799 .45838 L .52737 .45942 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54218 .47656 L p
1 g
F P
s
P
p
.52214 .46667 m .54218 .47656 L .53115 .47134 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56578 .50901 L p
1 g
F P
s
P
p
.55661 .4905 m .56578 .50901 L .56095 .49881 L 1 g
F
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56236 .48429 m .56369 .4861 L p
.56099 .49889 L 1 g
F P
s
P
p
.56236 .48429 m .56099 .49889 L .56012 .49705 L 1 g
F
P
p
.002 w
.56369 .4861 m .58505 .51541 L .56731 .52568 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56739 .52858 L p
1 g
F P
s
P
p
.58505 .51541 m .56787 .54616 L .56739 .52858 L 1 g
F
P
p
.002 w
.56731 .52568 m .56853 .52497 L p
.56739 .52858 L 1 g
F P
s
P
p
.002 w
.56853 .52497 m .58505 .51541 L p
.56739 .52858 L 1 g
F P
s
P
p
.002 w
.56739 .52858 m .56654 .52734 L p
.56483 .53667 L 1 g
F P
s
P
p
.56515 .50826 m .56739 .52858 L .56734 .52664 L 1 g
F
P
p
.56515 .50826 m .5676 .52889 L .56654 .51728 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56153 .54714 L p
1 g
F P
s
P
p
.56572 .53385 m .56382 .5437 L .56291 .54279 L 1 g
F
P
p
.002 w
.56093 .55858 m .55881 .55124 L p
.56382 .5437 L 1 g
F P
s
P
p
.56654 .52734 m .56153 .54714 L .56483 .53667 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.56093 .55858 m .54348 .56929 L .54919 .56304 L 1 g
F
P
p
.002 w
.55157 .56043 m .55383 .55999 L p
.54919 .56304 L 1 g
F P
s
P
p
.002 w
.55383 .55999 m .56093 .55858 L p
.54919 .56304 L 1 g
F P
s
P
p
.002 w
.54919 .56304 m .54854 .56129 L p
.54117 .56832 L 1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .55157 .56043 L 1 g
F
P
p
.002 w
.55881 .55124 m .56093 .55858 L .55157 .56043 L p
1 g
F P
s
P
p
.55424 .55704 m .55157 .56043 L .55352 .5583 L 1 g
F
P
p
.56075 .54566 m .55157 .56043 L .55424 .55704 L 1 g
F
P
p
.56075 .54566 m .54983 .56476 L .55211 .56133 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55369 .53355 m .55881 .55124 L p
.52593 .56551 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55157 .56043 m .52593 .56551 L p
.55881 .55124 L 1 g
F P
s
P
p
.54348 .56929 m .54024 .57127 L .55157 .56043 L 1 g
F
P
p
.54024 .57127 m .52366 .58145 L .534 .57367 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57455 L p
1 g
F P
s
P
p
.54024 .57127 m .534 .57367 L .54066 .56865 L 1 g
F
P
p
.54024 .57127 m .54066 .56865 L .5481 .56376 L 1 g
F
P
p
.54854 .56129 m .53169 .57455 L .54117 .56832 L 1 g
F
P
p
.53128 .57265 m .5191 .5789 L .52197 .57827 L 1 g
F
P
p
.002 w
.53169 .57455 m .53128 .57265 L p
.52197 .57827 L 1 g
F P
s
P
p
.002 w
.52593 .56551 m .55157 .56043 L p
.534 .57367 L 1 g
F P
s
P
p
.002 w
.52366 .58145 m .52424 .5774 L p
.534 .57367 L 1 g
F P
s
P
p
.002 w
.52424 .5774 m .52593 .56551 L p
.534 .57367 L 1 g
F P
s
P
p
.52366 .58145 m .50306 .58239 L .51094 .58068 L 1 g
F
P
p
.002 w
.51387 .58004 m .51759 .58057 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.51759 .58057 m .52366 .58145 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51079 .57862 L p
.49965 .58085 L 1 g
F P
s
P
p
.50306 .58239 m .4845 .58324 L .50756 .58073 L 1 g
F
P
p
.51094 .58068 m .50756 .58073 L .51387 .58004 L 1 g
F
P
p
.50306 .58239 m .50756 .58073 L .51094 .58068 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58101 L p
1 g
F P
s
P
p
.51079 .57862 m .48903 .58101 L .49965 .58085 L 1 g
F
P
p
.002 w
.4891 .57647 m .51387 .58004 L p
.49491 .58211 L 1 g
F P
s
P
p
.002 w
.4845 .58324 m .48636 .58051 L p
.49491 .58211 L 1 g
F P
s
P
p
.002 w
.48636 .58051 m .4891 .57647 L p
.49491 .58211 L 1 g
F P
s
P
p
.002 w
.48903 .58101 m .48889 .583 L p
.49965 .58085 L 1 g
F P
s
P
p
.002 w
.48982 .58528 m .4845 .58324 L p
.50306 .58239 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58068 L p
1 g
F P
s
P
p
.49965 .58085 m .48889 .583 L .51094 .58068 L 1 g
F
P
p
.52197 .57827 m .51111 .583 L .53203 .57608 L 1 g
F
P
p
.5191 .5789 m .51547 .58076 L .52197 .57827 L 1 g
F
P
p
.51547 .58076 m .51111 .583 L .52197 .57827 L 1 g
F
P
p
.002 w
.56093 .55858 m .5571 .58187 L .52366 .58145 L p
1 g
F P
s
P
p
.002 w
.53169 .57455 m .5322 .57686 L p
.54117 .56832 L 1 g
F P
s
P
p
.5481 .56376 m .54066 .56865 L .55157 .56043 L 1 g
F
P
p
.002 w
.53203 .57608 m .53169 .57455 L p
.52197 .57827 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54919 .56304 L p
1 g
F P
s
P
p
.54117 .56832 m .5322 .57686 L .54919 .56304 L 1 g
F
P
p
.002 w
.54919 .56304 m .54983 .56476 L p
.55352 .5583 L 1 g
F P
s
P
p
.002 w
.55881 .55124 m .55369 .53355 L p
.56382 .5437 L 1 g
F P
s
P
p
.002 w
.56153 .54714 m .56257 .5491 L p
.56483 .53667 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55369 .53355 m .56731 .52568 L p
.56572 .53385 L 1 g
F P
s
P
p
.56572 .53385 m .56291 .54279 L .55369 .53355 L 1 g
F
P
p
.002 w
.54983 .56476 m .54998 .56518 L p
.55211 .56133 L 1 g
F P
s
P
p
.56787 .54616 m .56093 .55858 L .56731 .52568 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56739 .52858 L p
1 g
F P
s
P
p
.56483 .53667 m .56257 .5491 L .56739 .52858 L 1 g
F
P
p
.002 w
.56739 .52858 m .5676 .52889 L p
.56734 .52664 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56731 .52568 m .55369 .53355 L p
.56369 .4861 L 1 g
F P
s
P
p
.56058 .49441 m .56012 .49705 L .55743 .49138 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55743 .49138 L p
1 g
F P
s
P
p
.002 w
.55743 .49138 m .55661 .4905 L p
.56095 .49881 L 1 g
F P
s
P
p
.56095 .49881 m .56713 .51061 L .55743 .49138 L 1 g
F
P
p
.56012 .49705 m .56099 .49889 L .55369 .53355 L 1 g
F
P
p
.002 w
.5676 .52889 m .56854 .53025 L p
.56654 .51728 L 1 g
F P
s
P
p
.002 w
.56578 .50901 m .56713 .51061 L p
.56095 .49881 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.55743 .49138 m .55369 .53355 L .55619 .49018 L 1 g
F
P
p
.56012 .49705 m .55369 .53355 L .55743 .49138 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55743 .49138 L p
1 g
F P
s
P
p
.002 w
.55743 .49138 m .55754 .49149 L p
.55661 .49058 L 1 g
F P
s
P
p
.54174 .47608 m .55743 .49138 L .55661 .49058 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55369 .53355 m .5358 .50965 L .55619 .49018 L p
1 g
F P
s
P
p
.54174 .47608 m .55754 .49149 L .54892 .48311 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55619 .49018 m .56236 .48429 L p
.56058 .49441 L 1 g
F P
s
P
p
.002 w
.52799 .45838 m .56236 .48429 L .55619 .49018 L p
1 g
F P
s
P
p
.002 w
.55619 .49018 m .5358 .50965 L p
.52987 .47073 L 1 g
F P
s
P
p
.54218 .47656 m .55619 .49018 L .52987 .47073 L 1 g
F
P
p
.002 w
.5358 .50965 m .50908 .48981 L .52263 .4673 L p
1 g
F P
s
P
p
.52987 .47073 m .5358 .50965 L .52263 .4673 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.5 .46372 m .51144 .4655 L .50908 .48981 L 1 g
F
P
p
.5 .4634 m .52247 .46722 L .50872 .46508 L 1 g
F
P
p
.002 w
.52263 .4673 m .50908 .48981 L p
.51144 .4655 L 1 g
F P
s
P
p
.51179 .46187 m .52247 .46722 L .51144 .4655 L 1 g
F
P
p
.52247 .46722 m .52263 .4673 L .51144 .4655 L 1 g
F
P
p
.49695 .4642 m .5 .46372 L .50908 .48981 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46372 L p
1 g
F P
s
P
p
.002 w
.5 .46372 m .5 .4634 L p
.50872 .46508 L 1 g
F P
s
P
p
.50872 .46508 m .52282 .46778 L .5 .46372 L 1 g
F
P
p
.002 w
.52247 .46722 m .52282 .46778 L p
.50872 .46508 L 1 g
F P
s
P
p
.5 .46372 m .51179 .46187 L .51144 .4655 L 1 g
F
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.53115 .47134 L 1 g
F P
s
P
p
.002 w
.52737 .45942 m .52263 .4673 L p
.51179 .46187 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .52247 .46722 L p
.52443 .4682 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .54116 .47658 L p
.52443 .4682 L 1 g
F P
s
P
p
.002 w
.54116 .47658 m .52282 .46778 L p
.52443 .4682 L 1 g
F P
s
P
p
.53115 .47134 m .54302 .47747 L .52247 .46722 L 1 g
F
P
p
.52878 .46353 m .54218 .47656 L .52987 .47073 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.52799 .45838 m .55619 .49018 L .52878 .46353 L 1 g
F
P
p
.002 w
.55754 .49149 m .55834 .49233 L p
.54892 .48311 L 1 g
F P
s
P
p
.002 w
.54218 .47656 m .54302 .47747 L p
.53115 .47134 L 1 g
F P
s
P
p
.002 w
.52263 .4673 m .52799 .45838 L p
.52987 .47073 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46372 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46372 L .48815 .46558 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.48603 .44112 m .52737 .45942 L .49695 .4642 L 1 g
F
P
p
.002 w
.5 .46372 m .5 .46433 L p
.48815 .46558 L 1 g
F P
s
P
p
.002 w
.5 .46433 m .5 .46442 L p
.49667 .46476 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46433 L .49667 .46476 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.44177 .43475 m .47935 .46633 L .47754 .4672 L 1 g
F
P
p
.45826 .47608 m .47754 .4672 L .47097 .47037 L 1 g
F
P
p
.4697 .46821 m .47754 .4672 L .47135 .47018 L 1 g
F
P
p
.44177 .43475 m .47754 .4672 L .4697 .46821 L 1 g
F
P
p
.002 w
.47917 .46699 m .48603 .44112 L p
.49695 .4642 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47751 .46726 L p
1 g
F P
s
P
p
.002 w
.47751 .46726 m .47754 .4672 L p
.47898 .46702 L 1 g
F P
s
P
p
.47898 .46702 m .5 .46442 L .47751 .46726 L 1 g
F
P
p
.49667 .46476 m .5 .46442 L .47754 .4672 L 1 g
F
P
p
.002 w
.47935 .46633 m .47917 .46699 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47736 .4675 L p
.47097 .47037 L 1 g
F P
s
P
p
.002 w
.47736 .4675 m .47718 .46778 L p
.47039 .47076 L 1 g
F P
s
P
p
.45826 .47608 m .47736 .4675 L .47039 .47076 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45769 .47671 L p
1 g
F P
s
P
p
.002 w
.45769 .47671 m .45698 .47747 L p
.44975 .4844 L 1 g
F P
s
P
p
.44339 .4905 m .45769 .47671 L .44975 .4844 L 1 g
F
P
p
.002 w
.44248 .47147 m .46036 .47411 L p
.45769 .47671 L 1 g
F P
s
P
p
.44873 .4809 m .45769 .47671 L .45054 .48364 L 1 g
F
P
p
.44248 .47147 m .45769 .47671 L .44873 .4809 L 1 g
F
P
p
.002 w
.44248 .47147 m .44177 .43475 L p
.47135 .47018 L 1 g
F P
s
P
p
.002 w
.46253 .47444 m .44248 .47147 L p
.47135 .47018 L 1 g
F P
s
P
p
.002 w
.46036 .47411 m .46253 .47444 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.46253 .47444 m .47665 .47652 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .47671 L p
1 g
F P
s
P
p
.47039 .47076 m .47718 .46778 L .45769 .47671 L 1 g
F
P
p
.002 w
.4681 .51011 m .44496 .5066 L .4438 .49018 L p
1 g
F P
s
P
p
.4382 .50039 m .4426 .49134 L .44496 .5066 L 1 g
F
P
p
.002 w
.44372 .48905 m .4438 .49018 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.4438 .49018 m .44496 .5066 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44255 .49139 L p
1 g
F P
s
P
p
.002 w
.44255 .49139 m .4426 .49134 L p
.44337 .4906 L 1 g
F P
s
P
p
.44337 .4906 m .45698 .47747 L .44255 .49139 L 1 g
F
P
p
.44975 .4844 m .45284 .48144 L .4438 .49018 L 1 g
F
P
p
.44975 .4844 m .4438 .49018 L .4426 .49134 L 1 g
F
P
p
.002 w
.4438 .49018 m .44248 .47147 L p
.45054 .48364 L 1 g
F P
s
P
p
.45284 .48144 m .45698 .47747 L .4426 .49134 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43371 .50961 L p
1 g
F P
s
P
p
.002 w
.43371 .50961 m .43382 .50949 L p
.43451 .50797 L 1 g
F P
s
P
p
.43451 .50797 m .44166 .49233 L .43371 .50961 L 1 g
F
P
p
.43834 .5001 m .44074 .4945 L .43464 .50771 L 1 g
F
P
p
.002 w
.44496 .5066 m .43464 .50771 L p
.4382 .50039 L 1 g
F P
s
P
p
.44074 .4945 m .44166 .49233 L .43382 .50949 L 1 g
F
P
p
.002 w
.44496 .5066 m .44908 .53882 L p
.43308 .52021 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52873 L p
1 g
F P
s
P
p
.002 w
.43251 .52873 m .43146 .53025 L p
.43474 .53674 L 1 g
F P
s
P
p
.43925 .54566 m .43251 .52873 L .43474 .53674 L 1 g
F
P
p
.43497 .53758 m .43251 .52873 L .43821 .5399 L 1 g
F
P
p
.002 w
.43202 .52697 m .43254 .52806 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43254 .52806 m .43821 .5399 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52874 L p
1 g
F P
s
P
p
.002 w
.4325 .52874 m .43251 .52873 L p
.43251 .52852 L 1 g
F P
s
P
p
.43251 .52852 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.43317 .51896 m .43312 .51745 L .43254 .52806 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44908 .53882 m .43821 .5399 L .43254 .52806 L p
1 g
F P
s
P
p
.43308 .52021 m .44908 .53882 L .43254 .52806 L 1 g
F
P
p
.43312 .51745 m .43287 .51061 L .43251 .52873 L 1 g
F
P
p
.002 w
.45069 .56335 m .45146 .56129 L p
.44425 .55502 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.43834 .54738 m .43821 .5399 L .44966 .56201 L 1 g
F
P
p
.002 w
.43395 .54172 m .43589 .54089 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.43589 .54089 m .43821 .5399 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43792 .54817 L p
1 g
F P
s
P
p
.002 w
.43792 .54817 m .43834 .54738 L p
.43627 .54223 L 1 g
F P
s
P
p
.43627 .54223 m .43146 .53025 L .43792 .54817 L 1 g
F
P
p
.43474 .53674 m .43316 .53362 L .43589 .54089 L 1 g
F
P
p
.002 w
.43821 .5399 m .43589 .54089 L p
.43497 .53758 L 1 g
F P
s
P
p
.43316 .53362 m .43146 .53025 L .43834 .54738 L 1 g
F
P
p
.002 w
.45042 .56314 m .42928 .5437 L p
.45395 .56587 L 1 g
F P
s
P
p
.002 w
.45069 .56335 m .45069 .56335 L p
.44409 .55488 L 1 g
F P
s
P
p
.44425 .55502 m .44409 .55488 L .45069 .56335 L 1 g
F
P
p
.002 w
.43821 .5399 m .45395 .56587 L p
.44966 .56201 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43821 .5399 m .44908 .53882 L .45451 .56629 L p
1 g
F P
s
P
p
.002 w
.45451 .56629 m .45465 .56703 L .45395 .56587 L p
1 g
F P
s
P
p
.002 w
.45395 .56587 m .43821 .5399 L p
.45451 .56629 L 1 g
F P
s
P
p
.46872 .57265 m .45474 .56647 L .45488 .56657 L 1 g
F
P
p
.46872 .57265 m .45477 .56652 L .45494 .56663 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46069 .54062 m .47171 .5451 L .45497 .56663 L p
1 g
F P
s
P
p
.002 w
.45497 .56663 m .45465 .56703 L .45478 .56649 L p
1 g
F P
s
P
p
.002 w
.45478 .56649 m .46069 .54062 L p
.45497 .56663 L 1 g
F P
s
P
p
.45488 .56657 m .45471 .56645 L .45487 .56656 L 1 g
F
P
p
.45474 .56647 m .45471 .56645 L .45488 .56657 L 1 g
F
P
p
.45487 .56656 m .45465 .56643 L .45484 .56655 L 1 g
F
P
p
.002 w
.45478 .56649 m .45465 .56703 L .45451 .56629 L p
1 g
F P
s
P
p
.45471 .56645 m .45465 .56643 L .45487 .56656 L 1 g
F
P
p
.46872 .57265 m .45487 .56659 L .45736 .56811 L 1 g
F
P
p
.002 w
.47171 .5451 m .48091 .55175 L .45514 .56675 L p
1 g
F P
s
P
p
.002 w
.45514 .56675 m .45465 .56703 L .45497 .56663 L p
1 g
F P
s
P
p
.002 w
.45497 .56663 m .47171 .5451 L p
.45514 .56675 L 1 g
F P
s
P
p
.002 w
.44908 .53882 m .46069 .54062 L .45478 .56649 L p
1 g
F P
s
P
p
.002 w
.45451 .56629 m .44908 .53882 L p
.45478 .56649 L 1 g
F P
s
P
p
.45474 .56647 m .45394 .56588 L .45465 .56643 L 1 g
F
P
p
.45484 .56655 m .45465 .56643 L .45477 .56652 L 1 g
F
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48091 .55175 m .48726 .55981 L .45534 .56688 L p
1 g
F P
s
P
p
.002 w
.45534 .56688 m .45465 .56703 L .45514 .56675 L p
1 g
F P
s
P
p
.002 w
.45514 .56675 m .48091 .55175 L p
.45534 .56688 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48726 .55981 m .49007 .56836 L .45565 .56707 L p
1 g
F P
s
P
p
.002 w
.45565 .56707 m .45465 .56703 L .45534 .56688 L p
1 g
F P
s
P
p
.002 w
.45534 .56688 m .48726 .55981 L p
.45565 .56707 L 1 g
F P
s
P
p
.45494 .56663 m .45477 .56652 L .45487 .56659 L 1 g
F
P
p
.45736 .56811 m .45487 .56659 L .45625 .56767 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49007 .56836 m .4891 .57647 L .45635 .5675 L p
1 g
F P
s
P
p
.002 w
.45635 .5675 m .45465 .56703 L .45565 .56707 L p
1 g
F P
s
P
p
.002 w
.45565 .56707 m .49007 .56836 L p
.45635 .5675 L 1 g
F P
s
P
p
.002 w
.45069 .56335 m .45069 .56335 L p
.4507 .56335 L 1 g
F P
s
P
p
.002 w
.42327 .54979 m .4276 .54541 L p
.4508 .56349 L 1 g
F P
s
P
p
.002 w
.45042 .56314 m .4508 .56349 L p
.4276 .54541 L 1 g
F P
s
P
p
.002 w
.4508 .56349 m .45465 .56703 L .45275 .56598 L p
1 g
F P
s
P
p
.002 w
.45275 .56598 m .42327 .54979 L p
.4508 .56349 L 1 g
F P
s
P
p
.002 w
.45069 .56335 m .45002 .56518 L p
.45625 .56767 L 1 g
F P
s
P
p
.002 w
.4276 .54541 m .42928 .5437 L .45042 .56314 L p
1 g
F P
s
P
p
.002 w
.45068 .56339 m .45069 .56335 L p
.44353 .5544 L 1 g
F P
s
P
p
.44409 .55488 m .44353 .5544 L .45069 .56335 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45068 .56339 L p
1 g
F P
s
P
p
.44353 .5544 m .43743 .5491 L .45068 .56339 L 1 g
F
P
p
.002 w
.45635 .5675 m .4891 .57647 L p
.46472 .5725 L 1 g
F P
s
P
p
.002 w
.45966 .57177 m .45465 .56703 L .46918 .57492 L p
1 g
F P
s
P
p
.002 w
.43467 .58126 m .42685 .57406 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.47681 .588 m .46689 .59025 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.42685 .57406 m .42204 .56584 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.42204 .56584 m .42079 .55745 L .45465 .56703 L closepath p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57463 L p
1 g
F P
s
P
p
.45736 .56811 m .45002 .56518 L .46829 .57463 L 1 g
F
P
p
.002 w
.4845 .58324 m .48363 .58378 L p
.47668 .57964 L 1 g
F P
s
P
p
.002 w
.48363 .58378 m .47681 .588 L p
.47668 .57964 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .46947 .57735 L p
.4782 .57791 L 1 g
F P
s
P
p
.47742 .57765 m .4678 .57686 L .4782 .57791 L 1 g
F
P
p
.002 w
.46947 .57735 m .48889 .583 L .48903 .58101 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53203 .57608 L p
1 g
F P
s
P
p
.002 w
.52593 .56551 m .52424 .5774 L p
.4891 .57647 L 1 g
F P
s
P
p
.002 w
.51387 .58004 m .4891 .57647 L p
.52424 .5774 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51111 .583 L p
.5191 .5789 L 1 g
F P
s
P
p
.002 w
.51432 .59465 m .52366 .58145 L .5571 .58187 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.5571 .58187 m .56093 .55858 L .5938 .54784 L p
1 g
F P
s
P
p
.002 w
.6136 .49482 m .62341 .53376 L .5938 .54784 L p
1 g
F P
s
P
p
.002 w
.62341 .53376 m .6136 .49482 L .63834 .47255 L p
1 g
F P
s
P
p
.002 w
.45027 .32921 m .39036 .33842 L .3935 .31007 L p
1 g
F P
s
P
p
.002 w
.3935 .31007 m .45619 .29997 L .45027 .32921 L p
1 g
F P
s
P
p
.002 w
.3852 .48698 m .36855 .50526 L .3471 .47964 L p
1 g
F P
s
P
p
.002 w
.3471 .47964 m .36812 .45565 L .3852 .48698 L p
1 g
F P
s
P
p
.002 w
.62672 .40256 m .65845 .44945 L .63834 .47255 L p
1 g
F P
s
P
p
.002 w
.65845 .44945 m .62672 .40256 L .64055 .37687 L p
1 g
F P
s
P
p
.002 w
.52436 .30878 m .45619 .29997 L .46326 .27543 L p
1 g
F P
s
P
p
.002 w
.46326 .27543 m .53233 .28417 L .52436 .30878 L p
1 g
F P
s
P
p
.002 w
.42327 .54979 m .42079 .55745 L .38965 .54417 L p
1 g
F P
s
P
p
.002 w
.38965 .54417 m .39422 .52894 L .42327 .54979 L p
1 g
F P
s
P
p
.002 w
.39401 .4045 m .3552 .42387 L .34683 .3928 L p
1 g
F P
s
P
p
.002 w
.34683 .3928 m .3905 .37025 L .39401 .4045 L p
1 g
F P
s
P
p
.002 w
.64055 .37687 m .58873 .33569 L .59749 .31149 L p
1 g
F P
s
P
p
.002 w
.53233 .28417 m .59749 .31149 L .58873 .33569 L p
1 g
F P
s
P
p
.002 w
.40584 .5167 m .39422 .52894 L .36855 .50526 L p
1 g
F P
s
P
p
.002 w
.36855 .50526 m .3852 .48698 L .40584 .5167 L p
1 g
F P
s
P
p
.002 w
.58873 .33569 m .64055 .37687 L .62672 .40256 L p
1 g
F P
s
P
p
.002 w
.58505 .51541 m .5938 .54784 L .56093 .55858 L p
1 g
F P
s
P
p
.002 w
.5938 .54784 m .58505 .51541 L .6136 .49482 L p
1 g
F P
s
P
p
.002 w
.58873 .33569 m .52436 .30878 L .53233 .28417 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.4891 .57647 m .49007 .56836 L .52593 .56551 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40084 .43992 m .36812 .45565 L .3552 .42387 L p
1 g
F P
s
P
p
.002 w
.3552 .42387 m .39401 .4045 L .40084 .43992 L p
1 g
F P
s
P
p
.002 w
.60867 .42969 m .63834 .47255 L .6136 .49482 L p
1 g
F P
s
P
p
.002 w
.63834 .47255 m .60867 .42969 L .62672 .40256 L p
1 g
F P
s
P
p
.002 w
.42928 .5437 m .42327 .54979 L .39422 .52894 L p
1 g
F P
s
P
p
.002 w
.39422 .52894 m .40584 .5167 L .42928 .5437 L p
1 g
F P
s
P
p
.002 w
.44576 .36223 m .3905 .37025 L .39036 .33842 L p
1 g
F P
s
P
p
.002 w
.39036 .33842 m .45027 .32921 L .44576 .36223 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49007 .56836 m .48726 .55981 L .52068 .54853 L p
1 g
F P
s
P
p
.002 w
.52068 .54853 m .52593 .56551 L .49007 .56836 L p
1 g
F P
s
P
p
.002 w
.51541 .33784 m .45027 .32921 L .45619 .29997 L p
1 g
F P
s
P
p
.002 w
.45619 .29997 m .52436 .30878 L .51541 .33784 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52593 .56551 m .52068 .54853 L .55369 .53355 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.41075 .47517 m .3852 .48698 L .36812 .45565 L p
1 g
F P
s
P
p
.002 w
.36812 .45565 m .40084 .43992 L .41075 .47517 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.58696 .45728 m .6136 .49482 L .58505 .51541 L p
1 g
F P
s
P
p
.002 w
.6136 .49482 m .58696 .45728 L .60867 .42969 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48726 .55981 m .48091 .55175 L .50829 .53242 L p
1 g
F P
s
P
p
.002 w
.50829 .53242 m .52068 .54853 L .48726 .55981 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.62672 .40256 m .577 .36349 L .58873 .33569 L p
1 g
F P
s
P
p
.002 w
.52436 .30878 m .58873 .33569 L .577 .36349 L p
1 g
F P
s
P
p
.002 w
.577 .36349 m .62672 .40256 L .60867 .42969 L p
1 g
F P
s
P
p
.002 w
.42338 .50892 m .40584 .5167 L .3852 .48698 L p
1 g
F P
s
P
p
.002 w
.3852 .48698 m .41075 .47517 L .42338 .50892 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.44289 .39786 m .39401 .4045 L .3905 .37025 L p
1 g
F P
s
P
p
.002 w
.3905 .37025 m .44576 .36223 L .44289 .39786 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.577 .36349 m .51541 .33784 L .52436 .30878 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48091 .55175 m .47171 .5451 L .49007 .51907 L p
1 g
F P
s
P
p
.002 w
.49007 .51907 m .50829 .53242 L .48091 .55175 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58505 .51541 m .56236 .48429 L .58696 .45728 L p
1 g
F P
s
P
p
.002 w
.52068 .54853 m .50829 .53242 L .5358 .50965 L p
1 g
F P
s
P
p
.002 w
.5358 .50965 m .55369 .53355 L .52068 .54853 L p
1 g
F P
s
P
p
.002 w
.46069 .54062 m .44908 .53882 L .44496 .5066 L p
1 g
F P
s
P
p
.002 w
.47171 .5451 m .46069 .54062 L .4681 .51011 L p
1 g
F P
s
P
p
.002 w
.4681 .51011 m .49007 .51907 L .47171 .5451 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44496 .5066 m .4681 .51011 L .46069 .54062 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.5058 .3704 m .44576 .36223 L .45027 .32921 L p
1 g
F P
s
P
p
.002 w
.45027 .32921 m .51541 .33784 L .5058 .3704 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.44177 .43475 m .40084 .43992 L .39401 .4045 L p
1 g
F P
s
P
p
.002 w
.39401 .4045 m .44289 .39786 L .44177 .43475 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.56261 .39397 m .60867 .42969 L .58696 .45728 L p
1 g
F P
s
P
p
.002 w
.60867 .42969 m .56261 .39397 L .577 .36349 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.57093 .4156 L
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50829 .53242 m .49007 .51907 L .50908 .48981 L p
1 g
F P
s
P
p
.002 w
.50908 .48981 m .5358 .50965 L .50829 .53242 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.51541 .33784 m .577 .36349 L .56261 .39397 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44248 .47147 m .41075 .47517 L .40084 .43992 L p
1 g
F P
s
P
p
.002 w
.40084 .43992 m .44177 .43475 L .44248 .47147 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.56261 .39397 m .5058 .3704 L .51541 .33784 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.54607 .42601 m .58696 .45728 L .56236 .48429 L p
1 g
F P
s
P
p
.002 w
.58696 .45728 m .54607 .42601 L .56261 .39397 L p
1 g
F P
s
P
p
.004 w
.57439 .41487 m
.57501 .41474 L
s
P
p
.004 w
.57501 .41474 m
.57837 .41403 L
s
P
p
.004 w
.57955 .41379 m
.62155 .40495 L
s
P
p
.004 w
.57837 .41403 m
.57955 .41379 L
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.49007 .51907 m .4681 .51011 L .47665 .47652 L p
1 g
F P
s
P
p
.002 w
.47665 .47652 m .50908 .48981 L .49007 .51907 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.49587 .40527 m .44289 .39786 L .44576 .36223 L p
1 g
F P
s
P
p
.002 w
.44576 .36223 m .5058 .3704 L .49587 .40527 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.004 w
.42805 .64713 m
.4361 .62289 L
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.004 w
.4361 .62289 m
.43932 .6132 L
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56236 .48429 m .52799 .45838 L .54607 .42601 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5058 .3704 m .56261 .39397 L .54607 .42601 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48603 .44112 m .44177 .43475 L .44289 .39786 L p
1 g
F P
s
P
p
.002 w
.44289 .39786 m .49587 .40527 L .48603 .44112 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54607 .42601 m .49587 .40527 L .5058 .3704 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49587 .40527 m .54607 .42601 L .52799 .45838 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.52799 .45838 m .48603 .44112 L .49587 .40527 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .62155 .40495 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .42805 .64713 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.217054)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.217054)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44416 .42924 m .47576 .45658 L .49128 .43275 L p
1 g
F P
s
P
p
.002 w
.49128 .43275 m .46503 .40992 L .44416 .42924 L p
1 g
F P
s
P
p
.002 w
.52279 .44786 m .49128 .43275 L .47576 .45658 L p
1 g
F P
s
P
p
.002 w
.46503 .40992 m .49128 .43275 L .50699 .4089 L p
1 g
F P
s
P
p
.002 w
.49128 .43275 m .52279 .44786 L .53144 .42059 L p
1 g
F P
s
P
p
.002 w
.53144 .42059 m .50699 .4089 L .49128 .43275 L p
1 g
F P
s
P
p
.002 w
.50699 .4089 m .48668 .39115 L .46503 .40992 L p
1 g
F P
s
P
p
.002 w
.48668 .39115 m .50699 .4089 L .52261 .38547 L p
1 g
F P
s
P
p
.002 w
.50699 .4089 m .53144 .42059 L .53936 .39345 L p
1 g
F P
s
P
p
.002 w
.53936 .39345 m .52261 .38547 L .50699 .4089 L p
1 g
F P
s
P
p
.002 w
.47576 .45658 m .51358 .47476 L .52279 .44786 L p
1 g
F P
s
P
p
.002 w
.55657 .45376 m .52279 .44786 L .51358 .47476 L p
1 g
F P
s
P
p
.002 w
.52279 .44786 m .55657 .45376 L .55763 .42504 L p
1 g
F P
s
P
p
.002 w
.55763 .42504 m .53144 .42059 L .52279 .44786 L p
1 g
F P
s
P
p
.002 w
.53144 .42059 m .55763 .42504 L .55729 .39641 L p
1 g
F P
s
P
p
.002 w
.55729 .39641 m .53936 .39345 L .53144 .42059 L p
1 g
F P
s
P
p
.002 w
.42447 .44876 m .46071 .47996 L .47576 .45658 L p
1 g
F P
s
P
p
.002 w
.47576 .45658 m .44416 .42924 L .42447 .44876 L p
1 g
F P
s
P
p
.002 w
.51358 .47476 m .47576 .45658 L .46071 .47996 L p
1 g
F P
s
P
p
.002 w
.42181 .3952 m .44416 .42924 L .46503 .40992 L p
1 g
F P
s
P
p
.002 w
.46503 .40992 m .4466 .38149 L .42181 .3952 L p
1 g
F P
s
P
p
.002 w
.4466 .38149 m .46503 .40992 L .48668 .39115 L p
1 g
F P
s
P
p
.002 w
.48668 .39115 m .47255 .36905 L .4466 .38149 L p
1 g
F P
s
P
p
.002 w
.47255 .36905 m .48668 .39115 L .50873 .37328 L p
1 g
F P
s
P
p
.002 w
.52261 .38547 m .50873 .37328 L .48668 .39115 L p
1 g
F P
s
P
p
.002 w
.46071 .47996 m .50395 .50081 L .51358 .47476 L p
1 g
F P
s
P
p
.002 w
.55412 .48205 m .51358 .47476 L .50395 .50081 L p
1 g
F P
s
P
p
.002 w
.51358 .47476 m .55412 .48205 L .55657 .45376 L p
1 g
F P
s
P
p
.002 w
.50873 .37328 m .52261 .38547 L .53785 .36287 L p
1 g
F P
s
P
p
.002 w
.52261 .38547 m .53936 .39345 L .5464 .36693 L p
1 g
F P
s
P
p
.002 w
.5464 .36693 m .53785 .36287 L .52261 .38547 L p
1 g
F P
s
P
p
.002 w
.53936 .39345 m .55729 .39641 L .55555 .3684 L p
1 g
F P
s
P
p
.002 w
.55555 .3684 m .5464 .36693 L .53936 .39345 L p
1 g
F P
s
P
p
.002 w
.39865 .40995 m .42447 .44876 L .44416 .42924 L p
1 g
F P
s
P
p
.002 w
.44416 .42924 m .42181 .3952 L .39865 .40995 L p
1 g
F P
s
P
p
.002 w
.58297 .42171 m .55763 .42504 L .55657 .45376 L p
1 g
F P
s
P
p
.002 w
.55763 .42504 m .58297 .42171 L .57457 .39399 L p
1 g
F P
s
P
p
.002 w
.57457 .39399 m .55729 .39641 L .55763 .42504 L p
1 g
F P
s
P
p
.002 w
.50873 .37328 m .49916 .35811 L .47255 .36905 L p
1 g
F P
s
P
p
.002 w
.49916 .35811 m .50873 .37328 L .53078 .35663 L p
1 g
F P
s
P
p
.002 w
.53785 .36287 m .53078 .35663 L .50873 .37328 L p
1 g
F P
s
P
p
.002 w
.58935 .44974 m .55657 .45376 L .55412 .48205 L p
1 g
F P
s
P
p
.002 w
.55657 .45376 m .58935 .44974 L .58297 .42171 L p
1 g
F P
s
P
p
.002 w
.40634 .46812 m .4464 .50245 L .46071 .47996 L p
1 g
F P
s
P
p
.002 w
.46071 .47996 m .42447 .44876 L .40634 .46812 L p
1 g
F P
s
P
p
.002 w
.50395 .50081 m .46071 .47996 L .4464 .50245 L p
1 g
F P
s
P
p
.002 w
.55729 .39641 m .57457 .39399 L .56433 .3671 L p
1 g
F P
s
P
p
.002 w
.56433 .3671 m .55555 .3684 L .55729 .39641 L p
1 g
F P
s
P
p
.002 w
.43798 .35014 m .4466 .38149 L .47255 .36905 L p
1 g
F P
s
P
p
.002 w
.47255 .36905 m .46611 .34475 L .43798 .35014 L p
1 g
F P
s
P
p
.002 w
.46611 .34475 m .47255 .36905 L .49916 .35811 L p
1 g
F P
s
P
p
.002 w
.4464 .50245 m .49409 .52552 L .50395 .50081 L p
1 g
F P
s
P
p
.002 w
.55032 .50937 m .50395 .50081 L .49409 .52552 L p
1 g
F P
s
P
p
.002 w
.50395 .50081 m .55032 .50937 L .55412 .48205 L p
1 g
F P
s
P
p
.002 w
.49916 .35811 m .49493 .34149 L .46611 .34475 L p
1 g
F P
s
P
p
.002 w
.49493 .34149 m .49916 .35811 L .52595 .34887 L p
1 g
F P
s
P
p
.002 w
.53078 .35663 m .52595 .34887 L .49916 .35811 L p
1 g
F P
s
P
p
.002 w
.41109 .35758 m .42181 .3952 L .4466 .38149 L p
1 g
F P
s
P
p
.002 w
.4466 .38149 m .43798 .35014 L .41109 .35758 L p
1 g
F P
s
P
p
.002 w
.59359 .47753 m .55412 .48205 L .55032 .50937 L p
1 g
F P
s
P
p
.002 w
.55412 .48205 m .59359 .47753 L .58935 .44974 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .53078 .35663 L .53785 .36287 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .53785 .36287 L .5464 .36693 L closepath p
1 g
F P
s
P
p
.002 w
.37761 .42546 m .40634 .46812 L .42447 .44876 L p
1 g
F P
s
P
p
.002 w
.42447 .44876 m .39865 .40995 L .37761 .42546 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .5464 .36693 L .55555 .3684 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .52595 .34887 L .53078 .35663 L closepath p
1 g
F P
s
P
p
.002 w
.58939 .38638 m .57457 .39399 L .58297 .42171 L p
1 g
F P
s
P
p
.002 w
.57457 .39399 m .58939 .38638 L .57181 .36315 L p
1 g
F P
s
P
p
.002 w
.57181 .36315 m .56433 .3671 L .57457 .39399 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .55555 .3684 L .56433 .3671 L closepath p
1 g
F P
s
P
p
.002 w
.60484 .41078 m .58297 .42171 L .58935 .44974 L p
1 g
F P
s
P
p
.002 w
.58297 .42171 m .60484 .41078 L .58939 .38638 L p
1 g
F P
s
P
p
.002 w
.52595 .34887 m .52388 .34041 L .49493 .34149 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .52388 .34041 L .52595 .34887 L closepath p
1 g
F P
s
P
p
.002 w
.38599 .36697 m .39865 .40995 L .42181 .3952 L p
1 g
F P
s
P
p
.002 w
.42181 .3952 m .41109 .35758 L .38599 .36697 L p
1 g
F P
s
P
p
.002 w
.46823 .3207 m .46611 .34475 L .49493 .34149 L p
1 g
F P
s
P
p
.002 w
.49493 .34149 m .49657 .32513 L .46823 .3207 L p
1 g
F P
s
P
p
.002 w
.49657 .32513 m .49493 .34149 L .52388 .34041 L p
1 g
F P
s
P
p
.002 w
.39017 .48696 m .43314 .52362 L .4464 .50245 L p
1 g
F P
s
P
p
.002 w
.4464 .50245 m .40634 .46812 L .39017 .48696 L p
1 g
F P
s
P
p
.002 w
.49409 .52552 m .4464 .50245 L .43314 .52362 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .56433 .3671 L .57181 .36315 L closepath p
1 g
F P
s
P
p
.002 w
.61783 .4359 m .58935 .44974 L .59359 .47753 L p
1 g
F P
s
P
p
.002 w
.58935 .44974 m .61783 .4359 L .60484 .41078 L p
1 g
F P
s
P
p
.002 w
.44035 .31896 m .43798 .35014 L .46611 .34475 L p
1 g
F P
s
P
p
.002 w
.46611 .34475 m .46823 .3207 L .44035 .31896 L p
1 g
F P
s
P
p
.002 w
.52388 .34041 m .52481 .33213 L .49657 .32513 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .52481 .33213 L .52388 .34041 L closepath p
1 g
F P
s
P
p
.002 w
.49409 .52552 m .54521 .53519 L .55032 .50937 L p
1 g
F P
s
P
p
.002 w
.59556 .50455 m .55032 .50937 L .54521 .53519 L p
1 g
F P
s
P
p
.002 w
.55032 .50937 m .59556 .50455 L .59359 .47753 L p
1 g
F P
s
P
p
.002 w
.43314 .52362 m .48418 .54836 L .49409 .52552 L p
1 g
F P
s
P
p
.002 w
.54521 .53519 m .49409 .52552 L .48418 .54836 L p
1 g
F P
s
P
p
.002 w
.57716 .35695 m .57181 .36315 L .58939 .38638 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .57181 .36315 L .57716 .35695 L closepath p
1 g
F P
s
P
p
.002 w
.60014 .37426 m .58939 .38638 L .60484 .41078 L p
1 g
F P
s
P
p
.002 w
.58939 .38638 m .60014 .37426 L .57716 .35695 L p
1 g
F P
s
P
p
.002 w
.35918 .44145 m .39017 .48696 L .40634 .46812 L p
1 g
F P
s
P
p
.002 w
.40634 .46812 m .37761 .42546 L .35918 .44145 L p
1 g
F P
s
P
p
.002 w
.50402 .3108 m .49657 .32513 L .52481 .33213 L p
1 g
F P
s
P
p
.002 w
.52481 .33213 m .52868 .32493 L .50402 .3108 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .52868 .32493 L .52481 .33213 L closepath p
1 g
F P
s
P
p
.002 w
.41352 .32 m .41109 .35758 L .43798 .35014 L p
1 g
F P
s
P
p
.002 w
.43798 .35014 m .44035 .31896 L .41352 .32 L p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .56986 .32491 L .56178 .31956 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .56178 .31956 L .5526 .31674 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .5526 .31674 L .54336 .31677 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .54336 .31677 L .53508 .31961 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .53508 .31961 L .52868 .32493 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .57716 .35695 L .5798 .34914 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .5798 .34914 L .57939 .34058 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .57939 .34058 L .57596 .33218 L closepath p
1 g
F P
s
P
p
.002 w
.55242 .34154 m .57596 .33218 L .56986 .32491 L closepath p
1 g
F P
s
P
p
.002 w
.36325 .37815 m .37761 .42546 L .39865 .40995 L p
1 g
F P
s
P
p
.002 w
.39865 .40995 m .38599 .36697 L .36325 .37815 L p
1 g
F P
s
P
p
.002 w
.62805 .46124 m .59359 .47753 L .59556 .50455 L p
1 g
F P
s
P
p
.002 w
.59359 .47753 m .62805 .46124 L .61783 .4359 L p
1 g
F P
s
P
p
.002 w
.47893 .29948 m .46823 .3207 L .49657 .32513 L p
1 g
F P
s
P
p
.002 w
.49657 .32513 m .50402 .3108 L .47893 .29948 L p
1 g
F P
s
P
p
.002 w
.5798 .34914 m .57716 .35695 L .60014 .37426 L p
1 g
F P
s
P
p
.002 w
.62086 .39317 m .60484 .41078 L .61783 .4359 L p
1 g
F P
s
P
p
.002 w
.60484 .41078 m .62086 .39317 L .60014 .37426 L p
1 g
F P
s
P
p
.002 w
.5166 .3001 m .50402 .3108 L .52868 .32493 L p
1 g
F P
s
P
p
.002 w
.52868 .32493 m .53508 .31961 L .5166 .3001 L p
1 g
F P
s
P
p
.002 w
.60014 .37426 m .60554 .35888 L .5798 .34914 L p
1 g
F P
s
P
p
.002 w
.57939 .34058 m .5798 .34914 L .60554 .35888 L p
1 g
F P
s
P
p
.002 w
.48418 .54836 m .53885 .55895 L .54521 .53519 L p
1 g
F P
s
P
p
.002 w
.59516 .53024 m .54521 .53519 L .53885 .55895 L p
1 g
F P
s
P
p
.002 w
.54521 .53519 m .59516 .53024 L .59556 .50455 L p
1 g
F P
s
P
p
.002 w
.4539 .29126 m .44035 .31896 L .46823 .3207 L p
1 g
F P
s
P
p
.002 w
.46823 .3207 m .47893 .29948 L .4539 .29126 L p
1 g
F P
s
P
p
.002 w
.37635 .50486 m .42122 .54298 L .43314 .52362 L p
1 g
F P
s
P
p
.002 w
.43314 .52362 m .39017 .48696 L .37635 .50486 L p
1 g
F P
s
P
p
.002 w
.48418 .54836 m .43314 .52362 L .42122 .54298 L p
1 g
F P
s
P
p
.002 w
.60554 .35888 m .60014 .37426 L .62086 .39317 L p
1 g
F P
s
P
p
.002 w
.38833 .32388 m .38599 .36697 L .41109 .35758 L p
1 g
F P
s
P
p
.002 w
.41109 .35758 m .41352 .32 L .38833 .32388 L p
1 g
F P
s
P
p
.002 w
.53301 .29431 m .5166 .3001 L .53508 .31961 L p
1 g
F P
s
P
p
.002 w
.53508 .31961 m .54336 .31677 L .53301 .29431 L p
1 g
F P
s
P
p
.002 w
.63887 .41333 m .61783 .4359 L .62805 .46124 L p
1 g
F P
s
P
p
.002 w
.61783 .4359 m .63887 .41333 L .62086 .39317 L p
1 g
F P
s
P
p
.002 w
.42122 .54298 m .4744 .56883 L .48418 .54836 L p
1 g
F P
s
P
p
.002 w
.53885 .55895 m .48418 .54836 L .4744 .56883 L p
1 g
F P
s
P
p
.002 w
.49731 .2835 m .47893 .29948 L .50402 .3108 L p
1 g
F P
s
P
p
.002 w
.50402 .3108 m .5166 .3001 L .49731 .2835 L p
1 g
F P
s
P
p
.002 w
.60554 .35888 m .6049 .34185 L .57939 .34058 L p
1 g
F P
s
P
p
.002 w
.57596 .33218 m .57939 .34058 L .6049 .34185 L p
1 g
F P
s
P
p
.002 w
.63522 .48629 m .59556 .50455 L .59516 .53024 L p
1 g
F P
s
P
p
.002 w
.59556 .50455 m .63522 .48629 L .62805 .46124 L p
1 g
F P
s
P
p
.002 w
.55145 .29417 m .53301 .29431 L .54336 .31677 L p
1 g
F P
s
P
p
.002 w
.54336 .31677 m .5526 .31674 L .55145 .29417 L p
1 g
F P
s
P
p
.002 w
.34345 .39097 m .35918 .44145 L .37761 .42546 L p
1 g
F P
s
P
p
.002 w
.37761 .42546 m .36325 .37815 L .34345 .39097 L p
1 g
F P
s
P
p
.002 w
.34385 .45761 m .37635 .50486 L .39017 .48696 L p
1 g
F P
s
P
p
.002 w
.39017 .48696 m .35918 .44145 L .34385 .45761 L p
1 g
F P
s
P
p
.002 w
.6049 .34185 m .59817 .32508 L .57596 .33218 L p
1 g
F P
s
P
p
.002 w
.56986 .32491 m .57596 .33218 L .59817 .32508 L p
1 g
F P
s
P
p
.002 w
.56983 .29976 m .55145 .29417 L .5526 .31674 L p
1 g
F P
s
P
p
.002 w
.5526 .31674 m .56178 .31956 L .56983 .29976 L p
1 g
F P
s
P
p
.002 w
.42949 .28643 m .41352 .32 L .44035 .31896 L p
1 g
F P
s
P
p
.002 w
.44035 .31896 m .4539 .29126 L .42949 .28643 L p
1 g
F P
s
P
p
.002 w
.62909 .3706 m .62086 .39317 L .63887 .41333 L p
1 g
F P
s
P
p
.002 w
.62086 .39317 m .62909 .3706 L .60554 .35888 L p
1 g
F P
s
P
p
.002 w
.56178 .31956 m .56986 .32491 L .58603 .31048 L p
1 g
F P
s
P
p
.002 w
.59817 .32508 m .58603 .31048 L .56986 .32491 L p
1 g
F P
s
P
p
.002 w
.58603 .31048 m .56983 .29976 L .56178 .31956 L p
1 g
F P
s
P
p
.002 w
.6049 .34185 m .60554 .35888 L .62909 .3706 L p
1 g
F P
s
P
p
.002 w
.36538 .33061 m .36325 .37815 L .38599 .36697 L p
1 g
F P
s
P
p
.002 w
.38599 .36697 m .38833 .32388 L .36538 .33061 L p
1 g
F P
s
P
p
.002 w
.52154 .27473 m .49731 .2835 L .5166 .3001 L p
1 g
F P
s
P
p
.002 w
.5166 .3001 m .53301 .29431 L .52154 .27473 L p
1 g
F P
s
P
p
.002 w
.65372 .43433 m .62805 .46124 L .63522 .48629 L p
1 g
F P
s
P
p
.002 w
.62805 .46124 m .65372 .43433 L .63887 .41333 L p
1 g
F P
s
P
p
.002 w
.4776 .27024 m .4539 .29126 L .47893 .29948 L p
1 g
F P
s
P
p
.002 w
.47893 .29948 m .49731 .2835 L .4776 .27024 L p
1 g
F P
s
P
p
.002 w
.4744 .56883 m .53134 .58007 L .53885 .55895 L p
1 g
F P
s
P
p
.002 w
.59233 .55401 m .53885 .55895 L .53134 .58007 L p
1 g
F P
s
P
p
.002 w
.53885 .55895 m .59233 .55401 L .59516 .53024 L p
1 g
F P
s
P
p
.002 w
.36528 .52141 m .41094 .56007 L .42122 .54298 L p
1 g
F P
s
P
p
.002 w
.42122 .54298 m .37635 .50486 L .36528 .52141 L p
1 g
F P
s
P
p
.002 w
.4744 .56883 m .42122 .54298 L .41094 .56007 L p
1 g
F P
s
P
p
.002 w
.62909 .3706 m .62837 .34542 L .6049 .34185 L p
1 g
F P
s
P
p
.002 w
.59817 .32508 m .6049 .34185 L .62837 .34542 L p
1 g
F P
s
P
p
.002 w
.6391 .5105 m .59516 .53024 L .59233 .55401 L p
1 g
F P
s
P
p
.002 w
.59516 .53024 m .6391 .5105 L .63522 .48629 L p
1 g
F P
s
P
p
.002 w
.64989 .38411 m .63887 .41333 L .65372 .43433 L p
1 g
F P
s
P
p
.002 w
.63887 .41333 m .64989 .38411 L .62909 .3706 L p
1 g
F P
s
P
p
.002 w
.54895 .27439 m .52154 .27473 L .53301 .29431 L p
1 g
F P
s
P
p
.002 w
.53301 .29431 m .55145 .29417 L .54895 .27439 L p
1 g
F P
s
P
p
.002 w
.40625 .28521 m .38833 .32388 L .41352 .32 L p
1 g
F P
s
P
p
.002 w
.41352 .32 m .42949 .28643 L .40625 .28521 L p
1 g
F P
s
P
p
.002 w
.41094 .56007 m .46498 .58639 L .4744 .56883 L p
1 g
F P
s
P
p
.002 w
.53134 .58007 m .4744 .56883 L .46498 .58639 L p
1 g
F P
s
P
p
.002 w
.32713 .4052 m .34385 .45761 L .35918 .44145 L p
1 g
F P
s
P
p
.002 w
.35918 .44145 m .34345 .39097 L .32713 .4052 L p
1 g
F P
s
P
p
.002 w
.62837 .34542 m .62909 .3706 L .64989 .38411 L p
1 g
F P
s
P
p
.002 w
.62837 .34542 m .61852 .32046 L .59817 .32508 L p
1 g
F P
s
P
p
.002 w
.58603 .31048 m .59817 .32508 L .61852 .32046 L p
1 g
F P
s
P
p
.002 w
.33209 .47357 m .36528 .52141 L .37635 .50486 L p
1 g
F P
s
P
p
.002 w
.37635 .50486 m .34385 .45761 L .33209 .47357 L p
1 g
F P
s
P
p
.002 w
.57636 .28268 m .54895 .27439 L .55145 .29417 L p
1 g
F P
s
P
p
.002 w
.55145 .29417 m .56983 .29976 L .57636 .28268 L p
1 g
F P
s
P
p
.002 w
.66497 .45576 m .63522 .48629 L .6391 .5105 L p
1 g
F P
s
P
p
.002 w
.63522 .48629 m .66497 .45576 L .65372 .43433 L p
1 g
F P
s
P
p
.002 w
.34529 .34016 m .34345 .39097 L .36325 .37815 L p
1 g
F P
s
P
p
.002 w
.36325 .37815 m .36538 .33061 L .34529 .34016 L p
1 g
F P
s
P
p
.002 w
.4579 .26078 m .42949 .28643 L .4539 .29126 L p
1 g
F P
s
P
p
.002 w
.4539 .29126 m .4776 .27024 L .4579 .26078 L p
1 g
F P
s
P
p
.002 w
.50915 .25859 m .4776 .27024 L .49731 .2835 L p
1 g
F P
s
P
p
.002 w
.49731 .2835 m .52154 .27473 L .50915 .25859 L p
1 g
F P
s
P
p
.002 w
.61852 .32046 m .6005 .29867 L .58603 .31048 L p
1 g
F P
s
P
p
.002 w
.56983 .29976 m .58603 .31048 L .6005 .29867 L p
1 g
F P
s
P
p
.002 w
.6005 .29867 m .57636 .28268 L .56983 .29976 L p
1 g
F P
s
P
p
.002 w
.46498 .58639 m .52277 .598 L .53134 .58007 L p
1 g
F P
s
P
p
.002 w
.58703 .57527 m .53134 .58007 L .52277 .598 L p
1 g
F P
s
P
p
.002 w
.53134 .58007 m .58703 .57527 L .59233 .55401 L p
1 g
F P
s
P
p
.002 w
.66736 .3992 m .65372 .43433 L .66497 .45576 L p
1 g
F P
s
P
p
.002 w
.65372 .43433 m .66736 .3992 L .64989 .38411 L p
1 g
F P
s
P
p
.002 w
.64989 .38411 m .64921 .35129 L .62837 .34542 L p
1 g
F P
s
P
p
.002 w
.61852 .32046 m .62837 .34542 L .64921 .35129 L p
1 g
F P
s
P
p
.002 w
.63947 .5333 m .59233 .55401 L .58703 .57527 L p
1 g
F P
s
P
p
.002 w
.59233 .55401 m .63947 .5333 L .6391 .5105 L p
1 g
F P
s
P
p
.002 w
.38478 .28779 m .36538 .33061 L .38833 .32388 L p
1 g
F P
s
P
p
.002 w
.38833 .32388 m .40625 .28521 L .38478 .28779 L p
1 g
F P
s
P
p
.002 w
.64921 .35129 m .64989 .38411 L .66736 .3992 L p
1 g
F P
s
P
p
.002 w
.35733 .53616 m .40262 .5744 L .41094 .56007 L p
1 g
F P
s
P
p
.002 w
.41094 .56007 m .36528 .52141 L .35733 .53616 L p
1 g
F P
s
P
p
.002 w
.46498 .58639 m .41094 .56007 L .40262 .5744 L p
1 g
F P
s
P
p
.002 w
.54507 .25801 m .50915 .25859 L .52154 .27473 L p
1 g
F P
s
P
p
.002 w
.52154 .27473 m .54895 .27439 L .54507 .25801 L p
1 g
F P
s
P
p
.002 w
.31486 .42057 m .33209 .47357 L .34385 .45761 L p
1 g
F P
s
P
p
.002 w
.34385 .45761 m .32713 .4052 L .31486 .42057 L p
1 g
F P
s
P
p
.002 w
.40262 .5744 m .45614 .60051 L .46498 .58639 L p
1 g
F P
s
P
p
.002 w
.52277 .598 m .46498 .58639 L .45614 .60051 L p
1 g
F P
s
P
p
.002 w
.43867 .2555 m .40625 .28521 L .42949 .28643 L p
1 g
F P
s
P
p
.002 w
.42949 .28643 m .4579 .26078 L .43867 .2555 L p
1 g
F P
s
P
p
.002 w
.67221 .47713 m .6391 .5105 L .63947 .5333 L p
1 g
F P
s
P
p
.002 w
.6391 .5105 m .67221 .47713 L .66497 .45576 L p
1 g
F P
s
P
p
.002 w
.32868 .35243 m .32713 .4052 L .34345 .39097 L p
1 g
F P
s
P
p
.002 w
.34345 .39097 m .34529 .34016 L .32868 .35243 L p
1 g
F P
s
P
p
.002 w
.64921 .35129 m .63647 .31857 L .61852 .32046 L p
1 g
F P
s
P
p
.002 w
.6005 .29867 m .61852 .32046 L .63647 .31857 L p
1 g
F P
s
P
p
.002 w
.49609 .24643 m .4579 .26078 L .4776 .27024 L p
1 g
F P
s
P
p
.002 w
.4776 .27024 m .50915 .25859 L .49609 .24643 L p
1 g
F P
s
P
p
.002 w
.32435 .48896 m .35733 .53616 L .36528 .52141 L p
1 g
F P
s
P
p
.002 w
.36528 .52141 m .33209 .47357 L .32435 .48896 L p
1 g
F P
s
P
p
.002 w
.58112 .26884 m .54507 .25801 L .54895 .27439 L p
1 g
F P
s
P
p
.002 w
.54895 .27439 m .57636 .28268 L .58112 .26884 L p
1 g
F P
s
P
p
.002 w
.57636 .28268 m .6005 .29867 L .61287 .2899 L p
1 g
F P
s
P
p
.002 w
.63647 .31857 m .61287 .2899 L .6005 .29867 L p
1 g
F P
s
P
p
.002 w
.61287 .2899 m .58112 .26884 L .57636 .28268 L p
1 g
F P
s
P
p
.002 w
.68096 .41557 m .66497 .45576 L .67221 .47713 L p
1 g
F P
s
P
p
.002 w
.66497 .45576 m .68096 .41557 L .66736 .3992 L p
1 g
F P
s
P
p
.002 w
.36569 .29429 m .34529 .34016 L .36538 .33061 L p
1 g
F P
s
P
p
.002 w
.36538 .33061 m .38478 .28779 L .36569 .29429 L p
1 g
F P
s
P
p
.002 w
.52277 .598 m .57927 .59342 L .58703 .57527 L p
1 g
F P
s
P
p
.002 w
.63617 .5541 m .58703 .57527 L .57927 .59342 L p
1 g
F P
s
P
p
.002 w
.58703 .57527 m .63617 .5541 L .63947 .5333 L p
1 g
F P
s
P
p
.002 w
.66736 .3992 m .6668 .35944 L .64921 .35129 L p
1 g
F P
s
P
p
.002 w
.63647 .31857 m .64921 .35129 L .6668 .35944 L p
1 g
F P
s
P
p
.002 w
.45614 .60051 m .5133 .61215 L .52277 .598 L p
1 g
F P
s
P
p
.002 w
.57927 .59342 m .52277 .598 L .5133 .61215 L p
1 g
F P
s
P
p
.002 w
.6668 .35944 m .66736 .3992 L .68096 .41557 L p
1 g
F P
s
P
p
.002 w
.53984 .2456 m .49609 .24643 L .50915 .25859 L p
1 g
F P
s
P
p
.002 w
.50915 .25859 m .54507 .25801 L .53984 .2456 L p
1 g
F P
s
P
p
.002 w
.42042 .25476 m .38478 .28779 L .40625 .28521 L p
1 g
F P
s
P
p
.002 w
.40625 .28521 m .43867 .2555 L .42042 .25476 L p
1 g
F P
s
P
p
.002 w
.6751 .49795 m .63947 .5333 L .63617 .5541 L p
1 g
F P
s
P
p
.002 w
.63947 .5333 m .6751 .49795 L .67221 .47713 L p
1 g
F P
s
P
p
.002 w
.30714 .43675 m .32435 .48896 L .33209 .47357 L p
1 g
F P
s
P
p
.002 w
.33209 .47357 m .31486 .42057 L .30714 .43675 L p
1 g
F P
s
P
p
.002 w
.35289 .54867 m .39656 .58546 L .40262 .5744 L p
1 g
F P
s
P
p
.002 w
.40262 .5744 m .35733 .53616 L .35289 .54867 L p
1 g
F P
s
P
p
.002 w
.45614 .60051 m .40262 .5744 L .39656 .58546 L p
1 g
F P
s
P
p
.002 w
.31615 .36723 m .31486 .42057 L .32713 .4052 L p
1 g
F P
s
P
p
.002 w
.32713 .4052 m .32868 .35243 L .31615 .36723 L p
1 g
F P
s
P
p
.002 w
.48264 .23877 m .43867 .2555 L .4579 .26078 L p
1 g
F P
s
P
p
.002 w
.4579 .26078 m .49609 .24643 L .48264 .23877 L p
1 g
F P
s
P
p
.002 w
.39656 .58546 m .44812 .61065 L .45614 .60051 L p
1 g
F P
s
P
p
.002 w
.5133 .61215 m .45614 .60051 L .44812 .61065 L p
1 g
F P
s
P
p
.002 w
.6668 .35944 m .65146 .31958 L .63647 .31857 L p
1 g
F P
s
P
p
.002 w
.61287 .2899 m .63647 .31857 L .65146 .31958 L p
1 g
F P
s
P
p
.002 w
.32107 .50336 m .35289 .54867 L .35733 .53616 L p
1 g
F P
s
P
p
.002 w
.35733 .53616 m .32435 .48896 L .32107 .50336 L p
1 g
F P
s
P
p
.002 w
.58389 .25878 m .53984 .2456 L .54507 .25801 L p
1 g
F P
s
P
p
.002 w
.54507 .25801 m .58112 .26884 L .58389 .25878 L p
1 g
F P
s
P
p
.002 w
.69018 .43289 m .67221 .47713 L .6751 .49795 L p
1 g
F P
s
P
p
.002 w
.67221 .47713 m .69018 .43289 L .68096 .41557 L p
1 g
F P
s
P
p
.002 w
.3496 .30474 m .32868 .35243 L .34529 .34016 L p
1 g
F P
s
P
p
.002 w
.34529 .34016 m .36569 .29429 L .3496 .30474 L p
1 g
F P
s
P
p
.002 w
.65146 .31958 m .62272 .28453 L .61287 .2899 L p
1 g
F P
s
P
p
.002 w
.58112 .26884 m .61287 .2899 L .62272 .28453 L p
1 g
F P
s
P
p
.002 w
.62272 .28453 m .58389 .25878 L .58112 .26884 L p
1 g
F P
s
P
p
.002 w
.5133 .61215 m .56911 .60785 L .57927 .59342 L p
1 g
F P
s
P
p
.002 w
.62909 .57228 m .57927 .59342 L .56911 .60785 L p
1 g
F P
s
P
p
.002 w
.57927 .59342 m .62909 .57228 L .63617 .5541 L p
1 g
F P
s
P
p
.002 w
.68096 .41557 m .68056 .36979 L .6668 .35944 L p
1 g
F P
s
P
p
.002 w
.65146 .31958 m .6668 .35944 L .68056 .36979 L p
1 g
F P
s
P
p
.002 w
.68056 .36979 m .68096 .41557 L .69018 .43289 L p
1 g
F P
s
P
p
.002 w
.44812 .61065 m .50311 .62196 L .5133 .61215 L p
1 g
F P
s
P
p
.002 w
.56911 .60785 m .5133 .61215 L .50311 .62196 L p
1 g
F P
s
P
p
.002 w
.40367 .25883 m .36569 .29429 L .38478 .28779 L p
1 g
F P
s
P
p
.002 w
.38478 .28779 m .42042 .25476 L .40367 .25883 L p
1 g
F P
s
P
p
.002 w
.67335 .51764 m .63617 .5541 L .62909 .57228 L p
1 g
F P
s
P
p
.002 w
.63617 .5541 m .67335 .51764 L .6751 .49795 L p
1 g
F P
s
P
p
.002 w
.53331 .23771 m .48264 .23877 L .49609 .24643 L p
1 g
F P
s
P
p
.002 w
.49609 .24643 m .53984 .2456 L .53331 .23771 L p
1 g
F P
s
P
p
.002 w
.30444 .45337 m .32107 .50336 L .32435 .48896 L p
1 g
F P
s
P
p
.002 w
.32435 .48896 m .30714 .43675 L .30444 .45337 L p
1 g
F P
s
P
p
.002 w
.30825 .38431 m .30714 .43675 L .31486 .42057 L p
1 g
F P
s
P
p
.002 w
.31486 .42057 m .31615 .36723 L .30825 .38431 L p
1 g
F P
s
P
p
.002 w
.46913 .23608 m .42042 .25476 L .43867 .2555 L p
1 g
F P
s
P
p
.002 w
.43867 .2555 m .48264 .23877 L .46913 .23608 L p
1 g
F P
s
P
p
.002 w
.35226 .55849 m .39305 .59279 L .39656 .58546 L p
1 g
F P
s
P
p
.002 w
.39656 .58546 m .35289 .54867 L .35226 .55849 L p
1 g
F P
s
P
p
.002 w
.44812 .61065 m .39656 .58546 L .39305 .59279 L p
1 g
F P
s
P
p
.002 w
.39305 .59279 m .44118 .61633 L .44812 .61065 L p
1 g
F P
s
P
p
.002 w
.50311 .62196 m .44812 .61065 L .44118 .61633 L p
1 g
F P
s
P
p
.002 w
.69453 .45077 m .6751 .49795 L .67335 .51764 L p
1 g
F P
s
P
p
.002 w
.6751 .49795 m .69453 .45077 L .69018 .43289 L p
1 g
F P
s
P
p
.002 w
.68056 .36979 m .66294 .32365 L .65146 .31958 L p
1 g
F P
s
P
p
.002 w
.62272 .28453 m .65146 .31958 L .66294 .32365 L p
1 g
F P
s
P
p
.002 w
.33712 .31907 m .31615 .36723 L .32868 .35243 L p
1 g
F P
s
P
p
.002 w
.32868 .35243 m .3496 .30474 L .33712 .31907 L p
1 g
F P
s
P
p
.002 w
.32258 .51633 m .35226 .55849 L .35289 .54867 L p
1 g
F P
s
P
p
.002 w
.35289 .54867 m .32107 .50336 L .32258 .51633 L p
1 g
F P
s
P
p
.002 w
.58449 .253 m .53331 .23771 L .53984 .2456 L p
1 g
F P
s
P
p
.002 w
.53984 .2456 m .58389 .25878 L .58449 .253 L p
1 g
F P
s
P
p
.002 w
.68992 .38219 m .69018 .43289 L .69453 .45077 L p
1 g
F P
s
P
p
.002 w
.69018 .43289 m .68992 .38219 L .68056 .36979 L p
1 g
F P
s
P
p
.002 w
.50311 .62196 m .55668 .61798 L .56911 .60785 L p
1 g
F P
s
P
p
.002 w
.61822 .58723 m .56911 .60785 L .55668 .61798 L p
1 g
F P
s
P
p
.002 w
.56911 .60785 m .61822 .58723 L .62909 .57228 L p
1 g
F P
s
P
p
.002 w
.66294 .32365 m .68056 .36979 L .68992 .38219 L p
1 g
F P
s
P
p
.002 w
.58389 .25878 m .62272 .28453 L .62962 .28294 L p
1 g
F P
s
P
p
.002 w
.66294 .32365 m .62962 .28294 L .62272 .28453 L p
1 g
F P
s
P
p
.002 w
.62962 .28294 m .58449 .253 L .58389 .25878 L p
1 g
F P
s
P
p
.002 w
.38899 .26786 m .3496 .30474 L .36569 .29429 L p
1 g
F P
s
P
p
.002 w
.36569 .29429 m .40367 .25883 L .38899 .26786 L p
1 g
F P
s
P
p
.002 w
.44118 .61633 m .49242 .62693 L .50311 .62196 L p
1 g
F P
s
P
p
.002 w
.55668 .61798 m .50311 .62196 L .49242 .62693 L p
1 g
F P
s
P
p
.002 w
.66676 .53563 m .62909 .57228 L .61822 .58723 L p
1 g
F P
s
P
p
.002 w
.62909 .57228 m .66676 .53563 L .67335 .51764 L p
1 g
F P
s
P
p
.002 w
.52556 .23486 m .46913 .23608 L .48264 .23877 L p
1 g
F P
s
P
p
.002 w
.48264 .23877 m .53331 .23771 L .52556 .23486 L p
1 g
F P
s
P
p
.002 w
.45594 .23874 m .40367 .25883 L .42042 .25476 L p
1 g
F P
s
P
p
.002 w
.42042 .25476 m .46913 .23608 L .45594 .23874 L p
1 g
F P
s
P
p
.002 w
.30544 .40332 m .30444 .45337 L .30714 .43675 L p
1 g
F P
s
P
p
.002 w
.30714 .43675 m .30825 .38431 L .30544 .40332 L p
1 g
F P
s
P
p
.002 w
.30712 .46999 m .32258 .51633 L .32107 .50336 L p
1 g
F P
s
P
p
.002 w
.32107 .50336 m .30444 .45337 L .30712 .46999 L p
1 g
F P
s
P
p
.002 w
.69365 .46874 m .67335 .51764 L .66676 .53563 L p
1 g
F P
s
P
p
.002 w
.67335 .51764 m .69365 .46874 L .69453 .45077 L p
1 g
F P
s
P
p
.002 w
.35573 .56516 m .39234 .59594 L .39305 .59279 L p
1 g
F P
s
P
p
.002 w
.39305 .59279 m .35226 .55849 L .35573 .56516 L p
1 g
F P
s
P
p
.002 w
.44118 .61633 m .39305 .59279 L .39234 .59594 L p
1 g
F P
s
P
p
.002 w
.32881 .33707 m .30825 .38431 L .31615 .36723 L p
1 g
F P
s
P
p
.002 w
.31615 .36723 m .33712 .31907 L .32881 .33707 L p
1 g
F P
s
P
p
.002 w
.68992 .38219 m .67038 .33086 L .66294 .32365 L p
1 g
F P
s
P
p
.002 w
.62962 .28294 m .66294 .32365 L .67038 .33086 L p
1 g
F P
s
P
p
.002 w
.39234 .59594 m .43556 .61708 L .44118 .61633 L p
1 g
F P
s
P
p
.002 w
.49242 .62693 m .44118 .61633 L .43556 .61708 L p
1 g
F P
s
P
p
.002 w
.32915 .52743 m .35573 .56516 L .35226 .55849 L p
1 g
F P
s
P
p
.002 w
.35226 .55849 m .32258 .51633 L .32915 .52743 L p
1 g
F P
s
P
p
.002 w
.69453 .45077 m .69435 .39643 L .68992 .38219 L p
1 g
F P
s
P
p
.002 w
.69435 .39643 m .69453 .45077 L .69365 .46874 L p
1 g
F P
s
P
p
.002 w
.58274 .25194 m .52556 .23486 L .53331 .23771 L p
1 g
F P
s
P
p
.002 w
.53331 .23771 m .58449 .253 L .58274 .25194 L p
1 g
F P
s
P
p
.002 w
.49242 .62693 m .54218 .62329 L .55668 .61798 L p
1 g
F P
s
P
p
.002 w
.55668 .61798 m .60366 .59836 L .61822 .58723 L p
1 g
F P
s
P
p
.002 w
.60366 .59836 m .55668 .61798 L .54218 .62329 L p
1 g
F P
s
P
p
.002 w
.67038 .33086 m .68992 .38219 L .69435 .39643 L p
1 g
F P
s
P
p
.002 w
.37693 .28187 m .33712 .31907 L .3496 .30474 L p
1 g
F P
s
P
p
.002 w
.3496 .30474 m .38899 .26786 L .37693 .28187 L p
1 g
F P
s
P
p
.002 w
.61822 .58723 m .65525 .55131 L .66676 .53563 L p
1 g
F P
s
P
p
.002 w
.65525 .55131 m .61822 .58723 L .60366 .59836 L p
1 g
F P
s
P
p
.002 w
.67038 .33086 m .6332 .28541 L .62962 .28294 L p
1 g
F P
s
P
p
.002 w
.58449 .253 m .62962 .28294 L .6332 .28541 L p
1 g
F P
s
P
p
.002 w
.43556 .61708 m .48149 .6266 L .49242 .62693 L p
1 g
F P
s
P
p
.002 w
.54218 .62329 m .49242 .62693 L .48149 .6266 L p
1 g
F P
s
P
p
.002 w
.6332 .28541 m .58274 .25194 L .58449 .253 L p
1 g
F P
s
P
p
.002 w
.44348 .24699 m .38899 .26786 L .40367 .25883 L p
1 g
F P
s
P
p
.002 w
.40367 .25883 m .45594 .23874 L .44348 .24699 L p
1 g
F P
s
P
p
.002 w
.51676 .23746 m .45594 .23874 L .46913 .23608 L p
1 g
F P
s
P
p
.002 w
.46913 .23608 m .52556 .23486 L .51676 .23746 L p
1 g
F P
s
P
p
.002 w
.30811 .42378 m .30712 .46999 L .30444 .45337 L p
1 g
F P
s
P
p
.002 w
.30444 .45337 m .30544 .40332 L .30811 .42378 L p
1 g
F P
s
P
p
.002 w
.31541 .48611 m .32915 .52743 L .32258 .51633 L p
1 g
F P
s
P
p
.002 w
.32258 .51633 m .30712 .46999 L .31541 .48611 L p
1 g
F P
s
P
p
.002 w
.66676 .53563 m .68726 .4863 L .69365 .46874 L p
1 g
F P
s
P
p
.002 w
.68726 .4863 m .66676 .53563 L .65525 .55131 L p
1 g
F P
s
P
p
.002 w
.32513 .35839 m .30544 .40332 L .30825 .38431 L p
1 g
F P
s
P
p
.002 w
.30825 .38431 m .32881 .33707 L .32513 .35839 L p
1 g
F P
s
P
p
.002 w
.36344 .56829 m .39466 .59455 L .39234 .59594 L p
1 g
F P
s
P
p
.002 w
.39234 .59594 m .35573 .56516 L .36344 .56829 L p
1 g
F P
s
P
p
.002 w
.43556 .61708 m .39234 .59594 L .39466 .59455 L p
1 g
F P
s
P
p
.002 w
.69435 .39643 m .67331 .34119 L .67038 .33086 L p
1 g
F P
s
P
p
.002 w
.6332 .28541 m .67038 .33086 L .67331 .34119 L p
1 g
F P
s
P
p
.002 w
.69343 .4122 m .69365 .46874 L .68726 .4863 L p
1 g
F P
s
P
p
.002 w
.69365 .46874 m .69343 .4122 L .69435 .39643 L p
1 g
F P
s
P
p
.002 w
.39466 .59455 m .43153 .61258 L .43556 .61708 L p
1 g
F P
s
P
p
.002 w
.48149 .6266 m .43556 .61708 L .43153 .61258 L p
1 g
F P
s
P
p
.002 w
.36799 .30069 m .32881 .33707 L .33712 .31907 L p
1 g
F P
s
P
p
.002 w
.33712 .31907 m .37693 .28187 L .36799 .30069 L p
1 g
F P
s
P
p
.002 w
.34088 .53619 m .36344 .56829 L .35573 .56516 L p
1 g
F P
s
P
p
.002 w
.35573 .56516 m .32915 .52743 L .34088 .53619 L p
1 g
F P
s
P
p
.002 w
.48149 .6266 m .52592 .62334 L .54218 .62329 L p
1 g
F P
s
P
p
.002 w
.58563 .60514 m .54218 .62329 L .52592 .62334 L p
1 g
F P
s
P
p
.002 w
.54218 .62329 m .58563 .60514 L .60366 .59836 L p
1 g
F P
s
P
p
.002 w
.67331 .34119 m .69435 .39643 L .69343 .4122 L p
1 g
F P
s
P
p
.002 w
.57855 .25594 m .51676 .23746 L .52556 .23486 L p
1 g
F P
s
P
p
.002 w
.52556 .23486 m .58274 .25194 L .57855 .25594 L p
1 g
F P
s
P
p
.002 w
.63889 .56411 m .60366 .59836 L .58563 .60514 L p
1 g
F P
s
P
p
.002 w
.60366 .59836 m .63889 .56411 L .65525 .55131 L p
1 g
F P
s
P
p
.002 w
.58274 .25194 m .6332 .28541 L .63312 .29214 L p
1 g
F P
s
P
p
.002 w
.67331 .34119 m .63312 .29214 L .6332 .28541 L p
1 g
F P
s
P
p
.002 w
.43153 .61258 m .47064 .62066 L .48149 .6266 L p
1 g
F P
s
P
p
.002 w
.52592 .62334 m .48149 .6266 L .47064 .62066 L p
1 g
F P
s
P
p
.002 w
.43218 .2609 m .37693 .28187 L .38899 .26786 L p
1 g
F P
s
P
p
.002 w
.38899 .26786 m .44348 .24699 L .43218 .2609 L p
1 g
F P
s
P
p
.002 w
.31644 .44513 m .31541 .48611 L .30712 .46999 L p
1 g
F P
s
P
p
.002 w
.30712 .46999 m .30811 .42378 L .31644 .44513 L p
1 g
F P
s
P
p
.002 w
.63312 .29214 m .57855 .25594 L .58274 .25194 L p
1 g
F P
s
P
p
.002 w
.5071 .24577 m .44348 .24699 L .45594 .23874 L p
1 g
F P
s
P
p
.002 w
.45594 .23874 m .51676 .23746 L .5071 .24577 L p
1 g
F P
s
P
p
.002 w
.67525 .50288 m .65525 .55131 L .63889 .56411 L p
1 g
F P
s
P
p
.002 w
.65525 .55131 m .67525 .50288 L .68726 .4863 L p
1 g
F P
s
P
p
.002 w
.32644 .38252 m .30811 .42378 L .30544 .40332 L p
1 g
F P
s
P
p
.002 w
.30544 .40332 m .32513 .35839 L .32644 .38252 L p
1 g
F P
s
P
p
.002 w
.32935 .5012 m .34088 .53619 L .32915 .52743 L p
1 g
F P
s
P
p
.002 w
.32915 .52743 m .31541 .48611 L .32935 .5012 L p
1 g
F P
s
P
p
.002 w
.68689 .4291 m .68726 .4863 L .67525 .50288 L p
1 g
F P
s
P
p
.002 w
.68726 .4863 m .68689 .4291 L .69343 .4122 L p
1 g
F P
s
P
p
.002 w
.36265 .32399 m .32513 .35839 L .32881 .33707 L p
1 g
F P
s
P
p
.002 w
.32881 .33707 m .36799 .30069 L .36265 .32399 L p
1 g
F P
s
P
p
.002 w
.69343 .4122 m .67135 .35453 L .67331 .34119 L p
1 g
F P
s
P
p
.002 w
.63312 .29214 m .67331 .34119 L .67135 .35453 L p
1 g
F P
s
P
p
.002 w
.37545 .56756 m .40013 .58835 L .39466 .59455 L p
1 g
F P
s
P
p
.002 w
.39466 .59455 m .36344 .56829 L .37545 .56756 L p
1 g
F P
s
P
p
.002 w
.43153 .61258 m .39466 .59455 L .40013 .58835 L p
1 g
F P
s
P
p
.002 w
.47064 .62066 m .50829 .61782 L .52592 .62334 L p
1 g
F P
s
P
p
.002 w
.56447 .60711 m .52592 .62334 L .50829 .61782 L p
1 g
F P
s
P
p
.002 w
.52592 .62334 m .56447 .60711 L .58563 .60514 L p
1 g
F P
s
P
p
.002 w
.40013 .58835 m .42931 .60261 L .43153 .61258 L p
1 g
F P
s
P
p
.002 w
.47064 .62066 m .43153 .61258 L .42931 .60261 L p
1 g
F P
s
P
p
.002 w
.61796 .57346 m .58563 .60514 L .56447 .60711 L p
1 g
F P
s
P
p
.002 w
.58563 .60514 m .61796 .57346 L .63889 .56411 L p
1 g
F P
s
P
p
.002 w
.67135 .35453 m .69343 .4122 L .68689 .4291 L p
1 g
F P
s
P
p
.002 w
.35772 .54221 m .37545 .56756 L .36344 .56829 L p
1 g
F P
s
P
p
.002 w
.36344 .56829 m .34088 .53619 L .35772 .54221 L p
1 g
F P
s
P
p
.002 w
.57187 .26523 m .5071 .24577 L .51676 .23746 L p
1 g
F P
s
P
p
.002 w
.51676 .23746 m .57855 .25594 L .57187 .26523 L p
1 g
F P
s
P
p
.002 w
.42248 .28035 m .36799 .30069 L .37693 .28187 L p
1 g
F P
s
P
p
.002 w
.37693 .28187 m .43218 .2609 L .42248 .28035 L p
1 g
F P
s
P
p
.002 w
.33045 .46672 m .32935 .5012 L .31541 .48611 L p
1 g
F P
s
P
p
.002 w
.31541 .48611 m .31644 .44513 L .33045 .46672 L p
1 g
F P
s
P
p
.002 w
.6577 .51792 m .63889 .56411 L .61796 .57346 L p
1 g
F P
s
P
p
.002 w
.63889 .56411 m .6577 .51792 L .67525 .50288 L p
1 g
F P
s
P
p
.002 w
.42931 .60261 m .46019 .60894 L .47064 .62066 L p
1 g
F P
s
P
p
.002 w
.50829 .61782 m .47064 .62066 L .46019 .60894 L p
1 g
F P
s
P
p
.002 w
.49684 .25987 m .43218 .2609 L .44348 .24699 L p
1 g
F P
s
P
p
.002 w
.44348 .24699 m .5071 .24577 L .49684 .25987 L p
1 g
F P
s
P
p
.002 w
.33295 .4088 m .31644 .44513 L .30811 .42378 L p
1 g
F P
s
P
p
.002 w
.30811 .42378 m .32644 .38252 L .33295 .4088 L p
1 g
F P
s
P
p
.002 w
.57855 .25594 m .63312 .29214 L .62916 .3032 L p
1 g
F P
s
P
p
.002 w
.67135 .35453 m .62916 .3032 L .63312 .29214 L p
1 g
F P
s
P
p
.002 w
.62916 .3032 m .57187 .26523 L .57855 .25594 L p
1 g
F P
s
P
p
.002 w
.34881 .51472 m .35772 .54221 L .34088 .53619 L p
1 g
F P
s
P
p
.002 w
.34088 .53619 m .32935 .5012 L .34881 .51472 L p
1 g
F P
s
P
p
.002 w
.6746 .44667 m .67525 .50288 L .6577 .51792 L p
1 g
F P
s
P
p
.002 w
.67525 .50288 m .6746 .44667 L .68689 .4291 L p
1 g
F P
s
P
p
.002 w
.36126 .35117 m .32644 .38252 L .32513 .35839 L p
1 g
F P
s
P
p
.002 w
.32513 .35839 m .36265 .32399 L .36126 .35117 L p
1 g
F P
s
P
p
.002 w
.50829 .61782 m .54073 .60397 L .56447 .60711 L p
1 g
F P
s
P
p
.002 w
.59289 .5789 m .56447 .60711 L .54073 .60397 L p
1 g
F P
s
P
p
.002 w
.56447 .60711 m .59289 .5789 L .61796 .57346 L p
1 g
F P
s
P
p
.002 w
.46019 .60894 m .48978 .60659 L .50829 .61782 L p
1 g
F P
s
P
p
.002 w
.54073 .60397 m .50829 .61782 L .48978 .60659 L p
1 g
F P
s
P
p
.002 w
.68689 .4291 m .66427 .37065 L .67135 .35453 L p
1 g
F P
s
P
p
.002 w
.62916 .3032 m .67135 .35453 L .66427 .37065 L p
1 g
F P
s
P
p
.002 w
.66427 .37065 m .68689 .4291 L .6746 .44667 L p
1 g
F P
s
P
p
.002 w
.39163 .56275 m .40877 .57722 L .40013 .58835 L p
1 g
F P
s
P
p
.002 w
.40013 .58835 m .37545 .56756 L .39163 .56275 L p
1 g
F P
s
P
p
.002 w
.42931 .60261 m .40013 .58835 L .40877 .57722 L p
1 g
F P
s
P
p
.004 w
.39638 .60638 m
.40813 .58644 L
s
P
p
.002 w
.40877 .57722 m .42908 .58713 L .42931 .60261 L p
1 g
F P
s
P
p
.002 w
.46019 .60894 m .42931 .60261 L .42908 .58713 L p
1 g
F P
s
P
p
.002 w
.63492 .53084 m .61796 .57346 L .59289 .5789 L p
1 g
F P
s
P
p
.002 w
.61796 .57346 m .63492 .53084 L .6577 .51792 L p
1 g
F P
s
P
p
.002 w
.3794 .54513 m .39163 .56275 L .37545 .56756 L p
1 g
F P
s
P
p
.002 w
.37545 .56756 m .35772 .54221 L .3794 .54513 L p
1 g
F P
s
P
p
.002 w
.41479 .30496 m .36265 .32399 L .36799 .30069 L p
1 g
F P
s
P
p
.002 w
.36799 .30069 m .42248 .28035 L .41479 .30496 L p
1 g
F P
s
P
p
.002 w
.56279 .27982 m .49684 .25987 L .5071 .24577 L p
1 g
F P
s
P
p
.002 w
.5071 .24577 m .57187 .26523 L .56279 .27982 L p
1 g
F P
s
P
p
.002 w
.34991 .48783 m .34881 .51472 L .32935 .5012 L p
1 g
F P
s
P
p
.002 w
.32935 .5012 m .33045 .46672 L .34991 .48783 L p
1 g
F P
s
P
p
.002 w
.34463 .43641 m .33045 .46672 L .31644 .44513 L p
1 g
F P
s
P
p
.002 w
.31644 .44513 m .33295 .4088 L .34463 .43641 L p
1 g
F P
s
P
p
.002 w
.42908 .58713 m .45053 .59147 L .46019 .60894 L p
1 g
F P
s
P
p
.002 w
.48978 .60659 m .46019 .60894 L .45053 .59147 L p
1 g
F P
s
P
p
.002 w
.4863 .27963 m .42248 .28035 L .43218 .2609 L p
1 g
F P
s
P
p
.002 w
.43218 .2609 m .49684 .25987 L .4863 .27963 L p
1 g
F P
s
P
p
.002 w
.57187 .26523 m .62916 .3032 L .62119 .31849 L p
1 g
F P
s
P
p
.002 w
.66427 .37065 m .62119 .31849 L .62916 .3032 L p
1 g
F P
s
P
p
.002 w
.37339 .52613 m .3794 .54513 L .35772 .54221 L p
1 g
F P
s
P
p
.002 w
.35772 .54221 m .34881 .51472 L .37339 .52613 L p
1 g
F P
s
P
p
.002 w
.6567 .46433 m .6577 .51792 L .63492 .53084 L p
1 g
F P
s
P
p
.002 w
.6577 .51792 m .6567 .46433 L .6746 .44667 L p
1 g
F P
s
P
p
.002 w
.62119 .31849 m .56279 .27982 L .57187 .26523 L p
1 g
F P
s
P
p
.002 w
.36402 .38145 m .33295 .4088 L .32644 .38252 L p
1 g
F P
s
P
p
.002 w
.32644 .38252 m .36126 .35117 L .36402 .38145 L p
1 g
F P
s
P
p
.002 w
.48978 .60659 m .51505 .59558 L .54073 .60397 L p
1 g
F P
s
P
p
.002 w
.56435 .58007 m .54073 .60397 L .51505 .59558 L p
1 g
F P
s
P
p
.002 w
.54073 .60397 m .56435 .58007 L .59289 .5789 L p
1 g
F P
s
P
p
.002 w
.45053 .59147 m .47097 .58974 L .48978 .60659 L p
1 g
F P
s
P
p
.002 w
.51505 .59558 m .48978 .60659 L .47097 .58974 L p
1 g
F P
s
P
p
.002 w
.65201 .38914 m .6746 .44667 L .6567 .46433 L p
1 g
F P
s
P
p
.002 w
.6746 .44667 m .65201 .38914 L .66427 .37065 L p
1 g
F P
s
P
p
.002 w
.60748 .54109 m .59289 .5789 L .56435 .58007 L p
1 g
F P
s
P
p
.002 w
.59289 .5789 m .60748 .54109 L .63492 .53084 L p
1 g
F P
s
P
p
.002 w
.62119 .31849 m .66427 .37065 L .65201 .38914 L p
1 g
F P
s
P
p
.002 w
.40949 .33407 m .36126 .35117 L .36265 .32399 L p
1 g
F P
s
P
p
.002 w
.36265 .32399 m .41479 .30496 L .40949 .33407 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.36126 .46441 m .34991 .48783 L .33045 .46672 L p
1 g
F P
s
P
p
.002 w
.33045 .46672 m .34463 .43641 L .36126 .46441 L p
1 g
F P
s
P
p
.002 w
.37436 .5077 m .37339 .52613 L .34881 .51472 L p
1 g
F P
s
P
p
.002 w
.34881 .51472 m .34991 .48783 L .37436 .5077 L p
1 g
F P
s
P
p
.002 w
.41167 .55378 m .4205 .56126 L .40877 .57722 L p
1 g
F P
s
P
p
.002 w
.40877 .57722 m .39163 .56275 L .41167 .55378 L p
1 g
F P
s
P
p
.002 w
.42908 .58713 m .40877 .57722 L .4205 .56126 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.4205 .56126 m .43098 .56636 L .42908 .58713 L p
1 g
F P
s
P
p
.002 w
.45053 .59147 m .42908 .58713 L .43098 .56636 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.40542 .54469 m .41167 .55378 L .39163 .56275 L p
1 g
F P
s
P
p
.002 w
.39163 .56275 m .3794 .54513 L .40542 .54469 L p
1 g
F P
s
P
p
.002 w
.55146 .29951 m .4863 .27963 L .49684 .25987 L p
1 g
F P
s
P
p
.002 w
.49684 .25987 m .56279 .27982 L .55146 .29951 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47584 .30463 m .41479 .30496 L .42248 .28035 L p
1 g
F P
s
P
p
.002 w
.42248 .28035 m .4863 .27963 L .47584 .30463 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37099 .41383 m .34463 .43641 L .33295 .4088 L p
1 g
F P
s
P
p
.002 w
.33295 .4088 m .36402 .38145 L .37099 .41383 L p
1 g
F P
s
P
p
.002 w
.43098 .56636 m .44203 .56856 L .45053 .59147 L p
1 g
F P
s
P
p
.002 w
.47097 .58974 m .45053 .59147 L .44203 .56856 L p
1 g
F P
s
P
p
.002 w
.63353 .48147 m .63492 .53084 L .60748 .54109 L p
1 g
F P
s
P
p
.002 w
.63492 .53084 m .63353 .48147 L .6567 .46433 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.40244 .53495 m .40542 .54469 L .3794 .54513 L p
1 g
F P
s
P
p
.002 w
.3794 .54513 m .37339 .52613 L .40244 .53495 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.47097 .58974 m .48826 .582 L .51505 .59558 L p
1 g
F P
s
P
p
.002 w
.47097 .58974 m .4545 .56999 L p
.46999 .57551 L 1 g
F P
s
P
p
.002 w
.46831 .57451 m .46872 .57265 L p
.45782 .56829 L 1 g
F P
s
P
p
.002 w
.48826 .582 m .4841 .58386 L p
.46999 .57551 L 1 g
F P
s
P
p
.002 w
.4841 .58386 m .47097 .58974 L p
.46999 .57551 L 1 g
F P
s
P
p
.48826 .582 m .4545 .56999 L .47549 .57686 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57451 L p
1 g
F P
s
P
p
.002 w
.48554 .58014 m .48826 .582 L p
.47549 .57686 L 1 g
F P
s
P
p
.002 w
.46831 .57451 m .4678 .57686 L p
.47809 .57771 L 1 g
F P
s
P
p
.48921 .57862 m .46831 .57451 L .47809 .57771 L 1 g
F
P
p
.48921 .57862 m .47809 .57771 L .48105 .57868 L 1 g
F
P
p
.002 w
.48902 .58119 m .48826 .582 L .48554 .58014 L p
1 g
F P
s
P
p
.002 w
.48902 .58119 m .48902 .58119 L p
.4742 .57872 L 1 g
F P
s
P
p
.002 w
.48902 .58119 m .48921 .57862 L p
.48066 .57868 L 1 g
F P
s
P
p
.48066 .57868 m .4742 .57872 L .48902 .58119 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48902 .58119 L p
1 g
F P
s
P
p
.002 w
.51505 .59558 m .48826 .582 L p
.49158 .58161 L 1 g
F P
s
P
p
.49846 .58081 m .52341 .58691 L .49158 .58161 L 1 g
F
P
p
.002 w
.53053 .57953 m .52341 .58691 L p
.50372 .58209 L 1 g
F P
s
P
p
.51092 .58031 m .50372 .58209 L .49846 .58081 L 1 g
F
P
p
.53053 .57953 m .50372 .58209 L .51092 .58031 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58031 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58031 L .52141 .57771 L 1 g
F
P
p
.51079 .57862 m .48902 .58119 L .48902 .58119 L 1 g
F
P
p
.51079 .57862 m .48902 .58119 L .50018 .58074 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51092 .58031 m .51079 .57862 L p
.50018 .58074 L 1 g
F P
s
P
p
.002 w
.52918 .57579 m .53008 .57601 L p
.51822 .5785 L 1 g
F P
s
P
p
.002 w
.53008 .57601 m .53321 .57675 L p
.52718 .57746 L 1 g
F P
s
P
p
.52718 .57746 m .51822 .5785 L .53008 .57601 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53178 .57495 L p
1 g
F P
s
P
p
.54854 .56129 m .53178 .57495 L .53281 .57432 L 1 g
F
P
p
.002 w
.53321 .57675 m .53008 .57601 L p
.53178 .57495 L 1 g
F P
s
P
p
.002 w
.53442 .57332 m .53411 .57421 L p
.53178 .57495 L 1 g
F P
s
P
p
.002 w
.53411 .57421 m .53321 .57675 L p
.53178 .57495 L 1 g
F P
s
P
p
.53128 .57265 m .52141 .57771 L .52918 .57579 L 1 g
F
P
p
.002 w
.53178 .57495 m .53128 .57265 L p
.52918 .57579 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54904 .56264 L p
1 g
F P
s
P
p
.57617 .54821 m .54229 .57072 L .54586 .56644 L 1 g
F
P
p
.56075 .54566 m .54904 .56264 L .55595 .55436 L 1 g
F
P
p
.002 w
.56751 .54914 m .57617 .54821 L p
.54586 .56644 L 1 g
F P
s
P
p
.54586 .56644 m .53442 .57332 L .54904 .56264 L 1 g
F
P
p
.54586 .56644 m .54904 .56264 L .56751 .54914 L 1 g
F
P
p
.56075 .54566 m .55595 .55436 L .55961 .54998 L 1 g
F
P
p
.002 w
.57504 .52692 m .57617 .54821 L .56069 .54986 L p
1 g
F P
s
P
p
.002 w
.56069 .54986 m .55961 .54998 L p
.56152 .54712 L 1 g
F P
s
P
p
.57504 .52692 m .56069 .54986 L .56152 .54712 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56152 .54712 L p
1 g
F P
s
P
p
.56654 .52734 m .56152 .54712 L .56506 .53546 L 1 g
F
P
p
.002 w
.56152 .54712 m .56075 .54566 L p
.55961 .54998 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56722 .52833 m .56654 .52734 L p
.56506 .53546 L 1 g
F P
s
P
p
.002 w
.55961 .54998 m .54201 .55186 L p
.56545 .53417 L 1 g
F P
s
P
p
.57504 .52692 m .56152 .54712 L .56545 .53417 L 1 g
F
P
p
.56152 .54712 m .55961 .54998 L .56545 .53417 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.57423 .51164 m .57504 .52692 L p
.56742 .53268 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56722 .52833 L p
1 g
F P
s
P
p
.56515 .50826 m .56722 .52833 L .56678 .51882 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56687 .52083 m .56742 .53268 L .54201 .55186 L 1 g
F
P
p
.57423 .51164 m .56742 .53268 L .56687 .52083 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.56515 .50826 m .56678 .51882 L .56657 .5143 L 1 g
F
P
p
.002 w
.56358 .48701 m .57423 .51164 L .56818 .51374 L p
1 g
F P
s
P
p
.002 w
.56818 .51374 m .56657 .5143 L p
.56602 .5093 L 1 g
F P
s
P
p
.56358 .48701 m .56818 .51374 L .56602 .5093 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56602 .5093 L p
1 g
F P
s
P
p
.55661 .4905 m .56602 .5093 L .5607 .49833 L 1 g
F
P
p
.002 w
.56602 .5093 m .56515 .50826 L p
.56657 .5143 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55722 .49115 m .55661 .4905 L p
.5607 .49833 L 1 g
F P
s
P
p
.002 w
.56657 .5143 m .54011 .52347 L p
.55881 .49442 L 1 g
F P
s
P
p
.56358 .48701 m .56602 .5093 L .55881 .49442 L 1 g
F
P
p
.56602 .5093 m .56657 .5143 L .55881 .49442 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55817 .4745 m .56358 .48701 L p
.5595 .49335 L 1 g
F P
s
P
p
.55339 .48745 m .5595 .49335 L .54011 .52347 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55722 .49115 L p
1 g
F P
s
P
p
.54174 .47608 m .55722 .49115 L .54977 .48394 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55817 .4745 m .5595 .49335 L .55339 .48745 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55722 .49115 L p
1 g
F P
s
P
p
.5607 .49833 m .56713 .51061 L .55722 .49115 L 1 g
F
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54011 .52347 m .52734 .49478 L .54736 .48161 L p
1 g
F P
s
P
p
.54174 .47608 m .54977 .48394 L .54736 .48161 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54736 .48161 m .52734 .49478 L p
.52833 .46993 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47661 L p
1 g
F P
s
P
p
.52214 .46667 m .54223 .47661 L .52972 .4706 L 1 g
F
P
p
.54223 .47661 m .54736 .48161 L .52833 .46993 L 1 g
F
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.52833 .46993 m .52734 .49478 L .51342 .46589 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46706 L p
1 g
F P
s
P
p
.5 .4634 m .52237 .46706 L .51195 .4657 L 1 g
F
P
p
.52237 .46706 m .51342 .46589 L .51146 .46181 L 1 g
F
P
p
.52833 .46993 m .51342 .46589 L .52237 .46706 L 1 g
F
P
p
.002 w
.52734 .49478 m .50495 .46921 L .50844 .46524 L p
1 g
F P
s
P
p
.5 .4634 m .51195 .4657 L .50844 .46524 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50495 .46921 m .49749 .46431 L p
.50375 .4645 L 1 g
F P
s
P
p
.50375 .4645 m .49749 .46431 L .5 .46391 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46712 L p
1 g
F P
s
P
p
.002 w
.50495 .46921 m .48043 .49571 L p
.47737 .46722 L 1 g
F P
s
P
p
.4775 .46716 m .50495 .46921 L .47737 .46722 L 1 g
F
P
p
.45826 .47608 m .47759 .46712 L .46781 .47189 L 1 g
F
P
p
.002 w
.49749 .46431 m .50495 .46921 L p
.47736 .46715 L 1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48043 .49571 m .46043 .48262 L .46467 .47343 L p
1 g
F P
s
P
p
.46838 .47162 m .48043 .49571 L .46467 .47343 L 1 g
F
P
p
.47736 .46715 m .48043 .49571 L .46688 .46863 L 1 g
F
P
p
.002 w
.45762 .47678 m .45826 .47608 L p
.46467 .47343 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45762 .47678 L p
1 g
F P
s
P
p
.44339 .4905 m .45762 .47678 L .45384 .48046 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44263 .49131 L p
1 g
F P
s
P
p
.43485 .50826 m .44263 .49131 L .43843 .49989 L 1 g
F
P
p
.002 w
.45384 .48046 m .46043 .48262 L p
.44241 .49175 L 1 g
F P
s
P
p
.44263 .49131 m .44241 .49175 L .44191 .492 L 1 g
F
P
p
.45384 .48046 m .44241 .49175 L .44263 .49131 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46043 .48262 m .44678 .51328 L p
.44191 .492 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42444 .50906 m .41602 .4745 L p
.43458 .50779 L 1 g
F P
s
P
p
.002 w
.43369 .50964 m .43485 .50826 L p
.43407 .5088 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43369 .50964 L p
1 g
F P
s
P
p
.002 w
.43228 .53248 m .42847 .52109 L p
.42981 .5189 L 1 g
F P
s
P
p
.42981 .5189 m .43349 .51292 L .43251 .52872 L 1 g
F
P
p
.42981 .5189 m .43251 .52872 L .43228 .53248 L 1 g
F
P
p
.43925 .54566 m .43469 .53664 L .43509 .53811 L 1 g
F
P
p
.43925 .54566 m .43509 .53811 L .43539 .53917 L 1 g
F
P
p
.43925 .54566 m .43538 .53916 L .43567 .54016 L 1 g
F
P
p
.43925 .54566 m .43567 .54016 L .43572 .54033 L 1 g
F
P
p
.43925 .54566 m .43572 .54032 L .43574 .54038 L 1 g
F
P
p
.002 w
.43583 .54069 m .43505 .54075 L .43576 .54046 L p
1 g
F P
s
P
p
.43578 .54053 m .43571 .54034 L .43577 .54051 L 1 g
F
P
p
.43925 .54566 m .43573 .54037 L .43578 .54053 L 1 g
F
P
p
.002 w
.43576 .54046 m .43505 .54075 L .43567 .54016 L p
1 g
F P
s
P
p
.43573 .54037 m .43571 .54034 L .43578 .54053 L 1 g
F
P
p
.43925 .54566 m .43574 .54048 L .4358 .54064 L 1 g
F
P
p
.43925 .54566 m .43578 .54061 L .43584 .54077 L 1 g
F
P
p
.002 w
.43833 .54739 m .43925 .54566 L p
.43581 .54073 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43505 .54075 m .43228 .53248 L p
.43271 .52945 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52872 L p
1 g
F P
s
P
p
.43925 .54566 m .43251 .52872 L .43469 .53664 L 1 g
F
P
p
.43346 .52734 m .43369 .50964 L .43315 .5184 L 1 g
F
P
p
.002 w
.42847 .52109 m .42444 .50906 L .4337 .50946 L p
1 g
F P
s
P
p
.4337 .50946 m .43369 .50964 L .42847 .52109 L 1 g
F
P
p
.002 w
.43377 .50947 m .43556 .50954 L p
.42847 .52109 L 1 g
F P
s
P
p
.002 w
.41465 .51185 m .42444 .50906 L .43228 .53248 L p
1 g
F P
s
P
p
.002 w
.43228 .53248 m .43505 .54075 L .43205 .5365 L p
1 g
F P
s
P
p
.002 w
.43205 .5365 m .41465 .51185 L p
.43228 .53248 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52874 L p
1 g
F P
s
P
p
.002 w
.4325 .52874 m .43251 .52872 L p
.43252 .52835 L 1 g
F P
s
P
p
.43252 .52835 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.002 w
.43251 .52872 m .43346 .52734 L p
.43315 .5184 L 1 g
F P
s
P
p
.43315 .5184 m .43287 .51061 L .43251 .52872 L 1 g
F
P
p
.002 w
.4337 .50946 m .43377 .50947 L p
.43369 .50964 L 1 g
F P
s
P
p
.002 w
.43556 .50954 m .43509 .53811 L p
.43271 .52945 L 1 g
F P
s
P
p
.002 w
.43509 .53811 m .43505 .54075 L p
.43271 .52945 L 1 g
F P
s
P
p
.43349 .51292 m .43556 .50954 L .43228 .53248 L 1 g
F
P
p
.002 w
.43251 .52872 m .43146 .53025 L p
.43469 .53664 L 1 g
F P
s
P
p
.002 w
.46918 .53828 m .47013 .54808 L .43591 .54093 L p
1 g
F P
s
P
p
.002 w
.43591 .54093 m .43505 .54075 L .43583 .54069 L p
1 g
F P
s
P
p
.002 w
.43583 .54069 m .46918 .53828 L p
.43591 .54093 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45683 .51984 m .46458 .52851 L .43576 .54046 L p
1 g
F P
s
P
p
.002 w
.43567 .54016 m .45683 .51984 L p
.43576 .54046 L 1 g
F P
s
P
p
.43572 .54033 m .43567 .54016 L .43572 .54032 L 1 g
F
P
p
.43574 .54038 m .43572 .54032 L .43573 .54038 L 1 g
F
P
p
.002 w
.46458 .52851 m .46918 .53828 L .43583 .54069 L p
1 g
F P
s
P
p
.002 w
.43576 .54046 m .46458 .52851 L p
.43583 .54069 L 1 g
F P
s
P
p
.002 w
.43556 .50954 m .44678 .51328 L .43552 .53965 L p
1 g
F P
s
P
p
.002 w
.43552 .53965 m .43505 .54075 L .43509 .53811 L p
1 g
F P
s
P
p
.002 w
.43509 .53811 m .43556 .50954 L p
.43552 .53965 L 1 g
F P
s
P
p
.43539 .53917 m .43509 .53811 L .43538 .53916 L 1 g
F
P
p
.002 w
.43567 .54016 m .43505 .54075 L .43552 .53965 L p
1 g
F P
s
P
p
.43573 .54038 m .43538 .53916 L .43571 .54034 L 1 g
F
P
p
.002 w
.44678 .51328 m .45683 .51984 L .43567 .54016 L p
1 g
F P
s
P
p
.002 w
.43552 .53965 m .44678 .51328 L p
.43567 .54016 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.47013 .54808 m .46737 .55681 L .43602 .54123 L p
1 g
F P
s
P
p
.002 w
.43602 .54123 m .43505 .54075 L .43591 .54093 L p
1 g
F P
s
P
p
.002 w
.43591 .54093 m .47013 .54808 L p
.43602 .54123 L 1 g
F P
s
P
p
.43577 .54051 m .43571 .54034 L .43574 .54048 L 1 g
F
P
p
.4358 .54064 m .43574 .54048 L .43578 .54061 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46737 .55681 m .46126 .56354 L .43621 .54176 L p
1 g
F P
s
P
p
.002 w
.43621 .54176 m .43505 .54075 L .43602 .54123 L p
1 g
F P
s
P
p
.002 w
.43602 .54123 m .46737 .55681 L p
.43621 .54176 L 1 g
F P
s
P
p
.002 w
.4525 .56759 m .4488 .5619 L p
.45069 .56335 L 1 g
F P
s
P
p
.002 w
.45482 .56652 m .45359 .56709 L p
.45069 .56335 L 1 g
F P
s
P
p
.002 w
.45359 .56709 m .4525 .56759 L p
.45069 .56335 L 1 g
F P
s
P
p
.002 w
.45069 .56335 m .45146 .56129 L p
.4442 .55499 L 1 g
F P
s
P
p
.002 w
.44483 .5558 m .4488 .5619 L p
.43833 .54739 L 1 g
F P
s
P
p
.002 w
.4488 .5619 m .4525 .56759 L p
.44816 .5614 L 1 g
F P
s
P
p
.44816 .5614 m .43833 .54739 L .4488 .5619 L 1 g
F
P
p
.002 w
.4525 .56759 m .4462 .56817 L p
.44174 .5564 L 1 g
F P
s
P
p
.44816 .5614 m .44174 .5564 L .43833 .54739 L 1 g
F
P
p
.4525 .56759 m .44174 .5564 L .44816 .5614 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45047 .56395 L p
1 g
F P
s
P
p
.46872 .57265 m .45047 .56395 L .45782 .56829 L 1 g
F
P
p
.002 w
.46126 .56354 m .48554 .58014 L p
.46403 .57197 L 1 g
F P
s
P
p
.002 w
.4525 .56759 m .45482 .56652 L p
.46403 .57197 L 1 g
F P
s
P
p
.002 w
.45482 .56652 m .46126 .56354 L p
.46403 .57197 L 1 g
F P
s
P
p
.002 w
.45047 .56395 m .45002 .56518 L p
.45782 .56829 L 1 g
F P
s
P
p
.47549 .57686 m .4525 .56759 L .48554 .58014 L 1 g
F
P
p
.002 w
.4545 .56999 m .4525 .56759 L p
.46543 .57281 L 1 g
F P
s
P
p
.47549 .57686 m .46831 .57451 L .46543 .57281 L 1 g
F
P
p
.46831 .57451 m .4545 .56999 L .46543 .57281 L 1 g
F
P
p
.45913 .56983 m .45865 .56958 L .46787 .57653 L 1 g
F
P
p
.45865 .56958 m .45002 .56518 L .46622 .57549 L 1 g
F
P
p
.45865 .56958 m .46622 .57549 L .46787 .57653 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46783 .57673 L p
1 g
F P
s
P
p
.002 w
.46783 .57673 m .46787 .57653 L p
.46622 .57549 L 1 g
F P
s
P
p
.46622 .57549 m .45002 .56518 L .46783 .57673 L 1 g
F
P
p
.4442 .55499 m .4442 .55498 L .44483 .5558 L 1 g
F
P
p
.4442 .55499 m .44483 .5558 L .45069 .56335 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43833 .54739 L p
1 g
F P
s
P
p
.002 w
.43833 .54739 m .43832 .54741 L p
.43845 .54754 L 1 g
F P
s
P
p
.45146 .56129 m .43833 .54739 L .43845 .54754 L 1 g
F
P
p
.002 w
.4462 .56817 m .44203 .56856 L p
.43744 .54623 L 1 g
F P
s
P
p
.43833 .54739 m .43744 .54623 L .43689 .54358 L 1 g
F
P
p
.4462 .56817 m .43744 .54623 L .43833 .54739 L 1 g
F
P
p
.45146 .56129 m .43832 .54741 L .4442 .55498 L 1 g
F
P
p
.45482 .56652 m .45069 .56335 L .43689 .54358 L 1 g
F
P
p
.002 w
.4488 .5619 m .44483 .5558 L p
.45069 .56335 L 1 g
F P
s
P
p
.002 w
.44483 .5558 m .43689 .54358 L p
.45069 .56335 L 1 g
F P
s
P
p
.002 w
.43505 .54075 m .43689 .54358 L p
.43744 .54623 L 1 g
F P
s
P
p
.002 w
.44203 .56856 m .43594 .54429 L p
.43744 .54623 L 1 g
F P
s
P
p
.002 w
.43594 .54429 m .43505 .54075 L p
.43744 .54623 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45069 .56337 L p
1 g
F P
s
P
p
.002 w
.45069 .56337 m .45069 .56335 L p
.45057 .56322 L 1 g
F P
s
P
p
.45057 .56322 m .43743 .5491 L .45069 .56337 L 1 g
F
P
p
.002 w
.43832 .54741 m .43743 .5491 L p
.4442 .55498 L 1 g
F P
s
P
p
.002 w
.43689 .54358 m .44483 .5558 L p
.43833 .54739 L 1 g
F P
s
P
p
.4442 .55498 m .43743 .5491 L .45069 .56335 L 1 g
F
P
p
.002 w
.46787 .57653 m .46831 .57451 L p
.45913 .56983 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46126 .56354 m .45482 .56652 L p
.43689 .54358 L 1 g
F P
s
P
p
.002 w
.43689 .54358 m .43505 .54075 L .43621 .54176 L p
1 g
F P
s
P
p
.002 w
.43621 .54176 m .46126 .56354 L p
.43689 .54358 L 1 g
F P
s
P
p
.43584 .54077 m .43578 .54061 L .43581 .54073 L 1 g
F
P
p
.002 w
.43788 .54825 m .43833 .54739 L p
.43581 .54073 L 1 g
F P
s
P
p
.002 w
.4205 .56126 m .41167 .55378 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.43098 .56636 m .4205 .56126 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.44203 .56856 m .43098 .56636 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.41167 .55378 m .40542 .54469 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.40542 .54469 m .40244 .53495 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.40244 .53495 m .40306 .52557 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.40306 .52557 m .40726 .51758 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.40726 .51758 m .41465 .51185 L .43505 .54075 L closepath p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43788 .54825 L p
1 g
F P
s
P
p
.43469 .53664 m .43146 .53025 L .43788 .54825 L 1 g
F
P
p
.002 w
.43369 .50964 m .43287 .51061 L p
.43315 .5184 L 1 g
F P
s
P
p
.002 w
.43556 .50954 m .43377 .50947 L p
.43458 .50779 L 1 g
F P
s
P
p
.002 w
.43377 .50947 m .42444 .50906 L p
.43458 .50779 L 1 g
F P
s
P
p
.43485 .50826 m .43843 .49989 L .43589 .50508 L 1 g
F
P
p
.43485 .50826 m .43589 .50508 L .4341 .50878 L 1 g
F
P
p
.002 w
.41602 .4745 m .43809 .47528 L .43589 .50508 L p
1 g
F P
s
P
p
.002 w
.43589 .50508 m .43556 .50954 L p
.43458 .50779 L 1 g
F P
s
P
p
.41602 .4745 m .43589 .50508 L .43458 .50779 L 1 g
F
P
p
.002 w
.43589 .50508 m .43647 .49727 L p
.44203 .49252 L 1 g
F P
s
P
p
.002 w
.43647 .49727 m .43809 .47528 L p
.44191 .492 L 1 g
F P
s
P
p
.44191 .492 m .44203 .49252 L .43647 .49727 L 1 g
F
P
p
.002 w
.44263 .49131 m .44166 .49233 L p
.43843 .49989 L 1 g
F P
s
P
p
.002 w
.46043 .48262 m .45384 .48046 L p
.45796 .47662 L 1 g
F P
s
P
p
.002 w
.45384 .48046 m .4515 .47969 L p
.45762 .47678 L 1 g
F P
s
P
p
.45796 .47662 m .45384 .48046 L .45762 .47678 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44188 .4921 L p
1 g
F P
s
P
p
.002 w
.44188 .4921 m .44263 .49131 L p
.44922 .48496 L 1 g
F P
s
P
p
.44922 .48496 m .45698 .47747 L .44188 .4921 L 1 g
F
P
p
.002 w
.44263 .49131 m .44339 .4905 L p
.45087 .48334 L 1 g
F P
s
P
p
.45087 .48334 m .45698 .47747 L .44263 .49131 L 1 g
F
P
p
.43589 .50508 m .44166 .49233 L .43362 .50972 L 1 g
F
P
p
.43843 .49989 m .43863 .49943 L .43589 .50508 L 1 g
F
P
p
.43863 .49943 m .44166 .49233 L .43589 .50508 L 1 g
F
P
p
.4341 .50878 m .43589 .50508 L .43407 .5088 L 1 g
F
P
p
.002 w
.43362 .50972 m .43369 .50964 L p
.43407 .5088 L 1 g
F P
s
P
p
.002 w
.44678 .51328 m .43556 .50954 L .43589 .50508 L p
1 g
F P
s
P
p
.44203 .49252 m .44678 .51328 L .43589 .50508 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43362 .50972 L p
1 g
F P
s
P
p
.45087 .48334 m .45384 .48046 L .45199 .48226 L 1 g
F
P
p
.44339 .4905 m .45384 .48046 L .45087 .48334 L 1 g
F
P
p
.002 w
.43809 .47528 m .45384 .48046 L p
.44191 .492 L 1 g
F P
s
P
p
.002 w
.45762 .47678 m .45698 .47747 L p
.45199 .48226 L 1 g
F P
s
P
p
.002 w
.43809 .47528 m .44258 .43921 L p
.45791 .4765 L 1 g
F P
s
P
p
.45791 .4765 m .45796 .47662 L .4578 .4766 L 1 g
F
P
p
.45791 .4765 m .4578 .4766 L .43809 .47528 L 1 g
F
P
p
.002 w
.4515 .47969 m .43809 .47528 L p
.45796 .47662 L 1 g
F P
s
P
p
.45826 .47608 m .46781 .47189 L .46467 .47343 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44258 .43921 m .47551 .4499 L .46467 .47343 L p
1 g
F P
s
P
p
.002 w
.46467 .47343 m .46043 .48262 L p
.45796 .47662 L 1 g
F P
s
P
p
.44258 .43921 m .46467 .47343 L .45796 .47662 L 1 g
F
P
p
.46467 .47343 m .47718 .46778 L .45747 .47694 L 1 g
F
P
p
.46781 .47189 m .46888 .47142 L .46467 .47343 L 1 g
F
P
p
.46888 .47142 m .47718 .46778 L .46467 .47343 L 1 g
F
P
p
.002 w
.45747 .47694 m .45762 .47678 L p
.46467 .47343 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45747 .47694 L p
1 g
F P
s
P
p
.002 w
.46467 .47343 m .46688 .46863 L p
.46838 .47162 L 1 g
F P
s
P
p
.002 w
.46688 .46863 m .47551 .4499 L p
.47736 .46715 L 1 g
F P
s
P
p
.002 w
.47733 .46755 m .47759 .46712 L p
.49134 .4653 L 1 g
F P
s
P
p
.002 w
.47759 .46712 m .47786 .46667 L p
.48828 .46561 L 1 g
F P
s
P
p
.48828 .46561 m .49134 .4653 L .47759 .46712 L 1 g
F
P
p
.002 w
.47759 .46712 m .47718 .46778 L p
.46781 .47189 L 1 g
F P
s
P
p
.47736 .46715 m .4775 .46716 L .47737 .46722 L 1 g
F
P
p
.47786 .46667 m .5 .46391 L .49134 .4653 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47551 .4499 m .49749 .46431 L p
.47736 .46715 L 1 g
F P
s
P
p
.49134 .4653 m .49749 .46431 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46391 m .5 .46396 L p
.49749 .46431 L 1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .46442 L p
.49749 .46431 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .4634 L p
.50844 .46524 L 1 g
F P
s
P
p
.002 w
.49589 .46326 m .47551 .4499 L p
.50199 .46359 L 1 g
F P
s
P
p
.50375 .4645 m .5 .46391 L .50199 .46359 L 1 g
F
P
p
.5 .46391 m .49589 .46326 L .50199 .46359 L 1 g
F
P
p
.002 w
.49749 .46431 m .49589 .46326 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47733 .46755 L p
1 g
F P
s
P
p
.49134 .4653 m .5 .46442 L .47733 .46755 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.49146 .41636 m .52947 .44134 L .50844 .46524 L p
1 g
F P
s
P
p
.002 w
.50844 .46524 m .50495 .46921 L p
.50375 .4645 L 1 g
F P
s
P
p
.49146 .41636 m .50844 .46524 L .50375 .4645 L 1 g
F
P
p
.51342 .46589 m .52734 .49478 L .50844 .46524 L 1 g
F
P
p
.50844 .46524 m .52282 .46778 L .5 .46413 L 1 g
F
P
p
.51195 .4657 m .5147 .46622 L .50844 .46524 L 1 g
F
P
p
.5147 .46622 m .52282 .46778 L .50844 .46524 L 1 g
F
P
p
.002 w
.5 .46413 m .5 .46391 L p
.50844 .46524 L 1 g
F P
s
P
p
.002 w
.47551 .4499 m .49146 .41636 L p
.50375 .4645 L 1 g
F P
s
P
p
.002 w
.50844 .46524 m .51146 .46181 L p
.51342 .46589 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46413 L p
1 g
F P
s
P
p
.002 w
.52237 .46706 m .52282 .46778 L p
.51195 .4657 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46706 L p
1 g
F P
s
P
p
.002 w
.52237 .46706 m .52214 .46667 L p
.52972 .4706 L 1 g
F P
s
P
p
.52972 .4706 m .54302 .47747 L .52237 .46706 L 1 g
F
P
p
.002 w
.51146 .46181 m .52947 .44134 L p
.52833 .46993 L 1 g
F P
s
P
p
.52859 .46333 m .54223 .47661 L .52833 .46993 L 1 g
F
P
p
.002 w
.54223 .47661 m .54302 .47747 L p
.52972 .4706 L 1 g
F P
s
P
p
.002 w
.54252 .47693 m .54223 .47661 L p
.54736 .48161 L 1 g
F P
s
P
p
.002 w
.54223 .47661 m .54174 .47608 L p
.54736 .48161 L 1 g
F P
s
P
p
.002 w
.52947 .44134 m .55817 .4745 L .54736 .48161 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.52947 .44134 m .54736 .48161 L .52859 .46333 L 1 g
F
P
p
.002 w
.54736 .48161 m .55817 .4745 L p
.55339 .48745 L 1 g
F P
s
P
p
.55339 .48745 m .54011 .52347 L .54736 .48161 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54252 .47693 L p
1 g
F P
s
P
p
.54977 .48394 m .55834 .49233 L .54252 .47693 L 1 g
F
P
p
.002 w
.55722 .49115 m .55834 .49233 L p
.54977 .48394 L 1 g
F P
s
P
p
.002 w
.56602 .5093 m .56713 .51061 L p
.5607 .49833 L 1 g
F P
s
P
p
.002 w
.56636 .5097 m .56602 .5093 L p
.56657 .5143 L 1 g
F P
s
P
p
.002 w
.54201 .55186 m .54011 .52347 L .56657 .5143 L p
1 g
F P
s
P
p
.002 w
.56657 .5143 m .57423 .51164 L p
.56687 .52083 L 1 g
F P
s
P
p
.56687 .52083 m .54201 .55186 L .56657 .5143 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56636 .5097 L p
1 g
F P
s
P
p
.56678 .51882 m .56854 .53025 L .56636 .5097 L 1 g
F
P
p
.002 w
.56722 .52833 m .56854 .53025 L p
.56678 .51882 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56722 .52833 L p
1 g
F P
s
P
p
.56506 .53546 m .56257 .5491 L .56722 .52833 L 1 g
F
P
p
.002 w
.56152 .54712 m .56257 .5491 L p
.56506 .53546 L 1 g
F P
s
P
p
.002 w
.56171 .54747 m .56152 .54712 L p
.55961 .54998 L 1 g
F P
s
P
p
.54854 .56129 m .53281 .57432 L .53442 .57332 L 1 g
F
P
p
.54084 .56863 m .53442 .57332 L .53868 .57069 L 1 g
F
P
p
.54854 .56129 m .53442 .57332 L .54084 .56863 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53442 .57332 m .54201 .55186 L .55961 .54998 L p
1 g
F P
s
P
p
.002 w
.55961 .54998 m .56751 .54914 L p
.54904 .56264 L 1 g
F P
s
P
p
.002 w
.53321 .57675 m .53442 .57332 L p
.54586 .56644 L 1 g
F P
s
P
p
.54229 .57072 m .53321 .57675 L .54586 .56644 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.54904 .56264 m .53442 .57332 L .55961 .54998 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56171 .54747 L p
1 g
F P
s
P
p
.55595 .55436 m .54998 .56518 L .56171 .54747 L 1 g
F
P
p
.002 w
.54904 .56264 m .54998 .56518 L p
.55595 .55436 L 1 g
F P
s
P
p
.53868 .57069 m .53287 .57446 L .53643 .57283 L 1 g
F
P
p
.53287 .57446 m .53182 .57514 L .53219 .57495 L 1 g
F
P
p
.53287 .57446 m .53219 .57495 L .53643 .57283 L 1 g
F
P
p
.53281 .57432 m .53182 .57514 L .53868 .57069 L 1 g
F
P
p
.002 w
.53008 .57601 m .52918 .57579 L p
.53178 .57495 L 1 g
F P
s
P
p
.002 w
.53321 .57675 m .53053 .57953 L p
.49846 .58081 L 1 g
F P
s
P
p
.52918 .57579 m .51111 .583 L .53182 .57514 L 1 g
F
P
p
.52141 .57771 m .51843 .57924 L .52918 .57579 L 1 g
F
P
p
.51843 .57924 m .51111 .583 L .52918 .57579 L 1 g
F
P
p
.53442 .57332 m .53178 .57495 L .5005 .56894 L 1 g
F
P
p
.002 w
.52918 .57579 m .5005 .56894 L p
.53178 .57495 L 1 g
F P
s
P
p
.002 w
.53182 .57514 m .53178 .57495 L p
.52918 .57579 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54201 .55186 m .53442 .57332 L p
.5005 .56894 L 1 g
F P
s
P
p
.002 w
.53178 .57495 m .53182 .57514 L p
.53281 .57432 L 1 g
F P
s
P
p
.002 w
.53182 .57514 m .5322 .57686 L p
.53643 .57283 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53182 .57514 L p
1 g
F P
s
P
p
.002 w
.5005 .56894 m .52918 .57579 L p
.49846 .58081 L 1 g
F P
s
P
p
.51822 .5785 m .49846 .58081 L .52918 .57579 L 1 g
F
P
p
.002 w
.48826 .582 m .48902 .58119 L p
.49846 .58081 L 1 g
F P
s
P
p
.002 w
.48902 .58119 m .5005 .56894 L p
.49846 .58081 L 1 g
F P
s
P
p
.002 w
.52341 .58691 m .51505 .59558 L p
.49158 .58161 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58031 L p
1 g
F P
s
P
p
.50018 .58074 m .48889 .583 L .51092 .58031 L 1 g
F
P
p
.50018 .58074 m .48902 .58119 L .49564 .58165 L 1 g
F
P
p
.002 w
.51092 .58031 m .51111 .583 L p
.52141 .57771 L 1 g
F P
s
P
p
.002 w
.48902 .58119 m .48889 .583 L p
.49564 .58165 L 1 g
F P
s
P
p
.002 w
.5005 .56894 m .48902 .58119 L p
.46126 .56354 L 1 g
F P
s
P
p
.002 w
.48554 .58014 m .46126 .56354 L p
.48902 .58119 L 1 g
F P
s
P
p
.45782 .56829 m .45002 .56518 L .46831 .57451 L 1 g
F
P
p
.002 w
.4678 .57686 m .4742 .57872 L p
.48105 .57868 L 1 g
F P
s
P
p
.47809 .57771 m .4678 .57686 L .48105 .57868 L 1 g
F
P
p
.002 w
.4742 .57872 m .48889 .583 L .48902 .58119 L p
1 g
F P
s
P
p
.002 w
.51505 .59558 m .53321 .57675 L .56435 .58007 L p
1 g
F P
s
P
p
.002 w
.56279 .27982 m .62119 .31849 L .60926 .33774 L p
1 g
F P
s
P
p
.002 w
.65201 .38914 m .60926 .33774 L .62119 .31849 L p
1 g
F P
s
P
p
.004 w
.45 .51538 m
.46683 .48681 L
s
P
p
.002 w
.60926 .33774 m .55146 .29951 L .56279 .27982 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.57617 .54821 m .56435 .58007 L .53321 .57675 L p
1 g
F P
s
P
p
.002 w
.56435 .58007 m .57617 .54821 L .60748 .54109 L p
1 g
F P
s
P
p
.002 w
.44203 .56856 m .4525 .56759 L .47097 .58974 L p
1 g
F P
s
P
p
.002 w
.38237 .49181 m .37436 .5077 L .34991 .48783 L p
1 g
F P
s
P
p
.002 w
.34991 .48783 m .36126 .46441 L .38237 .49181 L p
1 g
F P
s
P
p
.002 w
.63473 .40949 m .6567 .46433 L .63353 .48147 L p
1 g
F P
s
P
p
.002 w
.6567 .46433 m .63473 .40949 L .65201 .38914 L p
1 g
F P
s
P
p
.004 w
.63779 .45963 m
.68366 .46932 L
s
P
p
.002 w
.40685 .36679 m .36402 .38145 L .36126 .35117 L p
1 g
F P
s
P
p
.002 w
.36126 .35117 m .40949 .33407 L .40685 .36679 L p
1 g
F P
s
P
p
.002 w
.40306 .52557 m .40244 .53495 L .37339 .52613 L p
1 g
F P
s
P
p
.002 w
.37339 .52613 m .37436 .5077 L .40306 .52557 L p
1 g
F P
s
P
p
.002 w
.60926 .33774 m .65201 .38914 L .63473 .40949 L p
1 g
F P
s
P
p
.002 w
.38201 .44719 m .36126 .46441 L .34463 .43641 L p
1 g
F P
s
P
p
.002 w
.34463 .43641 m .37099 .41383 L .38201 .44719 L p
1 g
F P
s
P
p
.002 w
.60575 .49745 m .60748 .54109 L .57617 .54821 L p
1 g
F P
s
P
p
.002 w
.60748 .54109 m .60575 .49745 L .63353 .48147 L p
1 g
F P
s
P
p
.002 w
.46586 .33416 m .40949 .33407 L .41479 .30496 L p
1 g
F P
s
P
p
.002 w
.41479 .30496 m .47584 .30463 L .46586 .33416 L p
1 g
F P
s
P
p
.002 w
.5382 .32384 m .47584 .30463 L .4863 .27963 L p
1 g
F P
s
P
p
.002 w
.4863 .27963 m .55146 .29951 L .5382 .32384 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40726 .51758 m .40306 .52557 L .37436 .5077 L p
1 g
F P
s
P
p
.002 w
.37436 .5077 m .38237 .49181 L .40726 .51758 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40706 .40198 m .37099 .41383 L .36402 .38145 L p
1 g
F P
s
P
p
.002 w
.36402 .38145 m .40685 .36679 L .40706 .40198 L p
1 g
F P
s
P
p
.002 w
.55146 .29951 m .60926 .33774 L .5936 .36044 L p
1 g
F P
s
P
p
.002 w
.63473 .40949 m .5936 .36044 L .60926 .33774 L p
1 g
F P
s
P
p
.002 w
.61285 .43102 m .63353 .48147 L .60575 .49745 L p
1 g
F P
s
P
p
.004 w
.51915 .43456 m
.61041 .45384 L
s
P
p
.002 w
.63353 .48147 m .61285 .43102 L .63473 .40949 L p
1 g
F P
s
P
p
.004 w
.61337 .45447 m
.6143 .45467 L
s
P
p
.004 w
.61891 .45564 m
.63779 .45963 L
s
P
p
.004 w
.6143 .45467 m
.61891 .45564 L
s
P
p
.002 w
.39674 .48027 m .38237 .49181 L .36126 .46441 L p
1 g
F P
s
P
p
.002 w
.36126 .46441 m .38201 .44719 L .39674 .48027 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.5936 .36044 m .5382 .32384 L .55146 .29951 L p
1 g
F P
s
P
p
.002 w
.57617 .54821 m .57423 .51164 L .60575 .49745 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46126 .56354 m .46737 .55681 L .5005 .56894 L p
1 g
F P
s
P
p
.002 w
.50623 .55183 m .5005 .56894 L .46737 .55681 L p
1 g
F P
s
P
p
.002 w
.5005 .56894 m .50623 .55183 L .54201 .55186 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.5936 .36044 m .63473 .40949 L .61285 .43102 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.41465 .51185 m .40726 .51758 L .38237 .49181 L p
1 g
F P
s
P
p
.002 w
.38237 .49181 m .39674 .48027 L .41465 .51185 L p
1 g
F P
s
P
p
.002 w
.45675 .36727 m .40685 .36679 L .40949 .33407 L p
1 g
F P
s
P
p
.002 w
.40949 .33407 m .46586 .33416 L .45675 .36727 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.46737 .55681 m .47013 .54808 L .50623 .55183 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41014 .43835 m .38201 .44719 L .37099 .41383 L p
1 g
F P
s
P
p
.002 w
.37099 .41383 m .40706 .40198 L .41014 .43835 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.54011 .52347 m .54201 .55186 L .50623 .55183 L p
1 g
F P
s
P
p
.002 w
.52342 .35211 m .46586 .33416 L .47584 .30463 L p
1 g
F P
s
P
p
.002 w
.47584 .30463 m .5382 .32384 L .52342 .35211 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58703 .45297 m .60575 .49745 L .57423 .51164 L p
1 g
F P
s
P
p
.002 w
.60575 .49745 m .58703 .45297 L .61285 .43102 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.50464 .53246 m .50623 .55183 L .47013 .54808 L p
1 g
F P
s
P
p
.002 w
.50623 .55183 m .50464 .53246 L .54011 .52347 L p
1 g
F P
s
P
p
.002 w
.47013 .54808 m .46918 .53828 L .50464 .53246 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.41602 .4745 m .39674 .48027 L .38201 .44719 L p
1 g
F P
s
P
p
.002 w
.38201 .44719 m .41014 .43835 L .41602 .4745 L p
1 g
F P
s
P
p
.002 w
.42444 .50906 m .41465 .51185 L .39674 .48027 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5382 .32384 m .5936 .36044 L .57464 .38589 L p
1 g
F P
s
P
p
.002 w
.61285 .43102 m .57464 .38589 L .5936 .36044 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.39674 .48027 m .41602 .4745 L .42444 .50906 L p
1 g
F P
s
P
p
.002 w
.57464 .38589 m .52342 .35211 L .5382 .32384 L p
1 g
F P
s
P
p
.002 w
.44888 .40274 m .40706 .40198 L .40685 .36679 L p
1 g
F P
s
P
p
.002 w
.40685 .36679 m .45675 .36727 L .44888 .40274 L p
1 g
F P
s
P
p
.002 w
.57464 .38589 m .61285 .43102 L .58703 .45297 L p
1 g
F P
s
P
p
.002 w
.46918 .53828 m .46458 .52851 L .49574 .51301 L p
1 g
F P
s
P
p
.002 w
.49574 .51301 m .50464 .53246 L .46918 .53828 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57423 .51164 m .55817 .4745 L .58703 .45297 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46458 .52851 m .45683 .51984 L .48043 .49571 L p
1 g
F P
s
P
p
.002 w
.48043 .49571 m .49574 .51301 L .46458 .52851 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50764 .38334 m .45675 .36727 L .46586 .33416 L p
1 g
F P
s
P
p
.002 w
.46586 .33416 m .52342 .35211 L .50764 .38334 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.50464 .53246 m .49574 .51301 L .52734 .49478 L p
1 g
F P
s
P
p
.002 w
.52734 .49478 m .54011 .52347 L .50464 .53246 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.45683 .51984 m .44678 .51328 L .46043 .48262 L p
1 g
F P
s
P
p
.002 w
.46043 .48262 m .48043 .49571 L .45683 .51984 L p
1 g
F P
s
P
p
.002 w
.44258 .43921 m .41014 .43835 L .40706 .40198 L p
1 g
F P
s
P
p
.002 w
.40706 .40198 m .44888 .40274 L .44258 .43921 L p
1 g
F P
s
P
p
.002 w
.43809 .47528 m .41602 .4745 L .41014 .43835 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.41014 .43835 m .44258 .43921 L .43809 .47528 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.553 .4132 m .58703 .45297 L .55817 .4745 L p
1 g
F P
s
P
p
.002 w
.58703 .45297 m .553 .4132 L .57464 .38589 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52342 .35211 m .57464 .38589 L .553 .4132 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.49574 .51301 m .48043 .49571 L .50495 .46921 L p
1 g
F P
s
P
p
.002 w
.50495 .46921 m .52734 .49478 L .49574 .51301 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.553 .4132 m .50764 .38334 L .52342 .35211 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49146 .41636 m .44888 .40274 L .45675 .36727 L p
1 g
F P
s
P
p
.002 w
.45675 .36727 m .50764 .38334 L .49146 .41636 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.55817 .4745 m .52947 .44134 L .553 .4132 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.47551 .4499 m .44258 .43921 L .44888 .40274 L p
1 g
F P
s
P
p
.002 w
.44888 .40274 m .49146 .41636 L .47551 .4499 L p
1 g
F P
s
P
p
.002 w
.50764 .38334 m .553 .4132 L .52947 .44134 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52947 .44134 m .49146 .41636 L .50764 .38334 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.004 w
.40813 .58644 m
.41321 .57782 L
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .68366 .46932 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39638 .60638 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.222481)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.222481)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45417 .42347 m .4762 .45059 L .49544 .42958 L p
1 g
F P
s
P
p
.002 w
.49544 .42958 m .47845 .40858 L .45417 .42347 L p
1 g
F P
s
P
p
.002 w
.51784 .44481 m .49544 .42958 L .4762 .45059 L p
1 g
F P
s
P
p
.002 w
.47845 .40858 m .49544 .42958 L .51478 .40861 L p
1 g
F P
s
P
p
.002 w
.49544 .42958 m .51784 .44481 L .53009 .419 L p
1 g
F P
s
P
p
.002 w
.53009 .419 m .51478 .40861 L .49544 .42958 L p
1 g
F P
s
P
p
.002 w
.4762 .45059 m .50514 .4703 L .51784 .44481 L p
1 g
F P
s
P
p
.002 w
.54339 .45271 m .51784 .44481 L .50514 .4703 L p
1 g
F P
s
P
p
.002 w
.51784 .44481 m .54339 .45271 L .54755 .42432 L p
1 g
F P
s
P
p
.002 w
.54755 .42432 m .53009 .419 L .51784 .44481 L p
1 g
F P
s
P
p
.002 w
.51478 .40861 m .50321 .39425 L .47845 .40858 L p
1 g
F P
s
P
p
.002 w
.50321 .39425 m .51478 .40861 L .53388 .38805 L p
1 g
F P
s
P
p
.002 w
.51478 .40861 m .53009 .419 L .54168 .39333 L p
1 g
F P
s
P
p
.002 w
.54168 .39333 m .53388 .38805 L .51478 .40861 L p
1 g
F P
s
P
p
.002 w
.44127 .39157 m .45417 .42347 L .47845 .40858 L p
1 g
F P
s
P
p
.002 w
.47845 .40858 m .46859 .38389 L .44127 .39157 L p
1 g
F P
s
P
p
.002 w
.46859 .38389 m .47845 .40858 L .50321 .39425 L p
1 g
F P
s
P
p
.002 w
.43082 .43865 m .4574 .47125 L .4762 .45059 L p
1 g
F P
s
P
p
.002 w
.4762 .45059 m .45417 .42347 L .43082 .43865 L p
1 g
F P
s
P
p
.002 w
.50514 .4703 m .4762 .45059 L .4574 .47125 L p
1 g
F P
s
P
p
.002 w
.53009 .419 m .54755 .42432 L .55057 .396 L p
1 g
F P
s
P
p
.002 w
.55057 .396 m .54168 .39333 L .53009 .419 L p
1 g
F P
s
P
p
.002 w
.50321 .39425 m .49656 .37737 L .46859 .38389 L p
1 g
F P
s
P
p
.002 w
.49656 .37737 m .50321 .39425 L .528 .38073 L p
1 g
F P
s
P
p
.002 w
.53388 .38805 m .528 .38073 L .50321 .39425 L p
1 g
F P
s
P
p
.002 w
.4574 .47125 m .49222 .49502 L .50514 .4703 L p
1 g
F P
s
P
p
.002 w
.53816 .48065 m .50514 .4703 L .49222 .49502 L p
1 g
F P
s
P
p
.002 w
.50514 .4703 m .53816 .48065 L .54339 .45271 L p
1 g
F P
s
P
p
.002 w
.4151 .40029 m .43082 .43865 L .45417 .42347 L p
1 g
F P
s
P
p
.002 w
.45417 .42347 m .44127 .39157 L .4151 .40029 L p
1 g
F P
s
P
p
.002 w
.56537 .42399 m .54755 .42432 L .54339 .45271 L p
1 g
F P
s
P
p
.002 w
.54755 .42432 m .56537 .42399 L .55962 .39578 L p
1 g
F P
s
P
p
.002 w
.55962 .39578 m .55057 .396 L .54755 .42432 L p
1 g
F P
s
P
p
.002 w
.56954 .4524 m .54339 .45271 L .53816 .48065 L p
1 g
F P
s
P
p
.002 w
.54339 .45271 m .56954 .4524 L .56537 .42399 L p
1 g
F P
s
P
p
.002 w
.46698 .35798 m .46859 .38389 L .49656 .37737 L p
1 g
F P
s
P
p
.002 w
.49656 .37737 m .49559 .35972 L .46698 .35798 L p
1 g
F P
s
P
p
.002 w
.49559 .35972 m .49656 .37737 L .52466 .37213 L p
1 g
F P
s
P
p
.002 w
.528 .38073 m .52466 .37213 L .49656 .37737 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .528 .38073 L .53388 .38805 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .53388 .38805 L .54168 .39333 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .54168 .39333 L .55057 .396 L closepath p
1 g
F P
s
P
p
.002 w
.43894 .35802 m .44127 .39157 L .46859 .38389 L p
1 g
F P
s
P
p
.002 w
.46859 .38389 m .46698 .35798 L .43894 .35802 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .52466 .37213 L .528 .38073 L closepath p
1 g
F P
s
P
p
.002 w
.40884 .45383 m .4394 .49119 L .4574 .47125 L p
1 g
F P
s
P
p
.002 w
.4574 .47125 m .43082 .43865 L .40884 .45383 L p
1 g
F P
s
P
p
.002 w
.49222 .49502 m .4574 .47125 L .4394 .49119 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .55057 .396 L .55962 .39578 L closepath p
1 g
F P
s
P
p
.002 w
.49222 .49502 m .53195 .50764 L .53816 .48065 L p
1 g
F P
s
P
p
.002 w
.57203 .48047 m .53816 .48065 L .53195 .50764 L p
1 g
F P
s
P
p
.002 w
.53816 .48065 m .57203 .48047 L .56954 .4524 L p
1 g
F P
s
P
p
.002 w
.52466 .37213 m .52423 .36317 L .49559 .35972 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .52423 .36317 L .52466 .37213 L closepath p
1 g
F P
s
P
p
.002 w
.4394 .49119 m .47931 .51849 L .49222 .49502 L p
1 g
F P
s
P
p
.002 w
.53195 .50764 m .49222 .49502 L .47931 .51849 L p
1 g
F P
s
P
p
.002 w
.58168 .41799 m .56537 .42399 L .56954 .4524 L p
1 g
F P
s
P
p
.002 w
.56537 .42399 m .58168 .41799 L .56786 .39267 L p
1 g
F P
s
P
p
.002 w
.56786 .39267 m .55962 .39578 L .56537 .42399 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .55962 .39578 L .56786 .39267 L closepath p
1 g
F P
s
P
p
.002 w
.39061 .40989 m .40884 .45383 L .43082 .43865 L p
1 g
F P
s
P
p
.002 w
.43082 .43865 m .4151 .40029 L .39061 .40989 L p
1 g
F P
s
P
p
.002 w
.41202 .35984 m .4151 .40029 L .44127 .39157 L p
1 g
F P
s
P
p
.002 w
.44127 .39157 m .43894 .35802 L .41202 .35984 L p
1 g
F P
s
P
p
.002 w
.47393 .33354 m .46698 .35798 L .49559 .35972 L p
1 g
F P
s
P
p
.002 w
.49559 .35972 m .50046 .34314 L .47393 .33354 L p
1 g
F P
s
P
p
.002 w
.50046 .34314 m .49559 .35972 L .52423 .36317 L p
1 g
F P
s
P
p
.002 w
.52423 .36317 m .52678 .3548 L .50046 .34314 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .52678 .3548 L .52423 .36317 L closepath p
1 g
F P
s
P
p
.002 w
.59359 .44377 m .56954 .4524 L .57203 .48047 L p
1 g
F P
s
P
p
.002 w
.56954 .4524 m .59359 .44377 L .58168 .41799 L p
1 g
F P
s
P
p
.002 w
.57439 .38697 m .56786 .39267 L .58168 .41799 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .56786 .39267 L .57439 .38697 L closepath p
1 g
F P
s
P
p
.002 w
.44769 .32622 m .43894 .35802 L .46698 .35798 L p
1 g
F P
s
P
p
.002 w
.46698 .35798 m .47393 .33354 L .44769 .32622 L p
1 g
F P
s
P
p
.002 w
.51075 .32943 m .50046 .34314 L .52678 .3548 L p
1 g
F P
s
P
p
.002 w
.52678 .3548 m .53204 .34792 L .51075 .32943 L p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .53204 .34792 L .52678 .3548 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .57789 .36143 L .57319 .3532 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .57319 .3532 L .56615 .3467 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .56615 .3467 L .55753 .34264 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .55753 .34264 L .5483 .34147 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .5483 .34147 L .53948 .3433 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .53948 .3433 L .53204 .34792 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .57439 .38697 L .57851 .3793 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .57851 .3793 L .57973 .37046 L closepath p
1 g
F P
s
P
p
.002 w
.55238 .36828 m .57973 .37046 L .57789 .36143 L closepath p
1 g
F P
s
P
p
.002 w
.59472 .40685 m .58168 .41799 L .59359 .44377 L p
1 g
F P
s
P
p
.002 w
.58168 .41799 m .59472 .40685 L .57439 .38697 L p
1 g
F P
s
P
p
.002 w
.47931 .51849 m .52485 .53313 L .53195 .50764 L p
1 g
F P
s
P
p
.002 w
.57278 .50767 m .53195 .50764 L .52485 .53313 L p
1 g
F P
s
P
p
.002 w
.53195 .50764 m .57278 .50767 L .57203 .48047 L p
1 g
F P
s
P
p
.002 w
.38868 .46875 m .42256 .51 L .4394 .49119 L p
1 g
F P
s
P
p
.002 w
.4394 .49119 m .40884 .45383 L .38868 .46875 L p
1 g
F P
s
P
p
.002 w
.47931 .51849 m .4394 .49119 L .42256 .51 L p
1 g
F P
s
P
p
.002 w
.57851 .3793 m .57439 .38697 L .59472 .40685 L p
1 g
F P
s
P
p
.002 w
.48891 .3132 m .47393 .33354 L .50046 .34314 L p
1 g
F P
s
P
p
.002 w
.50046 .34314 m .51075 .32943 L .48891 .3132 L p
1 g
F P
s
P
p
.002 w
.60332 .46954 m .57203 .48047 L .57278 .50767 L p
1 g
F P
s
P
p
.002 w
.57203 .48047 m .60332 .46954 L .59359 .44377 L p
1 g
F P
s
P
p
.002 w
.52543 .32014 m .51075 .32943 L .53204 .34792 L p
1 g
F P
s
P
p
.002 w
.53204 .34792 m .53948 .3433 L .52543 .32014 L p
1 g
F P
s
P
p
.002 w
.38677 .36348 m .39061 .40989 L .4151 .40029 L p
1 g
F P
s
P
p
.002 w
.4151 .40029 m .41202 .35984 L .38677 .36348 L p
1 g
F P
s
P
p
.002 w
.42256 .51 m .46667 .54025 L .47931 .51849 L p
1 g
F P
s
P
p
.002 w
.52485 .53313 m .47931 .51849 L .46667 .54025 L p
1 g
F P
s
P
p
.002 w
.59472 .40685 m .60301 .39171 L .57851 .3793 L p
1 g
F P
s
P
p
.002 w
.57973 .37046 m .57851 .3793 L .60301 .39171 L p
1 g
F P
s
P
p
.002 w
.36832 .42022 m .38868 .46875 L .40884 .45383 L p
1 g
F P
s
P
p
.002 w
.40884 .45383 m .39061 .40989 L .36832 .42022 L p
1 g
F P
s
P
p
.002 w
.61294 .42756 m .59359 .44377 L .60332 .46954 L p
1 g
F P
s
P
p
.002 w
.59359 .44377 m .61294 .42756 L .59472 .40685 L p
1 g
F P
s
P
p
.002 w
.42227 .32137 m .41202 .35984 L .43894 .35802 L p
1 g
F P
s
P
p
.002 w
.43894 .35802 m .44769 .32622 L .42227 .32137 L p
1 g
F P
s
P
p
.002 w
.54294 .31637 m .52543 .32014 L .53948 .3433 L p
1 g
F P
s
P
p
.002 w
.53948 .3433 m .5483 .34147 L .54294 .31637 L p
1 g
F P
s
P
p
.002 w
.60301 .39171 m .59472 .40685 L .61294 .42756 L p
1 g
F P
s
P
p
.002 w
.60301 .39171 m .60556 .37417 L .57973 .37046 L p
1 g
F P
s
P
p
.002 w
.57789 .36143 m .57973 .37046 L .60556 .37417 L p
1 g
F P
s
P
p
.002 w
.46692 .29961 m .44769 .32622 L .47393 .33354 L p
1 g
F P
s
P
p
.002 w
.47393 .33354 m .48891 .3132 L .46692 .29961 L p
1 g
F P
s
P
p
.002 w
.56135 .31862 m .54294 .31637 L .5483 .34147 L p
1 g
F P
s
P
p
.002 w
.5483 .34147 m .55753 .34264 L .56135 .31862 L p
1 g
F P
s
P
p
.002 w
.51047 .2993 m .48891 .3132 L .51075 .32943 L p
1 g
F P
s
P
p
.002 w
.51075 .32943 m .52543 .32014 L .51047 .2993 L p
1 g
F P
s
P
p
.002 w
.57319 .3532 m .57789 .36143 L .60201 .35616 L p
1 g
F P
s
P
p
.002 w
.60556 .37417 m .60201 .35616 L .57789 .36143 L p
1 g
F P
s
P
p
.002 w
.57859 .3267 m .56135 .31862 L .55753 .34264 L p
1 g
F P
s
P
p
.002 w
.55753 .34264 m .56615 .3467 L .57859 .3267 L p
1 g
F P
s
P
p
.002 w
.46667 .54025 m .51698 .55661 L .52485 .53313 L p
1 g
F P
s
P
p
.002 w
.57173 .53345 m .52485 .53313 L .51698 .55661 L p
1 g
F P
s
P
p
.002 w
.52485 .53313 m .57173 .53345 L .57278 .50767 L p
1 g
F P
s
P
p
.002 w
.61064 .49477 m .57278 .50767 L .57173 .53345 L p
1 g
F P
s
P
p
.002 w
.57278 .50767 m .61064 .49477 L .60332 .46954 L p
1 g
F P
s
P
p
.002 w
.60201 .35616 m .59267 .3397 L .57319 .3532 L p
1 g
F P
s
P
p
.002 w
.56615 .3467 m .57319 .3532 L .59267 .3397 L p
1 g
F P
s
P
p
.002 w
.59267 .3397 m .57859 .3267 L .56615 .3467 L p
1 g
F P
s
P
p
.002 w
.61294 .42756 m .62537 .40532 L .60301 .39171 L p
1 g
F P
s
P
p
.002 w
.60556 .37417 m .60301 .39171 L .62537 .40532 L p
1 g
F P
s
P
p
.002 w
.62865 .44869 m .60332 .46954 L .61064 .49477 L p
1 g
F P
s
P
p
.002 w
.60332 .46954 m .62865 .44869 L .61294 .42756 L p
1 g
F P
s
P
p
.002 w
.37081 .48308 m .40723 .52729 L .42256 .51 L p
1 g
F P
s
P
p
.002 w
.42256 .51 m .38868 .46875 L .37081 .48308 L p
1 g
F P
s
P
p
.002 w
.46667 .54025 m .42256 .51 L .40723 .52729 L p
1 g
F P
s
P
p
.002 w
.36377 .3689 m .36832 .42022 L .39061 .40989 L p
1 g
F P
s
P
p
.002 w
.39061 .40989 m .38677 .36348 L .36377 .3689 L p
1 g
F P
s
P
p
.002 w
.39821 .31919 m .38677 .36348 L .41202 .35984 L p
1 g
F P
s
P
p
.002 w
.41202 .35984 m .42227 .32137 L .39821 .31919 L p
1 g
F P
s
P
p
.002 w
.62537 .40532 m .61294 .42756 L .62865 .44869 L p
1 g
F P
s
P
p
.002 w
.53637 .29355 m .51047 .2993 L .52543 .32014 L p
1 g
F P
s
P
p
.002 w
.52543 .32014 m .54294 .31637 L .53637 .29355 L p
1 g
F P
s
P
p
.002 w
.40723 .52729 m .45455 .55979 L .46667 .54025 L p
1 g
F P
s
P
p
.002 w
.51698 .55661 m .46667 .54025 L .45455 .55979 L p
1 g
F P
s
P
p
.002 w
.44526 .28902 m .42227 .32137 L .44769 .32622 L p
1 g
F P
s
P
p
.002 w
.44769 .32622 m .46692 .29961 L .44526 .28902 L p
1 g
F P
s
P
p
.002 w
.34878 .4311 m .37081 .48308 L .38868 .46875 L p
1 g
F P
s
P
p
.002 w
.38868 .46875 m .36832 .42022 L .34878 .4311 L p
1 g
F P
s
P
p
.002 w
.49488 .28128 m .46692 .29961 L .48891 .3132 L p
1 g
F P
s
P
p
.002 w
.48891 .3132 m .51047 .2993 L .49488 .28128 L p
1 g
F P
s
P
p
.002 w
.62537 .40532 m .62933 .37939 L .60556 .37417 L p
1 g
F P
s
P
p
.002 w
.60201 .35616 m .60556 .37417 L .62933 .37939 L p
1 g
F P
s
P
p
.002 w
.56373 .29678 m .53637 .29355 L .54294 .31637 L p
1 g
F P
s
P
p
.002 w
.54294 .31637 m .56135 .31862 L .56373 .29678 L p
1 g
F P
s
P
p
.002 w
.51698 .55661 m .56884 .55724 L .57173 .53345 L p
1 g
F P
s
P
p
.002 w
.61532 .51895 m .57173 .53345 L .56884 .55724 L p
1 g
F P
s
P
p
.002 w
.57173 .53345 m .61532 .51895 L .61064 .49477 L p
1 g
F P
s
P
p
.002 w
.59267 .3397 m .60201 .35616 L .62418 .35263 L p
1 g
F P
s
P
p
.002 w
.62933 .37939 m .62418 .35263 L .60201 .35616 L p
1 g
F P
s
P
p
.002 w
.45455 .55979 m .50848 .57751 L .51698 .55661 L p
1 g
F P
s
P
p
.002 w
.56884 .55724 m .51698 .55661 L .50848 .57751 L p
1 g
F P
s
P
p
.002 w
.58939 .30875 m .56373 .29678 L .56135 .31862 L p
1 g
F P
s
P
p
.002 w
.56135 .31862 m .57859 .3267 L .58939 .30875 L p
1 g
F P
s
P
p
.002 w
.62865 .44869 m .64507 .41987 L .62537 .40532 L p
1 g
F P
s
P
p
.002 w
.62933 .37939 m .62537 .40532 L .64507 .41987 L p
1 g
F P
s
P
p
.002 w
.64145 .46984 m .61064 .49477 L .61532 .51895 L p
1 g
F P
s
P
p
.002 w
.61064 .49477 m .64145 .46984 L .62865 .44869 L p
1 g
F P
s
P
p
.002 w
.62418 .35263 m .61036 .32812 L .59267 .3397 L p
1 g
F P
s
P
p
.002 w
.57859 .3267 m .59267 .3397 L .61036 .32812 L p
1 g
F P
s
P
p
.002 w
.64507 .41987 m .62865 .44869 L .64145 .46984 L p
1 g
F P
s
P
p
.002 w
.61036 .32812 m .58939 .30875 L .57859 .3267 L p
1 g
F P
s
P
p
.002 w
.37611 .31981 m .36377 .3689 L .38677 .36348 L p
1 g
F P
s
P
p
.002 w
.38677 .36348 m .39821 .31919 L .37611 .31981 L p
1 g
F P
s
P
p
.002 w
.52868 .27358 m .49488 .28128 L .51047 .2993 L p
1 g
F P
s
P
p
.002 w
.51047 .2993 m .53637 .29355 L .52868 .27358 L p
1 g
F P
s
P
p
.002 w
.34361 .37607 m .34878 .4311 L .36832 .42022 L p
1 g
F P
s
P
p
.002 w
.36832 .42022 m .36377 .3689 L .34361 .37607 L p
1 g
F P
s
P
p
.002 w
.42439 .28178 m .39821 .31919 L .42227 .32137 L p
1 g
F P
s
P
p
.002 w
.42227 .32137 m .44526 .28902 L .42439 .28178 L p
1 g
F P
s
P
p
.002 w
.35571 .4965 m .39381 .54264 L .40723 .52729 L p
1 g
F P
s
P
p
.002 w
.40723 .52729 m .37081 .48308 L .35571 .4965 L p
1 g
F P
s
P
p
.002 w
.45455 .55979 m .40723 .52729 L .39381 .54264 L p
1 g
F P
s
P
p
.002 w
.47898 .26658 m .44526 .28902 L .46692 .29961 L p
1 g
F P
s
P
p
.002 w
.46692 .29961 m .49488 .28128 L .47898 .26658 L p
1 g
F P
s
P
p
.002 w
.39381 .54264 m .44321 .57662 L .45455 .55979 L p
1 g
F P
s
P
p
.002 w
.50848 .57751 m .45455 .55979 L .44321 .57662 L p
1 g
F P
s
P
p
.002 w
.64507 .41987 m .65045 .38605 L .62933 .37939 L p
1 g
F P
s
P
p
.002 w
.62418 .35263 m .62933 .37939 L .65045 .38605 L p
1 g
F P
s
P
p
.002 w
.33252 .4423 m .35571 .4965 L .37081 .48308 L p
1 g
F P
s
P
p
.002 w
.37081 .48308 m .34878 .4311 L .33252 .4423 L p
1 g
F P
s
P
p
.002 w
.56454 .27768 m .52868 .27358 L .53637 .29355 L p
1 g
F P
s
P
p
.002 w
.53637 .29355 m .56373 .29678 L .56454 .27768 L p
1 g
F P
s
P
p
.002 w
.50848 .57751 m .5641 .57845 L .56884 .55724 L p
1 g
F P
s
P
p
.002 w
.61718 .54151 m .56884 .55724 L .5641 .57845 L p
1 g
F P
s
P
p
.002 w
.56884 .55724 m .61718 .54151 L .61532 .51895 L p
1 g
F P
s
P
p
.002 w
.65097 .49054 m .61532 .51895 L .61718 .54151 L p
1 g
F P
s
P
p
.002 w
.61532 .51895 m .65097 .49054 L .64145 .46984 L p
1 g
F P
s
P
p
.002 w
.64145 .46984 m .66159 .43509 L .64507 .41987 L p
1 g
F P
s
P
p
.002 w
.65045 .38605 m .64507 .41987 L .66159 .43509 L p
1 g
F P
s
P
p
.002 w
.65045 .38605 m .64385 .35099 L .62418 .35263 L p
1 g
F P
s
P
p
.002 w
.61036 .32812 m .62418 .35263 L .64385 .35099 L p
1 g
F P
s
P
p
.002 w
.66159 .43509 m .64145 .46984 L .65097 .49054 L p
1 g
F P
s
P
p
.002 w
.44321 .57662 m .49949 .59528 L .50848 .57751 L p
1 g
F P
s
P
p
.002 w
.5641 .57845 m .50848 .57751 L .49949 .59528 L p
1 g
F P
s
P
p
.002 w
.59825 .29334 m .56454 .27768 L .56373 .29678 L p
1 g
F P
s
P
p
.002 w
.56373 .29678 m .58939 .30875 L .59825 .29334 L p
1 g
F P
s
P
p
.002 w
.51998 .25703 m .47898 .26658 L .49488 .28128 L p
1 g
F P
s
P
p
.002 w
.49488 .28128 m .52868 .27358 L .51998 .25703 L p
1 g
F P
s
P
p
.002 w
.35653 .32335 m .34361 .37607 L .36377 .3689 L p
1 g
F P
s
P
p
.002 w
.36377 .3689 m .37611 .31981 L .35653 .32335 L p
1 g
F P
s
P
p
.002 w
.64385 .35099 m .62578 .3188 L .61036 .32812 L p
1 g
F P
s
P
p
.002 w
.58939 .30875 m .61036 .32812 L .62578 .3188 L p
1 g
F P
s
P
p
.002 w
.40483 .2782 m .37611 .31981 L .39821 .31919 L p
1 g
F P
s
P
p
.002 w
.39821 .31919 m .42439 .28178 L .40483 .2782 L p
1 g
F P
s
P
p
.002 w
.62578 .3188 m .59825 .29334 L .58939 .30875 L p
1 g
F P
s
P
p
.002 w
.32688 .38491 m .33252 .4423 L .34878 .4311 L p
1 g
F P
s
P
p
.002 w
.34878 .4311 m .34361 .37607 L .32688 .38491 L p
1 g
F P
s
P
p
.002 w
.46309 .2557 m .42439 .28178 L .44526 .28902 L p
1 g
F P
s
P
p
.002 w
.44526 .28902 m .47898 .26658 L .46309 .2557 L p
1 g
F P
s
P
p
.002 w
.34383 .50868 m .38268 .55561 L .39381 .54264 L p
1 g
F P
s
P
p
.002 w
.39381 .54264 m .35571 .4965 L .34383 .50868 L p
1 g
F P
s
P
p
.002 w
.44321 .57662 m .39381 .54264 L .38268 .55561 L p
1 g
F P
s
P
p
.002 w
.38268 .55561 m .43296 .59024 L .44321 .57662 L p
1 g
F P
s
P
p
.002 w
.49949 .59528 m .44321 .57662 L .43296 .59024 L p
1 g
F P
s
P
p
.002 w
.66159 .43509 m .66835 .39408 L .65045 .38605 L p
1 g
F P
s
P
p
.002 w
.64385 .35099 m .65045 .38605 L .66835 .39408 L p
1 g
F P
s
P
p
.002 w
.32009 .45359 m .34383 .50868 L .35571 .4965 L p
1 g
F P
s
P
p
.002 w
.35571 .4965 m .33252 .4423 L .32009 .45359 L p
1 g
F P
s
P
p
.002 w
.56368 .2619 m .51998 .25703 L .52868 .27358 L p
1 g
F P
s
P
p
.002 w
.52868 .27358 m .56454 .27768 L .56368 .2619 L p
1 g
F P
s
P
p
.002 w
.49949 .59528 m .55754 .59651 L .5641 .57845 L p
1 g
F P
s
P
p
.002 w
.61604 .56189 m .5641 .57845 L .55754 .59651 L p
1 g
F P
s
P
p
.002 w
.5641 .57845 m .61604 .56189 L .61718 .54151 L p
1 g
F P
s
P
p
.002 w
.65684 .51033 m .61718 .54151 L .61604 .56189 L p
1 g
F P
s
P
p
.002 w
.61718 .54151 m .65684 .51033 L .65097 .49054 L p
1 g
F P
s
P
p
.002 w
.65097 .49054 m .67441 .45068 L .66159 .43509 L p
1 g
F P
s
P
p
.002 w
.66835 .39408 m .66159 .43509 L .67441 .45068 L p
1 g
F P
s
P
p
.002 w
.67441 .45068 m .65097 .49054 L .65684 .51033 L p
1 g
F P
s
P
p
.002 w
.66835 .39408 m .66046 .35138 L .64385 .35099 L p
1 g
F P
s
P
p
.002 w
.62578 .3188 m .64385 .35099 L .66046 .35138 L p
1 g
F P
s
P
p
.002 w
.43296 .59024 m .49019 .60936 L .49949 .59528 L p
1 g
F P
s
P
p
.002 w
.55754 .59651 m .49949 .59528 L .49019 .60936 L p
1 g
F P
s
P
p
.002 w
.51043 .24447 m .46309 .2557 L .47898 .26658 L p
1 g
F P
s
P
p
.002 w
.47898 .26658 m .51998 .25703 L .51043 .24447 L p
1 g
F P
s
P
p
.002 w
.3401 .32988 m .32688 .38491 L .34361 .37607 L p
1 g
F P
s
P
p
.002 w
.34361 .37607 m .35653 .32335 L .3401 .32988 L p
1 g
F P
s
P
p
.002 w
.60486 .28097 m .56368 .2619 L .56454 .27768 L p
1 g
F P
s
P
p
.002 w
.56454 .27768 m .59825 .29334 L .60486 .28097 L p
1 g
F P
s
P
p
.002 w
.38712 .27858 m .35653 .32335 L .37611 .31981 L p
1 g
F P
s
P
p
.002 w
.37611 .31981 m .40483 .2782 L .38712 .27858 L p
1 g
F P
s
P
p
.002 w
.44762 .24908 m .40483 .2782 L .42439 .28178 L p
1 g
F P
s
P
p
.002 w
.42439 .28178 m .46309 .2557 L .44762 .24908 L p
1 g
F P
s
P
p
.002 w
.31415 .39529 m .32009 .45359 L .33252 .4423 L p
1 g
F P
s
P
p
.002 w
.33252 .4423 m .32688 .38491 L .31415 .39529 L p
1 g
F P
s
P
p
.002 w
.66046 .35138 m .63848 .31206 L .62578 .3188 L p
1 g
F P
s
P
p
.002 w
.59825 .29334 m .62578 .3188 L .63848 .31206 L p
1 g
F P
s
P
p
.002 w
.63848 .31206 m .60486 .28097 L .59825 .29334 L p
1 g
F P
s
P
p
.002 w
.33564 .51925 m .37422 .56577 L .38268 .55561 L p
1 g
F P
s
P
p
.002 w
.38268 .55561 m .34383 .50868 L .33564 .51925 L p
1 g
F P
s
P
p
.002 w
.43296 .59024 m .38268 .55561 L .37422 .56577 L p
1 g
F P
s
P
p
.002 w
.67441 .45068 m .68243 .40337 L .66835 .39408 L p
1 g
F P
s
P
p
.002 w
.66046 .35138 m .66835 .39408 L .68243 .40337 L p
1 g
F P
s
P
p
.002 w
.37422 .56577 m .42409 .60016 L .43296 .59024 L p
1 g
F P
s
P
p
.002 w
.49019 .60936 m .43296 .59024 L .42409 .60016 L p
1 g
F P
s
P
p
.002 w
.56108 .25002 m .51043 .24447 L .51998 .25703 L p
1 g
F P
s
P
p
.002 w
.51998 .25703 m .56368 .2619 L .56108 .25002 L p
1 g
F P
s
P
p
.002 w
.31201 .4647 m .33564 .51925 L .34383 .50868 L p
1 g
F P
s
P
p
.002 w
.34383 .50868 m .32009 .45359 L .31201 .4647 L p
1 g
F P
s
P
p
.002 w
.55754 .59651 m .61177 .57949 L .61604 .56189 L p
1 g
F P
s
P
p
.002 w
.65874 .52867 m .61604 .56189 L .61177 .57949 L p
1 g
F P
s
P
p
.002 w
.61604 .56189 m .65874 .52867 L .65684 .51033 L p
1 g
F P
s
P
p
.002 w
.65684 .51033 m .68305 .46628 L .67441 .45068 L p
1 g
F P
s
P
p
.002 w
.68243 .40337 m .67441 .45068 L .68305 .46628 L p
1 g
F P
s
P
p
.002 w
.49019 .60936 m .5492 .6108 L .55754 .59651 L p
1 g
F P
s
P
p
.002 w
.61177 .57949 m .55754 .59651 L .5492 .6108 L p
1 g
F P
s
P
p
.002 w
.68305 .46628 m .65684 .51033 L .65874 .52867 L p
1 g
F P
s
P
p
.002 w
.50023 .23646 m .44762 .24908 L .46309 .2557 L p
1 g
F P
s
P
p
.002 w
.46309 .2557 m .51043 .24447 L .50023 .23646 L p
1 g
F P
s
P
p
.002 w
.68243 .40337 m .67342 .3539 L .66046 .35138 L p
1 g
F P
s
P
p
.002 w
.63848 .31206 m .66046 .35138 L .67342 .3539 L p
1 g
F P
s
P
p
.002 w
.32739 .3394 m .31415 .39529 L .32688 .38491 L p
1 g
F P
s
P
p
.002 w
.32688 .38491 m .3401 .32988 L .32739 .3394 L p
1 g
F P
s
P
p
.002 w
.37182 .2831 m .3401 .32988 L .35653 .32335 L p
1 g
F P
s
P
p
.002 w
.35653 .32335 m .38712 .27858 L .37182 .2831 L p
1 g
F P
s
P
p
.002 w
.42409 .60016 m .4808 .61921 L .49019 .60936 L p
1 g
F P
s
P
p
.002 w
.5492 .6108 m .49019 .60936 L .4808 .61921 L p
1 g
F P
s
P
p
.002 w
.43298 .24715 m .38712 .27858 L .40483 .2782 L p
1 g
F P
s
P
p
.002 w
.40483 .2782 m .44762 .24908 L .43298 .24715 L p
1 g
F P
s
P
p
.002 w
.60892 .27211 m .56108 .25002 L .56368 .2619 L p
1 g
F P
s
P
p
.002 w
.56368 .2619 m .60486 .28097 L .60892 .27211 L p
1 g
F P
s
P
p
.002 w
.306 .40703 m .31201 .4647 L .32009 .45359 L p
1 g
F P
s
P
p
.002 w
.32009 .45359 m .31415 .39529 L .306 .40703 L p
1 g
F P
s
P
p
.002 w
.67342 .3539 m .64797 .30824 L .63848 .31206 L p
1 g
F P
s
P
p
.002 w
.60486 .28097 m .63848 .31206 L .64797 .30824 L p
1 g
F P
s
P
p
.002 w
.64797 .30824 m .60892 .27211 L .60486 .28097 L p
1 g
F P
s
P
p
.002 w
.68305 .46628 m .69213 .41374 L .68243 .40337 L p
1 g
F P
s
P
p
.002 w
.67342 .3539 m .68243 .40337 L .69213 .41374 L p
1 g
F P
s
P
p
.002 w
.33157 .52785 m .36881 .5727 L .37422 .56577 L p
1 g
F P
s
P
p
.002 w
.37422 .56577 m .33564 .51925 L .33157 .52785 L p
1 g
F P
s
P
p
.002 w
.42409 .60016 m .37422 .56577 L .36881 .5727 L p
1 g
F P
s
P
p
.002 w
.36881 .5727 m .41691 .60589 L .42409 .60016 L p
1 g
F P
s
P
p
.002 w
.4808 .61921 m .42409 .60016 L .41691 .60589 L p
1 g
F P
s
P
p
.002 w
.5492 .6108 m .60433 .59371 L .61177 .57949 L p
1 g
F P
s
P
p
.002 w
.65642 .54504 m .61177 .57949 L .60433 .59371 L p
1 g
F P
s
P
p
.002 w
.61177 .57949 m .65642 .54504 L .65874 .52867 L p
1 g
F P
s
P
p
.002 w
.5567 .24257 m .50023 .23646 L .51043 .24447 L p
1 g
F P
s
P
p
.002 w
.51043 .24447 m .56108 .25002 L .5567 .24257 L p
1 g
F P
s
P
p
.002 w
.65874 .52867 m .68707 .48149 L .68305 .46628 L p
1 g
F P
s
P
p
.002 w
.69213 .41374 m .68305 .46628 L .68707 .48149 L p
1 g
F P
s
P
p
.002 w
.68707 .48149 m .65874 .52867 L .65642 .54504 L p
1 g
F P
s
P
p
.002 w
.30875 .47533 m .33157 .52785 L .33564 .51925 L p
1 g
F P
s
P
p
.002 w
.33564 .51925 m .31201 .4647 L .30875 .47533 L p
1 g
F P
s
P
p
.002 w
.4808 .61921 m .53921 .62077 L .5492 .6108 L p
1 g
F P
s
P
p
.002 w
.60433 .59371 m .5492 .6108 L .53921 .62077 L p
1 g
F P
s
P
p
.002 w
.48959 .23348 m .43298 .24715 L .44762 .24908 L p
1 g
F P
s
P
p
.002 w
.44762 .24908 m .50023 .23646 L .48959 .23348 L p
1 g
F P
s
P
p
.002 w
.35947 .2919 m .32739 .3394 L .3401 .32988 L p
1 g
F P
s
P
p
.002 w
.3401 .32988 m .37182 .2831 L .35947 .2919 L p
1 g
F P
s
P
p
.002 w
.31898 .35182 m .306 .40703 L .31415 .39529 L p
1 g
F P
s
P
p
.002 w
.31415 .39529 m .32739 .3394 L .31898 .35182 L p
1 g
F P
s
P
p
.002 w
.41961 .25024 m .37182 .2831 L .38712 .27858 L p
1 g
F P
s
P
p
.002 w
.38712 .27858 m .43298 .24715 L .41961 .25024 L p
1 g
F P
s
P
p
.002 w
.69213 .41374 m .68219 .35862 L .67342 .3539 L p
1 g
F P
s
P
p
.002 w
.64797 .30824 m .67342 .3539 L .68219 .35862 L p
1 g
F P
s
P
p
.002 w
.41691 .60589 m .47154 .6243 L .4808 .61921 L p
1 g
F P
s
P
p
.002 w
.53921 .62077 m .4808 .61921 L .47154 .6243 L p
1 g
F P
s
P
p
.002 w
.61015 .26723 m .5567 .24257 L .56108 .25002 L p
1 g
F P
s
P
p
.002 w
.56108 .25002 m .60892 .27211 L .61015 .26723 L p
1 g
F P
s
P
p
.002 w
.30291 .41991 m .30875 .47533 L .31201 .4647 L p
1 g
F P
s
P
p
.002 w
.31201 .4647 m .306 .40703 L .30291 .41991 L p
1 g
F P
s
P
p
.002 w
.68219 .35862 m .6538 .30762 L .64797 .30824 L p
1 g
F P
s
P
p
.002 w
.60892 .27211 m .64797 .30824 L .6538 .30762 L p
1 g
F P
s
P
p
.002 w
.6538 .30762 m .61015 .26723 L .60892 .27211 L p
1 g
F P
s
P
p
.002 w
.68707 .48149 m .69694 .425 L .69213 .41374 L p
1 g
F P
s
P
p
.002 w
.68219 .35862 m .69213 .41374 L .69694 .425 L p
1 g
F P
s
P
p
.002 w
.332 .53412 m .36679 .576 L .36881 .5727 L p
1 g
F P
s
P
p
.002 w
.36881 .5727 m .33157 .52785 L .332 .53412 L p
1 g
F P
s
P
p
.002 w
.41691 .60589 m .36881 .5727 L .36679 .576 L p
1 g
F P
s
P
p
.002 w
.53921 .62077 m .59371 .60399 L .60433 .59371 L p
1 g
F P
s
P
p
.002 w
.6497 .55888 m .60433 .59371 L .59371 .60399 L p
1 g
F P
s
P
p
.002 w
.60433 .59371 m .6497 .55888 L .65642 .54504 L p
1 g
F P
s
P
p
.002 w
.68607 .4959 m .65642 .54504 L .6497 .55888 L p
1 g
F P
s
P
p
.002 w
.65642 .54504 m .68607 .4959 L .68707 .48149 L p
1 g
F P
s
P
p
.002 w
.69694 .425 m .68707 .48149 L .68607 .4959 L p
1 g
F P
s
P
p
.002 w
.55055 .24005 m .48959 .23348 L .50023 .23646 L p
1 g
F P
s
P
p
.002 w
.50023 .23646 m .5567 .24257 L .55055 .24005 L p
1 g
F P
s
P
p
.002 w
.36679 .576 m .41172 .60701 L .41691 .60589 L p
1 g
F P
s
P
p
.002 w
.47154 .6243 m .41691 .60589 L .41172 .60701 L p
1 g
F P
s
P
p
.002 w
.47154 .6243 m .52773 .62588 L .53921 .62077 L p
1 g
F P
s
P
p
.002 w
.59371 .60399 m .53921 .62077 L .52773 .62588 L p
1 g
F P
s
P
p
.002 w
.3107 .48515 m .332 .53412 L .33157 .52785 L p
1 g
F P
s
P
p
.002 w
.33157 .52785 m .30875 .47533 L .3107 .48515 L p
1 g
F P
s
P
p
.002 w
.35062 .30496 m .31898 .35182 L .32739 .3394 L p
1 g
F P
s
P
p
.002 w
.32739 .3394 m .35947 .2919 L .35062 .30496 L p
1 g
F P
s
P
p
.002 w
.4788 .23594 m .41961 .25024 L .43298 .24715 L p
1 g
F P
s
P
p
.002 w
.43298 .24715 m .48959 .23348 L .4788 .23594 L p
1 g
F P
s
P
p
.002 w
.40798 .25855 m .35947 .2919 L .37182 .2831 L p
1 g
F P
s
P
p
.002 w
.37182 .2831 m .41961 .25024 L .40798 .25855 L p
1 g
F P
s
P
p
.002 w
.31535 .36696 m .30291 .41991 L .306 .40703 L p
1 g
F P
s
P
p
.002 w
.306 .40703 m .31898 .35182 L .31535 .36696 L p
1 g
F P
s
P
p
.002 w
.69694 .425 m .68625 .36554 L .68219 .35862 L p
1 g
F P
s
P
p
.002 w
.6538 .30762 m .68219 .35862 L .68625 .36554 L p
1 g
F P
s
P
p
.002 w
.41172 .60701 m .46268 .62421 L .47154 .6243 L p
1 g
F P
s
P
p
.002 w
.52773 .62588 m .47154 .6243 L .46268 .62421 L p
1 g
F P
s
P
p
.002 w
.60834 .26672 m .55055 .24005 L .5567 .24257 L p
1 g
F P
s
P
p
.002 w
.5567 .24257 m .61015 .26723 L .60834 .26672 L p
1 g
F P
s
P
p
.002 w
.30528 .4336 m .3107 .48515 L .30875 .47533 L p
1 g
F P
s
P
p
.002 w
.30875 .47533 m .30291 .41991 L .30528 .4336 L p
1 g
F P
s
P
p
.002 w
.68625 .36554 m .65556 .31042 L .6538 .30762 L p
1 g
F P
s
P
p
.002 w
.61015 .26723 m .6538 .30762 L .65556 .31042 L p
1 g
F P
s
P
p
.002 w
.65556 .31042 m .60834 .26672 L .61015 .26723 L p
1 g
F P
s
P
p
.002 w
.68607 .4959 m .69641 .43688 L .69694 .425 L p
1 g
F P
s
P
p
.002 w
.68625 .36554 m .69694 .425 L .69641 .43688 L p
1 g
F P
s
P
p
.002 w
.52773 .62588 m .58003 .6098 L .59371 .60399 L p
1 g
F P
s
P
p
.002 w
.59371 .60399 m .63849 .56965 L .6497 .55888 L p
1 g
F P
s
P
p
.002 w
.63849 .56965 m .59371 .60399 L .58003 .6098 L p
1 g
F P
s
P
p
.002 w
.6497 .55888 m .6798 .50905 L .68607 .4959 L p
1 g
F P
s
P
p
.002 w
.6798 .50905 m .6497 .55888 L .63849 .56965 L p
1 g
F P
s
P
p
.002 w
.69641 .43688 m .68607 .4959 L .6798 .50905 L p
1 g
F P
s
P
p
.002 w
.3372 .53773 m .36844 .57534 L .36679 .576 L p
1 g
F P
s
P
p
.002 w
.36679 .576 m .332 .53412 L .3372 .53773 L p
1 g
F P
s
P
p
.002 w
.41172 .60701 m .36679 .576 L .36844 .57534 L p
1 g
F P
s
P
p
.002 w
.54268 .24287 m .4788 .23594 L .48959 .23348 L p
1 g
F P
s
P
p
.002 w
.48959 .23348 m .55055 .24005 L .54268 .24287 L p
1 g
F P
s
P
p
.002 w
.46268 .62421 m .51499 .62568 L .52773 .62588 L p
1 g
F P
s
P
p
.002 w
.58003 .6098 m .52773 .62588 L .51499 .62568 L p
1 g
F P
s
P
p
.002 w
.36844 .57534 m .40879 .60319 L .41172 .60701 L p
1 g
F P
s
P
p
.002 w
.46268 .62421 m .41172 .60701 L .40879 .60319 L p
1 g
F P
s
P
p
.002 w
.31813 .49383 m .3372 .53773 L .332 .53412 L p
1 g
F P
s
P
p
.002 w
.332 .53412 m .3107 .48515 L .31813 .49383 L p
1 g
F P
s
P
p
.002 w
.34574 .32215 m .31535 .36696 L .31898 .35182 L p
1 g
F P
s
P
p
.002 w
.31898 .35182 m .35062 .30496 L .34574 .32215 L p
1 g
F P
s
P
p
.002 w
.46817 .2441 m .40798 .25855 L .41961 .25024 L p
1 g
F P
s
P
p
.002 w
.41961 .25024 m .4788 .23594 L .46817 .2441 L p
1 g
F P
s
P
p
.002 w
.39854 .27215 m .35062 .30496 L .35947 .2919 L p
1 g
F P
s
P
p
.002 w
.35947 .2919 m .40798 .25855 L .39854 .27215 L p
1 g
F P
s
P
p
.002 w
.31691 .38451 m .30528 .4336 L .30291 .41991 L p
1 g
F P
s
P
p
.002 w
.30291 .41991 m .31535 .36696 L .31691 .38451 L p
1 g
F P
s
P
p
.002 w
.40879 .60319 m .45451 .6186 L .46268 .62421 L p
1 g
F P
s
P
p
.002 w
.51499 .62568 m .46268 .62421 L .45451 .6186 L p
1 g
F P
s
P
p
.002 w
.69641 .43688 m .68518 .37462 L .68625 .36554 L p
1 g
F P
s
P
p
.002 w
.65556 .31042 m .68625 .36554 L .68518 .37462 L p
1 g
F P
s
P
p
.002 w
.60334 .2709 m .54268 .24287 L .55055 .24005 L p
1 g
F P
s
P
p
.002 w
.55055 .24005 m .60834 .26672 L .60334 .2709 L p
1 g
F P
s
P
p
.002 w
.31337 .44775 m .31813 .49383 L .3107 .48515 L p
1 g
F P
s
P
p
.002 w
.3107 .48515 m .30528 .4336 L .31337 .44775 L p
1 g
F P
s
P
p
.002 w
.68518 .37462 m .65294 .31679 L .65556 .31042 L p
1 g
F P
s
P
p
.002 w
.60834 .26672 m .65556 .31042 L .65294 .31679 L p
1 g
F P
s
P
p
.002 w
.6798 .50905 m .69023 .44907 L .69641 .43688 L p
1 g
F P
s
P
p
.002 w
.68518 .37462 m .69641 .43688 L .69023 .44907 L p
1 g
F P
s
P
p
.002 w
.65294 .31679 m .60334 .2709 L .60834 .26672 L p
1 g
F P
s
P
p
.002 w
.51499 .62568 m .56352 .6107 L .58003 .6098 L p
1 g
F P
s
P
p
.002 w
.62288 .57686 m .58003 .6098 L .56352 .6107 L p
1 g
F P
s
P
p
.002 w
.58003 .6098 m .62288 .57686 L .63849 .56965 L p
1 g
F P
s
P
p
.002 w
.66811 .52046 m .63849 .56965 L .62288 .57686 L p
1 g
F P
s
P
p
.002 w
.63849 .56965 m .66811 .52046 L .6798 .50905 L p
1 g
F P
s
P
p
.004 w
.67382 .53185 m
.70372 .54929 L
s
P
p
.002 w
.69023 .44907 m .6798 .50905 L .66811 .52046 L p
1 g
F P
s
P
p
.002 w
.45451 .6186 m .5013 .61986 L .51499 .62568 L p
1 g
F P
s
P
p
.002 w
.56352 .6107 m .51499 .62568 L .5013 .61986 L p
1 g
F P
s
P
p
.002 w
.53323 .25128 m .46817 .2441 L .4788 .23594 L p
1 g
F P
s
P
p
.002 w
.4788 .23594 m .54268 .24287 L .53323 .25128 L p
1 g
F P
s
P
p
.002 w
.34734 .5384 m .37395 .57048 L .36844 .57534 L p
1 g
F P
s
P
p
.002 w
.36844 .57534 m .3372 .53773 L .34734 .5384 L p
1 g
F P
s
P
p
.002 w
.40879 .60319 m .36844 .57534 L .37395 .57048 L p
1 g
F P
s
P
p
.002 w
.37395 .57048 m .40837 .59421 L .40879 .60319 L p
1 g
F P
s
P
p
.002 w
.45451 .6186 m .40879 .60319 L .40837 .59421 L p
1 g
F P
s
P
p
.002 w
.3452 .34315 m .31691 .38451 L .31535 .36696 L p
1 g
F P
s
P
p
.002 w
.31535 .36696 m .34574 .32215 L .3452 .34315 L p
1 g
F P
s
P
p
.002 w
.39173 .29093 m .34574 .32215 L .35062 .30496 L p
1 g
F P
s
P
p
.002 w
.35062 .30496 m .39854 .27215 L .39173 .29093 L p
1 g
F P
s
P
p
.002 w
.45805 .25806 m .39854 .27215 L .40798 .25855 L p
1 g
F P
s
P
p
.002 w
.40798 .25855 m .46817 .2441 L .45805 .25806 L p
1 g
F P
s
P
p
.002 w
.33118 .50103 m .34734 .5384 L .3372 .53773 L p
1 g
F P
s
P
p
.002 w
.3372 .53773 m .31813 .49383 L .33118 .50103 L p
1 g
F P
s
P
p
.002 w
.32389 .40406 m .31337 .44775 L .30528 .4336 L p
1 g
F P
s
P
p
.002 w
.30528 .4336 m .31691 .38451 L .32389 .40406 L p
1 g
F P
s
P
p
.002 w
.40837 .59421 m .44731 .60729 L .45451 .6186 L p
1 g
F P
s
P
p
.002 w
.5013 .61986 m .45451 .6186 L .44731 .60729 L p
1 g
F P
s
P
p
.002 w
.69023 .44907 m .67869 .3857 L .68518 .37462 L p
1 g
F P
s
P
p
.002 w
.65294 .31679 m .68518 .37462 L .67869 .3857 L p
1 g
F P
s
P
p
.002 w
.32726 .46194 m .33118 .50103 L .31813 .49383 L p
1 g
F P
s
P
p
.002 w
.31813 .49383 m .31337 .44775 L .32726 .46194 L p
1 g
F P
s
P
p
.002 w
.59509 .27994 m .53323 .25128 L .54268 .24287 L p
1 g
F P
s
P
p
.002 w
.54268 .24287 m .60334 .2709 L .59509 .27994 L p
1 g
F P
s
P
p
.002 w
.66811 .52046 m .67825 .46121 L .69023 .44907 L p
1 g
F P
s
P
p
.002 w
.67869 .3857 m .69023 .44907 L .67825 .46121 L p
1 g
F P
s
P
p
.002 w
.56352 .6107 m .6031 .58006 L .62288 .57686 L p
1 g
F P
s
P
p
.002 w
.65107 .52967 m .62288 .57686 L .6031 .58006 L p
1 g
F P
s
P
p
.002 w
.62288 .57686 m .65107 .52967 L .66811 .52046 L p
1 g
F P
s
P
p
.002 w
.5013 .61986 m .54454 .60637 L .56352 .6107 L p
1 g
F P
s
P
p
.002 w
.6031 .58006 m .56352 .6107 L .54454 .60637 L p
1 g
F P
s
P
p
.002 w
.67825 .46121 m .66811 .52046 L .65107 .52967 L p
1 g
F P
s
P
p
.002 w
.67869 .3857 m .64573 .32676 L .65294 .31679 L p
1 g
F P
s
P
p
.002 w
.60334 .2709 m .65294 .31679 L .64573 .32676 L p
1 g
F P
s
P
p
.002 w
.64573 .32676 m .59509 .27994 L .60334 .2709 L p
1 g
F P
s
P
p
.002 w
.44731 .60729 m .48704 .60825 L .5013 .61986 L p
1 g
F P
s
P
p
.002 w
.54454 .60637 m .5013 .61986 L .48704 .60825 L p
1 g
F P
s
P
p
.002 w
.52242 .26534 m .45805 .25806 L .46817 .2441 L p
1 g
F P
s
P
p
.002 w
.46817 .2441 m .53323 .25128 L .52242 .26534 L p
1 g
F P
s
P
p
.002 w
.34926 .36746 m .32389 .40406 L .31691 .38451 L p
1 g
F P
s
P
p
.002 w
.31691 .38451 m .3452 .34315 L .34926 .36746 L p
1 g
F P
s
P
p
.002 w
.38791 .31451 m .3452 .34315 L .34574 .32215 L p
1 g
F P
s
P
p
.002 w
.34574 .32215 m .39173 .29093 L .38791 .31451 L p
1 g
F P
s
P
p
.002 w
.36241 .53592 m .38341 .56128 L .37395 .57048 L p
1 g
F P
s
P
p
.002 w
.37395 .57048 m .34734 .5384 L .36241 .53592 L p
1 g
F P
s
P
p
.002 w
.40837 .59421 m .37395 .57048 L .38341 .56128 L p
1 g
F P
s
P
p
.002 w
.44881 .27769 m .39173 .29093 L .39854 .27215 L p
1 g
F P
s
P
p
.002 w
.39854 .27215 m .45805 .25806 L .44881 .27769 L p
1 g
F P
s
P
p
.002 w
.38341 .56128 m .41063 .58004 L .40837 .59421 L p
1 g
F P
s
P
p
.002 w
.44731 .60729 m .40837 .59421 L .41063 .58004 L p
1 g
F P
s
P
p
.002 w
.33636 .42506 m .32726 .46194 L .31337 .44775 L p
1 g
F P
s
P
p
.002 w
.31337 .44775 m .32389 .40406 L .33636 .42506 L p
1 g
F P
s
P
p
.002 w
.34973 .50641 m .36241 .53592 L .34734 .5384 L p
1 g
F P
s
P
p
.002 w
.34734 .5384 m .33118 .50103 L .34973 .50641 L p
1 g
F P
s
P
p
.002 w
.41063 .58004 m .44139 .5903 L .44731 .60729 L p
1 g
F P
s
P
p
.002 w
.48704 .60825 m .44731 .60729 L .44139 .5903 L p
1 g
F P
s
P
p
.002 w
.67825 .46121 m .66664 .39855 L .67869 .3857 L p
1 g
F P
s
P
p
.002 w
.64573 .32676 m .67869 .3857 L .66664 .39855 L p
1 g
F P
s
P
p
.002 w
.34679 .47567 m .34973 .50641 L .33118 .50103 L p
1 g
F P
s
P
p
.002 w
.33118 .50103 m .32726 .46194 L .34679 .47567 L p
1 g
F P
s
P
p
.002 w
.58367 .29384 m .52242 .26534 L .53323 .25128 L p
1 g
F P
s
P
p
.002 w
.53323 .25128 m .59509 .27994 L .58367 .29384 L p
1 g
F P
s
P
p
.002 w
.54454 .60637 m .57958 .57893 L .6031 .58006 L p
1 g
F P
s
P
p
.002 w
.62894 .53627 m .6031 .58006 L .57958 .57893 L p
1 g
F P
s
P
p
.002 w
.6031 .58006 m .62894 .53627 L .65107 .52967 L p
1 g
F P
s
P
p
.002 w
.48704 .60825 m .52356 .59667 L .54454 .60637 L p
1 g
F P
s
P
p
.002 w
.57958 .57893 m .54454 .60637 L .52356 .59667 L p
1 g
F P
s
P
p
.002 w
.65107 .52967 m .66052 .47288 L .67825 .46121 L p
1 g
F P
s
P
p
.002 w
.66664 .39855 m .67825 .46121 L .66052 .47288 L p
1 g
F P
s
P
p
.002 w
.66052 .47288 m .65107 .52967 L .62894 .53627 L p
1 g
F P
s
P
p
.002 w
.66664 .39855 m .63387 .34024 L .64573 .32676 L p
1 g
F P
s
P
p
.002 w
.59509 .27994 m .64573 .32676 L .63387 .34024 L p
1 g
F P
s
P
p
.002 w
.44139 .5903 m .47265 .59093 L .48704 .60825 L p
1 g
F P
s
P
p
.002 w
.52356 .59667 m .48704 .60825 L .47265 .59093 L p
1 g
F P
s
P
p
.002 w
.63387 .34024 m .58367 .29384 L .59509 .27994 L p
1 g
F P
s
P
p
.002 w
.35799 .39438 m .33636 .42506 L .32389 .40406 L p
1 g
F P
s
P
p
.002 w
.32389 .40406 m .34926 .36746 L .35799 .39438 L p
1 g
F P
s
P
p
.002 w
.38737 .34233 m .34926 .36746 L .3452 .34315 L p
1 g
F P
s
P
p
.002 w
.3452 .34315 m .38791 .31451 L .38737 .34233 L p
1 g
F P
s
P
p
.002 w
.51054 .28491 m .44881 .27769 L .45805 .25806 L p
1 g
F P
s
P
p
.002 w
.45805 .25806 m .52242 .26534 L .51054 .28491 L p
1 g
F P
s
P
p
.002 w
.44082 .30259 m .38791 .31451 L .39173 .29093 L p
1 g
F P
s
P
p
.002 w
.39173 .29093 m .44881 .27769 L .44082 .30259 L p
1 g
F P
s
P
p
.002 w
.35413 .44684 m .34679 .47567 L .32726 .46194 L p
1 g
F P
s
P
p
.002 w
.32726 .46194 m .33636 .42506 L .35413 .44684 L p
1 g
F P
s
P
p
.002 w
.38218 .53017 m .39675 .54781 L .38341 .56128 L p
1 g
F P
s
P
p
.002 w
.38341 .56128 m .36241 .53592 L .38218 .53017 L p
1 g
F P
s
P
p
.002 w
.41063 .58004 m .38341 .56128 L .39675 .54781 L p
1 g
F P
s
P
p
.002 w
.39675 .54781 m .41567 .56082 L .41063 .58004 L p
1 g
F P
s
P
p
.002 w
.44139 .5903 m .41063 .58004 L .41567 .56082 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.37346 .50969 m .38218 .53017 L .36241 .53592 L p
1 g
F P
s
P
p
.002 w
.36241 .53592 m .34973 .50641 L .37346 .50969 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.41567 .56082 m .43702 .56788 L .44139 .5903 L p
1 g
F P
s
P
p
.002 w
.47265 .59093 m .44139 .5903 L .43702 .56788 L p
1 g
F P
s
P
p
.002 w
.63387 .34024 m .66664 .39855 L .64913 .41284 L p
1 g
F P
s
P
p
.002 w
.66052 .47288 m .64913 .41284 L .66664 .39855 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52356 .59667 m .55295 .57331 L .57958 .57893 L p
1 g
F P
s
P
p
.002 w
.60224 .53988 m .57958 .57893 L .55295 .57331 L p
1 g
F P
s
P
p
.002 w
.57958 .57893 m .60224 .53988 L .62894 .53627 L p
1 g
F P
s
P
p
.002 w
.37156 .48845 m .37346 .50969 L .34973 .50641 L p
1 g
F P
s
P
p
.002 w
.34973 .50641 m .34679 .47567 L .37156 .48845 L p
1 g
F P
s
P
p
.002 w
.47265 .59093 m .50122 .58166 L .52356 .59667 L p
1 g
F P
s
P
p
.002 w
.52356 .59667 m .50122 .58166 L p
.50451 .58113 L 1 g
F P
s
P
p
.002 w
.54864 .57673 m .52356 .59667 L p
.5057 .5821 L 1 g
F P
s
P
p
.51093 .58049 m .5057 .5821 L .50451 .58113 L 1 g
F
P
p
.54864 .57673 m .5057 .5821 L .51093 .58049 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58049 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58049 L .52364 .57657 L 1 g
F
P
p
.002 w
.51093 .58049 m .51079 .57862 L p
.49789 .5812 L 1 g
F P
s
P
p
.002 w
.47265 .59093 m .4651 .57869 L p
.48973 .58072 L 1 g
F P
s
P
p
.002 w
.50122 .58166 m .49731 .58293 L p
.48973 .58072 L 1 g
F P
s
P
p
.002 w
.49731 .58293 m .47265 .59093 L p
.48973 .58072 L 1 g
F P
s
P
p
.002 w
.48907 .58052 m .48921 .57862 L p
.47993 .57786 L 1 g
F P
s
P
p
.49789 .5812 m .50096 .58143 L .51093 .58049 L 1 g
F
P
p
.002 w
.50151 .58143 m .50122 .58166 L .50096 .58143 L p
1 g
F P
s
P
p
.50096 .58143 m .50126 .58145 L .50151 .58143 L 1 g
F
P
p
.50096 .58143 m .50151 .58143 L .51093 .58049 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.50122 .58166 m .4651 .57869 L .50035 .58139 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58052 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58052 L .4972 .58115 L 1 g
F
P
p
.51079 .57862 m .48891 .58268 L .49198 .58238 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45076 .56318 L p
1 g
F P
s
P
p
.002 w
.43702 .56788 m .43546 .55146 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.45729 .56818 m .45464 .56815 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.45464 .56815 m .43702 .56788 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.45076 .56318 m .45146 .56129 L p
.44465 .55537 L 1 g
F P
s
P
p
.46872 .57265 m .45076 .56318 L .45536 .56671 L 1 g
F
P
p
.45684 .56791 m .45029 .56445 L .45563 .56742 L 1 g
F
P
p
.46872 .57265 m .45391 .56606 L .45684 .56791 L 1 g
F
P
p
.45391 .56606 m .45029 .56445 L .45684 .56791 L 1 g
F
P
p
.002 w
.43702 .56788 m .45729 .56818 L p
.47265 .59093 L 1 g
F P
s
P
p
.002 w
.45946 .56955 m .47265 .59093 L p
.45729 .56818 L 1 g
F P
s
P
p
.002 w
.4651 .57869 m .46122 .5724 L p
.47764 .57965 L 1 g
F P
s
P
p
.002 w
.46122 .5724 m .45946 .56955 L p
.46832 .57447 L 1 g
F P
s
P
p
.47764 .57965 m .46122 .5724 L .46832 .57447 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46832 .57447 L p
1 g
F P
s
P
p
.48921 .57862 m .46832 .57447 L .47993 .57786 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46832 .57447 L p
1 g
F P
s
P
p
.002 w
.46832 .57447 m .46872 .57265 L p
.45563 .56742 L 1 g
F P
s
P
p
.45563 .56742 m .45002 .56518 L .46832 .57447 L 1 g
F
P
p
.50035 .58139 m .47764 .57965 L .45863 .56821 L 1 g
F
P
p
.002 w
.45946 .56955 m .45863 .56821 L p
.47764 .57965 L 1 g
F P
s
P
p
.002 w
.46832 .57447 m .4678 .57686 L p
.47993 .57786 L 1 g
F P
s
P
p
.002 w
.45729 .56818 m .45863 .56821 L .45946 .56955 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43836 .54734 L p
1 g
F P
s
P
p
.45146 .56129 m .43836 .54734 L .44465 .55537 L 1 g
F
P
p
.43693 .54358 m .43728 .54452 L .43443 .54057 L 1 g
F
P
p
.002 w
.43546 .55146 m .43462 .54256 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.43836 .54734 m .43925 .54566 L p
.43468 .53663 L 1 g
F P
s
P
p
.43468 .53663 m .4347 .53667 L .43836 .54734 L 1 g
F
P
p
.43467 .53661 m .43571 .5404 L .43836 .54734 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43578 .54058 m .43443 .54057 L .43433 .53535 L p
1 g
F P
s
P
p
.002 w
.42344 .53697 m .42997 .51945 L p
.43238 .53085 L 1 g
F P
s
P
p
.002 w
.43443 .54057 m .43184 .53972 L p
.43238 .53085 L 1 g
F P
s
P
p
.002 w
.43184 .53972 m .42344 .53697 L p
.43238 .53085 L 1 g
F P
s
P
p
.002 w
.43251 .52872 m .43346 .52734 L p
.43315 .51837 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52872 L p
1 g
F P
s
P
p
.002 w
.43433 .53535 m .43443 .54057 L p
.42997 .51945 L 1 g
F P
s
P
p
.002 w
.43251 .52872 m .43146 .53025 L p
.43467 .53661 L 1 g
F P
s
P
p
.43925 .54566 m .43251 .52872 L .43467 .53661 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43368 .50965 L p
1 g
F P
s
P
p
.002 w
.42997 .51945 m .43335 .51037 L p
.43251 .52872 L 1 g
F P
s
P
p
.002 w
.43335 .51037 m .43369 .50946 L p
.43368 .50965 L 1 g
F P
s
P
p
.43251 .52872 m .43335 .51037 L .43368 .50965 L 1 g
F
P
p
.002 w
.43423 .5085 m .43381 .50916 L p
.4425 .49144 L 1 g
F P
s
P
p
.44828 .47965 m .44258 .49136 L .4425 .49144 L 1 g
F
P
p
.44258 .49136 m .43423 .5085 L .4425 .49144 L 1 g
F
P
p
.002 w
.43381 .50916 m .44092 .47605 L .44828 .47965 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45199 .48226 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45234 .48192 m .46061 .48951 L p
.44961 .48456 L 1 g
F P
s
P
p
.45199 .48226 m .44958 .48459 L .44258 .49136 L 1 g
F
P
p
.43485 .50826 m .43848 .49978 L .43763 .50152 L 1 g
F
P
p
.002 w
.43368 .50965 m .43485 .50826 L p
.43774 .50126 L 1 g
F P
s
P
p
.43774 .50126 m .43846 .49951 L .43412 .50873 L 1 g
F
P
p
.43774 .50126 m .43412 .50873 L .43368 .50965 L 1 g
F
P
p
.43846 .49951 m .4342 .50854 L .43406 .50885 L 1 g
F
P
p
.43885 .49856 m .43405 .50885 L .43368 .50965 L 1 g
F
P
p
.43928 .49752 m .43392 .50912 L .43368 .50965 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.46669 .4997 m .46928 .51075 L .43391 .50916 L p
1 g
F P
s
P
p
.002 w
.43391 .50916 m .43381 .50916 L .43393 .50912 L p
1 g
F P
s
P
p
.002 w
.43393 .50912 m .46669 .4997 L p
.43391 .50916 L 1 g
F P
s
P
p
.002 w
.43397 .50904 m .43381 .50916 L .43423 .5085 L p
1 g
F P
s
P
p
.43439 .50816 m .43406 .50885 L .43401 .50894 L 1 g
F
P
p
.43418 .5086 m .43401 .50894 L .43368 .50965 L 1 g
F
P
p
.43439 .50816 m .43401 .50894 L .43418 .5086 L 1 g
F
P
p
.43846 .49951 m .43406 .50885 L .43439 .50816 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.46928 .51075 m .4681 .52144 L .43389 .50919 L p
1 g
F P
s
P
p
.002 w
.43389 .50919 m .43381 .50916 L .43391 .50916 L p
1 g
F P
s
P
p
.002 w
.43391 .50916 m .46928 .51075 L p
.43389 .50919 L 1 g
F P
s
P
p
.002 w
.46061 .48951 m .46669 .4997 L .43393 .50912 L p
1 g
F P
s
P
p
.002 w
.43393 .50912 m .43381 .50916 L .43397 .50904 L p
1 g
F P
s
P
p
.002 w
.43397 .50904 m .46061 .48951 L p
.43393 .50912 L 1 g
F P
s
P
p
.43968 .49656 m .43381 .50937 L .43368 .50965 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4681 .52144 m .46332 .53059 L .43388 .50921 L p
1 g
F P
s
P
p
.002 w
.43388 .50921 m .43381 .50916 L .43389 .50919 L p
1 g
F P
s
P
p
.002 w
.43389 .50919 m .4681 .52144 L p
.43388 .50921 L 1 g
F P
s
P
p
.43846 .49951 m .43885 .49856 L .4342 .50854 L 1 g
F
P
p
.43885 .49856 m .43928 .49752 L .43405 .50885 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.46332 .53059 m .4555 .53722 L .43387 .50924 L p
1 g
F P
s
P
p
.002 w
.43387 .50924 m .43381 .50916 L .43388 .50921 L p
1 g
F P
s
P
p
.002 w
.43388 .50921 m .46332 .53059 L p
.43387 .50924 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4555 .53722 m .44551 .54066 L .43385 .50928 L p
1 g
F P
s
P
p
.002 w
.43385 .50928 m .43381 .50916 L .43387 .50924 L p
1 g
F P
s
P
p
.002 w
.43387 .50924 m .4555 .53722 L p
.43385 .50928 L 1 g
F P
s
P
p
.43928 .49752 m .43968 .49656 L .43392 .50912 L 1 g
F
P
p
.002 w
.43433 .53535 m .43381 .50937 L p
.43578 .54058 L 1 g
F P
s
P
p
.002 w
.43381 .50937 m .43381 .50916 L p
.43382 .50935 L 1 g
F P
s
P
p
.43578 .54058 m .43381 .50937 L .43382 .50935 L 1 g
F
P
p
.002 w
.43381 .50916 m .43385 .50928 L p
.43382 .50935 L 1 g
F P
s
P
p
.43346 .52734 m .43368 .50965 L .43315 .51837 L 1 g
F
P
p
.002 w
.43381 .50916 m .43433 .53535 L p
.43251 .52872 L 1 g
F P
s
P
p
.002 w
.43369 .50946 m .43381 .50916 L p
.43251 .52872 L 1 g
F P
s
P
p
.002 w
.41369 .53028 m .40621 .52119 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.43368 .50965 m .43368 .50965 L p
.43315 .51837 L 1 g
F P
s
P
p
.002 w
.41369 .53028 m .43371 .50926 L p
.43335 .51037 L 1 g
F P
s
P
p
.002 w
.43335 .51037 m .42344 .53697 L .42176 .53582 L p
1 g
F P
s
P
p
.002 w
.42176 .53582 m .41369 .53028 L p
.43335 .51037 L 1 g
F P
s
P
p
.002 w
.43368 .50965 m .43287 .51061 L p
.43314 .51814 L 1 g
F P
s
P
p
.43315 .51837 m .43368 .50965 L .43314 .51814 L 1 g
F
P
p
.002 w
.43371 .50926 m .43381 .50916 L .43369 .50946 L p
1 g
F P
s
P
p
.002 w
.43369 .50946 m .43335 .51037 L p
.43371 .50926 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43368 .50965 L p
.43412 .5087 L 1 g
F P
s
P
p
.002 w
.43994 .49591 m .43985 .49611 L p
.43412 .5087 L 1 g
F P
s
P
p
.002 w
.40621 .52119 m .40178 .51065 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.40178 .51065 m .40088 .49977 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.40088 .49977 m .40366 .4897 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.40366 .4897 m .40983 .48154 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.40983 .48154 m .41878 .4762 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.42953 .47429 m .44092 .47605 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.41878 .4762 m .42953 .47429 L .43381 .50916 L closepath p
1 g
F P
s
P
p
.002 w
.43985 .49611 m .43287 .51061 L p
.43412 .5087 L 1 g
F P
s
P
p
.002 w
.43368 .50965 m .43368 .50965 L p
.43381 .50937 L 1 g
F P
s
P
p
.43381 .50937 m .43994 .49591 L .43368 .50965 L 1 g
F
P
p
.43968 .49656 m .43994 .49591 L .43381 .50937 L 1 g
F
P
p
.002 w
.44551 .54066 m .43578 .54058 L p
.43382 .50935 L 1 g
F P
s
P
p
.002 w
.43385 .50928 m .44551 .54066 L p
.43382 .50935 L 1 g
F P
s
P
p
.002 w
.43423 .5085 m .44958 .48459 L p
.43397 .50904 L 1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45762 .47678 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46061 .48951 m .45234 .48192 L p
.45762 .47678 L 1 g
F P
s
P
p
.002 w
.45762 .47678 m .45826 .47608 L p
.46747 .47204 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46747 .47204 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48904 .46771 m .46061 .48951 L p
.4665 .46865 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.49113 .46532 L 1 g
F P
s
P
p
.49113 .46532 m .49069 .46539 L .47754 .4672 L 1 g
F
P
p
.002 w
.48904 .46771 m .48711 .46594 L p
.48918 .46562 L 1 g
F P
s
P
p
.49133 .4653 m .48884 .46571 L .48711 .46594 L 1 g
F
P
p
.49069 .46539 m .48711 .46594 L .47754 .4672 L 1 g
F
P
p
.002 w
.49226 .46515 m .48904 .46771 L p
.48918 .46562 L 1 g
F P
s
P
p
.49133 .4653 m .48711 .46594 L .49069 .46539 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.50102 .48796 m .48904 .46771 L .49226 .46515 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46386 m .50102 .48796 L .49226 .46515 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46714 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46714 L .51 .46532 L 1 g
F
P
p
.5099 .46531 m .50102 .48796 L .5 .46386 L 1 g
F
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51 .46532 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53547 .47438 m .50102 .48796 L p
.51133 .46167 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47672 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54233 .47672 m .54245 .50651 L .53635 .47398 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56592 .50918 L p
1 g
F P
s
P
p
.002 w
.57734 .50085 m .57375 .52607 L p
.56668 .51081 L 1 g
F P
s
P
p
.55661 .4905 m .56592 .50918 L .56313 .50315 L 1 g
F
P
p
.56868 .45948 m .56384 .49756 L .5543 .48527 L 1 g
F
P
p
.56384 .49756 m .56313 .50315 L .55718 .49111 L 1 g
F
P
p
.56384 .49756 m .55718 .49111 L .5543 .48527 L 1 g
F
P
p
.55661 .4905 m .56313 .50315 L .56155 .49995 L 1 g
F
P
p
.002 w
.56868 .45948 m .57734 .50085 L .56313 .50315 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.53838 .53725 m .54245 .50651 L .56313 .50315 L p
1 g
F P
s
P
p
.57734 .50085 m .56668 .51081 L .56592 .50918 L 1 g
F
P
p
.002 w
.56592 .50918 m .56515 .50826 L p
.56645 .51671 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56728 .52842 L p
1 g
F P
s
P
p
.56515 .50826 m .56728 .52842 L .56645 .51671 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56592 .50918 m .53838 .53725 L .56313 .50315 L 1 g
F
P
p
.56668 .51081 m .56608 .51137 L .56592 .50918 L 1 g
F
P
p
.56608 .51137 m .53838 .53725 L .56592 .50918 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56668 .51081 m .56875 .52292 L .53838 .53725 L 1 g
F
P
p
.002 w
.57172 .54025 m .56429 .53958 L p
.56875 .52292 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56147 .54702 L p
1 g
F P
s
P
p
.57172 .54025 m .55166 .57286 L .56147 .54702 L 1 g
F
P
p
.56381 .54405 m .56147 .54702 L .56232 .54477 L 1 g
F
P
p
.57172 .54025 m .56147 .54702 L .56381 .54405 L 1 g
F
P
p
.002 w
.56147 .54702 m .56075 .54566 L p
.55661 .55316 L 1 g
F P
s
P
p
.56654 .52734 m .56147 .54702 L .5633 .54219 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54907 .56271 L p
1 g
F P
s
P
p
.56147 .54702 m .55807 .55598 L .55364 .55692 L 1 g
F
P
p
.002 w
.55166 .57286 m .54064 .56901 L p
.55807 .55598 L 1 g
F P
s
P
p
.56075 .54566 m .54907 .56271 L .55661 .55316 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5316 .57411 L p
1 g
F P
s
P
p
.55295 .57331 m .52505 .57781 L .5316 .57411 L 1 g
F
P
p
.002 w
.54064 .56901 m .54416 .57024 L p
.5316 .57411 L 1 g
F P
s
P
p
.002 w
.54416 .57024 m .55295 .57331 L p
.5316 .57411 L 1 g
F P
s
P
p
.002 w
.5316 .57411 m .53128 .57265 L p
.52364 .57657 L 1 g
F P
s
P
p
.54854 .56129 m .5316 .57411 L .53738 .57085 L 1 g
F
P
p
.54854 .56129 m .53191 .57553 L .53973 .56969 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.55295 .57331 m .54864 .57673 L p
.52232 .57936 L 1 g
F P
s
P
p
.52505 .57781 m .52232 .57936 L .50451 .58113 L 1 g
F
P
p
.55295 .57331 m .52232 .57936 L .52505 .57781 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54954 .56398 L p
1 g
F P
s
P
p
.002 w
.54954 .56398 m .54854 .56129 L p
.54016 .56928 L 1 g
F P
s
P
p
.54016 .56928 m .5322 .57686 L .54954 .56398 L 1 g
F
P
p
.52505 .57781 m .50451 .58113 L .54064 .56901 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5316 .57411 L p
1 g
F P
s
P
p
.52364 .57657 m .51111 .583 L .5316 .57411 L 1 g
F
P
p
.002 w
.5316 .57411 m .53191 .57553 L p
.53738 .57085 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.52402 .56319 m .54064 .56901 L p
.50451 .58113 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54064 .56901 m .52402 .56319 L p
.55807 .55598 L 1 g
F P
s
P
p
.002 w
.54907 .56271 m .54998 .56518 L p
.55661 .55316 L 1 g
F P
s
P
p
.56232 .54477 m .56147 .54702 L .52402 .56319 L 1 g
F
P
p
.56147 .54702 m .55364 .55692 L .52402 .56319 L 1 g
F
P
p
.002 w
.53191 .57553 m .5322 .57686 L p
.53973 .56969 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56147 .54702 L p
1 g
F P
s
P
p
.55661 .55316 m .54998 .56518 L .56147 .54702 L 1 g
F
P
p
.002 w
.56429 .53958 m .57172 .54025 L p
.56232 .54477 L 1 g
F P
s
P
p
.56654 .52734 m .56202 .54806 L .56433 .53945 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52402 .56319 m .53838 .53725 L .56429 .53958 L p
1 g
F P
s
P
p
.56232 .54477 m .52402 .56319 L .56429 .53958 L 1 g
F
P
p
.002 w
.56202 .54806 m .56257 .5491 L p
.56432 .53952 L 1 g
F P
s
P
p
.56433 .53945 m .56429 .53958 L .56432 .53952 L 1 g
F
P
p
.56429 .53958 m .56202 .54806 L .56432 .53952 L 1 g
F
P
p
.002 w
.56147 .54702 m .56202 .54806 L p
.5633 .54219 L 1 g
F P
s
P
p
.002 w
.57172 .54025 m .55295 .57331 L .55166 .57286 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56429 .53958 m .53838 .53725 L p
.56875 .52292 L 1 g
F P
s
P
p
.002 w
.56728 .52842 m .56854 .53025 L p
.56645 .51671 L 1 g
F P
s
P
p
.002 w
.57375 .52607 m .57172 .54025 L p
.56668 .51081 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56592 .50918 L p
1 g
F P
s
P
p
.56645 .51671 m .56854 .53025 L .56592 .50918 L 1 g
F
P
p
.002 w
.56313 .50315 m .56547 .50277 L p
.56592 .50918 L 1 g
F P
s
P
p
.002 w
.56547 .50277 m .57734 .50085 L p
.56592 .50918 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55791 .49189 L p
1 g
F P
s
P
p
.002 w
.55791 .49189 m .55661 .4905 L p
.56242 .50162 L 1 g
F P
s
P
p
.56242 .50162 m .56713 .51061 L .55791 .49189 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55718 .49111 L p
1 g
F P
s
P
p
.002 w
.56313 .50315 m .54245 .50651 L p
.5532 .48725 L 1 g
F P
s
P
p
.54174 .47608 m .55718 .49111 L .54851 .48271 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.5543 .48527 m .55718 .49111 L .5532 .48725 L 1 g
F
P
p
.55718 .49111 m .56313 .50315 L .5532 .48725 L 1 g
F
P
p
.5532 .48725 m .54245 .50651 L .54233 .47672 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54233 .47672 L p
1 g
F P
s
P
p
.002 w
.54233 .47672 m .54174 .47608 L p
.54851 .48271 L 1 g
F P
s
P
p
.54851 .48271 m .55834 .49233 L .54233 .47672 L 1 g
F
P
p
.56155 .49995 m .56313 .50315 L .56242 .50162 L 1 g
F
P
p
.002 w
.56592 .50918 m .56713 .51061 L p
.56242 .50162 L 1 g
F P
s
P
p
.55566 .48283 m .5532 .48725 L .54233 .47672 L 1 g
F
P
p
.002 w
.55718 .49111 m .55834 .49233 L p
.54851 .48271 L 1 g
F P
s
P
p
.002 w
.54233 .47672 m .54271 .47714 L p
.53791 .4747 L 1 g
F P
s
P
p
.52214 .46667 m .54233 .47672 L .53791 .4747 L 1 g
F
P
p
.002 w
.54245 .50651 m .53547 .47438 L .53635 .47398 L p
1 g
F P
s
P
p
.52214 .46667 m .53905 .47528 L .53527 .47347 L 1 g
F
P
p
.002 w
.51802 .4446 m .54641 .42107 L p
.53562 .47363 L 1 g
F P
s
P
p
.002 w
.53547 .47438 m .5348 .47324 L p
.53562 .47363 L 1 g
F P
s
P
p
.002 w
.5348 .47324 m .53547 .47438 L p
.51133 .46167 L 1 g
F P
s
P
p
.002 w
.52257 .46738 m .52214 .46667 L p
.53527 .47347 L 1 g
F P
s
P
p
.002 w
.5348 .47324 m .51802 .4446 L p
.53562 .47363 L 1 g
F P
s
P
p
.002 w
.53635 .47398 m .53547 .47438 L p
.53562 .47363 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52257 .46738 L p
1 g
F P
s
P
p
.53527 .47347 m .54302 .47747 L .52257 .46738 L 1 g
F
P
p
.53527 .47347 m .54271 .47714 L .53554 .47361 L 1 g
F
P
p
.53905 .47528 m .54271 .47714 L .53527 .47347 L 1 g
F
P
p
.002 w
.54641 .42107 m .56868 .45948 L .53635 .47398 L p
1 g
F P
s
P
p
.54641 .42107 m .53635 .47398 L .53562 .47363 L 1 g
F
P
p
.002 w
.53635 .47398 m .56868 .45948 L p
.55566 .48283 L 1 g
F P
s
P
p
.002 w
.51802 .4446 m .5348 .47324 L p
.51133 .46167 L 1 g
F P
s
P
p
.002 w
.54271 .47714 m .54302 .47747 L p
.53554 .47361 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46386 L p
1 g
F P
s
P
p
.51 .46532 m .52282 .46778 L .5 .46386 L 1 g
F
P
p
.51802 .4446 m .5112 .46201 L .5 .46386 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .46442 L p
.49133 .4653 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46386 L .49133 .4653 L 1 g
F
P
p
.002 w
.49226 .46515 m .49482 .46311 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.49482 .46311 m .51802 .4446 L p
.5 .46386 L 1 g
F P
s
P
p
.5112 .46201 m .5099 .46531 L .5 .46386 L 1 g
F
P
p
.002 w
.52242 .46714 m .52282 .46778 L p
.51 .46532 L 1 g
F P
s
P
p
.002 w
.49206 .42072 m .51802 .4446 L .49226 .46515 L p
1 g
F P
s
P
p
.49206 .42072 m .49226 .46515 L .48918 .46562 L 1 g
F
P
p
.002 w
.47135 .45146 m .49206 .42072 L p
.48918 .46562 L 1 g
F P
s
P
p
.002 w
.48711 .46594 m .47135 .45146 L p
.48918 .46562 L 1 g
F P
s
P
p
.49113 .46532 m .49133 .4653 L .49069 .46539 L 1 g
F
P
p
.49133 .4653 m .49423 .465 L .48884 .46571 L 1 g
F
P
p
.002 w
.47135 .45146 m .48711 .46594 L p
.4665 .46865 L 1 g
F P
s
P
p
.002 w
.48711 .46594 m .48904 .46771 L p
.4665 .46865 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47754 .4672 L p
1 g
F P
s
P
p
.49423 .465 m .5 .46442 L .47754 .4672 L 1 g
F
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46747 .47204 L 1 g
F P
s
P
p
.44339 .4905 m .45762 .47678 L .45449 .47983 L 1 g
F
P
p
.44339 .4905 m .45733 .4771 L .45205 .4822 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45234 .48192 m .45168 .48132 L p
.45579 .47766 L 1 g
F P
s
P
p
.4667 .46794 m .45762 .47678 L .45579 .47766 L 1 g
F
P
p
.45762 .47678 m .45234 .48192 L .45579 .47766 L 1 g
F
P
p
.4667 .46794 m .46523 .47312 L .45762 .47678 L 1 g
F
P
p
.46523 .47312 m .46061 .48951 L .45762 .47678 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45762 .47678 L p
1 g
F P
s
P
p
.46747 .47204 m .47718 .46778 L .45762 .47678 L 1 g
F
P
p
.002 w
.45762 .47678 m .45733 .4771 L p
.45449 .47983 L 1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45168 .48132 m .47135 .45146 L p
.4667 .46794 L 1 g
F P
s
P
p
.002 w
.44828 .47965 m .45168 .48132 L .44958 .48459 L p
1 g
F P
s
P
p
.002 w
.44958 .48459 m .43423 .5085 L p
.44258 .49136 L 1 g
F P
s
P
p
.44828 .47965 m .44958 .48459 L .44258 .49136 L 1 g
F
P
p
.002 w
.45733 .4771 m .45698 .47747 L p
.45205 .4822 L 1 g
F P
s
P
p
.002 w
.44958 .48459 m .45168 .48132 L p
.44961 .48456 L 1 g
F P
s
P
p
.44961 .48456 m .43397 .50904 L .44958 .48459 L 1 g
F
P
p
.002 w
.46061 .48951 m .43397 .50904 L p
.44961 .48456 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .44258 .49136 L p
.4431 .49086 L 1 g
F P
s
P
p
.4431 .49086 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.45199 .48226 m .45205 .4822 L .44958 .48459 L 1 g
F
P
p
.002 w
.45168 .48132 m .45234 .48192 L p
.44961 .48456 L 1 g
F P
s
P
p
.45205 .4822 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.43763 .50152 m .43851 .49971 L .43765 .50148 L 1 g
F
P
p
.43848 .49978 m .43851 .49971 L .43763 .50152 L 1 g
F
P
p
.002 w
.44166 .49233 m .43994 .49591 L p
.43765 .50148 L 1 g
F P
s
P
p
.43851 .49971 m .44166 .49233 L .43765 .50148 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52872 L p
1 g
F P
s
P
p
.43315 .51837 m .43287 .51061 L .43251 .52872 L 1 g
F
P
p
.43468 .53663 m .43467 .53661 L .4347 .53667 L 1 g
F
P
p
.43467 .53661 m .433 .53329 L .43571 .5404 L 1 g
F
P
p
.002 w
.43462 .54256 m .43443 .54057 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.45863 .56821 m .45729 .56818 L p
.43443 .54057 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43443 .54057 m .44551 .54066 L .45863 .56821 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43836 .54734 L p
1 g
F P
s
P
p
.433 .53329 m .43146 .53025 L .43836 .54734 L 1 g
F
P
p
.45729 .56818 m .45076 .56318 L .43728 .54452 L 1 g
F
P
p
.45729 .56818 m .43728 .54452 L .43693 .54358 L 1 g
F
P
p
.002 w
.43836 .54734 m .43743 .5491 L p
.44465 .55537 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45076 .56318 L p
1 g
F P
s
P
p
.44465 .55537 m .43743 .5491 L .45076 .56318 L 1 g
F
P
p
.002 w
.45076 .56318 m .45029 .56445 L p
.45536 .56671 L 1 g
F P
s
P
p
.002 w
.45029 .56445 m .45002 .56518 L p
.45563 .56742 L 1 g
F P
s
P
p
.002 w
.45863 .56821 m .47826 .56166 L .50096 .58143 L p
1 g
F P
s
P
p
.002 w
.50096 .58143 m .50122 .58166 L p
.50035 .58139 L 1 g
F P
s
P
p
.50035 .58139 m .45863 .56821 L .50096 .58143 L 1 g
F
P
p
.002 w
.48907 .58052 m .48891 .58268 L p
.4972 .58115 L 1 g
F P
s
P
p
.002 w
.48891 .58268 m .48889 .583 L p
.49198 .58238 L 1 g
F P
s
P
p
.002 w
.50122 .58166 m .50151 .58143 L p
.50451 .58113 L 1 g
F P
s
P
p
.002 w
.50151 .58143 m .52402 .56319 L p
.50451 .58113 L 1 g
F P
s
P
p
.002 w
.52402 .56319 m .50151 .58143 L p
.47826 .56166 L 1 g
F P
s
P
p
.002 w
.50096 .58143 m .47826 .56166 L p
.50151 .58143 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58052 L p
1 g
F P
s
P
p
.47993 .57786 m .4678 .57686 L .48907 .58052 L 1 g
F
P
p
.49789 .5812 m .49198 .58238 L .50126 .58145 L 1 g
F
P
p
.002 w
.51093 .58049 m .51111 .583 L p
.52364 .57657 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58049 L p
1 g
F P
s
P
p
.49198 .58238 m .48889 .583 L .51093 .58049 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.63736 .48365 m .62894 .53627 L .60224 .53988 L p
1 g
F P
s
P
p
.004 w
.5074 .43482 m
.52056 .4425 L
s
P
p
.004 w
.57132 .47209 m
.62502 .5034 L
s
P
p
.002 w
.62894 .53627 m .63736 .48365 L .66052 .47288 L p
1 g
F P
s
P
p
.004 w
.65391 .52024 m
.67382 .53185 L
s
P
p
.002 w
.5693 .31239 m .51054 .28491 L .52242 .26534 L p
1 g
F P
s
P
p
.002 w
.52242 .26534 m .58367 .29384 L .5693 .31239 L p
1 g
F P
s
P
p
.002 w
.64913 .41284 m .66052 .47288 L .63736 .48365 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.37126 .42305 m .35413 .44684 L .33636 .42506 L p
1 g
F P
s
P
p
.002 w
.33636 .42506 m .35799 .39438 L .37126 .42305 L p
1 g
F P
s
P
p
.002 w
.39027 .37353 m .35799 .39438 L .34926 .36746 L p
1 g
F P
s
P
p
.002 w
.34926 .36746 m .38737 .34233 L .39027 .37353 L p
1 g
F P
s
P
p
.002 w
.64913 .41284 m .61753 .35694 L .63387 .34024 L p
1 g
F P
s
P
p
.002 w
.58367 .29384 m .63387 .34024 L .61753 .35694 L p
1 g
F P
s
P
p
.002 w
.43443 .33209 m .38737 .34233 L .38791 .31451 L p
1 g
F P
s
P
p
.002 w
.38791 .31451 m .44082 .30259 L .43443 .33209 L p
1 g
F P
s
P
p
.002 w
.49796 .30956 m .44082 .30259 L .44881 .27769 L p
1 g
F P
s
P
p
.002 w
.44881 .27769 m .51054 .28491 L .49796 .30956 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.61753 .35694 m .5693 .31239 L .58367 .29384 L p
1 g
F P
s
P
p
.002 w
.37679 .46866 m .37156 .48845 L .34679 .47567 L p
1 g
F P
s
P
p
.002 w
.34679 .47567 m .35413 .44684 L .37679 .46866 L p
1 g
F P
s
P
p
.002 w
.40621 .52119 m .41369 .53028 L .39675 .54781 L p
1 g
F P
s
P
p
.002 w
.39675 .54781 m .38218 .53017 L .40621 .52119 L p
1 g
F P
s
P
p
.002 w
.41567 .56082 m .39675 .54781 L .41369 .53028 L p
1 g
F P
s
P
p
.002 w
.41369 .53028 m .42344 .53697 L .41567 .56082 L p
1 g
F P
s
P
p
.002 w
.43702 .56788 m .41567 .56082 L .42344 .53697 L p
1 g
F P
s
P
p
.002 w
.40178 .51065 m .40621 .52119 L .38218 .53017 L p
1 g
F P
s
P
p
.002 w
.38218 .53017 m .37346 .50969 L .40178 .51065 L p
1 g
F P
s
P
p
.002 w
.55295 .57331 m .57172 .54025 L .60224 .53988 L p
1 g
F P
s
P
p
.002 w
.42344 .53697 m .43443 .54057 L .43702 .56788 L p
1 g
F P
s
P
p
.002 w
.63736 .48365 m .62651 .42811 L .64913 .41284 L p
1 g
F P
s
P
p
.002 w
.61753 .35694 m .64913 .41284 L .62651 .42811 L p
1 g
F P
s
P
p
.002 w
.60935 .49311 m .60224 .53988 L .57172 .54025 L p
1 g
F P
s
P
p
.002 w
.60224 .53988 m .60935 .49311 L .63736 .48365 L p
1 g
F P
s
P
p
.004 w
.62813 .50521 m
.63321 .50818 L
s
P
p
.004 w
.63321 .50818 m
.65391 .52024 L
s
P
p
.004 w
.62711 .50462 m
.62813 .50521 L
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40088 .49977 m .40178 .51065 L .37346 .50969 L p
1 g
F P
s
P
p
.002 w
.37346 .50969 m .37156 .48845 L .40088 .49977 L p
1 g
F P
s
P
p
.002 w
.62651 .42811 m .63736 .48365 L .60935 .49311 L p
1 g
F P
s
P
p
.002 w
.38873 .45247 m .37679 .46866 L .35413 .44684 L p
1 g
F P
s
P
p
.002 w
.35413 .44684 m .37126 .42305 L .38873 .45247 L p
1 g
F P
s
P
p
.002 w
.39661 .40707 m .37126 .42305 L .35799 .39438 L p
1 g
F P
s
P
p
.002 w
.35799 .39438 m .39027 .37353 L .39661 .40707 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55235 .33515 m .49796 .30956 L .51054 .28491 L p
1 g
F P
s
P
p
.002 w
.51054 .28491 m .5693 .31239 L .55235 .33515 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.47826 .56166 m .45863 .56821 L .44551 .54066 L p
1 g
F P
s
P
p
.002 w
.42993 .36526 m .39027 .37353 L .38737 .34233 L p
1 g
F P
s
P
p
.002 w
.38737 .34233 m .43443 .33209 L .42993 .36526 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.48513 .33857 m .43443 .33209 L .44082 .30259 L p
1 g
F P
s
P
p
.002 w
.44082 .30259 m .49796 .30956 L .48513 .33857 L p
1 g
F P
s
P
p
.002 w
.40366 .4897 m .40088 .49977 L .37156 .48845 L p
1 g
F P
s
P
p
.002 w
.37156 .48845 m .37679 .46866 L .40366 .4897 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62651 .42811 m .59707 .37641 L .61753 .35694 L p
1 g
F P
s
P
p
.002 w
.5693 .31239 m .61753 .35694 L .59707 .37641 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59707 .37641 m .55235 .33515 L .5693 .31239 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.47826 .56166 m .49378 .54881 L .52402 .56319 L p
1 g
F P
s
P
p
.002 w
.53838 .53725 m .52402 .56319 L .49378 .54881 L p
1 g
F P
s
P
p
.002 w
.44551 .54066 m .4555 .53722 L .47826 .56166 L p
1 g
F P
s
P
p
.002 w
.49378 .54881 m .47826 .56166 L .4555 .53722 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57172 .54025 m .57734 .50085 L .60935 .49311 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.40983 .48154 m .40366 .4897 L .37679 .46866 L p
1 g
F P
s
P
p
.002 w
.37679 .46866 m .38873 .45247 L .40983 .48154 L p
1 g
F P
s
P
p
.002 w
.40622 .44173 m .38873 .45247 L .37126 .42305 L p
1 g
F P
s
P
p
.002 w
.37126 .42305 m .39661 .40707 L .40622 .44173 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.60935 .49311 m .5994 .44386 L .62651 .42811 L p
1 g
F P
s
P
p
.002 w
.59707 .37641 m .62651 .42811 L .5994 .44386 L p
1 g
F P
s
P
p
.002 w
.5994 .44386 m .60935 .49311 L .57734 .50085 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42755 .40093 m .39661 .40707 L .39027 .37353 L p
1 g
F P
s
P
p
.002 w
.39027 .37353 m .42993 .36526 L .42755 .40093 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53336 .36143 m .48513 .33857 L .49796 .30956 L p
1 g
F P
s
P
p
.002 w
.49796 .30956 m .55235 .33515 L .53336 .36143 L p
1 g
F P
s
P
p
.002 w
.4555 .53722 m .46332 .53059 L .49378 .54881 L p
1 g
F P
s
P
p
.002 w
.50341 .53092 m .49378 .54881 L .46332 .53059 L p
1 g
F P
s
P
p
.002 w
.49378 .54881 m .50341 .53092 L .53838 .53725 L p
1 g
F P
s
P
p
.002 w
.47253 .37098 m .42993 .36526 L .43443 .33209 L p
1 g
F P
s
P
p
.002 w
.43443 .33209 m .48513 .33857 L .47253 .37098 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54245 .50651 m .53838 .53725 L .50341 .53092 L p
1 g
F P
s
P
p
.002 w
.41878 .4762 m .40983 .48154 L .38873 .45247 L p
1 g
F P
s
P
p
.002 w
.38873 .45247 m .40622 .44173 L .41878 .4762 L p
1 g
F P
s
P
p
.002 w
.5994 .44386 m .57308 .39805 L .59707 .37641 L p
1 g
F P
s
P
p
.002 w
.55235 .33515 m .59707 .37641 L .57308 .39805 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.57308 .39805 m .53336 .36143 L .55235 .33515 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46332 .53059 m .4681 .52144 L .50341 .53092 L p
1 g
F P
s
P
p
.002 w
.42741 .43774 m .40622 .44173 L .39661 .40707 L p
1 g
F P
s
P
p
.002 w
.39661 .40707 m .42755 .40093 L .42741 .43774 L p
1 g
F P
s
P
p
.002 w
.57734 .50085 m .56868 .45948 L .5994 .44386 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50596 .50986 m .50341 .53092 L .4681 .52144 L p
1 g
F P
s
P
p
.002 w
.50341 .53092 m .50596 .50986 L .54245 .50651 L p
1 g
F P
s
P
p
.002 w
.57308 .39805 m .5994 .44386 L .56868 .45948 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.004 w
.43318 .5099 m
.43327 .5098 L
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4681 .52144 m .46928 .51075 L .50596 .50986 L p
1 g
F P
s
P
p
.002 w
.46066 .40559 m .42755 .40093 L .42993 .36526 L p
1 g
F P
s
P
p
.002 w
.42993 .36526 m .47253 .37098 L .46066 .40559 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.42953 .47429 m .41878 .4762 L .40622 .44173 L p
1 g
F P
s
P
p
.002 w
.40622 .44173 m .42741 .43774 L .42953 .47429 L p
1 g
F P
s
P
p
.002 w
.51301 .39031 m .47253 .37098 L .48513 .33857 L p
1 g
F P
s
P
p
.002 w
.48513 .33857 m .53336 .36143 L .51301 .39031 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.004 w
.4312 .51225 m
.43129 .51214 L
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53547 .47438 m .54245 .50651 L .50596 .50986 L p
1 g
F P
s
P
p
.002 w
.46928 .51075 m .46669 .4997 L .50102 .48796 L p
1 g
F P
s
P
p
.002 w
.50102 .48796 m .50596 .50986 L .46928 .51075 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.44092 .47605 m .42953 .47429 L .42741 .43774 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56868 .45948 m .54641 .42107 L .57308 .39805 L p
1 g
F P
s
P
p
.002 w
.53336 .36143 m .57308 .39805 L .54641 .42107 L p
1 g
F P
s
P
p
.002 w
.50596 .50986 m .50102 .48796 L .53547 .47438 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.44998 .44108 m .42741 .43774 L .42755 .40093 L p
1 g
F P
s
P
p
.002 w
.42755 .40093 m .46066 .40559 L .44998 .44108 L p
1 g
F P
s
P
p
.002 w
.46669 .4997 m .46061 .48951 L .48904 .46771 L p
1 g
F P
s
P
p
.002 w
.48904 .46771 m .50102 .48796 L .46669 .4997 L p
1 g
F P
s
P
p
.002 w
.54641 .42107 m .51301 .39031 L .53336 .36143 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.004 w
.42921 .51461 m
.4293 .51451 L
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.45168 .48132 m .44092 .47605 L .44998 .44108 L p
1 g
F P
s
P
p
.002 w
.42741 .43774 m .44998 .44108 L .44092 .47605 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.44998 .44108 m .47135 .45146 L .45168 .48132 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49206 .42072 m .46066 .40559 L .47253 .37098 L p
1 g
F P
s
P
p
.002 w
.47253 .37098 m .51301 .39031 L .49206 .42072 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.004 w
.42721 .517 m
.4273 .51689 L
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.47135 .45146 m .44998 .44108 L .46066 .40559 L p
1 g
F P
s
P
p
.002 w
.51301 .39031 m .54641 .42107 L .51802 .4446 L p
1 g
F P
s
P
p
.002 w
.46066 .40559 m .49206 .42072 L .47135 .45146 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51802 .4446 m .49206 .42072 L .51301 .39031 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.004 w
.42519 .5194 m
.42528 .51929 L
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.004 w
.42315 .52181 m
.42324 .52171 L
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.004 w
.42111 .52425 m
.4212 .52414 L
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.004 w
.41904 .5267 m
.41913 .52659 L
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.004 w
.41697 .52917 m
.41706 .52906 L
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.004 w
.41487 .53165 m
.41497 .53154 L
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.004 w
.3937 .55681 m
.41074 .53657 L
s
P
p
.004 w
.41277 .53416 m
.41286 .53404 L
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .70372 .54929 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .3937 .55681 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.227907)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.227907)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45796 .42178 m .47177 .44507 L .49366 .42684 L p
1 g
F P
s
P
p
.002 w
.49366 .42684 m .48428 .41097 L .45796 .42178 L p
1 g
F P
s
P
p
.002 w
.50753 .43907 m .49366 .42684 L .47177 .44507 L p
1 g
F P
s
P
p
.002 w
.48428 .41097 m .49366 .42684 L .51569 .40871 L p
1 g
F P
s
P
p
.002 w
.49366 .42684 m .50753 .43907 L .52273 .41491 L p
1 g
F P
s
P
p
.002 w
.52273 .41491 m .51569 .40871 L .49366 .42684 L p
1 g
F P
s
P
p
.002 w
.47177 .44507 m .49213 .46303 L .50753 .43907 L p
1 g
F P
s
P
p
.002 w
.52443 .44636 m .50753 .43907 L .49213 .46303 L p
1 g
F P
s
P
p
.002 w
.50753 .43907 m .52443 .44636 L .53131 .4186 L p
1 g
F P
s
P
p
.002 w
.53131 .4186 m .52273 .41491 L .50753 .43907 L p
1 g
F P
s
P
p
.002 w
.45215 .39553 m .45796 .42178 L .48428 .41097 L p
1 g
F P
s
P
p
.002 w
.48428 .41097 m .4804 .3931 L .45215 .39553 L p
1 g
F P
s
P
p
.002 w
.4804 .3931 m .48428 .41097 L .51095 .40065 L p
1 g
F P
s
P
p
.002 w
.51569 .40871 m .51095 .40065 L .48428 .41097 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .51095 .40065 L .51569 .40871 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .51569 .40871 L .52273 .41491 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .52273 .41491 L .53131 .4186 L closepath p
1 g
F P
s
P
p
.002 w
.49213 .46303 m .51694 .4738 L .52443 .44636 L p
1 g
F P
s
P
p
.002 w
.54261 .44794 m .52443 .44636 L .51694 .4738 L p
1 g
F P
s
P
p
.002 w
.52443 .44636 m .54261 .44794 L .54053 .41936 L p
1 g
F P
s
P
p
.002 w
.54053 .41936 m .53131 .4186 L .52443 .44636 L p
1 g
F P
s
P
p
.002 w
.43245 .43288 m .45042 .46307 L .47177 .44507 L p
1 g
F P
s
P
p
.002 w
.47177 .44507 m .45796 .42178 L .43245 .43288 L p
1 g
F P
s
P
p
.002 w
.49213 .46303 m .47177 .44507 L .45042 .46307 L p
1 g
F P
s
P
p
.002 w
.51095 .40065 m .50901 .39158 L .4804 .3931 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .50901 .39158 L .51095 .40065 L closepath p
1 g
F P
s
P
p
.002 w
.45042 .46307 m .47682 .48637 L .49213 .46303 L p
1 g
F P
s
P
p
.002 w
.51694 .4738 m .49213 .46303 L .47682 .48637 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .53131 .4186 L .54053 .41936 L closepath p
1 g
F P
s
P
p
.002 w
.48244 .37511 m .4804 .3931 L .50901 .39158 L p
1 g
F P
s
P
p
.002 w
.50901 .39158 m .51009 .38248 L .48244 .37511 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .51009 .38248 L .50901 .39158 L closepath p
1 g
F P
s
P
p
.002 w
.54939 .41711 m .54053 .41936 L .54261 .44794 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .54053 .41936 L .54939 .41711 L closepath p
1 g
F P
s
P
p
.002 w
.45503 .36904 m .45215 .39553 L .4804 .3931 L p
1 g
F P
s
P
p
.002 w
.4804 .3931 m .48244 .37511 L .45503 .36904 L p
1 g
F P
s
P
p
.002 w
.42479 .39884 m .43245 .43288 L .45796 .42178 L p
1 g
F P
s
P
p
.002 w
.45796 .42178 m .45215 .39553 L .42479 .39884 L p
1 g
F P
s
P
p
.002 w
.51694 .4738 m .54366 .47622 L .54261 .44794 L p
1 g
F P
s
P
p
.002 w
.56014 .44359 m .54261 .44794 L .54366 .47622 L p
1 g
F P
s
P
p
.002 w
.54261 .44794 m .56014 .44359 L .54939 .41711 L p
1 g
F P
s
P
p
.002 w
.47682 .48637 m .50898 .50042 L .51694 .4738 L p
1 g
F P
s
P
p
.002 w
.54366 .47622 m .51694 .4738 L .50898 .50042 L p
1 g
F P
s
P
p
.002 w
.49026 .35892 m .48244 .37511 L .51009 .38248 L p
1 g
F P
s
P
p
.002 w
.51009 .38248 m .51409 .37432 L .49026 .35892 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .51409 .37432 L .51009 .38248 L closepath p
1 g
F P
s
P
p
.002 w
.55695 .41208 m .54939 .41711 L .56014 .44359 L p
1 g
F P
s
P
p
.002 w
.53747 .391 m .54939 .41711 L .55695 .41208 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .55695 .41208 L .56237 .40479 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .56505 .39602 L .56469 .38674 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .56469 .38674 L .56131 .37795 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .56131 .37795 L .55528 .37062 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .55528 .37062 L .54726 .36557 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .54726 .36557 L .53813 .36335 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .53813 .36335 L .52891 .36419 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .52891 .36419 L .52059 .36799 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .52059 .36799 L .51409 .37432 L closepath p
1 g
F P
s
P
p
.002 w
.53747 .391 m .56237 .40479 L .56505 .39602 L closepath p
1 g
F P
s
P
p
.002 w
.50307 .34631 m .49026 .35892 L .51409 .37432 L p
1 g
F P
s
P
p
.002 w
.51409 .37432 m .52059 .36799 L .50307 .34631 L p
1 g
F P
s
P
p
.002 w
.46642 .34512 m .45503 .36904 L .48244 .37511 L p
1 g
F P
s
P
p
.002 w
.48244 .37511 m .49026 .35892 L .46642 .34512 L p
1 g
F P
s
P
p
.002 w
.42837 .36441 m .42479 .39884 L .45215 .39553 L p
1 g
F P
s
P
p
.002 w
.45215 .39553 m .45503 .36904 L .42837 .36441 L p
1 g
F P
s
P
p
.002 w
.40823 .44409 m .43 .48052 L .45042 .46307 L p
1 g
F P
s
P
p
.002 w
.45042 .46307 m .43245 .43288 L .40823 .44409 L p
1 g
F P
s
P
p
.002 w
.47682 .48637 m .45042 .46307 L .43 .48052 L p
1 g
F P
s
P
p
.002 w
.56014 .44359 m .57515 .43372 L .55695 .41208 L p
1 g
F P
s
P
p
.002 w
.56237 .40479 m .55695 .41208 L .57515 .43372 L p
1 g
F P
s
P
p
.002 w
.43 .48052 m .46187 .50866 L .47682 .48637 L p
1 g
F P
s
P
p
.002 w
.50898 .50042 m .47682 .48637 L .46187 .50866 L p
1 g
F P
s
P
p
.002 w
.54366 .47622 m .5695 .46995 L .56014 .44359 L p
1 g
F P
s
P
p
.002 w
.57515 .43372 m .56014 .44359 L .5695 .46995 L p
1 g
F P
s
P
p
.002 w
.50898 .50042 m .54365 .50369 L .54366 .47622 L p
1 g
F P
s
P
p
.002 w
.5695 .46995 m .54366 .47622 L .54365 .50369 L p
1 g
F P
s
P
p
.002 w
.51953 .33868 m .50307 .34631 L .52059 .36799 L p
1 g
F P
s
P
p
.002 w
.52059 .36799 m .52891 .36419 L .51953 .33868 L p
1 g
F P
s
P
p
.002 w
.57515 .43372 m .58598 .41933 L .56237 .40479 L p
1 g
F P
s
P
p
.002 w
.56505 .39602 m .56237 .40479 L .58598 .41933 L p
1 g
F P
s
P
p
.002 w
.39885 .40298 m .40823 .44409 L .43245 .43288 L p
1 g
F P
s
P
p
.002 w
.43245 .43288 m .42479 .39884 L .39885 .40298 L p
1 g
F P
s
P
p
.002 w
.46187 .50866 m .50068 .5257 L .50898 .50042 L p
1 g
F P
s
P
p
.002 w
.54365 .50369 m .50898 .50042 L .50068 .5257 L p
1 g
F P
s
P
p
.002 w
.48522 .32639 m .46642 .34512 L .49026 .35892 L p
1 g
F P
s
P
p
.002 w
.49026 .35892 m .50307 .34631 L .48522 .32639 L p
1 g
F P
s
P
p
.002 w
.53786 .33692 m .51953 .33868 L .52891 .36419 L p
1 g
F P
s
P
p
.002 w
.52891 .36419 m .53813 .36335 L .53786 .33692 L p
1 g
F P
s
P
p
.002 w
.56469 .38674 m .56505 .39602 L .5914 .40196 L p
1 g
F P
s
P
p
.002 w
.58598 .41933 m .5914 .40196 L .56505 .39602 L p
1 g
F P
s
P
p
.002 w
.5695 .46995 m .59171 .45553 L .57515 .43372 L p
1 g
F P
s
P
p
.002 w
.58598 .41933 m .57515 .43372 L .59171 .45553 L p
1 g
F P
s
P
p
.002 w
.44301 .33321 m .42837 .36441 L .45503 .36904 L p
1 g
F P
s
P
p
.002 w
.45503 .36904 m .46642 .34512 L .44301 .33321 L p
1 g
F P
s
P
p
.002 w
.55605 .3413 m .53786 .33692 L .53813 .36335 L p
1 g
F P
s
P
p
.002 w
.53813 .36335 m .54726 .36557 L .55605 .3413 L p
1 g
F P
s
P
p
.002 w
.5914 .40196 m .59075 .38349 L .56469 .38674 L p
1 g
F P
s
P
p
.002 w
.56131 .37795 m .56469 .38674 L .59075 .38349 L p
1 g
F P
s
P
p
.002 w
.54365 .50369 m .57728 .49571 L .5695 .46995 L p
1 g
F P
s
P
p
.002 w
.59171 .45553 m .5695 .46995 L .57728 .49571 L p
1 g
F P
s
P
p
.002 w
.57205 .35135 m .55605 .3413 L .54726 .36557 L p
1 g
F P
s
P
p
.002 w
.54726 .36557 m .55528 .37062 L .57205 .35135 L p
1 g
F P
s
P
p
.002 w
.59075 .38349 m .58406 .36596 L .56131 .37795 L p
1 g
F P
s
P
p
.002 w
.55528 .37062 m .56131 .37795 L .58406 .36596 L p
1 g
F P
s
P
p
.002 w
.58406 .36596 m .57205 .35135 L .55528 .37062 L p
1 g
F P
s
P
p
.002 w
.40299 .36133 m .39885 .40298 L .42479 .39884 L p
1 g
F P
s
P
p
.002 w
.42479 .39884 m .42837 .36441 L .40299 .36133 L p
1 g
F P
s
P
p
.002 w
.5095 .31498 m .48522 .32639 L .50307 .34631 L p
1 g
F P
s
P
p
.002 w
.50307 .34631 m .51953 .33868 L .5095 .31498 L p
1 g
F P
s
P
p
.002 w
.50068 .5257 m .54257 .5298 L .54365 .50369 L p
1 g
F P
s
P
p
.002 w
.57728 .49571 m .54365 .50369 L .54257 .5298 L p
1 g
F P
s
P
p
.002 w
.38581 .45518 m .41092 .49706 L .43 .48052 L p
1 g
F P
s
P
p
.002 w
.43 .48052 m .40823 .44409 L .38581 .45518 L p
1 g
F P
s
P
p
.002 w
.46187 .50866 m .43 .48052 L .41092 .49706 L p
1 g
F P
s
P
p
.002 w
.59171 .45553 m .60782 .43438 L .58598 .41933 L p
1 g
F P
s
P
p
.002 w
.5914 .40196 m .58598 .41933 L .60782 .43438 L p
1 g
F P
s
P
p
.002 w
.41092 .49706 m .44758 .52944 L .46187 .50866 L p
1 g
F P
s
P
p
.002 w
.50068 .5257 m .46187 .50866 L .44758 .52944 L p
1 g
F P
s
P
p
.002 w
.46737 .30867 m .44301 .33321 L .46642 .34512 L p
1 g
F P
s
P
p
.002 w
.46642 .34512 m .48522 .32639 L .46737 .30867 L p
1 g
F P
s
P
p
.002 w
.37487 .40791 m .38581 .45518 L .40823 .44409 L p
1 g
F P
s
P
p
.002 w
.40823 .44409 m .39885 .40298 L .37487 .40791 L p
1 g
F P
s
P
p
.002 w
.53665 .31227 m .5095 .31498 L .51953 .33868 L p
1 g
F P
s
P
p
.002 w
.51953 .33868 m .53786 .33692 L .53665 .31227 L p
1 g
F P
s
P
p
.002 w
.57728 .49571 m .60629 .4771 L .59171 .45553 L p
1 g
F P
s
P
p
.002 w
.60782 .43438 m .59171 .45553 L .60629 .4771 L p
1 g
F P
s
P
p
.002 w
.44758 .52944 m .49219 .54913 L .50068 .5257 L p
1 g
F P
s
P
p
.002 w
.54257 .5298 m .50068 .5257 L .49219 .54913 L p
1 g
F P
s
P
p
.002 w
.59075 .38349 m .5914 .40196 L .61597 .40872 L p
1 g
F P
s
P
p
.002 w
.60782 .43438 m .61597 .40872 L .5914 .40196 L p
1 g
F P
s
P
p
.002 w
.42052 .32347 m .40299 .36133 L .42837 .36441 L p
1 g
F P
s
P
p
.002 w
.42837 .36441 m .44301 .33321 L .42052 .32347 L p
1 g
F P
s
P
p
.002 w
.56365 .3187 m .53665 .31227 L .53786 .33692 L p
1 g
F P
s
P
p
.002 w
.53786 .33692 m .55605 .3413 L .56365 .3187 L p
1 g
F P
s
P
p
.002 w
.54257 .5298 m .58329 .52034 L .57728 .49571 L p
1 g
F P
s
P
p
.002 w
.60629 .4771 m .57728 .49571 L .58329 .52034 L p
1 g
F P
s
P
p
.002 w
.61597 .40872 m .61511 .38133 L .59075 .38349 L p
1 g
F P
s
P
p
.002 w
.58406 .36596 m .59075 .38349 L .61511 .38133 L p
1 g
F P
s
P
p
.002 w
.37944 .35992 m .37487 .40791 L .39885 .40298 L p
1 g
F P
s
P
p
.002 w
.39885 .40298 m .40299 .36133 L .37944 .35992 L p
1 g
F P
s
P
p
.002 w
.49899 .29362 m .46737 .30867 L .48522 .32639 L p
1 g
F P
s
P
p
.002 w
.48522 .32639 m .5095 .31498 L .49899 .29362 L p
1 g
F P
s
P
p
.002 w
.58742 .3336 m .56365 .3187 L .55605 .3413 L p
1 g
F P
s
P
p
.002 w
.55605 .3413 m .57205 .35135 L .58742 .3336 L p
1 g
F P
s
P
p
.002 w
.61511 .38133 m .60524 .3553 L .58406 .36596 L p
1 g
F P
s
P
p
.002 w
.57205 .35135 m .58406 .36596 L .60524 .3553 L p
1 g
F P
s
P
p
.002 w
.60524 .3553 m .58742 .3336 L .57205 .35135 L p
1 g
F P
s
P
p
.002 w
.60629 .4771 m .62744 .44965 L .60782 .43438 L p
1 g
F P
s
P
p
.002 w
.61597 .40872 m .60782 .43438 L .62744 .44965 L p
1 g
F P
s
P
p
.002 w
.49219 .54913 m .54039 .55402 L .54257 .5298 L p
1 g
F P
s
P
p
.002 w
.58329 .52034 m .54257 .5298 L .54039 .55402 L p
1 g
F P
s
P
p
.002 w
.36569 .46594 m .39359 .51234 L .41092 .49706 L p
1 g
F P
s
P
p
.002 w
.41092 .49706 m .38581 .45518 L .36569 .46594 L p
1 g
F P
s
P
p
.002 w
.44758 .52944 m .41092 .49706 L .39359 .51234 L p
1 g
F P
s
P
p
.002 w
.39359 .51234 m .43424 .54826 L .44758 .52944 L p
1 g
F P
s
P
p
.002 w
.49219 .54913 m .44758 .52944 L .43424 .54826 L p
1 g
F P
s
P
p
.002 w
.4499 .29357 m .42052 .32347 L .44301 .33321 L p
1 g
F P
s
P
p
.002 w
.44301 .33321 m .46737 .30867 L .4499 .29357 L p
1 g
F P
s
P
p
.002 w
.53448 .28995 m .49899 .29362 L .5095 .31498 L p
1 g
F P
s
P
p
.002 w
.5095 .31498 m .53665 .31227 L .53448 .28995 L p
1 g
F P
s
P
p
.002 w
.58329 .52034 m .61852 .49799 L .60629 .4771 L p
1 g
F P
s
P
p
.002 w
.62744 .44965 m .60629 .4771 L .61852 .49799 L p
1 g
F P
s
P
p
.002 w
.35341 .41353 m .36569 .46594 L .38581 .45518 L p
1 g
F P
s
P
p
.002 w
.38581 .45518 m .37487 .40791 L .35341 .41353 L p
1 g
F P
s
P
p
.002 w
.61511 .38133 m .61597 .40872 L .63823 .41619 L p
1 g
F P
s
P
p
.002 w
.62744 .44965 m .63823 .41619 L .61597 .40872 L p
1 g
F P
s
P
p
.002 w
.43424 .54826 m .48369 .57018 L .49219 .54913 L p
1 g
F P
s
P
p
.002 w
.54039 .55402 m .49219 .54913 L .48369 .57018 L p
1 g
F P
s
P
p
.002 w
.39944 .31619 m .37944 .35992 L .40299 .36133 L p
1 g
F P
s
P
p
.002 w
.40299 .36133 m .42052 .32347 L .39944 .31619 L p
1 g
F P
s
P
p
.002 w
.54039 .55402 m .58734 .54332 L .58329 .52034 L p
1 g
F P
s
P
p
.002 w
.61852 .49799 m .58329 .52034 L .58734 .54332 L p
1 g
F P
s
P
p
.002 w
.56984 .29828 m .53448 .28995 L .53665 .31227 L p
1 g
F P
s
P
p
.002 w
.53665 .31227 m .56365 .3187 L .56984 .29828 L p
1 g
F P
s
P
p
.002 w
.63823 .41619 m .63723 .38037 L .61511 .38133 L p
1 g
F P
s
P
p
.002 w
.60524 .3553 m .61511 .38133 L .63723 .38037 L p
1 g
F P
s
P
p
.002 w
.48821 .27514 m .4499 .29357 L .46737 .30867 L p
1 g
F P
s
P
p
.002 w
.46737 .30867 m .49899 .29362 L .48821 .27514 L p
1 g
F P
s
P
p
.002 w
.35828 .36027 m .35341 .41353 L .37487 .40791 L p
1 g
F P
s
P
p
.002 w
.37487 .40791 m .37944 .35992 L .35828 .36027 L p
1 g
F P
s
P
p
.002 w
.60102 .31778 m .56984 .29828 L .56365 .3187 L p
1 g
F P
s
P
p
.002 w
.56365 .3187 m .58742 .3336 L .60102 .31778 L p
1 g
F P
s
P
p
.002 w
.61852 .49799 m .64434 .46483 L .62744 .44965 L p
1 g
F P
s
P
p
.002 w
.63823 .41619 m .62744 .44965 L .64434 .46483 L p
1 g
F P
s
P
p
.002 w
.63723 .38037 m .62437 .34625 L .60524 .3553 L p
1 g
F P
s
P
p
.002 w
.58742 .3336 m .60524 .3553 L .62437 .34625 L p
1 g
F P
s
P
p
.002 w
.48369 .57018 m .53714 .57576 L .54039 .55402 L p
1 g
F P
s
P
p
.002 w
.58734 .54332 m .54039 .55402 L .53714 .57576 L p
1 g
F P
s
P
p
.002 w
.62437 .34625 m .60102 .31778 L .58742 .3336 L p
1 g
F P
s
P
p
.002 w
.43319 .28154 m .39944 .31619 L .42052 .32347 L p
1 g
F P
s
P
p
.002 w
.42052 .32347 m .4499 .29357 L .43319 .28154 L p
1 g
F P
s
P
p
.002 w
.34838 .47612 m .37846 .526 L .39359 .51234 L p
1 g
F P
s
P
p
.002 w
.39359 .51234 m .36569 .46594 L .34838 .47612 L p
1 g
F P
s
P
p
.002 w
.43424 .54826 m .39359 .51234 L .37846 .526 L p
1 g
F P
s
P
p
.002 w
.37846 .526 m .42218 .56464 L .43424 .54826 L p
1 g
F P
s
P
p
.002 w
.48369 .57018 m .43424 .54826 L .42218 .56464 L p
1 g
F P
s
P
p
.002 w
.58734 .54332 m .62808 .51774 L .61852 .49799 L p
1 g
F P
s
P
p
.002 w
.64434 .46483 m .61852 .49799 L .62808 .51774 L p
1 g
F P
s
P
p
.002 w
.53135 .27055 m .48821 .27514 L .49899 .29362 L p
1 g
F P
s
P
p
.002 w
.49899 .29362 m .53448 .28995 L .53135 .27055 L p
1 g
F P
s
P
p
.002 w
.33504 .41978 m .34838 .47612 L .36569 .46594 L p
1 g
F P
s
P
p
.002 w
.36569 .46594 m .35341 .41353 L .33504 .41978 L p
1 g
F P
s
P
p
.002 w
.63723 .38037 m .63823 .41619 L .6576 .42424 L p
1 g
F P
s
P
p
.002 w
.64434 .46483 m .6576 .42424 L .63823 .41619 L p
1 g
F P
s
P
p
.002 w
.38029 .31164 m .35828 .36027 L .37944 .35992 L p
1 g
F P
s
P
p
.002 w
.37944 .35992 m .39944 .31619 L .38029 .31164 L p
1 g
F P
s
P
p
.002 w
.42218 .56464 m .47533 .5883 L .48369 .57018 L p
1 g
F P
s
P
p
.002 w
.53714 .57576 m .48369 .57018 L .47533 .5883 L p
1 g
F P
s
P
p
.002 w
.53714 .57576 m .58928 .56409 L .58734 .54332 L p
1 g
F P
s
P
p
.002 w
.62808 .51774 m .58734 .54332 L .58928 .56409 L p
1 g
F P
s
P
p
.002 w
.57445 .28061 m .53135 .27055 L .53448 .28995 L p
1 g
F P
s
P
p
.002 w
.53448 .28995 m .56984 .29828 L .57445 .28061 L p
1 g
F P
s
P
p
.002 w
.47738 .26008 m .43319 .28154 L .4499 .29357 L p
1 g
F P
s
P
p
.002 w
.4499 .29357 m .48821 .27514 L .47738 .26008 L p
1 g
F P
s
P
p
.002 w
.6576 .42424 m .65652 .38066 L .63723 .38037 L p
1 g
F P
s
P
p
.002 w
.62437 .34625 m .63723 .38037 L .65652 .38066 L p
1 g
F P
s
P
p
.002 w
.3401 .36246 m .33504 .41978 L .35341 .41353 L p
1 g
F P
s
P
p
.002 w
.35341 .41353 m .35828 .36027 L .3401 .36246 L p
1 g
F P
s
P
p
.002 w
.62808 .51774 m .65804 .4796 L .64434 .46483 L p
1 g
F P
s
P
p
.002 w
.6576 .42424 m .64434 .46483 L .65804 .4796 L p
1 g
F P
s
P
p
.002 w
.61247 .30435 m .57445 .28061 L .56984 .29828 L p
1 g
F P
s
P
p
.002 w
.56984 .29828 m .60102 .31778 L .61247 .30435 L p
1 g
F P
s
P
p
.002 w
.47533 .5883 m .53281 .59446 L .53714 .57576 L p
1 g
F P
s
P
p
.002 w
.58928 .56409 m .53714 .57576 L .53281 .59446 L p
1 g
F P
s
P
p
.002 w
.65652 .38066 m .64092 .33907 L .62437 .34625 L p
1 g
F P
s
P
p
.002 w
.60102 .31778 m .62437 .34625 L .64092 .33907 L p
1 g
F P
s
P
p
.002 w
.64092 .33907 m .61247 .30435 L .60102 .31778 L p
1 g
F P
s
P
p
.002 w
.41764 .273 m .38029 .31164 L .39944 .31619 L p
1 g
F P
s
P
p
.002 w
.39944 .31619 m .43319 .28154 L .41764 .273 L p
1 g
F P
s
P
p
.002 w
.33442 .48547 m .36596 .53765 L .37846 .526 L p
1 g
F P
s
P
p
.002 w
.37846 .526 m .34838 .47612 L .33442 .48547 L p
1 g
F P
s
P
p
.002 w
.42218 .56464 m .37846 .526 L .36596 .53765 L p
1 g
F P
s
P
p
.002 w
.58928 .56409 m .63463 .53587 L .62808 .51774 L p
1 g
F P
s
P
p
.002 w
.65804 .4796 m .62808 .51774 L .63463 .53587 L p
1 g
F P
s
P
p
.002 w
.36596 .53765 m .41172 .57812 L .42218 .56464 L p
1 g
F P
s
P
p
.002 w
.47533 .5883 m .42218 .56464 L .41172 .57812 L p
1 g
F P
s
P
p
.002 w
.52729 .25463 m .47738 .26008 L .48821 .27514 L p
1 g
F P
s
P
p
.002 w
.48821 .27514 m .53135 .27055 L .52729 .25463 L p
1 g
F P
s
P
p
.002 w
.65804 .4796 m .67354 .43274 L .6576 .42424 L p
1 g
F P
s
P
p
.002 w
.65652 .38066 m .6576 .42424 L .67354 .43274 L p
1 g
F P
s
P
p
.002 w
.36361 .31006 m .3401 .36246 L .35828 .36027 L p
1 g
F P
s
P
p
.002 w
.35828 .36027 m .38029 .31164 L .36361 .31006 L p
1 g
F P
s
P
p
.002 w
.32033 .42653 m .33442 .48547 L .34838 .47612 L p
1 g
F P
s
P
p
.002 w
.34838 .47612 m .33504 .41978 L .32033 .42653 L p
1 g
F P
s
P
p
.002 w
.41172 .57812 m .46733 .60295 L .47533 .5883 L p
1 g
F P
s
P
p
.002 w
.53281 .59446 m .47533 .5883 L .46733 .60295 L p
1 g
F P
s
P
p
.002 w
.53281 .59446 m .58895 .58208 L .58928 .56409 L p
1 g
F P
s
P
p
.002 w
.63463 .53587 m .58928 .56409 L .58895 .58208 L p
1 g
F P
s
P
p
.002 w
.57726 .26621 m .52729 .25463 L .53135 .27055 L p
1 g
F P
s
P
p
.002 w
.53135 .27055 m .57445 .28061 L .57726 .26621 L p
1 g
F P
s
P
p
.002 w
.46674 .24897 m .41764 .273 L .43319 .28154 L p
1 g
F P
s
P
p
.002 w
.43319 .28154 m .47738 .26008 L .46674 .24897 L p
1 g
F P
s
P
p
.002 w
.67354 .43274 m .6724 .38228 L .65652 .38066 L p
1 g
F P
s
P
p
.002 w
.64092 .33907 m .65652 .38066 L .6724 .38228 L p
1 g
F P
s
P
p
.002 w
.32548 .36654 m .32033 .42653 L .33504 .41978 L p
1 g
F P
s
P
p
.002 w
.33504 .41978 m .3401 .36246 L .32548 .36654 L p
1 g
F P
s
P
p
.002 w
.63463 .53587 m .66808 .4936 L .65804 .4796 L p
1 g
F P
s
P
p
.002 w
.67354 .43274 m .65804 .4796 L .66808 .4936 L p
1 g
F P
s
P
p
.002 w
.46733 .60295 m .52747 .60953 L .53281 .59446 L p
1 g
F P
s
P
p
.002 w
.58895 .58208 m .53281 .59446 L .52747 .60953 L p
1 g
F P
s
P
p
.002 w
.62138 .29373 m .57726 .26621 L .57445 .28061 L p
1 g
F P
s
P
p
.002 w
.57445 .28061 m .61247 .30435 L .62138 .29373 L p
1 g
F P
s
P
p
.002 w
.6724 .38228 m .65439 .33403 L .64092 .33907 L p
1 g
F P
s
P
p
.002 w
.61247 .30435 m .64092 .33907 L .65439 .33403 L p
1 g
F P
s
P
p
.002 w
.40371 .26833 m .36361 .31006 L .38029 .31164 L p
1 g
F P
s
P
p
.002 w
.38029 .31164 m .41764 .273 L .40371 .26833 L p
1 g
F P
s
P
p
.002 w
.65439 .33403 m .62138 .29373 L .61247 .30435 L p
1 g
F P
s
P
p
.002 w
.58895 .58208 m .63786 .55188 L .63463 .53587 L p
1 g
F P
s
P
p
.002 w
.66808 .4936 m .63463 .53587 L .63786 .55188 L p
1 g
F P
s
P
p
.002 w
.32431 .49373 m .35652 .54692 L .36596 .53765 L p
1 g
F P
s
P
p
.002 w
.36596 .53765 m .33442 .48547 L .32431 .49373 L p
1 g
F P
s
P
p
.002 w
.41172 .57812 m .36596 .53765 L .35652 .54692 L p
1 g
F P
s
P
p
.002 w
.52234 .24279 m .46674 .24897 L .47738 .26008 L p
1 g
F P
s
P
p
.002 w
.47738 .26008 m .52729 .25463 L .52234 .24279 L p
1 g
F P
s
P
p
.002 w
.35652 .54692 m .40319 .5882 L .41172 .57812 L p
1 g
F P
s
P
p
.002 w
.46733 .60295 m .41172 .57812 L .40319 .5882 L p
1 g
F P
s
P
p
.002 w
.66808 .4936 m .68547 .44149 L .67354 .43274 L p
1 g
F P
s
P
p
.002 w
.6724 .38228 m .67354 .43274 L .68547 .44149 L p
1 g
F P
s
P
p
.002 w
.34995 .31164 m .32548 .36654 L .3401 .36246 L p
1 g
F P
s
P
p
.002 w
.3401 .36246 m .36361 .31006 L .34995 .31164 L p
1 g
F P
s
P
p
.002 w
.30986 .43366 m .32431 .49373 L .33442 .48547 L p
1 g
F P
s
P
p
.002 w
.33442 .48547 m .32033 .42653 L .30986 .43366 L p
1 g
F P
s
P
p
.002 w
.40319 .5882 m .45988 .61359 L .46733 .60295 L p
1 g
F P
s
P
p
.002 w
.52747 .60953 m .46733 .60295 L .45988 .61359 L p
1 g
F P
s
P
p
.002 w
.52747 .60953 m .58624 .59673 L .58895 .58208 L p
1 g
F P
s
P
p
.002 w
.63786 .55188 m .58895 .58208 L .58624 .59673 L p
1 g
F P
s
P
p
.002 w
.45657 .24232 m .40371 .26833 L .41764 .273 L p
1 g
F P
s
P
p
.002 w
.41764 .273 m .46674 .24897 L .45657 .24232 L p
1 g
F P
s
P
p
.002 w
.57811 .25564 m .52234 .24279 L .52729 .25463 L p
1 g
F P
s
P
p
.002 w
.52729 .25463 m .57726 .26621 L .57811 .25564 L p
1 g
F P
s
P
p
.002 w
.68547 .44149 m .68431 .38524 L .6724 .38228 L p
1 g
F P
s
P
p
.002 w
.65439 .33403 m .6724 .38228 L .68431 .38524 L p
1 g
F P
s
P
p
.002 w
.63786 .55188 m .674 .50645 L .66808 .4936 L p
1 g
F P
s
P
p
.002 w
.68547 .44149 m .66808 .4936 L .674 .50645 L p
1 g
F P
s
P
p
.002 w
.315 .37252 m .30986 .43366 L .32033 .42653 L p
1 g
F P
s
P
p
.002 w
.32033 .42653 m .32548 .36654 L .315 .37252 L p
1 g
F P
s
P
p
.002 w
.45988 .61359 m .52118 .62038 L .52747 .60953 L p
1 g
F P
s
P
p
.002 w
.58624 .59673 m .52747 .60953 L .52118 .62038 L p
1 g
F P
s
P
p
.002 w
.6274 .28636 m .57811 .25564 L .57726 .26621 L p
1 g
F P
s
P
p
.002 w
.57726 .26621 m .62138 .29373 L .6274 .28636 L p
1 g
F P
s
P
p
.002 w
.39183 .26789 m .34995 .31164 L .36361 .31006 L p
1 g
F P
s
P
p
.002 w
.36361 .31006 m .40371 .26833 L .39183 .26789 L p
1 g
F P
s
P
p
.002 w
.68431 .38524 m .66425 .33137 L .65439 .33403 L p
1 g
F P
s
P
p
.002 w
.62138 .29373 m .65439 .33403 L .66425 .33137 L p
1 g
F P
s
P
p
.002 w
.66425 .33137 m .6274 .28636 L .62138 .29373 L p
1 g
F P
s
P
p
.002 w
.58624 .59673 m .63749 .56524 L .63786 .55188 L p
1 g
F P
s
P
p
.002 w
.674 .50645 m .63786 .55188 L .63749 .56524 L p
1 g
F P
s
P
p
.002 w
.51658 .23557 m .45657 .24232 L .46674 .24897 L p
1 g
F P
s
P
p
.002 w
.46674 .24897 m .52234 .24279 L .51658 .23557 L p
1 g
F P
s
P
p
.002 w
.31855 .50061 m .35056 .55343 L .35652 .54692 L p
1 g
F P
s
P
p
.002 w
.35652 .54692 m .32431 .49373 L .31855 .50061 L p
1 g
F P
s
P
p
.002 w
.40319 .5882 m .35652 .54692 L .35056 .55343 L p
1 g
F P
s
P
p
.002 w
.35056 .55343 m .39693 .59444 L .40319 .5882 L p
1 g
F P
s
P
p
.002 w
.45988 .61359 m .40319 .5882 L .39693 .59444 L p
1 g
F P
s
P
p
.002 w
.674 .50645 m .69287 .4503 L .68547 .44149 L p
1 g
F P
s
P
p
.002 w
.68431 .38524 m .68547 .44149 L .69287 .4503 L p
1 g
F P
s
P
p
.002 w
.33983 .31656 m .315 .37252 L .32548 .36654 L p
1 g
F P
s
P
p
.002 w
.32548 .36654 m .34995 .31164 L .33983 .31656 L p
1 g
F P
s
P
p
.002 w
.30415 .441 m .31855 .50061 L .32431 .49373 L p
1 g
F P
s
P
p
.002 w
.32431 .49373 m .30986 .43366 L .30415 .441 L p
1 g
F P
s
P
p
.002 w
.52118 .62038 m .58108 .60744 L .58624 .59673 L p
1 g
F P
s
P
p
.002 w
.63749 .56524 m .58624 .59673 L .58108 .60744 L p
1 g
F P
s
P
p
.002 w
.39693 .59444 m .45321 .61969 L .45988 .61359 L p
1 g
F P
s
P
p
.002 w
.52118 .62038 m .45988 .61359 L .45321 .61969 L p
1 g
F P
s
P
p
.002 w
.44717 .24058 m .39183 .26789 L .40371 .26833 L p
1 g
F P
s
P
p
.002 w
.40371 .26833 m .45657 .24232 L .44717 .24058 L p
1 g
F P
s
P
p
.002 w
.57686 .24943 m .51658 .23557 L .52234 .24279 L p
1 g
F P
s
P
p
.002 w
.52234 .24279 m .57811 .25564 L .57686 .24943 L p
1 g
F P
s
P
p
.002 w
.69287 .4503 m .69167 .38957 L .68431 .38524 L p
1 g
F P
s
P
p
.002 w
.66425 .33137 m .68431 .38524 L .69167 .38957 L p
1 g
F P
s
P
p
.002 w
.63749 .56524 m .67542 .51775 L .674 .50645 L p
1 g
F P
s
P
p
.002 w
.69287 .4503 m .674 .50645 L .67542 .51775 L p
1 g
F P
s
P
p
.002 w
.30919 .38035 m .30415 .441 L .30986 .43366 L p
1 g
F P
s
P
p
.002 w
.30986 .43366 m .315 .37252 L .30919 .38035 L p
1 g
F P
s
P
p
.002 w
.45321 .61969 m .51404 .62649 L .52118 .62038 L p
1 g
F P
s
P
p
.002 w
.58108 .60744 m .52118 .62038 L .51404 .62649 L p
1 g
F P
s
P
p
.002 w
.38246 .27195 m .33983 .31656 L .34995 .31164 L p
1 g
F P
s
P
p
.002 w
.34995 .31164 m .39183 .26789 L .38246 .27195 L p
1 g
F P
s
P
p
.002 w
.63017 .28264 m .57686 .24943 L .57811 .25564 L p
1 g
F P
s
P
p
.002 w
.57811 .25564 m .6274 .28636 L .63017 .28264 L p
1 g
F P
s
P
p
.002 w
.69167 .38957 m .67002 .33133 L .66425 .33137 L p
1 g
F P
s
P
p
.002 w
.6274 .28636 m .66425 .33137 L .67002 .33133 L p
1 g
F P
s
P
p
.002 w
.67002 .33133 m .63017 .28264 L .6274 .28636 L p
1 g
F P
s
P
p
.002 w
.58108 .60744 m .63333 .57545 L .63749 .56524 L p
1 g
F P
s
P
p
.002 w
.67542 .51775 m .63749 .56524 L .63333 .57545 L p
1 g
F P
s
P
p
.002 w
.5101 .23347 m .44717 .24058 L .45657 .24232 L p
1 g
F P
s
P
p
.002 w
.45657 .24232 m .51658 .23557 L .5101 .23347 L p
1 g
F P
s
P
p
.002 w
.31756 .50586 m .34848 .55683 L .35056 .55343 L p
1 g
F P
s
P
p
.002 w
.35056 .55343 m .31855 .50061 L .31756 .50586 L p
1 g
F P
s
P
p
.002 w
.39693 .59444 m .35056 .55343 L .34848 .55683 L p
1 g
F P
s
P
p
.002 w
.34848 .55683 m .39324 .59642 L .39693 .59444 L p
1 g
F P
s
P
p
.002 w
.45321 .61969 m .39693 .59444 L .39324 .59642 L p
1 g
F P
s
P
p
.002 w
.33378 .32487 m .30919 .38035 L .315 .37252 L p
1 g
F P
s
P
p
.002 w
.315 .37252 m .33983 .31656 L .33378 .32487 L p
1 g
F P
s
P
p
.002 w
.67542 .51775 m .69524 .45894 L .69287 .4503 L p
1 g
F P
s
P
p
.002 w
.69167 .38957 m .69287 .4503 L .69524 .45894 L p
1 g
F P
s
P
p
.002 w
.30366 .44836 m .31756 .50586 L .31855 .50061 L p
1 g
F P
s
P
p
.002 w
.31855 .50061 m .30415 .441 L .30366 .44836 L p
1 g
F P
s
P
p
.002 w
.51404 .62649 m .57346 .61371 L .58108 .60744 L p
1 g
F P
s
P
p
.002 w
.63333 .57545 m .58108 .60744 L .57346 .61371 L p
1 g
F P
s
P
p
.002 w
.39324 .59642 m .44755 .6208 L .45321 .61969 L p
1 g
F P
s
P
p
.002 w
.51404 .62649 m .45321 .61969 L .44755 .6208 L p
1 g
F P
s
P
p
.002 w
.43886 .24411 m .38246 .27195 L .39183 .26789 L p
1 g
F P
s
P
p
.002 w
.39183 .26789 m .44717 .24058 L .43886 .24411 L p
1 g
F P
s
P
p
.002 w
.57339 .24801 m .5101 .23347 L .51658 .23557 L p
1 g
F P
s
P
p
.002 w
.51658 .23557 m .57686 .24943 L .57339 .24801 L p
1 g
F P
s
P
p
.004 w
.64235 .58563 m
.65421 .59856 L
s
P
p
.004 w
.65421 .59856 m
.66663 .6121 L
s
P
p
.004 w
.66663 .6121 m
.68 .62666 L
s
P
p
.002 w
.63333 .57545 m .672 .52709 L .67542 .51775 L p
1 g
F P
s
P
p
.002 w
.69524 .45894 m .67542 .51775 L .672 .52709 L p
1 g
F P
s
P
p
.002 w
.69524 .45894 m .69401 .39523 L .69167 .38957 L p
1 g
F P
s
P
p
.002 w
.67002 .33133 m .69167 .38957 L .69401 .39523 L p
1 g
F P
s
P
p
.002 w
.30852 .38993 m .30366 .44836 L .30415 .441 L p
1 g
F P
s
P
p
.002 w
.30415 .441 m .30919 .38035 L .30852 .38993 L p
1 g
F P
s
P
p
.002 w
.44755 .6208 m .50621 .62738 L .51404 .62649 L p
1 g
F P
s
P
p
.002 w
.57346 .61371 m .51404 .62649 L .50621 .62738 L p
1 g
F P
s
P
p
.002 w
.37603 .28069 m .33378 .32487 L .33983 .31656 L p
1 g
F P
s
P
p
.002 w
.33983 .31656 m .38246 .27195 L .37603 .28069 L p
1 g
F P
s
P
p
.002 w
.6294 .28291 m .57339 .24801 L .57686 .24943 L p
1 g
F P
s
P
p
.002 w
.57686 .24943 m .63017 .28264 L .6294 .28291 L p
1 g
F P
s
P
p
.002 w
.69401 .39523 m .67128 .33407 L .67002 .33133 L p
1 g
F P
s
P
p
.002 w
.63017 .28264 m .67002 .33133 L .67128 .33407 L p
1 g
F P
s
P
p
.002 w
.57346 .61371 m .62525 .58201 L .63333 .57545 L p
1 g
F P
s
P
p
.002 w
.672 .52709 m .63333 .57545 L .62525 .58201 L p
1 g
F P
s
P
p
.002 w
.67128 .33407 m .6294 .28291 L .63017 .28264 L p
1 g
F P
s
P
p
.002 w
.50305 .23688 m .43886 .24411 L .44717 .24058 L p
1 g
F P
s
P
p
.002 w
.44717 .24058 m .5101 .23347 L .50305 .23688 L p
1 g
F P
s
P
p
.002 w
.32171 .50919 m .35058 .55681 L .34848 .55683 L p
1 g
F P
s
P
p
.002 w
.34848 .55683 m .31756 .50586 L .32171 .50919 L p
1 g
F P
s
P
p
.002 w
.39324 .59642 m .34848 .55683 L .35058 .55681 L p
1 g
F P
s
P
p
.002 w
.33222 .33655 m .30852 .38993 L .30919 .38035 L p
1 g
F P
s
P
p
.002 w
.30919 .38035 m .33378 .32487 L .33222 .33655 L p
1 g
F P
s
P
p
.002 w
.35058 .55681 m .3924 .5938 L .39324 .59642 L p
1 g
F P
s
P
p
.002 w
.44755 .6208 m .39324 .59642 L .3924 .5938 L p
1 g
F P
s
P
p
.002 w
.672 .52709 m .6922 .46715 L .69524 .45894 L p
1 g
F P
s
P
p
.002 w
.69401 .39523 m .69524 .45894 L .6922 .46715 L p
1 g
F P
s
P
p
.002 w
.50621 .62738 m .56344 .61506 L .57346 .61371 L p
1 g
F P
s
P
p
.002 w
.62525 .58201 m .57346 .61371 L .56344 .61506 L p
1 g
F P
s
P
p
.002 w
.30875 .45553 m .32171 .50919 L .31756 .50586 L p
1 g
F P
s
P
p
.002 w
.31756 .50586 m .30366 .44836 L .30875 .45553 L p
1 g
F P
s
P
p
.002 w
.3924 .5938 m .44313 .61656 L .44755 .6208 L p
1 g
F P
s
P
p
.002 w
.50621 .62738 m .44755 .6208 L .44313 .61656 L p
1 g
F P
s
P
p
.002 w
.43195 .25315 m .37603 .28069 L .38246 .27195 L p
1 g
F P
s
P
p
.002 w
.38246 .27195 m .43886 .24411 L .43195 .25315 L p
1 g
F P
s
P
p
.002 w
.56766 .25177 m .50305 .23688 L .5101 .23347 L p
1 g
F P
s
P
p
.002 w
.5101 .23347 m .57339 .24801 L .56766 .25177 L p
1 g
F P
s
P
p
.002 w
.62525 .58201 m .66354 .53408 L .672 .52709 L p
1 g
F P
s
P
p
.002 w
.6922 .46715 m .672 .52709 L .66354 .53408 L p
1 g
F P
s
P
p
.002 w
.6922 .46715 m .69092 .40214 L .69401 .39523 L p
1 g
F P
s
P
p
.002 w
.67128 .33407 m .69401 .39523 L .69092 .40214 L p
1 g
F P
s
P
p
.002 w
.31334 .40108 m .30875 .45553 L .30366 .44836 L p
1 g
F P
s
P
p
.002 w
.30366 .44836 m .30852 .38993 L .31334 .40108 L p
1 g
F P
s
P
p
.002 w
.44313 .61656 m .49785 .62267 L .50621 .62738 L p
1 g
F P
s
P
p
.002 w
.56344 .61506 m .50621 .62738 L .49785 .62267 L p
1 g
F P
s
P
p
.002 w
.37292 .29412 m .33222 .33655 L .33378 .32487 L p
1 g
F P
s
P
p
.002 w
.33378 .32487 m .37603 .28069 L .37292 .29412 L p
1 g
F P
s
P
p
.002 w
.62488 .28743 m .56766 .25177 L .57339 .24801 L p
1 g
F P
s
P
p
.002 w
.57339 .24801 m .6294 .28291 L .62488 .28743 L p
1 g
F P
s
P
p
.002 w
.56344 .61506 m .61324 .58451 L .62525 .58201 L p
1 g
F P
s
P
p
.002 w
.66354 .53408 m .62525 .58201 L .61324 .58451 L p
1 g
F P
s
P
p
.002 w
.69092 .40214 m .66767 .3397 L .67128 .33407 L p
1 g
F P
s
P
p
.002 w
.6294 .28291 m .67128 .33407 L .66767 .3397 L p
1 g
F P
s
P
p
.002 w
.66767 .3397 m .62488 .28743 L .6294 .28291 L p
1 g
F P
s
P
p
.002 w
.49562 .24607 m .43195 .25315 L .43886 .24411 L p
1 g
F P
s
P
p
.002 w
.43886 .24411 m .50305 .23688 L .49562 .24607 L p
1 g
F P
s
P
p
.002 w
.33549 .35145 m .31334 .40108 L .30852 .38993 L p
1 g
F P
s
P
p
.002 w
.30852 .38993 m .33222 .33655 L .33549 .35145 L p
1 g
F P
s
P
p
.002 w
.66354 .53408 m .6835 .47465 L .6922 .46715 L p
1 g
F P
s
P
p
.002 w
.69092 .40214 m .6922 .46715 L .6835 .47465 L p
1 g
F P
s
P
p
.002 w
.33119 .5104 m .35708 .55314 L .35058 .55681 L p
1 g
F P
s
P
p
.002 w
.35058 .55681 m .32171 .50919 L .33119 .5104 L p
1 g
F P
s
P
p
.002 w
.3924 .5938 m .35058 .55681 L .35708 .55314 L p
1 g
F P
s
P
p
.002 w
.35708 .55314 m .39463 .58636 L .3924 .5938 L p
1 g
F P
s
P
p
.002 w
.44313 .61656 m .3924 .5938 L .39463 .58636 L p
1 g
F P
s
P
p
.002 w
.49785 .62267 m .55116 .61113 L .56344 .61506 L p
1 g
F P
s
P
p
.002 w
.61324 .58451 m .56344 .61506 L .55116 .61113 L p
1 g
F P
s
P
p
.002 w
.31963 .46228 m .33119 .5104 L .32171 .50919 L p
1 g
F P
s
P
p
.002 w
.32171 .50919 m .30875 .45553 L .31963 .46228 L p
1 g
F P
s
P
p
.002 w
.39463 .58636 m .44016 .60675 L .44313 .61656 L p
1 g
F P
s
P
p
.002 w
.49785 .62267 m .44313 .61656 L .44016 .60675 L p
1 g
F P
s
P
p
.002 w
.42676 .26777 m .37292 .29412 L .37603 .28069 L p
1 g
F P
s
P
p
.002 w
.37603 .28069 m .43195 .25315 L .42676 .26777 L p
1 g
F P
s
P
p
.002 w
.55971 .26092 m .49562 .24607 L .50305 .23688 L p
1 g
F P
s
P
p
.002 w
.50305 .23688 m .56766 .25177 L .55971 .26092 L p
1 g
F P
s
P
p
.002 w
.61324 .58451 m .64998 .53836 L .66354 .53408 L p
1 g
F P
s
P
p
.002 w
.6835 .47465 m .66354 .53408 L .64998 .53836 L p
1 g
F P
s
P
p
.002 w
.6835 .47465 m .68214 .41018 L .69092 .40214 L p
1 g
F P
s
P
p
.002 w
.66767 .3397 m .69092 .40214 L .68214 .41018 L p
1 g
F P
s
P
p
.002 w
.32384 .41356 m .31963 .46228 L .30875 .45553 L p
1 g
F P
s
P
p
.002 w
.30875 .45553 m .31334 .40108 L .32384 .41356 L p
1 g
F P
s
P
p
.002 w
.37344 .31211 m .33549 .35145 L .33222 .33655 L p
1 g
F P
s
P
p
.002 w
.33222 .33655 m .37292 .29412 L .37344 .31211 L p
1 g
F P
s
P
p
.002 w
.44016 .60675 m .48921 .61216 L .49785 .62267 L p
1 g
F P
s
P
p
.002 w
.55116 .61113 m .49785 .62267 L .48921 .61216 L p
1 g
F P
s
P
p
.002 w
.55116 .61113 m .59743 .58261 L .61324 .58451 L p
1 g
F P
s
P
p
.002 w
.64998 .53836 m .61324 .58451 L .59743 .58261 L p
1 g
F P
s
P
p
.002 w
.6165 .29636 m .55971 .26092 L .56766 .25177 L p
1 g
F P
s
P
p
.002 w
.56766 .25177 m .62488 .28743 L .6165 .29636 L p
1 g
F P
s
P
p
.002 w
.68214 .41018 m .659 .34823 L .66767 .3397 L p
1 g
F P
s
P
p
.002 w
.62488 .28743 m .66767 .3397 L .659 .34823 L p
1 g
F P
s
P
p
.002 w
.48801 .2611 m .42676 .26777 L .43195 .25315 L p
1 g
F P
s
P
p
.002 w
.43195 .25315 m .49562 .24607 L .48801 .2611 L p
1 g
F P
s
P
p
.002 w
.659 .34823 m .6165 .29636 L .62488 .28743 L p
1 g
F P
s
P
p
.002 w
.34377 .36927 m .32384 .41356 L .31334 .40108 L p
1 g
F P
s
P
p
.002 w
.31334 .40108 m .33549 .35145 L .34377 .36927 L p
1 g
F P
s
P
p
.002 w
.64998 .53836 m .66904 .48116 L .6835 .47465 L p
1 g
F P
s
P
p
.002 w
.68214 .41018 m .6835 .47465 L .66904 .48116 L p
1 g
F P
s
P
p
.002 w
.34605 .5093 m .36807 .54572 L .35708 .55314 L p
1 g
F P
s
P
p
.002 w
.35708 .55314 m .33119 .5104 L .34605 .5093 L p
1 g
F P
s
P
p
.002 w
.39463 .58636 m .35708 .55314 L .36807 .54572 L p
1 g
F P
s
P
p
.002 w
.36807 .54572 m .40006 .574 L .39463 .58636 L p
1 g
F P
s
P
p
.002 w
.44016 .60675 m .39463 .58636 L .40006 .574 L p
1 g
F P
s
P
p
.002 w
.48921 .61216 m .53688 .60173 L .55116 .61113 L p
1 g
F P
s
P
p
.002 w
.59743 .58261 m .55116 .61113 L .53688 .60173 L p
1 g
F P
s
P
p
.002 w
.3363 .46835 m .34605 .5093 L .33119 .5104 L p
1 g
F P
s
P
p
.002 w
.33119 .5104 m .31963 .46228 L .3363 .46835 L p
1 g
F P
s
P
p
.002 w
.42355 .28779 m .37344 .31211 L .37292 .29412 L p
1 g
F P
s
P
p
.002 w
.37292 .29412 m .42676 .26777 L .42355 .28779 L p
1 g
F P
s
P
p
.002 w
.40006 .574 m .43884 .59133 L .44016 .60675 L p
1 g
F P
s
P
p
.002 w
.48921 .61216 m .44016 .60675 L .43884 .59133 L p
1 g
F P
s
P
p
.002 w
.59743 .58261 m .63146 .53961 L .64998 .53836 L p
1 g
F P
s
P
p
.004 w
.63692 .57972 m
.64235 .58563 L
s
P
p
.002 w
.66904 .48116 m .64998 .53836 L .63146 .53961 L p
1 g
F P
s
P
p
.002 w
.54966 .2755 m .48801 .2611 L .49562 .24607 L p
1 g
F P
s
P
p
.002 w
.49562 .24607 m .55971 .26092 L .54966 .2755 L p
1 g
F P
s
P
p
.002 w
.66904 .48116 m .66759 .41914 L .68214 .41018 L p
1 g
F P
s
P
p
.002 w
.659 .34823 m .68214 .41018 L .66759 .41914 L p
1 g
F P
s
P
p
.002 w
.33999 .427 m .3363 .46835 L .31963 .46228 L p
1 g
F P
s
P
p
.002 w
.31963 .46228 m .32384 .41356 L .33999 .427 L p
1 g
F P
s
P
p
.002 w
.37778 .33431 m .34377 .36927 L .33549 .35145 L p
1 g
F P
s
P
p
.002 w
.33549 .35145 m .37344 .31211 L .37778 .33431 L p
1 g
F P
s
P
p
.002 w
.43884 .59133 m .48055 .59584 L .48921 .61216 L p
1 g
F P
s
P
p
.002 w
.53688 .60173 m .48921 .61216 L .48055 .59584 L p
1 g
F P
s
P
p
.002 w
.53688 .60173 m .57813 .57612 L .59743 .58261 L p
1 g
F P
s
P
p
.002 w
.63146 .53961 m .59743 .58261 L .57813 .57612 L p
1 g
F P
s
P
p
.002 w
.6043 .30965 m .54966 .2755 L .55971 .26092 L p
1 g
F P
s
P
p
.002 w
.55971 .26092 m .6165 .29636 L .6043 .30965 L p
1 g
F P
s
P
p
.002 w
.66759 .41914 m .64523 .35956 L .659 .34823 L p
1 g
F P
s
P
p
.002 w
.6165 .29636 m .659 .34823 L .64523 .35956 L p
1 g
F P
s
P
p
.002 w
.48048 .28178 m .42355 .28779 L .42676 .26777 L p
1 g
F P
s
P
p
.002 w
.42676 .26777 m .48801 .2611 L .48048 .28178 L p
1 g
F P
s
P
p
.002 w
.64523 .35956 m .6043 .30965 L .6165 .29636 L p
1 g
F P
s
P
p
.002 w
.35705 .38956 m .33999 .427 L .32384 .41356 L p
1 g
F P
s
P
p
.002 w
.32384 .41356 m .34377 .36927 L .35705 .38956 L p
1 g
F P
s
P
p
.002 w
.66759 .41914 m .66904 .48116 L .64898 .4864 L p
1 g
F P
s
P
p
.002 w
.63146 .53961 m .64898 .4864 L .66904 .48116 L p
1 g
F P
s
P
p
.002 w
.36611 .50579 m .38345 .53454 L .36807 .54572 L p
1 g
F P
s
P
p
.002 w
.36807 .54572 m .34605 .5093 L .36611 .50579 L p
1 g
F P
s
P
p
.002 w
.40006 .574 m .36807 .54572 L .38345 .53454 L p
1 g
F P
s
P
p
.002 w
.48055 .59584 m .52097 .58685 L .53688 .60173 L p
1 g
F P
s
P
p
.002 w
.57813 .57612 m .53688 .60173 L .52097 .58685 L p
1 g
F P
s
P
p
.002 w
.38345 .53454 m .4087 .55686 L .40006 .574 L p
1 g
F P
s
P
p
.002 w
.43884 .59133 m .40006 .574 L .4087 .55686 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.42255 .31283 m .37778 .33431 L .37344 .31211 L p
1 g
F P
s
P
p
.002 w
.37344 .31211 m .42355 .28779 L .42255 .31283 L p
1 g
F P
s
P
p
.002 w
.35851 .47351 m .36611 .50579 L .34605 .5093 L p
1 g
F P
s
P
p
.002 w
.34605 .5093 m .3363 .46835 L .35851 .47351 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.6122 .55279 L
s
P
p
.002 w
.4087 .55686 m .43931 .57048 L .43884 .59133 L p
1 g
F P
s
P
p
.002 w
.48055 .59584 m .43884 .59133 L .43931 .57048 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.57813 .57612 m .60831 .53762 L .63146 .53961 L p
1 g
F P
s
P
p
.004 w
.61349 .55419 m
.61439 .55517 L
s
P
p
.004 w
.61439 .55517 m
.61884 .56002 L
s
P
p
.004 w
.61884 .56002 m
.6276 .56957 L
s
P
p
.004 w
.6276 .56957 m
.63692 .57972 L
s
P
p
.002 w
.64898 .4864 m .63146 .53961 L .60831 .53762 L p
1 g
F P
s
P
p
.002 w
.53774 .2953 m .48048 .28178 L .48801 .2611 L p
1 g
F P
s
P
p
.002 w
.48801 .2611 m .54966 .2755 L .53774 .2953 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.36155 .441 m .35851 .47351 L .3363 .46835 L p
1 g
F P
s
P
p
.002 w
.3363 .46835 m .33999 .427 L .36155 .441 L p
1 g
F P
s
P
p
.002 w
.64898 .4864 m .64745 .42878 L .66759 .41914 L p
1 g
F P
s
P
p
.002 w
.64523 .35956 m .66759 .41914 L .64745 .42878 L p
1 g
F P
s
P
p
.002 w
.38597 .36013 m .35705 .38956 L .34377 .36927 L p
1 g
F P
s
P
p
.002 w
.34377 .36927 m .37778 .33431 L .38597 .36013 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.48055 .59584 m .46302 .57298 L .46825 .57482 L 1 g
F
P
p
.002 w
.47317 .57655 m .47376 .57808 L p
.46825 .57482 L 1 g
F P
s
P
p
.002 w
.47376 .57808 m .48055 .59584 L p
.46825 .57482 L 1 g
F P
s
P
p
.002 w
.43931 .57048 m .46302 .57298 L p
.48055 .59584 L 1 g
F P
s
P
p
.002 w
.46825 .57482 m .46872 .57265 L p
.45963 .56902 L 1 g
F P
s
P
p
.002 w
.43931 .57048 m .44066 .55559 L p
.45089 .56283 L 1 g
F P
s
P
p
.002 w
.4656 .57325 m .45902 .57256 L p
.45089 .56283 L 1 g
F P
s
P
p
.002 w
.45902 .57256 m .43931 .57048 L p
.45089 .56283 L 1 g
F P
s
P
p
.002 w
.45089 .56283 m .45146 .56129 L p
.44467 .55539 L 1 g
F P
s
P
p
.45963 .56902 m .4656 .57325 L .46825 .57482 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43833 .54739 L p
1 g
F P
s
P
p
.43931 .57048 m .43371 .54115 L .43833 .54739 L 1 g
F
P
p
.002 w
.44107 .55108 m .4408 .55402 L p
.43833 .54739 L 1 g
F P
s
P
p
.002 w
.4408 .55402 m .43931 .57048 L p
.43833 .54739 L 1 g
F P
s
P
p
.002 w
.43833 .54739 m .43925 .54566 L p
.43504 .53733 L 1 g
F P
s
P
p
.002 w
.42043 .53527 m .4298 .51884 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.43647 .54237 m .4319 .54035 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.4319 .54035 m .42043 .53527 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.43258 .52863 m .43346 .52734 L p
.43315 .51857 L 1 g
F P
s
P
p
.43504 .53733 m .43647 .54237 L .43833 .54739 L 1 g
F
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.45146 .56129 m .43833 .54739 L .43957 .54906 L 1 g
F
P
p
.45146 .56129 m .4382 .54765 L .44467 .55539 L 1 g
F
P
p
.002 w
.44165 .54467 m .44107 .55108 L p
.43833 .54739 L 1 g
F P
s
P
p
.002 w
.43371 .54115 m .43647 .54237 L p
.43833 .54739 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43178 .52978 L p
1 g
F P
s
P
p
.43925 .54566 m .43178 .52978 L .43334 .53397 L 1 g
F
P
p
.002 w
.43647 .54237 m .44165 .54467 L p
.43833 .54739 L 1 g
F P
s
P
p
.002 w
.43178 .52978 m .43146 .53025 L p
.43334 .53397 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4337 .50963 L p
1 g
F P
s
P
p
.42043 .53527 m .43376 .50876 L .4337 .50963 L 1 g
F
P
p
.002 w
.43351 .51234 m .42828 .5215 L p
.4337 .50963 L 1 g
F P
s
P
p
.002 w
.42828 .5215 m .42043 .53527 L p
.4337 .50963 L 1 g
F P
s
P
p
.43485 .50826 m .43847 .49979 L .43776 .50125 L 1 g
F
P
p
.002 w
.42596 .50187 m .44473 .48695 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.434 .50897 m .42897 .50453 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.42897 .50453 m .42596 .50187 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45751 .51574 m .44585 .51461 L .4516 .48264 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45199 .48226 m .45751 .51574 L p
.4516 .48264 L 1 g
F P
s
P
p
.002 w
.4337 .50963 m .43485 .50826 L p
.43776 .50125 L 1 g
F P
s
P
p
.43776 .50125 m .44022 .49534 L .434 .50897 L 1 g
F
P
p
.43776 .50125 m .434 .50897 L .4337 .50963 L 1 g
F
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43495 .50981 m .434 .50897 L p
.44994 .48424 L 1 g
F P
s
P
p
.002 w
.47815 .50686 m .46868 .51307 L .45222 .48203 L p
1 g
F P
s
P
p
.002 w
.48756 .47499 m .48816 .48674 L .45282 .48145 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45184 .4813 m .47537 .45444 L .47769 .45724 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47374 .46906 m .45451 .4798 L p
.45761 .47679 L 1 g
F P
s
P
p
.002 w
.48756 .47499 m .45323 .48106 L p
.47547 .46823 L 1 g
F P
s
P
p
.47751 .46725 m .48756 .47499 L .47547 .46823 L 1 g
F
P
p
.002 w
.47751 .46725 m .47786 .46667 L p
.49023 .46541 L 1 g
F P
s
P
p
.002 w
.48756 .47499 m .48415 .46638 L p
.49749 .46425 L 1 g
F P
s
P
p
.49023 .46541 m .49622 .4648 L .48415 .46638 L 1 g
F
P
p
.49023 .46541 m .48415 .46638 L .47751 .46725 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47662 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56584 .50908 L p
1 g
F P
s
P
p
.59395 .49211 m .5671 .51178 L .56572 .50762 L 1 g
F
P
p
.002 w
.56061 .49223 m .56442 .49221 L p
.56572 .50762 L 1 g
F P
s
P
p
.002 w
.56442 .49221 m .59395 .49211 L p
.56572 .50762 L 1 g
F P
s
P
p
.002 w
.56584 .50908 m .56515 .50826 L p
.56651 .51708 L 1 g
F P
s
P
p
.55661 .4905 m .56584 .50908 L .56188 .50059 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.58115 .5323 m .56767 .53692 L .56747 .5287 L 1 g
F
P
p
.002 w
.56746 .52843 m .56755 .52846 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56755 .52846 m .58115 .5323 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56654 .52734 L p
.5649 .53629 L 1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .56746 .52843 L 1 g
F
P
p
.59395 .49211 m .56746 .52843 L .56613 .51249 L 1 g
F
P
p
.56651 .51708 m .56746 .52843 L .56732 .52231 L 1 g
F
P
p
.56515 .50826 m .56746 .52843 L .56651 .51708 L 1 g
F
P
p
.002 w
.59395 .49211 m .58115 .5323 L .56746 .52843 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56136 .5468 L p
1 g
F P
s
P
p
.56654 .52734 m .56136 .5468 L .5649 .53629 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56747 .5287 m .53112 .54944 L .56746 .52843 L 1 g
F
P
p
.56767 .53692 m .5643 .53808 L .56747 .5287 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.5643 .53808 m .53112 .54944 L .56747 .5287 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.58115 .5323 m .5558 .565 L .55059 .56171 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54924 .56316 L p
1 g
F P
s
P
p
.5558 .565 m .54726 .56528 L .54924 .56316 L 1 g
F
P
p
.002 w
.55059 .56171 m .55108 .56202 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.55108 .56202 m .5558 .565 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.54924 .56316 m .54854 .56129 L p
.54163 .56788 L 1 g
F P
s
P
p
.56075 .54566 m .54924 .56316 L .55015 .56219 L 1 g
F
P
p
.56075 .54566 m .54934 .56344 L .55613 .55404 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53159 .5741 L p
1 g
F P
s
P
p
.002 w
.52097 .58685 m .51754 .58281 L p
.54836 .56846 L 1 g
F P
s
P
p
.002 w
.5558 .565 m .55249 .56707 L p
.54836 .56846 L 1 g
F P
s
P
p
.002 w
.55249 .56707 m .52097 .58685 L p
.54836 .56846 L 1 g
F P
s
P
p
.002 w
.53159 .5741 m .53128 .57265 L p
.52252 .57715 L 1 g
F P
s
P
p
.54854 .56129 m .53159 .5741 L .54163 .56788 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58045 L p
1 g
F P
s
P
p
.52097 .58685 m .50266 .582 L .51093 .58045 L 1 g
F
P
p
.002 w
.51491 .5797 m .51561 .58053 L p
.51093 .58045 L 1 g
F P
s
P
p
.002 w
.51561 .58053 m .52097 .58685 L p
.51093 .58045 L 1 g
F P
s
P
p
.002 w
.51093 .58045 m .51079 .57862 L p
.50235 .58031 L 1 g
F P
s
P
p
.53128 .57265 m .51093 .58045 L .51357 .57996 L 1 g
F
P
p
.53128 .57265 m .51097 .58103 L .52252 .57715 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46811 .57543 L p
1 g
F P
s
P
p
.002 w
.52027 .587 m .48055 .59584 L .47443 .57984 L p
1 g
F P
s
P
p
.002 w
.47443 .57984 m .47317 .57655 L p
.4891 .58009 L 1 g
F P
s
P
p
.52027 .587 m .47443 .57984 L .4891 .58009 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58009 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58009 L .50235 .58031 L 1 g
F
P
p
.002 w
.52097 .58685 m .52027 .587 L p
.47217 .57394 L 1 g
F P
s
P
p
.48921 .57862 m .46811 .57543 L .47856 .57775 L 1 g
F
P
p
.002 w
.48895 .58211 m .48921 .57862 L p
.47596 .57753 L 1 g
F P
s
P
p
.002 w
.47317 .57655 m .47217 .57394 L p
.52027 .587 L 1 g
F P
s
P
p
.51093 .58045 m .47217 .57394 L .51491 .5797 L 1 g
F
P
p
.50266 .582 m .49583 .5802 L .51093 .58045 L 1 g
F
P
p
.49583 .5802 m .47217 .57394 L .51093 .58045 L 1 g
F
P
p
.002 w
.4891 .58009 m .48889 .583 L p
.50235 .58031 L 1 g
F P
s
P
p
.002 w
.46811 .57543 m .4678 .57686 L p
.47856 .57775 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58045 L p
1 g
F P
s
P
p
.50235 .58031 m .48889 .583 L .51093 .58045 L 1 g
F
P
p
.002 w
.51093 .58045 m .51097 .58103 L p
.51357 .57996 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.47217 .57394 m .5039 .56673 L .51491 .5797 L p
1 g
F P
s
P
p
.54573 .56533 m .53159 .5741 L .5039 .56673 L 1 g
F
P
p
.002 w
.51754 .58281 m .51491 .5797 L p
.53159 .5741 L 1 g
F P
s
P
p
.002 w
.51491 .5797 m .5039 .56673 L p
.53159 .5741 L 1 g
F P
s
P
p
.002 w
.51097 .58103 m .51111 .583 L p
.52252 .57715 L 1 g
F P
s
P
p
.5558 .565 m .51754 .58281 L .54573 .56533 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53159 .5741 L p
1 g
F P
s
P
p
.52252 .57715 m .51111 .583 L .53159 .5741 L 1 g
F
P
p
.002 w
.53159 .5741 m .5322 .57686 L p
.54163 .56788 L 1 g
F P
s
P
p
.54726 .56528 m .5039 .56673 L .55059 .56171 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54924 .56316 L p
1 g
F P
s
P
p
.54163 .56788 m .5322 .57686 L .54924 .56316 L 1 g
F
P
p
.002 w
.54924 .56316 m .54934 .56344 L p
.55015 .56219 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5039 .56673 m .53112 .54944 L .55059 .56171 L p
1 g
F P
s
P
p
.58115 .5323 m .55059 .56171 L .56875 .53655 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55059 .56171 m .53112 .54944 L p
.56875 .53655 L 1 g
F P
s
P
p
.002 w
.54934 .56344 m .54998 .56518 L p
.55613 .55404 L 1 g
F P
s
P
p
.002 w
.56136 .5468 m .56257 .5491 L p
.5649 .53629 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56746 .52843 m .5508 .52372 L p
.56613 .51249 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56747 .5287 L p
1 g
F P
s
P
p
.5649 .53629 m .56257 .5491 L .56747 .5287 L 1 g
F
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.56732 .52231 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53112 .54944 m .5508 .52372 L .56746 .52843 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55956 .4956 m .56061 .49223 L p
.5671 .51178 L 1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56545 .50713 L p
.5621 .50083 L 1 g
F P
s
P
p
.55661 .4905 m .5633 .50329 L .5621 .50083 L 1 g
F
P
p
.5633 .50329 m .56713 .51061 L .5621 .50083 L 1 g
F
P
p
.002 w
.56061 .49223 m .55956 .4956 L p
.55842 .49325 L 1 g
F P
s
P
p
.002 w
.55756 .49151 m .55661 .4905 L p
.5621 .50083 L 1 g
F P
s
P
p
.002 w
.55785 .49209 m .56061 .49223 L p
.55842 .49325 L 1 g
F P
s
P
p
.5621 .50083 m .56545 .50713 L .55785 .49209 L 1 g
F
P
p
.5621 .50083 m .55785 .49209 L .55756 .49151 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.51832 .51208 m .5249 .49042 L .55785 .49209 L p
1 g
F P
s
P
p
.55842 .49325 m .51832 .51208 L .55785 .49209 L 1 g
F
P
p
.002 w
.5508 .52372 m .51832 .51208 L p
.55842 .49325 L 1 g
F P
s
P
p
.002 w
.55956 .4956 m .5508 .52372 L p
.55842 .49325 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55756 .49151 L p
1 g
F P
s
P
p
.54602 .4803 m .55454 .48858 L .5249 .49042 L 1 g
F
P
p
.002 w
.56061 .49223 m .55785 .49209 L p
.55603 .48849 L 1 g
F P
s
P
p
.54174 .47608 m .55756 .49151 L .54946 .48364 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55785 .49209 m .5249 .49042 L p
.55454 .48858 L 1 g
F P
s
P
p
.55603 .48849 m .55756 .49151 L .55454 .48858 L 1 g
F
P
p
.55756 .49151 m .55785 .49209 L .55454 .48858 L 1 g
F
P
p
.54055 .47583 m .54602 .4803 L .5249 .49042 L 1 g
F
P
p
.002 w
.56545 .50713 m .55834 .49233 L .55756 .49151 L p
1 g
F P
s
P
p
.002 w
.54223 .47662 m .54174 .47608 L p
.54946 .48364 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.56032 .48513 m .56061 .49223 L p
.54055 .47583 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54223 .47662 L p
1 g
F P
s
P
p
.54946 .48364 m .55834 .49233 L .54223 .47662 L 1 g
F
P
p
.002 w
.55756 .49151 m .55834 .49233 L p
.54946 .48364 L 1 g
F P
s
P
p
.54602 .4803 m .55603 .48849 L .55454 .48858 L 1 g
F
P
p
.002 w
.5508 .52372 m .55956 .4956 L p
.5671 .51178 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56584 .50908 L p
1 g
F P
s
P
p
.56651 .51708 m .56854 .53025 L .56584 .50908 L 1 g
F
P
p
.002 w
.56584 .50908 m .56713 .51061 L p
.56188 .50059 L 1 g
F P
s
P
p
.52214 .46667 m .54223 .47662 L .53261 .47209 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52384 .46725 m .55925 .4584 L p
.54055 .47583 L 1 g
F P
s
P
p
.002 w
.5249 .49042 m .52387 .46798 L p
.54055 .47583 L 1 g
F P
s
P
p
.002 w
.5249 .49042 m .48816 .48674 L p
.52315 .46763 L 1 g
F P
s
P
p
.52214 .46667 m .53261 .47209 L .52387 .46798 L 1 g
F
P
p
.002 w
.52384 .46725 m .52387 .46798 L p
.52315 .46763 L 1 g
F P
s
P
p
.002 w
.52387 .46798 m .5249 .49042 L p
.52315 .46763 L 1 g
F P
s
P
p
.52358 .46784 m .52387 .46798 L .5236 .46785 L 1 g
F
P
p
.52214 .46667 m .52387 .46798 L .52358 .46784 L 1 g
F
P
p
.002 w
.48816 .48674 m .48756 .47499 L .52283 .46747 L p
1 g
F P
s
P
p
.002 w
.52283 .46747 m .52384 .46725 L p
.52315 .46763 L 1 g
F P
s
P
p
.52315 .46763 m .48816 .48674 L .52283 .46747 L 1 g
F
P
p
.002 w
.52256 .46736 m .52253 .46732 L p
.5236 .46785 L 1 g
F P
s
P
p
.002 w
.52283 .46747 m .48756 .47499 L p
.52149 .46716 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52253 .46732 L p
1 g
F P
s
P
p
.52198 .46704 m .52253 .46732 L .52149 .46716 L 1 g
F
P
p
.52253 .46732 m .52283 .46747 L .52149 .46716 L 1 g
F
P
p
.5 .4634 m .52253 .46732 L .51176 .46566 L 1 g
F
P
p
.49749 .46425 m .51722 .4665 L .48756 .47499 L 1 g
F
P
p
.51722 .4665 m .52198 .46704 L .52149 .46716 L 1 g
F
P
p
.51722 .4665 m .52149 .46716 L .48756 .47499 L 1 g
F
P
p
.002 w
.5 .46385 m .5 .4634 L p
.51176 .46566 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52214 .46667 L p
.5236 .46785 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52118 .46048 m .52384 .46725 L p
.49749 .46425 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46385 L p
1 g
F P
s
P
p
.51176 .46566 m .52282 .46778 L .5 .46385 L 1 g
F
P
p
.002 w
.52253 .46732 m .52282 .46778 L p
.51176 .46566 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52253 .46732 L p
.52283 .46747 L 1 g
F P
s
P
p
.52283 .46747 m .5236 .46785 L .52253 .46732 L 1 g
F
P
p
.002 w
.52384 .46725 m .52283 .46747 L p
.52198 .46704 L 1 g
F P
s
P
p
.002 w
.52387 .46798 m .52384 .46725 L p
.54055 .47583 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52256 .46736 L p
1 g
F P
s
P
p
.53261 .47209 m .54302 .47747 L .52256 .46736 L 1 g
F
P
p
.002 w
.54223 .47662 m .54302 .47747 L p
.53261 .47209 L 1 g
F P
s
P
p
.002 w
.55925 .4584 m .56032 .48513 L p
.54055 .47583 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46385 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46385 L .49139 .46523 L 1 g
F
P
p
.002 w
.51518 .44515 m .52118 .46048 L p
.49749 .46425 L 1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .46431 L p
.49139 .46523 L 1 g
F P
s
P
p
.002 w
.5 .46431 m .5 .46442 L p
.49622 .4648 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46431 L .49622 .4648 L 1 g
F
P
p
.002 w
.48313 .46381 m .48338 .46443 L p
.47751 .46725 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46725 L p
1 g
F P
s
P
p
.45826 .47608 m .47751 .46725 L .47374 .46906 L 1 g
F
P
p
.46804 .47179 m .47374 .46906 L .46808 .47178 L 1 g
F
P
p
.45826 .47608 m .47374 .46906 L .46804 .47179 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45761 .47679 L p
1 g
F P
s
P
p
.44339 .4905 m .45761 .47679 L .45752 .47688 L 1 g
F
P
p
.44339 .4905 m .4576 .4768 L .45732 .47708 L 1 g
F
P
p
.44339 .4905 m .45758 .47682 L .45658 .4778 L 1 g
F
P
p
.45632 .47805 m .4575 .47691 L .45678 .47761 L 1 g
F
P
p
.44339 .4905 m .45693 .47745 L .45632 .47805 L 1 g
F
P
p
.45693 .47745 m .4575 .47691 L .45632 .47805 L 1 g
F
P
p
.002 w
.48816 .48674 m .4849 .49776 L .45259 .48168 L p
1 g
F P
s
P
p
.44339 .4905 m .45746 .47696 L .45669 .47771 L 1 g
F
P
p
.44339 .4905 m .45741 .477 L .45591 .47847 L 1 g
F
P
p
.002 w
.45282 .48145 m .48816 .48674 L p
.45259 .48168 L 1 g
F P
s
P
p
.46804 .47179 m .46808 .47178 L .45761 .47679 L 1 g
F
P
p
.002 w
.45451 .4798 m .47374 .46906 L p
.45323 .48106 L 1 g
F P
s
P
p
.47547 .46823 m .45323 .48106 L .47374 .46906 L 1 g
F
P
p
.46808 .47178 m .47718 .46778 L .45782 .4767 L 1 g
F
P
p
.46808 .47178 m .45782 .4767 L .45761 .47679 L 1 g
F
P
p
.002 w
.47374 .46906 m .48313 .46381 L p
.47547 .46823 L 1 g
F P
s
P
p
.002 w
.46868 .51307 m .45751 .51574 L .45199 .48226 L p
1 g
F P
s
P
p
.002 w
.45222 .48203 m .46868 .51307 L p
.45199 .48226 L 1 g
F P
s
P
p
.44339 .4905 m .45462 .4797 L .45201 .48224 L 1 g
F
P
p
.002 w
.45323 .48106 m .48756 .47499 L p
.45282 .48145 L 1 g
F P
s
P
p
.002 w
.4849 .49776 m .47815 .50686 L .45241 .48186 L p
1 g
F P
s
P
p
.002 w
.45259 .48168 m .4849 .49776 L p
.45241 .48186 L 1 g
F P
s
P
p
.002 w
.45241 .48186 m .47815 .50686 L p
.45222 .48203 L 1 g
F P
s
P
p
.45462 .4797 m .45733 .47709 L .45231 .48195 L 1 g
F
P
p
.45462 .4797 m .45231 .48195 L .45201 .48224 L 1 g
F
P
p
.002 w
.45259 .48168 m .45184 .4813 L .45282 .48145 L p
1 g
F P
s
P
p
.002 w
.45451 .4798 m .45184 .4813 L p
.45569 .47771 L 1 g
F P
s
P
p
.002 w
.45761 .47679 m .45826 .47608 L p
.46804 .47179 L 1 g
F P
s
P
p
.47769 .45724 m .45761 .47679 L .45569 .47771 L 1 g
F
P
p
.45761 .47679 m .45451 .4798 L .45569 .47771 L 1 g
F
P
p
.002 w
.47751 .46725 m .47718 .46778 L p
.46808 .47178 L 1 g
F P
s
P
p
.47707 .46731 m .47751 .46725 L .47547 .46823 L 1 g
F
P
p
.48313 .46381 m .47751 .46725 L .47707 .46731 L 1 g
F
P
p
.002 w
.48313 .46381 m .51518 .44515 L p
.49749 .46425 L 1 g
F P
s
P
p
.002 w
.48415 .46638 m .48313 .46381 L p
.49749 .46425 L 1 g
F P
s
P
p
.002 w
.48338 .46443 m .48415 .46638 L p
.47751 .46725 L 1 g
F P
s
P
p
.002 w
.48415 .46638 m .48756 .47499 L p
.47751 .46725 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47751 .46725 L p
1 g
F P
s
P
p
.49622 .4648 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4576 .4768 L p
1 g
F P
s
P
p
.002 w
.4576 .4768 m .45761 .47679 L p
.45782 .4767 L 1 g
F P
s
P
p
.45782 .4767 m .47718 .46778 L .4576 .4768 L 1 g
F
P
p
.002 w
.47769 .45724 m .48313 .46381 L .47374 .46906 L p
1 g
F P
s
P
p
.47769 .45724 m .47374 .46906 L .45761 .47679 L 1 g
F
P
p
.002 w
.45761 .47679 m .4576 .4768 L p
.45752 .47688 L 1 g
F P
s
P
p
.002 w
.4576 .4768 m .45758 .47682 L p
.45732 .47708 L 1 g
F P
s
P
p
.002 w
.45323 .48106 m .45184 .4813 L .45451 .4798 L p
1 g
F P
s
P
p
.002 w
.45282 .48145 m .45184 .4813 L .45323 .48106 L p
1 g
F P
s
P
p
.002 w
.45758 .47682 m .4575 .47691 L p
.45658 .4778 L 1 g
F P
s
P
p
.002 w
.4575 .47691 m .45746 .47696 L p
.45678 .47761 L 1 g
F P
s
P
p
.002 w
.45241 .48186 m .45184 .4813 L .45259 .48168 L p
1 g
F P
s
P
p
.002 w
.45222 .48203 m .45184 .4813 L .45241 .48186 L p
1 g
F P
s
P
p
.002 w
.45746 .47696 m .45741 .477 L p
.45669 .47771 L 1 g
F P
s
P
p
.002 w
.45741 .477 m .45733 .47709 L p
.45591 .47847 L 1 g
F P
s
P
p
.002 w
.45199 .48226 m .45184 .4813 L .45222 .48203 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45194 .48231 L 1 g
F P
s
P
p
.002 w
.45184 .4813 m .4503 .48389 L p
.44994 .48424 L 1 g
F P
s
P
p
.002 w
.4503 .48389 m .43495 .50981 L p
.44994 .48424 L 1 g
F P
s
P
p
.002 w
.45733 .47709 m .45698 .47747 L p
.45201 .48224 L 1 g
F P
s
P
p
.002 w
.4516 .48264 m .45184 .4813 L .45199 .48226 L p
1 g
F P
s
P
p
.45194 .48231 m .45196 .48229 L .45169 .48255 L 1 g
F
P
p
.45194 .48231 m .45169 .48255 L .44258 .49136 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.4516 .48264 m .44585 .51461 L p
.4503 .48389 L 1 g
F P
s
P
p
.45196 .48229 m .45201 .48224 L .4503 .48389 L 1 g
F
P
p
.45196 .48229 m .4503 .48389 L .44258 .49136 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44585 .51461 m .43495 .50981 L .4503 .48389 L p
1 g
F P
s
P
p
.002 w
.4503 .48389 m .45184 .4813 L .4516 .48264 L p
1 g
F P
s
P
p
.002 w
.44473 .48695 m .45184 .4813 L p
.434 .50897 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44258 .49136 L p
1 g
F P
s
P
p
.45201 .48224 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.002 w
.44166 .49233 m .44022 .49534 L p
.43776 .50125 L 1 g
F P
s
P
p
.43847 .49979 m .44166 .49233 L .43776 .50125 L 1 g
F
P
p
.43346 .52734 m .4337 .50963 L .43366 .5102 L 1 g
F
P
p
.43346 .52734 m .43367 .50967 L .43315 .51857 L 1 g
F
P
p
.002 w
.43376 .50876 m .43495 .50981 L .43351 .51234 L p
1 g
F P
s
P
p
.002 w
.44022 .49534 m .43287 .51061 L .4337 .50963 L p
1 g
F P
s
P
p
.002 w
.4337 .50963 m .43367 .50967 L p
.43366 .5102 L 1 g
F P
s
P
p
.002 w
.42596 .50187 m .43376 .50876 L p
.42043 .53527 L 1 g
F P
s
P
p
.43647 .54237 m .43258 .52863 L .43495 .50981 L 1 g
F
P
p
.002 w
.4298 .51884 m .43351 .51234 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.43351 .51234 m .43495 .50981 L p
.43258 .52863 L 1 g
F P
s
P
p
.002 w
.43367 .50967 m .43287 .51061 L p
.43315 .51857 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43258 .52863 L p
1 g
F P
s
P
p
.43315 .51857 m .43287 .51061 L .43258 .52863 L 1 g
F
P
p
.43504 .53733 m .43334 .53397 L .43647 .54237 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44165 .54467 m .43647 .54237 L p
.43495 .50981 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43833 .54739 L p
1 g
F P
s
P
p
.43334 .53397 m .43146 .53025 L .43833 .54739 L 1 g
F
P
p
.002 w
.43833 .54739 m .4382 .54765 L p
.43957 .54906 L 1 g
F P
s
P
p
.002 w
.42043 .53527 m .43371 .54115 L p
.43931 .57048 L 1 g
F P
s
P
p
.4656 .57325 m .45089 .56283 L .44165 .54467 L 1 g
F
P
p
.002 w
.44066 .55559 m .44107 .55108 L p
.45089 .56283 L 1 g
F P
s
P
p
.002 w
.44107 .55108 m .44165 .54467 L p
.45089 .56283 L 1 g
F P
s
P
p
.002 w
.4382 .54765 m .43743 .5491 L p
.44467 .55539 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45089 .56283 L p
1 g
F P
s
P
p
.44467 .55539 m .43743 .5491 L .45089 .56283 L 1 g
F
P
p
.45963 .56902 m .45607 .5676 L .4656 .57325 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47217 .57394 m .4656 .57325 L p
.44165 .54467 L 1 g
F P
s
P
p
.002 w
.46302 .57298 m .47217 .57394 L .47317 .57655 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46825 .57482 L p
1 g
F P
s
P
p
.45607 .5676 m .45002 .56518 L .46825 .57482 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48895 .58211 L p
1 g
F P
s
P
p
.47596 .57753 m .4678 .57686 L .48895 .58211 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52097 .58685 m .5558 .565 L .57813 .57612 L p
1 g
F P
s
P
p
.002 w
.60831 .53762 m .57813 .57612 L .5558 .565 L p
1 g
F P
s
P
p
.004 w
.47627 .45553 m
.5 .43051 L
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.58849 .32709 m .53774 .2953 L .54966 .2755 L p
1 g
F P
s
P
p
.002 w
.54966 .2755 m .6043 .30965 L .58849 .32709 L p
1 g
F P
s
P
p
.002 w
.47331 .30768 m .42255 .31283 L .42355 .28779 L p
1 g
F P
s
P
p
.002 w
.42355 .28779 m .48048 .28178 L .47331 .30768 L p
1 g
F P
s
P
p
.002 w
.64745 .42878 m .62656 .37346 L .64523 .35956 L p
1 g
F P
s
P
p
.002 w
.6043 .30965 m .64523 .35956 L .62656 .37346 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.37509 .4117 m .36155 .441 L .33999 .427 L p
1 g
F P
s
P
p
.002 w
.33999 .427 m .35705 .38956 L .37509 .4117 L p
1 g
F P
s
P
p
.002 w
.62656 .37346 m .58849 .32709 L .6043 .30965 L p
1 g
F P
s
P
p
.002 w
.64745 .42878 m .64898 .4864 L .62372 .49012 L p
1 g
F P
s
P
p
.002 w
.60831 .53762 m .62372 .49012 L .64898 .4864 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.39093 .49986 m .40292 .5198 L .38345 .53454 L p
1 g
F P
s
P
p
.002 w
.38345 .53454 m .36611 .50579 L .39093 .49986 L p
1 g
F P
s
P
p
.002 w
.4087 .55686 m .38345 .53454 L .40292 .5198 L p
1 g
F P
s
P
p
.002 w
.40292 .5198 m .42043 .53527 L .4087 .55686 L p
1 g
F P
s
P
p
.002 w
.43931 .57048 m .4087 .55686 L .42043 .53527 L p
1 g
F P
s
P
p
.002 w
.4239 .3422 m .38597 .36013 L .37778 .33431 L p
1 g
F P
s
P
p
.002 w
.37778 .33431 m .42255 .31283 L .4239 .3422 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.38574 .47751 m .39093 .49986 L .36611 .50579 L p
1 g
F P
s
P
p
.002 w
.36611 .50579 m .35851 .47351 L .38574 .47751 L p
1 g
F P
s
P
p
.002 w
.5558 .565 m .58115 .5323 L .60831 .53762 L p
1 g
F P
s
P
p
.002 w
.62372 .49012 m .60831 .53762 L .58115 .5323 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.52429 .31987 m .47331 .30768 L .48048 .28178 L p
1 g
F P
s
P
p
.002 w
.48048 .28178 m .53774 .2953 L .52429 .31987 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39788 .3888 m .37509 .4117 L .35705 .38956 L p
1 g
F P
s
P
p
.002 w
.35705 .38956 m .38597 .36013 L .39788 .3888 L p
1 g
F P
s
P
p
.002 w
.38795 .45507 m .38574 .47751 L .35851 .47351 L p
1 g
F P
s
P
p
.002 w
.35851 .47351 m .36155 .441 L .38795 .45507 L p
1 g
F P
s
P
p
.002 w
.62372 .49012 m .62216 .43878 L .64745 .42878 L p
1 g
F P
s
P
p
.002 w
.62656 .37346 m .64745 .42878 L .62216 .43878 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.44165 .54467 m .46438 .54697 L .47217 .57394 L p
1 g
F P
s
P
p
.002 w
.5039 .56673 m .47217 .57394 L .46438 .54697 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.46677 .33806 m .4239 .3422 L .42255 .31283 L p
1 g
F P
s
P
p
.002 w
.42255 .31283 m .47331 .30768 L .46677 .33806 L p
1 g
F P
s
P
p
.002 w
.56947 .34825 m .52429 .31987 L .53774 .2953 L p
1 g
F P
s
P
p
.002 w
.53774 .2953 m .58849 .32709 L .56947 .34825 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.39741 .43494 m .38795 .45507 L .36155 .441 L p
1 g
F P
s
P
p
.002 w
.36155 .441 m .37509 .4117 L .39741 .43494 L p
1 g
F P
s
P
p
.002 w
.62216 .43878 m .60342 .38953 L .62656 .37346 L p
1 g
F P
s
P
p
.002 w
.58849 .32709 m .62656 .37346 L .60342 .38953 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62216 .43878 m .62372 .49012 L .59395 .49211 L p
1 g
F P
s
P
p
.002 w
.58115 .5323 m .59395 .49211 L .62372 .49012 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46438 .54697 m .48626 .54189 L .5039 .56673 L p
1 g
F P
s
P
p
.002 w
.53112 .54944 m .5039 .56673 L .48626 .54189 L p
1 g
F P
s
P
p
.002 w
.60342 .38953 m .56947 .34825 L .58849 .32709 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42763 .37496 m .39788 .3888 L .38597 .36013 L p
1 g
F P
s
P
p
.002 w
.38597 .36013 m .4239 .3422 L .42763 .37496 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.41983 .49162 m .42596 .50187 L .40292 .5198 L p
1 g
F P
s
P
p
.002 w
.40292 .5198 m .39093 .49986 L .41983 .49162 L p
1 g
F P
s
P
p
.002 w
.42043 .53527 m .40292 .5198 L .42596 .50187 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41721 .48015 m .41983 .49162 L .39093 .49986 L p
1 g
F P
s
P
p
.002 w
.39093 .49986 m .38574 .47751 L .41721 .48015 L p
1 g
F P
s
P
p
.002 w
.43495 .50981 m .44585 .51461 L .44165 .54467 L p
1 g
F P
s
P
p
.002 w
.46438 .54697 m .44165 .54467 L .44585 .51461 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.4132 .41931 m .39741 .43494 L .37509 .4117 L p
1 g
F P
s
P
p
.002 w
.37509 .4117 m .39788 .3888 L .4132 .41931 L p
1 g
F P
s
P
p
.002 w
.50975 .34849 m .46677 .33806 L .47331 .30768 L p
1 g
F P
s
P
p
.002 w
.47331 .30768 m .52429 .31987 L .50975 .34849 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4184 .46868 m .41721 .48015 L .38574 .47751 L p
1 g
F P
s
P
p
.002 w
.38574 .47751 m .38795 .45507 L .4184 .46868 L p
1 g
F P
s
P
p
.002 w
.48626 .54189 m .50492 .52985 L .53112 .54944 L p
1 g
F P
s
P
p
.002 w
.5508 .52372 m .53112 .54944 L .50492 .52985 L p
1 g
F P
s
P
p
.002 w
.59395 .49211 m .59243 .44878 L .62216 .43878 L p
1 g
F P
s
P
p
.002 w
.60342 .38953 m .62216 .43878 L .59243 .44878 L p
1 g
F P
s
P
p
.002 w
.44585 .51461 m .45751 .51574 L .46438 .54697 L p
1 g
F P
s
P
p
.002 w
.48626 .54189 m .46438 .54697 L .45751 .51574 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46114 .37192 m .42763 .37496 L .4239 .3422 L p
1 g
F P
s
P
p
.002 w
.4239 .3422 m .46677 .33806 L .46114 .37192 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.4233 .45844 m .4184 .46868 L .38795 .45507 L p
1 g
F P
s
P
p
.002 w
.38795 .45507 m .39741 .43494 L .4233 .45844 L p
1 g
F P
s
P
p
.002 w
.54783 .37248 m .50975 .34849 L .52429 .31987 L p
1 g
F P
s
P
p
.002 w
.52429 .31987 m .56947 .34825 L .54783 .37248 L p
1 g
F P
s
P
p
.002 w
.59243 .44878 m .59395 .49211 L .56061 .49223 L p
1 g
F P
s
P
p
.002 w
.45751 .51574 m .46868 .51307 L .48626 .54189 L p
1 g
F P
s
P
p
.002 w
.50492 .52985 m .48626 .54189 L .46868 .51307 L p
1 g
F P
s
P
p
.002 w
.59243 .44878 m .57649 .40728 L .60342 .38953 L p
1 g
F P
s
P
p
.002 w
.56947 .34825 m .60342 .38953 L .57649 .40728 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43369 .40996 m .4132 .41931 L .39788 .3888 L p
1 g
F P
s
P
p
.002 w
.39788 .3888 m .42763 .37496 L .43369 .40996 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57649 .40728 m .54783 .37248 L .56947 .34825 L p
1 g
F P
s
P
p
.002 w
.50492 .52985 m .51832 .51208 L .5508 .52372 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42596 .50187 m .41983 .49162 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.43141 .45055 m .4233 .45844 L .39741 .43494 L p
1 g
F P
s
P
p
.002 w
.39741 .43494 m .4132 .41931 L .43141 .45055 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.41983 .49162 m .41721 .48015 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46868 .51307 m .47815 .50686 L .50492 .52985 L p
1 g
F P
s
P
p
.002 w
.51832 .51208 m .50492 .52985 L .47815 .50686 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49466 .38018 m .46114 .37192 L .46677 .33806 L p
1 g
F P
s
P
p
.002 w
.46677 .33806 m .50975 .34849 L .49466 .38018 L p
1 g
F P
s
P
p
.002 w
.41721 .48015 m .4184 .46868 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.56061 .49223 m .55925 .4584 L .59243 .44878 L p
1 g
F P
s
P
p
.002 w
.57649 .40728 m .59243 .44878 L .55925 .4584 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45666 .40801 m .43369 .40996 L .42763 .37496 L p
1 g
F P
s
P
p
.002 w
.42763 .37496 m .46114 .37192 L .45666 .40801 L p
1 g
F P
s
P
p
.002 w
.4184 .46868 m .4233 .45844 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.44186 .44587 m .43141 .45055 L .4132 .41931 L p
1 g
F P
s
P
p
.002 w
.4132 .41931 m .43369 .40996 L .44186 .44587 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.47815 .50686 m .4849 .49776 L .51832 .51208 L p
1 g
F P
s
P
p
.002 w
.5249 .49042 m .51832 .51208 L .4849 .49776 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.52432 .39894 m .49466 .38018 L .50975 .34849 L p
1 g
F P
s
P
p
.002 w
.50975 .34849 m .54783 .37248 L .52432 .39894 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.4233 .45844 m .43141 .45055 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.55925 .4584 m .54671 .42606 L .57649 .40728 L p
1 g
F P
s
P
p
.002 w
.54783 .37248 m .57649 .40728 L .54671 .42606 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54671 .42606 m .52432 .39894 L .54783 .37248 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.43141 .45055 m .44186 .44587 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.47958 .41376 m .45666 .40801 L .46114 .37192 L p
1 g
F P
s
P
p
.002 w
.46114 .37192 m .49466 .38018 L .47958 .41376 L p
1 g
F P
s
P
p
.002 w
.46512 .44791 m .47537 .45444 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.45352 .44495 m .46512 .44791 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.44186 .44587 m .45352 .44495 L .45184 .4813 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.45352 .44495 m .44186 .44587 L .43369 .40996 L p
1 g
F P
s
P
p
.002 w
.43369 .40996 m .45666 .40801 L .45352 .44495 L p
1 g
F P
s
P
p
.002 w
.4849 .49776 m .48816 .48674 L .5249 .49042 L p
1 g
F P
s
P
p
.002 w
.54671 .42606 m .55925 .4584 L .52384 .46725 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.004 w
.45029 .48294 m
.45184 .4813 L
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49985 .42662 m .47958 .41376 L .49466 .38018 L p
1 g
F P
s
P
p
.002 w
.49466 .38018 m .52432 .39894 L .49985 .42662 L p
1 g
F P
s
P
p
.002 w
.46512 .44791 m .45352 .44495 L .45666 .40801 L p
1 g
F P
s
P
p
.002 w
.45666 .40801 m .47958 .41376 L .46512 .44791 L p
1 g
F P
s
P
p
.002 w
.52384 .46725 m .51518 .44515 L .54671 .42606 L p
1 g
F P
s
P
p
.002 w
.52432 .39894 m .54671 .42606 L .51518 .44515 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51518 .44515 m .49985 .42662 L .52432 .39894 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47537 .45444 m .46512 .44791 L .47958 .41376 L p
1 g
F P
s
P
p
.002 w
.48313 .46381 m .47537 .45444 L .49985 .42662 L p
1 g
F P
s
P
p
.002 w
.49985 .42662 m .51518 .44515 L .48313 .46381 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47958 .41376 m .49985 .42662 L .47537 .45444 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.4222 .51255 m
.45029 .48294 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .68 .62666 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4222 .51255 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.233333)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.233333)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47649 .44798 m .49263 .45705 L .50241 .43026 L p
1 g
F P
s
P
p
.002 w
.50241 .43026 m .49424 .42567 L .47649 .44798 L p
1 g
F P
s
P
p
.002 w
.51161 .43199 m .50241 .43026 L .49263 .45705 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .49424 .42567 L .50241 .43026 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .50241 .43026 L .51161 .43199 L closepath p
1 g
F P
s
P
p
.002 w
.46411 .43425 m .47649 .44798 L .49424 .42567 L p
1 g
F P
s
P
p
.002 w
.49424 .42567 m .48799 .41871 L .46411 .43425 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .48799 .41871 L .49424 .42567 L closepath p
1 g
F P
s
P
p
.002 w
.49263 .45705 m .51082 .46048 L .51161 .43199 L p
1 g
F P
s
P
p
.002 w
.52087 .43067 m .51161 .43199 L .51082 .46048 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .51161 .43199 L .52087 .43067 L closepath p
1 g
F P
s
P
p
.002 w
.45683 .41731 m .46411 .43425 L .48799 .41871 L p
1 g
F P
s
P
p
.002 w
.48799 .41871 m .48432 .41013 L .45683 .41731 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .48432 .41013 L .48799 .41871 L closepath p
1 g
F P
s
P
p
.002 w
.51082 .46048 m .52911 .45792 L .52087 .43067 L p
1 g
F P
s
P
p
.002 w
.52917 .42645 m .52087 .43067 L .52911 .45792 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .52087 .43067 L .52917 .42645 L closepath p
1 g
F P
s
P
p
.002 w
.45543 .39895 m .45683 .41731 L .48432 .41013 L p
1 g
F P
s
P
p
.002 w
.48432 .41013 m .48364 .40085 L .45543 .39895 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .48364 .40085 L .48432 .41013 L closepath p
1 g
F P
s
P
p
.002 w
.4592 .47001 m .48298 .48336 L .49263 .45705 L p
1 g
F P
s
P
p
.002 w
.49263 .45705 m .47649 .44798 L .4592 .47001 L p
1 g
F P
s
P
p
.002 w
.51082 .46048 m .49263 .45705 L .48298 .48336 L p
1 g
F P
s
P
p
.002 w
.44094 .44981 m .4592 .47001 L .47649 .44798 L p
1 g
F P
s
P
p
.002 w
.47649 .44798 m .46411 .43425 L .44094 .44981 L p
1 g
F P
s
P
p
.002 w
.52911 .45792 m .54555 .4496 L .52917 .42645 L p
1 g
F P
s
P
p
.002 w
.53563 .41976 m .52917 .42645 L .54555 .4496 L p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .52917 .42645 L .53563 .41976 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .53563 .41976 L .53954 .41133 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .53954 .41133 L .54046 .40206 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .54046 .40206 L .5383 .39297 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .5383 .39297 L .53327 .38503 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .53327 .38503 L .52592 .37913 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .52592 .37913 L .51706 .37591 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .51706 .37591 L .50765 .37572 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .50765 .37572 L .49872 .37858 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .49872 .37858 L .49125 .38417 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .49125 .38417 L .48603 .39187 L closepath p
1 g
F P
s
P
p
.002 w
.51213 .40347 m .48603 .39187 L .48364 .40085 L closepath p
1 g
F P
s
P
p
.002 w
.48298 .48336 m .50975 .48844 L .51082 .46048 L p
1 g
F P
s
P
p
.002 w
.52911 .45792 m .51082 .46048 L .50975 .48844 L p
1 g
F P
s
P
p
.002 w
.46011 .38115 m .45543 .39895 L .48364 .40085 L p
1 g
F P
s
P
p
.002 w
.48364 .40085 m .48603 .39187 L .46011 .38115 L p
1 g
F P
s
P
p
.002 w
.43015 .42486 m .44094 .44981 L .46411 .43425 L p
1 g
F P
s
P
p
.002 w
.46411 .43425 m .45683 .41731 L .43015 .42486 L p
1 g
F P
s
P
p
.002 w
.53954 .41133 m .53563 .41976 L .55838 .4364 L p
1 g
F P
s
P
p
.002 w
.54555 .4496 m .55838 .4364 L .53563 .41976 L p
1 g
F P
s
P
p
.002 w
.50975 .48844 m .53671 .4847 L .52911 .45792 L p
1 g
F P
s
P
p
.002 w
.54555 .4496 m .52911 .45792 L .53671 .4847 L p
1 g
F P
s
P
p
.002 w
.4704 .36584 m .46011 .38115 L .48603 .39187 L p
1 g
F P
s
P
p
.002 w
.48603 .39187 m .49125 .38417 L .4704 .36584 L p
1 g
F P
s
P
p
.002 w
.55838 .4364 m .56618 .41972 L .53954 .41133 L p
1 g
F P
s
P
p
.002 w
.54046 .40206 m .53954 .41133 L .56618 .41972 L p
1 g
F P
s
P
p
.002 w
.42801 .39779 m .43015 .42486 L .45683 .41731 L p
1 g
F P
s
P
p
.002 w
.45683 .41731 m .45543 .39895 L .42801 .39779 L p
1 g
F P
s
P
p
.002 w
.4852 .3547 m .4704 .36584 L .49125 .38417 L p
1 g
F P
s
P
p
.002 w
.49125 .38417 m .49872 .37858 L .4852 .3547 L p
1 g
F P
s
P
p
.002 w
.53671 .4847 m .56098 .4725 L .54555 .4496 L p
1 g
F P
s
P
p
.002 w
.55838 .4364 m .54555 .4496 L .56098 .4725 L p
1 g
F P
s
P
p
.002 w
.56618 .41972 m .56807 .40134 L .54046 .40206 L p
1 g
F P
s
P
p
.002 w
.5383 .39297 m .54046 .40206 L .56807 .40134 L p
1 g
F P
s
P
p
.002 w
.50292 .34899 m .4852 .3547 L .49872 .37858 L p
1 g
F P
s
P
p
.002 w
.49872 .37858 m .50765 .37572 L .50292 .34899 L p
1 g
F P
s
P
p
.002 w
.56807 .40134 m .56382 .38327 L .5383 .39297 L p
1 g
F P
s
P
p
.002 w
.53327 .38503 m .5383 .39297 L .56382 .38327 L p
1 g
F P
s
P
p
.002 w
.43484 .3715 m .42801 .39779 L .45543 .39895 L p
1 g
F P
s
P
p
.002 w
.45543 .39895 m .46011 .38115 L .43484 .3715 L p
1 g
F P
s
P
p
.002 w
.52163 .34934 m .50292 .34899 L .50765 .37572 L p
1 g
F P
s
P
p
.002 w
.50765 .37572 m .51706 .37591 L .52163 .34934 L p
1 g
F P
s
P
p
.002 w
.44269 .49136 m .47362 .5087 L .48298 .48336 L p
1 g
F P
s
P
p
.002 w
.48298 .48336 m .4592 .47001 L .44269 .49136 L p
1 g
F P
s
P
p
.002 w
.50975 .48844 m .48298 .48336 L .47362 .5087 L p
1 g
F P
s
P
p
.002 w
.56382 .38327 m .55385 .36749 L .53327 .38503 L p
1 g
F P
s
P
p
.002 w
.52592 .37913 m .53327 .38503 L .55385 .36749 L p
1 g
F P
s
P
p
.002 w
.41891 .46511 m .44269 .49136 L .4592 .47001 L p
1 g
F P
s
P
p
.002 w
.4592 .47001 m .44094 .44981 L .41891 .46511 L p
1 g
F P
s
P
p
.002 w
.53925 .35574 m .52163 .34934 L .51706 .37591 L p
1 g
F P
s
P
p
.002 w
.51706 .37591 m .52592 .37913 L .53925 .35574 L p
1 g
F P
s
P
p
.002 w
.55385 .36749 m .53925 .35574 L .52592 .37913 L p
1 g
F P
s
P
p
.002 w
.56618 .41972 m .55838 .4364 L .57996 .45309 L p
1 g
F P
s
P
p
.002 w
.56098 .4725 m .57996 .45309 L .55838 .4364 L p
1 g
F P
s
P
p
.002 w
.47362 .5087 m .50843 .51533 L .50975 .48844 L p
1 g
F P
s
P
p
.002 w
.53671 .4847 m .50975 .48844 L .50843 .51533 L p
1 g
F P
s
P
p
.002 w
.40479 .43267 m .41891 .46511 L .44094 .44981 L p
1 g
F P
s
P
p
.002 w
.44094 .44981 m .43015 .42486 L .40479 .43267 L p
1 g
F P
s
P
p
.002 w
.44997 .34883 m .43484 .3715 L .46011 .38115 L p
1 g
F P
s
P
p
.002 w
.46011 .38115 m .4704 .36584 L .44997 .34883 L p
1 g
F P
s
P
p
.002 w
.50843 .51533 m .54351 .51053 L .53671 .4847 L p
1 g
F P
s
P
p
.002 w
.56098 .4725 m .53671 .4847 L .54351 .51053 L p
1 g
F P
s
P
p
.002 w
.57996 .45309 m .59155 .42849 L .56618 .41972 L p
1 g
F P
s
P
p
.002 w
.56807 .40134 m .56618 .41972 L .59155 .42849 L p
1 g
F P
s
P
p
.002 w
.40192 .39743 m .40479 .43267 L .43015 .42486 L p
1 g
F P
s
P
p
.002 w
.43015 .42486 m .42801 .39779 L .40192 .39743 L p
1 g
F P
s
P
p
.002 w
.47182 .3323 m .44997 .34883 L .4704 .36584 L p
1 g
F P
s
P
p
.002 w
.4704 .36584 m .4852 .3547 L .47182 .3323 L p
1 g
F P
s
P
p
.002 w
.54351 .51053 m .57515 .49473 L .56098 .4725 L p
1 g
F P
s
P
p
.002 w
.57996 .45309 m .56098 .4725 L .57515 .49473 L p
1 g
F P
s
P
p
.002 w
.59155 .42849 m .59443 .40133 L .56807 .40134 L p
1 g
F P
s
P
p
.002 w
.56382 .38327 m .56807 .40134 L .59443 .40133 L p
1 g
F P
s
P
p
.002 w
.49804 .32379 m .47182 .3323 L .4852 .3547 L p
1 g
F P
s
P
p
.002 w
.4852 .3547 m .50292 .34899 L .49804 .32379 L p
1 g
F P
s
P
p
.002 w
.41072 .36313 m .40192 .39743 L .42801 .39779 L p
1 g
F P
s
P
p
.002 w
.42801 .39779 m .43484 .3715 L .41072 .36313 L p
1 g
F P
s
P
p
.002 w
.59443 .40133 m .5882 .37457 L .56382 .38327 L p
1 g
F P
s
P
p
.002 w
.55385 .36749 m .56382 .38327 L .5882 .37457 L p
1 g
F P
s
P
p
.002 w
.52575 .32428 m .49804 .32379 L .50292 .34899 L p
1 g
F P
s
P
p
.002 w
.50292 .34899 m .52163 .34934 L .52575 .32428 L p
1 g
F P
s
P
p
.002 w
.42729 .51159 m .46473 .53258 L .47362 .5087 L p
1 g
F P
s
P
p
.002 w
.47362 .5087 m .44269 .49136 L .42729 .51159 L p
1 g
F P
s
P
p
.002 w
.50843 .51533 m .47362 .5087 L .46473 .53258 L p
1 g
F P
s
P
p
.002 w
.5882 .37457 m .57348 .35117 L .55385 .36749 L p
1 g
F P
s
P
p
.002 w
.53925 .35574 m .55385 .36749 L .57348 .35117 L p
1 g
F P
s
P
p
.002 w
.57515 .49473 m .59994 .46951 L .57996 .45309 L p
1 g
F P
s
P
p
.002 w
.59155 .42849 m .57996 .45309 L .59994 .46951 L p
1 g
F P
s
P
p
.002 w
.39845 .47984 m .42729 .51159 L .44269 .49136 L p
1 g
F P
s
P
p
.002 w
.44269 .49136 m .41891 .46511 L .39845 .47984 L p
1 g
F P
s
P
p
.002 w
.55187 .33376 m .52575 .32428 L .52163 .34934 L p
1 g
F P
s
P
p
.002 w
.52163 .34934 m .53925 .35574 L .55187 .33376 L p
1 g
F P
s
P
p
.002 w
.57348 .35117 m .55187 .33376 L .53925 .35574 L p
1 g
F P
s
P
p
.002 w
.46473 .53258 m .50688 .54064 L .50843 .51533 L p
1 g
F P
s
P
p
.002 w
.54351 .51053 m .50843 .51533 L .50688 .54064 L p
1 g
F P
s
P
p
.002 w
.43037 .3335 m .41072 .36313 L .43484 .3715 L p
1 g
F P
s
P
p
.002 w
.43484 .3715 m .44997 .34883 L .43037 .3335 L p
1 g
F P
s
P
p
.002 w
.38128 .44058 m .39845 .47984 L .41891 .46511 L p
1 g
F P
s
P
p
.002 w
.41891 .46511 m .40479 .43267 L .38128 .44058 L p
1 g
F P
s
P
p
.002 w
.50688 .54064 m .54937 .53489 L .54351 .51053 L p
1 g
F P
s
P
p
.002 w
.57515 .49473 m .54351 .51053 L .54937 .53489 L p
1 g
F P
s
P
p
.002 w
.59994 .46951 m .61515 .43747 L .59155 .42849 L p
1 g
F P
s
P
p
.002 w
.59443 .40133 m .59155 .42849 L .61515 .43747 L p
1 g
F P
s
P
p
.002 w
.37769 .39788 m .38128 .44058 L .40479 .43267 L p
1 g
F P
s
P
p
.002 w
.40479 .43267 m .40192 .39743 L .37769 .39788 L p
1 g
F P
s
P
p
.002 w
.45885 .31185 m .43037 .3335 L .44997 .34883 L p
1 g
F P
s
P
p
.002 w
.44997 .34883 m .47182 .3323 L .45885 .31185 L p
1 g
F P
s
P
p
.002 w
.61515 .43747 m .619 .40204 L .59443 .40133 L p
1 g
F P
s
P
p
.002 w
.5882 .37457 m .59443 .40133 L .619 .40204 L p
1 g
F P
s
P
p
.002 w
.54937 .53489 m .58774 .51583 L .57515 .49473 L p
1 g
F P
s
P
p
.002 w
.59994 .46951 m .57515 .49473 L .58774 .51583 L p
1 g
F P
s
P
p
.002 w
.4931 .30066 m .45885 .31185 L .47182 .3323 L p
1 g
F P
s
P
p
.002 w
.47182 .3323 m .49804 .32379 L .4931 .30066 L p
1 g
F P
s
P
p
.002 w
.38825 .35625 m .37769 .39788 L .40192 .39743 L p
1 g
F P
s
P
p
.002 w
.40192 .39743 m .41072 .36313 L .38825 .35625 L p
1 g
F P
s
P
p
.002 w
.619 .40204 m .61094 .36706 L .5882 .37457 L p
1 g
F P
s
P
p
.002 w
.57348 .35117 m .5882 .37457 L .61094 .36706 L p
1 g
F P
s
P
p
.002 w
.52933 .30127 m .4931 .30066 L .49804 .32379 L p
1 g
F P
s
P
p
.002 w
.49804 .32379 m .52575 .32428 L .52933 .30127 L p
1 g
F P
s
P
p
.002 w
.61515 .43747 m .59994 .46951 L .61789 .48533 L p
1 g
F P
s
P
p
.002 w
.58774 .51583 m .61789 .48533 L .59994 .46951 L p
1 g
F P
s
P
p
.002 w
.41334 .53029 m .45652 .55448 L .46473 .53258 L p
1 g
F P
s
P
p
.002 w
.46473 .53258 m .42729 .51159 L .41334 .53029 L p
1 g
F P
s
P
p
.002 w
.50688 .54064 m .46473 .53258 L .45652 .55448 L p
1 g
F P
s
P
p
.002 w
.61094 .36706 m .59174 .33645 L .57348 .35117 L p
1 g
F P
s
P
p
.002 w
.55187 .33376 m .57348 .35117 L .59174 .33645 L p
1 g
F P
s
P
p
.002 w
.38004 .49371 m .41334 .53029 L .42729 .51159 L p
1 g
F P
s
P
p
.002 w
.42729 .51159 m .39845 .47984 L .38004 .49371 L p
1 g
F P
s
P
p
.002 w
.56349 .31366 m .52933 .30127 L .52575 .32428 L p
1 g
F P
s
P
p
.002 w
.52575 .32428 m .55187 .33376 L .56349 .31366 L p
1 g
F P
s
P
p
.002 w
.59174 .33645 m .56349 .31366 L .55187 .33376 L p
1 g
F P
s
P
p
.002 w
.45652 .55448 m .50512 .56381 L .50688 .54064 L p
1 g
F P
s
P
p
.002 w
.54937 .53489 m .50688 .54064 L .50512 .56381 L p
1 g
F P
s
P
p
.002 w
.41201 .32022 m .38825 .35625 L .41072 .36313 L p
1 g
F P
s
P
p
.002 w
.41072 .36313 m .43037 .3335 L .41201 .32022 L p
1 g
F P
s
P
p
.002 w
.36014 .44845 m .38004 .49371 L .39845 .47984 L p
1 g
F P
s
P
p
.002 w
.39845 .47984 m .38128 .44058 L .36014 .44845 L p
1 g
F P
s
P
p
.002 w
.61789 .48533 m .63645 .44651 L .61515 .43747 L p
1 g
F P
s
P
p
.002 w
.619 .40204 m .61515 .43747 L .63645 .44651 L p
1 g
F P
s
P
p
.002 w
.50512 .56381 m .55414 .55724 L .54937 .53489 L p
1 g
F P
s
P
p
.002 w
.58774 .51583 m .54937 .53489 L .55414 .55724 L p
1 g
F P
s
P
p
.002 w
.35589 .39917 m .36014 .44845 L .38128 .44058 L p
1 g
F P
s
P
p
.002 w
.38128 .44058 m .37769 .39788 L .35589 .39917 L p
1 g
F P
s
P
p
.002 w
.44656 .29384 m .41201 .32022 L .43037 .3335 L p
1 g
F P
s
P
p
.002 w
.43037 .3335 m .45885 .31185 L .44656 .29384 L p
1 g
F P
s
P
p
.002 w
.63645 .44651 m .64123 .40348 L .619 .40204 L p
1 g
F P
s
P
p
.002 w
.61094 .36706 m .619 .40204 L .64123 .40348 L p
1 g
F P
s
P
p
.002 w
.55414 .55724 m .59846 .53534 L .58774 .51583 L p
1 g
F P
s
P
p
.002 w
.61789 .48533 m .58774 .51583 L .59846 .53534 L p
1 g
F P
s
P
p
.002 w
.48818 .28017 m .44656 .29384 L .45885 .31185 L p
1 g
F P
s
P
p
.002 w
.45885 .31185 m .4931 .30066 L .48818 .28017 L p
1 g
F P
s
P
p
.002 w
.36797 .35106 m .35589 .39917 L .37769 .39788 L p
1 g
F P
s
P
p
.002 w
.37769 .39788 m .38825 .35625 L .36797 .35106 L p
1 g
F P
s
P
p
.002 w
.64123 .40348 m .63151 .36096 L .61094 .36706 L p
1 g
F P
s
P
p
.002 w
.59174 .33645 m .61094 .36706 L .63151 .36096 L p
1 g
F P
s
P
p
.002 w
.59846 .53534 m .63335 .50021 L .61789 .48533 L p
1 g
F P
s
P
p
.002 w
.63645 .44651 m .61789 .48533 L .63335 .50021 L p
1 g
F P
s
P
p
.002 w
.53227 .28086 m .48818 .28017 L .4931 .30066 L p
1 g
F P
s
P
p
.002 w
.4931 .30066 m .52933 .30127 L .53227 .28086 L p
1 g
F P
s
P
p
.002 w
.40118 .54701 m .44917 .57388 L .45652 .55448 L p
1 g
F P
s
P
p
.002 w
.45652 .55448 m .41334 .53029 L .40118 .54701 L p
1 g
F P
s
P
p
.002 w
.50512 .56381 m .45652 .55448 L .44917 .57388 L p
1 g
F P
s
P
p
.002 w
.63151 .36096 m .60821 .32369 L .59174 .33645 L p
1 g
F P
s
P
p
.002 w
.56349 .31366 m .59174 .33645 L .60821 .32369 L p
1 g
F P
s
P
p
.002 w
.36412 .50638 m .40118 .54701 L .41334 .53029 L p
1 g
F P
s
P
p
.002 w
.41334 .53029 m .38004 .49371 L .36412 .50638 L p
1 g
F P
s
P
p
.002 w
.57385 .29594 m .53227 .28086 L .52933 .30127 L p
1 g
F P
s
P
p
.002 w
.52933 .30127 m .56349 .31366 L .57385 .29594 L p
1 g
F P
s
P
p
.002 w
.60821 .32369 m .57385 .29594 L .56349 .31366 L p
1 g
F P
s
P
p
.002 w
.44917 .57388 m .50318 .58427 L .50512 .56381 L p
1 g
F P
s
P
p
.002 w
.55414 .55724 m .50512 .56381 L .50318 .58427 L p
1 g
F P
s
P
p
.002 w
.39534 .30935 m .36797 .35106 L .38825 .35625 L p
1 g
F P
s
P
p
.002 w
.38825 .35625 m .41201 .32022 L .39534 .30935 L p
1 g
F P
s
P
p
.002 w
.34192 .4561 m .36412 .50638 L .38004 .49371 L p
1 g
F P
s
P
p
.002 w
.38004 .49371 m .36014 .44845 L .34192 .4561 L p
1 g
F P
s
P
p
.002 w
.63335 .50021 m .6549 .45541 L .63645 .44651 L p
1 g
F P
s
P
p
.002 w
.64123 .40348 m .63645 .44651 L .6549 .45541 L p
1 g
F P
s
P
p
.002 w
.50318 .58427 m .55767 .57705 L .55414 .55724 L p
1 g
F P
s
P
p
.002 w
.59846 .53534 m .55414 .55724 L .55767 .57705 L p
1 g
F P
s
P
p
.002 w
.33709 .40131 m .34192 .4561 L .36014 .44845 L p
1 g
F P
s
P
p
.002 w
.36014 .44845 m .35589 .39917 L .33709 .40131 L p
1 g
F P
s
P
p
.002 w
.43525 .27876 m .39534 .30935 L .41201 .32022 L p
1 g
F P
s
P
p
.002 w
.41201 .32022 m .44656 .29384 L .43525 .27876 L p
1 g
F P
s
P
p
.002 w
.6549 .45541 m .66053 .40567 L .64123 .40348 L p
1 g
F P
s
P
p
.002 w
.63151 .36096 m .64123 .40348 L .66053 .40567 L p
1 g
F P
s
P
p
.002 w
.55767 .57705 m .60699 .55278 L .59846 .53534 L p
1 g
F P
s
P
p
.002 w
.63335 .50021 m .59846 .53534 L .60699 .55278 L p
1 g
F P
s
P
p
.002 w
.48341 .26286 m .43525 .27876 L .44656 .29384 L p
1 g
F P
s
P
p
.002 w
.44656 .29384 m .48818 .28017 L .48341 .26286 L p
1 g
F P
s
P
p
.002 w
.35042 .34775 m .33709 .40131 L .35589 .39917 L p
1 g
F P
s
P
p
.002 w
.35589 .39917 m .36797 .35106 L .35042 .34775 L p
1 g
F P
s
P
p
.002 w
.66053 .40567 m .64937 .35644 L .63151 .36096 L p
1 g
F P
s
P
p
.002 w
.60821 .32369 m .63151 .36096 L .64937 .35644 L p
1 g
F P
s
P
p
.002 w
.60699 .55278 m .64587 .51378 L .63335 .50021 L p
1 g
F P
s
P
p
.002 w
.6549 .45541 m .63335 .50021 L .64587 .51378 L p
1 g
F P
s
P
p
.002 w
.53447 .26363 m .48341 .26286 L .48818 .28017 L p
1 g
F P
s
P
p
.002 w
.48818 .28017 m .53227 .28086 L .53447 .26363 L p
1 g
F P
s
P
p
.002 w
.64937 .35644 m .62244 .31326 L .60821 .32369 L p
1 g
F P
s
P
p
.002 w
.57385 .29594 m .60821 .32369 L .62244 .31326 L p
1 g
F P
s
P
p
.002 w
.39115 .56128 m .44288 .59023 L .44917 .57388 L p
1 g
F P
s
P
p
.002 w
.44917 .57388 m .40118 .54701 L .39115 .56128 L p
1 g
F P
s
P
p
.002 w
.50318 .58427 m .44917 .57388 L .44288 .59023 L p
1 g
F P
s
P
p
.002 w
.35119 .51753 m .39115 .56128 L .40118 .54701 L p
1 g
F P
s
P
p
.002 w
.40118 .54701 m .36412 .50638 L .35119 .51753 L p
1 g
F P
s
P
p
.002 w
.58265 .28109 m .53447 .26363 L .53227 .28086 L p
1 g
F P
s
P
p
.002 w
.53227 .28086 m .57385 .29594 L .58265 .28109 L p
1 g
F P
s
P
p
.002 w
.62244 .31326 m .58265 .28109 L .57385 .29594 L p
1 g
F P
s
P
p
.002 w
.44288 .59023 m .50108 .60146 L .50318 .58427 L p
1 g
F P
s
P
p
.002 w
.55767 .57705 m .50318 .58427 L .50108 .60146 L p
1 g
F P
s
P
p
.002 w
.38081 .30126 m .35042 .34775 L .36797 .35106 L p
1 g
F P
s
P
p
.002 w
.36797 .35106 m .39534 .30935 L .38081 .30126 L p
1 g
F P
s
P
p
.002 w
.32719 .46336 m .35119 .51753 L .36412 .50638 L p
1 g
F P
s
P
p
.002 w
.36412 .50638 m .34192 .4561 L .32719 .46336 L p
1 g
F P
s
P
p
.002 w
.64587 .51378 m .66996 .46397 L .6549 .45541 L p
1 g
F P
s
P
p
.002 w
.66053 .40567 m .6549 .45541 L .66996 .46397 L p
1 g
F P
s
P
p
.002 w
.50108 .60146 m .55982 .59373 L .55767 .57705 L p
1 g
F P
s
P
p
.002 w
.60699 .55278 m .55767 .57705 L .55982 .59373 L p
1 g
F P
s
P
p
.002 w
.42522 .26711 m .38081 .30126 L .39534 .30935 L p
1 g
F P
s
P
p
.002 w
.39534 .30935 m .43525 .27876 L .42522 .26711 L p
1 g
F P
s
P
p
.002 w
.32188 .40429 m .32719 .46336 L .34192 .4561 L p
1 g
F P
s
P
p
.002 w
.34192 .4561 m .33709 .40131 L .32188 .40429 L p
1 g
F P
s
P
p
.002 w
.66996 .46397 m .67633 .40859 L .66053 .40567 L p
1 g
F P
s
P
p
.002 w
.64937 .35644 m .66053 .40567 L .67633 .40859 L p
1 g
F P
s
P
p
.002 w
.55982 .59373 m .61303 .56765 L .60699 .55278 L p
1 g
F P
s
P
p
.002 w
.64587 .51378 m .60699 .55278 L .61303 .56765 L p
1 g
F P
s
P
p
.002 w
.47889 .24933 m .42522 .26711 L .43525 .27876 L p
1 g
F P
s
P
p
.002 w
.43525 .27876 m .48341 .26286 L .47889 .24933 L p
1 g
F P
s
P
p
.002 w
.33617 .3465 m .32188 .40429 L .33709 .40131 L p
1 g
F P
s
P
p
.002 w
.33709 .40131 m .35042 .34775 L .33617 .3465 L p
1 g
F P
s
P
p
.002 w
.67633 .40859 m .66396 .35371 L .64937 .35644 L p
1 g
F P
s
P
p
.002 w
.62244 .31326 m .64937 .35644 L .66396 .35371 L p
1 g
F P
s
P
p
.002 w
.61303 .56765 m .65503 .52566 L .64587 .51378 L p
1 g
F P
s
P
p
.002 w
.66996 .46397 m .64587 .51378 L .65503 .52566 L p
1 g
F P
s
P
p
.002 w
.53585 .25015 m .47889 .24933 L .48341 .26286 L p
1 g
F P
s
P
p
.002 w
.48341 .26286 m .53447 .26363 L .53585 .25015 L p
1 g
F P
s
P
p
.002 w
.66396 .35371 m .63398 .30553 L .62244 .31326 L p
1 g
F P
s
P
p
.002 w
.58265 .28109 m .62244 .31326 L .63398 .30553 L p
1 g
F P
s
P
p
.002 w
.38362 .57264 m .43786 .60298 L .44288 .59023 L p
1 g
F P
s
P
p
.002 w
.44288 .59023 m .39115 .56128 L .38362 .57264 L p
1 g
F P
s
P
p
.002 w
.50108 .60146 m .44288 .59023 L .43786 .60298 L p
1 g
F P
s
P
p
.002 w
.34169 .5268 m .38362 .57264 L .39115 .56128 L p
1 g
F P
s
P
p
.002 w
.39115 .56128 m .35119 .51753 L .34169 .5268 L p
1 g
F P
s
P
p
.002 w
.5896 .26962 m .53585 .25015 L .53447 .26363 L p
1 g
F P
s
P
p
.002 w
.53447 .26363 m .58265 .28109 L .5896 .26962 L p
1 g
F P
s
P
p
.002 w
.63398 .30553 m .5896 .26962 L .58265 .28109 L p
1 g
F P
s
P
p
.002 w
.36889 .29629 m .33617 .3465 L .35042 .34775 L p
1 g
F P
s
P
p
.002 w
.35042 .34775 m .38081 .30126 L .36889 .29629 L p
1 g
F P
s
P
p
.002 w
.43786 .60298 m .49888 .61478 L .50108 .60146 L p
1 g
F P
s
P
p
.002 w
.55982 .59373 m .50108 .60146 L .49888 .61478 L p
1 g
F P
s
P
p
.002 w
.31647 .47003 m .34169 .5268 L .35119 .51753 L p
1 g
F P
s
P
p
.002 w
.35119 .51753 m .32719 .46336 L .31647 .47003 L p
1 g
F P
s
P
p
.002 w
.65503 .52566 m .68109 .47197 L .66996 .46397 L p
1 g
F P
s
P
p
.002 w
.67633 .40859 m .66996 .46397 L .68109 .47197 L p
1 g
F P
s
P
p
.002 w
.49888 .61478 m .56047 .60673 L .55982 .59373 L p
1 g
F P
s
P
p
.002 w
.61303 .56765 m .55982 .59373 L .56047 .60673 L p
1 g
F P
s
P
p
.002 w
.41679 .25936 m .36889 .29629 L .38081 .30126 L p
1 g
F P
s
P
p
.002 w
.38081 .30126 m .42522 .26711 L .41679 .25936 L p
1 g
F P
s
P
p
.002 w
.31084 .4081 m .31647 .47003 L .32719 .46336 L p
1 g
F P
s
P
p
.002 w
.32719 .46336 m .32188 .40429 L .31084 .4081 L p
1 g
F P
s
P
p
.002 w
.68109 .47197 m .68805 .41221 L .67633 .40859 L p
1 g
F P
s
P
p
.002 w
.66396 .35371 m .67633 .40859 L .68805 .41221 L p
1 g
F P
s
P
p
.002 w
.56047 .60673 m .61629 .57944 L .61303 .56765 L p
1 g
F P
s
P
p
.002 w
.65503 .52566 m .61303 .56765 L .61629 .57944 L p
1 g
F P
s
P
p
.002 w
.47476 .24011 m .41679 .25936 L .42522 .26711 L p
1 g
F P
s
P
p
.002 w
.42522 .26711 m .47889 .24933 L .47476 .24011 L p
1 g
F P
s
P
p
.002 w
.32575 .34748 m .31084 .4081 L .32188 .40429 L p
1 g
F P
s
P
p
.002 w
.32188 .40429 m .33617 .3465 L .32575 .34748 L p
1 g
F P
s
P
p
.002 w
.68805 .41221 m .67475 .35293 L .66396 .35371 L p
1 g
F P
s
P
p
.002 w
.63398 .30553 m .66396 .35371 L .67475 .35293 L p
1 g
F P
s
P
p
.002 w
.61629 .57944 m .66038 .53546 L .65503 .52566 L p
1 g
F P
s
P
p
.002 w
.68109 .47197 m .65503 .52566 L .66038 .53546 L p
1 g
F P
s
P
p
.002 w
.53632 .24097 m .47476 .24011 L .47889 .24933 L p
1 g
F P
s
P
p
.002 w
.47889 .24933 m .53585 .25015 L .53632 .24097 L p
1 g
F P
s
P
p
.002 w
.67475 .35293 m .64238 .30085 L .63398 .30553 L p
1 g
F P
s
P
p
.002 w
.5896 .26962 m .63398 .30553 L .64238 .30085 L p
1 g
F P
s
P
p
.002 w
.37892 .58064 m .43431 .61162 L .43786 .60298 L p
1 g
F P
s
P
p
.002 w
.43786 .60298 m .38362 .57264 L .37892 .58064 L p
1 g
F P
s
P
p
.002 w
.49888 .61478 m .43786 .60298 L .43431 .61162 L p
1 g
F P
s
P
p
.002 w
.33608 .53385 m .37892 .58064 L .38362 .57264 L p
1 g
F P
s
P
p
.002 w
.38362 .57264 m .34169 .5268 L .33608 .53385 L p
1 g
F P
s
P
p
.002 w
.59442 .26202 m .53632 .24097 L .53585 .25015 L p
1 g
F P
s
P
p
.002 w
.53585 .25015 m .5896 .26962 L .59442 .26202 L p
1 g
F P
s
P
p
.002 w
.36003 .29477 m .32575 .34748 L .33617 .3465 L p
1 g
F P
s
P
p
.002 w
.33617 .3465 m .36889 .29629 L .36003 .29477 L p
1 g
F P
s
P
p
.002 w
.64238 .30085 m .59442 .26202 L .5896 .26962 L p
1 g
F P
s
P
p
.002 w
.43431 .61162 m .49661 .62368 L .49888 .61478 L p
1 g
F P
s
P
p
.002 w
.56047 .60673 m .49888 .61478 L .49661 .62368 L p
1 g
F P
s
P
p
.002 w
.3103 .47591 m .33608 .53385 L .34169 .5268 L p
1 g
F P
s
P
p
.002 w
.34169 .5268 m .31647 .47003 L .3103 .47591 L p
1 g
F P
s
P
p
.002 w
.66038 .53546 m .68778 .47918 L .68109 .47197 L p
1 g
F P
s
P
p
.002 w
.68805 .41221 m .68109 .47197 L .68778 .47918 L p
1 g
F P
s
P
p
.002 w
.49661 .62368 m .55951 .6155 L .56047 .60673 L p
1 g
F P
s
P
p
.002 w
.61629 .57944 m .56047 .60673 L .55951 .6155 L p
1 g
F P
s
P
p
.002 w
.41028 .25597 m .36003 .29477 L .36889 .29629 L p
1 g
F P
s
P
p
.002 w
.36889 .29629 m .41679 .25936 L .41028 .25597 L p
1 g
F P
s
P
p
.002 w
.3045 .41268 m .3103 .47591 L .31647 .47003 L p
1 g
F P
s
P
p
.002 w
.31647 .47003 m .31084 .4081 L .3045 .41268 L p
1 g
F P
s
P
p
.002 w
.68778 .47918 m .69513 .41648 L .68805 .41221 L p
1 g
F P
s
P
p
.002 w
.67475 .35293 m .68805 .41221 L .69513 .41648 L p
1 g
F P
s
P
p
.002 w
.55951 .6155 m .61652 .58767 L .61629 .57944 L p
1 g
F P
s
P
p
.002 w
.66038 .53546 m .61629 .57944 L .61652 .58767 L p
1 g
F P
s
P
p
.002 w
.47114 .23573 m .41028 .25597 L .41679 .25936 L p
1 g
F P
s
P
p
.002 w
.41679 .25936 m .47476 .24011 L .47114 .23573 L p
1 g
F P
s
P
p
.002 w
.31969 .35078 m .3045 .41268 L .31084 .4081 L p
1 g
F P
s
P
p
.002 w
.31084 .4081 m .32575 .34748 L .31969 .35078 L p
1 g
F P
s
P
p
.002 w
.69513 .41648 m .68121 .35424 L .67475 .35293 L p
1 g
F P
s
P
p
.002 w
.64238 .30085 m .67475 .35293 L .68121 .35424 L p
1 g
F P
s
P
p
.002 w
.61652 .58767 m .66156 .54281 L .66038 .53546 L p
1 g
F P
s
P
p
.002 w
.68778 .47918 m .66038 .53546 L .66156 .54281 L p
1 g
F P
s
P
p
.002 w
.5358 .23663 m .47114 .23573 L .47476 .24011 L p
1 g
F P
s
P
p
.002 w
.47476 .24011 m .53632 .24097 L .5358 .23663 L p
1 g
F P
s
P
p
.002 w
.68121 .35424 m .64723 .29953 L .64238 .30085 L p
1 g
F P
s
P
p
.002 w
.59442 .26202 m .64238 .30085 L .64723 .29953 L p
1 g
F P
s
P
p
.002 w
.37735 .58485 m .43242 .61564 L .43431 .61162 L p
1 g
F P
s
P
p
.002 w
.43431 .61162 m .37892 .58064 L .37735 .58485 L p
1 g
F P
s
P
p
.002 w
.49661 .62368 m .43431 .61162 L .43242 .61564 L p
1 g
F P
s
P
p
.002 w
.33476 .53835 m .37735 .58485 L .37892 .58064 L p
1 g
F P
s
P
p
.002 w
.37892 .58064 m .33608 .53385 L .33476 .53835 L p
1 g
F P
s
P
p
.002 w
.59685 .25873 m .5358 .23663 L .53632 .24097 L p
1 g
F P
s
P
p
.002 w
.53632 .24097 m .59442 .26202 L .59685 .25873 L p
1 g
F P
s
P
p
.002 w
.35467 .29695 m .31969 .35078 L .32575 .34748 L p
1 g
F P
s
P
p
.002 w
.32575 .34748 m .36003 .29477 L .35467 .29695 L p
1 g
F P
s
P
p
.002 w
.64723 .29953 m .59685 .25873 L .59442 .26202 L p
1 g
F P
s
P
p
.002 w
.43242 .61564 m .49434 .62764 L .49661 .62368 L p
1 g
F P
s
P
p
.002 w
.55951 .6155 m .49661 .62368 L .49434 .62764 L p
1 g
F P
s
P
p
.002 w
.30913 .48077 m .33476 .53835 L .33608 .53385 L p
1 g
F P
s
P
p
.002 w
.33608 .53385 m .3103 .47591 L .30913 .48077 L p
1 g
F P
s
P
p
.002 w
.66156 .54281 m .68956 .48535 L .68778 .47918 L p
1 g
F P
s
P
p
.002 w
.69513 .41648 m .68778 .47918 L .68956 .48535 L p
1 g
F P
s
P
p
.002 w
.49434 .62764 m .55685 .61952 L .55951 .6155 L p
1 g
F P
s
P
p
.002 w
.61652 .58767 m .55951 .6155 L .55685 .61952 L p
1 g
F P
s
P
p
.002 w
.40599 .25732 m .35467 .29695 L .36003 .29477 L p
1 g
F P
s
P
p
.002 w
.36003 .29477 m .41028 .25597 L .40599 .25732 L p
1 g
F P
s
P
p
.002 w
.30336 .41796 m .30913 .48077 L .3103 .47591 L p
1 g
F P
s
P
p
.002 w
.3103 .47591 m .3045 .41268 L .30336 .41796 L p
1 g
F P
s
P
p
.002 w
.68956 .48535 m .69708 .42133 L .69513 .41648 L p
1 g
F P
s
P
p
.002 w
.68121 .35424 m .69513 .41648 L .69708 .42133 L p
1 g
F P
s
P
p
.002 w
.55685 .61952 m .61351 .59189 L .61652 .58767 L p
1 g
F P
s
P
p
.002 w
.66156 .54281 m .61652 .58767 L .61351 .59189 L p
1 g
F P
s
P
p
.004 w
.59158 .62595 m
.59934 .64251 L
s
P
p
.004 w
.59934 .64251 m
.61975 .68606 L
s
P
p
.002 w
.46817 .23664 m .40599 .25732 L .41028 .25597 L p
1 g
F P
s
P
p
.002 w
.41028 .25597 m .47114 .23573 L .46817 .23664 L p
1 g
F P
s
P
p
.002 w
.31845 .35648 m .30336 .41796 L .3045 .41268 L p
1 g
F P
s
P
p
.002 w
.3045 .41268 m .31969 .35078 L .31845 .35648 L p
1 g
F P
s
P
p
.002 w
.69708 .42133 m .68287 .35774 L .68121 .35424 L p
1 g
F P
s
P
p
.002 w
.64723 .29953 m .68121 .35424 L .68287 .35774 L p
1 g
F P
s
P
p
.002 w
.61351 .59189 m .65825 .54732 L .66156 .54281 L p
1 g
F P
s
P
p
.002 w
.68956 .48535 m .66156 .54281 L .65825 .54732 L p
1 g
F P
s
P
p
.002 w
.53425 .23755 m .46817 .23664 L .47114 .23573 L p
1 g
F P
s
P
p
.002 w
.47114 .23573 m .5358 .23663 L .53425 .23755 L p
1 g
F P
s
P
p
.002 w
.68287 .35774 m .64814 .30184 L .64723 .29953 L p
1 g
F P
s
P
p
.002 w
.59685 .25873 m .64723 .29953 L .64814 .30184 L p
1 g
F P
s
P
p
.002 w
.37917 .58489 m .43234 .61463 L .43242 .61564 L p
1 g
F P
s
P
p
.002 w
.43242 .61564 m .37735 .58485 L .37917 .58489 L p
1 g
F P
s
P
p
.002 w
.49434 .62764 m .43242 .61564 L .43234 .61463 L p
1 g
F P
s
P
p
.002 w
.33806 .54 m .37917 .58489 L .37735 .58485 L p
1 g
F P
s
P
p
.002 w
.37735 .58485 m .33476 .53835 L .33806 .54 L p
1 g
F P
s
P
p
.002 w
.3532 .30301 m .31845 .35648 L .31969 .35078 L p
1 g
F P
s
P
p
.002 w
.31969 .35078 m .35467 .29695 L .3532 .30301 L p
1 g
F P
s
P
p
.002 w
.59665 .26015 m .53425 .23755 L .5358 .23663 L p
1 g
F P
s
P
p
.002 w
.5358 .23663 m .59685 .25873 L .59665 .26015 L p
1 g
F P
s
P
p
.002 w
.64814 .30184 m .59665 .26015 L .59685 .25873 L p
1 g
F P
s
P
p
.002 w
.43234 .61463 m .49213 .62621 L .49434 .62764 L p
1 g
F P
s
P
p
.002 w
.55685 .61952 m .49434 .62764 L .49213 .62621 L p
1 g
F P
s
P
p
.002 w
.31333 .48443 m .33806 .54 L .33476 .53835 L p
1 g
F P
s
P
p
.002 w
.33476 .53835 m .30913 .48077 L .31333 .48443 L p
1 g
F P
s
P
p
.002 w
.65825 .54732 m .68606 .49025 L .68956 .48535 L p
1 g
F P
s
P
p
.002 w
.69708 .42133 m .68956 .48535 L .68606 .49025 L p
1 g
F P
s
P
p
.002 w
.49213 .62621 m .55247 .61836 L .55685 .61952 L p
1 g
F P
s
P
p
.002 w
.61351 .59189 m .55685 .61952 L .55247 .61836 L p
1 g
F P
s
P
p
.002 w
.40419 .26367 m .3532 .30301 L .35467 .29695 L p
1 g
F P
s
P
p
.002 w
.35467 .29695 m .40599 .25732 L .40419 .26367 L p
1 g
F P
s
P
p
.002 w
.30779 .42383 m .31333 .48443 L .30913 .48077 L p
1 g
F P
s
P
p
.002 w
.30913 .48077 m .30336 .41796 L .30779 .42383 L p
1 g
F P
s
P
p
.002 w
.68606 .49025 m .69351 .42665 L .69708 .42133 L p
1 g
F P
s
P
p
.002 w
.68287 .35774 m .69708 .42133 L .69351 .42665 L p
1 g
F P
s
P
p
.002 w
.55247 .61836 m .60713 .59169 L .61351 .59189 L p
1 g
F P
s
P
p
.002 w
.65825 .54732 m .61351 .59189 L .60713 .59169 L p
1 g
F P
s
P
p
.002 w
.46598 .24315 m .40419 .26367 L .40599 .25732 L p
1 g
F P
s
P
p
.002 w
.40599 .25732 m .46817 .23664 L .46598 .24315 L p
1 g
F P
s
P
p
.002 w
.32238 .36455 m .30779 .42383 L .30336 .41796 L p
1 g
F P
s
P
p
.002 w
.30336 .41796 m .31845 .35648 L .32238 .36455 L p
1 g
F P
s
P
p
.002 w
.69351 .42665 m .67936 .36349 L .68287 .35774 L p
1 g
F P
s
P
p
.002 w
.64814 .30184 m .68287 .35774 L .67936 .36349 L p
1 g
F P
s
P
p
.002 w
.60713 .59169 m .65027 .54868 L .65825 .54732 L p
1 g
F P
s
P
p
.002 w
.68606 .49025 m .65825 .54732 L .65027 .54868 L p
1 g
F P
s
P
p
.002 w
.53165 .24408 m .46598 .24315 L .46817 .23664 L p
1 g
F P
s
P
p
.002 w
.46817 .23664 m .53425 .23755 L .53165 .24408 L p
1 g
F P
s
P
p
.002 w
.67936 .36349 m .64484 .30796 L .64814 .30184 L p
1 g
F P
s
P
p
.002 w
.59665 .26015 m .64814 .30184 L .64484 .30796 L p
1 g
F P
s
P
p
.002 w
.38455 .5805 m .4342 .60827 L .43234 .61463 L p
1 g
F P
s
P
p
.002 w
.43234 .61463 m .37917 .58489 L .38455 .5805 L p
1 g
F P
s
P
p
.002 w
.49213 .62621 m .43234 .61463 L .4342 .60827 L p
1 g
F P
s
P
p
.002 w
.35593 .31304 m .32238 .36455 L .31845 .35648 L p
1 g
F P
s
P
p
.002 w
.31845 .35648 m .3532 .30301 L .35593 .31304 L p
1 g
F P
s
P
p
.002 w
.34617 .53856 m .38455 .5805 L .37917 .58489 L p
1 g
F P
s
P
p
.002 w
.37917 .58489 m .33806 .54 L .34617 .53856 L p
1 g
F P
s
P
p
.002 w
.59366 .26653 m .53165 .24408 L .53425 .23755 L p
1 g
F P
s
P
p
.002 w
.53425 .23755 m .59665 .26015 L .59366 .26653 L p
1 g
F P
s
P
p
.002 w
.64484 .30796 m .59366 .26653 L .59665 .26015 L p
1 g
F P
s
P
p
.002 w
.4342 .60827 m .49005 .61908 L .49213 .62621 L p
1 g
F P
s
P
p
.002 w
.55247 .61836 m .49213 .62621 L .49005 .61908 L p
1 g
F P
s
P
p
.002 w
.32312 .48668 m .34617 .53856 L .33806 .54 L p
1 g
F P
s
P
p
.002 w
.33806 .54 m .31333 .48443 L .32312 .48668 L p
1 g
F P
s
P
p
.002 w
.65027 .54868 m .67703 .49363 L .68606 .49025 L p
1 g
F P
s
P
p
.002 w
.69351 .42665 m .68606 .49025 L .67703 .49363 L p
1 g
F P
s
P
p
.002 w
.49005 .61908 m .54638 .61173 L .55247 .61836 L p
1 g
F P
s
P
p
.002 w
.60713 .59169 m .55247 .61836 L .54638 .61173 L p
1 g
F P
s
P
p
.004 w
.58545 .61286 m
.59158 .62595 L
s
P
p
.002 w
.40512 .27516 m .35593 .31304 L .3532 .30301 L p
1 g
F P
s
P
p
.002 w
.3532 .30301 m .40419 .26367 L .40512 .27516 L p
1 g
F P
s
P
p
.002 w
.31801 .43015 m .32312 .48668 L .31333 .48443 L p
1 g
F P
s
P
p
.002 w
.31333 .48443 m .30779 .42383 L .31801 .43015 L p
1 g
F P
s
P
p
.002 w
.67703 .49363 m .68416 .43231 L .69351 .42665 L p
1 g
F P
s
P
p
.002 w
.67936 .36349 m .69351 .42665 L .68416 .43231 L p
1 g
F P
s
P
p
.002 w
.54638 .61173 m .59736 .5868 L .60713 .59169 L p
1 g
F P
s
P
p
.002 w
.65027 .54868 m .60713 .59169 L .59736 .5868 L p
1 g
F P
s
P
p
.002 w
.4647 .25543 m .40512 .27516 L .40419 .26367 L p
1 g
F P
s
P
p
.002 w
.40419 .26367 m .46598 .24315 L .4647 .25543 L p
1 g
F P
s
P
p
.002 w
.33168 .3749 m .31801 .43015 L .30779 .42383 L p
1 g
F P
s
P
p
.002 w
.30779 .42383 m .32238 .36455 L .33168 .3749 L p
1 g
F P
s
P
p
.002 w
.68416 .43231 m .67046 .37145 L .67936 .36349 L p
1 g
F P
s
P
p
.002 w
.64484 .30796 m .67936 .36349 L .67046 .37145 L p
1 g
F P
s
P
p
.002 w
.59736 .5868 m .63754 .54664 L .65027 .54868 L p
1 g
F P
s
P
p
.002 w
.67703 .49363 m .65027 .54868 L .63754 .54664 L p
1 g
F P
s
P
p
.002 w
.52801 .25636 m .4647 .25543 L .46598 .24315 L p
1 g
F P
s
P
p
.002 w
.46598 .24315 m .53165 .24408 L .52801 .25636 L p
1 g
F P
s
P
p
.002 w
.67046 .37145 m .63714 .31794 L .64484 .30796 L p
1 g
F P
s
P
p
.002 w
.59366 .26653 m .64484 .30796 L .63714 .31794 L p
1 g
F P
s
P
p
.002 w
.39355 .57151 m .43808 .59643 L .4342 .60827 L p
1 g
F P
s
P
p
.002 w
.4342 .60827 m .38455 .5805 L .39355 .57151 L p
1 g
F P
s
P
p
.002 w
.49005 .61908 m .4342 .60827 L .43808 .59643 L p
1 g
F P
s
P
p
.002 w
.36302 .32695 m .33168 .3749 L .32238 .36455 L p
1 g
F P
s
P
p
.002 w
.32238 .36455 m .35593 .31304 L .36302 .32695 L p
1 g
F P
s
P
p
.002 w
.35916 .53388 m .39355 .57151 L .38455 .5805 L p
1 g
F P
s
P
p
.002 w
.38455 .5805 m .34617 .53856 L .35916 .53388 L p
1 g
F P
s
P
p
.002 w
.58779 .27802 m .52801 .25636 L .53165 .24408 L p
1 g
F P
s
P
p
.002 w
.53165 .24408 m .59366 .26653 L .58779 .27802 L p
1 g
F P
s
P
p
.002 w
.63714 .31794 m .58779 .27802 L .59366 .26653 L p
1 g
F P
s
P
p
.002 w
.43808 .59643 m .48817 .6061 L .49005 .61908 L p
1 g
F P
s
P
p
.002 w
.54638 .61173 m .49005 .61908 L .48817 .6061 L p
1 g
F P
s
P
p
.002 w
.33855 .48737 m .35916 .53388 L .34617 .53856 L p
1 g
F P
s
P
p
.002 w
.34617 .53856 m .32312 .48668 L .33855 .48737 L p
1 g
F P
s
P
p
.002 w
.63754 .54664 m .66242 .4953 L .67703 .49363 L p
1 g
F P
s
P
p
.002 w
.68416 .43231 m .67703 .49363 L .66242 .4953 L p
1 g
F P
s
P
p
.002 w
.48817 .6061 m .53867 .59947 L .54638 .61173 L p
1 g
F P
s
P
p
.002 w
.59736 .5868 m .54638 .61173 L .53867 .59947 L p
1 g
F P
s
P
p
.004 w
.57967 .60053 m
.58545 .61286 L
s
P
p
.002 w
.4089 .29173 m .36302 .32695 L .35593 .31304 L p
1 g
F P
s
P
p
.002 w
.35593 .31304 m .40512 .27516 L .4089 .29173 L p
1 g
F P
s
P
p
.002 w
.33405 .43674 m .33855 .48737 L .32312 .48668 L p
1 g
F P
s
P
p
.002 w
.32312 .48668 m .31801 .43015 L .33405 .43674 L p
1 g
F P
s
P
p
.002 w
.66242 .4953 m .66897 .43816 L .68416 .43231 L p
1 g
F P
s
P
p
.002 w
.67046 .37145 m .68416 .43231 L .66897 .43816 L p
1 g
F P
s
P
p
.002 w
.53867 .59947 m .58431 .57707 L .59736 .5868 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5716 .58331 L
s
P
p
.004 w
.57614 .59299 m
.57673 .59425 L
s
P
p
.004 w
.57673 .59425 m
.57967 .60053 L
s
P
p
.002 w
.63754 .54664 m .59736 .5868 L .58431 .57707 L p
1 g
F P
s
P
p
.002 w
.46442 .27343 m .4089 .29173 L .40512 .27516 L p
1 g
F P
s
P
p
.002 w
.40512 .27516 m .4647 .25543 L .46442 .27343 L p
1 g
F P
s
P
p
.002 w
.34639 .38732 m .33405 .43674 L .31801 .43015 L p
1 g
F P
s
P
p
.002 w
.31801 .43015 m .33168 .3749 L .34639 .38732 L p
1 g
F P
s
P
p
.002 w
.66897 .43816 m .65612 .38148 L .67046 .37145 L p
1 g
F P
s
P
p
.002 w
.63714 .31794 m .67046 .37145 L .65612 .38148 L p
1 g
F P
s
P
p
.002 w
.66242 .4953 m .63754 .54664 L .62022 .54106 L p
1 g
F P
s
P
p
.002 w
.58431 .57707 m .62022 .54106 L .63754 .54664 L p
1 g
F P
s
P
p
.002 w
.52338 .27435 m .46442 .27343 L .4647 .25543 L p
1 g
F P
s
P
p
.002 w
.4647 .25543 m .52801 .25636 L .52338 .27435 L p
1 g
F P
s
P
p
.002 w
.65612 .38148 m .62503 .33168 L .63714 .31794 L p
1 g
F P
s
P
p
.002 w
.58779 .27802 m .63714 .31794 L .62503 .33168 L p
1 g
F P
s
P
p
.002 w
.37451 .34451 m .34639 .38732 L .33168 .3749 L p
1 g
F P
s
P
p
.002 w
.33168 .3749 m .36302 .32695 L .37451 .34451 L p
1 g
F P
s
P
p
.002 w
.40609 .55794 m .44397 .57914 L .43808 .59643 L p
1 g
F P
s
P
p
.002 w
.43808 .59643 m .39355 .57151 L .40609 .55794 L p
1 g
F P
s
P
p
.002 w
.48817 .6061 m .43808 .59643 L .44397 .57914 L p
1 g
F P
s
P
p
.002 w
.37688 .52592 m .40609 .55794 L .39355 .57151 L p
1 g
F P
s
P
p
.002 w
.39355 .57151 m .35916 .53388 L .37688 .52592 L p
1 g
F P
s
P
p
.002 w
.57905 .29453 m .52338 .27435 L .52801 .25636 L p
1 g
F P
s
P
p
.002 w
.52801 .25636 m .58779 .27802 L .57905 .29453 L p
1 g
F P
s
P
p
.002 w
.44397 .57914 m .48657 .58734 L .48817 .6061 L p
1 g
F P
s
P
p
.002 w
.53867 .59947 m .48817 .6061 L .48657 .58734 L p
1 g
F P
s
P
p
.002 w
.62503 .33168 m .57905 .29453 L .58779 .27802 L p
1 g
F P
s
P
p
.002 w
.62022 .54106 m .64237 .49508 L .66242 .4953 L p
1 g
F P
s
P
p
.002 w
.66897 .43816 m .66242 .4953 L .64237 .49508 L p
1 g
F P
s
P
p
.002 w
.35943 .48637 m .37688 .52592 L .35916 .53388 L p
1 g
F P
s
P
p
.002 w
.35916 .53388 m .33855 .48737 L .35943 .48637 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.48657 .58734 m .52949 .58166 L .53867 .59947 L p
1 g
F P
s
P
p
.002 w
.58431 .57707 m .53867 .59947 L .52949 .58166 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.41558 .31312 m .37451 .34451 L .36302 .32695 L p
1 g
F P
s
P
p
.002 w
.36302 .32695 m .4089 .29173 L .41558 .31312 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.3557 .44337 m .35943 .48637 L .33855 .48737 L p
1 g
F P
s
P
p
.002 w
.33855 .48737 m .33405 .43674 L .3557 .44337 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.64237 .49508 m .64811 .44399 L .66897 .43816 L p
1 g
F P
s
P
p
.002 w
.65612 .38148 m .66897 .43816 L .64811 .44399 L p
1 g
F P
s
P
p
.002 w
.52949 .58166 m .56823 .56256 L .58431 .57707 L p
1 g
F P
s
P
p
.002 w
.62022 .54106 m .58431 .57707 L .56823 .56256 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.36628 .40149 m .3557 .44337 L .33405 .43674 L p
1 g
F P
s
P
p
.002 w
.33405 .43674 m .34639 .38732 L .36628 .40149 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46521 .29685 m .41558 .31312 L .4089 .29173 L p
1 g
F P
s
P
p
.002 w
.4089 .29173 m .46442 .27343 L .46521 .29685 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.64811 .44399 m .63653 .39336 L .65612 .38148 L p
1 g
F P
s
P
p
.002 w
.62503 .33168 m .65612 .38148 L .63653 .39336 L p
1 g
F P
s
P
p
.002 w
.64237 .49508 m .62022 .54106 L .59863 .53193 L p
1 g
F P
s
P
p
.002 w
.56823 .56256 m .59863 .53193 L .62022 .54106 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.51788 .29773 m .46521 .29685 L .46442 .27343 L p
1 g
F P
s
P
p
.002 w
.46442 .27343 m .52338 .27435 L .51788 .29773 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.39021 .36527 m .36628 .40149 L .34639 .38732 L p
1 g
F P
s
P
p
.002 w
.34639 .38732 m .37451 .34451 L .39021 .36527 L p
1 g
F P
s
P
p
.002 w
.63653 .39336 m .60869 .34892 L .62503 .33168 L p
1 g
F P
s
P
p
.002 w
.57905 .29453 m .62503 .33168 L .60869 .34892 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.42194 .54 m .43919 .54967 L p
.44397 .57914 L 1 g
F P
s
P
p
.002 w
.43919 .54967 m .44069 .55051 L p
.44116 .55455 L 1 g
F P
s
P
p
.44397 .57914 m .43919 .54967 L .44116 .55455 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43842 .54723 L p
1 g
F P
s
P
p
.002 w
.44069 .55051 m .43919 .54967 L p
.43925 .54843 L 1 g
F P
s
P
p
.002 w
.42194 .54 m .4323 .52793 L p
.43254 .52868 L 1 g
F P
s
P
p
.002 w
.43919 .54967 m .43189 .54557 L p
.43254 .52868 L 1 g
F P
s
P
p
.002 w
.43189 .54557 m .42194 .54 L p
.43254 .52868 L 1 g
F P
s
P
p
.002 w
.43254 .52868 m .43346 .52734 L p
.43316 .51866 L 1 g
F P
s
P
p
.002 w
.43258 .5276 m .42194 .54 L p
.43369 .51047 L 1 g
F P
s
P
p
.43316 .51866 m .43305 .51548 L .43258 .5276 L 1 g
F
P
p
.43316 .51866 m .43258 .5276 L .43254 .52868 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43379 .50952 L p
1 g
F P
s
P
p
.002 w
.43369 .51047 m .43346 .51021 L p
.43376 .50982 L 1 g
F P
s
P
p
.002 w
.42482 .5007 m .44318 .49011 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.43346 .51021 m .42861 .50487 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.42861 .50487 m .42482 .5007 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45182 .48242 L 1 g
F P
s
P
p
.002 w
.45255 .48171 m .45359 .48412 L .44488 .48914 L p
1 g
F P
s
P
p
.45182 .48242 m .45246 .48181 L .44488 .48914 L 1 g
F
P
p
.45182 .48242 m .44488 .48914 L .44258 .49136 L 1 g
F
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43346 .52734 m .43379 .50952 L .43307 .51615 L 1 g
F
P
p
.43485 .50826 m .43826 .50029 L .43747 .50192 L 1 g
F
P
p
.002 w
.43375 .50957 m .43485 .50826 L p
.44003 .49573 L 1 g
F P
s
P
p
.43346 .51021 m .44258 .49136 L .45359 .48412 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45761 .47679 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.45255 .48171 m .45761 .47679 L .48162 .46671 L 1 g
F
P
p
.45255 .48171 m .48162 .46671 L .48224 .46663 L 1 g
F
P
p
.002 w
.48413 .50125 m .47225 .49899 L .48397 .4664 L p
1 g
F P
s
P
p
.002 w
.50677 .49422 m .49607 .4996 L .48451 .46633 L p
1 g
F P
s
P
p
.002 w
.52012 .47485 m .51509 .48566 L .4852 .46622 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47786 .46667 L p
.49055 .46538 L 1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49313 .46497 m .50263 .46429 L p
.4861 .46608 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .4673 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52012 .47485 m .52088 .46709 L p
.52252 .4673 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54232 .47672 L p
1 g
F P
s
P
p
.52214 .46667 m .54232 .47672 L .53277 .47217 L 1 g
F
P
p
.52986 .47079 m .52012 .47485 L .52252 .4673 L 1 g
F
P
p
.002 w
.52252 .4673 m .52214 .46667 L p
.53277 .47217 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .566 .50927 L p
1 g
F P
s
P
p
.5879 .48872 m .56996 .51753 L .566 .50927 L 1 g
F
P
p
.56469 .49692 m .566 .50927 L .56075 .49831 L 1 g
F
P
p
.5879 .48872 m .566 .50927 L .56469 .49692 L 1 g
F
P
p
.002 w
.566 .50927 m .56515 .50826 L p
.567 .52026 L 1 g
F P
s
P
p
.002 w
.57334 .5194 m .56737 .52546 L p
.56695 .51956 L 1 g
F P
s
P
p
.567 .52026 m .56668 .51572 L .566 .50927 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52865 L p
1 g
F P
s
P
p
.56767 .53925 m .56744 .52865 L .57334 .5194 L 1 g
F
P
p
.002 w
.56737 .52546 m .56902 .52378 L p
.56744 .52865 L 1 g
F P
s
P
p
.002 w
.56902 .52378 m .57334 .5194 L p
.56744 .52865 L 1 g
F P
s
P
p
.002 w
.56744 .52865 m .56654 .52734 L p
.56484 .53665 L 1 g
F P
s
P
p
.56515 .50826 m .56744 .52865 L .56733 .52384 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56147 .54701 L p
1 g
F P
s
P
p
.56654 .52734 m .56147 .54701 L .56484 .53665 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.54953 .54354 m .56737 .52546 L p
.56744 .52865 L 1 g
F P
s
P
p
.56767 .53925 m .56369 .54019 L .56744 .52865 L 1 g
F
P
p
.56369 .54019 m .54953 .54354 L .56744 .52865 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.59863 .53193 m .56823 .56256 L .55799 .55214 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54902 .56257 L p
1 g
F P
s
P
p
.002 w
.56823 .56256 m .53489 .579 L p
.54902 .56257 L 1 g
F P
s
P
p
.55104 .56118 m .54902 .56257 L .55026 .56112 L 1 g
F
P
p
.56823 .56256 m .54902 .56257 L .55104 .56118 L 1 g
F
P
p
.002 w
.54902 .56257 m .54854 .56129 L p
.54249 .56706 L 1 g
F P
s
P
p
.56075 .54566 m .54902 .56257 L .55456 .55613 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53168 .57449 L p
1 g
F P
s
P
p
.5483 .56307 m .54008 .57119 L .53816 .57004 L 1 g
F
P
p
.002 w
.52949 .58166 m .52707 .57629 L p
.54008 .57119 L 1 g
F P
s
P
p
.54854 .56129 m .53168 .57449 L .54249 .56706 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58017 L p
1 g
F P
s
P
p
.52949 .58166 m .48651 .58602 L .51091 .58017 L 1 g
F
P
p
.52525 .57988 m .51091 .58017 L .52047 .57788 L 1 g
F
P
p
.52949 .58166 m .51091 .58017 L .52525 .57988 L 1 g
F
P
p
.002 w
.51091 .58017 m .51079 .57862 L p
.50218 .58034 L 1 g
F P
s
P
p
.53128 .57265 m .51091 .58017 L .5208 .5778 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .5806 L p
1 g
F P
s
P
p
.51091 .58017 m .5 .58278 L .49824 .58042 L 1 g
F
P
p
.002 w
.48651 .58602 m .4862 .58003 L p
.5 .58278 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .5806 L .50218 .58034 L 1 g
F
P
p
.002 w
.48906 .5806 m .48921 .57862 L p
.47978 .57785 L 1 g
F P
s
P
p
.48657 .58734 m .44817 .56706 L .46843 .57397 L 1 g
F
P
p
.47814 .57992 m .46843 .57397 L .47325 .57562 L 1 g
F
P
p
.48657 .58734 m .46843 .57397 L .47814 .57992 L 1 g
F
P
p
.002 w
.46843 .57397 m .46872 .57265 L p
.46168 .56984 L 1 g
F P
s
P
p
.002 w
.44986 .56221 m .44397 .57914 L p
.44069 .55051 L 1 g
F P
s
P
p
.45146 .56129 m .43842 .54723 L .44319 .5541 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46843 .57397 L p
1 g
F P
s
P
p
.002 w
.4862 .58003 m .48657 .58734 L p
.47325 .57562 L 1 g
F P
s
P
p
.002 w
.46843 .57397 m .4678 .57686 L p
.47978 .57785 L 1 g
F P
s
P
p
.48921 .57862 m .46843 .57397 L .47978 .57785 L 1 g
F
P
p
.47978 .57785 m .4862 .58003 L .48906 .5806 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45177 .55671 m .48533 .56315 L .4862 .58003 L p
1 g
F P
s
P
p
.47325 .57562 m .45177 .55671 L .4862 .58003 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56315 L p
1 g
F P
s
P
p
.46843 .57397 m .45762 .57028 L .4559 .5663 L 1 g
F
P
p
.002 w
.44817 .56706 m .44986 .56221 L p
.45762 .57028 L 1 g
F P
s
P
p
.46872 .57265 m .45077 .56315 L .46168 .56984 L 1 g
F
P
p
.002 w
.45071 .5633 m .45146 .56129 L p
.4442 .55498 L 1 g
F P
s
P
p
.002 w
.44986 .56221 m .45177 .55671 L p
.45762 .57028 L 1 g
F P
s
P
p
.002 w
.45077 .56315 m .45002 .56518 L p
.46168 .56984 L 1 g
F P
s
P
p
.47325 .57562 m .46843 .57397 L .45177 .55671 L 1 g
F
P
p
.46843 .57397 m .4559 .5663 L .45177 .55671 L 1 g
F
P
p
.002 w
.45002 .56518 m .45071 .5633 L p
.44348 .55557 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .43814 .55001 L p
.44348 .55557 L 1 g
F P
s
P
p
.002 w
.43814 .55001 m .45002 .56518 L p
.44348 .55557 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46843 .57397 L p
1 g
F P
s
P
p
.46168 .56984 m .45002 .56518 L .46843 .57397 L 1 g
F
P
p
.47978 .57785 m .47197 .5772 L .4862 .58003 L 1 g
F
P
p
.002 w
.48657 .58734 m .44397 .57914 L .44817 .56706 L p
1 g
F P
s
P
p
.002 w
.4862 .58003 m .48533 .56315 L p
.5 .58278 L 1 g
F P
s
P
p
.002 w
.48906 .5806 m .48889 .583 L p
.50218 .58034 L 1 g
F P
s
P
p
.52047 .57788 m .51091 .58017 L .48533 .56315 L 1 g
F
P
p
.51091 .58017 m .49824 .58042 L .48533 .56315 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .5806 L p
1 g
F P
s
P
p
.47197 .5772 m .4678 .57686 L .48906 .5806 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58017 L p
1 g
F P
s
P
p
.50218 .58034 m .48889 .583 L .51091 .58017 L 1 g
F
P
p
.53128 .57265 m .5208 .5778 L .52164 .5776 L 1 g
F
P
p
.002 w
.52707 .57629 m .52949 .58166 L p
.52047 .57788 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.48533 .56315 m .5191 .55863 L .52707 .57629 L p
1 g
F P
s
P
p
.52047 .57788 m .48533 .56315 L .52707 .57629 L 1 g
F
P
p
.52164 .5776 m .51108 .58257 L .51474 .58113 L 1 g
F
P
p
.5208 .5778 m .51108 .58257 L .52164 .5776 L 1 g
F
P
p
.002 w
.51091 .58017 m .51108 .58257 L p
.5208 .5778 L 1 g
F P
s
P
p
.002 w
.52949 .58166 m .48657 .58734 L .48651 .58602 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52707 .57629 m .5191 .55863 L p
.54008 .57119 L 1 g
F P
s
P
p
.002 w
.53168 .57449 m .5322 .57686 L p
.54249 .56706 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.55026 .56112 m .5483 .56307 L .5191 .55863 L 1 g
F
P
p
.5483 .56307 m .53816 .57004 L .5191 .55863 L 1 g
F
P
p
.002 w
.51108 .58257 m .51111 .583 L p
.51474 .58113 L 1 g
F P
s
P
p
.002 w
.53489 .579 m .52949 .58166 L p
.55026 .56112 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54902 .56257 L p
1 g
F P
s
P
p
.54249 .56706 m .5322 .57686 L .54902 .56257 L 1 g
F
P
p
.56075 .54566 m .55456 .55613 L .55572 .55478 L 1 g
F
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55799 .55214 m .56823 .56256 L p
.55026 .56112 L 1 g
F P
s
P
p
.59863 .53193 m .55799 .55214 L .56656 .53951 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.5191 .55863 m .54953 .54354 L .55799 .55214 L p
1 g
F P
s
P
p
.55026 .56112 m .5191 .55863 L .55799 .55214 L 1 g
F
P
p
.55572 .55478 m .54969 .56437 L .55365 .55853 L 1 g
F
P
p
.55456 .55613 m .54969 .56437 L .55572 .55478 L 1 g
F
P
p
.002 w
.54902 .56257 m .54969 .56437 L p
.55456 .55613 L 1 g
F P
s
P
p
.002 w
.55799 .55214 m .54953 .54354 L p
.56656 .53951 L 1 g
F P
s
P
p
.002 w
.54969 .56437 m .54998 .56518 L p
.55365 .55853 L 1 g
F P
s
P
p
.002 w
.56147 .54701 m .56257 .5491 L p
.56484 .53665 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56744 .52865 L p
1 g
F P
s
P
p
.56484 .53665 m .56257 .5491 L .56744 .52865 L 1 g
F
P
p
.002 w
.56744 .52865 m .56815 .52969 L p
.56733 .52384 L 1 g
F P
s
P
p
.002 w
.57334 .5194 m .59863 .53193 L p
.56767 .53925 L 1 g
F P
s
P
p
.56515 .50826 m .56815 .52969 L .5675 .52352 L 1 g
F
P
p
.55661 .4905 m .566 .50927 L .56135 .49956 L 1 g
F
P
p
.002 w
.55511 .48265 m .5879 .48872 L p
.56075 .49831 L 1 g
F P
s
P
p
.002 w
.55741 .49136 m .55661 .4905 L p
.56135 .49956 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49136 L p
1 g
F P
s
P
p
.56075 .49831 m .55741 .49136 L .55868 .49258 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55741 .49136 L p
1 g
F P
s
P
p
.56135 .49956 m .56713 .51061 L .55741 .49136 L 1 g
F
P
p
.54174 .47608 m .55741 .49136 L .55388 .48795 L 1 g
F
P
p
.002 w
.54517 .50381 m .55301 .48711 L p
.56075 .49831 L 1 g
F P
s
P
p
.54174 .47608 m .55388 .48795 L .55301 .48711 L 1 g
F
P
p
.002 w
.55301 .48711 m .54517 .50381 L p
.5489 .48311 L 1 g
F P
s
P
p
.55156 .4857 m .55301 .48711 L .55221 .48634 L 1 g
F
P
p
.54174 .47608 m .55301 .48711 L .55156 .4857 L 1 g
F
P
p
.002 w
.54517 .50381 m .51509 .48566 L p
.5489 .48311 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.56075 .49831 m .55301 .48711 L .55741 .49136 L 1 g
F
P
p
.002 w
.54643 .48071 m .52012 .47485 L p
.53432 .46893 L 1 g
F P
s
P
p
.002 w
.51509 .48566 m .52012 .47485 L .54643 .48071 L p
1 g
F P
s
P
p
.5489 .48311 m .51509 .48566 L .54643 .48071 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54238 .47678 L p
1 g
F P
s
P
p
.002 w
.54238 .47678 m .54174 .47608 L p
.55156 .4857 L 1 g
F P
s
P
p
.55156 .4857 m .55834 .49233 L .54238 .47678 L 1 g
F
P
p
.002 w
.54643 .48071 m .55511 .48265 L p
.5489 .48311 L 1 g
F P
s
P
p
.002 w
.55511 .48265 m .55301 .48711 L p
.5489 .48311 L 1 g
F P
s
P
p
.002 w
.55301 .48711 m .55418 .48462 L p
.55741 .49136 L 1 g
F P
s
P
p
.55221 .48634 m .55794 .49191 L .55286 .48697 L 1 g
F
P
p
.55388 .48795 m .55794 .49191 L .55221 .48634 L 1 g
F
P
p
.002 w
.55741 .49136 m .55794 .49191 L p
.55388 .48795 L 1 g
F P
s
P
p
.002 w
.55418 .48462 m .55511 .48265 L p
.55868 .49258 L 1 g
F P
s
P
p
.55741 .49136 m .55418 .48462 L .55868 .49258 L 1 g
F
P
p
.56075 .49831 m .566 .50927 L .54517 .50381 L 1 g
F
P
p
.002 w
.56996 .51753 m .56668 .51572 L p
.566 .50927 L 1 g
F P
s
P
p
.002 w
.56668 .51572 m .54517 .50381 L p
.566 .50927 L 1 g
F P
s
P
p
.002 w
.56815 .52969 m .56854 .53025 L p
.5675 .52352 L 1 g
F P
s
P
p
.002 w
.52881 .52051 m .54517 .50381 L .56668 .51572 L p
1 g
F P
s
P
p
.002 w
.56668 .51572 m .57334 .5194 L p
.56695 .51956 L 1 g
F P
s
P
p
.56695 .51956 m .52881 .52051 L .56668 .51572 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56624 .50956 L p
1 g
F P
s
P
p
.002 w
.56624 .50956 m .566 .50927 L p
.56654 .51372 L 1 g
F P
s
P
p
.56654 .51372 m .56854 .53025 L .56624 .50956 L 1 g
F
P
p
.567 .52026 m .5675 .52352 L .56668 .51572 L 1 g
F
P
p
.002 w
.54953 .54354 m .52881 .52051 L p
.56695 .51956 L 1 g
F P
s
P
p
.002 w
.56737 .52546 m .54953 .54354 L p
.56695 .51956 L 1 g
F P
s
P
p
.5675 .52352 m .56854 .53025 L .566 .50927 L 1 g
F
P
p
.002 w
.566 .50927 m .56713 .51061 L p
.56135 .49956 L 1 g
F P
s
P
p
.002 w
.5879 .48872 m .57334 .5194 L .56996 .51753 L p
1 g
F P
s
P
p
.002 w
.5575 .45928 m .55511 .48265 L .54643 .48071 L p
1 g
F P
s
P
p
.5575 .45928 m .54643 .48071 L .53432 .46893 L 1 g
F
P
p
.002 w
.55794 .49191 m .55834 .49233 L p
.55286 .48697 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52252 .4673 L p
1 g
F P
s
P
p
.53277 .47217 m .54302 .47747 L .52252 .4673 L 1 g
F
P
p
.53464 .4688 m .52252 .4673 L .52129 .46294 L 1 g
F
P
p
.5 .4634 m .52252 .4673 L .52158 .46718 L 1 g
F
P
p
.5 .4634 m .52255 .46735 L .51254 .46581 L 1 g
F
P
p
.002 w
.52088 .46709 m .52093 .46654 L p
.52252 .4673 L 1 g
F P
s
P
p
.002 w
.52093 .46654 m .52129 .46294 L p
.52252 .4673 L 1 g
F P
s
P
p
.53464 .4688 m .52986 .47079 L .52252 .4673 L 1 g
F
P
p
.002 w
.54232 .47672 m .54302 .47747 L p
.53277 .47217 L 1 g
F P
s
P
p
.002 w
.52252 .4673 m .52255 .46735 L p
.52158 .46718 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.52129 .46294 m .5575 .45928 L p
.53464 .4688 L 1 g
F P
s
P
p
.50395 .46449 m .4861 .46608 L .50263 .46429 L 1 g
F
P
p
.002 w
.52012 .47485 m .4861 .46608 L p
.50395 .46449 L 1 g
F P
s
P
p
.002 w
.52088 .46709 m .52012 .47485 L p
.50395 .46449 L 1 g
F P
s
P
p
.5 .4634 m .51254 .46581 L .50263 .46429 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51847 .45124 m .52129 .46294 L .50263 .46429 L p
1 g
F P
s
P
p
.002 w
.50263 .46429 m .49313 .46497 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.4861 .46608 m .52012 .47485 L p
.4852 .46622 L 1 g
F P
s
P
p
.002 w
.51509 .48566 m .50677 .49422 L .48479 .46629 L p
1 g
F P
s
P
p
.002 w
.4852 .46622 m .51509 .48566 L p
.48479 .46629 L 1 g
F P
s
P
p
.002 w
.48479 .46629 m .50677 .49422 L p
.48451 .46633 L 1 g
F P
s
P
p
.002 w
.49607 .4996 m .48413 .50125 L .48425 .46637 L p
1 g
F P
s
P
p
.002 w
.48451 .46633 m .49607 .4996 L p
.48425 .46637 L 1 g
F P
s
P
p
.002 w
.48425 .46637 m .48413 .50125 L p
.48397 .4664 L 1 g
F P
s
P
p
.002 w
.47225 .49899 m .46169 .49307 L .48356 .46646 L p
1 g
F P
s
P
p
.002 w
.48397 .4664 m .47225 .49899 L p
.48356 .46646 L 1 g
F P
s
P
p
.49055 .46538 m .49013 .46545 L .47751 .46725 L 1 g
F
P
p
.49071 .46536 m .48975 .46551 L .47751 .46725 L 1 g
F
P
p
.49106 .46533 m .48939 .46558 L .47751 .46725 L 1 g
F
P
p
.49162 .46527 m .48892 .46567 L .47751 .46725 L 1 g
F
P
p
.49242 .46519 m .48821 .46579 L .47751 .46725 L 1 g
F
P
p
.49346 .46508 m .48707 .46597 L .47751 .46725 L 1 g
F
P
p
.49467 .46496 m .48356 .46646 L .47751 .46725 L 1 g
F
P
p
.002 w
.48356 .46646 m .46169 .49307 L p
.48265 .46658 L 1 g
F P
s
P
p
.48356 .46646 m .48322 .46651 L .48265 .46658 L 1 g
F
P
p
.48356 .46646 m .48265 .46658 L .47751 .46725 L 1 g
F
P
p
.002 w
.46169 .49307 m .45359 .48412 L .48265 .46658 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49057 .46538 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .49057 .46538 L 1 g
F
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.4915 .46257 m .51847 .45124 L p
.50386 .46327 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.50263 .46429 L 1 g
F P
s
P
p
.50386 .46327 m .50263 .46429 L .5 .46388 L 1 g
F
P
p
.50386 .46327 m .5 .46388 L .4915 .46257 L 1 g
F
P
p
.002 w
.48265 .46658 m .48426 .46561 L .48356 .46646 L p
1 g
F P
s
P
p
.002 w
.47831 .46687 m .48426 .46561 L p
.48162 .46671 L 1 g
F P
s
P
p
.45761 .47679 m .47751 .46725 L .48162 .46671 L 1 g
F
P
p
.47751 .46725 m .47831 .46687 L .48162 .46671 L 1 g
F
P
p
.002 w
.48426 .46561 m .45359 .48412 L .45255 .48171 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47738 .46747 L p
1 g
F P
s
P
p
.002 w
.47738 .46747 m .47751 .46725 L p
.48366 .46647 L 1 g
F P
s
P
p
.48366 .46647 m .5 .46442 L .47738 .46747 L 1 g
F
P
p
.002 w
.48426 .46561 m .4915 .46257 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.49313 .46497 m .48426 .46561 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46388 L p
.50263 .46429 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.51254 .46581 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.002 w
.52129 .46294 m .52088 .46709 L p
.50395 .46449 L 1 g
F P
s
P
p
.002 w
.50263 .46429 m .52129 .46294 L p
.50395 .46449 L 1 g
F P
s
P
p
.002 w
.52255 .46735 m .52282 .46778 L p
.51254 .46581 L 1 g
F P
s
P
p
.49055 .46538 m .49071 .46536 L .49013 .46545 L 1 g
F
P
p
.002 w
.4861 .46608 m .48426 .46561 L .49313 .46497 L p
1 g
F P
s
P
p
.002 w
.4852 .46622 m .48426 .46561 L .4861 .46608 L p
1 g
F P
s
P
p
.49071 .46536 m .49106 .46533 L .48975 .46551 L 1 g
F
P
p
.49106 .46533 m .49162 .46527 L .48939 .46558 L 1 g
F
P
p
.002 w
.48479 .46629 m .48426 .46561 L .4852 .46622 L p
1 g
F P
s
P
p
.002 w
.48451 .46633 m .48426 .46561 L .48479 .46629 L p
1 g
F P
s
P
p
.49162 .46527 m .49242 .46519 L .48892 .46567 L 1 g
F
P
p
.49242 .46519 m .49346 .46508 L .48821 .46579 L 1 g
F
P
p
.002 w
.48425 .46637 m .48426 .46561 L .48451 .46633 L p
1 g
F P
s
P
p
.002 w
.48397 .4664 m .48426 .46561 L .48425 .46637 L p
1 g
F P
s
P
p
.49346 .46508 m .49467 .46496 L .48707 .46597 L 1 g
F
P
p
.49467 .46496 m .49682 .46474 L .48322 .46651 L 1 g
F
P
p
.002 w
.48356 .46646 m .48426 .46561 L .48397 .4664 L p
1 g
F P
s
P
p
.49682 .46474 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.48224 .46663 m .48162 .46671 L .48426 .46561 L 1 g
F
P
p
.002 w
.45761 .47679 m .45826 .47608 L p
.46799 .47181 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46725 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47718 .46778 L p
.46799 .47181 L 1 g
F P
s
P
p
.45826 .47608 m .47751 .46725 L .46799 .47181 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44882 .47309 m .46489 .4697 L p
.45761 .47679 L 1 g
F P
s
P
p
.44339 .4905 m .45761 .47679 L .45417 .48014 L 1 g
F
P
p
.44339 .4905 m .45728 .47715 L .45246 .48181 L 1 g
F
P
p
.002 w
.45255 .48171 m .45166 .47965 L p
.45761 .47679 L 1 g
F P
s
P
p
.002 w
.45166 .47965 m .44882 .47309 L p
.45761 .47679 L 1 g
F P
s
P
p
.002 w
.46489 .4697 m .47831 .46687 L p
.45761 .47679 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45761 .47679 L p
1 g
F P
s
P
p
.46799 .47181 m .47718 .46778 L .45761 .47679 L 1 g
F
P
p
.002 w
.45761 .47679 m .45728 .47715 L p
.45417 .48014 L 1 g
F P
s
P
p
.002 w
.44318 .49011 m .44488 .48914 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44488 .48914 m .45359 .48412 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.45728 .47715 m .45698 .47747 L p
.45246 .48181 L 1 g
F P
s
P
p
.002 w
.44882 .47309 m .45255 .48171 L p
.42482 .5007 L 1 g
F P
s
P
p
.002 w
.44488 .48914 m .42482 .5007 L p
.45255 .48171 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44258 .49136 L p
1 g
F P
s
P
p
.45246 .48181 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.42194 .54 m .42233 .53473 L .43369 .51047 L 1 g
F
P
p
.002 w
.42482 .5007 m .43346 .51021 L p
.42233 .53473 L 1 g
F P
s
P
p
.002 w
.43346 .51021 m .43369 .51047 L p
.42233 .53473 L 1 g
F P
s
P
p
.002 w
.43379 .50952 m .43287 .51061 L p
.43307 .51615 L 1 g
F P
s
P
p
.002 w
.44067 .51816 m .43369 .51047 L p
.45359 .48412 L 1 g
F P
s
P
p
.43369 .51047 m .43376 .50982 L .45359 .48412 L 1 g
F
P
p
.002 w
.44166 .49233 m .44003 .49573 L p
.43747 .50192 L 1 g
F P
s
P
p
.43826 .50029 m .44166 .49233 L .43747 .50192 L 1 g
F
P
p
.002 w
.44003 .49573 m .43287 .51061 L .43375 .50957 L p
1 g
F P
s
P
p
.002 w
.43369 .51047 m .44067 .51816 L .43258 .5276 L p
1 g
F P
s
P
p
.43925 .54566 m .43568 .5386 L .43582 .53905 L 1 g
F
P
p
.002 w
.4383 .54745 m .43925 .54566 L p
.43177 .53122 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.4323 .52793 m .44067 .51816 L p
.43919 .54967 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43254 .52868 L p
1 g
F P
s
P
p
.43305 .51548 m .43287 .51061 L .43254 .52868 L 1 g
F
P
p
.002 w
.43842 .54723 m .43743 .5491 L p
.44319 .5541 L 1 g
F P
s
P
p
.002 w
.45177 .55671 m .44069 .55051 L p
.44067 .51816 L 1 g
F P
s
P
p
.44069 .55051 m .43925 .54843 L .44067 .51816 L 1 g
F
P
p
.002 w
.43146 .53025 m .43177 .53122 L p
.43582 .53905 L 1 g
F P
s
P
p
.43568 .5386 m .43146 .53025 L .43582 .53905 L 1 g
F
P
p
.002 w
.43177 .53122 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.4442 .55498 m .43743 .5491 L .45071 .5633 L 1 g
F
P
p
.002 w
.44069 .55051 m .45177 .55671 L .44986 .56221 L p
1 g
F P
s
P
p
.002 w
.44397 .57914 m .40609 .55794 L .42194 .54 L p
1 g
F P
s
P
p
.002 w
.39897 .51477 m .42194 .54 L .40609 .55794 L p
1 g
F P
s
P
p
.002 w
.40609 .55794 m .37688 .52592 L .39897 .51477 L p
1 g
F P
s
P
p
.002 w
.5676 .31576 m .51788 .29773 L .52338 .27435 L p
1 g
F P
s
P
p
.002 w
.52338 .27435 m .57905 .29453 L .5676 .31576 L p
1 g
F P
s
P
p
.002 w
.60869 .34892 m .5676 .31576 L .57905 .29453 L p
1 g
F P
s
P
p
.002 w
.59863 .53193 m .6173 .4929 L .64237 .49508 L p
1 g
F P
s
P
p
.002 w
.64811 .44399 m .64237 .49508 L .6173 .4929 L p
1 g
F P
s
P
p
.002 w
.3853 .48362 m .39897 .51477 L .37688 .52592 L p
1 g
F P
s
P
p
.002 w
.37688 .52592 m .35943 .48637 L .3853 .48362 L p
1 g
F P
s
P
p
.002 w
.42506 .33878 m .39021 .36527 L .37451 .34451 L p
1 g
F P
s
P
p
.002 w
.37451 .34451 m .41558 .31312 L .42506 .33878 L p
1 g
F P
s
P
p
.002 w
.38246 .44982 m .3853 .48362 L .35943 .48637 L p
1 g
F P
s
P
p
.002 w
.35943 .48637 m .3557 .44337 L .38246 .44982 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.6173 .4929 m .62205 .4496 L .64811 .44399 L p
1 g
F P
s
P
p
.002 w
.63653 .39336 m .64811 .44399 L .62205 .4496 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39087 .41697 m .38246 .44982 L .3557 .44337 L p
1 g
F P
s
P
p
.002 w
.3557 .44337 m .36628 .40149 L .39087 .41697 L p
1 g
F P
s
P
p
.002 w
.4671 .3251 m .42506 .33878 L .41558 .31312 L p
1 g
F P
s
P
p
.002 w
.41558 .31312 m .46521 .29685 L .4671 .3251 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.62205 .4496 m .61214 .40676 L .63653 .39336 L p
1 g
F P
s
P
p
.002 w
.60869 .34892 m .63653 .39336 L .61214 .40676 L p
1 g
F P
s
P
p
.002 w
.6173 .4929 m .59863 .53193 L .57334 .5194 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.51166 .3259 m .4671 .3251 L .46521 .29685 L p
1 g
F P
s
P
p
.002 w
.46521 .29685 m .51788 .29773 L .51166 .3259 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40973 .38862 m .39087 .41697 L .36628 .40149 L p
1 g
F P
s
P
p
.002 w
.36628 .40149 m .39021 .36527 L .40973 .38862 L p
1 g
F P
s
P
p
.002 w
.61214 .40676 m .58851 .36919 L .60869 .34892 L p
1 g
F P
s
P
p
.002 w
.5676 .31576 m .60869 .34892 L .58851 .36919 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.44067 .51816 m .46129 .52972 L .45177 .55671 L p
1 g
F P
s
P
p
.002 w
.48533 .56315 m .45177 .55671 L .46129 .52972 L p
1 g
F P
s
P
p
.002 w
.42194 .54 m .39897 .51477 L .42482 .5007 L p
1 g
F P
s
P
p
.002 w
.55372 .34117 m .51166 .3259 L .51788 .29773 L p
1 g
F P
s
P
p
.002 w
.51788 .29773 m .5676 .31576 L .55372 .34117 L p
1 g
F P
s
P
p
.002 w
.46129 .52972 m .4845 .53415 L .48533 .56315 L p
1 g
F P
s
P
p
.002 w
.5191 .55863 m .48533 .56315 L .4845 .53415 L p
1 g
F P
s
P
p
.002 w
.58851 .36919 m .55372 .34117 L .5676 .31576 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.57334 .5194 m .5879 .48872 L .6173 .4929 L p
1 g
F P
s
P
p
.002 w
.62205 .4496 m .6173 .4929 L .5879 .48872 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.41543 .47916 m .42482 .5007 L .39897 .51477 L p
1 g
F P
s
P
p
.002 w
.39897 .51477 m .3853 .48362 L .41543 .47916 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4845 .53415 m .50783 .53098 L .5191 .55863 L p
1 g
F P
s
P
p
.002 w
.54953 .54354 m .5191 .55863 L .50783 .53098 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.43711 .36795 m .40973 .38862 L .39021 .36527 L p
1 g
F P
s
P
p
.002 w
.39021 .36527 m .42506 .33878 L .43711 .36795 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41355 .45584 m .41543 .47916 L .3853 .48362 L p
1 g
F P
s
P
p
.002 w
.3853 .48362 m .38246 .44982 L .41355 .45584 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5879 .48872 m .5915 .45477 L .62205 .4496 L p
1 g
F P
s
P
p
.002 w
.61214 .40676 m .62205 .4496 L .5915 .45477 L p
1 g
F P
s
P
p
.002 w
.50783 .53098 m .52881 .52051 L .54953 .54354 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.41942 .43322 m .41355 .45584 L .38246 .44982 L p
1 g
F P
s
P
p
.002 w
.38246 .44982 m .39087 .41697 L .41942 .43322 L p
1 g
F P
s
P
p
.002 w
.47005 .35732 m .43711 .36795 L .42506 .33878 L p
1 g
F P
s
P
p
.002 w
.42506 .33878 m .4671 .3251 L .47005 .35732 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.5915 .45477 m .58365 .42123 L .61214 .40676 L p
1 g
F P
s
P
p
.002 w
.58851 .36919 m .61214 .40676 L .58365 .42123 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.50493 .358 m .47005 .35732 L .4671 .3251 L p
1 g
F P
s
P
p
.002 w
.4671 .3251 m .51166 .3259 L .50493 .358 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43248 .41376 m .41942 .43322 L .39087 .41697 L p
1 g
F P
s
P
p
.002 w
.39087 .41697 m .40973 .38862 L .43248 .41376 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.58365 .42123 m .56509 .39186 L .58851 .36919 L p
1 g
F P
s
P
p
.002 w
.55372 .34117 m .58851 .36919 L .56509 .39186 L p
1 g
F P
s
P
p
.002 w
.46169 .49307 m .47225 .49899 L .46129 .52972 L p
1 g
F P
s
P
p
.002 w
.46129 .52972 m .44067 .51816 L .46169 .49307 L p
1 g
F P
s
P
p
.002 w
.4845 .53415 m .46129 .52972 L .47225 .49899 L p
1 g
F P
s
P
p
.002 w
.45359 .48412 m .46169 .49307 L .44067 .51816 L p
1 g
F P
s
P
p
.002 w
.5915 .45477 m .5879 .48872 L .55511 .48265 L p
1 g
F P
s
P
p
.002 w
.53784 .36995 m .50493 .358 L .51166 .3259 L p
1 g
F P
s
P
p
.002 w
.51166 .3259 m .55372 .34117 L .53784 .36995 L p
1 g
F P
s
P
p
.002 w
.47225 .49899 m .48413 .50125 L .4845 .53415 L p
1 g
F P
s
P
p
.002 w
.50783 .53098 m .4845 .53415 L .48413 .50125 L p
1 g
F P
s
P
p
.002 w
.56509 .39186 m .53784 .36995 L .55372 .34117 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42482 .5007 m .41543 .47916 L .44882 .47309 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.48413 .50125 m .49607 .4996 L .50783 .53098 L p
1 g
F P
s
P
p
.002 w
.52881 .52051 m .50783 .53098 L .49607 .4996 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.45135 .39962 m .43248 .41376 L .40973 .38862 L p
1 g
F P
s
P
p
.002 w
.40973 .38862 m .43711 .36795 L .45135 .39962 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4479 .46118 m .44882 .47309 L .41543 .47916 L p
1 g
F P
s
P
p
.002 w
.41543 .47916 m .41355 .45584 L .4479 .46118 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.55511 .48265 m .5575 .45928 L .5915 .45477 L p
1 g
F P
s
P
p
.002 w
.58365 .42123 m .5915 .45477 L .5575 .45928 L p
1 g
F P
s
P
p
.002 w
.49607 .4996 m .50677 .49422 L .52881 .52051 L p
1 g
F P
s
P
p
.002 w
.54517 .50381 m .52881 .52051 L .50677 .49422 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45094 .44965 m .4479 .46118 L .41355 .45584 L p
1 g
F P
s
P
p
.002 w
.41355 .45584 m .41942 .43322 L .45094 .44965 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.474 .39238 m .45135 .39962 L .43711 .36795 L p
1 g
F P
s
P
p
.002 w
.43711 .36795 m .47005 .35732 L .474 .39238 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.50677 .49422 m .51509 .48566 L .54517 .50381 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5575 .45928 m .55203 .43625 L .58365 .42123 L p
1 g
F P
s
P
p
.002 w
.56509 .39186 m .58365 .42123 L .55203 .43625 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45764 .43976 m .45094 .44965 L .41942 .43322 L p
1 g
F P
s
P
p
.002 w
.41942 .43322 m .43248 .41376 L .45764 .43976 L p
1 g
F P
s
P
p
.002 w
.49794 .39288 m .474 .39238 L .47005 .35732 L p
1 g
F P
s
P
p
.002 w
.47005 .35732 m .50493 .358 L .49794 .39288 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.55203 .43625 m .53924 .41611 L .56509 .39186 L p
1 g
F P
s
P
p
.002 w
.53784 .36995 m .56509 .39186 L .53924 .41611 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52052 .40109 m .49794 .39288 L .50493 .358 L p
1 g
F P
s
P
p
.002 w
.50493 .358 m .53784 .36995 L .52052 .40109 L p
1 g
F P
s
P
p
.002 w
.53924 .41611 m .52052 .40109 L .53784 .36995 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.46727 .4326 m .45764 .43976 L .43248 .41376 L p
1 g
F P
s
P
p
.002 w
.43248 .41376 m .45135 .39962 L .46727 .4326 L p
1 g
F P
s
P
p
.002 w
.44882 .47309 m .4479 .46118 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.55203 .43625 m .5575 .45928 L .52129 .46294 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.4479 .46118 m .45094 .44965 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.47879 .42895 m .46727 .4326 L .45135 .39962 L p
1 g
F P
s
P
p
.002 w
.45135 .39962 m .474 .39238 L .47879 .42895 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45094 .44965 m .45764 .43976 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.52129 .46294 m .51847 .45124 L .55203 .43625 L p
1 g
F P
s
P
p
.002 w
.53924 .41611 m .55203 .43625 L .51847 .45124 L p
1 g
F P
s
P
p
.002 w
.49096 .42922 m .47879 .42895 L .474 .39238 L p
1 g
F P
s
P
p
.002 w
.474 .39238 m .49794 .39288 L .49096 .42922 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.45764 .43976 m .46727 .4326 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.51847 .45124 m .51194 .44102 L .53924 .41611 L p
1 g
F P
s
P
p
.002 w
.52052 .40109 m .53924 .41611 L .51194 .44102 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51194 .44102 m .51847 .45124 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.50243 .4334 m .51194 .44102 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.49096 .42922 m .50243 .4334 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.004 w
.49923 .43224 m
.5 .43051 L
s
P
p
.002 w
.47879 .42895 m .49096 .42922 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.46727 .4326 m .47879 .42895 L .48426 .46561 L closepath p
1 g
F P
s
P
p
.002 w
.50243 .4334 m .49096 .42922 L .49794 .39288 L p
1 g
F P
s
P
p
.002 w
.49794 .39288 m .52052 .40109 L .50243 .4334 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51194 .44102 m .50243 .4334 L .52052 .40109 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.47449 .48739 m
.48426 .46561 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .61975 .68606 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .47449 .48739 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.23876)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.23876)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50497 .42105 m .49773 .42699 L .51204 .45168 L p
1 g
F P
s
P
p
.002 w
.49475 .45826 m .51204 .45168 L .49773 .42699 L p
1 g
F P
s
P
p
.002 w
.49773 .42699 m .48897 .43031 L .49475 .45826 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .49773 .42699 L .50497 .42105 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .48897 .43031 L .49773 .42699 L closepath p
1 g
F P
s
P
p
.002 w
.51204 .45168 m .52634 .43995 L .50497 .42105 L p
1 g
F P
s
P
p
.002 w
.50991 .41311 m .50497 .42105 L .52634 .43995 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .50497 .42105 L .50991 .41311 L closepath p
1 g
F P
s
P
p
.002 w
.47629 .45897 m .49475 .45826 L .48897 .43031 L p
1 g
F P
s
P
p
.002 w
.48897 .43031 m .47963 .43066 L .47629 .45897 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .47963 .43066 L .48897 .43031 L closepath p
1 g
F P
s
P
p
.002 w
.52634 .43995 m .53613 .42429 L .50991 .41311 L p
1 g
F P
s
P
p
.002 w
.51202 .40404 m .50991 .41311 L .53613 .42429 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .50991 .41311 L .51202 .40404 L closepath p
1 g
F P
s
P
p
.002 w
.45865 .45371 m .47629 .45897 L .47963 .43066 L p
1 g
F P
s
P
p
.002 w
.47963 .43066 m .47072 .42798 L .45865 .45371 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .47072 .42798 L .47963 .43066 L closepath p
1 g
F P
s
P
p
.002 w
.52634 .43995 m .51204 .45168 L .52614 .476 L p
1 g
F P
s
P
p
.002 w
.50068 .48569 m .52614 .476 L .51204 .45168 L p
1 g
F P
s
P
p
.002 w
.51204 .45168 m .49475 .45826 L .50068 .48569 L p
1 g
F P
s
P
p
.002 w
.52614 .476 m .5472 .45873 L .52634 .43995 L p
1 g
F P
s
P
p
.002 w
.53613 .42429 m .52634 .43995 L .5472 .45873 L p
1 g
F P
s
P
p
.002 w
.47351 .48678 m .50068 .48569 L .49475 .45826 L p
1 g
F P
s
P
p
.002 w
.49475 .45826 m .47629 .45897 L .47351 .48678 L p
1 g
F P
s
P
p
.002 w
.53613 .42429 m .54035 .40637 L .51202 .40404 L p
1 g
F P
s
P
p
.002 w
.51106 .39481 m .51202 .40404 L .54035 .40637 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .51202 .40404 L .51106 .39481 L closepath p
1 g
F P
s
P
p
.002 w
.44371 .44303 m .45865 .45371 L .47072 .42798 L p
1 g
F P
s
P
p
.002 w
.47072 .42798 m .46318 .42255 L .44371 .44303 L p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .46318 .42255 L .47072 .42798 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .51106 .39481 L .50713 .38641 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .50713 .38641 L .50065 .37976 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .50065 .37976 L .4923 .37559 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .4923 .37559 L .483 .37436 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .483 .37436 L .47377 .3762 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .47377 .3762 L .4656 .38094 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .4656 .38094 L .4594 .38803 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .4594 .38803 L .45584 .39671 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .45584 .39671 L .45531 .40603 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .45531 .40603 L .45785 .41497 L closepath p
1 g
F P
s
P
p
.002 w
.48346 .40236 m .45785 .41497 L .46318 .42255 L closepath p
1 g
F P
s
P
p
.002 w
.5472 .45873 m .56166 .4357 L .53613 .42429 L p
1 g
F P
s
P
p
.002 w
.54035 .40637 m .53613 .42429 L .56166 .4357 L p
1 g
F P
s
P
p
.002 w
.44749 .4791 m .47351 .48678 L .47629 .45897 L p
1 g
F P
s
P
p
.002 w
.47629 .45897 m .45865 .45371 L .44749 .4791 L p
1 g
F P
s
P
p
.002 w
.54035 .40637 m .53852 .38809 L .51106 .39481 L p
1 g
F P
s
P
p
.002 w
.50713 .38641 m .51106 .39481 L .53852 .38809 L p
1 g
F P
s
P
p
.002 w
.43309 .42803 m .44371 .44303 L .46318 .42255 L p
1 g
F P
s
P
p
.002 w
.46318 .42255 m .45785 .41497 L .43309 .42803 L p
1 g
F P
s
P
p
.002 w
.53852 .38809 m .53079 .37142 L .50713 .38641 L p
1 g
F P
s
P
p
.002 w
.50065 .37976 m .50713 .38641 L .53079 .37142 L p
1 g
F P
s
P
p
.002 w
.42799 .41033 m .43309 .42803 L .45785 .41497 L p
1 g
F P
s
P
p
.002 w
.45785 .41497 m .45531 .40603 L .42799 .41033 L p
1 g
F P
s
P
p
.002 w
.56166 .4357 m .56794 .4093 L .54035 .40637 L p
1 g
F P
s
P
p
.002 w
.53852 .38809 m .54035 .40637 L .56794 .4093 L p
1 g
F P
s
P
p
.002 w
.4254 .46342 m .44749 .4791 L .45865 .45371 L p
1 g
F P
s
P
p
.002 w
.45865 .45371 m .44371 .44303 L .4254 .46342 L p
1 g
F P
s
P
p
.002 w
.53079 .37142 m .51798 .35819 L .50065 .37976 L p
1 g
F P
s
P
p
.002 w
.4923 .37559 m .50065 .37976 L .51798 .35819 L p
1 g
F P
s
P
p
.002 w
.429 .39183 m .42799 .41033 L .45531 .40603 L p
1 g
F P
s
P
p
.002 w
.45531 .40603 m .45584 .39671 L .429 .39183 L p
1 g
F P
s
P
p
.002 w
.5472 .45873 m .52614 .476 L .53976 .49948 L p
1 g
F P
s
P
p
.002 w
.50667 .51211 m .53976 .49948 L .52614 .476 L p
1 g
F P
s
P
p
.002 w
.52614 .476 m .50068 .48569 L .50667 .51211 L p
1 g
F P
s
P
p
.002 w
.53976 .49948 m .56716 .47705 L .5472 .45873 L p
1 g
F P
s
P
p
.002 w
.56166 .4357 m .5472 .45873 L .56716 .47705 L p
1 g
F P
s
P
p
.002 w
.47134 .51358 m .50667 .51211 L .50068 .48569 L p
1 g
F P
s
P
p
.002 w
.50068 .48569 m .47351 .48678 L .47134 .51358 L p
1 g
F P
s
P
p
.002 w
.51798 .35819 m .50143 .34986 L .4923 .37559 L p
1 g
F P
s
P
p
.002 w
.483 .37436 m .4923 .37559 L .50143 .34986 L p
1 g
F P
s
P
p
.002 w
.43603 .37456 m .429 .39183 L .45584 .39671 L p
1 g
F P
s
P
p
.002 w
.45584 .39671 m .4594 .38803 L .43603 .37456 L p
1 g
F P
s
P
p
.002 w
.56794 .4093 m .56532 .38234 L .53852 .38809 L p
1 g
F P
s
P
p
.002 w
.53079 .37142 m .53852 .38809 L .56532 .38234 L p
1 g
F P
s
P
p
.002 w
.40965 .44134 m .4254 .46342 L .44371 .44303 L p
1 g
F P
s
P
p
.002 w
.44371 .44303 m .43309 .42803 L .40965 .44134 L p
1 g
F P
s
P
p
.002 w
.50143 .34986 m .48296 .34737 L .483 .37436 L p
1 g
F P
s
P
p
.002 w
.47377 .3762 m .483 .37436 L .48296 .34737 L p
1 g
F P
s
P
p
.002 w
.44834 .36044 m .43603 .37456 L .4594 .38803 L p
1 g
F P
s
P
p
.002 w
.4594 .38803 m .4656 .38094 L .44834 .36044 L p
1 g
F P
s
P
p
.002 w
.48296 .34737 m .46458 .35103 L .47377 .3762 L p
1 g
F P
s
P
p
.002 w
.4656 .38094 m .47377 .3762 L .46458 .35103 L p
1 g
F P
s
P
p
.002 w
.46458 .35103 m .44834 .36044 L .4656 .38094 L p
1 g
F P
s
P
p
.002 w
.56716 .47705 m .58601 .44712 L .56166 .4357 L p
1 g
F P
s
P
p
.002 w
.56794 .4093 m .56166 .4357 L .58601 .44712 L p
1 g
F P
s
P
p
.002 w
.43745 .50368 m .47134 .51358 L .47351 .48678 L p
1 g
F P
s
P
p
.002 w
.47351 .48678 m .44749 .4791 L .43745 .50368 L p
1 g
F P
s
P
p
.002 w
.56532 .38234 m .55401 .35769 L .53079 .37142 L p
1 g
F P
s
P
p
.002 w
.51798 .35819 m .53079 .37142 L .55401 .35769 L p
1 g
F P
s
P
p
.002 w
.40203 .41519 m .40965 .44134 L .43309 .42803 L p
1 g
F P
s
P
p
.002 w
.43309 .42803 m .42799 .41033 L .40203 .41519 L p
1 g
F P
s
P
p
.002 w
.58601 .44712 m .59427 .4128 L .56794 .4093 L p
1 g
F P
s
P
p
.002 w
.56532 .38234 m .56794 .4093 L .59427 .4128 L p
1 g
F P
s
P
p
.002 w
.40863 .48334 m .43745 .50368 L .44749 .4791 L p
1 g
F P
s
P
p
.002 w
.44749 .4791 m .4254 .46342 L .40863 .48334 L p
1 g
F P
s
P
p
.002 w
.55401 .35769 m .53513 .33807 L .51798 .35819 L p
1 g
F P
s
P
p
.002 w
.50143 .34986 m .51798 .35819 L .53513 .33807 L p
1 g
F P
s
P
p
.002 w
.40344 .38781 m .40203 .41519 L .42799 .41033 L p
1 g
F P
s
P
p
.002 w
.42799 .41033 m .429 .39183 L .40344 .38781 L p
1 g
F P
s
P
p
.002 w
.51261 .53699 m .55264 .52169 L .53976 .49948 L p
1 g
F P
s
P
p
.002 w
.53976 .49948 m .50667 .51211 L .51261 .53699 L p
1 g
F P
s
P
p
.002 w
.56716 .47705 m .53976 .49948 L .55264 .52169 L p
1 g
F P
s
P
p
.002 w
.53513 .33807 m .51068 .32568 L .50143 .34986 L p
1 g
F P
s
P
p
.002 w
.48296 .34737 m .50143 .34986 L .51068 .32568 L p
1 g
F P
s
P
p
.002 w
.4138 .36222 m .40344 .38781 L .429 .39183 L p
1 g
F P
s
P
p
.002 w
.429 .39183 m .43603 .37456 L .4138 .36222 L p
1 g
F P
s
P
p
.002 w
.59427 .4128 m .59097 .37767 L .56532 .38234 L p
1 g
F P
s
P
p
.002 w
.55401 .35769 m .56532 .38234 L .59097 .37767 L p
1 g
F P
s
P
p
.002 w
.38801 .45462 m .40863 .48334 L .4254 .46342 L p
1 g
F P
s
P
p
.002 w
.4254 .46342 m .40965 .44134 L .38801 .45462 L p
1 g
F P
s
P
p
.002 w
.55264 .52169 m .58582 .49455 L .56716 .47705 L p
1 g
F P
s
P
p
.002 w
.58601 .44712 m .56716 .47705 L .58582 .49455 L p
1 g
F P
s
P
p
.002 w
.46983 .53883 m .51261 .53699 L .50667 .51211 L p
1 g
F P
s
P
p
.002 w
.50667 .51211 m .47134 .51358 L .46983 .53883 L p
1 g
F P
s
P
p
.002 w
.51068 .32568 m .48333 .32194 L .48296 .34737 L p
1 g
F P
s
P
p
.002 w
.46458 .35103 m .48296 .34737 L .48333 .32194 L p
1 g
F P
s
P
p
.002 w
.43203 .34127 m .4138 .36222 L .43603 .37456 L p
1 g
F P
s
P
p
.002 w
.43603 .37456 m .44834 .36044 L .43203 .34127 L p
1 g
F P
s
P
p
.002 w
.48333 .32194 m .4561 .32733 L .46458 .35103 L p
1 g
F P
s
P
p
.002 w
.44834 .36044 m .46458 .35103 L .4561 .32733 L p
1 g
F P
s
P
p
.002 w
.4561 .32733 m .43203 .34127 L .44834 .36044 L p
1 g
F P
s
P
p
.002 w
.58582 .49455 m .60869 .45836 L .58601 .44712 L p
1 g
F P
s
P
p
.002 w
.59427 .4128 m .58601 .44712 L .60869 .45836 L p
1 g
F P
s
P
p
.002 w
.42877 .52694 m .46983 .53883 L .47134 .51358 L p
1 g
F P
s
P
p
.002 w
.47134 .51358 m .43745 .50368 L .42877 .52694 L p
1 g
F P
s
P
p
.002 w
.59097 .37767 m .57632 .34551 L .55401 .35769 L p
1 g
F P
s
P
p
.002 w
.53513 .33807 m .55401 .35769 L .57632 .34551 L p
1 g
F P
s
P
p
.002 w
.37795 .42054 m .38801 .45462 L .40965 .44134 L p
1 g
F P
s
P
p
.002 w
.40965 .44134 m .40203 .41519 L .37795 .42054 L p
1 g
F P
s
P
p
.002 w
.60869 .45836 m .61879 .41681 L .59427 .4128 L p
1 g
F P
s
P
p
.002 w
.59097 .37767 m .59427 .4128 L .61879 .41681 L p
1 g
F P
s
P
p
.002 w
.39376 .50238 m .42877 .52694 L .43745 .50368 L p
1 g
F P
s
P
p
.002 w
.43745 .50368 m .40863 .48334 L .39376 .50238 L p
1 g
F P
s
P
p
.002 w
.57632 .34551 m .55176 .31983 L .53513 .33807 L p
1 g
F P
s
P
p
.002 w
.51068 .32568 m .53513 .33807 L .55176 .31983 L p
1 g
F P
s
P
p
.002 w
.3797 .38477 m .37795 .42054 L .40203 .41519 L p
1 g
F P
s
P
p
.002 w
.40203 .41519 m .40344 .38781 L .3797 .38477 L p
1 g
F P
s
P
p
.002 w
.61879 .41681 m .61491 .37423 L .59097 .37767 L p
1 g
F P
s
P
p
.002 w
.57632 .34551 m .59097 .37767 L .61491 .37423 L p
1 g
F P
s
P
p
.002 w
.58582 .49455 m .55264 .52169 L .56452 .54214 L p
1 g
F P
s
P
p
.002 w
.51837 .5598 m .56452 .54214 L .55264 .52169 L p
1 g
F P
s
P
p
.002 w
.55264 .52169 m .51261 .53699 L .51837 .5598 L p
1 g
F P
s
P
p
.002 w
.55176 .31983 m .51988 .30356 L .51068 .32568 L p
1 g
F P
s
P
p
.002 w
.48333 .32194 m .51068 .32568 L .51988 .30356 L p
1 g
F P
s
P
p
.002 w
.36864 .46763 m .39376 .50238 L .40863 .48334 L p
1 g
F P
s
P
p
.002 w
.40863 .48334 m .38801 .45462 L .36864 .46763 L p
1 g
F P
s
P
p
.002 w
.3932 .35129 m .3797 .38477 L .40344 .38781 L p
1 g
F P
s
P
p
.002 w
.40344 .38781 m .4138 .36222 L .3932 .35129 L p
1 g
F P
s
P
p
.002 w
.56452 .54214 m .60278 .51087 L .58582 .49455 L p
1 g
F P
s
P
p
.002 w
.60869 .45836 m .58582 .49455 L .60278 .51087 L p
1 g
F P
s
P
p
.002 w
.46905 .562 m .51837 .5598 L .51261 .53699 L p
1 g
F P
s
P
p
.002 w
.51261 .53699 m .46983 .53883 L .46905 .562 L p
1 g
F P
s
P
p
.002 w
.51988 .30356 m .48413 .29861 L .48333 .32194 L p
1 g
F P
s
P
p
.002 w
.4561 .32733 m .48333 .32194 L .48413 .29861 L p
1 g
F P
s
P
p
.002 w
.41701 .32387 m .3932 .35129 L .4138 .36222 L p
1 g
F P
s
P
p
.002 w
.4138 .36222 m .43203 .34127 L .41701 .32387 L p
1 g
F P
s
P
p
.002 w
.48413 .29861 m .4485 .30562 L .4561 .32733 L p
1 g
F P
s
P
p
.002 w
.43203 .34127 m .4561 .32733 L .4485 .30562 L p
1 g
F P
s
P
p
.002 w
.4485 .30562 m .41701 .32387 L .43203 .34127 L p
1 g
F P
s
P
p
.002 w
.60278 .51087 m .62921 .46917 L .60869 .45836 L p
1 g
F P
s
P
p
.002 w
.61879 .41681 m .60869 .45836 L .62921 .46917 L p
1 g
F P
s
P
p
.002 w
.42165 .54837 m .46905 .562 L .46983 .53883 L p
1 g
F P
s
P
p
.002 w
.46983 .53883 m .42877 .52694 L .42165 .54837 L p
1 g
F P
s
P
p
.002 w
.61491 .37423 m .59726 .33516 L .57632 .34551 L p
1 g
F P
s
P
p
.002 w
.55176 .31983 m .57632 .34551 L .59726 .33516 L p
1 g
F P
s
P
p
.002 w
.35632 .42628 m .36864 .46763 L .38801 .45462 L p
1 g
F P
s
P
p
.002 w
.38801 .45462 m .37795 .42054 L .35632 .42628 L p
1 g
F P
s
P
p
.002 w
.62921 .46917 m .64096 .42127 L .61879 .41681 L p
1 g
F P
s
P
p
.002 w
.61491 .37423 m .61879 .41681 L .64096 .42127 L p
1 g
F P
s
P
p
.002 w
.38117 .52014 m .42165 .54837 L .42877 .52694 L p
1 g
F P
s
P
p
.002 w
.42877 .52694 m .39376 .50238 L .38117 .52014 L p
1 g
F P
s
P
p
.002 w
.59726 .33516 m .56753 .3039 L .55176 .31983 L p
1 g
F P
s
P
p
.002 w
.51988 .30356 m .55176 .31983 L .56753 .3039 L p
1 g
F P
s
P
p
.002 w
.35835 .38281 m .35632 .42628 L .37795 .42054 L p
1 g
F P
s
P
p
.002 w
.37795 .42054 m .3797 .38477 L .35835 .38281 L p
1 g
F P
s
P
p
.002 w
.64096 .42127 m .63661 .37211 L .61491 .37423 L p
1 g
F P
s
P
p
.002 w
.59726 .33516 m .61491 .37423 L .63661 .37211 L p
1 g
F P
s
P
p
.002 w
.35206 .48007 m .38117 .52014 L .39376 .50238 L p
1 g
F P
s
P
p
.002 w
.39376 .50238 m .36864 .46763 L .35206 .48007 L p
1 g
F P
s
P
p
.002 w
.56753 .3039 m .52883 .28404 L .51988 .30356 L p
1 g
F P
s
P
p
.002 w
.48413 .29861 m .51988 .30356 L .52883 .28404 L p
1 g
F P
s
P
p
.002 w
.37469 .34205 m .35835 .38281 L .3797 .38477 L p
1 g
F P
s
P
p
.002 w
.3797 .38477 m .3932 .35129 L .37469 .34205 L p
1 g
F P
s
P
p
.002 w
.60278 .51087 m .56452 .54214 L .5751 .56034 L p
1 g
F P
s
P
p
.002 w
.52383 .57999 m .5751 .56034 L .56452 .54214 L p
1 g
F P
s
P
p
.002 w
.56452 .54214 m .51837 .5598 L .52383 .57999 L p
1 g
F P
s
P
p
.002 w
.5751 .56034 m .61763 .52562 L .60278 .51087 L p
1 g
F P
s
P
p
.002 w
.62921 .46917 m .60278 .51087 L .61763 .52562 L p
1 g
F P
s
P
p
.002 w
.46903 .5825 m .52383 .57999 L .51837 .5598 L p
1 g
F P
s
P
p
.002 w
.51837 .5598 m .46905 .562 L .46903 .5825 L p
1 g
F P
s
P
p
.002 w
.52883 .28404 m .48536 .27794 L .48413 .29861 L p
1 g
F P
s
P
p
.002 w
.4485 .30562 m .48413 .29861 L .48536 .27794 L p
1 g
F P
s
P
p
.002 w
.40365 .30865 m .37469 .34205 L .3932 .35129 L p
1 g
F P
s
P
p
.002 w
.3932 .35129 m .41701 .32387 L .40365 .30865 L p
1 g
F P
s
P
p
.002 w
.61763 .52562 m .64705 .47932 L .62921 .46917 L p
1 g
F P
s
P
p
.002 w
.64096 .42127 m .62921 .46917 L .64705 .47932 L p
1 g
F P
s
P
p
.002 w
.41631 .56746 m .46903 .5825 L .46905 .562 L p
1 g
F P
s
P
p
.002 w
.46905 .562 m .42165 .54837 L .41631 .56746 L p
1 g
F P
s
P
p
.002 w
.48536 .27794 m .44199 .28644 L .4485 .30562 L p
1 g
F P
s
P
p
.002 w
.41701 .32387 m .4485 .30562 L .44199 .28644 L p
1 g
F P
s
P
p
.002 w
.44199 .28644 m .40365 .30865 L .41701 .32387 L p
1 g
F P
s
P
p
.002 w
.63661 .37211 m .61634 .32693 L .59726 .33516 L p
1 g
F P
s
P
p
.002 w
.56753 .3039 m .59726 .33516 L .61634 .32693 L p
1 g
F P
s
P
p
.002 w
.3377 .43231 m .35206 .48007 L .36864 .46763 L p
1 g
F P
s
P
p
.002 w
.36864 .46763 m .35632 .42628 L .3377 .43231 L p
1 g
F P
s
P
p
.002 w
.64705 .47932 m .66021 .4261 L .64096 .42127 L p
1 g
F P
s
P
p
.002 w
.63661 .37211 m .64096 .42127 L .66021 .4261 L p
1 g
F P
s
P
p
.002 w
.37123 .53616 m .41631 .56746 L .42165 .54837 L p
1 g
F P
s
P
p
.002 w
.42165 .54837 m .38117 .52014 L .37123 .53616 L p
1 g
F P
s
P
p
.002 w
.61634 .32693 m .58207 .29072 L .56753 .3039 L p
1 g
F P
s
P
p
.002 w
.52883 .28404 m .56753 .3039 L .58207 .29072 L p
1 g
F P
s
P
p
.002 w
.33994 .38201 m .3377 .43231 L .35632 .42628 L p
1 g
F P
s
P
p
.002 w
.35632 .42628 m .35835 .38281 L .33994 .38201 L p
1 g
F P
s
P
p
.002 w
.66021 .4261 m .65549 .37144 L .63661 .37211 L p
1 g
F P
s
P
p
.002 w
.61634 .32693 m .63661 .37211 L .65549 .37144 L p
1 g
F P
s
P
p
.002 w
.33874 .49165 m .37123 .53616 L .38117 .52014 L p
1 g
F P
s
P
p
.002 w
.38117 .52014 m .35206 .48007 L .33874 .49165 L p
1 g
F P
s
P
p
.002 w
.58207 .29072 m .53734 .26765 L .52883 .28404 L p
1 g
F P
s
P
p
.002 w
.48536 .27794 m .52883 .28404 L .53734 .26765 L p
1 g
F P
s
P
p
.002 w
.35881 .33479 m .33994 .38201 L .35835 .38281 L p
1 g
F P
s
P
p
.002 w
.35835 .38281 m .37469 .34205 L .35881 .33479 L p
1 g
F P
s
P
p
.002 w
.61763 .52562 m .5751 .56034 L .58409 .57581 L p
1 g
F P
s
P
p
.002 w
.52886 .597 m .58409 .57581 L .5751 .56034 L p
1 g
F P
s
P
p
.002 w
.5751 .56034 m .52383 .57999 L .52886 .597 L p
1 g
F P
s
P
p
.002 w
.58409 .57581 m .62993 .53842 L .61763 .52562 L p
1 g
F P
s
P
p
.002 w
.64705 .47932 m .61763 .52562 L .62993 .53842 L p
1 g
F P
s
P
p
.002 w
.46981 .59977 m .52886 .597 L .52383 .57999 L p
1 g
F P
s
P
p
.002 w
.52383 .57999 m .46903 .5825 L .46981 .59977 L p
1 g
F P
s
P
p
.002 w
.53734 .26765 m .48701 .26052 L .48536 .27794 L p
1 g
F P
s
P
p
.002 w
.44199 .28644 m .48536 .27794 L .48701 .26052 L p
1 g
F P
s
P
p
.002 w
.39233 .29607 m .35881 .33479 L .37469 .34205 L p
1 g
F P
s
P
p
.002 w
.37469 .34205 m .40365 .30865 L .39233 .29607 L p
1 g
F P
s
P
p
.002 w
.62993 .53842 m .66169 .48856 L .64705 .47932 L p
1 g
F P
s
P
p
.002 w
.66021 .4261 m .64705 .47932 L .66169 .48856 L p
1 g
F P
s
P
p
.002 w
.41298 .58365 m .46981 .59977 L .46903 .5825 L p
1 g
F P
s
P
p
.002 w
.46903 .5825 m .41631 .56746 L .41298 .58365 L p
1 g
F P
s
P
p
.002 w
.48701 .26052 m .43676 .27034 L .44199 .28644 L p
1 g
F P
s
P
p
.002 w
.40365 .30865 m .44199 .28644 L .43676 .27034 L p
1 g
F P
s
P
p
.002 w
.43676 .27034 m .39233 .29607 L .40365 .30865 L p
1 g
F P
s
P
p
.002 w
.65549 .37144 m .63305 .32112 L .61634 .32693 L p
1 g
F P
s
P
p
.002 w
.58207 .29072 m .61634 .32693 L .63305 .32112 L p
1 g
F P
s
P
p
.002 w
.32265 .43851 m .33874 .49165 L .35206 .48007 L p
1 g
F P
s
P
p
.002 w
.35206 .48007 m .3377 .43231 L .32265 .43851 L p
1 g
F P
s
P
p
.002 w
.66169 .48856 m .67596 .43123 L .66021 .4261 L p
1 g
F P
s
P
p
.002 w
.65549 .37144 m .66021 .4261 L .67596 .43123 L p
1 g
F P
s
P
p
.002 w
.36432 .55 m .41298 .58365 L .41631 .56746 L p
1 g
F P
s
P
p
.002 w
.41631 .56746 m .37123 .53616 L .36432 .55 L p
1 g
F P
s
P
p
.002 w
.63305 .32112 m .59498 .28072 L .58207 .29072 L p
1 g
F P
s
P
p
.002 w
.53734 .26765 m .58207 .29072 L .59498 .28072 L p
1 g
F P
s
P
p
.002 w
.32506 .38245 m .32265 .43851 L .3377 .43231 L p
1 g
F P
s
P
p
.002 w
.3377 .43231 m .33994 .38201 L .32506 .38245 L p
1 g
F P
s
P
p
.002 w
.67596 .43123 m .67098 .37229 L .65549 .37144 L p
1 g
F P
s
P
p
.002 w
.63305 .32112 m .65549 .37144 L .67098 .37229 L p
1 g
F P
s
P
p
.002 w
.3292 .50206 m .36432 .55 L .37123 .53616 L p
1 g
F P
s
P
p
.002 w
.37123 .53616 m .33874 .49165 L .3292 .50206 L p
1 g
F P
s
P
p
.002 w
.59498 .28072 m .54517 .25493 L .53734 .26765 L p
1 g
F P
s
P
p
.002 w
.48701 .26052 m .53734 .26765 L .54517 .25493 L p
1 g
F P
s
P
p
.002 w
.34604 .32978 m .32506 .38245 L .33994 .38201 L p
1 g
F P
s
P
p
.002 w
.33994 .38201 m .35881 .33479 L .34604 .32978 L p
1 g
F P
s
P
p
.002 w
.53332 .61027 m .59122 .58804 L .58409 .57581 L p
1 g
F P
s
P
p
.002 w
.58409 .57581 m .52886 .597 L .53332 .61027 L p
1 g
F P
s
P
p
.002 w
.62993 .53842 m .58409 .57581 L .59122 .58804 L p
1 g
F P
s
P
p
.002 w
.59122 .58804 m .63928 .54885 L .62993 .53842 L p
1 g
F P
s
P
p
.002 w
.66169 .48856 m .62993 .53842 L .63928 .54885 L p
1 g
F P
s
P
p
.002 w
.47143 .61322 m .53332 .61027 L .52886 .597 L p
1 g
F P
s
P
p
.002 w
.52886 .597 m .46981 .59977 L .47143 .61322 L p
1 g
F P
s
P
p
.002 w
.54517 .25493 m .48907 .24693 L .48701 .26052 L p
1 g
F P
s
P
p
.002 w
.43676 .27034 m .48701 .26052 L .48907 .24693 L p
1 g
F P
s
P
p
.002 w
.38342 .28657 m .34604 .32978 L .35881 .33479 L p
1 g
F P
s
P
p
.002 w
.35881 .33479 m .39233 .29607 L .38342 .28657 L p
1 g
F P
s
P
p
.002 w
.63928 .54885 m .67261 .49661 L .66169 .48856 L p
1 g
F P
s
P
p
.002 w
.67596 .43123 m .66169 .48856 L .67261 .49661 L p
1 g
F P
s
P
p
.002 w
.41183 .59639 m .47143 .61322 L .46981 .59977 L p
1 g
F P
s
P
p
.002 w
.46981 .59977 m .41298 .58365 L .41183 .59639 L p
1 g
F P
s
P
p
.002 w
.48907 .24693 m .433 .25785 L .43676 .27034 L p
1 g
F P
s
P
p
.002 w
.39233 .29607 m .43676 .27034 L .433 .25785 L p
1 g
F P
s
P
p
.002 w
.433 .25785 m .38342 .28657 L .39233 .29607 L p
1 g
F P
s
P
p
.002 w
.67098 .37229 m .64688 .31798 L .63305 .32112 L p
1 g
F P
s
P
p
.002 w
.59498 .28072 m .63305 .32112 L .64688 .31798 L p
1 g
F P
s
P
p
.002 w
.31174 .44474 m .3292 .50206 L .33874 .49165 L p
1 g
F P
s
P
p
.002 w
.33874 .49165 m .32265 .43851 L .31174 .44474 L p
1 g
F P
s
P
p
.002 w
.67261 .49661 m .68764 .43653 L .67596 .43123 L p
1 g
F P
s
P
p
.002 w
.67098 .37229 m .67596 .43123 L .68764 .43653 L p
1 g
F P
s
P
p
.002 w
.36077 .56118 m .41183 .59639 L .41298 .58365 L p
1 g
F P
s
P
p
.002 w
.41298 .58365 m .36432 .55 L .36077 .56118 L p
1 g
F P
s
P
p
.002 w
.64688 .31798 m .60586 .27433 L .59498 .28072 L p
1 g
F P
s
P
p
.002 w
.54517 .25493 m .59498 .28072 L .60586 .27433 L p
1 g
F P
s
P
p
.002 w
.31428 .38421 m .31174 .44474 L .32265 .43851 L p
1 g
F P
s
P
p
.002 w
.32265 .43851 m .32506 .38245 L .31428 .38421 L p
1 g
F P
s
P
p
.002 w
.68764 .43653 m .6825 .37473 L .67098 .37229 L p
1 g
F P
s
P
p
.002 w
.64688 .31798 m .67098 .37229 L .6825 .37473 L p
1 g
F P
s
P
p
.002 w
.32388 .51096 m .36077 .56118 L .36432 .55 L p
1 g
F P
s
P
p
.002 w
.36432 .55 m .3292 .50206 L .32388 .51096 L p
1 g
F P
s
P
p
.002 w
.60586 .27433 m .55212 .24642 L .54517 .25493 L p
1 g
F P
s
P
p
.002 w
.48907 .24693 m .54517 .25493 L .55212 .24642 L p
1 g
F P
s
P
p
.002 w
.3369 .32728 m .31428 .38421 L .32506 .38245 L p
1 g
F P
s
P
p
.002 w
.32506 .38245 m .34604 .32978 L .3369 .32728 L p
1 g
F P
s
P
p
.002 w
.63928 .54885 m .59122 .58804 L .59618 .59653 L p
1 g
F P
s
P
p
.002 w
.53707 .61924 m .59618 .59653 L .59122 .58804 L p
1 g
F P
s
P
p
.002 w
.59122 .58804 m .53332 .61027 L .53707 .61924 L p
1 g
F P
s
P
p
.002 w
.59618 .59653 m .64526 .55653 L .63928 .54885 L p
1 g
F P
s
P
p
.002 w
.67261 .49661 m .63928 .54885 L .64526 .55653 L p
1 g
F P
s
P
p
.002 w
.47388 .62229 m .53707 .61924 L .53332 .61027 L p
1 g
F P
s
P
p
.002 w
.53332 .61027 m .47143 .61322 L .47388 .62229 L p
1 g
F P
s
P
p
.002 w
.55212 .24642 m .49151 .23772 L .48907 .24693 L p
1 g
F P
s
P
p
.002 w
.433 .25785 m .48907 .24693 L .49151 .23772 L p
1 g
F P
s
P
p
.002 w
.37729 .28056 m .3369 .32728 L .34604 .32978 L p
1 g
F P
s
P
p
.002 w
.34604 .32978 m .38342 .28657 L .37729 .28056 L p
1 g
F P
s
P
p
.002 w
.64526 .55653 m .67932 .50321 L .67261 .49661 L p
1 g
F P
s
P
p
.002 w
.68764 .43653 m .67261 .49661 L .67932 .50321 L p
1 g
F P
s
P
p
.002 w
.41303 .60515 m .47388 .62229 L .47143 .61322 L p
1 g
F P
s
P
p
.002 w
.47143 .61322 m .41183 .59639 L .41303 .60515 L p
1 g
F P
s
P
p
.002 w
.6825 .37473 m .6573 .31775 L .64688 .31798 L p
1 g
F P
s
P
p
.002 w
.60586 .27433 m .64688 .31798 L .6573 .31775 L p
1 g
F P
s
P
p
.002 w
.30551 .45084 m .32388 .51096 L .3292 .50206 L p
1 g
F P
s
P
p
.002 w
.3292 .50206 m .31174 .44474 L .30551 .45084 L p
1 g
F P
s
P
p
.002 w
.49151 .23772 m .43089 .24951 L .433 .25785 L p
1 g
F P
s
P
p
.002 w
.38342 .28657 m .433 .25785 L .43089 .24951 L p
1 g
F P
s
P
p
.002 w
.43089 .24951 m .37729 .28056 L .38342 .28657 L p
1 g
F P
s
P
p
.002 w
.67932 .50321 m .69471 .44189 L .68764 .43653 L p
1 g
F P
s
P
p
.002 w
.6825 .37473 m .68764 .43653 L .69471 .44189 L p
1 g
F P
s
P
p
.002 w
.36088 .56926 m .41303 .60515 L .41183 .59639 L p
1 g
F P
s
P
p
.002 w
.41183 .59639 m .36077 .56118 L .36088 .56926 L p
1 g
F P
s
P
p
.002 w
.6573 .31775 m .61431 .27192 L .60586 .27433 L p
1 g
F P
s
P
p
.002 w
.55212 .24642 m .60586 .27433 L .61431 .27192 L p
1 g
F P
s
P
p
.002 w
.30813 .38731 m .30551 .45084 L .31174 .44474 L p
1 g
F P
s
P
p
.002 w
.31174 .44474 m .31428 .38421 L .30813 .38731 L p
1 g
F P
s
P
p
.002 w
.69471 .44189 m .68951 .37881 L .6825 .37473 L p
1 g
F P
s
P
p
.002 w
.6573 .31775 m .6825 .37473 L .68951 .37881 L p
1 g
F P
s
P
p
.002 w
.3232 .51801 m .36088 .56926 L .36077 .56118 L p
1 g
F P
s
P
p
.002 w
.36077 .56118 m .32388 .51096 L .3232 .51801 L p
1 g
F P
s
P
p
.002 w
.61431 .27192 m .55793 .24259 L .55212 .24642 L p
1 g
F P
s
P
p
.002 w
.49151 .23772 m .55212 .24642 L .55793 .24259 L p
1 g
F P
s
P
p
.002 w
.33187 .32753 m .30813 .38731 L .31428 .38421 L p
1 g
F P
s
P
p
.002 w
.31428 .38421 m .3369 .32728 L .33187 .32753 L p
1 g
F P
s
P
p
.002 w
.64526 .55653 m .59618 .59653 L .59871 .60083 L p
1 g
F P
s
P
p
.002 w
.53996 .62341 m .59871 .60083 L .59618 .59653 L p
1 g
F P
s
P
p
.002 w
.59618 .59653 m .53707 .61924 L .53996 .62341 L p
1 g
F P
s
P
p
.002 w
.59871 .60083 m .6475 .56107 L .64526 .55653 L p
1 g
F P
s
P
p
.002 w
.67932 .50321 m .64526 .55653 L .6475 .56107 L p
1 g
F P
s
P
p
.002 w
.47716 .62646 m .53996 .62341 L .53707 .61924 L p
1 g
F P
s
P
p
.002 w
.53707 .61924 m .47388 .62229 L .47716 .62646 L p
1 g
F P
s
P
p
.002 w
.55793 .24259 m .49428 .23344 L .49151 .23772 L p
1 g
F P
s
P
p
.002 w
.43089 .24951 m .49151 .23772 L .49428 .23344 L p
1 g
F P
s
P
p
.002 w
.37429 .27843 m .33187 .32753 L .3369 .32728 L p
1 g
F P
s
P
p
.002 w
.3369 .32728 m .37729 .28056 L .37429 .27843 L p
1 g
F P
s
P
p
.002 w
.6475 .56107 m .68136 .50809 L .67932 .50321 L p
1 g
F P
s
P
p
.002 w
.69471 .44189 m .67932 .50321 L .68136 .50809 L p
1 g
F P
s
P
p
.002 w
.68951 .37881 m .66382 .32063 L .6573 .31775 L p
1 g
F P
s
P
p
.002 w
.61431 .27192 m .6573 .31775 L .66382 .32063 L p
1 g
F P
s
P
p
.002 w
.4167 .60945 m .47716 .62646 L .47388 .62229 L p
1 g
F P
s
P
p
.002 w
.47388 .62229 m .41303 .60515 L .4167 .60945 L p
1 g
F P
s
P
p
.002 w
.30442 .45664 m .3232 .51801 L .32388 .51096 L p
1 g
F P
s
P
p
.002 w
.32388 .51096 m .30551 .45084 L .30442 .45664 L p
1 g
F P
s
P
p
.002 w
.49428 .23344 m .43061 .24581 L .43089 .24951 L p
1 g
F P
s
P
p
.002 w
.37729 .28056 m .43089 .24951 L .43061 .24581 L p
1 g
F P
s
P
p
.002 w
.43061 .24581 m .37429 .27843 L .37729 .28056 L p
1 g
F P
s
P
p
.002 w
.68136 .50809 m .69668 .44717 L .69471 .44189 L p
1 g
F P
s
P
p
.002 w
.68951 .37881 m .69471 .44189 L .69668 .44717 L p
1 g
F P
s
P
p
.002 w
.3649 .5738 m .4167 .60945 L .41303 .60515 L p
1 g
F P
s
P
p
.002 w
.41303 .60515 m .36088 .56926 L .3649 .5738 L p
1 g
F P
s
P
p
.002 w
.66382 .32063 m .61995 .27383 L .61431 .27192 L p
1 g
F P
s
P
p
.002 w
.55793 .24259 m .61431 .27192 L .61995 .27383 L p
1 g
F P
s
P
p
.002 w
.30709 .39176 m .30442 .45664 L .30551 .45084 L p
1 g
F P
s
P
p
.002 w
.30551 .45084 m .30813 .38731 L .30709 .39176 L p
1 g
F P
s
P
p
.004 w
.52559 .6356 m
.53573 .71689 L
s
P
p
.002 w
.69668 .44717 m .69152 .38451 L .68951 .37881 L p
1 g
F P
s
P
p
.002 w
.66382 .32063 m .68951 .37881 L .69152 .38451 L p
1 g
F P
s
P
p
.002 w
.32748 .52291 m .3649 .5738 L .36088 .56926 L p
1 g
F P
s
P
p
.002 w
.36088 .56926 m .3232 .51801 L .32748 .52291 L p
1 g
F P
s
P
p
.002 w
.61995 .27383 m .56237 .24387 L .55793 .24259 L p
1 g
F P
s
P
p
.002 w
.49428 .23344 m .55793 .24259 L .56237 .24387 L p
1 g
F P
s
P
p
.002 w
.33135 .33068 m .30709 .39176 L .30813 .38731 L p
1 g
F P
s
P
p
.002 w
.30813 .38731 m .33187 .32753 L .33135 .33068 L p
1 g
F P
s
P
p
.002 w
.6475 .56107 m .59871 .60083 L .59858 .60053 L p
1 g
F P
s
P
p
.002 w
.54186 .62233 m .59858 .60053 L .59871 .60083 L p
1 g
F P
s
P
p
.002 w
.59871 .60083 m .53996 .62341 L .54186 .62233 L p
1 g
F P
s
P
p
.002 w
.59858 .60053 m .64569 .56214 L .6475 .56107 L p
1 g
F P
s
P
p
.002 w
.68136 .50809 m .6475 .56107 L .64569 .56214 L p
1 g
F P
s
P
p
.002 w
.48124 .62527 m .54186 .62233 L .53996 .62341 L p
1 g
F P
s
P
p
.002 w
.53996 .62341 m .47716 .62646 L .48124 .62527 L p
1 g
F P
s
P
p
.002 w
.56237 .24387 m .49735 .23452 L .49428 .23344 L p
1 g
F P
s
P
p
.002 w
.43061 .24581 m .49428 .23344 L .49735 .23452 L p
1 g
F P
s
P
p
.002 w
.37471 .28051 m .33135 .33068 L .33187 .32753 L p
1 g
F P
s
P
p
.002 w
.33187 .32753 m .37429 .27843 L .37471 .28051 L p
1 g
F P
s
P
p
.002 w
.69152 .38451 m .666 .32674 L .66382 .32063 L p
1 g
F P
s
P
p
.002 w
.61995 .27383 m .66382 .32063 L .666 .32674 L p
1 g
F P
s
P
p
.002 w
.64569 .56214 m .67838 .511 L .68136 .50809 L p
1 g
F P
s
P
p
.002 w
.69668 .44717 m .68136 .50809 L .67838 .511 L p
1 g
F P
s
P
p
.002 w
.42289 .60885 m .48124 .62527 L .47716 .62646 L p
1 g
F P
s
P
p
.002 w
.47716 .62646 m .4167 .60945 L .42289 .60885 L p
1 g
F P
s
P
p
.002 w
.30885 .46196 m .32748 .52291 L .3232 .51801 L p
1 g
F P
s
P
p
.002 w
.3232 .51801 m .30442 .45664 L .30885 .46196 L p
1 g
F P
s
P
p
.002 w
.49735 .23452 m .43227 .24716 L .43061 .24581 L p
1 g
F P
s
P
p
.002 w
.37429 .27843 m .43061 .24581 L .43227 .24716 L p
1 g
F P
s
P
p
.002 w
.43227 .24716 m .37471 .28051 L .37429 .27843 L p
1 g
F P
s
P
p
.002 w
.67838 .511 m .69314 .45221 L .69668 .44717 L p
1 g
F P
s
P
p
.002 w
.69152 .38451 m .69668 .44717 L .69314 .45221 L p
1 g
F P
s
P
p
.002 w
.37295 .57444 m .42289 .60885 L .4167 .60945 L p
1 g
F P
s
P
p
.002 w
.4167 .60945 m .3649 .5738 L .37295 .57444 L p
1 g
F P
s
P
p
.002 w
.666 .32674 m .62243 .28027 L .61995 .27383 L p
1 g
F P
s
P
p
.002 w
.56237 .24387 m .61995 .27383 L .62243 .28027 L p
1 g
F P
s
P
p
.002 w
.31154 .39752 m .30885 .46196 L .30442 .45664 L p
1 g
F P
s
P
p
.002 w
.30442 .45664 m .30709 .39176 L .31154 .39752 L p
1 g
F P
s
P
p
.002 w
.69314 .45221 m .68814 .39178 L .69152 .38451 L p
1 g
F P
s
P
p
.002 w
.666 .32674 m .69152 .38451 L .68814 .39178 L p
1 g
F P
s
P
p
.002 w
.33692 .52535 m .37295 .57444 L .3649 .5738 L p
1 g
F P
s
P
p
.002 w
.3649 .5738 m .32748 .52291 L .33692 .52535 L p
1 g
F P
s
P
p
.002 w
.62243 .28027 m .56522 .25055 L .56237 .24387 L p
1 g
F P
s
P
p
.002 w
.49735 .23452 m .56237 .24387 L .56522 .25055 L p
1 g
F P
s
P
p
.002 w
.33566 .33685 m .31154 .39752 L .30709 .39176 L p
1 g
F P
s
P
p
.002 w
.30709 .39176 m .33135 .33068 L .33566 .33685 L p
1 g
F P
s
P
p
.002 w
.54263 .61569 m .59562 .59534 L .59858 .60053 L p
1 g
F P
s
P
p
.002 w
.59858 .60053 m .54186 .62233 L .54263 .61569 L p
1 g
F P
s
P
p
.002 w
.64569 .56214 m .59858 .60053 L .59562 .59534 L p
1 g
F P
s
P
p
.002 w
.59562 .59534 m .63962 .55948 L .64569 .56214 L p
1 g
F P
s
P
p
.002 w
.67838 .511 m .64569 .56214 L .63962 .55948 L p
1 g
F P
s
P
p
.002 w
.48603 .61842 m .54263 .61569 L .54186 .62233 L p
1 g
F P
s
P
p
.002 w
.54186 .62233 m .48124 .62527 L .48603 .61842 L p
1 g
F P
s
P
p
.004 w
.52387 .62184 m
.52559 .6356 L
s
P
p
.002 w
.56522 .25055 m .50062 .24129 L .49735 .23452 L p
1 g
F P
s
P
p
.002 w
.43227 .24716 m .49735 .23452 L .50062 .24129 L p
1 g
F P
s
P
p
.002 w
.37876 .28701 m .33566 .33685 L .33135 .33068 L p
1 g
F P
s
P
p
.002 w
.33135 .33068 m .37471 .28051 L .37876 .28701 L p
1 g
F P
s
P
p
.002 w
.68814 .39178 m .6635 .33611 L .666 .32674 L p
1 g
F P
s
P
p
.002 w
.62243 .28027 m .666 .32674 L .6635 .33611 L p
1 g
F P
s
P
p
.002 w
.31903 .46659 m .33692 .52535 L .32748 .52291 L p
1 g
F P
s
P
p
.002 w
.32748 .52291 m .30885 .46196 L .31903 .46659 L p
1 g
F P
s
P
p
.002 w
.63962 .55948 m .67012 .51171 L .67838 .511 L p
1 g
F P
s
P
p
.002 w
.69314 .45221 m .67838 .511 L .67012 .51171 L p
1 g
F P
s
P
p
.002 w
.4316 .60305 m .48603 .61842 L .48124 .62527 L p
1 g
F P
s
P
p
.002 w
.48124 .62527 m .42289 .60885 L .4316 .60305 L p
1 g
F P
s
P
p
.002 w
.50062 .24129 m .43596 .25387 L .43227 .24716 L p
1 g
F P
s
P
p
.002 w
.37471 .28051 m .43227 .24716 L .43596 .25387 L p
1 g
F P
s
P
p
.002 w
.43596 .25387 m .37876 .28701 L .37471 .28051 L p
1 g
F P
s
P
p
.002 w
.67012 .51171 m .68385 .45684 L .69314 .45221 L p
1 g
F P
s
P
p
.002 w
.68814 .39178 m .69314 .45221 L .68385 .45684 L p
1 g
F P
s
P
p
.002 w
.38506 .57091 m .4316 .60305 L .42289 .60885 L p
1 g
F P
s
P
p
.002 w
.42289 .60885 m .37295 .57444 L .38506 .57091 L p
1 g
F P
s
P
p
.002 w
.6635 .33611 m .62145 .29136 L .62243 .28027 L p
1 g
F P
s
P
p
.002 w
.56522 .25055 m .62243 .28027 L .62145 .29136 L p
1 g
F P
s
P
p
.002 w
.32169 .40449 m .31903 .46659 L .30885 .46196 L p
1 g
F P
s
P
p
.002 w
.30885 .46196 m .31154 .39752 L .32169 .40449 L p
1 g
F P
s
P
p
.002 w
.68385 .45684 m .67913 .40049 L .68814 .39178 L p
1 g
F P
s
P
p
.002 w
.6635 .33611 m .68814 .39178 L .67913 .40049 L p
1 g
F P
s
P
p
.002 w
.35155 .52511 m .38506 .57091 L .37295 .57444 L p
1 g
F P
s
P
p
.002 w
.37295 .57444 m .33692 .52535 L .35155 .52511 L p
1 g
F P
s
P
p
.002 w
.62145 .29136 m .56629 .26278 L .56522 .25055 L p
1 g
F P
s
P
p
.002 w
.50062 .24129 m .56522 .25055 L .56629 .26278 L p
1 g
F P
s
P
p
.002 w
.34499 .34603 m .32169 .40449 L .31154 .39752 L p
1 g
F P
s
P
p
.002 w
.31154 .39752 m .33566 .33685 L .34499 .34603 L p
1 g
F P
s
P
p
.002 w
.63962 .55948 m .59562 .59534 L .58972 .58509 L p
1 g
F P
s
P
p
.002 w
.54219 .60334 m .58972 .58509 L .59562 .59534 L p
1 g
F P
s
P
p
.002 w
.59562 .59534 m .54263 .61569 L .54219 .60334 L p
1 g
F P
s
P
p
.002 w
.58972 .58509 m .62918 .55291 L .63962 .55948 L p
1 g
F P
s
P
p
.002 w
.67012 .51171 m .63962 .55948 L .62918 .55291 L p
1 g
F P
s
P
p
.002 w
.49144 .60574 m .54219 .60334 L .54263 .61569 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52169 .60431 L
s
P
p
.002 w
.54263 .61569 m .48603 .61842 L .49144 .60574 L p
1 g
F P
s
P
p
.004 w
.52282 .61342 m
.523 .61483 L
s
P
p
.004 w
.523 .61483 m
.52387 .62184 L
s
P
p
.002 w
.56629 .26278 m .50401 .25391 L .50062 .24129 L p
1 g
F P
s
P
p
.002 w
.43596 .25387 m .50062 .24129 L .50401 .25391 L p
1 g
F P
s
P
p
.002 w
.38656 .29802 m .34499 .34603 L .33566 .33685 L p
1 g
F P
s
P
p
.002 w
.33566 .33685 m .37876 .28701 L .38656 .29802 L p
1 g
F P
s
P
p
.002 w
.67913 .40049 m .65608 .34864 L .6635 .33611 L p
1 g
F P
s
P
p
.002 w
.62145 .29136 m .6635 .33611 L .65608 .34864 L p
1 g
F P
s
P
p
.002 w
.33498 .47034 m .35155 .52511 L .33692 .52535 L p
1 g
F P
s
P
p
.002 w
.33692 .52535 m .31903 .46659 L .33498 .47034 L p
1 g
F P
s
P
p
.002 w
.62918 .55291 m .6565 .51006 L .67012 .51171 L p
1 g
F P
s
P
p
.002 w
.68385 .45684 m .67012 .51171 L .6565 .51006 L p
1 g
F P
s
P
p
.002 w
.44268 .59191 m .49144 .60574 L .48603 .61842 L p
1 g
F P
s
P
p
.002 w
.48603 .61842 m .4316 .60305 L .44268 .59191 L p
1 g
F P
s
P
p
.002 w
.50401 .25391 m .4417 .26607 L .43596 .25387 L p
1 g
F P
s
P
p
.002 w
.37876 .28701 m .43596 .25387 L .4417 .26607 L p
1 g
F P
s
P
p
.002 w
.4417 .26607 m .38656 .29802 L .37876 .28701 L p
1 g
F P
s
P
p
.002 w
.6565 .51006 m .66875 .46088 L .68385 .45684 L p
1 g
F P
s
P
p
.002 w
.67913 .40049 m .68385 .45684 L .66875 .46088 L p
1 g
F P
s
P
p
.002 w
.40107 .56306 m .44268 .59191 L .4316 .60305 L p
1 g
F P
s
P
p
.002 w
.4316 .60305 m .38506 .57091 L .40107 .56306 L p
1 g
F P
s
P
p
.002 w
.65608 .34864 m .61684 .30702 L .62145 .29136 L p
1 g
F P
s
P
p
.002 w
.56629 .26278 m .62145 .29136 L .61684 .30702 L p
1 g
F P
s
P
p
.002 w
.33755 .41251 m .33498 .47034 L .31903 .46659 L p
1 g
F P
s
P
p
.002 w
.31903 .46659 m .32169 .40449 L .33755 .41251 L p
1 g
F P
s
P
p
.002 w
.66875 .46088 m .66442 .41044 L .67913 .40049 L p
1 g
F P
s
P
p
.002 w
.65608 .34864 m .67913 .40049 L .66442 .41044 L p
1 g
F P
s
P
p
.002 w
.37119 .52202 m .40107 .56306 L .38506 .57091 L p
1 g
F P
s
P
p
.002 w
.38506 .57091 m .35155 .52511 L .37119 .52202 L p
1 g
F P
s
P
p
.002 w
.61684 .30702 m .56542 .28049 L .56629 .26278 L p
1 g
F P
s
P
p
.002 w
.50401 .25391 m .56629 .26278 L .56542 .28049 L p
1 g
F P
s
P
p
.002 w
.35933 .35811 m .33755 .41251 L .32169 .40449 L p
1 g
F P
s
P
p
.002 w
.32169 .40449 m .34499 .34603 L .35933 .35811 L p
1 g
F P
s
P
p
.002 w
.62918 .55291 m .58972 .58509 L .58091 .56981 L p
1 g
F P
s
P
p
.002 w
.54047 .58532 m .58091 .56981 L .58972 .58509 L p
1 g
F P
s
P
p
.002 w
.58972 .58509 m .54219 .60334 L .54047 .58532 L p
1 g
F P
s
P
p
.002 w
.58091 .56981 m .61447 .54243 L .62918 .55291 L p
1 g
F P
s
P
p
.002 w
.6565 .51006 m .62918 .55291 L .61447 .54243 L p
1 g
F P
s
P
p
.002 w
.49731 .58732 m .54047 .58532 L .54219 .60334 L p
1 g
F P
s
P
p
.002 w
.54219 .60334 m .49144 .60574 L .49731 .58732 L p
1 g
F P
s
P
p
.002 w
.56542 .28049 m .50742 .27232 L .50401 .25391 L p
1 g
F P
s
P
p
.002 w
.4417 .26607 m .50401 .25391 L .50742 .27232 L p
1 g
F P
s
P
p
.002 w
.39807 .31343 m .35933 .35811 L .34499 .34603 L p
1 g
F P
s
P
p
.002 w
.34499 .34603 m .38656 .29802 L .39807 .31343 L p
1 g
F P
s
P
p
.002 w
.66442 .41044 m .64371 .3641 L .65608 .34864 L p
1 g
F P
s
P
p
.002 w
.61684 .30702 m .65608 .34864 L .64371 .3641 L p
1 g
F P
s
P
p
.002 w
.3565 .47303 m .37119 .52202 L .35155 .52511 L p
1 g
F P
s
P
p
.002 w
.35155 .52511 m .33498 .47034 L .3565 .47303 L p
1 g
F P
s
P
p
.002 w
.61447 .54243 m .63766 .50597 L .6565 .51006 L p
1 g
F P
s
P
p
.002 w
.66875 .46088 m .6565 .51006 L .63766 .50597 L p
1 g
F P
s
P
p
.002 w
.45591 .57549 m .49731 .58732 L .49144 .60574 L p
1 g
F P
s
P
p
.002 w
.49144 .60574 m .44268 .59191 L .45591 .57549 L p
1 g
F P
s
P
p
.002 w
.50742 .27232 m .44941 .28369 L .4417 .26607 L p
1 g
F P
s
P
p
.002 w
.38656 .29802 m .4417 .26607 L .44941 .28369 L p
1 g
F P
s
P
p
.002 w
.44941 .28369 m .39807 .31343 L .38656 .29802 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63766 .50597 m .64799 .46416 L .66875 .46088 L p
1 g
F P
s
P
p
.002 w
.66442 .41044 m .66875 .46088 L .64799 .46416 L p
1 g
F P
s
P
p
.002 w
.42066 .55092 m .45591 .57549 L .44268 .59191 L p
1 g
F P
s
P
p
.002 w
.44268 .59191 m .40107 .56306 L .42066 .55092 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.64371 .3641 m .60853 .32699 L .61684 .30702 L p
1 g
F P
s
P
p
.002 w
.56542 .28049 m .61684 .30702 L .60853 .32699 L p
1 g
F P
s
P
p
.002 w
.35892 .42137 m .3565 .47303 L .33498 .47034 L p
1 g
F P
s
P
p
.002 w
.33498 .47034 m .33755 .41251 L .35892 .42137 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.64799 .46416 m .64422 .42136 L .66442 .41044 L p
1 g
F P
s
P
p
.002 w
.64371 .3641 m .66442 .41044 L .64422 .42136 L p
1 g
F P
s
P
p
.002 w
.39542 .51605 m .42066 .55092 L .40107 .56306 L p
1 g
F P
s
P
p
.002 w
.40107 .56306 m .37119 .52202 L .39542 .51605 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.60853 .32699 m .56254 .30339 L .56542 .28049 L p
1 g
F P
s
P
p
.002 w
.50742 .27232 m .56542 .28049 L .56254 .30339 L p
1 g
F P
s
P
p
.002 w
.37846 .37282 m .35892 .42137 L .33755 .41251 L p
1 g
F P
s
P
p
.002 w
.33755 .41251 m .35933 .35811 L .37846 .37282 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.61447 .54243 m .58091 .56981 L .56932 .54975 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53162 .57423 L p
1 g
F P
s
P
p
.54854 .56129 m .53162 .57423 L .53578 .57194 L 1 g
F
P
p
.54047 .58532 m .52648 .57706 L .53162 .57423 L 1 g
F
P
p
.002 w
.53855 .57041 m .53877 .57218 L p
.53162 .57423 L 1 g
F P
s
P
p
.002 w
.53877 .57218 m .54047 .58532 L p
.53162 .57423 L 1 g
F P
s
P
p
.002 w
.53162 .57423 m .53128 .57265 L p
.52388 .57645 L 1 g
F P
s
P
p
.54854 .56129 m .53578 .57194 L .54027 .56917 L 1 g
F
P
p
.53578 .57194 m .53184 .57522 L .53855 .57041 L 1 g
F
P
p
.53578 .57194 m .53855 .57041 L .54027 .56917 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58017 L p
1 g
F P
s
P
p
.53128 .57265 m .51091 .58017 L .52388 .57645 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.54047 .58532 m .49731 .58732 L .49894 .58101 L p
1 g
F P
s
P
p
.002 w
.51091 .58017 m .51079 .57862 L p
.49886 .58101 L 1 g
F P
s
P
p
.002 w
.49894 .58101 m .49731 .58732 L p
.49192 .58053 L 1 g
F P
s
P
p
.49886 .58101 m .49877 .58102 L .49894 .58101 L 1 g
F
P
p
.49886 .58101 m .49894 .58101 L .51091 .58017 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58034 L p
1 g
F P
s
P
p
.002 w
.49731 .58732 m .46782 .57889 L p
.48908 .58034 L 1 g
F P
s
P
p
.49258 .58136 m .48908 .58034 L .49192 .58053 L 1 g
F
P
p
.49731 .58732 m .48908 .58034 L .49258 .58136 L 1 g
F
P
p
.002 w
.48908 .58034 m .48921 .57862 L p
.48084 .57793 L 1 g
F P
s
P
p
.51079 .57862 m .48908 .58034 L .49886 .58101 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46836 .57429 L p
1 g
F P
s
P
p
.48921 .57862 m .46836 .57429 L .48084 .57793 L 1 g
F
P
p
.49192 .58053 m .48774 .57995 L .47092 .5541 L 1 g
F
P
p
.002 w
.45591 .57549 m .45873 .57147 L p
.46836 .57429 L 1 g
F P
s
P
p
.47525 .5782 m .45591 .57549 L .46836 .57429 L 1 g
F
P
p
.002 w
.46836 .57429 m .46872 .57265 L p
.45899 .56876 L 1 g
F P
s
P
p
.002 w
.46006 .56957 m .45591 .57549 L p
.45224 .56364 L 1 g
F P
s
P
p
.45899 .56876 m .45778 .56828 L .46006 .56957 L 1 g
F
P
p
.45899 .56876 m .46006 .56957 L .46836 .57429 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45095 .56266 L p
1 g
F P
s
P
p
.45591 .57549 m .42828 .54546 L .45095 .56266 L 1 g
F
P
p
.45258 .56473 m .45095 .56266 L .45224 .56364 L 1 g
F
P
p
.45591 .57549 m .45095 .56266 L .45258 .56473 L 1 g
F
P
p
.002 w
.45095 .56266 m .45146 .56129 L p
.44643 .55692 L 1 g
F P
s
P
p
.46872 .57265 m .45095 .56266 L .45674 .56705 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43857 .54694 L p
1 g
F P
s
P
p
.45146 .56129 m .43857 .54694 L .44643 .55692 L 1 g
F
P
p
.45224 .56364 m .45095 .56266 L .44328 .5347 L 1 g
F
P
p
.002 w
.42828 .54546 m .43411 .54128 L p
.43857 .54694 L 1 g
F P
s
P
p
.44199 .55586 m .42828 .54546 L .43857 .54694 L 1 g
F
P
p
.002 w
.43857 .54694 m .43925 .54566 L p
.43529 .53783 L 1 g
F P
s
P
p
.42066 .55092 m .42855 .51419 L .43264 .52853 L 1 g
F
P
p
.002 w
.43591 .53999 m .43199 .5428 L p
.43264 .52853 L 1 g
F P
s
P
p
.002 w
.43199 .5428 m .42066 .55092 L p
.43264 .52853 L 1 g
F P
s
P
p
.002 w
.43264 .52853 m .43346 .52734 L p
.43316 .5187 L 1 g
F P
s
P
p
.002 w
.42357 .50727 m .43448 .50329 L p
.43396 .50931 L 1 g
F P
s
P
p
.002 w
.43301 .5204 m .43043 .5168 L p
.43396 .50931 L 1 g
F P
s
P
p
.002 w
.43043 .5168 m .42357 .50727 L p
.43396 .50931 L 1 g
F P
s
P
p
.002 w
.43396 .50931 m .43485 .50826 L p
.43826 .50029 L 1 g
F P
s
P
p
.42357 .50727 m .44942 .47743 L .44266 .49128 L 1 g
F
P
p
.002 w
.4373 .50226 m .42767 .50577 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.42767 .50577 m .42357 .50727 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43316 .5187 m .43301 .5204 L .43264 .52853 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43529 .53783 m .43591 .53999 L .43857 .54694 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43192 .52959 L p
1 g
F P
s
P
p
.43925 .54566 m .43192 .52959 L .43441 .53609 L 1 g
F
P
p
.45095 .56266 m .43857 .54694 L .44328 .5347 L 1 g
F
P
p
.002 w
.43411 .54128 m .43591 .53999 L p
.43857 .54694 L 1 g
F P
s
P
p
.002 w
.43591 .53999 m .44328 .5347 L p
.43857 .54694 L 1 g
F P
s
P
p
.002 w
.43192 .52959 m .43146 .53025 L p
.43441 .53609 L 1 g
F P
s
P
p
.002 w
.44328 .5347 m .43591 .53999 L p
.43264 .52853 L 1 g
F P
s
P
p
.002 w
.42855 .51419 m .43301 .5204 L p
.43264 .52853 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4335 .50987 L p
1 g
F P
s
P
p
.43346 .52734 m .4335 .50987 L .43313 .51786 L 1 g
F
P
p
.002 w
.43301 .5204 m .44328 .5347 L p
.43264 .52853 L 1 g
F P
s
P
p
.002 w
.4335 .50987 m .43287 .51061 L p
.43313 .51786 L 1 g
F P
s
P
p
.43301 .5204 m .43396 .50931 L .45474 .4959 L 1 g
F
P
p
.002 w
.43448 .50329 m .4373 .50226 L p
.43396 .50931 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44232 .49164 L p
1 g
F P
s
P
p
.43485 .50826 m .44232 .49164 L .43855 .49961 L 1 g
F
P
p
.43826 .50029 m .4373 .50226 L .43396 .50931 L 1 g
F
P
p
.002 w
.4373 .50226 m .45474 .4959 L p
.43396 .50931 L 1 g
F P
s
P
p
.002 w
.44232 .49164 m .44166 .49233 L p
.43855 .49961 L 1 g
F P
s
P
p
.002 w
.44266 .49128 m .44339 .4905 L p
.45137 .48285 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45107 .48315 m .45765 .47675 L .48454 .47087 L 1 g
F
P
p
.002 w
.45765 .47675 m .45826 .47608 L p
.46804 .47179 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48454 .47087 m .46744 .47208 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.47752 .46723 m .47786 .46667 L p
.49047 .46539 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56613 .50943 L p
1 g
F P
s
P
p
.002 w
.57351 .51046 m .56856 .51451 L p
.56613 .50943 L 1 g
F P
s
P
p
.56595 .50761 m .56613 .50943 L .56511 .50729 L 1 g
F
P
p
.57351 .51046 m .56613 .50943 L .56595 .50761 L 1 g
F
P
p
.002 w
.56613 .50943 m .56515 .50826 L p
.56697 .52004 L 1 g
F P
s
P
p
.002 w
.56678 .51597 m .57351 .51046 L p
.56726 .52622 L 1 g
F P
s
P
p
.56697 .52004 m .56754 .52379 L .56678 .51597 L 1 g
F
P
p
.56697 .52004 m .56678 .51597 L .56613 .50943 L 1 g
F
P
p
.002 w
.57351 .51046 m .59575 .52817 L p
.56726 .52622 L 1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56737 .52854 L p
1 g
F P
s
P
p
.59575 .52817 m .56828 .54794 L .56737 .52854 L 1 g
F
P
p
.56802 .52627 m .56737 .52854 L .56726 .52622 L 1 g
F
P
p
.59575 .52817 m .56737 .52854 L .56802 .52627 L 1 g
F
P
p
.002 w
.56737 .52854 m .56654 .52734 L p
.56453 .53832 L 1 g
F P
s
P
p
.56515 .50826 m .56737 .52854 L .56706 .522 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56159 .54725 L p
1 g
F P
s
P
p
.002 w
.56393 .54042 m .56932 .54975 L p
.56186 .54646 L 1 g
F P
s
P
p
.56654 .52734 m .56159 .54725 L .56262 .54423 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56932 .54975 m .58091 .56981 L p
.54819 .5639 L 1 g
F P
s
P
p
.54819 .5639 m .54774 .56381 L .54893 .56303 L 1 g
F
P
p
.54819 .5639 m .54893 .56303 L .56932 .54975 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56283 L p
1 g
F P
s
P
p
.56075 .54566 m .54911 .56283 L .55231 .55911 L 1 g
F
P
p
.56075 .54566 m .55231 .55911 L .55516 .5558 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56506 .55138 m .56932 .54975 L p
.54893 .56303 L 1 g
F P
s
P
p
.54774 .56381 m .54911 .56283 L .54893 .56303 L 1 g
F
P
p
.54911 .56283 m .56506 .55138 L .54893 .56303 L 1 g
F
P
p
.002 w
.55596 .55487 m .56506 .55138 L p
.54911 .56283 L 1 g
F P
s
P
p
.002 w
.55944 .55354 m .55596 .55487 L p
.56159 .54725 L 1 g
F P
s
P
p
.002 w
.56932 .54975 m .55944 .55354 L p
.56159 .54725 L 1 g
F P
s
P
p
.56209 .54657 m .56159 .54725 L .56186 .54646 L 1 g
F
P
p
.56932 .54975 m .56159 .54725 L .56209 .54657 L 1 g
F
P
p
.56075 .54566 m .55516 .5558 L .55596 .55487 L 1 g
F
P
p
.002 w
.56194 .54791 m .56159 .54725 L p
.55596 .55487 L 1 g
F P
s
P
p
.002 w
.56159 .54725 m .56075 .54566 L p
.55596 .55487 L 1 g
F P
s
P
p
.002 w
.58091 .56981 m .54047 .58532 L .53855 .57041 L p
1 g
F P
s
P
p
.58091 .56981 m .53855 .57041 L .54774 .56381 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56283 L p
1 g
F P
s
P
p
.002 w
.54911 .56283 m .54854 .56129 L p
.54027 .56917 L 1 g
F P
s
P
p
.54027 .56917 m .5322 .57686 L .54911 .56283 L 1 g
F
P
p
.002 w
.53855 .57041 m .53746 .56196 L p
.54774 .56381 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56194 .54791 L p
1 g
F P
s
P
p
.55516 .5558 m .54998 .56518 L .56194 .54791 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53746 .56196 m .55596 .55487 L p
.54774 .56381 L 1 g
F P
s
P
p
.54774 .56381 m .55596 .55487 L .54911 .56283 L 1 g
F
P
p
.55516 .5558 m .54943 .56369 L .55483 .5564 L 1 g
F
P
p
.55231 .55911 m .54943 .56369 L .55516 .5558 L 1 g
F
P
p
.002 w
.54911 .56283 m .54943 .56369 L p
.55231 .55911 L 1 g
F P
s
P
p
.002 w
.54943 .56369 m .54998 .56518 L p
.55483 .5564 L 1 g
F P
s
P
p
.56159 .54725 m .53746 .56196 L .56186 .54646 L 1 g
F
P
p
.002 w
.55596 .55487 m .53746 .56196 L p
.56159 .54725 L 1 g
F P
s
P
p
.002 w
.53746 .56196 m .5332 .53383 L p
.56186 .54646 L 1 g
F P
s
P
p
.002 w
.56828 .54794 m .56393 .54042 L p
.56737 .52854 L 1 g
F P
s
P
p
.002 w
.56182 .54768 m .56257 .5491 L p
.56441 .53901 L 1 g
F P
s
P
p
.56453 .53832 m .56393 .54042 L .56441 .53901 L 1 g
F
P
p
.56393 .54042 m .56182 .54768 L .56441 .53901 L 1 g
F
P
p
.002 w
.56159 .54725 m .56182 .54768 L p
.56262 .54423 L 1 g
F P
s
P
p
.56654 .52734 m .56182 .54768 L .56453 .53832 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5332 .53383 m .55524 .5254 L .56393 .54042 L p
1 g
F P
s
P
p
.56186 .54646 m .5332 .53383 L .56393 .54042 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56726 .52622 m .56737 .52854 L .55524 .5254 L 1 g
F
P
p
.002 w
.56393 .54042 m .55524 .5254 L p
.56737 .52854 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56737 .52854 L p
1 g
F P
s
P
p
.56453 .53832 m .56257 .5491 L .56737 .52854 L 1 g
F
P
p
.002 w
.56737 .52854 m .56812 .52964 L p
.56706 .522 L 1 g
F P
s
P
p
.002 w
.59575 .52817 m .56932 .54975 L .56828 .54794 L p
1 g
F P
s
P
p
.56515 .50826 m .56812 .52964 L .56754 .52379 L 1 g
F
P
p
.55661 .4905 m .56613 .50943 L .56215 .50111 L 1 g
F
P
p
.58608 .49057 m .56583 .49949 L .55677 .49 L 1 g
F
P
p
.56583 .49949 m .56215 .50111 L .55744 .49138 L 1 g
F
P
p
.56583 .49949 m .55744 .49138 L .55677 .49 L 1 g
F
P
p
.55661 .4905 m .56215 .50111 L .56208 .50096 L 1 g
F
P
p
.002 w
.58608 .49057 m .57351 .51046 L .56215 .50111 L p
1 g
F P
s
P
p
.002 w
.56215 .50111 m .57351 .51046 L p
.56511 .50729 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55755 .4915 L p
1 g
F P
s
P
p
.002 w
.55755 .4915 m .55661 .4905 L p
.56209 .50098 L 1 g
F P
s
P
p
.56209 .50098 m .56713 .51061 L .55755 .4915 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.5391 .4975 m .54845 .48984 L .56215 .50111 L p
1 g
F P
s
P
p
.56511 .50729 m .5391 .4975 L .56215 .50111 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55744 .49138 L p
1 g
F P
s
P
p
.54174 .47608 m .55744 .49138 L .55395 .48801 L 1 g
F
P
p
.002 w
.56215 .50111 m .54845 .48984 L p
.55599 .48999 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55677 .49 m .55744 .49138 L .55599 .48999 L 1 g
F
P
p
.55744 .49138 m .56215 .50111 L .55599 .48999 L 1 g
F
P
p
.54174 .47608 m .55395 .48801 L .55198 .4861 L 1 g
F
P
p
.002 w
.55486 .47965 m .58608 .49057 L p
.55599 .48999 L 1 g
F P
s
P
p
.002 w
.54845 .48984 m .55124 .4854 L p
.55599 .48999 L 1 g
F P
s
P
p
.002 w
.54281 .47725 m .54174 .47608 L p
.55198 .4861 L 1 g
F P
s
P
p
.002 w
.55124 .4854 m .55486 .47965 L p
.55599 .48999 L 1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55124 .4854 m .54845 .48984 L p
.54052 .47587 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47674 L p
1 g
F P
s
P
p
.52214 .46667 m .54235 .47674 L .53315 .47237 L 1 g
F
P
p
.54235 .47674 m .54052 .47587 L .53936 .47384 L 1 g
F
P
p
.55124 .4854 m .54052 .47587 L .54235 .47674 L 1 g
F
P
p
.002 w
.54845 .48984 m .52168 .46721 L p
.52463 .46832 L 1 g
F P
s
P
p
.52214 .46667 m .53315 .47237 L .52359 .46782 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52253 .46732 L p
1 g
F P
s
P
p
.002 w
.52145 .46701 m .52192 .46703 L p
.52253 .46732 L 1 g
F P
s
P
p
.002 w
.52359 .46782 m .52212 .46727 L p
.52253 .46732 L 1 g
F P
s
P
p
.002 w
.52212 .46727 m .52145 .46701 L p
.52253 .46732 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52253 .46732 L p
.52252 .46732 L 1 g
F P
s
P
p
.5 .4634 m .52253 .46732 L .52252 .46732 L 1 g
F
P
p
.002 w
.52253 .46732 m .52253 .46732 L p
.52359 .46782 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52214 .46667 L p
.52359 .46782 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.55764 .46801 m .55486 .47965 L .52359 .46782 L p
1 g
F P
s
P
p
.002 w
.52192 .46703 m .55764 .46801 L p
.52359 .46782 L 1 g
F P
s
P
p
.53936 .47384 m .54052 .47587 L .52463 .46832 L 1 g
F
P
p
.54052 .47587 m .54845 .48984 L .52463 .46832 L 1 g
F
P
p
.002 w
.52212 .46727 m .55486 .47965 L p
.52168 .46721 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52253 .46732 L p
1 g
F P
s
P
p
.53315 .47237 m .54302 .47747 L .52253 .46732 L 1 g
F
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.53315 .47237 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54281 .47725 L p
1 g
F P
s
P
p
.55198 .4861 m .55834 .49233 L .54281 .47725 L 1 g
F
P
p
.55198 .4861 m .55791 .49188 L .5527 .48681 L 1 g
F
P
p
.55395 .48801 m .55791 .49188 L .55198 .4861 L 1 g
F
P
p
.002 w
.55744 .49138 m .55791 .49188 L p
.55395 .48801 L 1 g
F P
s
P
p
.56208 .50096 m .56215 .50111 L .56209 .50098 L 1 g
F
P
p
.56613 .50943 m .55524 .5254 L .56511 .50729 L 1 g
F
P
p
.002 w
.56856 .51451 m .56678 .51597 L p
.56613 .50943 L 1 g
F P
s
P
p
.002 w
.56678 .51597 m .55524 .5254 L p
.56613 .50943 L 1 g
F P
s
P
p
.002 w
.56812 .52964 m .56854 .53025 L p
.56754 .52379 L 1 g
F P
s
P
p
.002 w
.55524 .5254 m .56678 .51597 L p
.56726 .52622 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56613 .50943 L p
1 g
F P
s
P
p
.56754 .52379 m .56854 .53025 L .56613 .50943 L 1 g
F
P
p
.002 w
.56613 .50943 m .56713 .51061 L p
.56209 .50098 L 1 g
F P
s
P
p
.002 w
.55524 .5254 m .5391 .4975 L p
.56511 .50729 L 1 g
F P
s
P
p
.002 w
.55791 .49188 m .55834 .49233 L p
.5527 .48681 L 1 g
F P
s
P
p
.002 w
.55486 .47965 m .55124 .4854 L p
.53936 .47384 L 1 g
F P
s
P
p
.002 w
.52168 .46721 m .52145 .46701 L .52212 .46727 L p
1 g
F P
s
P
p
.002 w
.52253 .46732 m .52253 .46732 L p
.52249 .46731 L 1 g
F P
s
P
p
.5 .4634 m .52253 .46732 L .52249 .46731 L 1 g
F
P
p
.002 w
.52253 .46732 m .52255 .46736 L p
.5219 .46724 L 1 g
F P
s
P
p
.5 .4634 m .52253 .46732 L .5219 .46724 L 1 g
F
P
p
.002 w
.54845 .48984 m .5391 .4975 L .52155 .4672 L p
1 g
F P
s
P
p
.002 w
.52155 .4672 m .52145 .46701 L .52168 .46721 L p
1 g
F P
s
P
p
.002 w
.52168 .46721 m .54845 .48984 L p
.52155 .4672 L 1 g
F P
s
P
p
.5 .4634 m .52193 .46725 L .51258 .46582 L 1 g
F
P
p
.002 w
.5278 .5018 m .51578 .5023 L .52142 .46718 L p
1 g
F P
s
P
p
.002 w
.52142 .46718 m .52145 .46701 L .52148 .46719 L p
1 g
F P
s
P
p
.002 w
.52148 .46719 m .5278 .5018 L p
.52142 .46718 L 1 g
F P
s
P
p
.002 w
.51578 .5023 m .5043 .49892 L .52136 .46717 L p
1 g
F P
s
P
p
.002 w
.52136 .46717 m .52145 .46701 L .52142 .46718 L p
1 g
F P
s
P
p
.002 w
.52142 .46718 m .51578 .5023 L p
.52136 .46717 L 1 g
F P
s
P
p
.002 w
.5043 .49892 m .49462 .49201 L .52129 .46716 L p
1 g
F P
s
P
p
.002 w
.52129 .46716 m .52145 .46701 L .52136 .46717 L p
1 g
F P
s
P
p
.002 w
.52136 .46717 m .5043 .49892 L p
.52129 .46716 L 1 g
F P
s
P
p
.52142 .46718 m .52255 .46736 L .52133 .46717 L 1 g
F
P
p
.52145 .46718 m .52149 .46719 L .52142 .46718 L 1 g
F
P
p
.52149 .46719 m .52255 .46736 L .52142 .46718 L 1 g
F
P
p
.52148 .46719 m .5215 .46719 L .52145 .46718 L 1 g
F
P
p
.5215 .46719 m .52255 .46736 L .52145 .46718 L 1 g
F
P
p
.52193 .46725 m .52199 .46726 L .52148 .46719 L 1 g
F
P
p
.52199 .46726 m .52255 .46736 L .52148 .46719 L 1 g
F
P
p
.002 w
.49462 .49201 m .48778 .48232 L .52117 .46714 L p
1 g
F P
s
P
p
.002 w
.52117 .46714 m .52145 .46701 L .52129 .46716 L p
1 g
F P
s
P
p
.002 w
.52129 .46716 m .49462 .49201 L p
.52117 .46714 L 1 g
F P
s
P
p
.52193 .46725 m .52139 .46718 L .51258 .46582 L 1 g
F
P
p
.52139 .46718 m .52133 .46717 L .52105 .46712 L 1 g
F
P
p
.002 w
.48778 .48232 m .48454 .47087 L .52078 .46708 L p
1 g
F P
s
P
p
.002 w
.52078 .46708 m .52145 .46701 L .52117 .46714 L p
1 g
F P
s
P
p
.002 w
.52117 .46714 m .48778 .48232 L p
.52078 .46708 L 1 g
F P
s
P
p
.52139 .46718 m .52117 .46714 L .51258 .46582 L 1 g
F
P
p
.52117 .46714 m .52105 .46712 L .52078 .46708 L 1 g
F
P
p
.52117 .46714 m .52078 .46708 L .51258 .46582 L 1 g
F
P
p
.002 w
.5391 .4975 m .5278 .5018 L .52148 .46719 L p
1 g
F P
s
P
p
.002 w
.52148 .46719 m .52145 .46701 L .52155 .4672 L p
1 g
F P
s
P
p
.002 w
.52155 .4672 m .5391 .4975 L p
.52148 .46719 L 1 g
F P
s
P
p
.002 w
.50438 .46319 m .52145 .46701 L p
.52017 .46699 L 1 g
F P
s
P
p
.48482 .46628 m .5 .46388 L .52017 .46699 L 1 g
F
P
p
.002 w
.48454 .47087 m .48482 .46628 L p
.52017 .46699 L 1 g
F P
s
P
p
.002 w
.52078 .46708 m .48454 .47087 L p
.52017 .46699 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51258 .46582 L 1 g
F P
s
P
p
.51258 .46582 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.002 w
.52145 .46701 m .52078 .46708 L p
.52017 .46699 L 1 g
F P
s
P
p
.5 .46388 m .50438 .46319 L .52017 .46699 L 1 g
F
P
p
.002 w
.52255 .46736 m .52282 .46778 L p
.51258 .46582 L 1 g
F P
s
P
p
.49047 .46539 m .4963 .46479 L .48482 .46628 L 1 g
F
P
p
.49047 .46539 m .48482 .46628 L .47752 .46723 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46431 L p
1 g
F P
s
P
p
.002 w
.5 .46431 m .5 .46442 L p
.4963 .46479 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46431 L .4963 .46479 L 1 g
F
P
p
.46804 .47179 m .46744 .47208 L .45765 .47675 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .46729 L p
1 g
F P
s
P
p
.002 w
.47748 .46729 m .47718 .46778 L p
.46811 .47176 L 1 g
F P
s
P
p
.45826 .47608 m .47748 .46729 L .46811 .47176 L 1 g
F
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45474 .4959 m .4373 .50226 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45734 .47708 L p
1 g
F P
s
P
p
.44339 .4905 m .45734 .47708 L .45159 .48265 L 1 g
F
P
p
.45137 .48285 m .45107 .48315 L .44266 .49128 L 1 g
F
P
p
.002 w
.44942 .47743 m .45107 .48315 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.45107 .48315 m .45474 .4959 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.45734 .47708 m .45698 .47747 L p
.45159 .48265 L 1 g
F P
s
P
p
.002 w
.44827 .47344 m .46205 .47247 L p
.45765 .47675 L 1 g
F P
s
P
p
.002 w
.45107 .48315 m .45024 .48028 L p
.45765 .47675 L 1 g
F P
s
P
p
.002 w
.45024 .48028 m .44827 .47344 L p
.45765 .47675 L 1 g
F P
s
P
p
.002 w
.46744 .47208 m .44827 .47344 L p
.46592 .46873 L 1 g
F P
s
P
p
.46592 .46873 m .48498 .46364 L .47752 .46723 L 1 g
F
P
p
.46592 .46873 m .47752 .46723 L .46744 .47208 L 1 g
F
P
p
.002 w
.48482 .46628 m .48527 .4589 L .50438 .46319 L p
1 g
F P
s
P
p
.002 w
.48498 .46364 m .48482 .46628 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.48482 .46628 m .48454 .47087 L p
.47752 .46723 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46723 L p
1 g
F P
s
P
p
.4963 .46479 m .5 .46442 L .47752 .46723 L 1 g
F
P
p
.46804 .47179 m .46811 .47176 L .46744 .47208 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48527 .4589 m .48498 .46364 L p
.44827 .47344 L 1 g
F P
s
P
p
.002 w
.46205 .47247 m .46744 .47208 L p
.45765 .47675 L 1 g
F P
s
P
p
.002 w
.46744 .47208 m .48454 .47087 L p
.45765 .47675 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47675 L p
1 g
F P
s
P
p
.46811 .47176 m .47718 .46778 L .45765 .47675 L 1 g
F
P
p
.45137 .48285 m .45159 .48265 L .45107 .48315 L 1 g
F
P
p
.002 w
.45474 .4959 m .45107 .48315 L p
.48454 .47087 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44266 .49128 L p
1 g
F P
s
P
p
.45159 .48265 m .45698 .47747 L .44266 .49128 L 1 g
F
P
p
.43826 .50029 m .43855 .49961 L .4373 .50226 L 1 g
F
P
p
.002 w
.44827 .47344 m .44942 .47743 L p
.42357 .50727 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43396 .50931 L p
1 g
F P
s
P
p
.43855 .49961 m .44166 .49233 L .43396 .50931 L 1 g
F
P
p
.43316 .5187 m .43313 .51786 L .43301 .5204 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44328 .5347 m .43301 .5204 L p
.45474 .4959 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43264 .52853 L p
1 g
F P
s
P
p
.43313 .51786 m .43287 .51061 L .43264 .52853 L 1 g
F
P
p
.43529 .53783 m .43441 .53609 L .43591 .53999 L 1 g
F
P
p
.002 w
.42357 .50727 m .42855 .51419 L p
.42066 .55092 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43857 .54694 L p
1 g
F P
s
P
p
.43441 .53609 m .43146 .53025 L .43857 .54694 L 1 g
F
P
p
.45095 .56266 m .44199 .55586 L .43857 .54694 L 1 g
F
P
p
.002 w
.43857 .54694 m .43743 .5491 L p
.44643 .55692 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45095 .56266 L p
1 g
F P
s
P
p
.44643 .55692 m .43743 .5491 L .45095 .56266 L 1 g
F
P
p
.002 w
.45095 .56266 m .45042 .5641 L p
.45674 .56705 L 1 g
F P
s
P
p
.002 w
.45591 .57549 m .42066 .55092 L .42828 .54546 L p
1 g
F P
s
P
p
.46872 .57265 m .45042 .5641 L .45778 .56828 L 1 g
F
P
p
.48774 .57995 m .46836 .57429 L .47092 .5541 L 1 g
F
P
p
.002 w
.45873 .57147 m .46006 .56957 L p
.46836 .57429 L 1 g
F P
s
P
p
.002 w
.46006 .56957 m .47092 .5541 L p
.46836 .57429 L 1 g
F P
s
P
p
.002 w
.45042 .5641 m .45002 .56518 L p
.45778 .56828 L 1 g
F P
s
P
p
.002 w
.44328 .5347 m .47092 .5541 L .46006 .56957 L p
1 g
F P
s
P
p
.45224 .56364 m .44328 .5347 L .46006 .56957 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46836 .57429 L p
1 g
F P
s
P
p
.45778 .56828 m .45002 .56518 L .46836 .57429 L 1 g
F
P
p
.48774 .57995 m .47525 .5782 L .46836 .57429 L 1 g
F
P
p
.002 w
.46836 .57429 m .4678 .57686 L p
.48084 .57793 L 1 g
F P
s
P
p
.002 w
.46782 .57889 m .45591 .57549 L p
.49192 .58053 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58034 L p
1 g
F P
s
P
p
.48084 .57793 m .4678 .57686 L .48908 .58034 L 1 g
F
P
p
.002 w
.48908 .58034 m .48889 .583 L p
.49886 .58101 L 1 g
F P
s
P
p
.002 w
.47092 .5541 m .50347 .56348 L .49894 .58101 L p
1 g
F P
s
P
p
.49192 .58053 m .47092 .5541 L .49894 .58101 L 1 g
F
P
p
.002 w
.49894 .58101 m .50347 .56348 L p
.52951 .57885 L 1 g
F P
s
P
p
.54047 .58532 m .49894 .58101 L .52951 .57885 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58017 L p
1 g
F P
s
P
p
.49877 .58102 m .48889 .583 L .51091 .58017 L 1 g
F
P
p
.002 w
.51091 .58017 m .51111 .583 L p
.52388 .57645 L 1 g
F P
s
P
p
.53162 .57423 m .50347 .56348 L .53855 .57041 L 1 g
F
P
p
.52648 .57706 m .52493 .57615 L .53162 .57423 L 1 g
F
P
p
.52493 .57615 m .50347 .56348 L .53162 .57423 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53162 .57423 L p
1 g
F P
s
P
p
.52388 .57645 m .51111 .583 L .53162 .57423 L 1 g
F
P
p
.002 w
.50347 .56348 m .53746 .56196 L .53855 .57041 L p
1 g
F P
s
P
p
.002 w
.53162 .57423 m .53184 .57522 L p
.53578 .57194 L 1 g
F P
s
P
p
.002 w
.53184 .57522 m .5322 .57686 L p
.54027 .56917 L 1 g
F P
s
P
p
.002 w
.56932 .54975 m .59575 .52817 L .61447 .54243 L p
1 g
F P
s
P
p
.002 w
.63766 .50597 m .61447 .54243 L .59575 .52817 L p
1 g
F P
s
P
p
.002 w
.56254 .30339 m .51072 .29619 L .50742 .27232 L p
1 g
F P
s
P
p
.002 w
.44941 .28369 m .50742 .27232 L .51072 .29619 L p
1 g
F P
s
P
p
.002 w
.64422 .42136 m .62653 .38212 L .64371 .3641 L p
1 g
F P
s
P
p
.002 w
.60853 .32699 m .64371 .3641 L .62653 .38212 L p
1 g
F P
s
P
p
.002 w
.41309 .33295 m .37846 .37282 L .35933 .35811 L p
1 g
F P
s
P
p
.002 w
.35933 .35811 m .39807 .31343 L .41309 .33295 L p
1 g
F P
s
P
p
.002 w
.38311 .47451 m .39542 .51605 L .37119 .52202 L p
1 g
F P
s
P
p
.002 w
.37119 .52202 m .3565 .47303 L .38311 .47451 L p
1 g
F P
s
P
p
.002 w
.59575 .52817 m .61398 .49943 L .63766 .50597 L p
1 g
F P
s
P
p
.002 w
.64799 .46416 m .63766 .50597 L .61398 .49943 L p
1 g
F P
s
P
p
.002 w
.51072 .29619 m .45893 .3064 L .44941 .28369 L p
1 g
F P
s
P
p
.002 w
.39807 .31343 m .44941 .28369 L .45893 .3064 L p
1 g
F P
s
P
p
.002 w
.45893 .3064 m .41309 .33295 L .39807 .31343 L p
1 g
F P
s
P
p
.002 w
.61398 .49943 m .62202 .46652 L .64799 .46416 L p
1 g
F P
s
P
p
.002 w
.64422 .42136 m .64799 .46416 L .62202 .46652 L p
1 g
F P
s
P
p
.002 w
.62653 .38212 m .59664 .35078 L .60853 .32699 L p
1 g
F P
s
P
p
.002 w
.56254 .30339 m .60853 .32699 L .59664 .35078 L p
1 g
F P
s
P
p
.002 w
.38528 .43078 m .38311 .47451 L .3565 .47303 L p
1 g
F P
s
P
p
.002 w
.3565 .47303 m .35892 .42137 L .38528 .43078 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.62202 .46652 m .61895 .4329 L .64422 .42136 L p
1 g
F P
s
P
p
.002 w
.62653 .38212 m .64422 .42136 L .61895 .4329 L p
1 g
F P
s
P
p
.002 w
.42066 .55092 m .39542 .51605 L .42357 .50727 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.59664 .35078 m .55765 .33091 L .56254 .30339 L p
1 g
F P
s
P
p
.002 w
.51072 .29619 m .56254 .30339 L .55765 .33091 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4019 .38974 m .38528 .43078 L .35892 .42137 L p
1 g
F P
s
P
p
.002 w
.35892 .42137 m .37846 .37282 L .4019 .38974 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.61398 .49943 m .59575 .52817 L .57351 .51046 L p
1 g
F P
s
P
p
.002 w
.5097 .53484 m .5332 .53383 L .53746 .56196 L p
1 g
F P
s
P
p
.002 w
.53746 .56196 m .50347 .56348 L .5097 .53484 L p
1 g
F P
s
P
p
.002 w
.61895 .4329 m .60496 .40215 L .62653 .38212 L p
1 g
F P
s
P
p
.002 w
.59664 .35078 m .62653 .38212 L .60496 .40215 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.41404 .47466 m .42357 .50727 L .39542 .51605 L p
1 g
F P
s
P
p
.002 w
.39542 .51605 m .38311 .47451 L .41404 .47466 L p
1 g
F P
s
P
p
.002 w
.55765 .33091 m .5138 .32491 L .51072 .29619 L p
1 g
F P
s
P
p
.002 w
.45893 .3064 m .51072 .29619 L .5138 .32491 L p
1 g
F P
s
P
p
.002 w
.43123 .35606 m .4019 .38974 L .37846 .37282 L p
1 g
F P
s
P
p
.002 w
.37846 .37282 m .41309 .33295 L .43123 .35606 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.57351 .51046 m .58608 .49057 L .61398 .49943 L p
1 g
F P
s
P
p
.002 w
.62202 .46652 m .61398 .49943 L .58608 .49057 L p
1 g
F P
s
P
p
.002 w
.48725 .5283 m .5097 .53484 L .50347 .56348 L p
1 g
F P
s
P
p
.002 w
.50347 .56348 m .47092 .5541 L .48725 .5283 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.5138 .32491 m .47 .3336 L .45893 .3064 L p
1 g
F P
s
P
p
.002 w
.41309 .33295 m .45893 .3064 L .47 .3336 L p
1 g
F P
s
P
p
.002 w
.47 .3336 m .43123 .35606 L .41309 .33295 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.58608 .49057 m .59157 .46783 L .62202 .46652 L p
1 g
F P
s
P
p
.002 w
.61895 .4329 m .62202 .46652 L .59157 .46783 L p
1 g
F P
s
P
p
.002 w
.46823 .51485 m .48725 .5283 L .47092 .5541 L p
1 g
F P
s
P
p
.002 w
.47092 .5541 m .44328 .5347 L .46823 .51485 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.60496 .40215 m .58144 .37766 L .59664 .35078 L p
1 g
F P
s
P
p
.002 w
.55765 .33091 m .59664 .35078 L .58144 .37766 L p
1 g
F P
s
P
p
.002 w
.41586 .44042 m .41404 .47466 L .38311 .47451 L p
1 g
F P
s
P
p
.002 w
.38311 .47451 m .38528 .43078 L .41586 .44042 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.59157 .46783 m .58937 .44465 L .61895 .4329 L p
1 g
F P
s
P
p
.002 w
.60496 .40215 m .61895 .4329 L .58937 .44465 L p
1 g
F P
s
P
p
.002 w
.45474 .4959 m .46823 .51485 L .44328 .5347 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.58144 .37766 m .55084 .36221 L .55765 .33091 L p
1 g
F P
s
P
p
.002 w
.5138 .32491 m .55765 .33091 L .55084 .36221 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42895 .40833 m .41586 .44042 L .38528 .43078 L p
1 g
F P
s
P
p
.002 w
.38528 .43078 m .4019 .38974 L .42895 .40833 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.5278 .5018 m .5391 .4975 L .55524 .5254 L p
1 g
F P
s
P
p
.002 w
.55524 .5254 m .5332 .53383 L .5278 .5018 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.58937 .44465 m .57965 .42351 L .60496 .40215 L p
1 g
F P
s
P
p
.002 w
.58144 .37766 m .60496 .40215 L .57965 .42351 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.51578 .5023 m .5278 .5018 L .5332 .53383 L p
1 g
F P
s
P
p
.002 w
.5332 .53383 m .5097 .53484 L .51578 .5023 L p
1 g
F P
s
P
p
.002 w
.42357 .50727 m .41404 .47466 L .44827 .47344 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.55084 .36221 m .51651 .3576 L .5138 .32491 L p
1 g
F P
s
P
p
.002 w
.47 .3336 m .5138 .32491 L .51651 .3576 L p
1 g
F P
s
P
p
.002 w
.45193 .38201 m .42895 .40833 L .4019 .38974 L p
1 g
F P
s
P
p
.002 w
.4019 .38974 m .43123 .35606 L .45193 .38201 L p
1 g
F P
s
P
p
.002 w
.59157 .46783 m .58608 .49057 L .55486 .47965 L p
1 g
F P
s
P
p
.002 w
.5043 .49892 m .51578 .5023 L .5097 .53484 L p
1 g
F P
s
P
p
.002 w
.5097 .53484 m .48725 .5283 L .5043 .49892 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51651 .3576 m .48225 .36444 L .47 .3336 L p
1 g
F P
s
P
p
.002 w
.43123 .35606 m .47 .3336 L .48225 .36444 L p
1 g
F P
s
P
p
.002 w
.48225 .36444 m .45193 .38201 L .43123 .35606 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55486 .47965 m .55764 .46801 L .59157 .46783 L p
1 g
F P
s
P
p
.002 w
.58937 .44465 m .59157 .46783 L .55764 .46801 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.49462 .49201 m .5043 .49892 L .48725 .5283 L p
1 g
F P
s
P
p
.002 w
.48725 .5283 m .46823 .51485 L .49462 .49201 L p
1 g
F P
s
P
p
.002 w
.57965 .42351 m .56339 .40673 L .58144 .37766 L p
1 g
F P
s
P
p
.002 w
.55084 .36221 m .58144 .37766 L .56339 .40673 L p
1 g
F P
s
P
p
.002 w
.44961 .44992 m .44827 .47344 L .41404 .47466 L p
1 g
F P
s
P
p
.002 w
.41404 .47466 m .41586 .44042 L .44961 .44992 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.55764 .46801 m .55646 .45617 L .58937 .44465 L p
1 g
F P
s
P
p
.002 w
.57965 .42351 m .58937 .44465 L .55646 .45617 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.48778 .48232 m .49462 .49201 L .46823 .51485 L p
1 g
F P
s
P
p
.002 w
.46823 .51485 m .45474 .4959 L .48778 .48232 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56339 .40673 m .54233 .39619 L .55084 .36221 L p
1 g
F P
s
P
p
.002 w
.51651 .3576 m .55084 .36221 L .54233 .39619 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.45865 .42791 m .44961 .44992 L .41586 .44042 L p
1 g
F P
s
P
p
.002 w
.41586 .44042 m .42895 .40833 L .45865 .42791 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55646 .45617 m .55146 .44542 L .57965 .42351 L p
1 g
F P
s
P
p
.002 w
.56339 .40673 m .57965 .42351 L .55146 .44542 L p
1 g
F P
s
P
p
.002 w
.48454 .47087 m .48778 .48232 L .45474 .4959 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54233 .39619 m .51875 .39309 L .51651 .3576 L p
1 g
F P
s
P
p
.002 w
.48225 .36444 m .51651 .3576 L .51875 .39309 L p
1 g
F P
s
P
p
.002 w
.47445 .40988 m .45865 .42791 L .42895 .40833 L p
1 g
F P
s
P
p
.002 w
.42895 .40833 m .45193 .38201 L .47445 .40988 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55646 .45617 m .55764 .46801 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.51875 .39309 m .49525 .39782 L .48225 .36444 L p
1 g
F P
s
P
p
.002 w
.45193 .38201 m .48225 .36444 L .49525 .39782 L p
1 g
F P
s
P
p
.002 w
.49525 .39782 m .47445 .40988 L .45193 .38201 L p
1 g
F P
s
P
p
.002 w
.55146 .44542 m .54314 .43691 L .56339 .40673 L p
1 g
F P
s
P
p
.002 w
.54233 .39619 m .56339 .40673 L .54314 .43691 L p
1 g
F P
s
P
p
.002 w
.44827 .47344 m .44961 .44992 L .48527 .4589 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.55146 .44542 m .55646 .45617 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54314 .43691 m .53241 .43159 L .54233 .39619 L p
1 g
F P
s
P
p
.002 w
.51875 .39309 m .54233 .39619 L .53241 .43159 L p
1 g
F P
s
P
p
.002 w
.48989 .44773 m .48527 .4589 L .44961 .44992 L p
1 g
F P
s
P
p
.002 w
.44961 .44992 m .45865 .42791 L .48989 .44773 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54314 .43691 m .55146 .44542 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53241 .43159 m .54314 .43691 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.52042 .43005 m .53241 .43159 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.50849 .43247 m .52042 .43005 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.49793 .43859 m .50849 .43247 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50301 .43564 L
s
P
p
.002 w
.48989 .44773 m .49793 .43859 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.48527 .4589 m .48989 .44773 L .52145 .46701 L closepath p
1 g
F P
s
P
p
.002 w
.53241 .43159 m .52042 .43005 L .51875 .39309 L p
1 g
F P
s
P
p
.002 w
.49525 .39782 m .51875 .39309 L .52042 .43005 L p
1 g
F P
s
P
p
.002 w
.49793 .43859 m .48989 .44773 L .45865 .42791 L p
1 g
F P
s
P
p
.002 w
.45865 .42791 m .47445 .40988 L .49793 .43859 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52042 .43005 m .50849 .43247 L .49525 .39782 L p
1 g
F P
s
P
p
.002 w
.47445 .40988 m .49525 .39782 L .50849 .43247 L p
1 g
F P
s
P
p
.002 w
.50849 .43247 m .49793 .43859 L .47445 .40988 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.52145 .46701 m
.53475 .48965 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .53573 .71689 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .53475 .48965 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.244186)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.244186)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49341 .46597 m .51611 .45117 L .49701 .42997 L p
1 g
F P
s
P
p
.002 w
.49701 .42997 m .48154 .44004 L .49341 .46597 L p
1 g
F P
s
P
p
.002 w
.50866 .41563 m .49701 .42997 L .51611 .45117 L p
1 g
F P
s
P
p
.002 w
.48154 .44004 m .49701 .42997 L .47797 .40878 L p
1 g
F P
s
P
p
.002 w
.49701 .42997 m .50866 .41563 L .48388 .4015 L p
1 g
F P
s
P
p
.002 w
.48388 .4015 m .47797 .40878 L .49701 .42997 L p
1 g
F P
s
P
p
.002 w
.51611 .45117 m .53322 .43013 L .50866 .41563 L p
1 g
F P
s
P
p
.002 w
.51526 .39851 m .50866 .41563 L .53322 .43013 L p
1 g
F P
s
P
p
.002 w
.50866 .41563 m .51526 .39851 L .48721 .3928 L p
1 g
F P
s
P
p
.002 w
.48721 .3928 m .48388 .4015 L .50866 .41563 L p
1 g
F P
s
P
p
.002 w
.46745 .47301 m .49341 .46597 L .48154 .44004 L p
1 g
F P
s
P
p
.002 w
.48154 .44004 m .46385 .44477 L .46745 .47301 L p
1 g
F P
s
P
p
.002 w
.46385 .44477 m .48154 .44004 L .47011 .41389 L p
1 g
F P
s
P
p
.002 w
.47797 .40878 m .47011 .41389 L .48154 .44004 L p
1 g
F P
s
P
p
.002 w
.50552 .49122 m .53493 .47198 L .51611 .45117 L p
1 g
F P
s
P
p
.002 w
.51611 .45117 m .49341 .46597 L .50552 .49122 L p
1 g
F P
s
P
p
.002 w
.53322 .43013 m .51611 .45117 L .53493 .47198 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .47011 .41389 L .47797 .40878 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .47797 .40878 L .48388 .4015 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .48388 .4015 L .48721 .3928 L closepath p
1 g
F P
s
P
p
.002 w
.53493 .47198 m .55714 .44473 L .53322 .43013 L p
1 g
F P
s
P
p
.002 w
.54299 .40501 m .53322 .43013 L .55714 .44473 L p
1 g
F P
s
P
p
.002 w
.53322 .43013 m .54299 .40501 L .51526 .39851 L p
1 g
F P
s
P
p
.002 w
.47011 .41389 m .46113 .41626 L .46385 .44477 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .46113 .41626 L .47011 .41389 L closepath p
1 g
F P
s
P
p
.002 w
.51609 .3804 m .51526 .39851 L .54299 .40501 L p
1 g
F P
s
P
p
.002 w
.51526 .39851 m .51609 .3804 L .48758 .38361 L p
1 g
F P
s
P
p
.002 w
.48758 .38361 m .48721 .3928 L .51526 .39851 L p
1 g
F P
s
P
p
.002 w
.47187 .50045 m .50552 .49122 L .49341 .46597 L p
1 g
F P
s
P
p
.002 w
.49341 .46597 m .46745 .47301 L .47187 .50045 L p
1 g
F P
s
P
p
.002 w
.44089 .47147 m .46745 .47301 L .46385 .44477 L p
1 g
F P
s
P
p
.002 w
.46385 .44477 m .44579 .44364 L .44089 .47147 L p
1 g
F P
s
P
p
.002 w
.44579 .44364 m .46385 .44477 L .46113 .41626 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .48721 .3928 L .48758 .38361 L closepath p
1 g
F P
s
P
p
.002 w
.46113 .41626 m .45198 .41564 L .44579 .44364 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .45198 .41564 L .46113 .41626 L closepath p
1 g
F P
s
P
p
.002 w
.48496 .37493 m .48758 .38361 L .51609 .3804 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .48758 .38361 L .48496 .37493 L closepath p
1 g
F P
s
P
p
.002 w
.55714 .44473 m .5699 .41219 L .54299 .40501 L p
1 g
F P
s
P
p
.002 w
.54433 .37839 m .54299 .40501 L .5699 .41219 L p
1 g
F P
s
P
p
.002 w
.54299 .40501 m .54433 .37839 L .51609 .3804 L p
1 g
F P
s
P
p
.002 w
.42928 .4367 m .44579 .44364 L .45198 .41564 L p
1 g
F P
s
P
p
.002 w
.45198 .41564 m .44365 .41208 L .42928 .4367 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .44365 .41208 L .45198 .41564 L closepath p
1 g
F P
s
P
p
.002 w
.51101 .3632 m .51609 .3804 L .54433 .37839 L p
1 g
F P
s
P
p
.002 w
.51609 .3804 m .51101 .3632 L .48496 .37493 L p
1 g
F P
s
P
p
.002 w
.43738 .49862 m .47187 .50045 L .46745 .47301 L p
1 g
F P
s
P
p
.002 w
.46745 .47301 m .44089 .47147 L .43738 .49862 L p
1 g
F P
s
P
p
.002 w
.51765 .51529 m .55312 .49203 L .53493 .47198 L p
1 g
F P
s
P
p
.002 w
.53493 .47198 m .50552 .49122 L .51765 .51529 L p
1 g
F P
s
P
p
.002 w
.55714 .44473 m .53493 .47198 L .55312 .49203 L p
1 g
F P
s
P
p
.002 w
.41652 .46141 m .44089 .47147 L .44579 .44364 L p
1 g
F P
s
P
p
.002 w
.44579 .44364 m .42928 .4367 L .41652 .46141 L p
1 g
F P
s
P
p
.002 w
.4796 .36767 m .48496 .37493 L .51101 .3632 L p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .48496 .37493 L .4796 .36767 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .4796 .36767 L .47208 .36265 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .47208 .36265 L .46319 .36042 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .46319 .36042 L .4539 .36124 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .4539 .36124 L .44525 .36504 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .44525 .36504 L .43818 .37139 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .43818 .37139 L .43347 .37961 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .43347 .37961 L .43164 .38878 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .43164 .38878 L .43288 .39789 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .43288 .39789 L .43704 .40594 L closepath p
1 g
F P
s
P
p
.002 w
.45934 .38797 m .43704 .40594 L .44365 .41208 L closepath p
1 g
F P
s
P
p
.002 w
.55312 .49203 m .57996 .45916 L .55714 .44473 L p
1 g
F P
s
P
p
.002 w
.5699 .41219 m .55714 .44473 L .57996 .45916 L p
1 g
F P
s
P
p
.002 w
.41612 .42465 m .42928 .4367 L .44365 .41208 L p
1 g
F P
s
P
p
.002 w
.44365 .41208 m .43704 .40594 L .41612 .42465 L p
1 g
F P
s
P
p
.002 w
.47706 .52657 m .51765 .51529 L .50552 .49122 L p
1 g
F P
s
P
p
.002 w
.50552 .49122 m .47187 .50045 L .47706 .52657 L p
1 g
F P
s
P
p
.002 w
.51101 .3632 m .5005 .34877 L .4796 .36767 L p
1 g
F P
s
P
p
.002 w
.47208 .36265 m .4796 .36767 L .5005 .34877 L p
1 g
F P
s
P
p
.002 w
.40776 .40872 m .41612 .42465 L .43704 .40594 L p
1 g
F P
s
P
p
.002 w
.43704 .40594 m .43288 .39789 L .40776 .40872 L p
1 g
F P
s
P
p
.002 w
.54433 .37839 m .537 .35302 L .51101 .3632 L p
1 g
F P
s
P
p
.002 w
.5005 .34877 m .51101 .3632 L .537 .35302 L p
1 g
F P
s
P
p
.002 w
.5699 .41219 m .5718 .37763 L .54433 .37839 L p
1 g
F P
s
P
p
.002 w
.537 .35302 m .54433 .37839 L .5718 .37763 L p
1 g
F P
s
P
p
.002 w
.39698 .44375 m .41652 .46141 L .42928 .4367 L p
1 g
F P
s
P
p
.002 w
.42928 .4367 m .41612 .42465 L .39698 .44375 L p
1 g
F P
s
P
p
.002 w
.40562 .48572 m .43738 .49862 L .44089 .47147 L p
1 g
F P
s
P
p
.002 w
.44089 .47147 m .41652 .46141 L .40562 .48572 L p
1 g
F P
s
P
p
.002 w
.57996 .45916 m .59547 .41991 L .5699 .41219 L p
1 g
F P
s
P
p
.002 w
.5718 .37763 m .5699 .41219 L .59547 .41991 L p
1 g
F P
s
P
p
.002 w
.5005 .34877 m .48563 .33872 L .47208 .36265 L p
1 g
F P
s
P
p
.002 w
.46319 .36042 m .47208 .36265 L .48563 .33872 L p
1 g
F P
s
P
p
.002 w
.4052 .39062 m .40776 .40872 L .43288 .39789 L p
1 g
F P
s
P
p
.002 w
.43288 .39789 m .43164 .38878 L .4052 .39062 L p
1 g
F P
s
P
p
.002 w
.43536 .52455 m .47706 .52657 L .47187 .50045 L p
1 g
F P
s
P
p
.002 w
.47187 .50045 m .43738 .49862 L .43536 .52455 L p
1 g
F P
s
P
p
.002 w
.48563 .33872 m .46799 .33419 L .46319 .36042 L p
1 g
F P
s
P
p
.002 w
.4539 .36124 m .46319 .36042 L .46799 .33419 L p
1 g
F P
s
P
p
.002 w
.40878 .37236 m .4052 .39062 L .43164 .38878 L p
1 g
F P
s
P
p
.002 w
.43164 .38878 m .43347 .37961 L .40878 .37236 L p
1 g
F P
s
P
p
.002 w
.52958 .53773 m .57033 .51093 L .55312 .49203 L p
1 g
F P
s
P
p
.002 w
.55312 .49203 m .51765 .51529 L .52958 .53773 L p
1 g
F P
s
P
p
.002 w
.57996 .45916 m .55312 .49203 L .57033 .51093 L p
1 g
F P
s
P
p
.002 w
.537 .35302 m .52164 .33164 L .5005 .34877 L p
1 g
F P
s
P
p
.002 w
.48563 .33872 m .5005 .34877 L .52164 .33164 L p
1 g
F P
s
P
p
.002 w
.46799 .33419 m .44951 .33576 L .4539 .36124 L p
1 g
F P
s
P
p
.002 w
.44525 .36504 m .4539 .36124 L .44951 .33576 L p
1 g
F P
s
P
p
.002 w
.41814 .35596 m .40878 .37236 L .43347 .37961 L p
1 g
F P
s
P
p
.002 w
.43347 .37961 m .43818 .37139 L .41814 .35596 L p
1 g
F P
s
P
p
.002 w
.3845 .42028 m .39698 .44375 L .41612 .42465 L p
1 g
F P
s
P
p
.002 w
.41612 .42465 m .40776 .40872 L .3845 .42028 L p
1 g
F P
s
P
p
.002 w
.57033 .51093 m .60122 .47315 L .57996 .45916 L p
1 g
F P
s
P
p
.002 w
.59547 .41991 m .57996 .45916 L .60122 .47315 L p
1 g
F P
s
P
p
.002 w
.44951 .33576 m .43224 .34329 L .44525 .36504 L p
1 g
F P
s
P
p
.002 w
.43818 .37139 m .44525 .36504 L .43224 .34329 L p
1 g
F P
s
P
p
.002 w
.43224 .34329 m .41814 .35596 L .43818 .37139 L p
1 g
F P
s
P
p
.002 w
.5718 .37763 m .56246 .34461 L .537 .35302 L p
1 g
F P
s
P
p
.002 w
.52164 .33164 m .537 .35302 L .56246 .34461 L p
1 g
F P
s
P
p
.002 w
.48292 .55083 m .52958 .53773 L .51765 .51529 L p
1 g
F P
s
P
p
.002 w
.51765 .51529 m .47706 .52657 L .48292 .55083 L p
1 g
F P
s
P
p
.002 w
.38004 .46288 m .40562 .48572 L .41652 .46141 L p
1 g
F P
s
P
p
.002 w
.41652 .46141 m .39698 .44375 L .38004 .46288 L p
1 g
F P
s
P
p
.002 w
.59547 .41991 m .59795 .37817 L .5718 .37763 L p
1 g
F P
s
P
p
.002 w
.56246 .34461 m .5718 .37763 L .59795 .37817 L p
1 g
F P
s
P
p
.002 w
.39686 .50915 m .43536 .52455 L .43738 .49862 L p
1 g
F P
s
P
p
.002 w
.43738 .49862 m .40562 .48572 L .39686 .50915 L p
1 g
F P
s
P
p
.002 w
.52164 .33164 m .49977 .31666 L .48563 .33872 L p
1 g
F P
s
P
p
.002 w
.46799 .33419 m .48563 .33872 L .49977 .31666 L p
1 g
F P
s
P
p
.002 w
.38058 .3935 m .3845 .42028 L .40776 .40872 L p
1 g
F P
s
P
p
.002 w
.40776 .40872 m .4052 .39062 L .38058 .3935 L p
1 g
F P
s
P
p
.002 w
.60122 .47315 m .61918 .42806 L .59547 .41991 L p
1 g
F P
s
P
p
.002 w
.59795 .37817 m .59547 .41991 L .61918 .42806 L p
1 g
F P
s
P
p
.002 w
.43492 .54871 m .48292 .55083 L .47706 .52657 L p
1 g
F P
s
P
p
.002 w
.47706 .52657 m .43536 .52455 L .43492 .54871 L p
1 g
F P
s
P
p
.002 w
.56246 .34461 m .54264 .31667 L .52164 .33164 L p
1 g
F P
s
P
p
.002 w
.49977 .31666 m .52164 .33164 L .54264 .31667 L p
1 g
F P
s
P
p
.002 w
.49977 .31666 m .4737 .30983 L .46799 .33419 L p
1 g
F P
s
P
p
.002 w
.44951 .33576 m .46799 .33419 L .4737 .30983 L p
1 g
F P
s
P
p
.002 w
.38579 .36639 m .38058 .3935 L .4052 .39062 L p
1 g
F P
s
P
p
.002 w
.4052 .39062 m .40878 .37236 L .38579 .36639 L p
1 g
F P
s
P
p
.002 w
.36359 .43236 m .38004 .46288 L .39698 .44375 L p
1 g
F P
s
P
p
.002 w
.39698 .44375 m .3845 .42028 L .36359 .43236 L p
1 g
F P
s
P
p
.002 w
.59795 .37817 m .58687 .33817 L .56246 .34461 L p
1 g
F P
s
P
p
.002 w
.54264 .31667 m .56246 .34461 L .58687 .33817 L p
1 g
F P
s
P
p
.002 w
.54105 .55802 m .58619 .52827 L .57033 .51093 L p
1 g
F P
s
P
p
.002 w
.57033 .51093 m .52958 .53773 L .54105 .55802 L p
1 g
F P
s
P
p
.002 w
.60122 .47315 m .57033 .51093 L .58619 .52827 L p
1 g
F P
s
P
p
.002 w
.4737 .30983 m .44628 .31205 L .44951 .33576 L p
1 g
F P
s
P
p
.002 w
.43224 .34329 m .44951 .33576 L .44628 .31205 L p
1 g
F P
s
P
p
.002 w
.39965 .34201 m .38579 .36639 L .40878 .37236 L p
1 g
F P
s
P
p
.002 w
.40878 .37236 m .41814 .35596 L .39965 .34201 L p
1 g
F P
s
P
p
.002 w
.36572 .48166 m .39686 .50915 L .40562 .48572 L p
1 g
F P
s
P
p
.002 w
.40562 .48572 m .38004 .46288 L .36572 .48166 L p
1 g
F P
s
P
p
.002 w
.58619 .52827 m .62047 .48642 L .60122 .47315 L p
1 g
F P
s
P
p
.002 w
.61918 .42806 m .60122 .47315 L .62047 .48642 L p
1 g
F P
s
P
p
.002 w
.44628 .31205 m .42061 .32319 L .43224 .34329 L p
1 g
F P
s
P
p
.002 w
.41814 .35596 m .43224 .34329 L .42061 .32319 L p
1 g
F P
s
P
p
.002 w
.42061 .32319 m .39965 .34201 L .41814 .35596 L p
1 g
F P
s
P
p
.002 w
.61918 .42806 m .62222 .38003 L .59795 .37817 L p
1 g
F P
s
P
p
.002 w
.58687 .33817 m .59795 .37817 L .62222 .38003 L p
1 g
F P
s
P
p
.002 w
.48936 .57268 m .54105 .55802 L .52958 .53773 L p
1 g
F P
s
P
p
.002 w
.52958 .53773 m .48292 .55083 L .48936 .57268 L p
1 g
F P
s
P
p
.002 w
.54264 .31667 m .51423 .29696 L .49977 .31666 L p
1 g
F P
s
P
p
.002 w
.4737 .30983 m .49977 .31666 L .51423 .29696 L p
1 g
F P
s
P
p
.002 w
.39048 .5312 m .43492 .54871 L .43536 .52455 L p
1 g
F P
s
P
p
.002 w
.43536 .52455 m .39686 .50915 L .39048 .5312 L p
1 g
F P
s
P
p
.002 w
.35832 .39739 m .36359 .43236 L .3845 .42028 L p
1 g
F P
s
P
p
.002 w
.3845 .42028 m .38058 .3935 L .35832 .39739 L p
1 g
F P
s
P
p
.002 w
.62047 .48642 m .64049 .43647 L .61918 .42806 L p
1 g
F P
s
P
p
.002 w
.62222 .38003 m .61918 .42806 L .64049 .43647 L p
1 g
F P
s
P
p
.002 w
.43612 .57054 m .48936 .57268 L .48292 .55083 L p
1 g
F P
s
P
p
.002 w
.48292 .55083 m .43492 .54871 L .43612 .57054 L p
1 g
F P
s
P
p
.002 w
.58687 .33817 m .56305 .3042 L .54264 .31667 L p
1 g
F P
s
P
p
.002 w
.51423 .29696 m .54264 .31667 L .56305 .3042 L p
1 g
F P
s
P
p
.002 w
.51423 .29696 m .48021 .28788 L .4737 .30983 L p
1 g
F P
s
P
p
.002 w
.44628 .31205 m .4737 .30983 L .48021 .28788 L p
1 g
F P
s
P
p
.002 w
.34558 .44473 m .36572 .48166 L .38004 .46288 L p
1 g
F P
s
P
p
.002 w
.38004 .46288 m .36359 .43236 L .34558 .44473 L p
1 g
F P
s
P
p
.002 w
.36505 .36188 m .35832 .39739 L .38058 .3935 L p
1 g
F P
s
P
p
.002 w
.38058 .3935 m .38579 .36639 L .36505 .36188 L p
1 g
F P
s
P
p
.002 w
.62222 .38003 m .60969 .33391 L .58687 .33817 L p
1 g
F P
s
P
p
.002 w
.56305 .3042 m .58687 .33817 L .60969 .33391 L p
1 g
F P
s
P
p
.002 w
.35443 .49968 m .39048 .5312 L .39686 .50915 L p
1 g
F P
s
P
p
.002 w
.39686 .50915 m .36572 .48166 L .35443 .49968 L p
1 g
F P
s
P
p
.002 w
.48021 .28788 m .44432 .29068 L .44628 .31205 L p
1 g
F P
s
P
p
.002 w
.42061 .32319 m .44628 .31205 L .44432 .29068 L p
1 g
F P
s
P
p
.002 w
.55182 .57567 m .60033 .54363 L .58619 .52827 L p
1 g
F P
s
P
p
.002 w
.58619 .52827 m .54105 .55802 L .55182 .57567 L p
1 g
F P
s
P
p
.002 w
.62047 .48642 m .58619 .52827 L .60033 .54363 L p
1 g
F P
s
P
p
.002 w
.38317 .3299 m .36505 .36188 L .38579 .36639 L p
1 g
F P
s
P
p
.002 w
.38579 .36639 m .39965 .34201 L .38317 .3299 L p
1 g
F P
s
P
p
.002 w
.64049 .43647 m .64406 .38322 L .62222 .38003 L p
1 g
F P
s
P
p
.002 w
.60969 .33391 m .62222 .38003 L .64406 .38322 L p
1 g
F P
s
P
p
.002 w
.60033 .54363 m .63722 .49865 L .62047 .48642 L p
1 g
F P
s
P
p
.002 w
.64049 .43647 m .62047 .48642 L .63722 .49865 L p
1 g
F P
s
P
p
.002 w
.44432 .29068 m .41066 .30522 L .42061 .32319 L p
1 g
F P
s
P
p
.002 w
.39965 .34201 m .42061 .32319 L .41066 .30522 L p
1 g
F P
s
P
p
.002 w
.41066 .30522 m .38317 .3299 L .39965 .34201 L p
1 g
F P
s
P
p
.002 w
.49627 .59157 m .55182 .57567 L .54105 .55802 L p
1 g
F P
s
P
p
.002 w
.54105 .55802 m .48936 .57268 L .49627 .59157 L p
1 g
F P
s
P
p
.002 w
.56305 .3042 m .52873 .28013 L .51423 .29696 L p
1 g
F P
s
P
p
.002 w
.48021 .28788 m .51423 .29696 L .52873 .28013 L p
1 g
F P
s
P
p
.002 w
.38674 .55133 m .43612 .57054 L .43492 .54871 L p
1 g
F P
s
P
p
.002 w
.43492 .54871 m .39048 .5312 L .38674 .55133 L p
1 g
F P
s
P
p
.002 w
.33901 .40226 m .34558 .44473 L .36359 .43236 L p
1 g
F P
s
P
p
.002 w
.36359 .43236 m .35832 .39739 L .33901 .40226 L p
1 g
F P
s
P
p
.002 w
.63722 .49865 m .65886 .44499 L .64049 .43647 L p
1 g
F P
s
P
p
.002 w
.64406 .38322 m .64049 .43647 L .65886 .44499 L p
1 g
F P
s
P
p
.002 w
.60969 .33391 m .58244 .29461 L .56305 .3042 L p
1 g
F P
s
P
p
.002 w
.52873 .28013 m .56305 .3042 L .58244 .29461 L p
1 g
F P
s
P
p
.002 w
.43902 .58944 m .49627 .59157 L .48936 .57268 L p
1 g
F P
s
P
p
.002 w
.48936 .57268 m .43612 .57054 L .43902 .58944 L p
1 g
F P
s
P
p
.002 w
.33099 .45714 m .35443 .49968 L .36572 .48166 L p
1 g
F P
s
P
p
.002 w
.36572 .48166 m .34558 .44473 L .33099 .45714 L p
1 g
F P
s
P
p
.002 w
.52873 .28013 m .48743 .26893 L .48021 .28788 L p
1 g
F P
s
P
p
.002 w
.44432 .29068 m .48021 .28788 L .48743 .26893 L p
1 g
F P
s
P
p
.002 w
.3471 .35899 m .33901 .40226 L .35832 .39739 L p
1 g
F P
s
P
p
.002 w
.35832 .39739 m .36505 .36188 L .3471 .35899 L p
1 g
F P
s
P
p
.002 w
.64406 .38322 m .63038 .332 L .60969 .33391 L p
1 g
F P
s
P
p
.002 w
.58244 .29461 m .60969 .33391 L .63038 .332 L p
1 g
F P
s
P
p
.002 w
.34655 .5165 m .38674 .55133 L .39048 .5312 L p
1 g
F P
s
P
p
.002 w
.39048 .5312 m .35443 .49968 L .34655 .5165 L p
1 g
F P
s
P
p
.002 w
.48743 .26893 m .44373 .27222 L .44432 .29068 L p
1 g
F P
s
P
p
.002 w
.41066 .30522 m .44432 .29068 L .44373 .27222 L p
1 g
F P
s
P
p
.002 w
.56161 .59016 m .61236 .55659 L .60033 .54363 L p
1 g
F P
s
P
p
.002 w
.60033 .54363 m .55182 .57567 L .56161 .59016 L p
1 g
F P
s
P
p
.002 w
.63722 .49865 m .60033 .54363 L .61236 .55659 L p
1 g
F P
s
P
p
.002 w
.36915 .31998 m .3471 .35899 L .36505 .36188 L p
1 g
F P
s
P
p
.002 w
.36505 .36188 m .38317 .3299 L .36915 .31998 L p
1 g
F P
s
P
p
.002 w
.65886 .44499 m .66288 .38774 L .64406 .38322 L p
1 g
F P
s
P
p
.002 w
.63038 .332 m .64406 .38322 L .66288 .38774 L p
1 g
F P
s
P
p
.002 w
.58244 .29461 m .54294 .26665 L .52873 .28013 L p
1 g
F P
s
P
p
.002 w
.48743 .26893 m .52873 .28013 L .54294 .26665 L p
1 g
F P
s
P
p
.002 w
.61236 .55659 m .65098 .50954 L .63722 .49865 L p
1 g
F P
s
P
p
.002 w
.65886 .44499 m .63722 .49865 L .65098 .50954 L p
1 g
F P
s
P
p
.002 w
.44373 .27222 m .40268 .28988 L .41066 .30522 L p
1 g
F P
s
P
p
.002 w
.38317 .3299 m .41066 .30522 L .40268 .28988 L p
1 g
F P
s
P
p
.002 w
.38583 .56898 m .43902 .58944 L .43612 .57054 L p
1 g
F P
s
P
p
.002 w
.43612 .57054 m .38674 .55133 L .38583 .56898 L p
1 g
F P
s
P
p
.002 w
.50352 .6069 m .56161 .59016 L .55182 .57567 L p
1 g
F P
s
P
p
.002 w
.55182 .57567 m .49627 .59157 L .50352 .6069 L p
1 g
F P
s
P
p
.002 w
.40268 .28988 m .36915 .31998 L .38317 .3299 L p
1 g
F P
s
P
p
.002 w
.32324 .40803 m .33099 .45714 L .34558 .44473 L p
1 g
F P
s
P
p
.002 w
.34558 .44473 m .33901 .40226 L .32324 .40803 L p
1 g
F P
s
P
p
.002 w
.63038 .332 m .60032 .28825 L .58244 .29461 L p
1 g
F P
s
P
p
.002 w
.54294 .26665 m .58244 .29461 L .60032 .28825 L p
1 g
F P
s
P
p
.002 w
.65098 .50954 m .67373 .45342 L .65886 .44499 L p
1 g
F P
s
P
p
.002 w
.66288 .38774 m .65886 .44499 L .67373 .45342 L p
1 g
F P
s
P
p
.002 w
.44363 .60485 m .50352 .6069 L .49627 .59157 L p
1 g
F P
s
P
p
.002 w
.49627 .59157 m .43902 .58944 L .44363 .60485 L p
1 g
F P
s
P
p
.002 w
.32034 .4693 m .34655 .5165 L .35443 .49968 L p
1 g
F P
s
P
p
.002 w
.35443 .49968 m .33099 .45714 L .32034 .4693 L p
1 g
F P
s
P
p
.002 w
.54294 .26665 m .49524 .25354 L .48743 .26893 L p
1 g
F P
s
P
p
.002 w
.44373 .27222 m .48743 .26893 L .49524 .25354 L p
1 g
F P
s
P
p
.002 w
.66288 .38774 m .64837 .33261 L .63038 .332 L p
1 g
F P
s
P
p
.002 w
.60032 .28825 m .63038 .332 L .64837 .33261 L p
1 g
F P
s
P
p
.002 w
.33251 .35788 m .32324 .40803 L .33901 .40226 L p
1 g
F P
s
P
p
.002 w
.33901 .40226 m .3471 .35899 L .33251 .35788 L p
1 g
F P
s
P
p
.002 w
.34247 .53166 m .38583 .56898 L .38674 .55133 L p
1 g
F P
s
P
p
.002 w
.38674 .55133 m .34655 .5165 L .34247 .53166 L p
1 g
F P
s
P
p
.002 w
.49524 .25354 m .44461 .25723 L .44373 .27222 L p
1 g
F P
s
P
p
.002 w
.40268 .28988 m .44373 .27222 L .44461 .25723 L p
1 g
F P
s
P
p
.002 w
.67373 .45342 m .67809 .39356 L .66288 .38774 L p
1 g
F P
s
P
p
.002 w
.64837 .33261 m .66288 .38774 L .67809 .39356 L p
1 g
F P
s
P
p
.002 w
.35805 .3126 m .33251 .35788 L .3471 .35899 L p
1 g
F P
s
P
p
.002 w
.3471 .35899 m .36915 .31998 L .35805 .3126 L p
1 g
F P
s
P
p
.002 w
.57015 .60098 m .62188 .56672 L .61236 .55659 L p
1 g
F P
s
P
p
.002 w
.61236 .55659 m .56161 .59016 L .57015 .60098 L p
1 g
F P
s
P
p
.002 w
.65098 .50954 m .61236 .55659 L .62188 .56672 L p
1 g
F P
s
P
p
.002 w
.60032 .28825 m .55653 .257 L .54294 .26665 L p
1 g
F P
s
P
p
.002 w
.49524 .25354 m .54294 .26665 L .55653 .257 L p
1 g
F P
s
P
p
.002 w
.38795 .5836 m .44363 .60485 L .43902 .58944 L p
1 g
F P
s
P
p
.002 w
.43902 .58944 m .38583 .56898 L .38795 .5836 L p
1 g
F P
s
P
p
.002 w
.62188 .56672 m .66129 .51875 L .65098 .50954 L p
1 g
F P
s
P
p
.002 w
.67373 .45342 m .65098 .50954 L .66129 .51875 L p
1 g
F P
s
P
p
.002 w
.44461 .25723 m .39697 .27767 L .40268 .28988 L p
1 g
F P
s
P
p
.002 w
.36915 .31998 m .40268 .28988 L .39697 .27767 L p
1 g
F P
s
P
p
.002 w
.31157 .41463 m .32034 .4693 L .33099 .45714 L p
1 g
F P
s
P
p
.002 w
.33099 .45714 m .32324 .40803 L .31157 .41463 L p
1 g
F P
s
P
p
.002 w
.51097 .61814 m .57015 .60098 L .56161 .59016 L p
1 g
F P
s
P
p
.002 w
.56161 .59016 m .50352 .6069 L .51097 .61814 L p
1 g
F P
s
P
p
.002 w
.39697 .27767 m .35805 .3126 L .36915 .31998 L p
1 g
F P
s
P
p
.002 w
.64837 .33261 m .61619 .28542 L .60032 .28825 L p
1 g
F P
s
P
p
.002 w
.55653 .257 m .60032 .28825 L .61619 .28542 L p
1 g
F P
s
P
p
.002 w
.66129 .51875 m .68455 .46158 L .67373 .45342 L p
1 g
F P
s
P
p
.002 w
.67809 .39356 m .67373 .45342 L .68455 .46158 L p
1 g
F P
s
P
p
.002 w
.3141 .48089 m .34247 .53166 L .34655 .5165 L p
1 g
F P
s
P
p
.002 w
.34655 .5165 m .32034 .4693 L .3141 .48089 L p
1 g
F P
s
P
p
.002 w
.44994 .61616 m .51097 .61814 L .50352 .6069 L p
1 g
F P
s
P
p
.002 w
.50352 .6069 m .44363 .60485 L .44994 .61616 L p
1 g
F P
s
P
p
.002 w
.55653 .257 m .50347 .24227 L .49524 .25354 L p
1 g
F P
s
P
p
.002 w
.44461 .25723 m .49524 .25354 L .50347 .24227 L p
1 g
F P
s
P
p
.002 w
.67809 .39356 m .66308 .33585 L .64837 .33261 L p
1 g
F P
s
P
p
.002 w
.61619 .28542 m .64837 .33261 L .66308 .33585 L p
1 g
F P
s
P
p
.002 w
.32183 .35868 m .31157 .41463 L .32324 .40803 L p
1 g
F P
s
P
p
.002 w
.32324 .40803 m .33251 .35788 L .32183 .35868 L p
1 g
F P
s
P
p
.002 w
.3425 .54467 m .38795 .5836 L .38583 .56898 L p
1 g
F P
s
P
p
.002 w
.38583 .56898 m .34247 .53166 L .3425 .54467 L p
1 g
F P
s
P
p
.002 w
.68455 .46158 m .68911 .40059 L .67809 .39356 L p
1 g
F P
s
P
p
.002 w
.66308 .33585 m .67809 .39356 L .68911 .40059 L p
1 g
F P
s
P
p
.002 w
.50347 .24227 m .44701 .2463 L .44461 .25723 L p
1 g
F P
s
P
p
.002 w
.39697 .27767 m .44461 .25723 L .44701 .2463 L p
1 g
F P
s
P
p
.002 w
.61619 .28542 m .56913 .25165 L .55653 .257 L p
1 g
F P
s
P
p
.002 w
.50347 .24227 m .55653 .257 L .56913 .25165 L p
1 g
F P
s
P
p
.002 w
.35032 .3081 m .32183 .35868 L .33251 .35788 L p
1 g
F P
s
P
p
.002 w
.33251 .35788 m .35805 .3126 L .35032 .3081 L p
1 g
F P
s
P
p
.002 w
.57715 .60764 m .62851 .5736 L .62188 .56672 L p
1 g
F P
s
P
p
.002 w
.62188 .56672 m .57015 .60098 L .57715 .60764 L p
1 g
F P
s
P
p
.002 w
.66129 .51875 m .62188 .56672 L .62851 .5736 L p
1 g
F P
s
P
p
.002 w
.3932 .59464 m .44994 .61616 L .44363 .60485 L p
1 g
F P
s
P
p
.002 w
.44363 .60485 m .38795 .5836 L .3932 .59464 L p
1 g
F P
s
P
p
.002 w
.30456 .42194 m .3141 .48089 L .32034 .4693 L p
1 g
F P
s
P
p
.002 w
.32034 .4693 m .31157 .41463 L .30456 .42194 L p
1 g
F P
s
P
p
.002 w
.62851 .5736 m .66766 .52597 L .66129 .51875 L p
1 g
F P
s
P
p
.002 w
.68455 .46158 m .66129 .51875 L .66766 .52597 L p
1 g
F P
s
P
p
.002 w
.44701 .2463 m .3938 .26908 L .39697 .27767 L p
1 g
F P
s
P
p
.002 w
.35805 .3126 m .39697 .27767 L .3938 .26908 L p
1 g
F P
s
P
p
.002 w
.51842 .62473 m .57715 .60764 L .57015 .60098 L p
1 g
F P
s
P
p
.002 w
.57015 .60098 m .51097 .61814 L .51842 .62473 L p
1 g
F P
s
P
p
.002 w
.3938 .26908 m .35032 .3081 L .35805 .3126 L p
1 g
F P
s
P
p
.002 w
.66308 .33585 m .62954 .28641 L .61619 .28542 L p
1 g
F P
s
P
p
.002 w
.56913 .25165 m .61619 .28542 L .62954 .28641 L p
1 g
F P
s
P
p
.002 w
.66766 .52597 m .69081 .46923 L .68455 .46158 L p
1 g
F P
s
P
p
.002 w
.68911 .40059 m .68455 .46158 L .69081 .46923 L p
1 g
F P
s
P
p
.002 w
.31273 .49157 m .3425 .54467 L .34247 .53166 L p
1 g
F P
s
P
p
.002 w
.34247 .53166 m .3141 .48089 L .31273 .49157 L p
1 g
F P
s
P
p
.002 w
.4579 .62284 m .51842 .62473 L .51097 .61814 L p
1 g
F P
s
P
p
.002 w
.51097 .61814 m .44994 .61616 L .4579 .62284 L p
1 g
F P
s
P
p
.002 w
.56913 .25165 m .51194 .23567 L .50347 .24227 L p
1 g
F P
s
P
p
.002 w
.44701 .2463 m .50347 .24227 L .51194 .23567 L p
1 g
F P
s
P
p
.002 w
.68911 .40059 m .67394 .34179 L .66308 .33585 L p
1 g
F P
s
P
p
.002 w
.62954 .28641 m .66308 .33585 L .67394 .34179 L p
1 g
F P
s
P
p
.002 w
.31559 .36149 m .30456 .42194 L .31157 .41463 L p
1 g
F P
s
P
p
.002 w
.31157 .41463 m .32183 .35868 L .31559 .36149 L p
1 g
F P
s
P
p
.002 w
.34689 .55505 m .3932 .59464 L .38795 .5836 L p
1 g
F P
s
P
p
.002 w
.38795 .5836 m .3425 .54467 L .34689 .55505 L p
1 g
F P
s
P
p
.002 w
.69081 .46923 m .6954 .40873 L .68911 .40059 L p
1 g
F P
s
P
p
.002 w
.67394 .34179 m .68911 .40059 L .6954 .40873 L p
1 g
F P
s
P
p
.002 w
.51194 .23567 m .45096 .23997 L .44701 .2463 L p
1 g
F P
s
P
p
.002 w
.3938 .26908 m .44701 .2463 L .45096 .23997 L p
1 g
F P
s
P
p
.002 w
.62954 .28641 m .58035 .25099 L .56913 .25165 L p
1 g
F P
s
P
p
.002 w
.51194 .23567 m .56913 .25165 L .58035 .25099 L p
1 g
F P
s
P
p
.002 w
.34639 .30679 m .31559 .36149 L .32183 .35868 L p
1 g
F P
s
P
p
.002 w
.32183 .35868 m .35032 .3081 L .34639 .30679 L p
1 g
F P
s
P
p
.002 w
.40166 .60156 m .4579 .62284 L .44994 .61616 L p
1 g
F P
s
P
p
.002 w
.44994 .61616 m .3932 .59464 L .40166 .60156 L p
1 g
F P
s
P
p
.002 w
.58232 .60971 m .63189 .57684 L .62851 .5736 L p
1 g
F P
s
P
p
.002 w
.62851 .5736 m .57715 .60764 L .58232 .60971 L p
1 g
F P
s
P
p
.002 w
.66766 .52597 m .62851 .5736 L .63189 .57684 L p
1 g
F P
s
P
p
.002 w
.30269 .4298 m .31273 .49157 L .3141 .48089 L p
1 g
F P
s
P
p
.002 w
.3141 .48089 m .30456 .42194 L .30269 .4298 L p
1 g
F P
s
P
p
.002 w
.63189 .57684 m .66969 .53086 L .66766 .52597 L p
1 g
F P
s
P
p
.002 w
.69081 .46923 m .66766 .52597 L .66969 .53086 L p
1 g
F P
s
P
p
.002 w
.52568 .62621 m .58232 .60971 L .57715 .60764 L p
1 g
F P
s
P
p
.002 w
.57715 .60764 m .51842 .62473 L .52568 .62621 L p
1 g
F P
s
P
p
.002 w
.45096 .23997 m .39343 .26457 L .3938 .26908 L p
1 g
F P
s
P
p
.002 w
.35032 .3081 m .3938 .26908 L .39343 .26457 L p
1 g
F P
s
P
p
.002 w
.39343 .26457 m .34639 .30679 L .35032 .3081 L p
1 g
F P
s
P
p
.002 w
.67394 .34179 m .63986 .29142 L .62954 .28641 L p
1 g
F P
s
P
p
.002 w
.58035 .25099 m .62954 .28641 L .63986 .29142 L p
1 g
F P
s
P
p
.002 w
.31656 .50099 m .34689 .55505 L .3425 .54467 L p
1 g
F P
s
P
p
.002 w
.3425 .54467 m .31273 .49157 L .31656 .50099 L p
1 g
F P
s
P
p
.002 w
.66969 .53086 m .69204 .47613 L .69081 .46923 L p
1 g
F P
s
P
p
.002 w
.6954 .40873 m .69081 .46923 L .69204 .47613 L p
1 g
F P
s
P
p
.002 w
.46737 .6244 m .52568 .62621 L .51842 .62473 L p
1 g
F P
s
P
p
.002 w
.51842 .62473 m .4579 .62284 L .46737 .6244 L p
1 g
F P
s
P
p
.002 w
.58035 .25099 m .52044 .2342 L .51194 .23567 L p
1 g
F P
s
P
p
.002 w
.45096 .23997 m .51194 .23567 L .52044 .2342 L p
1 g
F P
s
P
p
.002 w
.6954 .40873 m .68042 .35045 L .67394 .34179 L p
1 g
F P
s
P
p
.002 w
.63986 .29142 m .67394 .34179 L .68042 .35045 L p
1 g
F P
s
P
p
.002 w
.31427 .36636 m .30269 .4298 L .30456 .42194 L p
1 g
F P
s
P
p
.002 w
.30456 .42194 m .31559 .36149 L .31427 .36636 L p
1 g
F P
s
P
p
.004 w
.45795 .64104 m
.46093 .62613 L
s
P
p
.004 w
.45496 .65602 m
.45795 .64104 L
s
P
p
.004 w
.44346 .71359 m
.45496 .65602 L
s
P
p
.002 w
.3558 .56236 m .40166 .60156 L .3932 .59464 L p
1 g
F P
s
P
p
.002 w
.3932 .59464 m .34689 .55505 L .3558 .56236 L p
1 g
F P
s
P
p
.002 w
.69204 .47613 m .69648 .41784 L .6954 .40873 L p
1 g
F P
s
P
p
.002 w
.68042 .35045 m .6954 .40873 L .69648 .41784 L p
1 g
F P
s
P
p
.002 w
.63986 .29142 m .58979 .25533 L .58035 .25099 L p
1 g
F P
s
P
p
.002 w
.52044 .2342 m .58035 .25099 L .58979 .25533 L p
1 g
F P
s
P
p
.002 w
.52044 .2342 m .45647 .2387 L .45096 .23997 L p
1 g
F P
s
P
p
.002 w
.39343 .26457 m .45096 .23997 L .45647 .2387 L p
1 g
F P
s
P
p
.002 w
.41327 .6039 m .46737 .6244 L .4579 .62284 L p
1 g
F P
s
P
p
.002 w
.4579 .62284 m .40166 .60156 L .41327 .6039 L p
1 g
F P
s
P
p
.002 w
.34662 .3089 m .31427 .36636 L .31559 .36149 L p
1 g
F P
s
P
p
.002 w
.31559 .36149 m .34639 .30679 L .34662 .3089 L p
1 g
F P
s
P
p
.002 w
.30635 .43802 m .31656 .50099 L .31273 .49157 L p
1 g
F P
s
P
p
.002 w
.31273 .49157 m .30269 .4298 L .30635 .43802 L p
1 g
F P
s
P
p
.002 w
.5854 .60681 m .63171 .5761 L .63189 .57684 L p
1 g
F P
s
P
p
.002 w
.63189 .57684 m .58232 .60971 L .5854 .60681 L p
1 g
F P
s
P
p
.002 w
.66969 .53086 m .63189 .57684 L .63171 .5761 L p
1 g
F P
s
P
p
.002 w
.63171 .5761 m .66703 .53315 L .66969 .53086 L p
1 g
F P
s
P
p
.002 w
.69204 .47613 m .66969 .53086 L .66703 .53315 L p
1 g
F P
s
P
p
.002 w
.53252 .62221 m .5854 .60681 L .58232 .60971 L p
1 g
F P
s
P
p
.002 w
.58232 .60971 m .52568 .62621 L .53252 .62221 L p
1 g
F P
s
P
p
.002 w
.45647 .2387 m .39604 .26455 L .39343 .26457 L p
1 g
F P
s
P
p
.002 w
.34639 .30679 m .39343 .26457 L .39604 .26455 L p
1 g
F P
s
P
p
.002 w
.39604 .26455 m .34662 .3089 L .34639 .30679 L p
1 g
F P
s
P
p
.002 w
.68042 .35045 m .64668 .30056 L .63986 .29142 L p
1 g
F P
s
P
p
.002 w
.58979 .25533 m .63986 .29142 L .64668 .30056 L p
1 g
F P
s
P
p
.002 w
.32581 .50878 m .3558 .56236 L .34689 .55505 L p
1 g
F P
s
P
p
.002 w
.34689 .55505 m .31656 .50099 L .32581 .50878 L p
1 g
F P
s
P
p
.002 w
.66703 .53315 m .68789 .48205 L .69204 .47613 L p
1 g
F P
s
P
p
.002 w
.69648 .41784 m .69204 .47613 L .68789 .48205 L p
1 g
F P
s
P
p
.002 w
.47818 .62048 m .53252 .62221 L .52568 .62621 L p
1 g
F P
s
P
p
.002 w
.52568 .62621 m .46737 .6244 L .47818 .62048 L p
1 g
F P
s
P
p
.002 w
.69648 .41784 m .68205 .36175 L .68042 .35045 L p
1 g
F P
s
P
p
.002 w
.64668 .30056 m .68042 .35045 L .68205 .36175 L p
1 g
F P
s
P
p
.002 w
.58979 .25533 m .52873 .23824 L .52044 .2342 L p
1 g
F P
s
P
p
.002 w
.45647 .2387 m .52044 .2342 L .52873 .23824 L p
1 g
F P
s
P
p
.002 w
.31821 .37329 m .30635 .43802 L .30269 .4298 L p
1 g
F P
s
P
p
.002 w
.30269 .4298 m .31427 .36636 L .31821 .37329 L p
1 g
F P
s
P
p
.002 w
.36924 .56616 m .41327 .6039 L .40166 .60156 L p
1 g
F P
s
P
p
.002 w
.40166 .60156 m .3558 .56236 L .36924 .56616 L p
1 g
F P
s
P
p
.002 w
.68789 .48205 m .69199 .42769 L .69648 .41784 L p
1 g
F P
s
P
p
.002 w
.68205 .36175 m .69648 .41784 L .69199 .42769 L p
1 g
F P
s
P
p
.002 w
.64668 .30056 m .59706 .26486 L .58979 .25533 L p
1 g
F P
s
P
p
.002 w
.52873 .23824 m .58979 .25533 L .59706 .26486 L p
1 g
F P
s
P
p
.002 w
.52873 .23824 m .46346 .24287 L .45647 .2387 L p
1 g
F P
s
P
p
.002 w
.39604 .26455 m .45647 .2387 L .46346 .24287 L p
1 g
F P
s
P
p
.002 w
.42787 .60131 m .47818 .62048 L .46737 .6244 L p
1 g
F P
s
P
p
.002 w
.46737 .6244 m .41327 .6039 L .42787 .60131 L p
1 g
F P
s
P
p
.002 w
.31579 .44637 m .32581 .50878 L .31656 .50099 L p
1 g
F P
s
P
p
.002 w
.31656 .50099 m .30635 .43802 L .31579 .44637 L p
1 g
F P
s
P
p
.002 w
.35128 .31462 m .31821 .37329 L .31427 .36636 L p
1 g
F P
s
P
p
.002 w
.31427 .36636 m .34662 .3089 L .35128 .31462 L p
1 g
F P
s
P
p
.002 w
.58616 .5987 m .62773 .57115 L .63171 .5761 L p
1 g
F P
s
P
p
.002 w
.63171 .5761 m .5854 .60681 L .58616 .5987 L p
1 g
F P
s
P
p
.002 w
.66703 .53315 m .63171 .5761 L .62773 .57115 L p
1 g
F P
s
P
p
.002 w
.62773 .57115 m .65944 .53258 L .66703 .53315 L p
1 g
F P
s
P
p
.002 w
.68789 .48205 m .66703 .53315 L .65944 .53258 L p
1 g
F P
s
P
p
.002 w
.68205 .36175 m .64955 .31382 L .64668 .30056 L p
1 g
F P
s
P
p
.002 w
.59706 .26486 m .64668 .30056 L .64955 .31382 L p
1 g
F P
s
P
p
.002 w
.53872 .61247 m .58616 .5987 L .5854 .60681 L p
1 g
F P
s
P
p
.002 w
.5854 .60681 m .53252 .62221 L .53872 .61247 L p
1 g
F P
s
P
p
.002 w
.46346 .24287 m .40177 .2693 L .39604 .26455 L p
1 g
F P
s
P
p
.002 w
.34662 .3089 m .39604 .26455 L .40177 .2693 L p
1 g
F P
s
P
p
.002 w
.40177 .2693 m .35128 .31462 L .34662 .3089 L p
1 g
F P
s
P
p
.002 w
.34053 .51461 m .36924 .56616 L .3558 .56236 L p
1 g
F P
s
P
p
.002 w
.3558 .56236 m .32581 .50878 L .34053 .51461 L p
1 g
F P
s
P
p
.002 w
.65944 .53258 m .67812 .48672 L .68789 .48205 L p
1 g
F P
s
P
p
.002 w
.69199 .42769 m .68789 .48205 L .67812 .48672 L p
1 g
F P
s
P
p
.002 w
.69199 .42769 m .67848 .37551 L .68205 .36175 L p
1 g
F P
s
P
p
.002 w
.64955 .31382 m .68205 .36175 L .67848 .37551 L p
1 g
F P
s
P
p
.002 w
.49007 .61084 m .53872 .61247 L .53252 .62221 L p
1 g
F P
s
P
p
.002 w
.53252 .62221 m .47818 .62048 L .49007 .61084 L p
1 g
F P
s
P
p
.002 w
.59706 .26486 m .53654 .24802 L .52873 .23824 L p
1 g
F P
s
P
p
.002 w
.46346 .24287 m .52873 .23824 L .53654 .24802 L p
1 g
F P
s
P
p
.002 w
.38704 .56612 m .42787 .60131 L .41327 .6039 L p
1 g
F P
s
P
p
.002 w
.41327 .6039 m .36924 .56616 L .38704 .56612 L p
1 g
F P
s
P
p
.002 w
.32765 .38219 m .31579 .44637 L .30635 .43802 L p
1 g
F P
s
P
p
.002 w
.30635 .43802 m .31821 .37329 L .32765 .38219 L p
1 g
F P
s
P
p
.002 w
.67812 .48672 m .68172 .43804 L .69199 .42769 L p
1 g
F P
s
P
p
.002 w
.67848 .37551 m .69199 .42769 L .68172 .43804 L p
1 g
F P
s
P
p
.002 w
.64955 .31382 m .6018 .27962 L .59706 .26486 L p
1 g
F P
s
P
p
.002 w
.53654 .24802 m .59706 .26486 L .6018 .27962 L p
1 g
F P
s
P
p
.002 w
.44516 .59358 m .49007 .61084 L .47818 .62048 L p
1 g
F P
s
P
p
.002 w
.47818 .62048 m .42787 .60131 L .44516 .59358 L p
1 g
F P
s
P
p
.004 w
.46093 .62613 m
.46222 .61965 L
s
P
p
.004 w
.46222 .61965 m
.46361 .61272 L
s
P
p
.004 w
.46584 .60152 m
.5 .43051 L
s
P
p
.004 w
.46361 .61272 m
.46388 .61133 L
s
P
p
.002 w
.53654 .24802 m .47183 .25272 L .46346 .24287 L p
1 g
F P
s
P
p
.002 w
.40177 .2693 m .46346 .24287 L .47183 .25272 L p
1 g
F P
s
P
p
.002 w
.33106 .45458 m .34053 .51461 L .32581 .50878 L p
1 g
F P
s
P
p
.002 w
.32581 .50878 m .31579 .44637 L .33106 .45458 L p
1 g
F P
s
P
p
.002 w
.36052 .32399 m .32765 .38219 L .31821 .37329 L p
1 g
F P
s
P
p
.002 w
.31821 .37329 m .35128 .31462 L .36052 .32399 L p
1 g
F P
s
P
p
.002 w
.58441 .58531 m .61984 .56186 L .62773 .57115 L p
1 g
F P
s
P
p
.002 w
.62773 .57115 m .58616 .5987 L .58441 .58531 L p
1 g
F P
s
P
p
.002 w
.65944 .53258 m .62773 .57115 L .61984 .56186 L p
1 g
F P
s
P
p
.002 w
.67848 .37551 m .64816 .33103 L .64955 .31382 L p
1 g
F P
s
P
p
.002 w
.6018 .27962 m .64955 .31382 L .64816 .33103 L p
1 g
F P
s
P
p
.002 w
.61984 .56186 m .64684 .52898 L .65944 .53258 L p
1 g
F P
s
P
p
.002 w
.67812 .48672 m .65944 .53258 L .64684 .52898 L p
1 g
F P
s
P
p
.002 w
.54403 .59696 m .58441 .58531 L .58616 .5987 L p
1 g
F P
s
P
p
.002 w
.58616 .5987 m .53872 .61247 L .54403 .59696 L p
1 g
F P
s
P
p
.002 w
.47183 .25272 m .41063 .279 L .40177 .2693 L p
1 g
F P
s
P
p
.002 w
.35128 .31462 m .40177 .2693 L .41063 .279 L p
1 g
F P
s
P
p
.002 w
.41063 .279 m .36052 .32399 L .35128 .31462 L p
1 g
F P
s
P
p
.002 w
.36056 .51815 m .38704 .56612 L .36924 .56616 L p
1 g
F P
s
P
p
.002 w
.36924 .56616 m .34053 .51461 L .36056 .51815 L p
1 g
F P
s
P
p
.002 w
.64684 .52898 m .66269 .48993 L .67812 .48672 L p
1 g
F P
s
P
p
.002 w
.68172 .43804 m .67812 .48672 L .66269 .48993 L p
1 g
F P
s
P
p
.002 w
.68172 .43804 m .66951 .39142 L .67848 .37551 L p
1 g
F P
s
P
p
.002 w
.64816 .33103 m .67848 .37551 L .66951 .39142 L p
1 g
F P
s
P
p
.002 w
.6018 .27962 m .54358 .26358 L .53654 .24802 L p
1 g
F P
s
P
p
.002 w
.47183 .25272 m .53654 .24802 L .54358 .26358 L p
1 g
F P
s
P
p
.002 w
.50271 .59546 m .54403 .59696 L .53872 .61247 L p
1 g
F P
s
P
p
.002 w
.53872 .61247 m .49007 .61084 L .50271 .59546 L p
1 g
F P
s
P
p
.002 w
.40888 .56203 m .44516 .59358 L .42787 .60131 L p
1 g
F P
s
P
p
.002 w
.42787 .60131 m .38704 .56612 L .40888 .56203 L p
1 g
F P
s
P
p
.002 w
.34261 .39288 m .33106 .45458 L .31579 .44637 L p
1 g
F P
s
P
p
.002 w
.31579 .44637 m .32765 .38219 L .34261 .39288 L p
1 g
F P
s
P
p
.002 w
.64816 .33103 m .60369 .29942 L .6018 .27962 L p
1 g
F P
s
P
p
.002 w
.54358 .26358 m .6018 .27962 L .60369 .29942 L p
1 g
F P
s
P
p
.002 w
.66269 .48993 m .66564 .44856 L .68172 .43804 L p
1 g
F P
s
P
p
.002 w
.66951 .39142 m .68172 .43804 L .66564 .44856 L p
1 g
F P
s
P
p
.002 w
.46472 .58067 m .50271 .59546 L .49007 .61084 L p
1 g
F P
s
P
p
.002 w
.49007 .61084 m .44516 .59358 L .46472 .58067 L p
1 g
F P
s
P
p
.002 w
.35198 .46237 m .36056 .51815 L .34053 .51461 L p
1 g
F P
s
P
p
.002 w
.34053 .51461 m .33106 .45458 L .35198 .46237 L p
1 g
F P
s
P
p
.002 w
.54358 .26358 m .48136 .26825 L .47183 .25272 L p
1 g
F P
s
P
p
.002 w
.41063 .279 m .47183 .25272 L .48136 .26825 L p
1 g
F P
s
P
p
.002 w
.3743 .33693 m .34261 .39288 L .32765 .38219 L p
1 g
F P
s
P
p
.002 w
.32765 .38219 m .36052 .32399 L .3743 .33693 L p
1 g
F P
s
P
p
.002 w
.66951 .39142 m .64229 .35184 L .64816 .33103 L p
1 g
F P
s
P
p
.002 w
.60369 .29942 m .64816 .33103 L .64229 .35184 L p
1 g
F P
s
P
p
.002 w
.58007 .56676 m .60805 .54826 L .61984 .56186 L p
1 g
F P
s
P
p
.002 w
.61984 .56186 m .58441 .58531 L .58007 .56676 L p
1 g
F P
s
P
p
.002 w
.64684 .52898 m .61984 .56186 L .60805 .54826 L p
1 g
F P
s
P
p
.002 w
.60805 .54826 m .62935 .5223 L .64684 .52898 L p
1 g
F P
s
P
p
.002 w
.66269 .48993 m .64684 .52898 L .62935 .5223 L p
1 g
F P
s
P
p
.002 w
.38549 .51916 m .40888 .56203 L .38704 .56612 L p
1 g
F P
s
P
p
.002 w
.38704 .56612 m .36056 .51815 L .38549 .51916 L p
1 g
F P
s
P
p
.002 w
.54821 .57587 m .58007 .56676 L .58441 .58531 L p
1 g
F P
s
P
p
.002 w
.58441 .58531 m .54403 .59696 L .54821 .57587 L p
1 g
F P
s
P
p
.002 w
.48136 .26825 m .42252 .29363 L .41063 .279 L p
1 g
F P
s
P
p
.002 w
.36052 .32399 m .41063 .279 L .42252 .29363 L p
1 g
F P
s
P
p
.002 w
.42252 .29363 m .3743 .33693 L .36052 .32399 L p
1 g
F P
s
P
p
.002 w
.66564 .44856 m .65513 .40908 L .66951 .39142 L p
1 g
F P
s
P
p
.002 w
.64229 .35184 m .66951 .39142 L .65513 .40908 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.62935 .5223 m .64179 .49148 L .66269 .48993 L p
1 g
F P
s
P
p
.002 w
.66564 .44856 m .66269 .48993 L .64179 .49148 L p
1 g
F P
s
P
p
.002 w
.60369 .29942 m .54957 .28473 L .54358 .26358 L p
1 g
F P
s
P
p
.002 w
.48136 .26825 m .54358 .26358 L .54957 .28473 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58071 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58071 L .5115 .58061 L 1 g
F
P
p
.50271 .59546 m .49646 .58326 L .51095 .58071 L 1 g
F
P
p
.002 w
.512 .58052 m .51187 .58074 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.51187 .58074 m .50271 .59546 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51079 .57862 L p
.50184 .58041 L 1 g
F P
s
P
p
.53128 .57265 m .5115 .58061 L .52118 .57783 L 1 g
F
P
p
.5115 .58061 m .51095 .58083 L .512 .58052 L 1 g
F
P
p
.5115 .58061 m .512 .58052 L .52118 .57783 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48911 .58 L p
1 g
F P
s
P
p
.49646 .58326 m .49487 .58018 L .51095 .58071 L 1 g
F
P
p
.51079 .57862 m .48911 .58 L .50184 .58041 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.50271 .59546 m .46472 .58067 L .4708 .57556 L p
1 g
F P
s
P
p
.002 w
.48911 .58 m .48921 .57862 L p
.48047 .5779 L 1 g
F P
s
P
p
.50271 .59546 m .4708 .57556 L .49558 .58157 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57459 L p
1 g
F P
s
P
p
.46472 .58067 m .46422 .57301 L .4683 .57459 L 1 g
F
P
p
.002 w
.4708 .57556 m .4703 .57597 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.4703 .57597 m .46472 .58067 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.4683 .57459 m .46872 .57265 L p
.46098 .56956 L 1 g
F P
s
P
p
.48921 .57862 m .4683 .57459 L .47589 .57753 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45095 .56266 L p
1 g
F P
s
P
p
.46872 .57265 m .45095 .56266 L .46098 .56956 L 1 g
F
P
p
.4683 .57459 m .46217 .5416 L .4708 .57556 L 1 g
F
P
p
.46422 .57301 m .46414 .57173 L .4683 .57459 L 1 g
F
P
p
.46414 .57173 m .46217 .5416 L .4683 .57459 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46472 .58067 m .43418 .55382 L .44091 .55088 L p
1 g
F P
s
P
p
.002 w
.45095 .56266 m .45146 .56129 L p
.445 .55567 L 1 g
F P
s
P
p
.46472 .58067 m .44091 .55088 L .46459 .57868 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43845 .54716 L p
1 g
F P
s
P
p
.43418 .55382 m .43699 .54495 L .43845 .54716 L 1 g
F
P
p
.002 w
.44091 .55088 m .43972 .5514 L p
.43845 .54716 L 1 g
F P
s
P
p
.002 w
.43972 .5514 m .43418 .55382 L p
.43845 .54716 L 1 g
F P
s
P
p
.002 w
.43845 .54716 m .43925 .54566 L p
.4362 .53963 L 1 g
F P
s
P
p
.45146 .56129 m .43845 .54716 L .44285 .55381 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43281 .52829 L p
1 g
F P
s
P
p
.43925 .54566 m .43281 .52829 L .4362 .53963 L 1 g
F
P
p
.43845 .54716 m .4471 .51308 L .44091 .55088 L 1 g
F
P
p
.43699 .54495 m .4374 .54365 L .43845 .54716 L 1 g
F
P
p
.4374 .54365 m .4471 .51308 L .43845 .54716 L 1 g
F
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43418 .55382 m .43181 .54941 L p
.4471 .51308 L 1 g
F P
s
P
p
.002 w
.43181 .54941 m .41464 .51748 L .43344 .51493 L p
1 g
F P
s
P
p
.002 w
.43281 .52829 m .43346 .52734 L p
.4332 .51996 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43405 .50921 L p
1 g
F P
s
P
p
.41464 .51748 m .43624 .48874 L .43405 .50921 L 1 g
F
P
p
.002 w
.43344 .51493 m .43117 .51524 L p
.43405 .50921 L 1 g
F P
s
P
p
.002 w
.43117 .51524 m .41464 .51748 L p
.43405 .50921 L 1 g
F P
s
P
p
.002 w
.43405 .50921 m .43485 .50826 L p
.43778 .50141 L 1 g
F P
s
P
p
.43346 .52734 m .43405 .50921 L .43313 .51785 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .43778 .50141 L 1 g
F
P
p
.002 w
.4471 .51308 m .43344 .51493 L p
.43608 .50497 L 1 g
F P
s
P
p
.43608 .50497 m .43868 .49512 L .44258 .49136 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45057 .48362 L 1 g
F P
s
P
p
.002 w
.45307 .4812 m .4788 .48353 L p
.44395 .49004 L 1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.4788 .48353 m .45307 .4812 L p
.46481 .47329 L 1 g
F P
s
P
p
.46481 .47329 m .47753 .46721 L .4788 .48353 L 1 g
F
P
p
.002 w
.47753 .46721 m .47786 .46667 L p
.48999 .46544 L 1 g
F P
s
P
p
.002 w
.49456 .46474 m .51827 .47357 L p
.48233 .46661 L 1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47675 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5662 .50951 L p
1 g
F P
s
P
p
.55661 .4905 m .5662 .50951 L .56206 .50093 L 1 g
F
P
p
.002 w
.57372 .50932 m .56794 .51312 L p
.5662 .50951 L 1 g
F P
s
P
p
.56516 .49988 m .5662 .50951 L .55747 .49142 L 1 g
F
P
p
.57372 .50932 m .5662 .50951 L .56516 .49988 L 1 g
F
P
p
.002 w
.5662 .50951 m .56515 .50826 L p
.56704 .52053 L 1 g
F P
s
P
p
.002 w
.57372 .50932 m .59255 .5306 L p
.56688 .51748 L 1 g
F P
s
P
p
.002 w
.56668 .51395 m .57372 .50932 L p
.56688 .51748 L 1 g
F P
s
P
p
.56704 .52053 m .56668 .51395 L .5662 .50951 L 1 g
F
P
p
.002 w
.59255 .5306 m .57313 .54341 L .56737 .52651 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.59255 .5306 m .56737 .52651 L .56688 .51748 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.57313 .54341 m .56787 .53723 L .56747 .5287 L 1 g
F
P
p
.002 w
.56737 .52651 m .56777 .5277 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56777 .5277 m .57313 .54341 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56654 .52734 L p
.56448 .53859 L 1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .5671 .52094 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56171 .54747 L p
1 g
F P
s
P
p
.55895 .55431 m .56171 .54747 L .57313 .54341 L 1 g
F
P
p
.002 w
.56209 .54653 m .56257 .5464 L p
.56171 .54747 L 1 g
F P
s
P
p
.002 w
.56257 .5464 m .57313 .54341 L p
.56171 .54747 L 1 g
F P
s
P
p
.002 w
.56171 .54747 m .56075 .54566 L p
.55535 .55545 L 1 g
F P
s
P
p
.56654 .52734 m .56171 .54747 L .56192 .54695 L 1 g
F
P
p
.56654 .52734 m .56177 .54759 L .56448 .53859 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54921 .5631 L p
1 g
F P
s
P
p
.54821 .57587 m .5436 .56947 L .54921 .5631 L 1 g
F
P
p
.002 w
.54965 .5626 m .54963 .56283 L p
.54921 .5631 L 1 g
F P
s
P
p
.002 w
.54963 .56283 m .54821 .57587 L p
.54921 .5631 L 1 g
F P
s
P
p
.002 w
.54921 .5631 m .54854 .56129 L p
.54086 .56861 L 1 g
F P
s
P
p
.56075 .54566 m .54921 .5631 L .54936 .56293 L 1 g
F
P
p
.56075 .54566 m .54923 .56313 L .55535 .55545 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57464 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57464 L .54086 .56861 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54921 .5631 m .5286 .54864 L .54965 .5626 L 1 g
F
P
p
.5436 .56947 m .5423 .56766 L .54921 .5631 L 1 g
F
P
p
.5423 .56766 m .5286 .54864 L .54921 .5631 L 1 g
F
P
p
.002 w
.53032 .57515 m .54821 .57587 L p
.5202 .57812 L 1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51571 .57456 m .5286 .54864 L p
.54407 .57013 L 1 g
F P
s
P
p
.002 w
.54821 .57587 m .53032 .57515 L p
.54407 .57013 L 1 g
F P
s
P
p
.002 w
.54821 .57587 m .54403 .59696 L p
.5202 .57812 L 1 g
F P
s
P
p
.002 w
.53171 .57464 m .53128 .57265 L p
.52118 .57783 L 1 g
F P
s
P
p
.54403 .59696 m .512 .58052 L .5202 .57812 L 1 g
F
P
p
.52118 .57783 m .51673 .58011 L .53032 .57515 L 1 g
F
P
p
.52118 .57783 m .53032 .57515 L .53171 .57464 L 1 g
F
P
p
.002 w
.48889 .583 m .48907 .583 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.54403 .59696 m .50271 .59546 L .51187 .58074 L p
1 g
F P
s
P
p
.002 w
.48907 .583 m .51111 .583 L .51095 .58083 L p
1 g
F P
s
P
p
.002 w
.51095 .58083 m .51095 .58071 L p
.48907 .583 L 1 g
F P
s
P
p
.002 w
.51187 .58074 m .512 .58052 L p
.51234 .58069 L 1 g
F P
s
P
p
.54403 .59696 m .51187 .58074 L .51234 .58069 L 1 g
F
P
p
.002 w
.512 .58052 m .51571 .57456 L p
.5202 .57812 L 1 g
F P
s
P
p
.002 w
.53032 .57515 m .51571 .57456 L p
.54407 .57013 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57464 L p
1 g
F P
s
P
p
.51673 .58011 m .51111 .583 L .53171 .57464 L 1 g
F
P
p
.002 w
.53171 .57464 m .5322 .57686 L p
.54086 .56861 L 1 g
F P
s
P
p
.002 w
.58007 .56676 m .54821 .57587 L .54963 .56283 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54963 .56283 m .55106 .54965 L p
.55992 .55488 L 1 g
F P
s
P
p
.58007 .56676 m .54963 .56283 L .55992 .55488 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54923 .56313 L p
1 g
F P
s
P
p
.002 w
.54923 .56313 m .54921 .5631 L p
.54798 .5641 L 1 g
F P
s
P
p
.54798 .5641 m .5322 .57686 L .54923 .56313 L 1 g
F
P
p
.54086 .56861 m .5322 .57686 L .54921 .5631 L 1 g
F
P
p
.002 w
.54921 .5631 m .54923 .56313 L p
.54936 .56293 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5286 .54864 m .55106 .54965 L .54965 .5626 L p
1 g
F P
s
P
p
.002 w
.55106 .54965 m .56209 .54653 L p
.56171 .54747 L 1 g
F P
s
P
p
.55895 .55431 m .55712 .55323 L .56171 .54747 L 1 g
F
P
p
.55712 .55323 m .55106 .54965 L .56171 .54747 L 1 g
F
P
p
.002 w
.54923 .56313 m .54998 .56518 L p
.55535 .55545 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56171 .54747 L p
1 g
F P
s
P
p
.55535 .55545 m .54998 .56518 L .56171 .54747 L 1 g
F
P
p
.002 w
.56171 .54747 m .56177 .54759 L p
.56192 .54695 L 1 g
F P
s
P
p
.002 w
.57313 .54341 m .58007 .56676 L p
.55895 .55431 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56747 .5287 m .5524 .51905 L .56737 .52651 L 1 g
F
P
p
.56787 .53723 m .56568 .53464 L .56747 .5287 L 1 g
F
P
p
.56568 .53464 m .5524 .51905 L .56747 .5287 L 1 g
F
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.57313 .54341 m .55106 .54965 L .5524 .51905 L p
1 g
F P
s
P
p
.002 w
.56177 .54759 m .56257 .5491 L p
.56448 .53859 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56747 .5287 L p
1 g
F P
s
P
p
.56448 .53859 m .56257 .5491 L .56747 .5287 L 1 g
F
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.5671 .52094 L 1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.5524 .51905 m .56374 .51588 L .56737 .52651 L p
1 g
F P
s
P
p
.002 w
.56737 .52651 m .56374 .51588 L p
.56688 .51748 L 1 g
F P
s
P
p
.002 w
.55978 .49365 m .57372 .50932 L p
.55747 .49142 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55747 .49142 L p
1 g
F P
s
P
p
.002 w
.55747 .49142 m .55661 .4905 L p
.56206 .50093 L 1 g
F P
s
P
p
.56206 .50093 m .56713 .51061 L .55747 .49142 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55747 .49142 L p
1 g
F P
s
P
p
.54174 .47608 m .55747 .49142 L .55407 .48813 L 1 g
F
P
p
.5662 .50951 m .56374 .51588 L .55709 .49062 L 1 g
F
P
p
.002 w
.56794 .51312 m .56668 .51395 L p
.5662 .50951 L 1 g
F P
s
P
p
.002 w
.56668 .51395 m .56374 .51588 L p
.5662 .50951 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56646 .50982 L p
1 g
F P
s
P
p
.002 w
.56646 .50982 m .5662 .50951 L p
.56666 .51362 L 1 g
F P
s
P
p
.56666 .51362 m .56854 .53025 L .56646 .50982 L 1 g
F
P
p
.56704 .52053 m .56824 .5283 L .56668 .51395 L 1 g
F
P
p
.002 w
.56374 .51588 m .56668 .51395 L p
.56688 .51748 L 1 g
F P
s
P
p
.56824 .5283 m .56854 .53025 L .5662 .50951 L 1 g
F
P
p
.002 w
.55215 .48507 m .55709 .49062 L p
.55724 .49119 L 1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56374 .51588 m .55286 .48696 L p
.55724 .49119 L 1 g
F P
s
P
p
.54174 .47608 m .55407 .48813 L .55286 .48696 L 1 g
F
P
p
.002 w
.55286 .48696 m .56374 .51588 L p
.55216 .48628 L 1 g
F P
s
P
p
.55216 .48629 m .55286 .48696 L .55219 .48631 L 1 g
F
P
p
.54174 .47608 m .55286 .48696 L .55216 .48629 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56374 .51588 m .5524 .51905 L .55216 .48628 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55216 .48628 m .55215 .48507 L .55286 .48696 L p
1 g
F P
s
P
p
.002 w
.55286 .48696 m .55215 .48507 L p
.55724 .49119 L 1 g
F P
s
P
p
.55219 .48631 m .55793 .4919 L .55294 .48705 L 1 g
F
P
p
.55407 .48813 m .55793 .4919 L .55219 .48631 L 1 g
F
P
p
.002 w
.55747 .49142 m .55793 .4919 L p
.55407 .48813 L 1 g
F P
s
P
p
.002 w
.55709 .49062 m .55978 .49365 L p
.55747 .49142 L 1 g
F P
s
P
p
.002 w
.5662 .50951 m .56713 .51061 L p
.56206 .50093 L 1 g
F P
s
P
p
.002 w
.54554 .47985 m .5405 .47586 L p
.54235 .47675 L 1 g
F P
s
P
p
.002 w
.5524 .51905 m .54091 .51847 L .55184 .48598 L p
1 g
F P
s
P
p
.002 w
.55184 .48598 m .55215 .48507 L .55216 .48628 L p
1 g
F P
s
P
p
.002 w
.55216 .48628 m .5524 .51905 L p
.55184 .48598 L 1 g
F P
s
P
p
.002 w
.54091 .51847 m .5305 .51418 L .55163 .48577 L p
1 g
F P
s
P
p
.002 w
.55163 .48577 m .55215 .48507 L .55184 .48598 L p
1 g
F P
s
P
p
.002 w
.55184 .48598 m .54091 .51847 L p
.55163 .48577 L 1 g
F P
s
P
p
.002 w
.54235 .47675 m .54174 .47608 L p
.55219 .48632 L 1 g
F P
s
P
p
.002 w
.5305 .51418 m .52229 .50662 L .55143 .48558 L p
1 g
F P
s
P
p
.002 w
.55143 .48558 m .55215 .48507 L .55163 .48577 L p
1 g
F P
s
P
p
.002 w
.55163 .48577 m .5305 .51418 L p
.55143 .48558 L 1 g
F P
s
P
p
.002 w
.52229 .50662 m .51719 .49658 L .55122 .48537 L p
1 g
F P
s
P
p
.002 w
.55122 .48537 m .55215 .48507 L .55143 .48558 L p
1 g
F P
s
P
p
.002 w
.55143 .48558 m .52229 .50662 L p
.55122 .48537 L 1 g
F P
s
P
p
.002 w
.51719 .49658 m .51579 .48515 L .55091 .48507 L p
1 g
F P
s
P
p
.002 w
.55091 .48507 m .55215 .48507 L .55122 .48537 L p
1 g
F P
s
P
p
.002 w
.55122 .48537 m .51719 .49658 L p
.55091 .48507 L 1 g
F P
s
P
p
.55144 .48558 m .55294 .48705 L .55109 .48525 L 1 g
F
P
p
.55153 .48568 m .55164 .48579 L .55144 .48558 L 1 g
F
P
p
.55164 .48579 m .55294 .48705 L .55144 .48558 L 1 g
F
P
p
.55163 .48577 m .55168 .48582 L .55153 .48568 L 1 g
F
P
p
.55168 .48582 m .55294 .48705 L .55153 .48568 L 1 g
F
P
p
.55219 .48632 m .55226 .48638 L .55163 .48577 L 1 g
F
P
p
.55226 .48638 m .55294 .48705 L .55163 .48577 L 1 g
F
P
p
.002 w
.5405 .47586 m .54554 .47985 L p
.52245 .4673 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52253 .46731 L p
1 g
F P
s
P
p
.52205 .46709 m .52253 .46731 L .52245 .4673 L 1 g
F
P
p
.52253 .46731 m .5405 .47586 L .52245 .4673 L 1 g
F
P
p
.5 .4634 m .52253 .46731 L .52196 .46724 L 1 g
F
P
p
.002 w
.52196 .46724 m .51827 .47357 L p
.50278 .46429 L 1 g
F P
s
P
p
.51209 .46572 m .52196 .46724 L .51622 .46652 L 1 g
F
P
p
.5 .4634 m .52196 .46724 L .51209 .46572 L 1 g
F
P
p
.002 w
.51827 .47357 m .49456 .46474 L p
.50278 .46429 L 1 g
F P
s
P
p
.52214 .46667 m .54235 .47675 L .53329 .47244 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .53759 .47487 L p
.52214 .46667 L 1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51209 .46572 L 1 g
F P
s
P
p
.51006 .46225 m .52436 .46312 L .49456 .46474 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46439 L p
1 g
F P
s
P
p
.002 w
.5 .46439 m .5 .46442 L p
.4988 .46454 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46439 L .4988 .46454 L 1 g
F
P
p
.002 w
.48357 .46064 m .48272 .46474 L p
.47753 .46721 L 1 g
F P
s
P
p
.002 w
.45772 .47667 m .45826 .47608 L p
.46684 .47232 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46721 L p
1 g
F P
s
P
p
.002 w
.47753 .46721 m .47718 .46778 L p
.46684 .47232 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46721 L .46684 .47232 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.46509 .46949 m .48357 .46064 L .45307 .4812 L 1 g
F
P
p
.43608 .50497 m .44258 .49136 L .4471 .51308 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45699 .47747 L p
1 g
F P
s
P
p
.44339 .4905 m .45699 .47747 L .45681 .47764 L 1 g
F
P
p
.002 w
.44379 .48883 m .44395 .49004 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44395 .49004 m .4471 .51308 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.45699 .47747 m .45698 .47747 L p
.45681 .47764 L 1 g
F P
s
P
p
.44262 .48026 m .46509 .46949 L .45772 .47667 L 1 g
F
P
p
.002 w
.45307 .4812 m .449 .48083 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.449 .48083 m .44262 .48026 L p
.45772 .47667 L 1 g
F P
s
P
p
.46481 .47329 m .47297 .46779 L .47753 .46721 L 1 g
F
P
p
.47297 .46779 m .48357 .46064 L .47753 .46721 L 1 g
F
P
p
.48357 .46064 m .51006 .46225 L .5 .46386 L 1 g
F
P
p
.002 w
.49456 .46474 m .48676 .46183 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.48676 .46183 m .48357 .46064 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .5 .46386 L p
.51622 .46652 L 1 g
F P
s
P
p
.51209 .46572 m .51622 .46652 L .5 .46386 L 1 g
F
P
p
.002 w
.51827 .47357 m .52196 .46724 L p
.54554 .47985 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .50241 .46477 L p
.51622 .46652 L 1 g
F P
s
P
p
.002 w
.50241 .46477 m .5 .46442 L p
.51622 .46652 L 1 g
F P
s
P
p
.002 w
.52196 .46724 m .52205 .46709 L p
.52245 .4673 L 1 g
F P
s
P
p
.52196 .46724 m .52245 .4673 L .54554 .47985 L 1 g
F
P
p
.002 w
.52723 .4699 m .52282 .46778 L .52256 .46736 L p
1 g
F P
s
P
p
.002 w
.52256 .46736 m .52254 .46733 L p
.52723 .4699 L 1 g
F P
s
P
p
.002 w
.53759 .47487 m .52723 .4699 L p
.52254 .46733 L 1 g
F P
s
P
p
.002 w
.52254 .46733 m .52214 .46667 L p
.53759 .47487 L 1 g
F P
s
P
p
.50278 .46429 m .51514 .46362 L .52196 .46724 L 1 g
F
P
p
.002 w
.52436 .46312 m .52205 .46709 L p
.51514 .46362 L 1 g
F P
s
P
p
.002 w
.52205 .46709 m .52196 .46724 L p
.51514 .46362 L 1 g
F P
s
P
p
.002 w
.52253 .46731 m .52282 .46778 L p
.51622 .46652 L 1 g
F P
s
P
p
.53329 .47244 m .5405 .47586 L .54302 .47747 L 1 g
F
P
p
.002 w
.54235 .47675 m .54235 .47675 L p
.5405 .47586 L 1 g
F P
s
P
p
.002 w
.54235 .47675 m .54302 .47747 L p
.5405 .47586 L 1 g
F P
s
P
p
.002 w
.52205 .46709 m .52436 .46312 L .5405 .47586 L p
1 g
F P
s
P
p
.55219 .48632 m .55134 .48549 L .54235 .47675 L 1 g
F
P
p
.55134 .48549 m .55123 .48538 L .55032 .48449 L 1 g
F
P
p
.55134 .48549 m .55032 .48449 L .54235 .47675 L 1 g
F
P
p
.002 w
.51579 .48515 m .51827 .47357 L .55024 .48442 L p
1 g
F P
s
P
p
.002 w
.55024 .48442 m .55215 .48507 L .55091 .48507 L p
1 g
F P
s
P
p
.002 w
.55091 .48507 m .51579 .48515 L p
.55024 .48442 L 1 g
F P
s
P
p
.55123 .48538 m .54554 .47985 L .54235 .47675 L 1 g
F
P
p
.002 w
.54554 .47985 m .55215 .48507 L .55024 .48442 L p
1 g
F P
s
P
p
.002 w
.55024 .48442 m .51827 .47357 L p
.54554 .47985 L 1 g
F P
s
P
p
.55123 .48538 m .55109 .48525 L .54554 .47985 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54274 .47717 L p
1 g
F P
s
P
p
.002 w
.54274 .47717 m .54235 .47675 L p
.54867 .48291 L 1 g
F P
s
P
p
.54867 .48291 m .55834 .49233 L .54274 .47717 L 1 g
F
P
p
.55294 .48705 m .55834 .49233 L .54235 .47675 L 1 g
F
P
p
.002 w
.5405 .47586 m .52436 .46312 L p
.53769 .47221 L 1 g
F P
s
P
p
.53769 .47221 m .5489 .47986 L .54235 .47675 L 1 g
F
P
p
.53769 .47221 m .54235 .47675 L .5405 .47586 L 1 g
F
P
p
.002 w
.5489 .47986 m .55215 .48507 L .54554 .47985 L p
1 g
F P
s
P
p
.54235 .47675 m .5489 .47986 L .54554 .47985 L 1 g
F
P
p
.002 w
.55793 .4919 m .55834 .49233 L p
.55294 .48705 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.52436 .46312 m .53341 .45498 L .5489 .47986 L p
1 g
F P
s
P
p
.48999 .46544 m .49054 .46538 L .48233 .46661 L 1 g
F
P
p
.49054 .46538 m .4988 .46454 L .48483 .46629 L 1 g
F
P
p
.49054 .46538 m .48483 .46629 L .48233 .46661 L 1 g
F
P
p
.48999 .46544 m .48233 .46661 L .47753 .46721 L 1 g
F
P
p
.002 w
.4788 .48353 m .48233 .46661 L p
.51827 .47357 L 1 g
F P
s
P
p
.002 w
.48233 .46661 m .48357 .46064 L .49456 .46474 L p
1 g
F P
s
P
p
.002 w
.48272 .46474 m .48233 .46661 L p
.47753 .46721 L 1 g
F P
s
P
p
.002 w
.48233 .46661 m .4788 .48353 L p
.47753 .46721 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47753 .46721 L p
1 g
F P
s
P
p
.4988 .46454 m .5 .46442 L .47753 .46721 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45772 .47667 L p
1 g
F P
s
P
p
.46684 .47232 m .47718 .46778 L .45772 .47667 L 1 g
F
P
p
.45057 .48362 m .45121 .48301 L .44395 .49004 L 1 g
F
P
p
.45121 .48301 m .45681 .47764 L .44773 .48639 L 1 g
F
P
p
.45121 .48301 m .44773 .48639 L .44395 .49004 L 1 g
F
P
p
.45057 .48362 m .44395 .49004 L .44258 .49136 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.4471 .51308 m .44395 .49004 L p
.4788 .48353 L 1 g
F P
s
P
p
.002 w
.44395 .49004 m .44262 .48026 L .45307 .4812 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44166 .49233 L p
.43778 .50141 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44258 .49136 L p
1 g
F P
s
P
p
.45681 .47764 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.002 w
.44262 .48026 m .44379 .48883 L p
.44258 .49136 L 1 g
F P
s
P
p
.43868 .49512 m .44262 .48026 L .44258 .49136 L 1 g
F
P
p
.43624 .48874 m .44262 .48026 L .43344 .51493 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43405 .50921 L p
1 g
F P
s
P
p
.43778 .50141 m .44166 .49233 L .43405 .50921 L 1 g
F
P
p
.002 w
.43405 .50921 m .43287 .51061 L p
.43313 .51785 L 1 g
F P
s
P
p
.002 w
.43344 .51493 m .4471 .51308 L p
.43181 .54941 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43281 .52829 L p
1 g
F P
s
P
p
.4332 .51996 m .43287 .51061 L .43281 .52829 L 1 g
F
P
p
.002 w
.43281 .52829 m .43146 .53025 L p
.4362 .53963 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43845 .54716 L p
1 g
F P
s
P
p
.4362 .53963 m .43146 .53025 L .43845 .54716 L 1 g
F
P
p
.002 w
.43845 .54716 m .43743 .5491 L p
.44285 .55381 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4471 .51308 m .46217 .5416 L .44091 .55088 L p
1 g
F P
s
P
p
.002 w
.44091 .55088 m .46217 .5416 L p
.46459 .57868 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45095 .56266 L p
1 g
F P
s
P
p
.445 .55567 m .43743 .5491 L .45095 .56266 L 1 g
F
P
p
.002 w
.45095 .56266 m .45002 .56518 L p
.46098 .56956 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4683 .57459 L p
1 g
F P
s
P
p
.46098 .56956 m .45002 .56518 L .4683 .57459 L 1 g
F
P
p
.002 w
.4683 .57459 m .4678 .57686 L p
.47589 .57753 L 1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46217 .5416 m .48595 .5628 L .4708 .57556 L p
1 g
F P
s
P
p
.002 w
.4708 .57556 m .48595 .5628 L p
.49558 .58157 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48911 .58 L p
1 g
F P
s
P
p
.48047 .5779 m .4678 .57686 L .48911 .58 L 1 g
F
P
p
.002 w
.48911 .58 m .48889 .583 L p
.50184 .58041 L 1 g
F P
s
P
p
.51095 .58071 m .48595 .5628 L .512 .58052 L 1 g
F
P
p
.49487 .58018 m .48595 .5628 L .51095 .58071 L 1 g
F
P
p
.50184 .58041 m .48889 .583 L .51095 .58071 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48595 .5628 m .51571 .57456 L .512 .58052 L p
1 g
F P
s
P
p
.002 w
.51095 .58071 m .51095 .58083 L p
.5115 .58061 L 1 g
F P
s
P
p
.002 w
.51095 .58083 m .51111 .583 L p
.52118 .57783 L 1 g
F P
s
P
p
.002 w
.51571 .57456 m .53032 .57515 L p
.5202 .57812 L 1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.43418 .55382 m .46472 .58067 L .44516 .59358 L p
1 g
F P
s
P
p
.002 w
.44516 .59358 m .40888 .56203 L .43418 .55382 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.36287 .4051 m .35198 .46237 L .33106 .45458 L p
1 g
F P
s
P
p
.002 w
.33106 .45458 m .34261 .39288 L .36287 .4051 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.64229 .35184 m .60252 .32386 L .60369 .29942 L p
1 g
F P
s
P
p
.002 w
.54957 .28473 m .60369 .29942 L .60252 .32386 L p
1 g
F P
s
P
p
.002 w
.64179 .49148 m .644 .45891 L .66564 .44856 L p
1 g
F P
s
P
p
.002 w
.65513 .40908 m .66564 .44856 L .644 .45891 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52802 .45983 L
s
P
p
.002 w
.37808 .46944 m .38549 .51916 L .36056 .51815 L p
1 g
F P
s
P
p
.002 w
.36056 .51815 m .35198 .46237 L .37808 .46944 L p
1 g
F P
s
P
p
.002 w
.54957 .28473 m .4918 .28926 L .48136 .26825 L p
1 g
F P
s
P
p
.002 w
.42252 .29363 m .48136 .26825 L .4918 .28926 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.65513 .40908 m .63193 .37572 L .64229 .35184 L p
1 g
F P
s
P
p
.002 w
.60252 .32386 m .64229 .35184 L .63193 .37572 L p
1 g
F P
s
P
p
.002 w
.3924 .35317 m .36287 .4051 L .34261 .39288 L p
1 g
F P
s
P
p
.002 w
.34261 .39288 m .3743 .33693 L .3924 .35317 L p
1 g
F P
s
P
p
.002 w
.41464 .51748 m .43418 .55382 L .40888 .56203 L p
1 g
F P
s
P
p
.002 w
.40888 .56203 m .38549 .51916 L .41464 .51748 L p
1 g
F P
s
P
p
.002 w
.57313 .54341 m .59255 .5306 L .60805 .54826 L p
1 g
F P
s
P
p
.002 w
.60805 .54826 m .58007 .56676 L .57313 .54341 L p
1 g
F P
s
P
p
.002 w
.62935 .5223 m .60805 .54826 L .59255 .5306 L p
1 g
F P
s
P
p
.002 w
.59255 .5306 m .60731 .51259 L .62935 .5223 L p
1 g
F P
s
P
p
.002 w
.64179 .49148 m .62935 .5223 L .60731 .51259 L p
1 g
F P
s
P
p
.002 w
.4918 .28926 m .43719 .31294 L .42252 .29363 L p
1 g
F P
s
P
p
.002 w
.3743 .33693 m .42252 .29363 L .43719 .31294 L p
1 g
F P
s
P
p
.002 w
.43719 .31294 m .3924 .35317 L .3743 .33693 L p
1 g
F P
s
P
p
.002 w
.644 .45891 m .63559 .42795 L .65513 .40908 L p
1 g
F P
s
P
p
.002 w
.63193 .37572 m .65513 .40908 L .63559 .42795 L p
1 g
F P
s
P
p
.002 w
.60731 .51259 m .61587 .49122 L .64179 .49148 L p
1 g
F P
s
P
p
.002 w
.644 .45891 m .64179 .49148 L .61587 .49122 L p
1 g
F P
s
P
p
.002 w
.60252 .32386 m .55425 .31101 L .54957 .28473 L p
1 g
F P
s
P
p
.002 w
.4918 .28926 m .54957 .28473 L .55425 .31101 L p
1 g
F P
s
P
p
.002 w
.38798 .41847 m .37808 .46944 L .35198 .46237 L p
1 g
F P
s
P
p
.002 w
.35198 .46237 m .36287 .4051 L .38798 .41847 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.63193 .37572 m .59818 .35228 L .60252 .32386 L p
1 g
F P
s
P
p
.002 w
.55425 .31101 m .60252 .32386 L .59818 .35228 L p
1 g
F P
s
P
p
.002 w
.61587 .49122 m .6173 .4687 L .644 .45891 L p
1 g
F P
s
P
p
.002 w
.63559 .42795 m .644 .45891 L .6173 .4687 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.50815 .5404 m .5286 .54864 L .51571 .57456 L p
1 g
F P
s
P
p
.002 w
.51571 .57456 m .48595 .5628 L .50815 .5404 L p
1 g
F P
s
P
p
.002 w
.40863 .47549 m .41464 .51748 L .38549 .51916 L p
1 g
F P
s
P
p
.002 w
.38549 .51916 m .37808 .46944 L .40863 .47549 L p
1 g
F P
s
P
p
.002 w
.63559 .42795 m .61724 .40193 L .63193 .37572 L p
1 g
F P
s
P
p
.002 w
.59818 .35228 m .63193 .37572 L .61724 .40193 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.55425 .31101 m .50281 .31525 L .4918 .28926 L p
1 g
F P
s
P
p
.002 w
.43719 .31294 m .4918 .28926 L .50281 .31525 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41435 .37228 m .38798 .41847 L .36287 .4051 L p
1 g
F P
s
P
p
.002 w
.36287 .4051 m .3924 .35317 L .41435 .37228 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60731 .51259 m .59255 .5306 L .57372 .50932 L p
1 g
F P
s
P
p
.002 w
.6173 .4687 m .61137 .44738 L .63559 .42795 L p
1 g
F P
s
P
p
.002 w
.61724 .40193 m .63559 .42795 L .61137 .44738 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.57372 .50932 m .5813 .50006 L .60731 .51259 L p
1 g
F P
s
P
p
.002 w
.61587 .49122 m .60731 .51259 L .5813 .50006 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.50281 .31525 m .45423 .33644 L .43719 .31294 L p
1 g
F P
s
P
p
.002 w
.3924 .35317 m .43719 .31294 L .45423 .33644 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.4919 .5257 m .50815 .5404 L .48595 .5628 L p
1 g
F P
s
P
p
.002 w
.48595 .5628 m .46217 .5416 L .4919 .5257 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.45423 .33644 m .41435 .37228 L .3924 .35317 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59818 .35228 m .55737 .34168 L .55425 .31101 L p
1 g
F P
s
P
p
.002 w
.50281 .31525 m .55425 .31101 L .55737 .34168 L p
1 g
F P
s
P
p
.002 w
.5813 .50006 m .58566 .48908 L .61587 .49122 L p
1 g
F P
s
P
p
.002 w
.6173 .4687 m .61587 .49122 L .58566 .48908 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.54091 .51847 m .5524 .51905 L .55106 .54965 L p
1 g
F P
s
P
p
.002 w
.55106 .54965 m .5286 .54864 L .54091 .51847 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.41716 .43254 m .40863 .47549 L .37808 .46944 L p
1 g
F P
s
P
p
.002 w
.37808 .46944 m .38798 .41847 L .41716 .43254 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.61724 .40193 m .59071 .38378 L .59818 .35228 L p
1 g
F P
s
P
p
.002 w
.55737 .34168 m .59818 .35228 L .59071 .38378 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58566 .48908 m .58633 .47754 L .6173 .4687 L p
1 g
F P
s
P
p
.002 w
.61137 .44738 m .6173 .4687 L .58633 .47754 L p
1 g
F P
s
P
p
.002 w
.41464 .51748 m .40863 .47549 L .44262 .48026 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.5305 .51418 m .54091 .51847 L .5286 .54864 L p
1 g
F P
s
P
p
.002 w
.5286 .54864 m .50815 .5404 L .5305 .51418 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.61137 .44738 m .59861 .42958 L .61724 .40193 L p
1 g
F P
s
P
p
.002 w
.59071 .38378 m .61724 .40193 L .59861 .42958 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.48172 .50604 m .4919 .5257 L .46217 .5416 L p
1 g
F P
s
P
p
.002 w
.46217 .5416 m .4471 .51308 L .48172 .50604 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55737 .34168 m .514 .34545 L .50281 .31525 L p
1 g
F P
s
P
p
.002 w
.45423 .33644 m .50281 .31525 L .514 .34545 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43948 .39364 m .41716 .43254 L .38798 .41847 L p
1 g
F P
s
P
p
.002 w
.38798 .41847 m .41435 .37228 L .43948 .39364 L p
1 g
F P
s
P
p
.002 w
.58633 .47754 m .58322 .46667 L .61137 .44738 L p
1 g
F P
s
P
p
.002 w
.59861 .42958 m .61137 .44738 L .58322 .46667 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.52229 .50662 m .5305 .51418 L .50815 .5404 L p
1 g
F P
s
P
p
.002 w
.50815 .5404 m .4919 .5257 L .52229 .50662 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5813 .50006 m .57372 .50932 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.58566 .48908 m .5813 .50006 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.59071 .38378 m .55878 .37571 L .55737 .34168 L p
1 g
F P
s
P
p
.002 w
.514 .34545 m .55737 .34168 L .55878 .37571 L p
1 g
F P
s
P
p
.002 w
.514 .34545 m .47309 .36343 L .45423 .33644 L p
1 g
F P
s
P
p
.002 w
.41435 .37228 m .45423 .33644 L .47309 .36343 L p
1 g
F P
s
P
p
.002 w
.58633 .47754 m .58566 .48908 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.47309 .36343 m .43948 .39364 L .41435 .37228 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.59861 .42958 m .58029 .41726 L .59071 .38378 L p
1 g
F P
s
P
p
.002 w
.55878 .37571 m .59071 .38378 L .58029 .41726 L p
1 g
F P
s
P
p
.002 w
.44943 .44678 m .44262 .48026 L .40863 .47549 L p
1 g
F P
s
P
p
.002 w
.40863 .47549 m .41716 .43254 L .44943 .44678 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58322 .46667 m .57664 .45765 L .59861 .42958 L p
1 g
F P
s
P
p
.002 w
.58029 .41726 m .59861 .42958 L .57664 .45765 L p
1 g
F P
s
P
p
.002 w
.58322 .46667 m .58633 .47754 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.4788 .48353 m .48172 .50604 L .4471 .51308 L p
1 g
F P
s
P
p
.002 w
.51719 .49658 m .52229 .50662 L .4919 .5257 L p
1 g
F P
s
P
p
.002 w
.4919 .5257 m .48172 .50604 L .51719 .49658 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57664 .45765 m .58322 .46667 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55878 .37571 m .52495 .37883 L .514 .34545 L p
1 g
F P
s
P
p
.002 w
.47309 .36343 m .514 .34545 L .52495 .37883 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.4669 .4165 m .44943 .44678 L .41716 .43254 L p
1 g
F P
s
P
p
.002 w
.41716 .43254 m .43948 .39364 L .4669 .4165 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57664 .45765 m .56728 .45147 L .58029 .41726 L p
1 g
F P
s
P
p
.002 w
.55837 .41189 m .58029 .41726 L .56728 .45147 L p
1 g
F P
s
P
p
.002 w
.58029 .41726 m .55837 .41189 L .55878 .37571 L p
1 g
F P
s
P
p
.002 w
.56728 .45147 m .57664 .45765 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.52495 .37883 m .55878 .37571 L .55837 .41189 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.51579 .48515 m .51719 .49658 L .48172 .50604 L p
1 g
F P
s
P
p
.002 w
.48172 .50604 m .4788 .48353 L .51579 .48515 L p
1 g
F P
s
P
p
.002 w
.44262 .48026 m .44943 .44678 L .48357 .46064 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.55613 .44882 m .56728 .45147 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.54441 .45003 m .55613 .44882 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.53341 .45498 m .54441 .45003 L .55215 .48507 L closepath p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52495 .37883 m .49309 .39294 L .47309 .36343 L p
1 g
F P
s
P
p
.002 w
.43948 .39364 m .47309 .36343 L .49309 .39294 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.49309 .39294 m .4669 .4165 L .43948 .39364 L p
1 g
F P
s
P
p
.002 w
.56728 .45147 m .55613 .44882 L .55837 .41189 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.004 w
.55215 .48507 m
.55382 .48682 L
s
P
p
.002 w
.53522 .41415 m .55837 .41189 L .55613 .44882 L p
1 g
F P
s
P
p
.002 w
.55837 .41189 m .53522 .41415 L .52495 .37883 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55613 .44882 m .54441 .45003 L .53522 .41415 L p
1 g
F P
s
P
p
.002 w
.49309 .39294 m .52495 .37883 L .53522 .41415 L p
1 g
F P
s
P
p
.002 w
.51827 .47357 m .51579 .48515 L .4788 .48353 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49557 .43997 m .48357 .46064 L .44943 .44678 L p
1 g
F P
s
P
p
.002 w
.44943 .44678 m .4669 .4165 L .49557 .43997 L p
1 g
F P
s
P
p
.002 w
.54441 .45003 m .53341 .45498 L .51347 .42386 L p
1 g
F P
s
P
p
.002 w
.51347 .42386 m .53522 .41415 L .54441 .45003 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53341 .45498 m .52436 .46312 L .49557 .43997 L p
1 g
F P
s
P
p
.002 w
.49557 .43997 m .51347 .42386 L .53341 .45498 L p
1 g
F P
s
P
p
.002 w
.48357 .46064 m .49557 .43997 L .52436 .46312 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53522 .41415 m .51347 .42386 L .49309 .39294 L p
1 g
F P
s
P
p
.002 w
.4669 .4165 m .49309 .39294 L .51347 .42386 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51347 .42386 m .49557 .43997 L .4669 .4165 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.55382 .48682 m
.58417 .51857 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .44346 .71359 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58417 .51857 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.249612)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.249612)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47806 .4722 m .50932 .45676 L .4931 .4333 L p
1 g
F P
s
P
p
.002 w
.4931 .4333 m .46889 .44519 L .47806 .4722 L p
1 g
F P
s
P
p
.002 w
.51298 .41489 m .4931 .4333 L .50932 .45676 L p
1 g
F P
s
P
p
.002 w
.46889 .44519 m .4931 .4333 L .47704 .40976 L p
1 g
F P
s
P
p
.002 w
.4931 .4333 m .51298 .41489 L .49062 .39717 L p
1 g
F P
s
P
p
.002 w
.49062 .39717 m .47704 .40976 L .4931 .4333 L p
1 g
F P
s
P
p
.002 w
.50932 .45676 m .53504 .43299 L .51298 .41489 L p
1 g
F P
s
P
p
.002 w
.52653 .39181 m .51298 .41489 L .53504 .43299 L p
1 g
F P
s
P
p
.002 w
.51298 .41489 m .52653 .39181 L .49981 .38137 L p
1 g
F P
s
P
p
.002 w
.49981 .38137 m .49062 .39717 L .51298 .41489 L p
1 g
F P
s
P
p
.002 w
.48783 .4984 m .52542 .47973 L .50932 .45676 L p
1 g
F P
s
P
p
.002 w
.50932 .45676 m .47806 .4722 L .48783 .4984 L p
1 g
F P
s
P
p
.002 w
.53504 .43299 m .50932 .45676 L .52542 .47973 L p
1 g
F P
s
P
p
.002 w
.47704 .40976 m .46048 .41784 L .46889 .44519 L p
1 g
F P
s
P
p
.002 w
.46048 .41784 m .47704 .40976 L .46143 .38657 L p
1 g
F P
s
P
p
.002 w
.47704 .40976 m .49062 .39717 L .46834 .38015 L p
1 g
F P
s
P
p
.002 w
.46834 .38015 m .46143 .38657 L .47704 .40976 L p
1 g
F P
s
P
p
.002 w
.44428 .47774 m .47806 .4722 L .46889 .44519 L p
1 g
F P
s
P
p
.002 w
.46889 .44519 m .44276 .44933 L .44428 .47774 L p
1 g
F P
s
P
p
.002 w
.44276 .44933 m .46889 .44519 L .46048 .41784 L p
1 g
F P
s
P
p
.002 w
.49062 .39717 m .49981 .38137 L .47299 .37209 L p
1 g
F P
s
P
p
.002 w
.47299 .37209 m .46834 .38015 L .49062 .39717 L p
1 g
F P
s
P
p
.002 w
.52542 .47973 m .55638 .45115 L .53504 .43299 L p
1 g
F P
s
P
p
.002 w
.55267 .40321 m .53504 .43299 L .55638 .45115 L p
1 g
F P
s
P
p
.002 w
.53504 .43299 m .55267 .40321 L .52653 .39181 L p
1 g
F P
s
P
p
.002 w
.46048 .41784 m .44264 .42057 L .44276 .44933 L p
1 g
F P
s
P
p
.002 w
.44264 .42057 m .46048 .41784 L .45299 .39066 L p
1 g
F P
s
P
p
.002 w
.46143 .38657 m .45299 .39066 L .46048 .41784 L p
1 g
F P
s
P
p
.002 w
.53232 .36633 m .52653 .39181 L .55267 .40321 L p
1 g
F P
s
P
p
.002 w
.52653 .39181 m .53232 .36633 L .50364 .36397 L p
1 g
F P
s
P
p
.002 w
.50364 .36397 m .49981 .38137 L .52653 .39181 L p
1 g
F P
s
P
p
.002 w
.44718 .50527 m .48783 .4984 L .47806 .4722 L p
1 g
F P
s
P
p
.002 w
.47806 .4722 m .44428 .47774 L .44718 .50527 L p
1 g
F P
s
P
p
.002 w
.49981 .38137 m .50364 .36397 L .47488 .36324 L p
1 g
F P
s
P
p
.002 w
.47488 .36324 m .47299 .37209 L .49981 .38137 L p
1 g
F P
s
P
p
.002 w
.49803 .52328 m .54108 .50177 L .52542 .47973 L p
1 g
F P
s
P
p
.002 w
.52542 .47973 m .48783 .4984 L .49803 .52328 L p
1 g
F P
s
P
p
.002 w
.55638 .45115 m .52542 .47973 L .54108 .50177 L p
1 g
F P
s
P
p
.002 w
.41734 .44518 m .44276 .44933 L .44264 .42057 L p
1 g
F P
s
P
p
.002 w
.44264 .42057 m .42534 .41761 L .41734 .44518 L p
1 g
F P
s
P
p
.002 w
.42534 .41761 m .44264 .42057 L .44391 .392 L p
1 g
F P
s
P
p
.002 w
.45299 .39066 m .44391 .392 L .44264 .42057 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .45299 .39066 L .46143 .38657 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .46143 .38657 L .46834 .38015 L closepath p
1 g
F P
s
P
p
.002 w
.55638 .45115 m .57774 .41536 L .55267 .40321 L p
1 g
F P
s
P
p
.002 w
.56037 .37026 m .55267 .40321 L .57774 .41536 L p
1 g
F P
s
P
p
.002 w
.55267 .40321 m .56037 .37026 L .53232 .36633 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .46834 .38015 L .47299 .37209 L closepath p
1 g
F P
s
P
p
.002 w
.54108 .50177 m .57661 .46903 L .55638 .45115 L p
1 g
F P
s
P
p
.002 w
.57774 .41536 m .55638 .45115 L .57661 .46903 L p
1 g
F P
s
P
p
.002 w
.41131 .47262 m .44428 .47774 L .44276 .44933 L p
1 g
F P
s
P
p
.002 w
.44276 .44933 m .41734 .44518 L .41131 .47262 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .44391 .392 L .45299 .39066 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .47299 .37209 L .47488 .36324 L closepath p
1 g
F P
s
P
p
.002 w
.50164 .34677 m .50364 .36397 L .53232 .36633 L p
1 g
F P
s
P
p
.002 w
.50364 .36397 m .50164 .34677 L .47379 .35453 L p
1 g
F P
s
P
p
.002 w
.47379 .35453 m .47488 .36324 L .50364 .36397 L p
1 g
F P
s
P
p
.002 w
.44391 .392 m .43515 .39043 L .42534 .41761 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .43515 .39043 L .44391 .392 L closepath p
1 g
F P
s
P
p
.002 w
.45143 .53139 m .49803 .52328 L .48783 .4984 L p
1 g
F P
s
P
p
.002 w
.48783 .4984 m .44718 .50527 L .45143 .53139 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .47488 .36324 L .47379 .35453 L closepath p
1 g
F P
s
P
p
.002 w
.5296 .34104 m .53232 .36633 L .56037 .37026 L p
1 g
F P
s
P
p
.002 w
.53232 .36633 m .5296 .34104 L .50164 .34677 L p
1 g
F P
s
P
p
.002 w
.40739 .49939 m .44718 .50527 L .44428 .47774 L p
1 g
F P
s
P
p
.002 w
.44428 .47774 m .41131 .47262 L .40739 .49939 L p
1 g
F P
s
P
p
.002 w
.39531 .43301 m .41734 .44518 L .42534 .41761 L p
1 g
F P
s
P
p
.002 w
.42534 .41761 m .41044 .4092 L .39531 .43301 L p
1 g
F P
s
P
p
.002 w
.41044 .4092 m .42534 .41761 L .43515 .39043 L p
1 g
F P
s
P
p
.002 w
.43515 .39043 m .42764 .3861 L .41044 .4092 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .42764 .3861 L .43515 .39043 L closepath p
1 g
F P
s
P
p
.002 w
.57661 .46903 m .60125 .42807 L .57774 .41536 L p
1 g
F P
s
P
p
.002 w
.58726 .37573 m .57774 .41536 L .60125 .42807 L p
1 g
F P
s
P
p
.002 w
.57774 .41536 m .58726 .37573 L .56037 .37026 L p
1 g
F P
s
P
p
.002 w
.46981 .3469 m .47379 .35453 L .50164 .34677 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .47379 .35453 L .46981 .3469 L closepath p
1 g
F P
s
P
p
.002 w
.50847 .54634 m .55602 .52246 L .54108 .50177 L p
1 g
F P
s
P
p
.002 w
.54108 .50177 m .49803 .52328 L .50847 .54634 L p
1 g
F P
s
P
p
.002 w
.57661 .46903 m .54108 .50177 L .55602 .52246 L p
1 g
F P
s
P
p
.002 w
.49393 .33161 m .50164 .34677 L .5296 .34104 L p
1 g
F P
s
P
p
.002 w
.50164 .34677 m .49393 .33161 L .46981 .3469 L p
1 g
F P
s
P
p
.002 w
.38258 .45709 m .41131 .47262 L .41734 .44518 L p
1 g
F P
s
P
p
.002 w
.41734 .44518 m .39531 .43301 L .38258 .45709 L p
1 g
F P
s
P
p
.002 w
.39957 .39613 m .41044 .4092 L .42764 .3861 L p
1 g
F P
s
P
p
.002 w
.42764 .3861 m .42222 .37944 L .39957 .39613 L p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .42222 .37944 L .42764 .3861 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .46981 .3469 L .46336 .34119 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .46336 .34119 L .4551 .33803 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .4551 .33803 L .44595 .3378 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .44595 .3378 L .4369 .34054 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .4369 .34054 L .42897 .34596 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .42897 .34596 L .42304 .35345 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .42304 .35345 L .41976 .36217 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .41976 .36217 L .41948 .37117 L closepath p
1 g
F P
s
P
p
.002 w
.44657 .36415 m .41948 .37117 L .42222 .37944 L closepath p
1 g
F P
s
P
p
.002 w
.55712 .33745 m .56037 .37026 L .58726 .37573 L p
1 g
F P
s
P
p
.002 w
.56037 .37026 m .55712 .33745 L .5296 .34104 L p
1 g
F P
s
P
p
.002 w
.55602 .52246 m .59532 .48629 L .57661 .46903 L p
1 g
F P
s
P
p
.002 w
.60125 .42807 m .57661 .46903 L .59532 .48629 L p
1 g
F P
s
P
p
.002 w
.46336 .34119 m .46981 .3469 L .49393 .33161 L p
1 g
F P
s
P
p
.002 w
.40571 .52496 m .45143 .53139 L .44718 .50527 L p
1 g
F P
s
P
p
.002 w
.44718 .50527 m .40739 .49939 L .40571 .52496 L p
1 g
F P
s
P
p
.002 w
.37911 .41392 m .39531 .43301 L .41044 .4092 L p
1 g
F P
s
P
p
.002 w
.41044 .4092 m .39957 .39613 L .37911 .41392 L p
1 g
F P
s
P
p
.002 w
.45699 .55554 m .50847 .54634 L .49803 .52328 L p
1 g
F P
s
P
p
.002 w
.49803 .52328 m .45143 .53139 L .45699 .55554 L p
1 g
F P
s
P
p
.002 w
.39399 .37977 m .39957 .39613 L .42222 .37944 L p
1 g
F P
s
P
p
.002 w
.42222 .37944 m .41948 .37117 L .39399 .37977 L p
1 g
F P
s
P
p
.002 w
.51847 .31861 m .5296 .34104 L .55712 .33745 L p
1 g
F P
s
P
p
.002 w
.5296 .34104 m .51847 .31861 L .49393 .33161 L p
1 g
F P
s
P
p
.002 w
.49393 .33161 m .48125 .32017 L .46336 .34119 L p
1 g
F P
s
P
p
.002 w
.4551 .33803 m .46336 .34119 L .48125 .32017 L p
1 g
F P
s
P
p
.002 w
.37255 .48095 m .40739 .49939 L .41131 .47262 L p
1 g
F P
s
P
p
.002 w
.41131 .47262 m .38258 .45709 L .37255 .48095 L p
1 g
F P
s
P
p
.002 w
.48125 .32017 m .49393 .33161 L .51847 .31861 L p
1 g
F P
s
P
p
.002 w
.39442 .36187 m .39399 .37977 L .41948 .37117 L p
1 g
F P
s
P
p
.002 w
.41948 .37117 m .41976 .36217 L .39442 .36187 L p
1 g
F P
s
P
p
.002 w
.59532 .48629 m .62272 .44109 L .60125 .42807 L p
1 g
F P
s
P
p
.002 w
.61245 .38266 m .60125 .42807 L .62272 .44109 L p
1 g
F P
s
P
p
.002 w
.60125 .42807 m .61245 .38266 L .58726 .37573 L p
1 g
F P
s
P
p
.002 w
.48125 .32017 m .4649 .31376 L .4551 .33803 L p
1 g
F P
s
P
p
.002 w
.44595 .3378 m .4551 .33803 L .4649 .31376 L p
1 g
F P
s
P
p
.002 w
.58367 .33612 m .58726 .37573 L .61245 .38266 L p
1 g
F P
s
P
p
.002 w
.58726 .37573 m .58367 .33612 L .55712 .33745 L p
1 g
F P
s
P
p
.002 w
.36128 .43246 m .38258 .45709 L .39531 .43301 L p
1 g
F P
s
P
p
.002 w
.39531 .43301 m .37911 .41392 L .36128 .43246 L p
1 g
F P
s
P
p
.002 w
.40089 .34443 m .39442 .36187 L .41976 .36217 L p
1 g
F P
s
P
p
.002 w
.41976 .36217 m .42304 .35345 L .40089 .34443 L p
1 g
F P
s
P
p
.002 w
.37066 .38981 m .37911 .41392 L .39957 .39613 L p
1 g
F P
s
P
p
.002 w
.39957 .39613 m .39399 .37977 L .37066 .38981 L p
1 g
F P
s
P
p
.002 w
.4649 .31376 m .44667 .3132 L .44595 .3378 L p
1 g
F P
s
P
p
.002 w
.4369 .34054 m .44595 .3378 L .44667 .3132 L p
1 g
F P
s
P
p
.002 w
.51896 .56706 m .56992 .54135 L .55602 .52246 L p
1 g
F P
s
P
p
.002 w
.55602 .52246 m .50847 .54634 L .51896 .56706 L p
1 g
F P
s
P
p
.002 w
.59532 .48629 m .55602 .52246 L .56992 .54135 L p
1 g
F P
s
P
p
.002 w
.41272 .32943 m .40089 .34443 L .42304 .35345 L p
1 g
F P
s
P
p
.002 w
.42304 .35345 m .42897 .34596 L .41272 .32943 L p
1 g
F P
s
P
p
.002 w
.54295 .30819 m .55712 .33745 L .58367 .33612 L p
1 g
F P
s
P
p
.002 w
.55712 .33745 m .54295 .30819 L .51847 .31861 L p
1 g
F P
s
P
p
.002 w
.44667 .3132 m .42858 .31862 L .4369 .34054 L p
1 g
F P
s
P
p
.002 w
.42897 .34596 m .4369 .34054 L .42858 .31862 L p
1 g
F P
s
P
p
.002 w
.42858 .31862 m .41272 .32943 L .42897 .34596 L p
1 g
F P
s
P
p
.002 w
.56992 .54135 m .6121 .50257 L .59532 .48629 L p
1 g
F P
s
P
p
.002 w
.62272 .44109 m .59532 .48629 L .6121 .50257 L p
1 g
F P
s
P
p
.002 w
.51847 .31861 m .49992 .30155 L .48125 .32017 L p
1 g
F P
s
P
p
.002 w
.4649 .31376 m .48125 .32017 L .49992 .30155 L p
1 g
F P
s
P
p
.002 w
.40639 .54876 m .45699 .55554 L .45143 .53139 L p
1 g
F P
s
P
p
.002 w
.45143 .53139 m .40571 .52496 L .40639 .54876 L p
1 g
F P
s
P
p
.002 w
.49992 .30155 m .51847 .31861 L .54295 .30819 L p
1 g
F P
s
P
p
.002 w
.36553 .50411 m .40571 .52496 L .40739 .49939 L p
1 g
F P
s
P
p
.002 w
.40739 .49939 m .37255 .48095 L .36553 .50411 L p
1 g
F P
s
P
p
.002 w
.46379 .57715 m .51896 .56706 L .50847 .54634 L p
1 g
F P
s
P
p
.002 w
.50847 .54634 m .45699 .55554 L .46379 .57715 L p
1 g
F P
s
P
p
.002 w
.37112 .36329 m .37066 .38981 L .39399 .37977 L p
1 g
F P
s
P
p
.002 w
.39399 .37977 m .39442 .36187 L .37112 .36329 L p
1 g
F P
s
P
p
.002 w
.34656 .45141 m .37255 .48095 L .38258 .45709 L p
1 g
F P
s
P
p
.002 w
.38258 .45709 m .36128 .43246 L .34656 .45141 L p
1 g
F P
s
P
p
.002 w
.49992 .30155 m .47581 .29189 L .4649 .31376 L p
1 g
F P
s
P
p
.002 w
.44667 .3132 m .4649 .31376 L .47581 .29189 L p
1 g
F P
s
P
p
.002 w
.35003 .40115 m .36128 .43246 L .37911 .41392 L p
1 g
F P
s
P
p
.002 w
.37911 .41392 m .37066 .38981 L .35003 .40115 L p
1 g
F P
s
P
p
.002 w
.62272 .44109 m .63538 .39095 L .61245 .38266 L p
1 g
F P
s
P
p
.002 w
.60868 .33715 m .61245 .38266 L .63538 .39095 L p
1 g
F P
s
P
p
.002 w
.61245 .38266 m .60868 .33715 L .58367 .33612 L p
1 g
F P
s
P
p
.002 w
.6121 .50257 m .64163 .45418 L .62272 .44109 L p
1 g
F P
s
P
p
.002 w
.63538 .39095 m .62272 .44109 L .64163 .45418 L p
1 g
F P
s
P
p
.002 w
.38063 .33734 m .37112 .36329 L .39442 .36187 L p
1 g
F P
s
P
p
.002 w
.39442 .36187 m .40089 .34443 L .38063 .33734 L p
1 g
F P
s
P
p
.002 w
.56687 .30063 m .58367 .33612 L .60868 .33715 L p
1 g
F P
s
P
p
.002 w
.58367 .33612 m .56687 .30063 L .54295 .30819 L p
1 g
F P
s
P
p
.002 w
.47581 .29189 m .44876 .29092 L .44667 .3132 L p
1 g
F P
s
P
p
.002 w
.42858 .31862 m .44667 .3132 L .44876 .29092 L p
1 g
F P
s
P
p
.002 w
.54295 .30819 m .519 .28578 L .49992 .30155 L p
1 g
F P
s
P
p
.002 w
.47581 .29189 m .49992 .30155 L .519 .28578 L p
1 g
F P
s
P
p
.002 w
.519 .28578 m .54295 .30819 L .56687 .30063 L p
1 g
F P
s
P
p
.002 w
.52928 .58491 m .58245 .55797 L .56992 .54135 L p
1 g
F P
s
P
p
.002 w
.56992 .54135 m .51896 .56706 L .52928 .58491 L p
1 g
F P
s
P
p
.002 w
.6121 .50257 m .56992 .54135 L .58245 .55797 L p
1 g
F P
s
P
p
.002 w
.3982 .31499 m .38063 .33734 L .40089 .34443 L p
1 g
F P
s
P
p
.002 w
.40089 .34443 m .41272 .32943 L .3982 .31499 L p
1 g
F P
s
P
p
.002 w
.4095 .57019 m .46379 .57715 L .45699 .55554 L p
1 g
F P
s
P
p
.002 w
.45699 .55554 m .40639 .54876 L .4095 .57019 L p
1 g
F P
s
P
p
.002 w
.44876 .29092 m .42184 .2989 L .42858 .31862 L p
1 g
F P
s
P
p
.002 w
.41272 .32943 m .42858 .31862 L .42184 .2989 L p
1 g
F P
s
P
p
.002 w
.58245 .55797 m .62652 .5175 L .6121 .50257 L p
1 g
F P
s
P
p
.002 w
.64163 .45418 m .6121 .50257 L .62652 .5175 L p
1 g
F P
s
P
p
.002 w
.36178 .52601 m .40639 .54876 L .40571 .52496 L p
1 g
F P
s
P
p
.002 w
.40571 .52496 m .36553 .50411 L .36178 .52601 L p
1 g
F P
s
P
p
.002 w
.42184 .2989 m .3982 .31499 L .41272 .32943 L p
1 g
F P
s
P
p
.002 w
.35044 .36648 m .35003 .40115 L .37066 .38981 L p
1 g
F P
s
P
p
.002 w
.37066 .38981 m .37112 .36329 L .35044 .36648 L p
1 g
F P
s
P
p
.002 w
.33539 .47037 m .36553 .50411 L .37255 .48095 L p
1 g
F P
s
P
p
.002 w
.37255 .48095 m .34656 .45141 L .33539 .47037 L p
1 g
F P
s
P
p
.002 w
.47174 .59565 m .52928 .58491 L .51896 .56706 L p
1 g
F P
s
P
p
.002 w
.51896 .56706 m .46379 .57715 L .47174 .59565 L p
1 g
F P
s
P
p
.002 w
.33267 .41357 m .34656 .45141 L .36128 .43246 L p
1 g
F P
s
P
p
.002 w
.36128 .43246 m .35003 .40115 L .33267 .41357 L p
1 g
F P
s
P
p
.002 w
.519 .28578 m .48764 .27296 L .47581 .29189 L p
1 g
F P
s
P
p
.002 w
.44876 .29092 m .47581 .29189 L .48764 .27296 L p
1 g
F P
s
P
p
.002 w
.64163 .45418 m .65548 .40048 L .63538 .39095 L p
1 g
F P
s
P
p
.002 w
.63156 .34059 m .63538 .39095 L .65548 .40048 L p
1 g
F P
s
P
p
.002 w
.63538 .39095 m .63156 .34059 L .60868 .33715 L p
1 g
F P
s
P
p
.002 w
.5897 .29622 m .60868 .33715 L .63156 .34059 L p
1 g
F P
s
P
p
.002 w
.60868 .33715 m .5897 .29622 L .56687 .30063 L p
1 g
F P
s
P
p
.002 w
.62652 .5175 m .65748 .46706 L .64163 .45418 L p
1 g
F P
s
P
p
.002 w
.65548 .40048 m .64163 .45418 L .65748 .46706 L p
1 g
F P
s
P
p
.002 w
.36278 .33242 m .35044 .36648 L .37112 .36329 L p
1 g
F P
s
P
p
.002 w
.37112 .36329 m .38063 .33734 L .36278 .33242 L p
1 g
F P
s
P
p
.002 w
.56687 .30063 m .53812 .27329 L .519 .28578 L p
1 g
F P
s
P
p
.002 w
.48764 .27296 m .519 .28578 L .53812 .27329 L p
1 g
F P
s
P
p
.002 w
.53812 .27329 m .56687 .30063 L .5897 .29622 L p
1 g
F P
s
P
p
.002 w
.48764 .27296 m .45224 .27153 L .44876 .29092 L p
1 g
F P
s
P
p
.002 w
.42184 .2989 m .44876 .29092 L .45224 .27153 L p
1 g
F P
s
P
p
.002 w
.36155 .54611 m .4095 .57019 L .40639 .54876 L p
1 g
F P
s
P
p
.002 w
.40639 .54876 m .36178 .52601 L .36155 .54611 L p
1 g
F P
s
P
p
.002 w
.41509 .58867 m .47174 .59565 L .46379 .57715 L p
1 g
F P
s
P
p
.002 w
.46379 .57715 m .4095 .57019 L .41509 .58867 L p
1 g
F P
s
P
p
.002 w
.38582 .30305 m .36278 .33242 L .38063 .33734 L p
1 g
F P
s
P
p
.002 w
.38063 .33734 m .3982 .31499 L .38582 .30305 L p
1 g
F P
s
P
p
.002 w
.5392 .59936 m .59327 .57187 L .58245 .55797 L p
1 g
F P
s
P
p
.002 w
.58245 .55797 m .52928 .58491 L .5392 .59936 L p
1 g
F P
s
P
p
.002 w
.62652 .5175 m .58245 .55797 L .59327 .57187 L p
1 g
F P
s
P
p
.002 w
.33296 .37145 m .33267 .41357 L .35003 .40115 L p
1 g
F P
s
P
p
.002 w
.35003 .40115 m .35044 .36648 L .33296 .37145 L p
1 g
F P
s
P
p
.002 w
.45224 .27153 m .41689 .28191 L .42184 .2989 L p
1 g
F P
s
P
p
.002 w
.3982 .31499 m .42184 .2989 L .41689 .28191 L p
1 g
F P
s
P
p
.002 w
.32818 .48889 m .36178 .52601 L .36553 .50411 L p
1 g
F P
s
P
p
.002 w
.36553 .50411 m .33539 .47037 L .32818 .48889 L p
1 g
F P
s
P
p
.002 w
.59327 .57187 m .63816 .53068 L .62652 .5175 L p
1 g
F P
s
P
p
.002 w
.65748 .46706 m .62652 .5175 L .63816 .53068 L p
1 g
F P
s
P
p
.002 w
.41689 .28191 m .38582 .30305 L .3982 .31499 L p
1 g
F P
s
P
p
.002 w
.31912 .42686 m .33539 .47037 L .34656 .45141 L p
1 g
F P
s
P
p
.002 w
.34656 .45141 m .33267 .41357 L .31912 .42686 L p
1 g
F P
s
P
p
.002 w
.4807 .61046 m .5392 .59936 L .52928 .58491 L p
1 g
F P
s
P
p
.002 w
.52928 .58491 m .47174 .59565 L .4807 .61046 L p
1 g
F P
s
P
p
.002 w
.53812 .27329 m .50016 .25753 L .48764 .27296 L p
1 g
F P
s
P
p
.002 w
.45224 .27153 m .48764 .27296 L .50016 .25753 L p
1 g
F P
s
P
p
.002 w
.65748 .46706 m .67218 .4111 L .65548 .40048 L p
1 g
F P
s
P
p
.002 w
.65171 .34648 m .65548 .40048 L .67218 .4111 L p
1 g
F P
s
P
p
.002 w
.65548 .40048 m .65171 .34648 L .63156 .34059 L p
1 g
F P
s
P
p
.002 w
.61088 .29517 m .63156 .34059 L .65171 .34648 L p
1 g
F P
s
P
p
.002 w
.63156 .34059 m .61088 .29517 L .5897 .29622 L p
1 g
F P
s
P
p
.002 w
.55683 .26453 m .5897 .29622 L .61088 .29517 L p
1 g
F P
s
P
p
.002 w
.5897 .29622 m .55683 .26453 L .53812 .27329 L p
1 g
F P
s
P
p
.002 w
.63816 .53068 m .66978 .47943 L .65748 .46706 L p
1 g
F P
s
P
p
.002 w
.67218 .4111 m .65748 .46706 L .66978 .47943 L p
1 g
F P
s
P
p
.002 w
.50016 .25753 m .53812 .27329 L .55683 .26453 L p
1 g
F P
s
P
p
.002 w
.34789 .32991 m .33296 .37145 L .35044 .36648 L p
1 g
F P
s
P
p
.002 w
.35044 .36648 m .36278 .33242 L .34789 .32991 L p
1 g
F P
s
P
p
.002 w
.50016 .25753 m .4571 .25562 L .45224 .27153 L p
1 g
F P
s
P
p
.002 w
.41689 .28191 m .45224 .27153 L .4571 .25562 L p
1 g
F P
s
P
p
.002 w
.36501 .56382 m .41509 .58867 L .4095 .57019 L p
1 g
F P
s
P
p
.002 w
.4095 .57019 m .36155 .54611 L .36501 .56382 L p
1 g
F P
s
P
p
.002 w
.42315 .60359 m .4807 .61046 L .47174 .59565 L p
1 g
F P
s
P
p
.002 w
.47174 .59565 m .41509 .58867 L .42315 .60359 L p
1 g
F P
s
P
p
.002 w
.32533 .5065 m .36155 .54611 L .36178 .52601 L p
1 g
F P
s
P
p
.002 w
.36178 .52601 m .32818 .48889 L .32533 .5065 L p
1 g
F P
s
P
p
.002 w
.31928 .37819 m .31912 .42686 L .33267 .41357 L p
1 g
F P
s
P
p
.002 w
.33267 .41357 m .33296 .37145 L .31928 .37819 L p
1 g
F P
s
P
p
.002 w
.37599 .29401 m .34789 .32991 L .36278 .33242 L p
1 g
F P
s
P
p
.002 w
.36278 .33242 m .38582 .30305 L .37599 .29401 L p
1 g
F P
s
P
p
.002 w
.54845 .60988 m .60205 .58256 L .59327 .57187 L p
1 g
F P
s
P
p
.002 w
.59327 .57187 m .5392 .59936 L .54845 .60988 L p
1 g
F P
s
P
p
.002 w
.63816 .53068 m .59327 .57187 L .60205 .58256 L p
1 g
F P
s
P
p
.002 w
.30993 .44073 m .32818 .48889 L .33539 .47037 L p
1 g
F P
s
P
p
.002 w
.33539 .47037 m .31912 .42686 L .30993 .44073 L p
1 g
F P
s
P
p
.002 w
.4571 .25562 m .41395 .26821 L .41689 .28191 L p
1 g
F P
s
P
p
.002 w
.38582 .30305 m .41689 .28191 L .41395 .26821 L p
1 g
F P
s
P
p
.002 w
.60205 .58256 m .64658 .54172 L .63816 .53068 L p
1 g
F P
s
P
p
.002 w
.66978 .47943 m .63816 .53068 L .64658 .54172 L p
1 g
F P
s
P
p
.002 w
.41395 .26821 m .37599 .29401 L .38582 .30305 L p
1 g
F P
s
P
p
.002 w
.55683 .26453 m .51312 .24613 L .50016 .25753 L p
1 g
F P
s
P
p
.002 w
.4571 .25562 m .50016 .25753 L .51312 .24613 L p
1 g
F P
s
P
p
.002 w
.66978 .47943 m .68491 .42261 L .67218 .4111 L p
1 g
F P
s
P
p
.002 w
.66853 .3548 m .67218 .4111 L .68491 .42261 L p
1 g
F P
s
P
p
.002 w
.67218 .4111 m .66853 .3548 L .65171 .34648 L p
1 g
F P
s
P
p
.002 w
.49054 .62101 m .54845 .60988 L .5392 .59936 L p
1 g
F P
s
P
p
.002 w
.5392 .59936 m .4807 .61046 L .49054 .62101 L p
1 g
F P
s
P
p
.002 w
.62983 .29767 m .65171 .34648 L .66853 .3548 L p
1 g
F P
s
P
p
.002 w
.65171 .34648 m .62983 .29767 L .61088 .29517 L p
1 g
F P
s
P
p
.002 w
.57467 .25987 m .61088 .29517 L .62983 .29767 L p
1 g
F P
s
P
p
.002 w
.61088 .29517 m .57467 .25987 L .55683 .26453 L p
1 g
F P
s
P
p
.002 w
.51312 .24613 m .55683 .26453 L .57467 .25987 L p
1 g
F P
s
P
p
.002 w
.64658 .54172 m .67801 .49097 L .66978 .47943 L p
1 g
F P
s
P
p
.002 w
.68491 .42261 m .66978 .47943 L .67801 .49097 L p
1 g
F P
s
P
p
.002 w
.33649 .33001 m .31928 .37819 L .33296 .37145 L p
1 g
F P
s
P
p
.002 w
.33296 .37145 m .34789 .32991 L .33649 .33001 L p
1 g
F P
s
P
p
.002 w
.37228 .57856 m .42315 .60359 L .41509 .58867 L p
1 g
F P
s
P
p
.002 w
.41509 .58867 m .36501 .56382 L .37228 .57856 L p
1 g
F P
s
P
p
.002 w
.51312 .24613 m .46329 .24378 L .4571 .25562 L p
1 g
F P
s
P
p
.002 w
.41395 .26821 m .4571 .25562 L .46329 .24378 L p
1 g
F P
s
P
p
.002 w
.32714 .52269 m .36501 .56382 L .36155 .54611 L p
1 g
F P
s
P
p
.002 w
.36155 .54611 m .32533 .5065 L .32714 .52269 L p
1 g
F P
s
P
p
.002 w
.30997 .38661 m .30993 .44073 L .31912 .42686 L p
1 g
F P
s
P
p
.002 w
.31912 .42686 m .31928 .37819 L .30997 .38661 L p
1 g
F P
s
P
p
.002 w
.43362 .61436 m .49054 .62101 L .4807 .61046 L p
1 g
F P
s
P
p
.002 w
.4807 .61046 m .42315 .60359 L .43362 .61436 L p
1 g
F P
s
P
p
.002 w
.30557 .45486 m .32533 .5065 L .32818 .48889 L p
1 g
F P
s
P
p
.002 w
.32818 .48889 m .30993 .44073 L .30557 .45486 L p
1 g
F P
s
P
p
.002 w
.3691 .28829 m .33649 .33001 L .34789 .32991 L p
1 g
F P
s
P
p
.002 w
.34789 .32991 m .37599 .29401 L .3691 .28829 L p
1 g
F P
s
P
p
.002 w
.55677 .61598 m .60843 .5896 L .60205 .58256 L p
1 g
F P
s
P
p
.002 w
.60205 .58256 m .54845 .60988 L .55677 .61598 L p
1 g
F P
s
P
p
.002 w
.64658 .54172 m .60205 .58256 L .60843 .5896 L p
1 g
F P
s
P
p
.002 w
.46329 .24378 m .41321 .25832 L .41395 .26821 L p
1 g
F P
s
P
p
.002 w
.37599 .29401 m .41395 .26821 L .41321 .25832 L p
1 g
F P
s
P
p
.002 w
.60843 .5896 m .6514 .55021 L .64658 .54172 L p
1 g
F P
s
P
p
.002 w
.67801 .49097 m .64658 .54172 L .6514 .55021 L p
1 g
F P
s
P
p
.002 w
.41321 .25832 m .3691 .28829 L .37599 .29401 L p
1 g
F P
s
P
p
.002 w
.68491 .42261 m .68143 .36546 L .66853 .3548 L p
1 g
F P
s
P
p
.002 w
.64596 .30386 m .66853 .3548 L .68143 .36546 L p
1 g
F P
s
P
p
.002 w
.66853 .3548 m .64596 .30386 L .62983 .29767 L p
1 g
F P
s
P
p
.002 w
.57467 .25987 m .52623 .23927 L .51312 .24613 L p
1 g
F P
s
P
p
.002 w
.46329 .24378 m .51312 .24613 L .52623 .23927 L p
1 g
F P
s
P
p
.002 w
.67801 .49097 m .69313 .43478 L .68491 .42261 L p
1 g
F P
s
P
p
.002 w
.68143 .36546 m .68491 .42261 L .69313 .43478 L p
1 g
F P
s
P
p
.002 w
.59116 .25965 m .62983 .29767 L .64596 .30386 L p
1 g
F P
s
P
p
.002 w
.62983 .29767 m .59116 .25965 L .57467 .25987 L p
1 g
F P
s
P
p
.002 w
.50103 .62677 m .55677 .61598 L .54845 .60988 L p
1 g
F P
s
P
p
.002 w
.54845 .60988 m .49054 .62101 L .50103 .62677 L p
1 g
F P
s
P
p
.002 w
.52623 .23927 m .57467 .25987 L .59116 .25965 L p
1 g
F P
s
P
p
.002 w
.6514 .55021 m .68175 .50134 L .67801 .49097 L p
1 g
F P
s
P
p
.002 w
.69313 .43478 m .67801 .49097 L .68175 .50134 L p
1 g
F P
s
P
p
.002 w
.3291 .33287 m .30997 .38661 L .31928 .37819 L p
1 g
F P
s
P
p
.002 w
.31928 .37819 m .33649 .33001 L .3291 .33287 L p
1 g
F P
s
P
p
.002 w
.38339 .58976 m .43362 .61436 L .42315 .60359 L p
1 g
F P
s
P
p
.002 w
.42315 .60359 m .37228 .57856 L .38339 .58976 L p
1 g
F P
s
P
p
.002 w
.33383 .53695 m .37228 .57856 L .36501 .56382 L p
1 g
F P
s
P
p
.002 w
.36501 .56382 m .32714 .52269 L .33383 .53695 L p
1 g
F P
s
P
p
.002 w
.52623 .23927 m .47075 .23655 L .46329 .24378 L p
1 g
F P
s
P
p
.002 w
.41321 .25832 m .46329 .24378 L .47075 .23655 L p
1 g
F P
s
P
p
.002 w
.30555 .39661 m .30557 .45486 L .30993 .44073 L p
1 g
F P
s
P
p
.002 w
.30993 .44073 m .30997 .38661 L .30555 .39661 L p
1 g
F P
s
P
p
.002 w
.30646 .46888 m .32714 .52269 L .32533 .5065 L p
1 g
F P
s
P
p
.002 w
.32533 .5065 m .30557 .45486 L .30646 .46888 L p
1 g
F P
s
P
p
.002 w
.44635 .62046 m .50103 .62677 L .49054 .62101 L p
1 g
F P
s
P
p
.002 w
.49054 .62101 m .43362 .61436 L .44635 .62046 L p
1 g
F P
s
P
p
.002 w
.36552 .28624 m .3291 .33287 L .33649 .33001 L p
1 g
F P
s
P
p
.002 w
.33649 .33001 m .3691 .28829 L .36552 .28624 L p
1 g
F P
s
P
p
.002 w
.56388 .61721 m .61211 .59256 L .60843 .5896 L p
1 g
F P
s
P
p
.002 w
.60843 .5896 m .55677 .61598 L .56388 .61721 L p
1 g
F P
s
P
p
.002 w
.6514 .55021 m .60843 .5896 L .61211 .59256 L p
1 g
F P
s
P
p
.002 w
.69313 .43478 m .68983 .37832 L .68143 .36546 L p
1 g
F P
s
P
p
.002 w
.65869 .31377 m .68143 .36546 L .68983 .37832 L p
1 g
F P
s
P
p
.002 w
.68143 .36546 m .65869 .31377 L .64596 .30386 L p
1 g
F P
s
P
p
.002 w
.47075 .23655 m .41483 .25275 L .41321 .25832 L p
1 g
F P
s
P
p
.002 w
.3691 .28829 m .41321 .25832 L .41483 .25275 L p
1 g
F P
s
P
p
.002 w
.61211 .59256 m .65225 .55577 L .6514 .55021 L p
1 g
F P
s
P
p
.002 w
.68175 .50134 m .6514 .55021 L .65225 .55577 L p
1 g
F P
s
P
p
.002 w
.59116 .25965 m .53914 .23739 L .52623 .23927 L p
1 g
F P
s
P
p
.002 w
.47075 .23655 m .52623 .23927 L .53914 .23739 L p
1 g
F P
s
P
p
.002 w
.68175 .50134 m .69637 .44731 L .69313 .43478 L p
1 g
F P
s
P
p
.002 w
.68983 .37832 m .69313 .43478 L .69637 .44731 L p
1 g
F P
s
P
p
.002 w
.60577 .26413 m .64596 .30386 L .65869 .31377 L p
1 g
F P
s
P
p
.002 w
.64596 .30386 m .60577 .26413 L .59116 .25965 L p
1 g
F P
s
P
p
.002 w
.41483 .25275 m .36552 .28624 L .3691 .28829 L p
1 g
F P
s
P
p
.002 w
.53914 .23739 m .59116 .25965 L .60577 .26413 L p
1 g
F P
s
P
p
.002 w
.51193 .62729 m .56388 .61721 L .55677 .61598 L p
1 g
F P
s
P
p
.002 w
.55677 .61598 m .50103 .62677 L .51193 .62729 L p
1 g
F P
s
P
p
.002 w
.32619 .33859 m .30555 .39661 L .30997 .38661 L p
1 g
F P
s
P
p
.002 w
.30997 .38661 m .3291 .33287 L .32619 .33859 L p
1 g
F P
s
P
p
.002 w
.65225 .55577 m .68059 .51019 L .68175 .50134 L p
1 g
F P
s
P
p
.002 w
.69637 .44731 m .68175 .50134 L .68059 .51019 L p
1 g
F P
s
P
p
.002 w
.39822 .59689 m .44635 .62046 L .43362 .61436 L p
1 g
F P
s
P
p
.002 w
.43362 .61436 m .38339 .58976 L .39822 .59689 L p
1 g
F P
s
P
p
.002 w
.3455 .54875 m .38339 .58976 L .37228 .57856 L p
1 g
F P
s
P
p
.002 w
.37228 .57856 m .33383 .53695 L .3455 .54875 L p
1 g
F P
s
P
p
.004 w
.36983 .65774 m
.39594 .61217 L
s
P
p
.004 w
.35963 .67556 m
.36983 .65774 L
s
P
p
.002 w
.31288 .48237 m .33383 .53695 L .32714 .52269 L p
1 g
F P
s
P
p
.002 w
.32714 .52269 m .30646 .46888 L .31288 .48237 L p
1 g
F P
s
P
p
.002 w
.30645 .40799 m .30646 .46888 L .30557 .45486 L p
1 g
F P
s
P
p
.002 w
.30557 .45486 m .30555 .39661 L .30645 .40799 L p
1 g
F P
s
P
p
.002 w
.53914 .23739 m .47934 .23444 L .47075 .23655 L p
1 g
F P
s
P
p
.002 w
.41483 .25275 m .47075 .23655 L .47934 .23444 L p
1 g
F P
s
P
p
.002 w
.46111 .62142 m .51193 .62729 L .50103 .62677 L p
1 g
F P
s
P
p
.002 w
.50103 .62677 m .44635 .62046 L .46111 .62142 L p
1 g
F P
s
P
p
.002 w
.36557 .28818 m .32619 .33859 L .3291 .33287 L p
1 g
F P
s
P
p
.002 w
.3291 .33287 m .36552 .28624 L .36557 .28818 L p
1 g
F P
s
P
p
.002 w
.69637 .44731 m .69324 .39315 L .68983 .37832 L p
1 g
F P
s
P
p
.002 w
.68983 .37832 m .66746 .32733 L .65869 .31377 L p
1 g
F P
s
P
p
.002 w
.66746 .32733 m .68983 .37832 L .69324 .39315 L p
1 g
F P
s
P
p
.002 w
.65869 .31377 m .61798 .27347 L .60577 .26413 L p
1 g
F P
s
P
p
.002 w
.61798 .27347 m .65869 .31377 L .66746 .32733 L p
1 g
F P
s
P
p
.002 w
.60577 .26413 m .55148 .24087 L .53914 .23739 L p
1 g
F P
s
P
p
.002 w
.47934 .23444 m .53914 .23739 L .55148 .24087 L p
1 g
F P
s
P
p
.002 w
.56949 .61322 m .61279 .59109 L .61211 .59256 L p
1 g
F P
s
P
p
.002 w
.61211 .59256 m .56388 .61721 L .56949 .61322 L p
1 g
F P
s
P
p
.002 w
.65225 .55577 m .61211 .59256 L .61279 .59109 L p
1 g
F P
s
P
p
.002 w
.68059 .51019 m .69421 .45989 L .69637 .44731 L p
1 g
F P
s
P
p
.002 w
.69324 .39315 m .69637 .44731 L .69421 .45989 L p
1 g
F P
s
P
p
.002 w
.47934 .23444 m .41892 .25194 L .41483 .25275 L p
1 g
F P
s
P
p
.002 w
.36552 .28624 m .41483 .25275 L .41892 .25194 L p
1 g
F P
s
P
p
.002 w
.55148 .24087 m .60577 .26413 L .61798 .27347 L p
1 g
F P
s
P
p
.002 w
.61279 .59109 m .64885 .55805 L .65225 .55577 L p
1 g
F P
s
P
p
.002 w
.68059 .51019 m .65225 .55577 L .64885 .55805 L p
1 g
F P
s
P
p
.002 w
.41892 .25194 m .36557 .28818 L .36552 .28624 L p
1 g
F P
s
P
p
.002 w
.52294 .62222 m .56949 .61322 L .56388 .61721 L p
1 g
F P
s
P
p
.002 w
.56388 .61721 m .51193 .62729 L .52294 .62222 L p
1 g
F P
s
P
p
.002 w
.32813 .3472 m .30645 .40799 L .30555 .39661 L p
1 g
F P
s
P
p
.002 w
.30555 .39661 m .32619 .33859 L .32813 .3472 L p
1 g
F P
s
P
p
.002 w
.64885 .55805 m .67426 .51715 L .68059 .51019 L p
1 g
F P
s
P
p
.002 w
.69421 .45989 m .68059 .51019 L .67426 .51715 L p
1 g
F P
s
P
p
.002 w
.36207 .55757 m .39822 .59689 L .38339 .58976 L p
1 g
F P
s
P
p
.002 w
.38339 .58976 m .3455 .54875 L .36207 .55757 L p
1 g
F P
s
P
p
.002 w
.41656 .59949 m .46111 .62142 L .44635 .62046 L p
1 g
F P
s
P
p
.002 w
.44635 .62046 m .39822 .59689 L .41656 .59949 L p
1 g
F P
s
P
p
.002 w
.32497 .49488 m .3455 .54875 L .33383 .53695 L p
1 g
F P
s
P
p
.002 w
.33383 .53695 m .31288 .48237 L .32497 .49488 L p
1 g
F P
s
P
p
.002 w
.31298 .42049 m .31288 .48237 L .30646 .46888 L p
1 g
F P
s
P
p
.002 w
.30646 .46888 m .30645 .40799 L .31298 .42049 L p
1 g
F P
s
P
p
.002 w
.55148 .24087 m .48889 .23782 L .47934 .23444 L p
1 g
F P
s
P
p
.002 w
.41892 .25194 m .47934 .23444 L .48889 .23782 L p
1 g
F P
s
P
p
.002 w
.47757 .61689 m .52294 .62222 L .51193 .62729 L p
1 g
F P
s
P
p
.002 w
.51193 .62729 m .46111 .62142 L .47757 .61689 L p
1 g
F P
s
P
p
.002 w
.69421 .45989 m .69127 .40963 L .69324 .39315 L p
1 g
F P
s
P
p
.002 w
.67178 .34437 m .69324 .39315 L .69127 .40963 L p
1 g
F P
s
P
p
.002 w
.69324 .39315 m .67178 .34437 L .66746 .32733 L p
1 g
F P
s
P
p
.002 w
.62729 .28768 m .66746 .32733 L .67178 .34437 L p
1 g
F P
s
P
p
.002 w
.66746 .32733 m .62729 .28768 L .61798 .27347 L p
1 g
F P
s
P
p
.002 w
.36951 .2943 m .32813 .3472 L .32619 .33859 L p
1 g
F P
s
P
p
.002 w
.32619 .33859 m .36557 .28818 L .36951 .2943 L p
1 g
F P
s
P
p
.002 w
.61798 .27347 m .56285 .24993 L .55148 .24087 L p
1 g
F P
s
P
p
.002 w
.48889 .23782 m .55148 .24087 L .56285 .24993 L p
1 g
F P
s
P
p
.002 w
.67426 .51715 m .6864 .47215 L .69421 .45989 L p
1 g
F P
s
P
p
.002 w
.69127 .40963 m .69421 .45989 L .6864 .47215 L p
1 g
F P
s
P
p
.002 w
.56285 .24993 m .61798 .27347 L .62729 .28768 L p
1 g
F P
s
P
p
.002 w
.57334 .60378 m .61027 .58493 L .61279 .59109 L p
1 g
F P
s
P
p
.002 w
.61279 .59109 m .56949 .61322 L .57334 .60378 L p
1 g
F P
s
P
p
.002 w
.64885 .55805 m .61279 .59109 L .61027 .58493 L p
1 g
F P
s
P
p
.002 w
.48889 .23782 m .42552 .25623 L .41892 .25194 L p
1 g
F P
s
P
p
.002 w
.36557 .28818 m .41892 .25194 L .42552 .25623 L p
1 g
F P
s
P
p
.002 w
.61027 .58493 m .64101 .55675 L .64885 .55805 L p
1 g
F P
s
P
p
.002 w
.67426 .51715 m .64885 .55805 L .64101 .55675 L p
1 g
F P
s
P
p
.002 w
.42552 .25623 m .36951 .2943 L .36557 .28818 L p
1 g
F P
s
P
p
.002 w
.53374 .61138 m .57334 .60378 L .56949 .61322 L p
1 g
F P
s
P
p
.002 w
.56949 .61322 m .52294 .62222 L .53374 .61138 L p
1 g
F P
s
P
p
.002 w
.3833 .56298 m .41656 .59949 L .39822 .59689 L p
1 g
F P
s
P
p
.002 w
.39822 .59689 m .36207 .55757 L .3833 .56298 L p
1 g
F P
s
P
p
.002 w
.33519 .35862 m .31298 .42049 L .30645 .40799 L p
1 g
F P
s
P
p
.002 w
.30645 .40799 m .32813 .3472 L .33519 .35862 L p
1 g
F P
s
P
p
.002 w
.438 .59722 m .47757 .61689 L .46111 .62142 L p
1 g
F P
s
P
p
.002 w
.46111 .62142 m .41656 .59949 L .438 .59722 L p
1 g
F P
s
P
p
.002 w
.64101 .55675 m .66262 .5219 L .67426 .51715 L p
1 g
F P
s
P
p
.002 w
.6864 .47215 m .67426 .51715 L .66262 .5219 L p
1 g
F P
s
P
p
.002 w
.34267 .50597 m .36207 .55757 L .3455 .54875 L p
1 g
F P
s
P
p
.002 w
.3455 .54875 m .32497 .49488 L .34267 .50597 L p
1 g
F P
s
P
p
.002 w
.32528 .43377 m .32497 .49488 L .31288 .48237 L p
1 g
F P
s
P
p
.002 w
.31288 .48237 m .31298 .42049 L .32528 .43377 L p
1 g
F P
s
P
p
.002 w
.49531 .60673 m .53374 .61138 L .52294 .62222 L p
1 g
F P
s
P
p
.002 w
.52294 .62222 m .47757 .61689 L .49531 .60673 L p
1 g
F P
s
P
p
.002 w
.56285 .24993 m .49916 .24695 L .48889 .23782 L p
1 g
F P
s
P
p
.002 w
.42552 .25623 m .48889 .23782 L .49916 .24695 L p
1 g
F P
s
P
p
.002 w
.6864 .47215 m .68365 .42734 L .69127 .40963 L p
1 g
F P
s
P
p
.002 w
.67127 .36455 m .69127 .40963 L .68365 .42734 L p
1 g
F P
s
P
p
.002 w
.69127 .40963 m .67127 .36455 L .67178 .34437 L p
1 g
F P
s
P
p
.002 w
.63324 .30658 m .67178 .34437 L .67127 .36455 L p
1 g
F P
s
P
p
.002 w
.67178 .34437 m .63324 .30658 L .62729 .28768 L p
1 g
F P
s
P
p
.002 w
.57283 .26462 m .62729 .28768 L .63324 .30658 L p
1 g
F P
s
P
p
.002 w
.62729 .28768 m .57283 .26462 L .56285 .24993 L p
1 g
F P
s
P
p
.002 w
.49916 .24695 m .56285 .24993 L .57283 .26462 L p
1 g
F P
s
P
p
.002 w
.66262 .5219 m .67284 .48366 L .6864 .47215 L p
1 g
F P
s
P
p
.002 w
.68365 .42734 m .6864 .47215 L .67284 .48366 L p
1 g
F P
s
P
p
.002 w
.37745 .30469 m .33519 .35862 L .32813 .3472 L p
1 g
F P
s
P
p
.002 w
.32813 .3472 m .36951 .2943 L .37745 .30469 L p
1 g
F P
s
P
p
.002 w
.57519 .58885 m .60439 .57398 L .61027 .58493 L p
1 g
F P
s
P
p
.002 w
.61027 .58493 m .57334 .60378 L .57519 .58885 L p
1 g
F P
s
P
p
.002 w
.64101 .55675 m .61027 .58493 L .60439 .57398 L p
1 g
F P
s
P
p
.002 w
.49916 .24695 m .43459 .26583 L .42552 .25623 L p
1 g
F P
s
P
p
.002 w
.36951 .2943 m .42552 .25623 L .43459 .26583 L p
1 g
F P
s
P
p
.002 w
.60439 .57398 m .6287 .55169 L .64101 .55675 L p
1 g
F P
s
P
p
.002 w
.66262 .5219 m .64101 .55675 L .6287 .55169 L p
1 g
F P
s
P
p
.002 w
.43459 .26583 m .37745 .30469 L .36951 .2943 L p
1 g
F P
s
P
p
.002 w
.40869 .56461 m .438 .59722 L .41656 .59949 L p
1 g
F P
s
P
p
.004 w
.41754 .57446 m
.5 .43051 L
s
P
p
.002 w
.41656 .59949 m .3833 .56298 L .40869 .56461 L p
1 g
F P
s
P
p
.004 w
.40727 .59238 m
.41005 .58754 L
s
P
p
.004 w
.41005 .58754 m
.41074 .58633 L
s
P
p
.004 w
.40337 .5992 m
.40727 .59238 L
s
P
p
.004 w
.39594 .61217 m
.40337 .5992 L
s
P
p
.002 w
.54396 .59475 m .57519 .58885 L .57334 .60378 L p
1 g
F P
s
P
p
.002 w
.57334 .60378 m .53374 .61138 L .54396 .59475 L p
1 g
F P
s
P
p
.002 w
.462 .58991 m .49531 .60673 L .47757 .61689 L p
1 g
F P
s
P
p
.002 w
.47757 .61689 m .438 .59722 L .462 .58991 L p
1 g
F P
s
P
p
.002 w
.36566 .51516 m .3833 .56298 L .36207 .55757 L p
1 g
F P
s
P
p
.002 w
.36207 .55757 m .34267 .50597 L .36566 .51516 L p
1 g
F P
s
P
p
.002 w
.34743 .37263 m .32528 .43377 L .31298 .42049 L p
1 g
F P
s
P
p
.002 w
.31298 .42049 m .33519 .35862 L .34743 .37263 L p
1 g
F P
s
P
p
.002 w
.6287 .55169 m .64571 .52414 L .66262 .5219 L p
1 g
F P
s
P
p
.002 w
.67284 .48366 m .66262 .5219 L .64571 .52414 L p
1 g
F P
s
P
p
.002 w
.34325 .44744 m .34267 .50597 L .32497 .49488 L p
1 g
F P
s
P
p
.002 w
.32497 .49488 m .32528 .43377 L .34325 .44744 L p
1 g
F P
s
P
p
.002 w
.51379 .59095 m .54396 .59475 L .53374 .61138 L p
1 g
F P
s
P
p
.002 w
.53374 .61138 m .49531 .60673 L .51379 .59095 L p
1 g
F P
s
P
p
.002 w
.67284 .48366 m .67034 .44577 L .68365 .42734 L p
1 g
F P
s
P
p
.002 w
.66566 .38737 m .68365 .42734 L .67034 .44577 L p
1 g
F P
s
P
p
.002 w
.68365 .42734 m .66566 .38737 L .67127 .36455 L p
1 g
F P
s
P
p
.002 w
.57283 .26462 m .50987 .26189 L .49916 .24695 L p
1 g
F P
s
P
p
.002 w
.43459 .26583 m .49916 .24695 L .50987 .26189 L p
1 g
F P
s
P
p
.002 w
.63544 .32982 m .67127 .36455 L .66566 .38737 L p
1 g
F P
s
P
p
.002 w
.67127 .36455 m .63544 .32982 L .63324 .30658 L p
1 g
F P
s
P
p
.002 w
.58101 .28477 m .63324 .30658 L .63544 .32982 L p
1 g
F P
s
P
p
.002 w
.63324 .30658 m .58101 .28477 L .57283 .26462 L p
1 g
F P
s
P
p
.002 w
.50987 .26189 m .57283 .26462 L .58101 .28477 L p
1 g
F P
s
P
p
.002 w
.64571 .52414 m .65364 .49402 L .67284 .48366 L p
1 g
F P
s
P
p
.002 w
.67034 .44577 m .67284 .48366 L .65364 .49402 L p
1 g
F P
s
P
p
.002 w
.38937 .31926 m .34743 .37263 L .33519 .35862 L p
1 g
F P
s
P
p
.002 w
.33519 .35862 m .37745 .30469 L .38937 .31926 L p
1 g
F P
s
P
p
.002 w
.43756 .56224 m .462 .58991 L .438 .59722 L p
1 g
F P
s
P
p
.002 w
.438 .59722 m .40869 .56461 L .43756 .56224 L p
1 g
F P
s
P
p
.002 w
.57486 .5686 m .59516 .5583 L .60439 .57398 L p
1 g
F P
s
P
p
.002 w
.60439 .57398 m .57519 .58885 L .57486 .5686 L p
1 g
F P
s
P
p
.002 w
.6287 .55169 m .60439 .57398 L .59516 .5583 L p
1 g
F P
s
P
p
.002 w
.50987 .26189 m .44598 .28073 L .43459 .26583 L p
1 g
F P
s
P
p
.002 w
.37745 .30469 m .43459 .26583 L .44598 .28073 L p
1 g
F P
s
P
p
.002 w
.59516 .5583 m .61205 .5428 L .6287 .55169 L p
1 g
F P
s
P
p
.002 w
.64571 .52414 m .6287 .55169 L .61205 .5428 L p
1 g
F P
s
P
p
.002 w
.3934 .52206 m .40869 .56461 L .3833 .56298 L p
1 g
F P
s
P
p
.002 w
.3833 .56298 m .36566 .51516 L .3934 .52206 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51379 .59095 m .49531 .60673 L p
.48865 .58076 L 1 g
F P
s
P
p
.48865 .58076 m .48863 .58068 L .48884 .58077 L 1 g
F
P
p
.48865 .58076 m .48884 .58077 L .51379 .59095 L 1 g
F
P
p
.002 w
.48905 .58078 m .48921 .57862 L p
.47872 .57776 L 1 g
F P
s
P
p
.462 .58991 m .46547 .57299 L .46842 .57405 L 1 g
F
P
p
.002 w
.4837 .57956 m .47994 .58135 L p
.46842 .57405 L 1 g
F P
s
P
p
.002 w
.47994 .58135 m .462 .58991 L p
.46842 .57405 L 1 g
F P
s
P
p
.002 w
.46842 .57405 m .46872 .57265 L p
.46195 .56995 L 1 g
F P
s
P
p
.47872 .57776 m .4837 .57956 L .48905 .58078 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46799 .57596 L p
1 g
F P
s
P
p
.002 w
.46799 .57596 m .4678 .57686 L p
.47423 .57739 L 1 g
F P
s
P
p
.48921 .57862 m .46799 .57596 L .47423 .57739 L 1 g
F
P
p
.002 w
.49531 .60673 m .462 .58991 L .4837 .57956 L p
1 g
F P
s
P
p
.002 w
.4837 .57956 m .48784 .57758 L p
.48863 .58068 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58078 L p
1 g
F P
s
P
p
.49531 .60673 m .48414 .58056 L .48865 .58076 L 1 g
F
P
p
.51079 .57862 m .48905 .58078 L .49451 .58102 L 1 g
F
P
p
.002 w
.51379 .59095 m .49914 .5834 L p
.51409 .58026 L 1 g
F P
s
P
p
.002 w
.49914 .5834 m .49451 .58102 L p
.51092 .58038 L 1 g
F P
s
P
p
.49914 .5834 m .51092 .58038 L .51409 .58026 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58038 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58038 L .52148 .57768 L 1 g
F
P
p
.51079 .57862 m .49451 .58102 L .49983 .58081 L 1 g
F
P
p
.002 w
.51102 .58174 m .51079 .57862 L p
.49803 .58117 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48784 .57758 m .51465 .56048 L p
.51409 .58026 L 1 g
F P
s
P
p
.002 w
.49451 .58102 m .48784 .57758 L p
.51409 .58026 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.53128 .57265 m .52148 .57768 L .52667 .57635 L 1 g
F
P
p
.54396 .59475 m .52743 .57716 L .53426 .57385 L 1 g
F
P
p
.52743 .57716 m .52667 .57635 L .53172 .57468 L 1 g
F
P
p
.52743 .57716 m .53172 .57468 L .53426 .57385 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57468 L p
1 g
F P
s
P
p
.54854 .56129 m .53172 .57468 L .53868 .57068 L 1 g
F
P
p
.002 w
.55321 .57261 m .54253 .57119 L p
.55209 .56093 L 1 g
F P
s
P
p
.002 w
.54253 .57119 m .53868 .57068 L p
.54919 .56304 L 1 g
F P
s
P
p
.54253 .57119 m .54919 .56304 L .55209 .56093 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .55526 .55562 L 1 g
F
P
p
.54854 .56129 m .53868 .57068 L .53873 .57064 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55321 .57261 m .54396 .59475 L p
.53403 .57335 L 1 g
F P
s
P
p
.002 w
.53868 .57068 m .55321 .57261 L p
.53403 .57335 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54968 .56435 L p
1 g
F P
s
P
p
.002 w
.54968 .56435 m .54854 .56129 L p
.53871 .57066 L 1 g
F P
s
P
p
.53871 .57066 m .5322 .57686 L .54968 .56435 L 1 g
F
P
p
.002 w
.5324 .56985 m .53868 .57068 L p
.53403 .57335 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5324 .56985 m .55048 .54397 L p
.55209 .56093 L 1 g
F P
s
P
p
.002 w
.53868 .57068 m .5324 .56985 L p
.55209 .56093 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.56075 .54566 m .55526 .55562 L .55975 .55012 L 1 g
F
P
p
.57486 .5686 m .56042 .55094 L .5621 .54712 L 1 g
F
P
p
.56042 .55094 m .55975 .55012 L .56176 .54756 L 1 g
F
P
p
.56042 .55094 m .56176 .54756 L .5621 .54712 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56176 .54756 L p
1 g
F P
s
P
p
.56654 .52734 m .56176 .54756 L .56269 .54518 L 1 g
F
P
p
.002 w
.56892 .52368 m .57224 .54346 L .56827 .54417 L p
1 g
F P
s
P
p
.002 w
.56827 .54417 m .56269 .54518 L p
.56747 .5287 L 1 g
F P
s
P
p
.56827 .54417 m .56747 .5287 L .56892 .52368 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .56706 .52062 L 1 g
F
P
p
.56654 .52734 m .56269 .54518 L .56428 .53969 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56654 .52734 L p
.56379 .54239 L 1 g
F P
s
P
p
.002 w
.57224 .54346 m .57486 .5686 L p
.56199 .54695 L 1 g
F P
s
P
p
.002 w
.56269 .54518 m .57224 .54346 L p
.56199 .54695 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56839 .53074 L p
.56379 .54239 L 1 g
F P
s
P
p
.002 w
.56839 .53074 m .56854 .53025 L p
.56379 .54239 L 1 g
F P
s
P
p
.002 w
.56111 .54546 m .56269 .54518 L p
.56199 .54695 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56732 .51412 m .56892 .52368 L p
.56743 .52785 L 1 g
F P
s
P
p
.56515 .50826 m .56706 .52062 L .56684 .51652 L 1 g
F
P
p
.56515 .50826 m .56684 .51652 L .56675 .51485 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56621 .50952 L p
1 g
F P
s
P
p
.002 w
.56587 .48013 m .56721 .51161 L p
.56645 .51003 L 1 g
F P
s
P
p
.55661 .4905 m .56621 .50952 L .5621 .50099 L 1 g
F
P
p
.002 w
.56732 .51412 m .56649 .51214 L p
.56645 .51003 L 1 g
F P
s
P
p
.002 w
.56308 .48105 m .56587 .48013 L p
.56645 .51003 L 1 g
F P
s
P
p
.56621 .50952 m .56645 .51003 L .56649 .51214 L 1 g
F
P
p
.56308 .48105 m .56645 .51003 L .56621 .50952 L 1 g
F
P
p
.002 w
.55468 .48381 m .56308 .48105 L p
.56621 .50952 L 1 g
F P
s
P
p
.55661 .4905 m .5621 .50099 L .56025 .49716 L 1 g
F
P
p
.002 w
.55402 .48426 m .55468 .48381 L .55811 .49203 L p
1 g
F P
s
P
p
.002 w
.55811 .49203 m .56025 .49716 L p
.55748 .49142 L 1 g
F P
s
P
p
.55402 .48426 m .55811 .49203 L .55748 .49142 L 1 g
F
P
p
.002 w
.55748 .49142 m .55661 .4905 L p
.56025 .49716 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55748 .49142 L p
1 g
F P
s
P
p
.002 w
.55748 .49142 m .55748 .49142 L p
.56025 .49716 L 1 g
F P
s
P
p
.54174 .47608 m .55748 .49142 L .55213 .48626 L 1 g
F
P
p
.56515 .50826 m .56675 .51485 L .56673 .51444 L 1 g
F
P
p
.002 w
.56671 .51425 m .56732 .51412 L .56673 .51444 L p
1 g
F P
s
P
p
.56672 .51434 m .56673 .51444 L .56672 .51434 L 1 g
F
P
p
.56515 .50826 m .56673 .51444 L .56672 .51434 L 1 g
F
P
p
.56515 .50826 m .56672 .51434 L .56671 .51424 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.53511 .53133 m .53209 .52149 L .56671 .51425 L p
1 g
F P
s
P
p
.002 w
.56673 .51444 m .53511 .53133 L p
.56671 .51425 L 1 g
F P
s
P
p
.56515 .50826 m .56671 .51425 L .5667 .51414 L 1 g
F
P
p
.56515 .50826 m .56671 .51416 L .5667 .51404 L 1 g
F
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53209 .52149 m .53278 .51064 L .5667 .51406 L p
1 g
F P
s
P
p
.002 w
.5667 .51406 m .56732 .51412 L .56671 .51425 L p
1 g
F P
s
P
p
.002 w
.56671 .51425 m .53209 .52149 L p
.5667 .51406 L 1 g
F P
s
P
p
.56671 .51424 m .56672 .51434 L .56671 .51425 L 1 g
F
P
p
.5667 .51414 m .56671 .51425 L .56671 .51416 L 1 g
F
P
p
.002 w
.56621 .50953 m .56515 .50826 L p
.5667 .51406 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53278 .51064 m .53715 .49997 L .56667 .51382 L p
1 g
F P
s
P
p
.002 w
.56667 .51382 m .56732 .51412 L .5667 .51406 L p
1 g
F P
s
P
p
.002 w
.5667 .51406 m .53278 .51064 L p
.56667 .51382 L 1 g
F P
s
P
p
.002 w
.53715 .49997 m .54473 .49068 L .56663 .5134 L p
1 g
F P
s
P
p
.002 w
.56663 .5134 m .56732 .51412 L .56667 .51382 L p
1 g
F P
s
P
p
.002 w
.56667 .51382 m .53715 .49997 L p
.56663 .5134 L 1 g
F P
s
P
p
.5667 .51404 m .56671 .51416 L .5667 .51406 L 1 g
F
P
p
.002 w
.56025 .49716 m .56649 .51214 L p
.55703 .49099 L 1 g
F P
s
P
p
.55748 .49142 m .56025 .49716 L .55703 .49099 L 1 g
F
P
p
.55402 .48426 m .56649 .51214 L .56651 .51231 L 1 g
F
P
p
.54174 .47608 m .55213 .48626 L .55172 .48586 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.54473 .49068 m .52262 .46734 L p
.54305 .47742 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54232 .47671 L p
1 g
F P
s
P
p
.52214 .46667 m .54232 .47671 L .53267 .47212 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.53811 .47471 m .54305 .47742 L .52262 .46734 L 1 g
F
P
p
.002 w
.52262 .46734 m .54473 .49068 L p
.52079 .46706 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52251 .46729 L p
1 g
F P
s
P
p
.5 .4634 m .52251 .46729 L .51887 .4668 L 1 g
F
P
p
.002 w
.51887 .4668 m .50538 .48344 L p
.50759 .46501 L 1 g
F P
s
P
p
.51206 .46572 m .51887 .4668 L .51504 .46629 L 1 g
F
P
p
.5 .4634 m .51887 .4668 L .51206 .46572 L 1 g
F
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.002 w
.50538 .48344 m .47722 .46741 L p
.50759 .46501 L 1 g
F P
s
P
p
.4775 .46727 m .50759 .46501 L .47722 .46741 L 1 g
F
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.48821 .46562 L 1 g
F P
s
P
p
.49179 .46506 m .50759 .46501 L .4775 .46727 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .48821 .46562 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .4634 L p
.51206 .46572 L 1 g
F P
s
P
p
.002 w
.49515 .43794 m .52037 .46496 L p
.50759 .46501 L 1 g
F P
s
P
p
.002 w
.47323 .46513 m .47722 .46017 L p
.50759 .46501 L 1 g
F P
s
P
p
.002 w
.47722 .46017 m .49515 .43794 L p
.50759 .46501 L 1 g
F P
s
P
p
.002 w
.50538 .48344 m .51887 .4668 L p
.54473 .49068 L 1 g
F P
s
P
p
.002 w
.51887 .4668 m .51961 .4659 L p
.52079 .46706 L 1 g
F P
s
P
p
.51887 .4668 m .52079 .46706 L .54473 .49068 L 1 g
F
P
p
.51206 .46572 m .51504 .46629 L .5 .4638 L 1 g
F
P
p
.51504 .46629 m .52282 .46778 L .51174 .46585 L 1 g
F
P
p
.51504 .46629 m .51174 .46585 L .5 .4638 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4638 L p
1 g
F P
s
P
p
.002 w
.5 .4638 m .5 .46442 L p
.48821 .46562 L 1 g
F P
s
P
p
.47323 .46513 m .48183 .4651 L .4775 .46727 L 1 g
F
P
p
.002 w
.47722 .46741 m .47709 .46733 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.47709 .46733 m .47323 .46513 L p
.4775 .46727 L 1 g
F P
s
P
p
.48183 .4651 m .49179 .46506 L .4775 .46727 L 1 g
F
P
p
.45826 .47608 m .4775 .46727 L .47722 .46741 L 1 g
F
P
p
.002 w
.46095 .49628 m .47118 .47033 L p
.50538 .48344 L 1 g
F P
s
P
p
.47118 .47033 m .47405 .46894 L .50538 .48344 L 1 g
F
P
p
.45826 .47608 m .47722 .46741 L .47118 .47033 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4426 .49134 L p
1 g
F P
s
P
p
.42506 .52631 m .43431 .50786 L .42661 .52502 L 1 g
F
P
p
.43431 .50786 m .44257 .49137 L .4342 .50903 L 1 g
F
P
p
.44257 .49137 m .4426 .49134 L .4342 .50903 L 1 g
F
P
p
.002 w
.4426 .49134 m .44256 .49138 L p
.44215 .49229 L 1 g
F P
s
P
p
.43485 .50826 m .4426 .49134 L .44215 .49229 L 1 g
F
P
p
.002 w
.42506 .52631 m .42642 .48594 L .43608 .48883 L p
1 g
F P
s
P
p
.002 w
.43608 .48883 m .44283 .49085 L p
.43431 .50786 L 1 g
F P
s
P
p
.42506 .52631 m .43608 .48883 L .43431 .50786 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4342 .50903 L p
1 g
F P
s
P
p
.43431 .50786 m .4342 .50903 L .42661 .52502 L 1 g
F
P
p
.43346 .52734 m .4342 .50903 L .4332 .5198 L 1 g
F
P
p
.002 w
.4426 .49134 m .44339 .4905 L p
.44917 .48497 L 1 g
F P
s
P
p
.44391 .49007 m .47118 .47033 L .44304 .49092 L 1 g
F
P
p
.44917 .48497 m .44304 .49092 L .4426 .49134 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.4578 .47658 m .47118 .47033 L .44391 .49007 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4578 .47658 L p
1 g
F P
s
P
p
.002 w
.4578 .47658 m .45698 .47747 L p
.44917 .48497 L 1 g
F P
s
P
p
.44339 .4905 m .4578 .47658 L .44917 .48497 L 1 g
F
P
p
.002 w
.43332 .48801 m .42642 .48594 L p
.46034 .47411 L 1 g
F P
s
P
p
.45826 .47608 m .47118 .47033 L .46825 .4717 L 1 g
F
P
p
.002 w
.47118 .47033 m .46095 .49628 L .44304 .49092 L p
1 g
F P
s
P
p
.002 w
.47709 .46733 m .47722 .46741 L p
.47208 .46803 L 1 g
F P
s
P
p
.002 w
.47722 .46741 m .50538 .48344 L p
.47405 .46894 L 1 g
F P
s
P
p
.47208 .46803 m .47722 .46741 L .47405 .46894 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45743 .47698 L p
1 g
F P
s
P
p
.002 w
.45743 .47698 m .45826 .47608 L p
.46934 .47122 L 1 g
F P
s
P
p
.46934 .47122 m .47718 .46778 L .45743 .47698 L 1 g
F
P
p
.46034 .47411 m .47118 .47033 L .4578 .47658 L 1 g
F
P
p
.46034 .47411 m .4578 .47658 L .43332 .48801 L 1 g
F
P
p
.44765 .48132 m .4578 .47658 L .44283 .49085 L 1 g
F
P
p
.4578 .47658 m .44391 .49007 L .44283 .49085 L 1 g
F
P
p
.43485 .50826 m .44256 .49138 L .43936 .49772 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.42661 .52502 m .4426 .49134 L .46095 .49628 L 1 g
F
P
p
.002 w
.44283 .49085 m .44304 .49092 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.44304 .49092 m .46095 .49628 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.44256 .49138 m .44166 .49233 L p
.43936 .49772 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .4426 .49134 L p
.443 .49095 L 1 g
F P
s
P
p
.443 .49095 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.44917 .48497 m .45555 .47885 L .44304 .49092 L 1 g
F
P
p
.002 w
.44304 .49092 m .44283 .49085 L p
.44391 .49007 L 1 g
F P
s
P
p
.43346 .52734 m .4332 .5198 L .43256 .52661 L 1 g
F
P
p
.002 w
.43205 .54639 m .42506 .52631 L .43179 .52658 L p
1 g
F P
s
P
p
.002 w
.43179 .52658 m .43256 .52661 L p
.43251 .52873 L 1 g
F P
s
P
p
.43205 .54639 m .43179 .52658 L .43251 .52873 L 1 g
F
P
p
.002 w
.43862 .54685 m .43925 .54566 L p
.43615 .53954 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43756 .56224 m .43205 .54639 L p
.43623 .54355 L 1 g
F P
s
P
p
.43756 .56224 m .43623 .54355 L .44328 .55328 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43862 .54685 L p
1 g
F P
s
P
p
.45146 .56129 m .43862 .54685 L .44456 .55505 L 1 g
F
P
p
.002 w
.44819 .56006 m .43756 .56224 L p
.44328 .55328 L 1 g
F P
s
P
p
.45146 .56129 m .43761 .54876 L .4401 .55142 L 1 g
F
P
p
.462 .58991 m .44895 .5617 L .46454 .57753 L 1 g
F
P
p
.44895 .5617 m .44819 .56006 L .45086 .56291 L 1 g
F
P
p
.44895 .5617 m .45086 .56291 L .46454 .57753 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45086 .56291 L p
1 g
F P
s
P
p
.002 w
.462 .58991 m .43756 .56224 L .44819 .56006 L p
1 g
F P
s
P
p
.46872 .57265 m .45086 .56291 L .46195 .56995 L 1 g
F
P
p
.45146 .56129 m .44504 .55571 L .44819 .56006 L 1 g
F
P
p
.002 w
.45065 .56346 m .45086 .56291 L p
.44819 .56006 L 1 g
F P
s
P
p
.002 w
.45086 .56291 m .45146 .56129 L p
.44819 .56006 L 1 g
F P
s
P
p
.002 w
.44819 .56006 m .469 .55579 L p
.46454 .57753 L 1 g
F P
s
P
p
.002 w
.45086 .56291 m .45002 .56518 L p
.46195 .56995 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45958 .52769 m .469 .55579 L .44819 .56006 L p
1 g
F P
s
P
p
.44328 .55328 m .45958 .52769 L .44819 .56006 L 1 g
F
P
p
.002 w
.43862 .54685 m .43761 .54876 L p
.44456 .55505 L 1 g
F P
s
P
p
.002 w
.43761 .54876 m .43743 .5491 L p
.4401 .55142 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52873 L p
1 g
F P
s
P
p
.43925 .54566 m .43251 .52873 L .43615 .53954 L 1 g
F
P
p
.002 w
.43251 .52873 m .43346 .52734 L p
.43256 .52661 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43256 .52661 m .45958 .52769 L p
.43205 .54639 L 1 g
F P
s
P
p
.002 w
.43251 .52873 m .43146 .53025 L p
.43615 .53954 L 1 g
F P
s
P
p
.44328 .55328 m .43862 .54685 L .45958 .52769 L 1 g
F
P
p
.43862 .54685 m .43623 .54355 L .43727 .54284 L 1 g
F
P
p
.43862 .54685 m .43727 .54284 L .45958 .52769 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45065 .56346 L p
1 g
F P
s
P
p
.44504 .55571 m .43743 .5491 L .45065 .56346 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43862 .54685 L p
1 g
F P
s
P
p
.43615 .53954 m .43146 .53025 L .43862 .54685 L 1 g
F
P
p
.002 w
.43235 .52896 m .43251 .52873 L p
.43256 .52661 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.46095 .49628 m .45958 .52769 L .42506 .52631 L p
1 g
F P
s
P
p
.002 w
.4342 .50903 m .43287 .51061 L p
.4332 .5198 L 1 g
F P
s
P
p
.45555 .47885 m .45698 .47747 L .4426 .49134 L 1 g
F
P
p
.44257 .49137 m .44283 .49085 L .4426 .49134 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43235 .52896 L p
1 g
F P
s
P
p
.4332 .5198 m .43287 .51061 L .43235 .52896 L 1 g
F
P
p
.002 w
.44283 .49085 m .43332 .48801 L p
.44765 .48132 L 1 g
F P
s
P
p
.46825 .4717 m .47118 .47033 L .46934 .47122 L 1 g
F
P
p
.002 w
.47323 .46513 m .47118 .47033 L p
.42642 .48594 L 1 g
F P
s
P
p
.46934 .47122 m .47722 .46741 L .47146 .47029 L 1 g
F
P
p
.002 w
.47118 .47033 m .47208 .46803 L p
.47405 .46894 L 1 g
F P
s
P
p
.002 w
.47208 .46803 m .47323 .46513 L .47709 .46733 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47749 .46728 L p
1 g
F P
s
P
p
.002 w
.47749 .46728 m .4775 .46727 L p
.47797 .46721 L 1 g
F P
s
P
p
.47797 .46721 m .5 .46442 L .47749 .46728 L 1 g
F
P
p
.48821 .46562 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.002 w
.4775 .46727 m .47718 .46778 L p
.47146 .47029 L 1 g
F P
s
P
p
.002 w
.52037 .46496 m .51887 .4668 L p
.50759 .46501 L 1 g
F P
s
P
p
.51961 .4659 m .52251 .46729 L .52079 .46706 L 1 g
F
P
p
.52251 .46729 m .52262 .46734 L .52079 .46706 L 1 g
F
P
p
.002 w
.52251 .46729 m .52282 .46778 L p
.51504 .46629 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52251 .46729 L p
1 g
F P
s
P
p
.002 w
.52251 .46729 m .52214 .46667 L p
.53384 .47273 L 1 g
F P
s
P
p
.53384 .47273 m .54302 .47747 L .52251 .46729 L 1 g
F
P
p
.002 w
.51961 .4659 m .52037 .46496 L .52262 .46734 L p
1 g
F P
s
P
p
.002 w
.52262 .46734 m .52037 .46496 L p
.53811 .47471 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54174 .47608 L p
.55172 .48586 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54012 .45135 m .55468 .48381 L p
.54305 .47742 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52037 .46496 m .52615 .46098 L p
.54305 .47742 L 1 g
F P
s
P
p
.002 w
.52615 .46098 m .54012 .45135 L p
.54305 .47742 L 1 g
F P
s
P
p
.002 w
.55172 .48586 m .54473 .49068 L p
.54305 .47742 L 1 g
F P
s
P
p
.002 w
.54473 .49068 m .55172 .48586 L p
.56651 .51231 L 1 g
F P
s
P
p
.002 w
.55172 .48586 m .55402 .48426 L p
.55701 .49097 L 1 g
F P
s
P
p
.55172 .48586 m .55701 .49097 L .56651 .51231 L 1 g
F
P
p
.002 w
.56025 .49716 m .55811 .49203 L p
.56621 .50952 L 1 g
F P
s
P
p
.002 w
.55811 .49203 m .55468 .48381 L p
.55856 .49247 L 1 g
F P
s
P
p
.55856 .49247 m .56621 .50952 L .55811 .49203 L 1 g
F
P
p
.55172 .48586 m .55193 .48607 L .54281 .47725 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55748 .49142 L p
1 g
F P
s
P
p
.5621 .50099 m .56713 .51061 L .55748 .49142 L 1 g
F
P
p
.55193 .48607 m .55834 .49233 L .54397 .47838 L 1 g
F
P
p
.55193 .48607 m .54397 .47838 L .54281 .47725 L 1 g
F
P
p
.55213 .48626 m .55256 .48668 L .55172 .48586 L 1 g
F
P
p
.55256 .48668 m .55834 .49233 L .55172 .48586 L 1 g
F
P
p
.002 w
.54232 .47671 m .54302 .47747 L p
.53267 .47212 L 1 g
F P
s
P
p
.002 w
.54281 .47725 m .54232 .47671 L p
.55172 .48586 L 1 g
F P
s
P
p
.002 w
.55468 .48381 m .55172 .48586 L p
.54305 .47742 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54281 .47725 L p
1 g
F P
s
P
p
.55402 .48426 m .55748 .49142 L .55703 .49099 L 1 g
F
P
p
.002 w
.56649 .51214 m .56732 .51412 L p
.56651 .51231 L 1 g
F P
s
P
p
.002 w
.56732 .51412 m .56663 .5134 L p
.56651 .51231 L 1 g
F P
s
P
p
.002 w
.5665 .50987 m .56649 .50985 L p
.56672 .51426 L 1 g
F P
s
P
p
.002 w
.56673 .51444 m .56732 .51412 L .56674 .51468 L p
1 g
F P
s
P
p
.56672 .51426 m .56677 .5151 L .56673 .51431 L 1 g
F
P
p
.56672 .51426 m .56673 .51431 L .5665 .50987 L 1 g
F
P
p
.002 w
.56641 .50976 m .56621 .50953 L p
.5667 .51406 L 1 g
F P
s
P
p
.002 w
.56663 .5134 m .54473 .49068 L p
.56651 .51231 L 1 g
F P
s
P
p
.002 w
.55748 .49142 m .55834 .49233 L p
.55213 .48626 L 1 g
F P
s
P
p
.002 w
.56649 .51214 m .56025 .49716 L p
.56621 .50952 L 1 g
F P
s
P
p
.002 w
.56621 .50952 m .56713 .51061 L p
.5621 .50099 L 1 g
F P
s
P
p
.002 w
.56721 .51161 m .56732 .51412 L p
.56645 .51003 L 1 g
F P
s
P
p
.002 w
.56649 .50985 m .56641 .50976 L p
.56669 .51396 L 1 g
F P
s
P
p
.56669 .51396 m .56675 .51485 L .56672 .51417 L 1 g
F
P
p
.56669 .51396 m .56672 .51417 L .56649 .50985 L 1 g
F
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54148 .53909 m .53511 .53133 L .56673 .51444 L p
1 g
F P
s
P
p
.002 w
.56674 .51468 m .54148 .53909 L p
.56673 .51444 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55048 .54397 m .54148 .53909 L .56674 .51468 L p
1 g
F P
s
P
p
.002 w
.56674 .51468 m .56732 .51412 L .56677 .5151 L p
1 g
F P
s
P
p
.002 w
.56677 .5151 m .55048 .54397 L p
.56674 .51468 L 1 g
F P
s
P
p
.002 w
.56677 .5151 m .56732 .51412 L .56684 .51652 L p
1 g
F P
s
P
p
.56677 .5151 m .56684 .51652 L .56679 .51553 L 1 g
F
P
p
.56677 .5151 m .56679 .51553 L .5665 .50987 L 1 g
F
P
p
.002 w
.56111 .54546 m .55048 .54397 L .56677 .5151 L p
1 g
F P
s
P
p
.002 w
.56684 .51652 m .56111 .54546 L p
.56677 .5151 L 1 g
F P
s
P
p
.002 w
.56111 .54546 m .56684 .51652 L p
.56743 .52785 L 1 g
F P
s
P
p
.002 w
.56684 .51652 m .56732 .51412 L p
.56743 .52785 L 1 g
F P
s
P
p
.002 w
.56269 .54518 m .56111 .54546 L p
.56892 .52368 L 1 g
F P
s
P
p
.002 w
.5827 .53818 m .57224 .54346 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.5914 .53018 m .5827 .53818 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.59742 .52032 m .5914 .53018 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.60011 .5096 m .59742 .52032 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.59917 .49917 m .60011 .5096 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.59465 .49015 m .59917 .49917 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.58702 .48352 m .59465 .49015 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.57707 .48004 m .58702 .48352 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.56587 .48013 m .57707 .48004 L .56732 .51412 L closepath p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5665 .50987 L p
1 g
F P
s
P
p
.56706 .52062 m .56854 .53025 L .5665 .50987 L 1 g
F
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.56706 .52062 L 1 g
F P
s
P
p
.56428 .53969 m .56269 .54518 L .56379 .54239 L 1 g
F
P
p
.002 w
.56176 .54756 m .56075 .54566 L p
.55975 .55012 L 1 g
F P
s
P
p
.002 w
.55975 .55012 m .56111 .54546 L p
.5621 .54712 L 1 g
F P
s
P
p
.002 w
.56176 .54756 m .56257 .5491 L p
.56379 .54239 L 1 g
F P
s
P
p
.002 w
.56179 .54763 m .56176 .54756 L p
.55975 .55012 L 1 g
F P
s
P
p
.002 w
.57486 .5686 m .55321 .57261 L .55975 .55012 L p
1 g
F P
s
P
p
.002 w
.55048 .54397 m .56111 .54546 L .55975 .55012 L p
1 g
F P
s
P
p
.002 w
.55975 .55012 m .55321 .57261 L p
.55197 .55964 L 1 g
F P
s
P
p
.55197 .55964 m .55048 .54397 L .55975 .55012 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56179 .54763 L p
1 g
F P
s
P
p
.55526 .55562 m .54998 .56518 L .56179 .54763 L 1 g
F
P
p
.002 w
.54919 .56304 m .54998 .56518 L p
.55526 .55562 L 1 g
F P
s
P
p
.53873 .57064 m .53868 .57068 L .53871 .57066 L 1 g
F
P
p
.002 w
.53172 .57468 m .53128 .57265 L p
.52667 .57635 L 1 g
F P
s
P
p
.002 w
.52667 .57635 m .5324 .56985 L p
.53426 .57385 L 1 g
F P
s
P
p
.002 w
.53172 .57468 m .5322 .57686 L p
.53871 .57066 L 1 g
F P
s
P
p
.002 w
.5318 .57503 m .53172 .57468 L p
.52667 .57635 L 1 g
F P
s
P
p
.002 w
.54396 .59475 m .51379 .59095 L .52667 .57635 L p
1 g
F P
s
P
p
.002 w
.51465 .56048 m .5324 .56985 L .52667 .57635 L p
1 g
F P
s
P
p
.002 w
.52667 .57635 m .51379 .59095 L p
.51411 .57957 L 1 g
F P
s
P
p
.51411 .57957 m .51465 .56048 L .52667 .57635 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5318 .57503 L p
1 g
F P
s
P
p
.52148 .57768 m .51111 .583 L .5318 .57503 L 1 g
F
P
p
.002 w
.51092 .58038 m .51111 .583 L p
.52148 .57768 L 1 g
F P
s
P
p
.49983 .58081 m .49451 .58102 L .49803 .58117 L 1 g
F
P
p
.002 w
.48784 .57758 m .49451 .58102 L p
.48863 .58068 L 1 g
F P
s
P
p
.002 w
.49451 .58102 m .49803 .58283 L p
.48905 .58078 L 1 g
F P
s
P
p
.48863 .58068 m .49451 .58102 L .48905 .58078 L 1 g
F
P
p
.002 w
.49803 .58283 m .51379 .59095 L p
.48863 .58068 L 1 g
F P
s
P
p
.002 w
.48905 .58078 m .48889 .583 L p
.49803 .58117 L 1 g
F P
s
P
p
.48865 .58076 m .4837 .57956 L .48863 .58068 L 1 g
F
P
p
.48414 .58056 m .4837 .57956 L .48865 .58076 L 1 g
F
P
p
.46547 .57299 m .469 .55579 L .4837 .57956 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46842 .57405 L p
1 g
F P
s
P
p
.46195 .56995 m .45002 .56518 L .46842 .57405 L 1 g
F
P
p
.47872 .57776 m .47423 .57739 L .4837 .57956 L 1 g
F
P
p
.002 w
.469 .55579 m .48784 .57758 L .4837 .57956 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51102 .58174 L p
1 g
F P
s
P
p
.49803 .58117 m .48889 .583 L .51102 .58174 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58078 L p
1 g
F P
s
P
p
.47423 .57739 m .4678 .57686 L .48905 .58078 L 1 g
F
P
p
.002 w
.44598 .28073 m .38937 .31926 L .37745 .30469 L p
1 g
F P
s
P
p
.002 w
.55321 .57261 m .57486 .5686 L .57519 .58885 L p
1 g
F P
s
P
p
.002 w
.57519 .58885 m .54396 .59475 L .55321 .57261 L p
1 g
F P
s
P
p
.002 w
.36474 .38888 m .34325 .44744 L .32528 .43377 L p
1 g
F P
s
P
p
.002 w
.32528 .43377 m .34743 .37263 L .36474 .38888 L p
1 g
F P
s
P
p
.002 w
.36656 .46103 m .36566 .51516 L .34267 .50597 L p
1 g
F P
s
P
p
.002 w
.34267 .50597 m .34325 .44744 L .36656 .46103 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.61205 .5428 m .6238 .52365 L .64571 .52414 L p
1 g
F P
s
P
p
.002 w
.65364 .49402 m .64571 .52414 L .6238 .52365 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.67034 .44577 m .65492 .41219 L .66566 .38737 L p
1 g
F P
s
P
p
.002 w
.63364 .3568 m .66566 .38737 L .65492 .41219 L p
1 g
F P
s
P
p
.002 w
.66566 .38737 m .63364 .3568 L .63544 .32982 L p
1 g
F P
s
P
p
.002 w
.65364 .49402 m .65149 .46433 L .67034 .44577 L p
1 g
F P
s
P
p
.002 w
.65492 .41219 m .67034 .44577 L .65149 .46433 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52511 .46169 L
s
P
p
.002 w
.58101 .28477 m .52065 .28244 L .50987 .26189 L p
1 g
F P
s
P
p
.002 w
.44598 .28073 m .50987 .26189 L .52065 .28244 L p
1 g
F P
s
P
p
.002 w
.58701 .30998 m .63544 .32982 L .63364 .3568 L p
1 g
F P
s
P
p
.002 w
.63544 .32982 m .58701 .30998 L .58101 .28477 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52065 .28244 m .58101 .28477 L .58701 .30998 L p
1 g
F P
s
P
p
.002 w
.6238 .52365 m .62918 .50279 L .65364 .49402 L p
1 g
F P
s
P
p
.002 w
.65149 .46433 m .65364 .49402 L .62918 .50279 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.40509 .33774 m .36474 .38888 L .34743 .37263 L p
1 g
F P
s
P
p
.002 w
.34743 .37263 m .38937 .31926 L .40509 .33774 L p
1 g
F P
s
P
p
.002 w
.42506 .52631 m .43756 .56224 L .40869 .56461 L p
1 g
F P
s
P
p
.002 w
.40869 .56461 m .3934 .52206 L .42506 .52631 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.57224 .54346 m .5827 .53818 L .59516 .5583 L p
1 g
F P
s
P
p
.002 w
.59516 .5583 m .57486 .5686 L .57224 .54346 L p
1 g
F P
s
P
p
.002 w
.61205 .5428 m .59516 .5583 L .5827 .53818 L p
1 g
F P
s
P
p
.002 w
.52065 .28244 m .45941 .30071 L .44598 .28073 L p
1 g
F P
s
P
p
.002 w
.38937 .31926 m .44598 .28073 L .45941 .30071 L p
1 g
F P
s
P
p
.002 w
.39458 .47403 m .3934 .52206 L .36566 .51516 L p
1 g
F P
s
P
p
.002 w
.36566 .51516 m .36656 .46103 L .39458 .47403 L p
1 g
F P
s
P
p
.002 w
.5827 .53818 m .5914 .53018 L .61205 .5428 L p
1 g
F P
s
P
p
.002 w
.6238 .52365 m .61205 .5428 L .5914 .53018 L p
1 g
F P
s
P
p
.002 w
.38672 .40691 m .36656 .46103 L .34325 .44744 L p
1 g
F P
s
P
p
.002 w
.34325 .44744 m .36474 .38888 L .38672 .40691 L p
1 g
F P
s
P
p
.002 w
.45941 .30071 m .40509 .33774 L .38937 .31926 L p
1 g
F P
s
P
p
.002 w
.65149 .46433 m .6392 .43821 L .65492 .41219 L p
1 g
F P
s
P
p
.002 w
.62772 .38672 m .65492 .41219 L .6392 .43821 L p
1 g
F P
s
P
p
.002 w
.65492 .41219 m .62772 .38672 L .63364 .3568 L p
1 g
F P
s
P
p
.002 w
.62918 .50279 m .62754 .48235 L .65149 .46433 L p
1 g
F P
s
P
p
.002 w
.6392 .43821 m .65149 .46433 L .62754 .48235 L p
1 g
F P
s
P
p
.002 w
.5914 .53018 m .59742 .52032 L .6238 .52365 L p
1 g
F P
s
P
p
.002 w
.62918 .50279 m .6238 .52365 L .59742 .52032 L p
1 g
F P
s
P
p
.002 w
.59052 .33956 m .63364 .3568 L .62772 .38672 L p
1 g
F P
s
P
p
.002 w
.63364 .3568 m .59052 .33956 L .58701 .30998 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.58701 .30998 m .53114 .30816 L .52065 .28244 L p
1 g
F P
s
P
p
.002 w
.45941 .30071 m .52065 .28244 L .53114 .30816 L p
1 g
F P
s
P
p
.002 w
.53114 .30816 m .58701 .30998 L .59052 .33956 L p
1 g
F P
s
P
p
.002 w
.59742 .52032 m .60011 .5096 L .62918 .50279 L p
1 g
F P
s
P
p
.002 w
.62754 .48235 m .62918 .50279 L .60011 .5096 L p
1 g
F P
s
P
p
.002 w
.50192 .54538 m .51465 .56048 L .48784 .57758 L p
1 g
F P
s
P
p
.002 w
.48784 .57758 m .469 .55579 L .50192 .54538 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.54148 .53909 m .55048 .54397 L .5324 .56985 L p
1 g
F P
s
P
p
.002 w
.5324 .56985 m .51465 .56048 L .54148 .53909 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.42421 .35963 m .38672 .40691 L .36474 .38888 L p
1 g
F P
s
P
p
.002 w
.36474 .38888 m .40509 .33774 L .42421 .35963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.42642 .48594 m .42506 .52631 L .3934 .52206 L p
1 g
F P
s
P
p
.002 w
.3934 .52206 m .39458 .47403 L .42642 .48594 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62754 .48235 m .6189 .46452 L .6392 .43821 L p
1 g
F P
s
P
p
.002 w
.61777 .41859 m .6392 .43821 L .6189 .46452 L p
1 g
F P
s
P
p
.002 w
.6392 .43821 m .61777 .41859 L .62772 .38672 L p
1 g
F P
s
P
p
.002 w
.60011 .5096 m .59917 .49917 L .62754 .48235 L p
1 g
F P
s
P
p
.002 w
.6189 .46452 m .62754 .48235 L .59917 .49917 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41275 .42611 m .39458 .47403 L .36656 .46103 L p
1 g
F P
s
P
p
.002 w
.36656 .46103 m .38672 .40691 L .41275 .42611 L p
1 g
F P
s
P
p
.002 w
.53114 .30816 m .47449 .32528 L .45941 .30071 L p
1 g
F P
s
P
p
.002 w
.40509 .33774 m .45941 .30071 L .47449 .32528 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.59132 .37258 m .62772 .38672 L .61777 .41859 L p
1 g
F P
s
P
p
.002 w
.62772 .38672 m .59132 .37258 L .59052 .33956 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.47449 .32528 m .42421 .35963 L .40509 .33774 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.53511 .53133 m .54148 .53909 L .51465 .56048 L p
1 g
F P
s
P
p
.002 w
.51465 .56048 m .50192 .54538 L .53511 .53133 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.49571 .52607 m .50192 .54538 L .469 .55579 L p
1 g
F P
s
P
p
.002 w
.469 .55579 m .45958 .52769 L .49571 .52607 L p
1 g
F P
s
P
p
.002 w
.54093 .33829 m .59052 .33956 L .59132 .37258 L p
1 g
F P
s
P
p
.002 w
.59052 .33956 m .54093 .33829 L .53114 .30816 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.47449 .32528 m .53114 .30816 L .54093 .33829 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59917 .49917 m .59465 .49015 L .6189 .46452 L p
1 g
F P
s
P
p
.002 w
.60405 .45127 m .6189 .46452 L .59465 .49015 L p
1 g
F P
s
P
p
.002 w
.6189 .46452 m .60405 .45127 L .61777 .41859 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5893 .40789 m .61777 .41859 L .60405 .45127 L p
1 g
F P
s
P
p
.002 w
.61777 .41859 m .5893 .40789 L .59132 .37258 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44612 .38423 m .41275 .42611 L .38672 .40691 L p
1 g
F P
s
P
p
.002 w
.38672 .40691 m .42421 .35963 L .44612 .38423 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.53209 .52149 m .53511 .53133 L .50192 .54538 L p
1 g
F P
s
P
p
.002 w
.50192 .54538 m .49571 .52607 L .53209 .52149 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44194 .44577 m .42642 .48594 L .39458 .47403 L p
1 g
F P
s
P
p
.002 w
.39458 .47403 m .41275 .42611 L .44194 .44577 L p
1 g
F P
s
P
p
.002 w
.59465 .49015 m .58702 .48352 L .60405 .45127 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.54093 .33829 m .49072 .35371 L .47449 .32528 L p
1 g
F P
s
P
p
.002 w
.42421 .35963 m .47449 .32528 L .49072 .35371 L p
1 g
F P
s
P
p
.002 w
.54963 .37185 m .59132 .37258 L .5893 .40789 L p
1 g
F P
s
P
p
.002 w
.59132 .37258 m .54963 .37185 L .54093 .33829 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.58449 .44418 m .60405 .45127 L .58702 .48352 L p
1 g
F P
s
P
p
.002 w
.60405 .45127 m .58449 .44418 L .5893 .40789 L p
1 g
F P
s
P
p
.002 w
.49687 .50462 m .49571 .52607 L .45958 .52769 L p
1 g
F P
s
P
p
.002 w
.45958 .52769 m .46095 .49628 L .49687 .50462 L p
1 g
F P
s
P
p
.002 w
.49072 .35371 m .44612 .38423 L .42421 .35963 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58702 .48352 m .57707 .48004 L .58449 .44418 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.49072 .35371 m .54093 .33829 L .54963 .37185 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53278 .51064 m .53209 .52149 L .49571 .52607 L p
1 g
F P
s
P
p
.002 w
.49571 .52607 m .49687 .50462 L .53278 .51064 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42642 .48594 m .44194 .44577 L .47323 .46513 L p
1 g
F P
s
P
p
.002 w
.55687 .4076 m .5893 .40789 L .58449 .44418 L p
1 g
F P
s
P
p
.002 w
.5893 .40789 m .55687 .4076 L .54963 .37185 L p
1 g
F P
s
P
p
.002 w
.57707 .48004 m .56587 .48013 L .56235 .44417 L p
1 g
F P
s
P
p
.002 w
.56235 .44417 m .58449 .44418 L .57707 .48004 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.47008 .41067 m .44194 .44577 L .41275 .42611 L p
1 g
F P
s
P
p
.002 w
.41275 .42611 m .44612 .38423 L .47008 .41067 L p
1 g
F P
s
P
p
.002 w
.53715 .49997 m .53278 .51064 L .49687 .50462 L p
1 g
F P
s
P
p
.002 w
.58449 .44418 m .56235 .44417 L .55687 .4076 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56587 .48013 m .55468 .48381 L .54012 .45135 L p
1 g
F P
s
P
p
.002 w
.54012 .45135 m .56235 .44417 L .56587 .48013 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54473 .49068 m .53715 .49997 L .50538 .48344 L p
1 g
F P
s
P
p
.002 w
.49687 .50462 m .50538 .48344 L .53715 .49997 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.54963 .37185 m .5075 .385 L .49072 .35371 L p
1 g
F P
s
P
p
.002 w
.44612 .38423 m .49072 .35371 L .5075 .385 L p
1 g
F P
s
P
p
.002 w
.5075 .385 m .54963 .37185 L .55687 .4076 L p
1 g
F P
s
P
p
.002 w
.50538 .48344 m .49687 .50462 L .46095 .49628 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.5075 .385 m .47008 .41067 L .44612 .38423 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.56235 .44417 m .54012 .45135 L .52419 .41798 L p
1 g
F P
s
P
p
.002 w
.52419 .41798 m .55687 .4076 L .56235 .44417 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.55687 .4076 m .52419 .41798 L .5075 .385 L p
1 g
F P
s
P
p
.002 w
.49515 .43794 m .47323 .46513 L .44194 .44577 L p
1 g
F P
s
P
p
.002 w
.44194 .44577 m .47008 .41067 L .49515 .43794 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.47008 .41067 m .5075 .385 L .52419 .41798 L p
1 g
F P
s
P
p
.002 w
.54012 .45135 m .52037 .46496 L .49515 .43794 L p
1 g
F P
s
P
p
.002 w
.49515 .43794 m .52419 .41798 L .54012 .45135 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52419 .41798 m .49515 .43794 L .47008 .41067 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59009 .5424 m
.608 .56464 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .35963 .67556 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .608 .56464 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.255039)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.255039)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4676 .47532 m .50728 .46241 L .49492 .43676 L p
1 g
F P
s
P
p
.002 w
.49492 .43676 m .46184 .44742 L .4676 .47532 L p
1 g
F P
s
P
p
.002 w
.52421 .41768 m .49492 .43676 L .50728 .46241 L p
1 g
F P
s
P
p
.002 w
.46184 .44742 m .49492 .43676 L .4827 .41097 L p
1 g
F P
s
P
p
.002 w
.49492 .43676 m .52421 .41768 L .5054 .39615 L p
1 g
F P
s
P
p
.002 w
.5054 .39615 m .4827 .41097 L .49492 .43676 L p
1 g
F P
s
P
p
.002 w
.4827 .41097 m .45702 .41917 L .46184 .44742 L p
1 g
F P
s
P
p
.002 w
.45702 .41917 m .4827 .41097 L .47083 .38551 L p
1 g
F P
s
P
p
.002 w
.4827 .41097 m .5054 .39615 L .48637 .37534 L p
1 g
F P
s
P
p
.002 w
.48637 .37534 m .47083 .38551 L .4827 .41097 L p
1 g
F P
s
P
p
.002 w
.50728 .46241 m .54246 .43955 L .52421 .41768 L p
1 g
F P
s
P
p
.002 w
.54688 .39198 m .52421 .41768 L .54246 .43955 L p
1 g
F P
s
P
p
.002 w
.52421 .41768 m .54688 .39198 L .52288 .37614 L p
1 g
F P
s
P
p
.002 w
.52288 .37614 m .5054 .39615 L .52421 .41768 L p
1 g
F P
s
P
p
.002 w
.47419 .50236 m .51955 .48747 L .50728 .46241 L p
1 g
F P
s
P
p
.002 w
.50728 .46241 m .4676 .47532 L .47419 .50236 L p
1 g
F P
s
P
p
.002 w
.54246 .43955 m .50728 .46241 L .51955 .48747 L p
1 g
F P
s
P
p
.002 w
.5054 .39615 m .52288 .37614 L .49826 .36159 L p
1 g
F P
s
P
p
.002 w
.49826 .36159 m .48637 .37534 L .5054 .39615 L p
1 g
F P
s
P
p
.002 w
.42705 .47696 m .4676 .47532 L .46184 .44742 L p
1 g
F P
s
P
p
.002 w
.46184 .44742 m .42809 .44857 L .42705 .47696 L p
1 g
F P
s
P
p
.002 w
.42809 .44857 m .46184 .44742 L .45702 .41917 L p
1 g
F P
s
P
p
.002 w
.51955 .48747 m .55981 .46137 L .54246 .43955 L p
1 g
F P
s
P
p
.002 w
.56984 .40881 m .54246 .43955 L .55981 .46137 L p
1 g
F P
s
P
p
.002 w
.54246 .43955 m .56984 .40881 L .54688 .39198 L p
1 g
F P
s
P
p
.002 w
.45702 .41917 m .43087 .41989 L .42809 .44857 L p
1 g
F P
s
P
p
.002 w
.43087 .41989 m .45702 .41917 L .45322 .39108 L p
1 g
F P
s
P
p
.002 w
.47083 .38551 m .45322 .39108 L .45702 .41917 L p
1 g
F P
s
P
p
.002 w
.45322 .39108 m .47083 .38551 L .45952 .36085 L p
1 g
F P
s
P
p
.002 w
.47083 .38551 m .48637 .37534 L .46745 .35565 L p
1 g
F P
s
P
p
.002 w
.46745 .35565 m .45952 .36085 L .47083 .38551 L p
1 g
F P
s
P
p
.002 w
.4278 .50453 m .47419 .50236 L .4676 .47532 L p
1 g
F P
s
P
p
.002 w
.4676 .47532 m .42705 .47696 L .4278 .50453 L p
1 g
F P
s
P
p
.002 w
.48637 .37534 m .49826 .36159 L .47349 .34861 L p
1 g
F P
s
P
p
.002 w
.47349 .34861 m .46745 .35565 L .48637 .37534 L p
1 g
F P
s
P
p
.002 w
.53332 .35287 m .52288 .37614 L .54688 .39198 L p
1 g
F P
s
P
p
.002 w
.52288 .37614 m .53332 .35287 L .50526 .34564 L p
1 g
F P
s
P
p
.002 w
.50526 .34564 m .49826 .36159 L .52288 .37614 L p
1 g
F P
s
P
p
.002 w
.48151 .52803 m .5315 .51148 L .51955 .48747 L p
1 g
F P
s
P
p
.002 w
.51955 .48747 m .47419 .50236 L .48151 .52803 L p
1 g
F P
s
P
p
.002 w
.55981 .46137 m .51955 .48747 L .5315 .51148 L p
1 g
F P
s
P
p
.002 w
.56064 .36203 m .54688 .39198 L .56984 .40881 L p
1 g
F P
s
P
p
.002 w
.54688 .39198 m .56064 .36203 L .53332 .35287 L p
1 g
F P
s
P
p
.002 w
.45322 .39108 m .43534 .39146 L .43087 .41989 L p
1 g
F P
s
P
p
.002 w
.43534 .39146 m .45322 .39108 L .45053 .36367 L p
1 g
F P
s
P
p
.002 w
.45952 .36085 m .45053 .36367 L .45322 .39108 L p
1 g
F P
s
P
p
.002 w
.5315 .51148 m .57594 .48273 L .55981 .46137 L p
1 g
F P
s
P
p
.002 w
.59131 .42635 m .55981 .46137 L .57594 .48273 L p
1 g
F P
s
P
p
.002 w
.55981 .46137 m .59131 .42635 L .56984 .40881 L p
1 g
F P
s
P
p
.002 w
.49826 .36159 m .50526 .34564 L .47698 .34047 L p
1 g
F P
s
P
p
.002 w
.47698 .34047 m .47349 .34861 L .49826 .36159 L p
1 g
F P
s
P
p
.002 w
.39697 .43988 m .42809 .44857 L .43087 .41989 L p
1 g
F P
s
P
p
.002 w
.43087 .41989 m .40687 .41294 L .39697 .43988 L p
1 g
F P
s
P
p
.002 w
.40687 .41294 m .43087 .41989 L .43534 .39146 L p
1 g
F P
s
P
p
.002 w
.58667 .37294 m .56984 .40881 L .59131 .42635 L p
1 g
F P
s
P
p
.002 w
.56984 .40881 m .58667 .37294 L .56064 .36203 L p
1 g
F P
s
P
p
.002 w
.38952 .46687 m .42705 .47696 L .42809 .44857 L p
1 g
F P
s
P
p
.002 w
.42809 .44857 m .39697 .43988 L .38952 .46687 L p
1 g
F P
s
P
p
.002 w
.43534 .39146 m .41901 .38655 L .40687 .41294 L p
1 g
F P
s
P
p
.002 w
.41901 .38655 m .43534 .39146 L .44142 .36381 L p
1 g
F P
s
P
p
.002 w
.45053 .36367 m .44142 .36381 L .43534 .39146 L p
1 g
F P
s
P
p
.002 w
.43036 .53072 m .48151 .52803 L .47419 .50236 L p
1 g
F P
s
P
p
.002 w
.47419 .50236 m .4278 .50453 L .43036 .53072 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .45053 .36367 L .45952 .36085 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .45952 .36085 L .46745 .35565 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .46745 .35565 L .47349 .34861 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .44142 .36381 L .45053 .36367 L closepath p
1 g
F P
s
P
p
.002 w
.53552 .32865 m .53332 .35287 L .56064 .36203 L p
1 g
F P
s
P
p
.002 w
.53332 .35287 m .53552 .32865 L .50657 .32911 L p
1 g
F P
s
P
p
.002 w
.50657 .32911 m .50526 .34564 L .53332 .35287 L p
1 g
F P
s
P
p
.002 w
.50526 .34564 m .50657 .32911 L .47755 .33207 L p
1 g
F P
s
P
p
.002 w
.47755 .33207 m .47698 .34047 L .50526 .34564 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .47349 .34861 L .47698 .34047 L closepath p
1 g
F P
s
P
p
.002 w
.38472 .49337 m .4278 .50453 L .42705 .47696 L p
1 g
F P
s
P
p
.002 w
.42705 .47696 m .38952 .46687 L .38472 .49337 L p
1 g
F P
s
P
p
.002 w
.48945 .55178 m .54291 .53394 L .5315 .51148 L p
1 g
F P
s
P
p
.002 w
.5315 .51148 m .48151 .52803 L .48945 .55178 L p
1 g
F P
s
P
p
.002 w
.57594 .48273 m .5315 .51148 L .54291 .53394 L p
1 g
F P
s
P
p
.002 w
.44142 .36381 m .43315 .36123 L .41901 .38655 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .43315 .36123 L .44142 .36381 L closepath p
1 g
F P
s
P
p
.002 w
.57594 .48273 m .61085 .44426 L .59131 .42635 L p
1 g
F P
s
P
p
.002 w
.61091 .38544 m .59131 .42635 L .61085 .44426 L p
1 g
F P
s
P
p
.002 w
.59131 .42635 m .61091 .38544 L .58667 .37294 L p
1 g
F P
s
P
p
.002 w
.56383 .33071 m .56064 .36203 L .58667 .37294 L p
1 g
F P
s
P
p
.002 w
.56064 .36203 m .56383 .33071 L .53552 .32865 L p
1 g
F P
s
P
p
.002 w
.38755 .39882 m .40687 .41294 L .41901 .38655 L p
1 g
F P
s
P
p
.002 w
.41901 .38655 m .40598 .37678 L .38755 .39882 L p
1 g
F P
s
P
p
.002 w
.40598 .37678 m .41901 .38655 L .43315 .36123 L p
1 g
F P
s
P
p
.002 w
.54291 .53394 m .5905 .50322 L .57594 .48273 L p
1 g
F P
s
P
p
.002 w
.61085 .44426 m .57594 .48273 L .5905 .50322 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .47698 .34047 L .47755 .33207 L closepath p
1 g
F P
s
P
p
.002 w
.37173 .42191 m .39697 .43988 L .40687 .41294 L p
1 g
F P
s
P
p
.002 w
.40687 .41294 m .38755 .39882 L .37173 .42191 L p
1 g
F P
s
P
p
.002 w
.43315 .36123 m .4266 .3562 L .40598 .37678 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .4266 .3562 L .43315 .36123 L closepath p
1 g
F P
s
P
p
.002 w
.43473 .55496 m .48945 .55178 L .48151 .52803 L p
1 g
F P
s
P
p
.002 w
.48151 .52803 m .43036 .53072 L .43473 .55496 L p
1 g
F P
s
P
p
.002 w
.47509 .32433 m .47755 .33207 L .50657 .32911 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .47755 .33207 L .47509 .32433 L closepath p
1 g
F P
s
P
p
.002 w
.50192 .31375 m .50657 .32911 L .53552 .32865 L p
1 g
F P
s
P
p
.002 w
.50657 .32911 m .50192 .31375 L .47509 .32433 L p
1 g
F P
s
P
p
.002 w
.38274 .51882 m .43036 .53072 L .4278 .50453 L p
1 g
F P
s
P
p
.002 w
.4278 .50453 m .38472 .49337 L .38274 .51882 L p
1 g
F P
s
P
p
.002 w
.35888 .44559 m .38952 .46687 L .39697 .43988 L p
1 g
F P
s
P
p
.002 w
.39697 .43988 m .37173 .42191 L .35888 .44559 L p
1 g
F P
s
P
p
.002 w
.59094 .3353 m .58667 .37294 L .61091 .38544 L p
1 g
F P
s
P
p
.002 w
.58667 .37294 m .59094 .3353 L .56383 .33071 L p
1 g
F P
s
P
p
.002 w
.3977 .36308 m .40598 .37678 L .4266 .3562 L p
1 g
F P
s
P
p
.002 w
.4266 .3562 m .42251 .34921 L .3977 .36308 L p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .42251 .34921 L .4266 .3562 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .47509 .32433 L .46985 .31808 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .43529 .31825 L .42809 .32462 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .42809 .32462 L .42327 .33251 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .42327 .33251 L .42135 .34102 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .42135 .34102 L .42251 .34921 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .46985 .31808 L .46236 .31403 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .46236 .31403 L .45344 .31264 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .45344 .31264 L .44407 .3141 L closepath p
1 g
F P
s
P
p
.002 w
.44902 .33747 m .44407 .3141 L .43529 .31825 L closepath p
1 g
F P
s
P
p
.002 w
.52899 .30598 m .53552 .32865 L .56383 .33071 L p
1 g
F P
s
P
p
.002 w
.53552 .32865 m .52899 .30598 L .50192 .31375 L p
1 g
F P
s
P
p
.002 w
.37512 .37883 m .38755 .39882 L .40598 .37678 L p
1 g
F P
s
P
p
.002 w
.40598 .37678 m .3977 .36308 L .37512 .37883 L p
1 g
F P
s
P
p
.002 w
.46985 .31808 m .47509 .32433 L .50192 .31375 L p
1 g
F P
s
P
p
.002 w
.5905 .50322 m .62803 .4622 L .61085 .44426 L p
1 g
F P
s
P
p
.002 w
.63282 .3993 m .61085 .44426 L .62803 .4622 L p
1 g
F P
s
P
p
.002 w
.61085 .44426 m .63282 .3993 L .61091 .38544 L p
1 g
F P
s
P
p
.002 w
.49785 .57308 m .55352 .55437 L .54291 .53394 L p
1 g
F P
s
P
p
.002 w
.54291 .53394 m .48945 .55178 L .49785 .57308 L p
1 g
F P
s
P
p
.002 w
.5905 .50322 m .54291 .53394 L .55352 .55437 L p
1 g
F P
s
P
p
.002 w
.3952 .34687 m .3977 .36308 L .42251 .34921 L p
1 g
F P
s
P
p
.002 w
.42251 .34921 m .42135 .34102 L .3952 .34687 L p
1 g
F P
s
P
p
.002 w
.55352 .55437 m .60315 .5224 L .5905 .50322 L p
1 g
F P
s
P
p
.002 w
.62803 .4622 m .5905 .50322 L .60315 .5224 L p
1 g
F P
s
P
p
.002 w
.34937 .46939 m .38472 .49337 L .38952 .46687 L p
1 g
F P
s
P
p
.002 w
.38952 .46687 m .35888 .44559 L .34937 .46939 L p
1 g
F P
s
P
p
.002 w
.50192 .31375 m .49171 .30125 L .46985 .31808 L p
1 g
F P
s
P
p
.002 w
.46236 .31403 m .46985 .31808 L .49171 .30125 L p
1 g
F P
s
P
p
.002 w
.49171 .30125 m .50192 .31375 L .52899 .30598 L p
1 g
F P
s
P
p
.002 w
.35528 .39619 m .37173 .42191 L .38755 .39882 L p
1 g
F P
s
P
p
.002 w
.38755 .39882 m .37512 .37883 L .35528 .39619 L p
1 g
F P
s
P
p
.002 w
.55575 .30122 m .56383 .33071 L .59094 .3353 L p
1 g
F P
s
P
p
.002 w
.56383 .33071 m .55575 .30122 L .52899 .30598 L p
1 g
F P
s
P
p
.002 w
.39887 .32991 m .3952 .34687 L .42135 .34102 L p
1 g
F P
s
P
p
.002 w
.42135 .34102 m .42327 .33251 L .39887 .32991 L p
1 g
F P
s
P
p
.002 w
.61625 .34238 m .61091 .38544 L .63282 .3993 L p
1 g
F P
s
P
p
.002 w
.61091 .38544 m .61625 .34238 L .59094 .3353 L p
1 g
F P
s
P
p
.002 w
.44089 .57668 m .49785 .57308 L .48945 .55178 L p
1 g
F P
s
P
p
.002 w
.48945 .55178 m .43473 .55496 L .44089 .57668 L p
1 g
F P
s
P
p
.002 w
.38372 .54265 m .43473 .55496 L .43036 .53072 L p
1 g
F P
s
P
p
.002 w
.43036 .53072 m .38274 .51882 L .38372 .54265 L p
1 g
F P
s
P
p
.002 w
.49171 .30125 m .47692 .29305 L .46236 .31403 L p
1 g
F P
s
P
p
.002 w
.45344 .31264 m .46236 .31403 L .47692 .29305 L p
1 g
F P
s
P
p
.002 w
.37116 .35497 m .37512 .37883 L .3977 .36308 L p
1 g
F P
s
P
p
.002 w
.3977 .36308 m .3952 .34687 L .37116 .35497 L p
1 g
F P
s
P
p
.002 w
.40842 .31411 m .39887 .32991 L .42327 .33251 L p
1 g
F P
s
P
p
.002 w
.42327 .33251 m .42809 .32462 L .40842 .31411 L p
1 g
F P
s
P
p
.002 w
.47692 .29305 m .45915 .29017 L .45344 .31264 L p
1 g
F P
s
P
p
.002 w
.44407 .3141 m .45344 .31264 L .45915 .29017 L p
1 g
F P
s
P
p
.002 w
.51417 .28737 m .52899 .30598 L .55575 .30122 L p
1 g
F P
s
P
p
.002 w
.52899 .30598 m .51417 .28737 L .49171 .30125 L p
1 g
F P
s
P
p
.002 w
.4228 .30132 m .40842 .31411 L .42809 .32462 L p
1 g
F P
s
P
p
.002 w
.42809 .32462 m .43529 .31825 L .4228 .30132 L p
1 g
F P
s
P
p
.002 w
.3387 .41482 m .35888 .44559 L .37173 .42191 L p
1 g
F P
s
P
p
.002 w
.37173 .42191 m .35528 .39619 L .3387 .41482 L p
1 g
F P
s
P
p
.002 w
.45915 .29017 m .44039 .29302 L .44407 .3141 L p
1 g
F P
s
P
p
.002 w
.43529 .31825 m .44407 .3141 L .44039 .29302 L p
1 g
F P
s
P
p
.002 w
.47692 .29305 m .49171 .30125 L .51417 .28737 L p
1 g
F P
s
P
p
.002 w
.44039 .29302 m .4228 .30132 L .43529 .31825 L p
1 g
F P
s
P
p
.002 w
.3435 .49277 m .38274 .51882 L .38472 .49337 L p
1 g
F P
s
P
p
.002 w
.38472 .49337 m .34937 .46939 L .3435 .49277 L p
1 g
F P
s
P
p
.002 w
.58162 .29966 m .59094 .3353 L .61625 .34238 L p
1 g
F P
s
P
p
.002 w
.59094 .3353 m .58162 .29966 L .55575 .30122 L p
1 g
F P
s
P
p
.002 w
.60315 .5224 m .64242 .47982 L .62803 .4622 L p
1 g
F P
s
P
p
.002 w
.65186 .41429 m .62803 .4622 L .64242 .47982 L p
1 g
F P
s
P
p
.002 w
.62803 .4622 m .65186 .41429 L .63282 .3993 L p
1 g
F P
s
P
p
.002 w
.3764 .32982 m .37116 .35497 L .3952 .34687 L p
1 g
F P
s
P
p
.002 w
.3952 .34687 m .39887 .32991 L .3764 .32982 L p
1 g
F P
s
P
p
.002 w
.50656 .59138 m .56309 .57227 L .55352 .55437 L p
1 g
F P
s
P
p
.002 w
.55352 .55437 m .49785 .57308 L .50656 .59138 L p
1 g
F P
s
P
p
.002 w
.60315 .5224 m .55352 .55437 L .56309 .57227 L p
1 g
F P
s
P
p
.002 w
.34982 .36521 m .35528 .39619 L .37512 .37883 L p
1 g
F P
s
P
p
.002 w
.37512 .37883 m .37116 .35497 L .34982 .36521 L p
1 g
F P
s
P
p
.002 w
.63916 .35188 m .63282 .3993 L .65186 .41429 L p
1 g
F P
s
P
p
.002 w
.63282 .3993 m .63916 .35188 L .61625 .34238 L p
1 g
F P
s
P
p
.002 w
.56309 .57227 m .61355 .53981 L .60315 .5224 L p
1 g
F P
s
P
p
.002 w
.64242 .47982 m .60315 .5224 L .61355 .53981 L p
1 g
F P
s
P
p
.002 w
.51417 .28737 m .49243 .27506 L .47692 .29305 L p
1 g
F P
s
P
p
.002 w
.45915 .29017 m .47692 .29305 L .49243 .27506 L p
1 g
F P
s
P
p
.002 w
.38776 .56424 m .44089 .57668 L .43473 .55496 L p
1 g
F P
s
P
p
.002 w
.43473 .55496 m .38372 .54265 L .38776 .56424 L p
1 g
F P
s
P
p
.002 w
.53677 .27685 m .55575 .30122 L .58162 .29966 L p
1 g
F P
s
P
p
.002 w
.55575 .30122 m .53677 .27685 L .51417 .28737 L p
1 g
F P
s
P
p
.002 w
.32588 .43437 m .34937 .46939 L .35888 .44559 L p
1 g
F P
s
P
p
.002 w
.35888 .44559 m .3387 .41482 L .32588 .43437 L p
1 g
F P
s
P
p
.002 w
.44877 .59528 m .50656 .59138 L .49785 .57308 L p
1 g
F P
s
P
p
.002 w
.49785 .57308 m .44089 .57668 L .44877 .59528 L p
1 g
F P
s
P
p
.002 w
.39048 .30627 m .3764 .32982 L .39887 .32991 L p
1 g
F P
s
P
p
.002 w
.39887 .32991 m .40842 .31411 L .39048 .30627 L p
1 g
F P
s
P
p
.002 w
.49243 .27506 m .51417 .28737 L .53677 .27685 L p
1 g
F P
s
P
p
.002 w
.60602 .30145 m .61625 .34238 L .63916 .35188 L p
1 g
F P
s
P
p
.002 w
.61625 .34238 m .60602 .30145 L .58162 .29966 L p
1 g
F P
s
P
p
.002 w
.49243 .27506 m .46609 .27063 L .45915 .29017 L p
1 g
F P
s
P
p
.002 w
.44039 .29302 m .45915 .29017 L .46609 .27063 L p
1 g
F P
s
P
p
.002 w
.34158 .5152 m .38372 .54265 L .38274 .51882 L p
1 g
F P
s
P
p
.002 w
.38274 .51882 m .3435 .49277 L .34158 .5152 L p
1 g
F P
s
P
p
.002 w
.41189 .28715 m .39048 .30627 L .40842 .31411 L p
1 g
F P
s
P
p
.002 w
.40842 .31411 m .4228 .30132 L .41189 .28715 L p
1 g
F P
s
P
p
.002 w
.33177 .37747 m .3387 .41482 L .35528 .39619 L p
1 g
F P
s
P
p
.002 w
.35528 .39619 m .34982 .36521 L .33177 .37747 L p
1 g
F P
s
P
p
.002 w
.35644 .33234 m .34982 .36521 L .37116 .35497 L p
1 g
F P
s
P
p
.002 w
.37116 .35497 m .3764 .32982 L .35644 .33234 L p
1 g
F P
s
P
p
.002 w
.46609 .27063 m .43814 .27479 L .44039 .29302 L p
1 g
F P
s
P
p
.002 w
.4228 .30132 m .44039 .29302 L .43814 .27479 L p
1 g
F P
s
P
p
.002 w
.43814 .27479 m .41189 .28715 L .4228 .30132 L p
1 g
F P
s
P
p
.002 w
.61355 .53981 m .65357 .4967 L .64242 .47982 L p
1 g
F P
s
P
p
.002 w
.66752 .43012 m .64242 .47982 L .65357 .4967 L p
1 g
F P
s
P
p
.002 w
.64242 .47982 m .66752 .43012 L .65186 .41429 L p
1 g
F P
s
P
p
.002 w
.65908 .36368 m .65186 .41429 L .66752 .43012 L p
1 g
F P
s
P
p
.002 w
.65186 .41429 m .65908 .36368 L .63916 .35188 L p
1 g
F P
s
P
p
.002 w
.55903 .27002 m .58162 .29966 L .60602 .30145 L p
1 g
F P
s
P
p
.002 w
.58162 .29966 m .55903 .27002 L .53677 .27685 L p
1 g
F P
s
P
p
.002 w
.51541 .60612 m .57136 .5871 L .56309 .57227 L p
1 g
F P
s
P
p
.002 w
.56309 .57227 m .50656 .59138 L .51541 .60612 L p
1 g
F P
s
P
p
.002 w
.61355 .53981 m .56309 .57227 L .57136 .5871 L p
1 g
F P
s
P
p
.002 w
.31727 .4544 m .3435 .49277 L .34937 .46939 L p
1 g
F P
s
P
p
.002 w
.34937 .46939 m .32588 .43437 L .31727 .4544 L p
1 g
F P
s
P
p
.002 w
.53677 .27685 m .50859 .26056 L .49243 .27506 L p
1 g
F P
s
P
p
.002 w
.46609 .27063 m .49243 .27506 L .50859 .26056 L p
1 g
F P
s
P
p
.002 w
.57136 .5871 m .62136 .55498 L .61355 .53981 L p
1 g
F P
s
P
p
.002 w
.65357 .4967 m .61355 .53981 L .62136 .55498 L p
1 g
F P
s
P
p
.002 w
.3949 .583 m .44877 .59528 L .44089 .57668 L p
1 g
F P
s
P
p
.002 w
.44089 .57668 m .38776 .56424 L .3949 .583 L p
1 g
F P
s
P
p
.002 w
.50859 .26056 m .53677 .27685 L .55903 .27002 L p
1 g
F P
s
P
p
.002 w
.37477 .30141 m .35644 .33234 L .3764 .32982 L p
1 g
F P
s
P
p
.002 w
.3764 .32982 m .39048 .30627 L .37477 .30141 L p
1 g
F P
s
P
p
.002 w
.62833 .30666 m .63916 .35188 L .65908 .36368 L p
1 g
F P
s
P
p
.002 w
.63916 .35188 m .62833 .30666 L .60602 .30145 L p
1 g
F P
s
P
p
.002 w
.45829 .61017 m .51541 .60612 L .50656 .59138 L p
1 g
F P
s
P
p
.002 w
.50656 .59138 m .44877 .59528 L .45829 .61017 L p
1 g
F P
s
P
p
.002 w
.34382 .53608 m .38776 .56424 L .38372 .54265 L p
1 g
F P
s
P
p
.002 w
.38372 .54265 m .34158 .5152 L .34382 .53608 L p
1 g
F P
s
P
p
.002 w
.3176 .39153 m .32588 .43437 L .3387 .41482 L p
1 g
F P
s
P
p
.002 w
.3387 .41482 m .33177 .37747 L .3176 .39153 L p
1 g
F P
s
P
p
.002 w
.50859 .26056 m .47415 .2546 L .46609 .27063 L p
1 g
F P
s
P
p
.002 w
.43814 .27479 m .46609 .27063 L .47415 .2546 L p
1 g
F P
s
P
p
.002 w
.33958 .33755 m .33177 .37747 L .34982 .36521 L p
1 g
F P
s
P
p
.002 w
.34982 .36521 m .35644 .33234 L .33958 .33755 L p
1 g
F P
s
P
p
.002 w
.40289 .27623 m .37477 .30141 L .39048 .30627 L p
1 g
F P
s
P
p
.002 w
.39048 .30627 m .41189 .28715 L .40289 .27623 L p
1 g
F P
s
P
p
.002 w
.58041 .26722 m .60602 .30145 L .62833 .30666 L p
1 g
F P
s
P
p
.002 w
.60602 .30145 m .58041 .26722 L .55903 .27002 L p
1 g
F P
s
P
p
.002 w
.62136 .55498 m .66108 .51244 L .65357 .4967 L p
1 g
F P
s
P
p
.002 w
.67929 .44646 m .65357 .4967 L .66108 .51244 L p
1 g
F P
s
P
p
.002 w
.65357 .4967 m .67929 .44646 L .66752 .43012 L p
1 g
F P
s
P
p
.002 w
.67541 .37761 m .66752 .43012 L .67929 .44646 L p
1 g
F P
s
P
p
.002 w
.66752 .43012 m .67541 .37761 L .65908 .36368 L p
1 g
F P
s
P
p
.002 w
.47415 .2546 m .43743 .25997 L .43814 .27479 L p
1 g
F P
s
P
p
.002 w
.41189 .28715 m .43814 .27479 L .43743 .25997 L p
1 g
F P
s
P
p
.002 w
.43743 .25997 m .40289 .27623 L .41189 .28715 L p
1 g
F P
s
P
p
.002 w
.3133 .47445 m .34158 .5152 L .3435 .49277 L p
1 g
F P
s
P
p
.002 w
.3435 .49277 m .31727 .4544 L .3133 .47445 L p
1 g
F P
s
P
p
.002 w
.55903 .27002 m .52505 .25007 L .50859 .26056 L p
1 g
F P
s
P
p
.002 w
.47415 .2546 m .50859 .26056 L .52505 .25007 L p
1 g
F P
s
P
p
.002 w
.52505 .25007 m .55903 .27002 L .58041 .26722 L p
1 g
F P
s
P
p
.002 w
.52419 .61675 m .57805 .59837 L .57136 .5871 L p
1 g
F P
s
P
p
.002 w
.57136 .5871 m .51541 .60612 L .52419 .61675 L p
1 g
F P
s
P
p
.002 w
.62136 .55498 m .57136 .5871 L .57805 .59837 L p
1 g
F P
s
P
p
.002 w
.40513 .5983 m .45829 .61017 L .44877 .59528 L p
1 g
F P
s
P
p
.002 w
.44877 .59528 m .3949 .583 L .40513 .5983 L p
1 g
F P
s
P
p
.002 w
.64791 .31533 m .65908 .36368 L .67541 .37761 L p
1 g
F P
s
P
p
.002 w
.65908 .36368 m .64791 .31533 L .62833 .30666 L p
1 g
F P
s
P
p
.002 w
.57805 .59837 m .62625 .56744 L .62136 .55498 L p
1 g
F P
s
P
p
.002 w
.66108 .51244 m .62136 .55498 L .62625 .56744 L p
1 g
F P
s
P
p
.002 w
.36181 .29981 m .33958 .33755 L .35644 .33234 L p
1 g
F P
s
P
p
.002 w
.35644 .33234 m .37477 .30141 L .36181 .29981 L p
1 g
F P
s
P
p
.002 w
.30786 .40715 m .31727 .4544 L .32588 .43437 L p
1 g
F P
s
P
p
.002 w
.32588 .43437 m .3176 .39153 L .30786 .40715 L p
1 g
F P
s
P
p
.002 w
.35038 .5548 m .3949 .583 L .38776 .56424 L p
1 g
F P
s
P
p
.002 w
.38776 .56424 m .34382 .53608 L .35038 .5548 L p
1 g
F P
s
P
p
.002 w
.46929 .62078 m .52419 .61675 L .51541 .60612 L p
1 g
F P
s
P
p
.002 w
.51541 .60612 m .45829 .61017 L .46929 .62078 L p
1 g
F P
s
P
p
.002 w
.32641 .34548 m .3176 .39153 L .33177 .37747 L p
1 g
F P
s
P
p
.002 w
.33177 .37747 m .33958 .33755 L .32641 .34548 L p
1 g
F P
s
P
p
.002 w
.52505 .25007 m .48321 .24266 L .47415 .2546 L p
1 g
F P
s
P
p
.002 w
.43743 .25997 m .47415 .2546 L .48321 .24266 L p
1 g
F P
s
P
p
.002 w
.60035 .2687 m .62833 .30666 L .64791 .31533 L p
1 g
F P
s
P
p
.002 w
.62833 .30666 m .60035 .2687 L .58041 .26722 L p
1 g
F P
s
P
p
.002 w
.3143 .49399 m .34382 .53608 L .34158 .5152 L p
1 g
F P
s
P
p
.002 w
.34158 .5152 m .3133 .47445 L .3143 .49399 L p
1 g
F P
s
P
p
.002 w
.39612 .26901 m .36181 .29981 L .37477 .30141 L p
1 g
F P
s
P
p
.002 w
.37477 .30141 m .40289 .27623 L .39612 .26901 L p
1 g
F P
s
P
p
.002 w
.66108 .51244 m .68667 .46295 L .67929 .44646 L p
1 g
F P
s
P
p
.002 w
.68757 .39343 m .67929 .44646 L .68667 .46295 L p
1 g
F P
s
P
p
.002 w
.67929 .44646 m .68757 .39343 L .67541 .37761 L p
1 g
F P
s
P
p
.002 w
.62625 .56744 m .66455 .52659 L .66108 .51244 L p
1 g
F P
s
P
p
.002 w
.68667 .46295 m .66108 .51244 L .66455 .52659 L p
1 g
F P
s
P
p
.002 w
.48321 .24266 m .43837 .24914 L .43743 .25997 L p
1 g
F P
s
P
p
.002 w
.40289 .27623 m .43743 .25997 L .43837 .24914 L p
1 g
F P
s
P
p
.002 w
.54144 .24405 m .58041 .26722 L .60035 .2687 L p
1 g
F P
s
P
p
.002 w
.58041 .26722 m .54144 .24405 L .52505 .25007 L p
1 g
F P
s
P
p
.002 w
.48321 .24266 m .52505 .25007 L .54144 .24405 L p
1 g
F P
s
P
p
.002 w
.43837 .24914 m .39612 .26901 L .40289 .27623 L p
1 g
F P
s
P
p
.002 w
.66415 .32741 m .67541 .37761 L .68757 .39343 L p
1 g
F P
s
P
p
.002 w
.67541 .37761 m .66415 .32741 L .64791 .31533 L p
1 g
F P
s
P
p
.002 w
.30306 .42398 m .3133 .47445 L .31727 .4544 L p
1 g
F P
s
P
p
.002 w
.31727 .4544 m .30786 .40715 L .30306 .42398 L p
1 g
F P
s
P
p
.002 w
.41835 .60956 m .46929 .62078 L .45829 .61017 L p
1 g
F P
s
P
p
.002 w
.45829 .61017 m .40513 .5983 L .41835 .60956 L p
1 g
F P
s
P
p
.002 w
.53267 .62275 m .58292 .60556 L .57805 .59837 L p
1 g
F P
s
P
p
.002 w
.57805 .59837 m .52419 .61675 L .53267 .62275 L p
1 g
F P
s
P
p
.002 w
.62625 .56744 m .57805 .59837 L .58292 .60556 L p
1 g
F P
s
P
p
.002 w
.3613 .57075 m .40513 .5983 L .3949 .583 L p
1 g
F P
s
P
p
.002 w
.3949 .583 m .35038 .5548 L .3613 .57075 L p
1 g
F P
s
P
p
.002 w
.35208 .30172 m .32641 .34548 L .33958 .33755 L p
1 g
F P
s
P
p
.002 w
.33958 .33755 m .36181 .29981 L .35208 .30172 L p
1 g
F P
s
P
p
.002 w
.58292 .60556 m .62792 .57671 L .62625 .56744 L p
1 g
F P
s
P
p
.002 w
.66455 .52659 m .62625 .56744 L .62792 .57671 L p
1 g
F P
s
P
p
.002 w
.31751 .35606 m .30786 .40715 L .3176 .39153 L p
1 g
F P
s
P
p
.002 w
.3176 .39153 m .32641 .34548 L .31751 .35606 L p
1 g
F P
s
P
p
.002 w
.61825 .27465 m .64791 .31533 L .66415 .32741 L p
1 g
F P
s
P
p
.002 w
.64791 .31533 m .61825 .27465 L .60035 .2687 L p
1 g
F P
s
P
p
.002 w
.48158 .62658 m .53267 .62275 L .52419 .61675 L p
1 g
F P
s
P
p
.002 w
.52419 .61675 m .46929 .62078 L .48158 .62658 L p
1 g
F P
s
P
p
.002 w
.3205 .51246 m .35038 .5548 L .34382 .53608 L p
1 g
F P
s
P
p
.002 w
.34382 .53608 m .3143 .49399 L .3205 .51246 L p
1 g
F P
s
P
p
.002 w
.54144 .24405 m .49308 .23535 L .48321 .24266 L p
1 g
F P
s
P
p
.002 w
.43837 .24914 m .48321 .24266 L .49308 .23535 L p
1 g
F P
s
P
p
.002 w
.66455 .52659 m .68925 .47918 L .68667 .46295 L p
1 g
F P
s
P
p
.002 w
.69504 .41081 m .68667 .46295 L .68925 .47918 L p
1 g
F P
s
P
p
.002 w
.68667 .46295 m .69504 .41081 L .68757 .39343 L p
1 g
F P
s
P
p
.002 w
.39193 .26593 m .35208 .30172 L .36181 .29981 L p
1 g
F P
s
P
p
.002 w
.36181 .29981 m .39612 .26901 L .39193 .26593 L p
1 g
F P
s
P
p
.002 w
.55731 .2429 m .60035 .2687 L .61825 .27465 L p
1 g
F P
s
P
p
.002 w
.60035 .2687 m .55731 .2429 L .54144 .24405 L p
1 g
F P
s
P
p
.002 w
.62792 .57671 m .66367 .53868 L .66455 .52659 L p
1 g
F P
s
P
p
.002 w
.68925 .47918 m .66455 .52659 L .66367 .53868 L p
1 g
F P
s
P
p
.002 w
.49308 .23535 m .54144 .24405 L .55731 .2429 L p
1 g
F P
s
P
p
.002 w
.67643 .34275 m .68757 .39343 L .69504 .41081 L p
1 g
F P
s
P
p
.002 w
.68757 .39343 m .67643 .34275 L .66415 .32741 L p
1 g
F P
s
P
p
.002 w
.49308 .23535 m .44104 .24283 L .43837 .24914 L p
1 g
F P
s
P
p
.002 w
.39612 .26901 m .43837 .24914 L .44104 .24283 L p
1 g
F P
s
P
p
.002 w
.3036 .44164 m .3143 .49399 L .3133 .47445 L p
1 g
F P
s
P
p
.002 w
.3133 .47445 m .30306 .42398 L .3036 .44164 L p
1 g
F P
s
P
p
.002 w
.44104 .24283 m .39193 .26593 L .39612 .26901 L p
1 g
F P
s
P
p
.002 w
.43435 .61624 m .48158 .62658 L .46929 .62078 L p
1 g
F P
s
P
p
.002 w
.46929 .62078 m .41835 .60956 L .43435 .61624 L p
1 g
F P
s
P
p
.002 w
.37651 .58334 m .41835 .60956 L .40513 .5983 L p
1 g
F P
s
P
p
.002 w
.40513 .5983 m .3613 .57075 L .37651 .58334 L p
1 g
F P
s
P
p
.002 w
.34607 .30732 m .31751 .35606 L .32641 .34548 L p
1 g
F P
s
P
p
.002 w
.32641 .34548 m .35208 .30172 L .34607 .30732 L p
1 g
F P
s
P
p
.002 w
.31337 .36916 m .30306 .42398 L .30786 .40715 L p
1 g
F P
s
P
p
.002 w
.30786 .40715 m .31751 .35606 L .31337 .36916 L p
1 g
F P
s
P
p
.002 w
.54061 .62367 m .5857 .60823 L .58292 .60556 L p
1 g
F P
s
P
p
.002 w
.58292 .60556 m .53267 .62275 L .54061 .62367 L p
1 g
F P
s
P
p
.002 w
.62792 .57671 m .58292 .60556 L .5857 .60823 L p
1 g
F P
s
P
p
.002 w
.63352 .28514 m .66415 .32741 L .67643 .34275 L p
1 g
F P
s
P
p
.002 w
.66415 .32741 m .63352 .28514 L .61825 .27465 L p
1 g
F P
s
P
p
.002 w
.5857 .60823 m .62612 .58232 L .62792 .57671 L p
1 g
F P
s
P
p
.002 w
.66367 .53868 m .62792 .57671 L .62612 .58232 L p
1 g
F P
s
P
p
.002 w
.33201 .52927 m .3613 .57075 L .35038 .5548 L p
1 g
F P
s
P
p
.002 w
.35038 .5548 m .3205 .51246 L .33201 .52927 L p
1 g
F P
s
P
p
.002 w
.49489 .62712 m .54061 .62367 L .53267 .62275 L p
1 g
F P
s
P
p
.002 w
.53267 .62275 m .48158 .62658 L .49489 .62712 L p
1 g
F P
s
P
p
.002 w
.55731 .2429 m .50356 .23317 L .49308 .23535 L p
1 g
F P
s
P
p
.002 w
.44104 .24283 m .49308 .23535 L .50356 .23317 L p
1 g
F P
s
P
p
.002 w
.66367 .53868 m .68667 .49468 L .68925 .47918 L p
1 g
F P
s
P
p
.002 w
.68925 .47918 m .69735 .42938 L .69504 .41081 L p
1 g
F P
s
P
p
.002 w
.69735 .42938 m .68925 .47918 L .68667 .49468 L p
1 g
F P
s
P
p
.002 w
.61825 .27465 m .5722 .24693 L .55731 .2429 L p
1 g
F P
s
P
p
.002 w
.5722 .24693 m .61825 .27465 L .63352 .28514 L p
1 g
F P
s
P
p
.004 w
.32842 .58309 m
.33557 .57673 L
s
P
p
.004 w
.30618 .60287 m
.32842 .58309 L
s
P
p
.004 w
.30102 .60746 m
.30618 .60287 L
s
P
p
.002 w
.69504 .41081 m .6842 .36109 L .67643 .34275 L p
1 g
F P
s
P
p
.002 w
.6842 .36109 m .69504 .41081 L .69735 .42938 L p
1 g
F P
s
P
p
.002 w
.39058 .26732 m .34607 .30732 L .35208 .30172 L p
1 g
F P
s
P
p
.002 w
.35208 .30172 m .39193 .26593 L .39058 .26732 L p
1 g
F P
s
P
p
.002 w
.50356 .23317 m .55731 .2429 L .5722 .24693 L p
1 g
F P
s
P
p
.002 w
.62612 .58232 m .65817 .54825 L .66367 .53868 L p
1 g
F P
s
P
p
.002 w
.68667 .49468 m .66367 .53868 L .65817 .54825 L p
1 g
F P
s
P
p
.002 w
.30977 .45963 m .3205 .51246 L .3143 .49399 L p
1 g
F P
s
P
p
.002 w
.3143 .49399 m .3036 .44164 L .30977 .45963 L p
1 g
F P
s
P
p
.002 w
.50356 .23317 m .44549 .24151 L .44104 .24283 L p
1 g
F P
s
P
p
.002 w
.39193 .26593 m .44104 .24283 L .44549 .24151 L p
1 g
F P
s
P
p
.002 w
.39579 .59199 m .43435 .61624 L .41835 .60956 L p
1 g
F P
s
P
p
.002 w
.41835 .60956 m .37651 .58334 L .39579 .59199 L p
1 g
F P
s
P
p
.002 w
.44549 .24151 m .39058 .26732 L .39193 .26593 L p
1 g
F P
s
P
p
.002 w
.45282 .61787 m .49489 .62712 L .48158 .62658 L p
1 g
F P
s
P
p
.002 w
.48158 .62658 m .43435 .61624 L .45282 .61787 L p
1 g
F P
s
P
p
.002 w
.67643 .34275 m .64557 .30012 L .63352 .28514 L p
1 g
F P
s
P
p
.002 w
.64557 .30012 m .67643 .34275 L .6842 .36109 L p
1 g
F P
s
P
p
.002 w
.31442 .38455 m .3036 .44164 L .30306 .42398 L p
1 g
F P
s
P
p
.002 w
.30306 .42398 m .31337 .36916 L .31442 .38455 L p
1 g
F P
s
P
p
.002 w
.34418 .31666 m .31337 .36916 L .31751 .35606 L p
1 g
F P
s
P
p
.002 w
.31751 .35606 m .34607 .30732 L .34418 .31666 L p
1 g
F P
s
P
p
.002 w
.34876 .5438 m .37651 .58334 L .3613 .57075 L p
1 g
F P
s
P
p
.002 w
.3613 .57075 m .33201 .52927 L .34876 .5438 L p
1 g
F P
s
P
p
.004 w
.33557 .57673 m
.34381 .5694 L
s
P
p
.002 w
.54774 .61915 m .58619 .60599 L .5857 .60823 L p
1 g
F P
s
P
p
.002 w
.5857 .60823 m .54061 .62367 L .54774 .61915 L p
1 g
F P
s
P
p
.002 w
.62612 .58232 m .5857 .60823 L .58619 .60599 L p
1 g
F P
s
P
p
.002 w
.58619 .60599 m .62067 .58389 L .62612 .58232 L p
1 g
F P
s
P
p
.002 w
.65817 .54825 m .62612 .58232 L .62067 .58389 L p
1 g
F P
s
P
p
.002 w
.65817 .54825 m .6787 .50897 L .68667 .49468 L p
1 g
F P
s
P
p
.002 w
.69416 .44865 m .68667 .49468 L .6787 .50897 L p
1 g
F P
s
P
p
.002 w
.68667 .49468 m .69416 .44865 L .69735 .42938 L p
1 g
F P
s
P
p
.002 w
.58563 .25634 m .63352 .28514 L .64557 .30012 L p
1 g
F P
s
P
p
.002 w
.63352 .28514 m .58563 .25634 L .5722 .24693 L p
1 g
F P
s
P
p
.002 w
.50887 .62205 m .54774 .61915 L .54061 .62367 L p
1 g
F P
s
P
p
.002 w
.54061 .62367 m .49489 .62712 L .50887 .62205 L p
1 g
F P
s
P
p
.002 w
.5722 .24693 m .51439 .23649 L .50356 .23317 L p
1 g
F P
s
P
p
.002 w
.44549 .24151 m .50356 .23317 L .51439 .23649 L p
1 g
F P
s
P
p
.002 w
.68699 .38206 m .69735 .42938 L .69416 .44865 L p
1 g
F P
s
P
p
.002 w
.69735 .42938 m .68699 .38206 L .6842 .36109 L p
1 g
F P
s
P
p
.002 w
.32169 .47742 m .33201 .52927 L .3205 .51246 L p
1 g
F P
s
P
p
.002 w
.3205 .51246 m .30977 .45963 L .32169 .47742 L p
1 g
F P
s
P
p
.002 w
.51439 .23649 m .5722 .24693 L .58563 .25634 L p
1 g
F P
s
P
p
.002 w
.62067 .58389 m .64794 .55487 L .65817 .54825 L p
1 g
F P
s
P
p
.002 w
.6787 .50897 m .65817 .54825 L .64794 .55487 L p
1 g
F P
s
P
p
.002 w
.39232 .27347 m .34418 .31666 L .34607 .30732 L p
1 g
F P
s
P
p
.002 w
.34607 .30732 m .39058 .26732 L .39232 .27347 L p
1 g
F P
s
P
p
.002 w
.41874 .59625 m .45282 .61787 L .43435 .61624 L p
1 g
F P
s
P
p
.002 w
.43435 .61624 m .39579 .59199 L .41874 .59625 L p
1 g
F P
s
P
p
.002 w
.65387 .31939 m .6842 .36109 L .68699 .38206 L p
1 g
F P
s
P
p
.002 w
.6842 .36109 m .65387 .31939 L .64557 .30012 L p
1 g
F P
s
P
p
.002 w
.32093 .40188 m .30977 .45963 L .3036 .44164 L p
1 g
F P
s
P
p
.002 w
.3036 .44164 m .31442 .38455 L .32093 .40188 L p
1 g
F P
s
P
p
.002 w
.51439 .23649 m .4517 .24554 L .44549 .24151 L p
1 g
F P
s
P
p
.002 w
.39058 .26732 m .44549 .24151 L .4517 .24554 L p
1 g
F P
s
P
p
.002 w
.47333 .61412 m .50887 .62205 L .49489 .62712 L p
1 g
F P
s
P
p
.002 w
.49489 .62712 m .45282 .61787 L .47333 .61412 L p
1 g
F P
s
P
p
.002 w
.37048 .5555 m .39579 .59199 L .37651 .58334 L p
1 g
F P
s
P
p
.002 w
.37651 .58334 m .34876 .5438 L .37048 .5555 L p
1 g
F P
s
P
p
.004 w
.34381 .5694 m
.35337 .56091 L
s
P
p
.002 w
.4517 .24554 m .39232 .27347 L .39058 .26732 L p
1 g
F P
s
P
p
.002 w
.34676 .32972 m .31442 .38455 L .31337 .36916 L p
1 g
F P
s
P
p
.002 w
.31337 .36916 m .34418 .31666 L .34676 .32972 L p
1 g
F P
s
P
p
.002 w
.55379 .60898 m .58421 .59859 L .58619 .60599 L p
1 g
F P
s
P
p
.002 w
.58619 .60599 m .54774 .61915 L .55379 .60898 L p
1 g
F P
s
P
p
.002 w
.62067 .58389 m .58619 .60599 L .58421 .59859 L p
1 g
F P
s
P
p
.002 w
.59708 .27115 m .64557 .30012 L .65387 .31939 L p
1 g
F P
s
P
p
.002 w
.64557 .30012 m .59708 .27115 L .58563 .25634 L p
1 g
F P
s
P
p
.002 w
.64794 .55487 m .66528 .52154 L .6787 .50897 L p
1 g
F P
s
P
p
.002 w
.68525 .46808 m .6787 .50897 L .66528 .52154 L p
1 g
F P
s
P
p
.002 w
.6787 .50897 m .68525 .46808 L .69416 .44865 L p
1 g
F P
s
P
p
.002 w
.58421 .59859 m .61149 .58109 L .62067 .58389 L p
1 g
F P
s
P
p
.002 w
.64794 .55487 m .62067 .58389 L .61149 .58109 L p
1 g
F P
s
P
p
.002 w
.68446 .40513 m .69416 .44865 L .68525 .46808 L p
1 g
F P
s
P
p
.002 w
.69416 .44865 m .68446 .40513 L .68699 .38206 L p
1 g
F P
s
P
p
.002 w
.33926 .49441 m .34876 .5438 L .33201 .52927 L p
1 g
F P
s
P
p
.002 w
.33201 .52927 m .32169 .47742 L .33926 .49441 L p
1 g
F P
s
P
p
.002 w
.52315 .61119 m .55379 .60898 L .54774 .61915 L p
1 g
F P
s
P
p
.002 w
.54774 .61915 m .50887 .62205 L .52315 .61119 L p
1 g
F P
s
P
p
.002 w
.58563 .25634 m .52524 .24556 L .51439 .23649 L p
1 g
F P
s
P
p
.002 w
.4517 .24554 m .51439 .23649 L .52524 .24556 L p
1 g
F P
s
P
p
.002 w
.52524 .24556 m .58563 .25634 L .59708 .27115 L p
1 g
F P
s
P
p
.002 w
.61149 .58109 m .633 .55814 L .64794 .55487 L p
1 g
F P
s
P
p
.002 w
.66528 .52154 m .64794 .55487 L .633 .55814 L p
1 g
F P
s
P
p
.002 w
.44479 .59575 m .47333 .61412 L .45282 .61787 L p
1 g
F P
s
P
p
.002 w
.45282 .61787 m .41874 .59625 L .44479 .59575 L p
1 g
F P
s
P
p
.002 w
.65794 .34255 m .68699 .38206 L .68446 .40513 L p
1 g
F P
s
P
p
.002 w
.68699 .38206 m .65794 .34255 L .65387 .31939 L p
1 g
F P
s
P
p
.002 w
.39729 .28449 m .34676 .32972 L .34418 .31666 L p
1 g
F P
s
P
p
.002 w
.34418 .31666 m .39232 .27347 L .39729 .28449 L p
1 g
F P
s
P
p
.002 w
.33299 .42068 m .32169 .47742 L .30977 .45963 L p
1 g
F P
s
P
p
.002 w
.30977 .45963 m .32093 .40188 L .33299 .42068 L p
1 g
F P
s
P
p
.002 w
.39667 .56383 m .41874 .59625 L .39579 .59199 L p
1 g
F P
s
P
p
.002 w
.39579 .59199 m .37048 .5555 L .39667 .56383 L p
1 g
F P
s
P
p
.002 w
.49531 .60484 m .52315 .61119 L .50887 .62205 L p
1 g
F P
s
P
p
.002 w
.50887 .62205 m .47333 .61412 L .49531 .60484 L p
1 g
F P
s
P
p
.002 w
.35398 .34628 m .32093 .40188 L .31442 .38455 L p
1 g
F P
s
P
p
.002 w
.31442 .38455 m .34676 .32972 L .35398 .34628 L p
1 g
F P
s
P
p
.002 w
.52524 .24556 m .45958 .25516 L .4517 .24554 L p
1 g
F P
s
P
p
.002 w
.39232 .27347 m .4517 .24554 L .45958 .25516 L p
1 g
F P
s
P
p
.002 w
.45958 .25516 m .39729 .28449 L .39232 .27347 L p
1 g
F P
s
P
p
.002 w
.60609 .29119 m .65387 .31939 L .65794 .34255 L p
1 g
F P
s
P
p
.002 w
.65387 .31939 m .60609 .29119 L .59708 .27115 L p
1 g
F P
s
P
p
.002 w
.66528 .52154 m .67063 .48705 L .68525 .46808 L p
1 g
F P
s
P
p
.002 w
.67642 .42967 m .68525 .46808 L .67063 .48705 L p
1 g
F P
s
P
p
.002 w
.68525 .46808 m .67642 .42967 L .68446 .40513 L p
1 g
F P
s
P
p
.002 w
.36217 .51 m .37048 .5555 L .34876 .5438 L p
1 g
F P
s
P
p
.002 w
.34876 .5438 m .33926 .49441 L .36217 .51 L p
1 g
F P
s
P
p
.002 w
.633 .55814 m .64653 .5319 L .66528 .52154 L p
1 g
F P
s
P
p
.002 w
.67063 .48705 m .66528 .52154 L .64653 .5319 L p
1 g
F P
s
P
p
.002 w
.5585 .59312 m .57967 .58592 L .58421 .59859 L p
1 g
F P
s
P
p
.002 w
.58421 .59859 m .55379 .60898 L .5585 .59312 L p
1 g
F P
s
P
p
.002 w
.61149 .58109 m .58421 .59859 L .57967 .58592 L p
1 g
F P
s
P
p
.004 w
.58903 .59299 m
.60038 .6137 L
s
P
p
.002 w
.57967 .58592 m .59865 .57374 L .61149 .58109 L p
1 g
F P
s
P
p
.002 w
.633 .55814 m .61149 .58109 L .59865 .57374 L p
1 g
F P
s
P
p
.002 w
.59708 .27115 m .53577 .26044 L .52524 .24556 L p
1 g
F P
s
P
p
.002 w
.45958 .25516 m .52524 .24556 L .53577 .26044 L p
1 g
F P
s
P
p
.002 w
.53577 .26044 m .59708 .27115 L .60609 .29119 L p
1 g
F P
s
P
p
.002 w
.53726 .59458 m .5585 .59312 L .55379 .60898 L p
1 g
F P
s
P
p
.002 w
.55379 .60898 m .52315 .61119 L .53726 .59458 L p
1 g
F P
s
P
p
.002 w
.65747 .36903 m .68446 .40513 L .67642 .42967 L p
1 g
F P
s
P
p
.002 w
.68446 .40513 m .65747 .36903 L .65794 .34255 L p
1 g
F P
s
P
p
.002 w
.47321 .5903 m .49531 .60484 L .47333 .61412 L p
1 g
F P
s
P
p
.002 w
.47333 .61412 m .44479 .59575 L .47321 .5903 L p
1 g
F P
s
P
p
.002 w
.42662 .56837 m .44479 .59575 L .41874 .59625 L p
1 g
F P
s
P
p
.002 w
.41874 .59625 m .39667 .56383 L .42662 .56837 L p
1 g
F P
s
P
p
.002 w
.35047 .44037 m .33926 .49441 L .32169 .47742 L p
1 g
F P
s
P
p
.002 w
.32169 .47742 m .33299 .42068 L .35047 .44037 L p
1 g
F P
s
P
p
.002 w
.59865 .57374 m .61354 .55777 L .633 .55814 L p
1 g
F P
s
P
p
.002 w
.64653 .5319 m .633 .55814 L .61354 .55777 L p
1 g
F P
s
P
p
.002 w
.40552 .30031 m .35398 .34628 L .34676 .32972 L p
1 g
F P
s
P
p
.002 w
.34676 .32972 m .39729 .28449 L .40552 .30031 L p
1 g
F P
s
P
p
.002 w
.5181 .59006 m .53726 .59458 L .52315 .61119 L p
1 g
F P
s
P
p
.002 w
.52315 .61119 m .49531 .60484 L .5181 .59006 L p
1 g
F P
s
P
p
.002 w
.36586 .36597 m .33299 .42068 L .32093 .40188 L p
1 g
F P
s
P
p
.002 w
.32093 .40188 m .35398 .34628 L .36586 .36597 L p
1 g
F P
s
P
p
.002 w
.61222 .31604 m .65794 .34255 L .65747 .36903 L p
1 g
F P
s
P
p
.002 w
.65794 .34255 m .61222 .31604 L .60609 .29119 L p
1 g
F P
s
P
p
.002 w
.38981 .52356 m .39667 .56383 L .37048 .5555 L p
1 g
F P
s
P
p
.004 w
.39054 .52785 m
.5 .43051 L
s
P
p
.002 w
.37048 .5555 m .36217 .51 L .38981 .52356 L p
1 g
F P
s
P
p
.004 w
.36959 .54648 m
.37354 .54296 L
s
P
p
.004 w
.37354 .54296 m
.37453 .54208 L
s
P
p
.004 w
.35337 .56091 m
.36401 .55145 L
s
P
p
.004 w
.36401 .55145 m
.36959 .54648 L
s
P
p
.002 w
.53577 .26044 m .46898 .27039 L .45958 .25516 L p
1 g
F P
s
P
p
.002 w
.39729 .28449 m .45958 .25516 L .46898 .27039 L p
1 g
F P
s
P
p
.002 w
.64653 .5319 m .65051 .50493 L .67063 .48705 L p
1 g
F P
s
P
p
.002 w
.66292 .45491 m .67063 .48705 L .65051 .50493 L p
1 g
F P
s
P
p
.002 w
.67063 .48705 m .66292 .45491 L .67642 .42967 L p
1 g
F P
s
P
p
.002 w
.46898 .27039 m .40552 .30031 L .39729 .28449 L p
1 g
F P
s
P
p
.002 w
.61354 .55777 m .62279 .53958 L .64653 .5319 L p
1 g
F P
s
P
p
.002 w
.65051 .50493 m .64653 .5319 L .62279 .53958 L p
1 g
F P
s
P
p
.002 w
.65225 .39806 m .67642 .42967 L .66292 .45491 L p
1 g
F P
s
P
p
.002 w
.67642 .42967 m .65225 .39806 L .65747 .36903 L p
1 g
F P
s
P
p
.002 w
.54562 .28096 m .60609 .29119 L .61222 .31604 L p
1 g
F P
s
P
p
.002 w
.60609 .29119 m .54562 .28096 L .53577 .26044 L p
1 g
F P
s
P
p
.002 w
.56163 .57179 m .57255 .5681 L .57967 .58592 L p
1 g
F P
s
P
p
.002 w
.57967 .58592 m .5585 .59312 L .56163 .57179 L p
1 g
F P
s
P
p
.002 w
.59865 .57374 m .57967 .58592 L .57255 .5681 L p
1 g
F P
s
P
p
.002 w
.5181 .59006 m .49531 .60484 L p
.50265 .58126 L 1 g
F P
s
P
p
.002 w
.50512 .5813 m .5181 .59006 L p
.50265 .58126 L 1 g
F P
s
P
p
.51079 .57862 m .49822 .58113 L .5054 .58128 L 1 g
F
P
p
.002 w
.51095 .58082 m .51079 .57862 L p
.5054 .58128 L 1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.47321 .5903 m .48168 .57996 L .48907 .58049 L 1 g
F
P
p
.002 w
.49935 .58121 m .49585 .58243 L p
.48907 .58049 L 1 g
F P
s
P
p
.002 w
.49585 .58243 m .47321 .5903 L p
.48907 .58049 L 1 g
F P
s
P
p
.002 w
.48907 .58049 m .48921 .57862 L p
.47991 .57786 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58049 L p
1 g
F P
s
P
p
.002 w
.48907 .58049 m .48889 .583 L p
.49822 .58113 L 1 g
F P
s
P
p
.51079 .57862 m .48907 .58049 L .49822 .58113 L 1 g
F
P
p
.002 w
.5181 .59006 m .50641 .58217 L p
.52435 .57972 L 1 g
F P
s
P
p
.002 w
.50641 .58217 m .50512 .5813 L p
.51095 .58082 L 1 g
F P
s
P
p
.50641 .58217 m .51095 .58082 L .52435 .57972 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58082 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58082 L .52143 .5777 L 1 g
F
P
p
.002 w
.53171 .57464 m .53128 .57265 L p
.52143 .5777 L 1 g
F P
s
P
p
.002 w
.50307 .57992 m .53336 .56482 L p
.52648 .5762 L 1 g
F P
s
P
p
.52435 .57972 m .51434 .57982 L .52648 .5762 L 1 g
F
P
p
.51434 .57982 m .50307 .57992 L .52648 .5762 L 1 g
F
P
p
.49822 .58113 m .49935 .58121 L .50512 .5813 L 1 g
F
P
p
.5054 .58128 m .50512 .5813 L .511 .58139 L 1 g
F
P
p
.49822 .58113 m .50512 .5813 L .5054 .58128 L 1 g
F
P
p
.002 w
.50512 .5813 m .50307 .57992 L p
.52435 .57972 L 1 g
F P
s
P
p
.002 w
.54094 .57009 m .5181 .59006 L p
.52522 .5783 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57464 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57464 L .53858 .57078 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54043 .56974 m .54094 .57009 L p
.52522 .5783 L 1 g
F P
s
P
p
.002 w
.54094 .57009 m .55071 .57249 L .53726 .59458 L p
1 g
F P
s
P
p
.002 w
.53726 .59458 m .5181 .59006 L .54094 .57009 L p
1 g
F P
s
P
p
.002 w
.55071 .57249 m .54094 .57009 L .54284 .56796 L p
1 g
F P
s
P
p
.002 w
.55786 .55674 m .55071 .57249 L p
.54459 .56896 L 1 g
F P
s
P
p
.54459 .56896 m .54284 .56796 L .54924 .56318 L 1 g
F
P
p
.54459 .56896 m .54924 .56318 L .55786 .55674 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54924 .56318 L p
1 g
F P
s
P
p
.56075 .54566 m .54924 .56318 L .55513 .55585 L 1 g
F
P
p
.002 w
.54924 .56318 m .54854 .56129 L p
.53704 .57225 L 1 g
F P
s
P
p
.53704 .57225 m .53683 .57245 L .54284 .56796 L 1 g
F
P
p
.53704 .57225 m .54284 .56796 L .54924 .56318 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56177 .54759 m .56075 .54566 L p
.55513 .55585 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56177 .54759 L p
1 g
F P
s
P
p
.002 w
.56298 .54545 m .56232 .5469 L p
.56183 .54743 L 1 g
F P
s
P
p
.002 w
.56233 .54618 m .56298 .54545 L p
.56183 .54743 L 1 g
F P
s
P
p
.002 w
.56232 .5469 m .55786 .55674 L p
.54924 .56318 L 1 g
F P
s
P
p
.56654 .52734 m .56177 .54759 L .56233 .54618 L 1 g
F
P
p
.56654 .52734 m .56233 .54618 L .56252 .54568 L 1 g
F
P
p
.002 w
.56255 .5456 m .56298 .54545 L .56249 .54578 L p
1 g
F P
s
P
p
.56256 .54559 m .56252 .54568 L .56255 .5456 L 1 g
F
P
p
.56654 .52734 m .56252 .54568 L .56256 .54559 L 1 g
F
P
p
.56654 .52734 m .56255 .5456 L .56258 .54552 L 1 g
F
P
p
.56654 .52734 m .56258 .54554 L .5626 .54546 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.52883 .55721 m .52788 .54805 L .56259 .54548 L p
1 g
F P
s
P
p
.002 w
.56259 .54548 m .56298 .54545 L .56255 .5456 L p
1 g
F P
s
P
p
.002 w
.56255 .5456 m .52883 .55721 L p
.56259 .54548 L 1 g
F P
s
P
p
.56654 .52734 m .5626 .54549 L .56263 .54539 L 1 g
F
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52788 .54805 m .53066 .53834 L .56263 .54538 L p
1 g
F P
s
P
p
.002 w
.56263 .54538 m .56298 .54545 L .56259 .54548 L p
1 g
F P
s
P
p
.002 w
.56259 .54548 m .52788 .54805 L p
.56263 .54538 L 1 g
F P
s
P
p
.56258 .54552 m .56255 .5456 L .56258 .54554 L 1 g
F
P
p
.5626 .54546 m .56258 .54554 L .5626 .54549 L 1 g
F
P
p
.56654 .52734 m .56262 .54544 L .56265 .54533 L 1 g
F
P
p
.56654 .52734 m .56264 .54539 L .56267 .54527 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.53066 .53834 m .5369 .52916 L .56267 .54526 L p
1 g
F P
s
P
p
.002 w
.56267 .54526 m .56298 .54545 L .56263 .54538 L p
1 g
F P
s
P
p
.002 w
.56263 .54538 m .53066 .53834 L p
.56267 .54526 L 1 g
F P
s
P
p
.56654 .52734 m .56266 .54534 L .56427 .53975 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.5369 .52916 m .54593 .52154 L .56272 .54509 L p
1 g
F P
s
P
p
.002 w
.56272 .54509 m .56298 .54545 L .56267 .54526 L p
1 g
F P
s
P
p
.002 w
.56267 .54526 m .5369 .52916 L p
.56272 .54509 L 1 g
F P
s
P
p
.56263 .54539 m .5626 .54549 L .56262 .54544 L 1 g
F
P
p
.56265 .54533 m .56262 .54544 L .56264 .54539 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54593 .52154 m .55673 .51635 L .56283 .54473 L p
1 g
F P
s
P
p
.002 w
.56283 .54473 m .56298 .54545 L .56272 .54509 L p
1 g
F P
s
P
p
.002 w
.56272 .54509 m .54593 .52154 L p
.56283 .54473 L 1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.5681 .51417 m .57158 .51452 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .56746 .52846 L 1 g
F
P
p
.002 w
.56706 .52053 m .5681 .51417 L p
.56747 .5287 L 1 g
F P
s
P
p
.57158 .51452 m .56779 .53484 L .56747 .5287 L 1 g
F
P
p
.56706 .52066 m .56749 .52872 L .56706 .52067 L 1 g
F
P
p
.56515 .50826 m .56746 .52846 L .56706 .52066 L 1 g
F
P
p
.56746 .52846 m .56749 .52872 L .56706 .52066 L 1 g
F
P
p
.002 w
.57158 .51452 m .57874 .51523 L p
.56779 .53484 L 1 g
F P
s
P
p
.56747 .5287 m .56779 .53484 L .56345 .54261 L 1 g
F
P
p
.002 w
.57874 .51523 m .56298 .54545 L .56345 .54261 L p
1 g
F P
s
P
p
.002 w
.57255 .5681 m .56163 .57179 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.58235 .5618 m .57255 .5681 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.58999 .55355 m .58235 .5618 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.56163 .57179 m .55192 .57241 L p
.56246 .54674 L 1 g
F P
s
P
p
.002 w
.56295 .54612 m .56163 .57179 L p
.56246 .54674 L 1 g
F P
s
P
p
.002 w
.55192 .57241 m .55071 .57249 L .56013 .55173 L p
1 g
F P
s
P
p
.002 w
.56013 .55173 m .56298 .54545 L p
.55192 .57241 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56177 .54759 L p
1 g
F P
s
P
p
.002 w
.56177 .54759 m .56177 .54759 L p
.56174 .54763 L 1 g
F P
s
P
p
.56174 .54763 m .54998 .56518 L .56177 .54759 L 1 g
F
P
p
.002 w
.56298 .54545 m .56295 .54612 L p
.56246 .54674 L 1 g
F P
s
P
p
.002 w
.56345 .54261 m .56298 .54545 L .56283 .54473 L p
1 g
F P
s
P
p
.002 w
.56249 .54578 m .56298 .54545 L .56233 .54618 L p
1 g
F P
s
P
p
.54924 .56318 m .54284 .56796 L .56183 .54743 L 1 g
F
P
p
.56177 .54759 m .56183 .54743 L .56232 .5469 L 1 g
F
P
p
.54924 .56318 m .56183 .54743 L .56177 .54759 L 1 g
F
P
p
.002 w
.56177 .54759 m .56177 .54759 L p
.56376 .54256 L 1 g
F P
s
P
p
.002 w
.59466 .5442 m .58999 .55355 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.59585 .53472 m .59466 .5442 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.59338 .52614 m .59585 .53472 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.58748 .51938 m .59338 .52614 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.57874 .51523 m .58748 .51938 L .56298 .54545 L closepath p
1 g
F P
s
P
p
.002 w
.56177 .54759 m .56257 .5491 L p
.56375 .5426 L 1 g
F P
s
P
p
.56376 .54256 m .56177 .54759 L .56375 .5426 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56673 .51443 m .5681 .51417 L .56706 .52053 L p
1 g
F P
s
P
p
.002 w
.5681 .51417 m .56673 .51443 L p
.56641 .51156 L 1 g
F P
s
P
p
.002 w
.56618 .50949 m .56515 .50826 L p
.56838 .52918 L 1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56618 .50949 L p
1 g
F P
s
P
p
.55661 .4905 m .56618 .50949 L .56179 .50042 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55338 .48304 m .57119 .47972 L .56913 .50267 L p
1 g
F P
s
P
p
.002 w
.56913 .50267 m .56815 .51356 L p
.5574 .49135 L 1 g
F P
s
P
p
.55338 .48304 m .56913 .50267 L .5574 .49135 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5574 .49135 L p
1 g
F P
s
P
p
.54174 .47608 m .5574 .49135 L .5516 .48573 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54858 .48393 m .54955 .48375 L p
.5681 .51417 L 1 g
F P
s
P
p
.54174 .47608 m .5516 .48573 L .54955 .48375 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.51986 .46679 m .54074 .47596 L .54858 .48393 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46713 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46713 L .51267 .46584 L 1 g
F
P
p
.51207 .46214 m .52242 .46713 L .51986 .46679 L 1 g
F
P
p
.52242 .46713 m .54074 .47596 L .51986 .46679 L 1 g
F
P
p
.002 w
.50705 .46454 m .51207 .46214 L p
.51986 .46679 L 1 g
F P
s
P
p
.50869 .46531 m .51986 .46679 L .54858 .48393 L 1 g
F
P
p
.5 .4634 m .51267 .46584 L .50746 .46514 L 1 g
F
P
p
.002 w
.48075 .48707 m .50652 .465 L p
.52706 .49425 L 1 g
F P
s
P
p
.002 w
.50746 .46514 m .52706 .49425 L p
.50652 .465 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48075 .48707 m .46491 .47329 L p
.5031 .46442 L 1 g
F P
s
P
p
.47764 .46704 m .5031 .46442 L .46491 .47329 L 1 g
F
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48646 .4658 L 1 g
F P
s
P
p
.4975 .46423 m .5031 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .48646 .4658 L 1 g
F
P
p
.5 .4634 m .50746 .46514 L .50652 .465 L 1 g
F
P
p
.002 w
.5 .46388 m .5 .4634 L p
.50652 .465 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48668 .43356 m .50705 .46454 L p
.5031 .46442 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.45283 .46279 m .45962 .45692 L p
.5031 .46442 L 1 g
F P
s
P
p
.002 w
.45962 .45692 m .48668 .43356 L p
.5031 .46442 L 1 g
F P
s
P
p
.002 w
.50652 .465 m .48075 .48707 L p
.5031 .46442 L 1 g
F P
s
P
p
.002 w
.5 .46403 m .5 .46388 L p
.50652 .465 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.48646 .4658 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47736 .4675 L p
1 g
F P
s
P
p
.002 w
.47736 .4675 m .47718 .46778 L p
.46972 .47105 L 1 g
F P
s
P
p
.45826 .47608 m .47736 .4675 L .46972 .47105 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.43025 .49792 m .44531 .48601 L .44275 .49118 L 1 g
F
P
p
.43738 .49639 m .44275 .49118 L .4405 .49572 L 1 g
F
P
p
.43025 .49792 m .44275 .49118 L .43738 .49639 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44275 .49118 L p
1 g
F P
s
P
p
.43485 .50826 m .44275 .49118 L .43947 .49779 L 1 g
F
P
p
.002 w
.4376 .50156 m .43025 .49792 L p
.4405 .49572 L 1 g
F P
s
P
p
.43485 .50826 m .44207 .4919 L .43911 .49829 L 1 g
F
P
p
.002 w
.42135 .53455 m .43025 .49792 L .43471 .50013 L p
1 g
F P
s
P
p
.002 w
.43471 .50013 m .4376 .50156 L p
.43411 .50865 L 1 g
F P
s
P
p
.42135 .53455 m .43471 .50013 L .43411 .50865 L 1 g
F
P
p
.002 w
.43272 .52841 m .43346 .52734 L p
.43324 .52103 L 1 g
F P
s
P
p
.43485 .50826 m .43843 .49989 L .4376 .50156 L 1 g
F
P
p
.42135 .53455 m .43411 .50865 L .42262 .53393 L 1 g
F
P
p
.43411 .50865 m .4376 .50156 L .43407 .50919 L 1 g
F
P
p
.43411 .50865 m .43407 .50919 L .42262 .53393 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43407 .50919 L p
1 g
F P
s
P
p
.43346 .52734 m .43407 .50919 L .43324 .52103 L 1 g
F
P
p
.002 w
.43407 .50919 m .43485 .50826 L p
.4376 .50156 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43272 .52841 L p
1 g
F P
s
P
p
.43925 .54566 m .43272 .52841 L .4352 .53765 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4376 .50156 m .46301 .51415 L p
.43286 .52892 L 1 g
F P
s
P
p
.42262 .53393 m .42995 .51809 L .43286 .52892 L 1 g
F
P
p
.42995 .51809 m .4376 .50156 L .43286 .52892 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.43925 .54566 m .4352 .53765 L .43523 .53776 L 1 g
F
P
p
.42662 .56837 m .43428 .54114 L .44167 .55499 L 1 g
F
P
p
.43428 .54114 m .43523 .53776 L .43862 .54684 L 1 g
F
P
p
.43428 .54114 m .43862 .54684 L .44167 .55499 L 1 g
F
P
p
.002 w
.43862 .54684 m .43925 .54566 L p
.43523 .53776 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43862 .54684 L p
1 g
F P
s
P
p
.45146 .56129 m .43862 .54684 L .44602 .55657 L 1 g
F
P
p
.002 w
.43523 .53776 m .45572 .5425 L p
.44355 .55332 L 1 g
F P
s
P
p
.44167 .55499 m .43862 .54684 L .44355 .55332 L 1 g
F
P
p
.43862 .54684 m .43523 .53776 L .44355 .55332 L 1 g
F
P
p
.002 w
.45086 .56292 m .45146 .56129 L p
.44602 .55657 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46872 .57265 m .4574 .56813 L .45826 .56881 L 1 g
F
P
p
.002 w
.47321 .5903 m .44479 .59575 L p
.4581 .5712 L 1 g
F P
s
P
p
.4581 .5712 m .4591 .56935 L .46116 .5724 L 1 g
F
P
p
.4581 .5712 m .46116 .5724 L .47321 .5903 L 1 g
F
P
p
.002 w
.46016 .57003 m .46187 .57268 L p
.4591 .56935 L 1 g
F P
s
P
p
.002 w
.46187 .57268 m .47321 .5903 L p
.46116 .5724 L 1 g
F P
s
P
p
.4591 .56935 m .46187 .57268 L .46116 .5724 L 1 g
F
P
p
.002 w
.47321 .5903 m .46187 .57268 L p
.48058 .5813 L 1 g
F P
s
P
p
.002 w
.46187 .57268 m .46016 .57003 L p
.46831 .57453 L 1 g
F P
s
P
p
.46187 .57268 m .46831 .57453 L .48058 .5813 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57453 L p
1 g
F P
s
P
p
.48921 .57862 m .46831 .57453 L .47991 .57786 L 1 g
F
P
p
.46872 .57265 m .45826 .56881 L .46016 .57003 L 1 g
F
P
p
.002 w
.46817 .57515 m .46831 .57453 L p
.46016 .57003 L 1 g
F P
s
P
p
.002 w
.46831 .57453 m .46872 .57265 L p
.46016 .57003 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45826 .56881 m .42662 .56837 L p
.44131 .55531 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45051 .56385 L p
1 g
F P
s
P
p
.002 w
.45051 .56385 m .45002 .56518 L p
.45685 .56791 L 1 g
F P
s
P
p
.46872 .57265 m .45051 .56385 L .45685 .56791 L 1 g
F
P
p
.002 w
.44479 .59575 m .42662 .56837 L .45826 .56881 L p
1 g
F P
s
P
p
.002 w
.45826 .56881 m .45939 .56883 L p
.4591 .56935 L 1 g
F P
s
P
p
.44479 .59575 m .45826 .56881 L .4591 .56935 L 1 g
F
P
p
.002 w
.45939 .56883 m .49387 .56509 L p
.48058 .5813 L 1 g
F P
s
P
p
.002 w
.46016 .57003 m .45939 .56883 L p
.48058 .5813 L 1 g
F P
s
P
p
.002 w
.46831 .57453 m .4678 .57686 L p
.47991 .57786 L 1 g
F P
s
P
p
.002 w
.46788 .57647 m .46817 .57515 L p
.46016 .57003 L 1 g
F P
s
P
p
.46016 .57003 m .45826 .56881 L .45894 .56936 L 1 g
F
P
p
.46016 .57003 m .45894 .56936 L .46788 .57647 L 1 g
F
P
p
.002 w
.4678 .57686 m .46687 .58109 L p
.48793 .58291 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .48602 .58216 L p
.48793 .58291 L 1 g
F P
s
P
p
.002 w
.48602 .58216 m .4678 .57686 L p
.48793 .58291 L 1 g
F P
s
P
p
.002 w
.49531 .60484 m .47321 .5903 L .49585 .58243 L p
1 g
F P
s
P
p
.002 w
.49585 .58243 m .50307 .57992 L p
.50191 .58365 L 1 g
F P
s
P
p
.49531 .60484 m .49585 .58243 L .50191 .58365 L 1 g
F
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48887 .58328 L p
1 g
F P
s
P
p
.002 w
.48887 .58328 m .48889 .583 L p
.48793 .58291 L 1 g
F P
s
P
p
.48793 .58291 m .46687 .58109 L .48887 .58328 L 1 g
F
P
p
.002 w
.45939 .56883 m .46016 .57003 L p
.4591 .56935 L 1 g
F P
s
P
p
.002 w
.45572 .5425 m .45939 .56883 L .45826 .56881 L p
1 g
F P
s
P
p
.44131 .55531 m .45572 .5425 L .45826 .56881 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46788 .57647 L p
1 g
F P
s
P
p
.4574 .56813 m .45002 .56518 L .46788 .57647 L 1 g
F
P
p
.002 w
.43862 .54684 m .43743 .5491 L p
.44602 .55657 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45086 .56292 L p
1 g
F P
s
P
p
.44602 .55657 m .43743 .5491 L .45086 .56292 L 1 g
F
P
p
.002 w
.43799 .54804 m .43862 .54684 L p
.43523 .53776 L 1 g
F P
s
P
p
.002 w
.42662 .56837 m .42135 .53455 L .43523 .53776 L p
1 g
F P
s
P
p
.002 w
.46301 .51415 m .45572 .5425 L .43523 .53776 L p
1 g
F P
s
P
p
.002 w
.43523 .53776 m .42135 .53455 L p
.43286 .52892 L 1 g
F P
s
P
p
.43286 .52892 m .46301 .51415 L .43523 .53776 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43799 .54804 L p
1 g
F P
s
P
p
.4352 .53765 m .43146 .53025 L .43799 .54804 L 1 g
F
P
p
.002 w
.43272 .52841 m .43146 .53025 L p
.4352 .53765 L 1 g
F P
s
P
p
.002 w
.43407 .50919 m .43287 .51061 L p
.43324 .52103 L 1 g
F P
s
P
p
.002 w
.43345 .50993 m .43407 .50919 L p
.4376 .50156 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43272 .52841 L p
1 g
F P
s
P
p
.43324 .52103 m .43287 .51061 L .43272 .52841 L 1 g
F
P
p
.002 w
.48075 .48707 m .46301 .51415 L .4376 .50156 L p
1 g
F P
s
P
p
.4405 .49572 m .48075 .48707 L .4376 .50156 L 1 g
F
P
p
.002 w
.44275 .49118 m .44207 .4919 L p
.43947 .49779 L 1 g
F P
s
P
p
.002 w
.44207 .4919 m .44166 .49233 L p
.43911 .49829 L 1 g
F P
s
P
p
.002 w
.44275 .49118 m .44339 .4905 L p
.44849 .48561 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.4405 .49572 m .44275 .49118 L .48075 .48707 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45777 .47662 L p
1 g
F P
s
P
p
.44339 .4905 m .45777 .47662 L .44849 .48561 L 1 g
F
P
p
.44275 .49118 m .44531 .48601 L .448 .48609 L 1 g
F
P
p
.44275 .49118 m .448 .48609 L .48075 .48707 L 1 g
F
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46491 .47329 m .48075 .48707 L p
.43804 .4858 L 1 g
F P
s
P
p
.002 w
.45777 .47662 m .45698 .47747 L p
.44849 .48561 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44275 .49118 L p
1 g
F P
s
P
p
.44849 .48561 m .45698 .47747 L .44275 .49118 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43345 .50993 L p
1 g
F P
s
P
p
.43843 .49989 m .44166 .49233 L .43345 .50993 L 1 g
F
P
p
.002 w
.43025 .49792 m .43804 .4858 L p
.44531 .48601 L 1 g
F P
s
P
p
.002 w
.45746 .47695 m .45826 .47608 L p
.46737 .47209 L 1 g
F P
s
P
p
.002 w
.43804 .4858 m .45283 .46279 L .46491 .47329 L p
1 g
F P
s
P
p
.45283 .46279 m .48423 .4638 L .47764 .46704 L 1 g
F
P
p
.002 w
.46491 .47329 m .46051 .46947 L p
.47764 .46704 L 1 g
F P
s
P
p
.002 w
.46051 .46947 m .45283 .46279 L p
.47764 .46704 L 1 g
F P
s
P
p
.48423 .4638 m .4975 .46423 L .47764 .46704 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48646 .4658 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45746 .47695 L p
1 g
F P
s
P
p
.46737 .47209 m .47718 .46778 L .45746 .47695 L 1 g
F
P
p
.002 w
.50705 .46454 m .50652 .465 L p
.5031 .46442 L 1 g
F P
s
P
p
.002 w
.5 .46416 m .5 .46403 L p
.50652 .465 L 1 g
F P
s
P
p
.50652 .465 m .50746 .46514 L .50693 .46507 L 1 g
F
P
p
.50652 .465 m .50693 .46507 L .5 .46416 L 1 g
F
P
p
.002 w
.50652 .465 m .50705 .46454 L .50746 .46514 L p
1 g
F P
s
P
p
.50705 .46454 m .51986 .46679 L .50869 .46531 L 1 g
F
P
p
.002 w
.54858 .48393 m .52706 .49425 L .50705 .46454 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46416 L p
1 g
F P
s
P
p
.51267 .46584 m .52282 .46778 L .5 .46416 L 1 g
F
P
p
.002 w
.52242 .46713 m .52282 .46778 L p
.51267 .46584 L 1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .53121 .47137 L 1 g
F
P
p
.002 w
.54815 .48239 m .54858 .48393 L p
.54074 .47596 L 1 g
F P
s
P
p
.52233 .45724 m .54233 .47673 L .54074 .47596 L 1 g
F
P
p
.54233 .47673 m .54815 .48239 L .54074 .47596 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52242 .46713 L p
1 g
F P
s
P
p
.002 w
.52242 .46713 m .52214 .46667 L p
.53121 .47137 L 1 g
F P
s
P
p
.53121 .47137 m .54302 .47747 L .52242 .46713 L 1 g
F
P
p
.002 w
.54233 .47673 m .54302 .47747 L p
.53121 .47137 L 1 g
F P
s
P
p
.002 w
.51207 .46214 m .52233 .45724 L p
.54074 .47596 L 1 g
F P
s
P
p
.002 w
.54245 .47685 m .54174 .47608 L p
.54955 .48375 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.52233 .45724 m .53879 .44937 L .54815 .48239 L p
1 g
F P
s
P
p
.002 w
.54275 .47718 m .54245 .47685 L p
.54815 .48239 L 1 g
F P
s
P
p
.002 w
.54955 .48375 m .54858 .48393 L .54815 .48239 L p
1 g
F P
s
P
p
.54815 .48239 m .54955 .48375 L .54911 .48333 L 1 g
F
P
p
.54815 .48239 m .54911 .48333 L .54275 .47718 L 1 g
F
P
p
.002 w
.57119 .47972 m .54955 .48375 L p
.53879 .44937 L 1 g
F P
s
P
p
.002 w
.54815 .48239 m .53879 .44937 L p
.54955 .48375 L 1 g
F P
s
P
p
.002 w
.54955 .48375 m .55338 .48304 L p
.55723 .49118 L 1 g
F P
s
P
p
.54955 .48375 m .55723 .49118 L .5681 .51417 L 1 g
F
P
p
.002 w
.56815 .51356 m .5681 .51417 L p
.55338 .48304 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54275 .47718 L p
1 g
F P
s
P
p
.5516 .48573 m .55834 .49233 L .54275 .47718 L 1 g
F
P
p
.002 w
.5574 .49135 m .55834 .49233 L p
.5516 .48573 L 1 g
F P
s
P
p
.002 w
.56618 .50949 m .56713 .51061 L p
.56179 .50042 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56618 .50949 L p
1 g
F P
s
P
p
.56838 .52918 m .56854 .53025 L .56618 .50949 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55673 .51635 m .54858 .48393 L p
.56641 .51156 L 1 g
F P
s
P
p
.002 w
.56673 .51443 m .55673 .51635 L p
.56641 .51156 L 1 g
F P
s
P
p
.002 w
.56345 .54261 m .56706 .52053 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56749 .52872 L p
.56746 .52846 L 1 g
F P
s
P
p
.002 w
.56749 .52872 m .56854 .53025 L p
.56706 .52067 L 1 g
F P
s
P
p
.002 w
.55673 .51635 m .56673 .51443 L p
.56345 .54261 L 1 g
F P
s
P
p
.002 w
.56706 .52053 m .56345 .54261 L p
.56673 .51443 L 1 g
F P
s
P
p
.002 w
.56283 .54473 m .55673 .51635 L p
.56345 .54261 L 1 g
F P
s
P
p
.56267 .54527 m .56264 .54539 L .56266 .54534 L 1 g
F
P
p
.56427 .53975 m .56266 .54534 L .56378 .54244 L 1 g
F
P
p
.002 w
.53336 .56482 m .52883 .55721 L .56255 .5456 L p
1 g
F P
s
P
p
.002 w
.56249 .54578 m .53336 .56482 L p
.56255 .5456 L 1 g
F P
s
P
p
.56378 .54244 m .56249 .54578 L .56376 .54256 L 1 g
F
P
p
.56249 .54578 m .56233 .54618 L .56243 .54593 L 1 g
F
P
p
.56249 .54578 m .56243 .54593 L .56376 .54256 L 1 g
F
P
p
.002 w
.53336 .56482 m .56249 .54578 L p
.54284 .56796 L 1 g
F P
s
P
p
.002 w
.56233 .54618 m .54284 .56796 L p
.56249 .54578 L 1 g
F P
s
P
p
.002 w
.54284 .56796 m .56233 .54618 L p
.56183 .54743 L 1 g
F P
s
P
p
.55513 .55585 m .54998 .56518 L .56177 .54759 L 1 g
F
P
p
.002 w
.54284 .56796 m .54094 .57009 L .54043 .56974 L p
1 g
F P
s
P
p
.002 w
.54043 .56974 m .53336 .56482 L p
.54284 .56796 L 1 g
F P
s
P
p
.002 w
.54924 .56318 m .54998 .56518 L p
.55513 .55585 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54924 .56318 L p
1 g
F P
s
P
p
.53683 .57245 m .5322 .57686 L .54924 .56318 L 1 g
F
P
p
.002 w
.53336 .56482 m .54043 .56974 L p
.52522 .5783 L 1 g
F P
s
P
p
.002 w
.53171 .57464 m .5322 .57686 L p
.53858 .57078 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57464 L p
1 g
F P
s
P
p
.52143 .5777 m .51111 .583 L .53171 .57464 L 1 g
F
P
p
.002 w
.51095 .58082 m .51111 .583 L p
.52143 .5777 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.48168 .57996 m .49387 .56509 L .49935 .58121 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58049 L p
1 g
F P
s
P
p
.47991 .57786 m .4678 .57686 L .48907 .58049 L 1 g
F
P
p
.002 w
.511 .58139 m .51095 .58082 L p
.5054 .58128 L 1 g
F P
s
P
p
.49822 .58113 m .49793 .58119 L .49935 .58121 L 1 g
F
P
p
.002 w
.49387 .56509 m .50307 .57992 L .49935 .58121 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58139 L p
1 g
F P
s
P
p
.49793 .58119 m .48889 .583 L .511 .58139 L 1 g
F
P
p
.002 w
.50307 .57992 m .50512 .5813 L p
.50265 .58126 L 1 g
F P
s
P
p
.002 w
.57255 .5681 m .58235 .5618 L .59865 .57374 L p
1 g
F P
s
P
p
.002 w
.61354 .55777 m .59865 .57374 L .58235 .5618 L p
1 g
F P
s
P
p
.002 w
.46898 .27039 m .53577 .26044 L .54562 .28096 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51552 .45883 L
s
P
p
.004 w
.53329 .49126 m
.54901 .51996 L
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.37298 .4603 m .36217 .51 L .33926 .49441 L p
1 g
F P
s
P
p
.002 w
.33926 .49441 m .35047 .44037 L .37298 .4603 L p
1 g
F P
s
P
p
.002 w
.55071 .57249 m .56163 .57179 L .5585 .59312 L p
1 g
F P
s
P
p
.002 w
.5585 .59312 m .53726 .59458 L .55071 .57249 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.58235 .5618 m .58999 .55355 L .61354 .55777 L p
1 g
F P
s
P
p
.002 w
.62279 .53958 m .61354 .55777 L .58999 .55355 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.61513 .34504 m .65747 .36903 L .65225 .39806 L p
1 g
F P
s
P
p
.002 w
.65747 .36903 m .61513 .34504 L .61222 .31604 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.42135 .53455 m .42662 .56837 L .39667 .56383 L p
1 g
F P
s
P
p
.002 w
.39667 .56383 m .38981 .52356 L .42135 .53455 L p
1 g
F P
s
P
p
.002 w
.41693 .32065 m .36586 .36597 L .35398 .34628 L p
1 g
F P
s
P
p
.002 w
.35398 .34628 m .40552 .30031 L .41693 .32065 L p
1 g
F P
s
P
p
.002 w
.62279 .53958 m .62534 .52103 L .65051 .50493 L p
1 g
F P
s
P
p
.002 w
.6442 .48 m .65051 .50493 L .62534 .52103 L p
1 g
F P
s
P
p
.002 w
.65051 .50493 m .6442 .48 L .66292 .45491 L p
1 g
F P
s
P
p
.002 w
.38222 .38826 m .35047 .44037 L .33299 .42068 L p
1 g
F P
s
P
p
.002 w
.33299 .42068 m .36586 .36597 L .38222 .38826 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.64231 .42871 m .66292 .45491 L .6442 .48 L p
1 g
F P
s
P
p
.002 w
.66292 .45491 m .64231 .42871 L .65225 .39806 L p
1 g
F P
s
P
p
.002 w
.58999 .55355 m .59466 .5442 L .62279 .53958 L p
1 g
F P
s
P
p
.002 w
.62534 .52103 m .62279 .53958 L .59466 .5442 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.54562 .28096 m .47967 .29102 L .46898 .27039 L p
1 g
F P
s
P
p
.002 w
.40552 .30031 m .46898 .27039 L .47967 .29102 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.47967 .29102 m .41693 .32065 L .40552 .30031 L p
1 g
F P
s
P
p
.002 w
.55438 .30668 m .61222 .31604 L .61513 .34504 L p
1 g
F P
s
P
p
.002 w
.61222 .31604 m .55438 .30668 L .54562 .28096 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.39987 .47973 m .38981 .52356 L .36217 .51 L p
1 g
F P
s
P
p
.002 w
.36217 .51 m .37298 .4603 L .39987 .47973 L p
1 g
F P
s
P
p
.002 w
.47967 .29102 m .54562 .28096 L .55438 .30668 L p
1 g
F P
s
P
p
.002 w
.61458 .37732 m .65225 .39806 L .64231 .42871 L p
1 g
F P
s
P
p
.002 w
.65225 .39806 m .61458 .37732 L .61513 .34504 L p
1 g
F P
s
P
p
.002 w
.59466 .5442 m .59585 .53472 L .62534 .52103 L p
1 g
F P
s
P
p
.002 w
.62077 .50404 m .62534 .52103 L .59585 .53472 L p
1 g
F P
s
P
p
.002 w
.62534 .52103 m .62077 .50404 L .6442 .48 L p
1 g
F P
s
P
p
.002 w
.62787 .45991 m .6442 .48 L .62077 .50404 L p
1 g
F P
s
P
p
.002 w
.6442 .48 m .62787 .45991 L .64231 .42871 L p
1 g
F P
s
P
p
.002 w
.40263 .41241 m .37298 .4603 L .35047 .44037 L p
1 g
F P
s
P
p
.002 w
.35047 .44037 m .38222 .38826 L .40263 .41241 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.52883 .55721 m .53336 .56482 L .50307 .57992 L p
1 g
F P
s
P
p
.002 w
.50307 .57992 m .49387 .56509 L .52883 .55721 L p
1 g
F P
s
P
p
.002 w
.43124 .34501 m .38222 .38826 L .36586 .36597 L p
1 g
F P
s
P
p
.002 w
.36586 .36597 m .41693 .32065 L .43124 .34501 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.43025 .49792 m .42135 .53455 L .38981 .52356 L p
1 g
F P
s
P
p
.002 w
.38981 .52356 m .39987 .47973 L .43025 .49792 L p
1 g
F P
s
P
p
.002 w
.49167 .54706 m .49387 .56509 L .45939 .56883 L p
1 g
F P
s
P
p
.002 w
.45939 .56883 m .45572 .5425 L .49167 .54706 L p
1 g
F P
s
P
p
.002 w
.5617 .33687 m .61513 .34504 L .61458 .37732 L p
1 g
F P
s
P
p
.002 w
.61513 .34504 m .5617 .33687 L .55438 .30668 L p
1 g
F P
s
P
p
.002 w
.6105 .41176 m .64231 .42871 L .62787 .45991 L p
1 g
F P
s
P
p
.002 w
.64231 .42871 m .6105 .41176 L .61458 .37732 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.59585 .53472 m .59338 .52614 L .62077 .50404 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60938 .49051 m .62077 .50404 L .59338 .52614 L p
1 g
F P
s
P
p
.002 w
.62077 .50404 m .60938 .49051 L .62787 .45991 L p
1 g
F P
s
P
p
.002 w
.55438 .30668 m .4913 .31658 L .47967 .29102 L p
1 g
F P
s
P
p
.002 w
.41693 .32065 m .47967 .29102 L .4913 .31658 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.4913 .31658 m .43124 .34501 L .41693 .32065 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.4913 .31658 m .55438 .30668 L .5617 .33687 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.52788 .54805 m .52883 .55721 L .49387 .56509 L p
1 g
F P
s
P
p
.002 w
.49387 .56509 m .49167 .54706 L .52788 .54805 L p
1 g
F P
s
P
p
.002 w
.59338 .52614 m .58748 .51938 L .60938 .49051 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60297 .44711 m .62787 .45991 L .60938 .49051 L p
1 g
F P
s
P
p
.002 w
.62787 .45991 m .60297 .44711 L .6105 .41176 L p
1 g
F P
s
P
p
.002 w
.42645 .43757 m .39987 .47973 L .37298 .4603 L p
1 g
F P
s
P
p
.002 w
.37298 .4603 m .40263 .41241 L .42645 .43757 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.56725 .37055 m .61458 .37732 L .6105 .41176 L p
1 g
F P
s
P
p
.002 w
.61458 .37732 m .56725 .37055 L .5617 .33687 L p
1 g
F P
s
P
p
.002 w
.44804 .37262 m .40263 .41241 L .38222 .38826 L p
1 g
F P
s
P
p
.002 w
.38222 .38826 m .43124 .34501 L .44804 .37262 L p
1 g
F P
s
P
p
.002 w
.59225 .48204 m .60938 .49051 L .58748 .51938 L p
1 g
F P
s
P
p
.002 w
.60938 .49051 m .59225 .48204 L .60297 .44711 L p
1 g
F P
s
P
p
.002 w
.58748 .51938 m .57874 .51523 L .59225 .48204 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53066 .53834 m .52788 .54805 L .49167 .54706 L p
1 g
F P
s
P
p
.002 w
.49691 .5278 m .49167 .54706 L .45572 .5425 L p
1 g
F P
s
P
p
.002 w
.45572 .5425 m .46301 .51415 L .49691 .5278 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.49167 .54706 m .49691 .5278 L .53066 .53834 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57874 .51523 m .5681 .51417 L .57119 .47972 L p
1 g
F P
s
P
p
.002 w
.57119 .47972 m .59225 .48204 L .57874 .51523 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.5617 .33687 m .5035 .34631 L .4913 .31658 L p
1 g
F P
s
P
p
.002 w
.43124 .34501 m .4913 .31658 L .5035 .34631 L p
1 g
F P
s
P
p
.002 w
.5035 .34631 m .5617 .33687 L .56725 .37055 L p
1 g
F P
s
P
p
.002 w
.5369 .52916 m .53066 .53834 L .49691 .5278 L p
1 g
F P
s
P
p
.002 w
.57077 .4065 m .6105 .41176 L .60297 .44711 L p
1 g
F P
s
P
p
.002 w
.6105 .41176 m .57077 .4065 L .56725 .37055 L p
1 g
F P
s
P
p
.002 w
.45283 .46279 m .43025 .49792 L .39987 .47973 L p
1 g
F P
s
P
p
.002 w
.39987 .47973 m .42645 .43757 L .45283 .46279 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.5035 .34631 m .44804 .37262 L .43124 .34501 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59225 .48204 m .57119 .47972 L .5721 .44337 L p
1 g
F P
s
P
p
.002 w
.5721 .44337 m .60297 .44711 L .59225 .48204 L p
1 g
F P
s
P
p
.002 w
.54593 .52154 m .5369 .52916 L .50915 .50947 L p
1 g
F P
s
P
p
.002 w
.49691 .5278 m .50915 .50947 L .5369 .52916 L p
1 g
F P
s
P
p
.002 w
.60297 .44711 m .5721 .44337 L .57077 .4065 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55673 .51635 m .54593 .52154 L .52706 .49425 L p
1 g
F P
s
P
p
.002 w
.52706 .49425 m .54858 .48393 L .55673 .51635 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.50915 .50947 m .52706 .49425 L .54593 .52154 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46675 .40251 m .42645 .43757 L .40263 .41241 L p
1 g
F P
s
P
p
.002 w
.40263 .41241 m .44804 .37262 L .46675 .40251 L p
1 g
F P
s
P
p
.002 w
.50915 .50947 m .49691 .5278 L .46301 .51415 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46301 .51415 m .48075 .48707 L .50915 .50947 L p
1 g
F P
s
P
p
.002 w
.5158 .37919 m .56725 .37055 L .57077 .4065 L p
1 g
F P
s
P
p
.002 w
.56725 .37055 m .5158 .37919 L .5035 .34631 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53879 .44937 m .5721 .44337 L .57119 .47972 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.44804 .37262 m .5035 .34631 L .5158 .37919 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52706 .49425 m .50915 .50947 L .48075 .48707 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.5158 .37919 m .46675 .40251 L .44804 .37262 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52772 .41399 m .57077 .4065 L .5721 .44337 L p
1 g
F P
s
P
p
.002 w
.57077 .4065 m .52772 .41399 L .5158 .37919 L p
1 g
F P
s
P
p
.002 w
.48668 .43356 m .45283 .46279 L .42645 .43757 L p
1 g
F P
s
P
p
.002 w
.42645 .43757 m .46675 .40251 L .48668 .43356 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5721 .44337 m .53879 .44937 L .52772 .41399 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46675 .40251 m .5158 .37919 L .52772 .41399 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52772 .41399 m .48668 .43356 L .46675 .40251 L p
1 g
F P
s
P
p
.002 w
.53879 .44937 m .50705 .46454 L .48668 .43356 L p
1 g
F P
s
P
p
.002 w
.48668 .43356 m .52772 .41399 L .53879 .44937 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.58452 .58475 m
.58903 .59299 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .30102 .60746 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60038 .6137 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.260465)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.260465)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4588 .45247 m .5001 .44678 L .49278 .41916 L p
1 g
F P
s
P
p
.002 w
.49278 .41916 m .4583 .42382 L .4588 .45247 L p
1 g
F P
s
P
p
.002 w
.52516 .40613 m .49278 .41916 L .5001 .44678 L p
1 g
F P
s
P
p
.002 w
.4583 .42382 m .49278 .41916 L .48561 .39173 L p
1 g
F P
s
P
p
.002 w
.49278 .41916 m .52516 .40613 L .51076 .38157 L p
1 g
F P
s
P
p
.002 w
.51076 .38157 m .48561 .39173 L .49278 .41916 L p
1 g
F P
s
P
p
.002 w
.46029 .48072 m .50744 .4741 L .5001 .44678 L p
1 g
F P
s
P
p
.002 w
.5001 .44678 m .4588 .45247 L .46029 .48072 L p
1 g
F P
s
P
p
.002 w
.53893 .43123 m .5001 .44678 L .50744 .4741 L p
1 g
F P
s
P
p
.002 w
.5001 .44678 m .53893 .43123 L .52516 .40613 L p
1 g
F P
s
P
p
.002 w
.55241 .3859 m .52516 .40613 L .53893 .43123 L p
1 g
F P
s
P
p
.002 w
.52516 .40613 m .55241 .3859 L .53181 .36574 L p
1 g
F P
s
P
p
.002 w
.53181 .36574 m .51076 .38157 L .52516 .40613 L p
1 g
F P
s
P
p
.002 w
.50744 .4741 m .55181 .45642 L .53893 .43123 L p
1 g
F P
s
P
p
.002 w
.57175 .40716 m .53893 .43123 L .55181 .45642 L p
1 g
F P
s
P
p
.002 w
.53893 .43123 m .57175 .40716 L .55241 .3859 L p
1 g
F P
s
P
p
.002 w
.48561 .39173 m .45882 .39529 L .4583 .42382 L p
1 g
F P
s
P
p
.002 w
.45882 .39529 m .48561 .39173 L .47873 .365 L p
1 g
F P
s
P
p
.002 w
.48561 .39173 m .51076 .38157 L .49598 .358 L p
1 g
F P
s
P
p
.002 w
.49598 .358 m .47873 .365 L .48561 .39173 L p
1 g
F P
s
P
p
.002 w
.41877 .44767 m .4588 .45247 L .4583 .42382 L p
1 g
F P
s
P
p
.002 w
.4583 .42382 m .42496 .41959 L .41877 .44767 L p
1 g
F P
s
P
p
.002 w
.42496 .41959 m .4583 .42382 L .45882 .39529 L p
1 g
F P
s
P
p
.002 w
.46278 .50804 m .51468 .50062 L .50744 .4741 L p
1 g
F P
s
P
p
.002 w
.50744 .4741 m .46029 .48072 L .46278 .50804 L p
1 g
F P
s
P
p
.002 w
.55181 .45642 m .50744 .4741 L .51468 .50062 L p
1 g
F P
s
P
p
.002 w
.41453 .47554 m .46029 .48072 L .4588 .45247 L p
1 g
F P
s
P
p
.002 w
.4588 .45247 m .41877 .44767 L .41453 .47554 L p
1 g
F P
s
P
p
.002 w
.51076 .38157 m .53181 .36574 L .51034 .34707 L p
1 g
F P
s
P
p
.002 w
.51034 .34707 m .49598 .358 L .51076 .38157 L p
1 g
F P
s
P
p
.002 w
.45882 .39529 m .43297 .39183 L .42496 .41959 L p
1 g
F P
s
P
p
.002 w
.43297 .39183 m .45882 .39529 L .46034 .3674 L p
1 g
F P
s
P
p
.002 w
.47873 .365 m .46034 .3674 L .45882 .39529 L p
1 g
F P
s
P
p
.002 w
.51468 .50062 m .56356 .48123 L .55181 .45642 L p
1 g
F P
s
P
p
.002 w
.58946 .42915 m .55181 .45642 L .56356 .48123 L p
1 g
F P
s
P
p
.002 w
.55181 .45642 m .58946 .42915 L .57175 .40716 L p
1 g
F P
s
P
p
.002 w
.41235 .50267 m .46278 .50804 L .46029 .48072 L p
1 g
F P
s
P
p
.002 w
.46029 .48072 m .41453 .47554 L .41235 .50267 L p
1 g
F P
s
P
p
.002 w
.5718 .36027 m .55241 .3859 L .57175 .40716 L p
1 g
F P
s
P
p
.002 w
.55241 .3859 m .5718 .36027 L .54663 .34573 L p
1 g
F P
s
P
p
.002 w
.54663 .34573 m .53181 .36574 L .55241 .3859 L p
1 g
F P
s
P
p
.002 w
.46034 .3674 m .47873 .365 L .47226 .33947 L p
1 g
F P
s
P
p
.002 w
.47873 .365 m .49598 .358 L .48108 .33588 L p
1 g
F P
s
P
p
.002 w
.48108 .33588 m .47226 .33947 L .47873 .365 L p
1 g
F P
s
P
p
.002 w
.46623 .53391 m .52166 .52585 L .51468 .50062 L p
1 g
F P
s
P
p
.002 w
.51468 .50062 m .46278 .50804 L .46623 .53391 L p
1 g
F P
s
P
p
.002 w
.56356 .48123 m .51468 .50062 L .52166 .52585 L p
1 g
F P
s
P
p
.002 w
.53181 .36574 m .54663 .34573 L .52033 .3333 L p
1 g
F P
s
P
p
.002 w
.52033 .3333 m .51034 .34707 L .53181 .36574 L p
1 g
F P
s
P
p
.002 w
.49598 .358 m .51034 .34707 L .48838 .33026 L p
1 g
F P
s
P
p
.002 w
.48838 .33026 m .48108 .33588 L .49598 .358 L p
1 g
F P
s
P
p
.002 w
.46034 .3674 m .44266 .36491 L .43297 .39183 L p
1 g
F P
s
P
p
.002 w
.44266 .36491 m .46034 .3674 L .46286 .34067 L p
1 g
F P
s
P
p
.002 w
.47226 .33947 m .46286 .34067 L .46034 .3674 L p
1 g
F P
s
P
p
.002 w
.59534 .37662 m .57175 .40716 L .58946 .42915 L p
1 g
F P
s
P
p
.002 w
.57175 .40716 m .59534 .37662 L .5718 .36027 L p
1 g
F P
s
P
p
.002 w
.38383 .43254 m .41877 .44767 L .42496 .41959 L p
1 g
F P
s
P
p
.002 w
.42496 .41959 m .39601 .40668 L .38383 .43254 L p
1 g
F P
s
P
p
.002 w
.39601 .40668 m .42496 .41959 L .43297 .39183 L p
1 g
F P
s
P
p
.002 w
.43297 .39183 m .41067 .38158 L .39601 .40668 L p
1 g
F P
s
P
p
.002 w
.41067 .38158 m .43297 .39183 L .44266 .36491 L p
1 g
F P
s
P
p
.002 w
.52166 .52585 m .57394 .50521 L .56356 .48123 L p
1 g
F P
s
P
p
.002 w
.60519 .45144 m .56356 .48123 L .57394 .50521 L p
1 g
F P
s
P
p
.002 w
.56356 .48123 m .60519 .45144 L .58946 .42915 L p
1 g
F P
s
P
p
.002 w
.37441 .45867 m .41453 .47554 L .41877 .44767 L p
1 g
F P
s
P
p
.002 w
.41877 .44767 m .38383 .43254 L .37441 .45867 L p
1 g
F P
s
P
p
.002 w
.51034 .34707 m .52033 .3333 L .49339 .3232 L p
1 g
F P
s
P
p
.002 w
.49339 .3232 m .48838 .33026 L .51034 .34707 L p
1 g
F P
s
P
p
.002 w
.41232 .5285 m .46623 .53391 L .46278 .50804 L p
1 g
F P
s
P
p
.002 w
.46278 .50804 m .41235 .50267 L .41232 .5285 L p
1 g
F P
s
P
p
.002 w
.44266 .36491 m .42749 .35774 L .41067 .38158 L p
1 g
F P
s
P
p
.002 w
.42749 .35774 m .44266 .36491 L .45384 .33935 L p
1 g
F P
s
P
p
.002 w
.46286 .34067 m .45384 .33935 L .44266 .36491 L p
1 g
F P
s
P
p
.002 w
.61677 .3945 m .58946 .42915 L .60519 .45144 L p
1 g
F P
s
P
p
.002 w
.58946 .42915 m .61677 .3945 L .59534 .37662 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .46286 .34067 L .47226 .33947 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .47226 .33947 L .48108 .33588 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .48108 .33588 L .48838 .33026 L closepath p
1 g
F P
s
P
p
.002 w
.36799 .48454 m .41235 .50267 L .41453 .47554 L p
1 g
F P
s
P
p
.002 w
.41453 .47554 m .37441 .45867 L .36799 .48454 L p
1 g
F P
s
P
p
.002 w
.55354 .32346 m .54663 .34573 L .5718 .36027 L p
1 g
F P
s
P
p
.002 w
.54663 .34573 m .55354 .32346 L .52483 .31804 L p
1 g
F P
s
P
p
.002 w
.52483 .31804 m .52033 .3333 L .54663 .34573 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .45384 .33935 L .46286 .34067 L closepath p
1 g
F P
s
P
p
.002 w
.4706 .55777 m .52827 .54926 L .52166 .52585 L p
1 g
F P
s
P
p
.002 w
.52166 .52585 m .46623 .53391 L .4706 .55777 L p
1 g
F P
s
P
p
.002 w
.57394 .50521 m .52166 .52585 L .52827 .54926 L p
1 g
F P
s
P
p
.002 w
.52033 .3333 m .52483 .31804 L .49557 .31542 L p
1 g
F P
s
P
p
.002 w
.49557 .31542 m .49339 .3232 L .52033 .3333 L p
1 g
F P
s
P
p
.002 w
.58113 .33159 m .5718 .36027 L .59534 .37662 L p
1 g
F P
s
P
p
.002 w
.5718 .36027 m .58113 .33159 L .55354 .32346 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .48838 .33026 L .49339 .3232 L closepath p
1 g
F P
s
P
p
.002 w
.37451 .38606 m .39601 .40668 L .41067 .38158 L p
1 g
F P
s
P
p
.002 w
.41067 .38158 m .39427 .3654 L .37451 .38606 L p
1 g
F P
s
P
p
.002 w
.39427 .3654 m .41067 .38158 L .42749 .35774 L p
1 g
F P
s
P
p
.002 w
.45384 .33935 m .44617 .33562 L .42749 .35774 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .44617 .33562 L .45384 .33935 L closepath p
1 g
F P
s
P
p
.002 w
.42749 .35774 m .41648 .34655 L .39427 .3654 L p
1 g
F P
s
P
p
.002 w
.41648 .34655 m .42749 .35774 L .44617 .33562 L p
1 g
F P
s
P
p
.002 w
.52827 .54926 m .5827 .52786 L .57394 .50521 L p
1 g
F P
s
P
p
.002 w
.61859 .47362 m .57394 .50521 L .5827 .52786 L p
1 g
F P
s
P
p
.002 w
.57394 .50521 m .61859 .47362 L .60519 .45144 L p
1 g
F P
s
P
p
.002 w
.35764 .40812 m .38383 .43254 L .39601 .40668 L p
1 g
F P
s
P
p
.002 w
.39601 .40668 m .37451 .38606 L .35764 .40812 L p
1 g
F P
s
P
p
.002 w
.63561 .41357 m .60519 .45144 L .61859 .47362 L p
1 g
F P
s
P
p
.002 w
.60519 .45144 m .63561 .41357 L .61677 .3945 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .49339 .3232 L .49557 .31542 L closepath p
1 g
F P
s
P
p
.002 w
.41451 .55246 m .4706 .55777 L .46623 .53391 L p
1 g
F P
s
P
p
.002 w
.46623 .53391 m .41232 .5285 L .41451 .55246 L p
1 g
F P
s
P
p
.002 w
.44617 .33562 m .44067 .32986 L .41648 .34655 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .44067 .32986 L .44617 .33562 L closepath p
1 g
F P
s
P
p
.002 w
.60701 .34232 m .59534 .37662 L .61677 .3945 L p
1 g
F P
s
P
p
.002 w
.59534 .37662 m .60701 .34232 L .58113 .33159 L p
1 g
F P
s
P
p
.002 w
.3648 .5096 m .41232 .5285 L .41235 .50267 L p
1 g
F P
s
P
p
.002 w
.41235 .50267 m .36799 .48454 L .3648 .5096 L p
1 g
F P
s
P
p
.002 w
.49464 .30777 m .49557 .31542 L .52483 .31804 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .49557 .31542 L .49464 .30777 L closepath p
1 g
F P
s
P
p
.002 w
.52323 .3029 m .52483 .31804 L .55354 .32346 L p
1 g
F P
s
P
p
.002 w
.52483 .31804 m .52323 .3029 L .49464 .30777 L p
1 g
F P
s
P
p
.002 w
.3441 .43116 m .37441 .45867 L .38383 .43254 L p
1 g
F P
s
P
p
.002 w
.38383 .43254 m .35764 .40812 L .3441 .43116 L p
1 g
F P
s
P
p
.002 w
.41088 .33243 m .41648 .34655 L .44067 .32986 L p
1 g
F P
s
P
p
.002 w
.44067 .32986 m .43795 .32267 L .41088 .33243 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .43795 .32267 L .44067 .32986 L closepath p
1 g
F P
s
P
p
.002 w
.38572 .34479 m .39427 .3654 L .41648 .34655 L p
1 g
F P
s
P
p
.002 w
.41648 .34655 m .41088 .33243 L .38572 .34479 L p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .49464 .30777 L .49067 .30106 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .49067 .30106 L .48405 .29605 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .48405 .29605 L .47549 .29332 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .47549 .29332 L .46594 .29318 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .46594 .29318 L .45647 .29567 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .45647 .29567 L .44813 .3005 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .44813 .3005 L .44186 .30713 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .44186 .30713 L .43835 .3148 L closepath p
1 g
F P
s
P
p
.002 w
.46635 .31566 m .43835 .3148 L .43795 .32267 L closepath p
1 g
F P
s
P
p
.002 w
.55155 .30119 m .55354 .32346 L .58113 .33159 L p
1 g
F P
s
P
p
.002 w
.55354 .32346 m .55155 .30119 L .52323 .3029 L p
1 g
F P
s
P
p
.002 w
.47584 .57906 m .53434 .57031 L .52827 .54926 L p
1 g
F P
s
P
p
.002 w
.52827 .54926 m .4706 .55777 L .47584 .57906 L p
1 g
F P
s
P
p
.002 w
.5827 .52786 m .52827 .54926 L .53434 .57031 L p
1 g
F P
s
P
p
.002 w
.63062 .35546 m .61677 .3945 L .63561 .41357 L p
1 g
F P
s
P
p
.002 w
.61677 .3945 m .63062 .35546 L .60701 .34232 L p
1 g
F P
s
P
p
.002 w
.49067 .30106 m .49464 .30777 L .52323 .3029 L p
1 g
F P
s
P
p
.002 w
.36304 .35955 m .37451 .38606 L .39427 .3654 L p
1 g
F P
s
P
p
.002 w
.39427 .3654 m .38572 .34479 L .36304 .35955 L p
1 g
F P
s
P
p
.002 w
.41145 .31686 m .41088 .33243 L .43795 .32267 L p
1 g
F P
s
P
p
.002 w
.43795 .32267 m .43835 .3148 L .41145 .31686 L p
1 g
F P
s
P
p
.002 w
.5827 .52786 m .6293 .49523 L .61859 .47362 L p
1 g
F P
s
P
p
.002 w
.65141 .43348 m .61859 .47362 L .6293 .49523 L p
1 g
F P
s
P
p
.002 w
.61859 .47362 m .65141 .43348 L .63561 .41357 L p
1 g
F P
s
P
p
.002 w
.53434 .57031 m .58961 .54866 L .5827 .52786 L p
1 g
F P
s
P
p
.002 w
.6293 .49523 m .5827 .52786 L .58961 .54866 L p
1 g
F P
s
P
p
.002 w
.579 .30273 m .58113 .33159 L .60701 .34232 L p
1 g
F P
s
P
p
.002 w
.58113 .33159 m .579 .30273 L .55155 .30119 L p
1 g
F P
s
P
p
.002 w
.33429 .45469 m .36799 .48454 L .37441 .45867 L p
1 g
F P
s
P
p
.002 w
.37441 .45867 m .3441 .43116 L .33429 .45469 L p
1 g
F P
s
P
p
.002 w
.51557 .28951 m .52323 .3029 L .55155 .30119 L p
1 g
F P
s
P
p
.002 w
.52323 .3029 m .51557 .28951 L .49067 .30106 L p
1 g
F P
s
P
p
.002 w
.48405 .29605 m .49067 .30106 L .51557 .28951 L p
1 g
F P
s
P
p
.002 w
.41897 .57397 m .47584 .57906 L .4706 .55777 L p
1 g
F P
s
P
p
.002 w
.4706 .55777 m .41451 .55246 L .41897 .57397 L p
1 g
F P
s
P
p
.002 w
.41828 .30154 m .41145 .31686 L .43835 .3148 L p
1 g
F P
s
P
p
.002 w
.43835 .3148 m .44186 .30713 L .41828 .30154 L p
1 g
F P
s
P
p
.002 w
.36503 .53326 m .41451 .55246 L .41232 .5285 L p
1 g
F P
s
P
p
.002 w
.41232 .5285 m .3648 .5096 L .36503 .53326 L p
1 g
F P
s
P
p
.002 w
.38625 .32186 m .38572 .34479 L .41088 .33243 L p
1 g
F P
s
P
p
.002 w
.41088 .33243 m .41145 .31686 L .38625 .32186 L p
1 g
F P
s
P
p
.002 w
.34341 .37645 m .35764 .40812 L .37451 .38606 L p
1 g
F P
s
P
p
.002 w
.37451 .38606 m .36304 .35955 L .34341 .37645 L p
1 g
F P
s
P
p
.002 w
.51557 .28951 m .50255 .27942 L .48405 .29605 L p
1 g
F P
s
P
p
.002 w
.47549 .29332 m .48405 .29605 L .50255 .27942 L p
1 g
F P
s
P
p
.002 w
.43071 .28822 m .41828 .30154 L .44186 .30713 L p
1 g
F P
s
P
p
.002 w
.44186 .30713 m .44813 .3005 L .43071 .28822 L p
1 g
F P
s
P
p
.002 w
.65137 .37081 m .63561 .41357 L .65141 .43348 L p
1 g
F P
s
P
p
.002 w
.63561 .41357 m .65137 .37081 L .63062 .35546 L p
1 g
F P
s
P
p
.002 w
.60495 .30759 m .60701 .34232 L .63062 .35546 L p
1 g
F P
s
P
p
.002 w
.60701 .34232 m .60495 .30759 L .579 .30273 L p
1 g
F P
s
P
p
.002 w
.54056 .28134 m .55155 .30119 L .579 .30273 L p
1 g
F P
s
P
p
.002 w
.55155 .30119 m .54056 .28134 L .51557 .28951 L p
1 g
F P
s
P
p
.002 w
.50255 .27942 m .48552 .27385 L .47549 .29332 L p
1 g
F P
s
P
p
.002 w
.46594 .29318 m .47549 .29332 L .48552 .27385 L p
1 g
F P
s
P
p
.002 w
.44738 .2785 m .43071 .28822 L .44813 .3005 L p
1 g
F P
s
P
p
.002 w
.44813 .3005 m .45647 .29567 L .44738 .2785 L p
1 g
F P
s
P
p
.002 w
.48552 .27385 m .46639 .27351 L .46594 .29318 L p
1 g
F P
s
P
p
.002 w
.45647 .29567 m .46594 .29318 L .46639 .27351 L p
1 g
F P
s
P
p
.002 w
.46639 .27351 m .44738 .2785 L .45647 .29567 L p
1 g
F P
s
P
p
.002 w
.50255 .27942 m .51557 .28951 L .54056 .28134 L p
1 g
F P
s
P
p
.002 w
.32856 .47819 m .3648 .5096 L .36799 .48454 L p
1 g
F P
s
P
p
.002 w
.36799 .48454 m .33429 .45469 L .32856 .47819 L p
1 g
F P
s
P
p
.002 w
.36337 .3298 m .36304 .35955 L .38572 .34479 L p
1 g
F P
s
P
p
.002 w
.38572 .34479 m .38625 .32186 L .36337 .3298 L p
1 g
F P
s
P
p
.002 w
.48187 .5972 m .53972 .58845 L .53434 .57031 L p
1 g
F P
s
P
p
.002 w
.53434 .57031 m .47584 .57906 L .48187 .5972 L p
1 g
F P
s
P
p
.002 w
.58961 .54866 m .53434 .57031 L .53972 .58845 L p
1 g
F P
s
P
p
.002 w
.39614 .29912 m .38625 .32186 L .41145 .31686 L p
1 g
F P
s
P
p
.002 w
.41145 .31686 m .41828 .30154 L .39614 .29912 L p
1 g
F P
s
P
p
.002 w
.32738 .39518 m .3441 .43116 L .35764 .40812 L p
1 g
F P
s
P
p
.002 w
.35764 .40812 m .34341 .37645 L .32738 .39518 L p
1 g
F P
s
P
p
.002 w
.58961 .54866 m .63699 .51579 L .6293 .49523 L p
1 g
F P
s
P
p
.002 w
.66371 .45382 m .6293 .49523 L .63699 .51579 L p
1 g
F P
s
P
p
.002 w
.6293 .49523 m .66371 .45382 L .65141 .43348 L p
1 g
F P
s
P
p
.002 w
.53972 .58845 m .59442 .56709 L .58961 .54866 L p
1 g
F P
s
P
p
.002 w
.63699 .51579 m .58961 .54866 L .59442 .56709 L p
1 g
F P
s
P
p
.002 w
.36881 .55492 m .41897 .57397 L .41451 .55246 L p
1 g
F P
s
P
p
.002 w
.41451 .55246 m .36503 .53326 L .36881 .55492 L p
1 g
F P
s
P
p
.002 w
.56509 .27682 m .579 .30273 L .60495 .30759 L p
1 g
F P
s
P
p
.002 w
.579 .30273 m .56509 .27682 L .54056 .28134 L p
1 g
F P
s
P
p
.002 w
.4257 .59241 m .48187 .5972 L .47584 .57906 L p
1 g
F P
s
P
p
.002 w
.47584 .57906 m .41897 .57397 L .4257 .59241 L p
1 g
F P
s
P
p
.002 w
.62879 .31575 m .63062 .35546 L .65137 .37081 L p
1 g
F P
s
P
p
.002 w
.63062 .35546 m .62879 .31575 L .60495 .30759 L p
1 g
F P
s
P
p
.002 w
.54056 .28134 m .52147 .26625 L .50255 .27942 L p
1 g
F P
s
P
p
.002 w
.48552 .27385 m .50255 .27942 L .52147 .26625 L p
1 g
F P
s
P
p
.002 w
.66869 .38809 m .65141 .43348 L .66371 .45382 L p
1 g
F P
s
P
p
.002 w
.65141 .43348 m .66869 .38809 L .65137 .37081 L p
1 g
F P
s
P
p
.002 w
.4145 .27924 m .39614 .29912 L .41828 .30154 L p
1 g
F P
s
P
p
.002 w
.41828 .30154 m .43071 .28822 L .4145 .27924 L p
1 g
F P
s
P
p
.002 w
.34342 .34061 m .34341 .37645 L .36304 .35955 L p
1 g
F P
s
P
p
.002 w
.36304 .35955 m .36337 .3298 L .34342 .34061 L p
1 g
F P
s
P
p
.002 w
.52147 .26625 m .54056 .28134 L .56509 .27682 L p
1 g
F P
s
P
p
.002 w
.31548 .41537 m .33429 .45469 L .3441 .43116 L p
1 g
F P
s
P
p
.002 w
.3441 .43116 m .32738 .39518 L .31548 .41537 L p
1 g
F P
s
P
p
.002 w
.32722 .50111 m .36503 .53326 L .3648 .5096 L p
1 g
F P
s
P
p
.002 w
.3648 .5096 m .32856 .47819 L .32722 .50111 L p
1 g
F P
s
P
p
.002 w
.37601 .30007 m .36337 .3298 L .38625 .32186 L p
1 g
F P
s
P
p
.002 w
.38625 .32186 m .39614 .29912 L .37601 .30007 L p
1 g
F P
s
P
p
.002 w
.52147 .26625 m .49625 .25782 L .48552 .27385 L p
1 g
F P
s
P
p
.002 w
.46639 .27351 m .48552 .27385 L .49625 .25782 L p
1 g
F P
s
P
p
.002 w
.43935 .26468 m .4145 .27924 L .43071 .28822 L p
1 g
F P
s
P
p
.002 w
.43071 .28822 m .44738 .2785 L .43935 .26468 L p
1 g
F P
s
P
p
.002 w
.49625 .25782 m .46774 .25724 L .46639 .27351 L p
1 g
F P
s
P
p
.002 w
.44738 .2785 m .46639 .27351 L .46774 .25724 L p
1 g
F P
s
P
p
.002 w
.46774 .25724 m .43935 .26468 L .44738 .2785 L p
1 g
F P
s
P
p
.002 w
.59442 .56709 m .64136 .53479 L .63699 .51579 L p
1 g
F P
s
P
p
.002 w
.67209 .47415 m .63699 .51579 L .64136 .53479 L p
1 g
F P
s
P
p
.002 w
.63699 .51579 m .67209 .47415 L .66371 .45382 L p
1 g
F P
s
P
p
.002 w
.58858 .2762 m .60495 .30759 L .62879 .31575 L p
1 g
F P
s
P
p
.002 w
.60495 .30759 m .58858 .2762 L .56509 .27682 L p
1 g
F P
s
P
p
.002 w
.64987 .32715 m .65137 .37081 L .66869 .38809 L p
1 g
F P
s
P
p
.002 w
.65137 .37081 m .64987 .32715 L .62879 .31575 L p
1 g
F P
s
P
p
.002 w
.4886 .61162 m .54426 .60311 L .53972 .58845 L p
1 g
F P
s
P
p
.002 w
.53972 .58845 m .48187 .5972 L .4886 .61162 L p
1 g
F P
s
P
p
.002 w
.59442 .56709 m .53972 .58845 L .54426 .60311 L p
1 g
F P
s
P
p
.002 w
.37622 .57396 m .4257 .59241 L .41897 .57397 L p
1 g
F P
s
P
p
.002 w
.41897 .57397 m .36881 .55492 L .37622 .57396 L p
1 g
F P
s
P
p
.002 w
.68205 .40699 m .66371 .45382 L .67209 .47415 L p
1 g
F P
s
P
p
.002 w
.66371 .45382 m .68205 .40699 L .66869 .38809 L p
1 g
F P
s
P
p
.002 w
.32702 .35416 m .32738 .39518 L .34341 .37645 L p
1 g
F P
s
P
p
.002 w
.34341 .37645 m .34342 .34061 L .32702 .35416 L p
1 g
F P
s
P
p
.002 w
.56509 .27682 m .54042 .25696 L .52147 .26625 L p
1 g
F P
s
P
p
.002 w
.49625 .25782 m .52147 .26625 L .54042 .25696 L p
1 g
F P
s
P
p
.002 w
.54426 .60311 m .59694 .5826 L .59442 .56709 L p
1 g
F P
s
P
p
.002 w
.64136 .53479 m .59442 .56709 L .59694 .5826 L p
1 g
F P
s
P
p
.002 w
.54042 .25696 m .56509 .27682 L .58858 .2762 L p
1 g
F P
s
P
p
.002 w
.30818 .43658 m .32856 .47819 L .33429 .45469 L p
1 g
F P
s
P
p
.002 w
.33429 .45469 m .31548 .41537 L .30818 .43658 L p
1 g
F P
s
P
p
.002 w
.39997 .27394 m .37601 .30007 L .39614 .29912 L p
1 g
F P
s
P
p
.002 w
.39614 .29912 m .4145 .27924 L .39997 .27394 L p
1 g
F P
s
P
p
.002 w
.43464 .6072 m .4886 .61162 L .48187 .5972 L p
1 g
F P
s
P
p
.002 w
.48187 .5972 m .4257 .59241 L .43464 .6072 L p
1 g
F P
s
P
p
.002 w
.3305 .52284 m .36881 .55492 L .36503 .53326 L p
1 g
F P
s
P
p
.002 w
.36503 .53326 m .32722 .50111 L .3305 .52284 L p
1 g
F P
s
P
p
.002 w
.3585 .30454 m .34342 .34061 L .36337 .3298 L p
1 g
F P
s
P
p
.002 w
.36337 .3298 m .37601 .30007 L .3585 .30454 L p
1 g
F P
s
P
p
.002 w
.61042 .27967 m .62879 .31575 L .64987 .32715 L p
1 g
F P
s
P
p
.002 w
.62879 .31575 m .61042 .27967 L .58858 .2762 L p
1 g
F P
s
P
p
.002 w
.54042 .25696 m .50747 .24579 L .49625 .25782 L p
1 g
F P
s
P
p
.002 w
.46774 .25724 m .49625 .25782 L .50747 .24579 L p
1 g
F P
s
P
p
.002 w
.43261 .25473 m .39997 .27394 L .4145 .27924 L p
1 g
F P
s
P
p
.002 w
.4145 .27924 m .43935 .26468 L .43261 .25473 L p
1 g
F P
s
P
p
.002 w
.66756 .34166 m .66869 .38809 L .68205 .40699 L p
1 g
F P
s
P
p
.002 w
.66869 .38809 m .66756 .34166 L .64987 .32715 L p
1 g
F P
s
P
p
.002 w
.59694 .5826 m .64213 .5517 L .64136 .53479 L p
1 g
F P
s
P
p
.002 w
.67616 .49398 m .64136 .53479 L .64213 .5517 L p
1 g
F P
s
P
p
.002 w
.64136 .53479 m .67616 .49398 L .67209 .47415 L p
1 g
F P
s
P
p
.002 w
.31478 .37025 m .31548 .41537 L .32738 .39518 L p
1 g
F P
s
P
p
.002 w
.32738 .39518 m .32702 .35416 L .31478 .37025 L p
1 g
F P
s
P
p
.002 w
.50747 .24579 m .47 .24495 L .46774 .25724 L p
1 g
F P
s
P
p
.002 w
.43935 .26468 m .46774 .25724 L .47 .24495 L p
1 g
F P
s
P
p
.002 w
.47 .24495 m .43261 .25473 L .43935 .26468 L p
1 g
F P
s
P
p
.002 w
.69093 .42709 m .67209 .47415 L .67616 .49398 L p
1 g
F P
s
P
p
.002 w
.67209 .47415 m .69093 .42709 L .68205 .40699 L p
1 g
F P
s
P
p
.002 w
.55893 .25199 m .58858 .2762 L .61042 .27967 L p
1 g
F P
s
P
p
.002 w
.58858 .2762 m .55893 .25199 L .54042 .25696 L p
1 g
F P
s
P
p
.002 w
.30589 .4583 m .32722 .50111 L .32856 .47819 L p
1 g
F P
s
P
p
.002 w
.32856 .47819 m .30818 .43658 L .30589 .4583 L p
1 g
F P
s
P
p
.002 w
.38726 .58976 m .43464 .6072 L .4257 .59241 L p
1 g
F P
s
P
p
.002 w
.4257 .59241 m .37622 .57396 L .38726 .58976 L p
1 g
F P
s
P
p
.002 w
.4959 .62174 m .5478 .61376 L .54426 .60311 L p
1 g
F P
s
P
p
.002 w
.54426 .60311 m .4886 .61162 L .4959 .62174 L p
1 g
F P
s
P
p
.002 w
.59694 .5826 m .54426 .60311 L .5478 .61376 L p
1 g
F P
s
P
p
.002 w
.50747 .24579 m .54042 .25696 L .55893 .25199 L p
1 g
F P
s
P
p
.002 w
.38756 .27266 m .3585 .30454 L .37601 .30007 L p
1 g
F P
s
P
p
.002 w
.37601 .30007 m .39997 .27394 L .38756 .27266 L p
1 g
F P
s
P
p
.002 w
.5478 .61376 m .59695 .59466 L .59694 .5826 L p
1 g
F P
s
P
p
.002 w
.64213 .5517 m .59694 .5826 L .59695 .59466 L p
1 g
F P
s
P
p
.002 w
.34418 .31261 m .32702 .35416 L .34342 .34061 L p
1 g
F P
s
P
p
.002 w
.34342 .34061 m .3585 .30454 L .34418 .31261 L p
1 g
F P
s
P
p
.002 w
.33854 .54274 m .37622 .57396 L .36881 .55492 L p
1 g
F P
s
P
p
.002 w
.36881 .55492 m .3305 .52284 L .33854 .54274 L p
1 g
F P
s
P
p
.002 w
.44571 .61775 m .4959 .62174 L .4886 .61162 L p
1 g
F P
s
P
p
.002 w
.4886 .61162 m .43464 .6072 L .44571 .61775 L p
1 g
F P
s
P
p
.002 w
.62998 .28733 m .64987 .32715 L .66756 .34166 L p
1 g
F P
s
P
p
.002 w
.64987 .32715 m .62998 .28733 L .61042 .27967 L p
1 g
F P
s
P
p
.002 w
.68125 .35903 m .68205 .40699 L .69093 .42709 L p
1 g
F P
s
P
p
.002 w
.68205 .40699 m .68125 .35903 L .66756 .34166 L p
1 g
F P
s
P
p
.002 w
.55893 .25199 m .51892 .23827 L .50747 .24579 L p
1 g
F P
s
P
p
.002 w
.47 .24495 m .50747 .24579 L .51892 .23827 L p
1 g
F P
s
P
p
.002 w
.30722 .38856 m .30818 .43658 L .31548 .41537 L p
1 g
F P
s
P
p
.002 w
.31548 .41537 m .31478 .37025 L .30722 .38856 L p
1 g
F P
s
P
p
.002 w
.42743 .24915 m .38756 .27266 L .39997 .27394 L p
1 g
F P
s
P
p
.002 w
.39997 .27394 m .43261 .25473 L .42743 .24915 L p
1 g
F P
s
P
p
.002 w
.30892 .47997 m .3305 .52284 L .32722 .50111 L p
1 g
F P
s
P
p
.002 w
.32722 .50111 m .30589 .4583 L .30892 .47997 L p
1 g
F P
s
P
p
.002 w
.59695 .59466 m .63908 .56598 L .64213 .5517 L p
1 g
F P
s
P
p
.002 w
.67561 .51278 m .64213 .5517 L .63908 .56598 L p
1 g
F P
s
P
p
.002 w
.64213 .5517 m .67561 .51278 L .67616 .49398 L p
1 g
F P
s
P
p
.002 w
.57651 .25168 m .61042 .27967 L .62998 .28733 L p
1 g
F P
s
P
p
.002 w
.61042 .27967 m .57651 .25168 L .55893 .25199 L p
1 g
F P
s
P
p
.002 w
.6949 .44795 m .67616 .49398 L .67561 .51278 L p
1 g
F P
s
P
p
.002 w
.67616 .49398 m .6949 .44795 L .69093 .42709 L p
1 g
F P
s
P
p
.002 w
.51892 .23827 m .47317 .23719 L .47 .24495 L p
1 g
F P
s
P
p
.002 w
.43261 .25473 m .47 .24495 L .47317 .23719 L p
1 g
F P
s
P
p
.002 w
.51892 .23827 m .55893 .25199 L .57651 .25168 L p
1 g
F P
s
P
p
.002 w
.47317 .23719 m .42743 .24915 L .43261 .25473 L p
1 g
F P
s
P
p
.002 w
.40182 .60172 m .44571 .61775 L .43464 .6072 L p
1 g
F P
s
P
p
.002 w
.43464 .6072 m .38726 .58976 L .40182 .60172 L p
1 g
F P
s
P
p
.002 w
.33364 .32427 m .31478 .37025 L .32702 .35416 L p
1 g
F P
s
P
p
.002 w
.32702 .35416 m .34418 .31261 L .33364 .32427 L p
1 g
F P
s
P
p
.002 w
.50362 .62704 m .55019 .61986 L .5478 .61376 L p
1 g
F P
s
P
p
.002 w
.5478 .61376 m .4959 .62174 L .50362 .62704 L p
1 g
F P
s
P
p
.002 w
.59695 .59466 m .5478 .61376 L .55019 .61986 L p
1 g
F P
s
P
p
.002 w
.37774 .27569 m .34418 .31261 L .3585 .30454 L p
1 g
F P
s
P
p
.002 w
.3585 .30454 m .38756 .27266 L .37774 .27569 L p
1 g
F P
s
P
p
.002 w
.35136 .56018 m .38726 .58976 L .37622 .57396 L p
1 g
F P
s
P
p
.002 w
.37622 .57396 m .33854 .54274 L .35136 .56018 L p
1 g
F P
s
P
p
.002 w
.64663 .29918 m .66756 .34166 L .68125 .35903 L p
1 g
F P
s
P
p
.002 w
.66756 .34166 m .64663 .29918 L .62998 .28733 L p
1 g
F P
s
P
p
.002 w
.55019 .61986 m .59431 .60273 L .59695 .59466 L p
1 g
F P
s
P
p
.002 w
.63908 .56598 m .59695 .59466 L .59431 .60273 L p
1 g
F P
s
P
p
.002 w
.69038 .37894 m .69093 .42709 L .6949 .44795 L p
1 g
F P
s
P
p
.002 w
.69093 .42709 m .69038 .37894 L .68125 .35903 L p
1 g
F P
s
P
p
.002 w
.45872 .62353 m .50362 .62704 L .4959 .62174 L p
1 g
F P
s
P
p
.002 w
.4959 .62174 m .44571 .61775 L .45872 .62353 L p
1 g
F P
s
P
p
.002 w
.30482 .4087 m .30589 .4583 L .30818 .43658 L p
1 g
F P
s
P
p
.002 w
.30818 .43658 m .30722 .38856 L .30482 .4087 L p
1 g
F P
s
P
p
.002 w
.31744 .50095 m .33854 .54274 L .3305 .52284 L p
1 g
F P
s
P
p
.002 w
.3305 .52284 m .30892 .47997 L .31744 .50095 L p
1 g
F P
s
P
p
.002 w
.57651 .25168 m .53032 .23575 L .51892 .23827 L p
1 g
F P
s
P
p
.002 w
.47317 .23719 m .51892 .23827 L .53032 .23575 L p
1 g
F P
s
P
p
.002 w
.59264 .25631 m .62998 .28733 L .64663 .29918 L p
1 g
F P
s
P
p
.002 w
.62998 .28733 m .59264 .25631 L .57651 .25168 L p
1 g
F P
s
P
p
.002 w
.42403 .24837 m .37774 .27569 L .38756 .27266 L p
1 g
F P
s
P
p
.002 w
.38756 .27266 m .42743 .24915 L .42403 .24837 L p
1 g
F P
s
P
p
.002 w
.63908 .56598 m .67019 .53 L .67561 .51278 L p
1 g
F P
s
P
p
.002 w
.69359 .46903 m .67561 .51278 L .67019 .53 L p
1 g
F P
s
P
p
.002 w
.67561 .51278 m .69359 .46903 L .6949 .44795 L p
1 g
F P
s
P
p
.002 w
.59431 .60273 m .63206 .5771 L .63908 .56598 L p
1 g
F P
s
P
p
.002 w
.67019 .53 m .63908 .56598 L .63206 .5771 L p
1 g
F P
s
P
p
.002 w
.53032 .23575 m .57651 .25168 L .59264 .25631 L p
1 g
F P
s
P
p
.002 w
.3274 .33939 m .30722 .38856 L .31478 .37025 L p
1 g
F P
s
P
p
.002 w
.31478 .37025 m .33364 .32427 L .3274 .33939 L p
1 g
F P
s
P
p
.002 w
.68125 .35903 m .65976 .31511 L .64663 .29918 L p
1 g
F P
s
P
p
.002 w
.65976 .31511 m .68125 .35903 L .69038 .37894 L p
1 g
F P
s
P
p
.002 w
.41968 .60928 m .45872 .62353 L .44571 .61775 L p
1 g
F P
s
P
p
.002 w
.44571 .61775 m .40182 .60172 L .41968 .60928 L p
1 g
F P
s
P
p
.002 w
.36881 .57452 m .40182 .60172 L .38726 .58976 L p
1 g
F P
s
P
p
.002 w
.38726 .58976 m .35136 .56018 L .36881 .57452 L p
1 g
F P
s
P
p
.002 w
.53032 .23575 m .47723 .23446 L .47317 .23719 L p
1 g
F P
s
P
p
.002 w
.42743 .24915 m .47317 .23719 L .47723 .23446 L p
1 g
F P
s
P
p
.002 w
.47723 .23446 m .42403 .24837 L .42743 .24915 L p
1 g
F P
s
P
p
.002 w
.37095 .28322 m .33364 .32427 L .34418 .31261 L p
1 g
F P
s
P
p
.002 w
.34418 .31261 m .37774 .27569 L .37095 .28322 L p
1 g
F P
s
P
p
.004 w
.28834 .51777 m
.31324 .50751 L
s
P
p
.004 w
.28478 .51924 m
.28834 .51777 L
s
P
p
.004 w
.28254 .52016 m
.28478 .51924 L
s
P
p
.002 w
.6949 .44795 m .69446 .40095 L .69038 .37894 L p
1 g
F P
s
P
p
.002 w
.69446 .40095 m .6949 .44795 L .69359 .46903 L p
1 g
F P
s
P
p
.002 w
.51157 .62707 m .55128 .62094 L .55019 .61986 L p
1 g
F P
s
P
p
.004 w
.55764 .62723 m
.56489 .65197 L
s
P
p
.002 w
.55019 .61986 m .50362 .62704 L .51157 .62707 L p
1 g
F P
s
P
p
.002 w
.59431 .60273 m .55019 .61986 L .55128 .62094 L p
1 g
F P
s
P
p
.002 w
.30792 .43015 m .30892 .47997 L .30589 .4583 L p
1 g
F P
s
P
p
.002 w
.30589 .4583 m .30482 .4087 L .30792 .43015 L p
1 g
F P
s
P
p
.002 w
.55128 .62094 m .58892 .60633 L .59431 .60273 L p
1 g
F P
s
P
p
.002 w
.63206 .5771 m .59431 .60273 L .58892 .60633 L p
1 g
F P
s
P
p
.002 w
.47342 .62408 m .51157 .62707 L .50362 .62704 L p
1 g
F P
s
P
p
.002 w
.50362 .62704 m .45872 .62353 L .47342 .62408 L p
1 g
F P
s
P
p
.002 w
.33147 .52057 m .35136 .56018 L .33854 .54274 L p
1 g
F P
s
P
p
.002 w
.33854 .54274 m .31744 .50095 L .33147 .52057 L p
1 g
F P
s
P
p
.002 w
.64663 .29918 m .60678 .26602 L .59264 .25631 L p
1 g
F P
s
P
p
.002 w
.60678 .26602 m .64663 .29918 L .65976 .31511 L p
1 g
F P
s
P
p
.002 w
.59264 .25631 m .54135 .23859 L .53032 .23575 L p
1 g
F P
s
P
p
.002 w
.47723 .23446 m .53032 .23575 L .54135 .23859 L p
1 g
F P
s
P
p
.002 w
.63206 .5771 m .6598 .54506 L .67019 .53 L p
1 g
F P
s
P
p
.002 w
.67019 .53 m .68678 .48973 L .69359 .46903 L p
1 g
F P
s
P
p
.002 w
.68678 .48973 m .67019 .53 L .6598 .54506 L p
1 g
F P
s
P
p
.002 w
.6688 .33487 m .69038 .37894 L .69446 .40095 L p
1 g
F P
s
P
p
.002 w
.69038 .37894 m .6688 .33487 L .65976 .31511 L p
1 g
F P
s
P
p
.002 w
.42265 .25274 m .37095 .28322 L .37774 .27569 L p
1 g
F P
s
P
p
.002 w
.37774 .27569 m .42403 .24837 L .42265 .25274 L p
1 g
F P
s
P
p
.002 w
.32589 .35771 m .30482 .4087 L .30722 .38856 L p
1 g
F P
s
P
p
.002 w
.30722 .38856 m .3274 .33939 L .32589 .35771 L p
1 g
F P
s
P
p
.002 w
.58892 .60633 m .62103 .58453 L .63206 .5771 L p
1 g
F P
s
P
p
.002 w
.6598 .54506 m .63206 .5771 L .62103 .58453 L p
1 g
F P
s
P
p
.002 w
.54135 .23859 m .59264 .25631 L .60678 .26602 L p
1 g
F P
s
P
p
.002 w
.39059 .58517 m .41968 .60928 L .40182 .60172 L p
1 g
F P
s
P
p
.002 w
.40182 .60172 m .36881 .57452 L .39059 .58517 L p
1 g
F P
s
P
p
.002 w
.44047 .61199 m .47342 .62408 L .45872 .62353 L p
1 g
F P
s
P
p
.002 w
.45872 .62353 m .41968 .60928 L .44047 .61199 L p
1 g
F P
s
P
p
.002 w
.69314 .42451 m .69359 .46903 L .68678 .48973 L p
1 g
F P
s
P
p
.002 w
.69359 .46903 m .69314 .42451 L .69446 .40095 L p
1 g
F P
s
P
p
.002 w
.36759 .29531 m .3274 .33939 L .33364 .32427 L p
1 g
F P
s
P
p
.002 w
.33364 .32427 m .37095 .28322 L .36759 .29531 L p
1 g
F P
s
P
p
.002 w
.31671 .45233 m .31744 .50095 L .30892 .47997 L p
1 g
F P
s
P
p
.002 w
.30892 .47997 m .30792 .43015 L .31671 .45233 L p
1 g
F P
s
P
p
.002 w
.54135 .23859 m .48211 .23719 L .47723 .23446 L p
1 g
F P
s
P
p
.002 w
.42403 .24837 m .47723 .23446 L .48211 .23719 L p
1 g
F P
s
P
p
.002 w
.48211 .23719 m .42265 .25274 L .42403 .24837 L p
1 g
F P
s
P
p
.002 w
.35082 .53817 m .36881 .57452 L .35136 .56018 L p
1 g
F P
s
P
p
.002 w
.35136 .56018 m .33147 .52057 L .35082 .53817 L p
1 g
F P
s
P
p
.002 w
.51954 .62148 m .55096 .61664 L .55128 .62094 L p
1 g
F P
s
P
p
.002 w
.55128 .62094 m .51157 .62707 L .51954 .62148 L p
1 g
F P
s
P
p
.002 w
.58892 .60633 m .55128 .62094 L .55096 .61664 L p
1 g
F P
s
P
p
.002 w
.61838 .28081 m .65976 .31511 L .6688 .33487 L p
1 g
F P
s
P
p
.002 w
.65976 .31511 m .61838 .28081 L .60678 .26602 L p
1 g
F P
s
P
p
.002 w
.55096 .61664 m .58075 .60507 L .58892 .60633 L p
1 g
F P
s
P
p
.002 w
.62103 .58453 m .58892 .60633 L .58075 .60507 L p
1 g
F P
s
P
p
.002 w
.48946 .61907 m .51954 .62148 L .51157 .62707 L p
1 g
F P
s
P
p
.002 w
.51157 .62707 m .47342 .62408 L .48946 .61907 L p
1 g
F P
s
P
p
.002 w
.67326 .35805 m .69446 .40095 L .69314 .42451 L p
1 g
F P
s
P
p
.002 w
.69446 .40095 m .67326 .35805 L .6688 .33487 L p
1 g
F P
s
P
p
.002 w
.62103 .58453 m .64445 .55741 L .6598 .54506 L p
1 g
F P
s
P
p
.002 w
.6744 .50941 m .6598 .54506 L .64445 .55741 L p
1 g
F P
s
P
p
.002 w
.6598 .54506 m .6744 .50941 L .68678 .48973 L p
1 g
F P
s
P
p
.002 w
.32943 .37884 m .30792 .43015 L .30482 .4087 L p
1 g
F P
s
P
p
.002 w
.30482 .4087 m .32589 .35771 L .32943 .37884 L p
1 g
F P
s
P
p
.002 w
.60678 .26602 m .55164 .24707 L .54135 .23859 L p
1 g
F P
s
P
p
.002 w
.48211 .23719 m .54135 .23859 L .55164 .24707 L p
1 g
F P
s
P
p
.002 w
.55164 .24707 m .60678 .26602 L .61838 .28081 L p
1 g
F P
s
P
p
.002 w
.41621 .59162 m .44047 .61199 L .41968 .60928 L p
1 g
F P
s
P
p
.002 w
.41968 .60928 m .39059 .58517 L .41621 .59162 L p
1 g
F P
s
P
p
.002 w
.68619 .44897 m .68678 .48973 L .6744 .50941 L p
1 g
F P
s
P
p
.002 w
.68678 .48973 m .68619 .44897 L .69314 .42451 L p
1 g
F P
s
P
p
.002 w
.58075 .60507 m .60607 .58783 L .62103 .58453 L p
1 g
F P
s
P
p
.002 w
.64445 .55741 m .62103 .58453 L .60607 .58783 L p
1 g
F P
s
P
p
.002 w
.42345 .26246 m .36759 .29531 L .37095 .28322 L p
1 g
F P
s
P
p
.002 w
.37095 .28322 m .42265 .25274 L .42345 .26246 L p
1 g
F P
s
P
p
.002 w
.33116 .47453 m .33147 .52057 L .31744 .50095 L p
1 g
F P
s
P
p
.002 w
.31744 .50095 m .31671 .45233 L .33116 .47453 L p
1 g
F P
s
P
p
.004 w
.31324 .50751 m
.33037 .50044 L
s
P
p
.002 w
.4637 .6095 m .48946 .61907 L .47342 .62408 L p
1 g
F P
s
P
p
.002 w
.47342 .62408 m .44047 .61199 L .4637 .6095 L p
1 g
F P
s
P
p
.002 w
.36799 .31185 m .32589 .35771 L .3274 .33939 L p
1 g
F P
s
P
p
.002 w
.3274 .33939 m .36759 .29531 L .36799 .31185 L p
1 g
F P
s
P
p
.002 w
.37509 .55306 m .39059 .58517 L .36881 .57452 L p
1 g
F P
s
P
p
.002 w
.36881 .57452 m .35082 .53817 L .37509 .55306 L p
1 g
F P
s
P
p
.002 w
.55164 .24707 m .48772 .24564 L .48211 .23719 L p
1 g
F P
s
P
p
.002 w
.42265 .25274 m .48211 .23719 L .48772 .24564 L p
1 g
F P
s
P
p
.002 w
.62694 .30051 m .6688 .33487 L .67326 .35805 L p
1 g
F P
s
P
p
.002 w
.6688 .33487 m .62694 .30051 L .61838 .28081 L p
1 g
F P
s
P
p
.002 w
.48772 .24564 m .42345 .26246 L .42265 .25274 L p
1 g
F P
s
P
p
.002 w
.67278 .38405 m .69314 .42451 L .68619 .44897 L p
1 g
F P
s
P
p
.002 w
.69314 .42451 m .67278 .38405 L .67326 .35805 L p
1 g
F P
s
P
p
.002 w
.52726 .61007 m .54914 .60672 L .55096 .61664 L p
1 g
F P
s
P
p
.002 w
.55096 .61664 m .51954 .62148 L .52726 .61007 L p
1 g
F P
s
P
p
.002 w
.58075 .60507 m .55096 .61664 L .54914 .60672 L p
1 g
F P
s
P
p
.002 w
.54914 .60672 m .56988 .59866 L .58075 .60507 L p
1 g
F P
s
P
p
.002 w
.60607 .58783 m .58075 .60507 L .56988 .59866 L p
1 g
F P
s
P
p
.002 w
.60607 .58783 m .62437 .56649 L .64445 .55741 L p
1 g
F P
s
P
p
.002 w
.65656 .52741 m .64445 .55741 L .62437 .56649 L p
1 g
F P
s
P
p
.002 w
.64445 .55741 m .65656 .52741 L .6744 .50941 L p
1 g
F P
s
P
p
.002 w
.33817 .4022 m .31671 .45233 L .30792 .43015 L p
1 g
F P
s
P
p
.002 w
.30792 .43015 m .32943 .37884 L .33817 .4022 L p
1 g
F P
s
P
p
.002 w
.50642 .60834 m .52726 .61007 L .51954 .62148 L p
1 g
F P
s
P
p
.002 w
.51954 .62148 m .48946 .61907 L .50642 .60834 L p
1 g
F P
s
P
p
.002 w
.67358 .47357 m .6744 .50941 L .65656 .52741 L p
1 g
F P
s
P
p
.002 w
.6744 .50941 m .67358 .47357 L .68619 .44897 L p
1 g
F P
s
P
p
.002 w
.35102 .49602 m .35082 .53817 L .33147 .52057 L p
1 g
F P
s
P
p
.002 w
.33147 .52057 m .33116 .47453 L .35102 .49602 L p
1 g
F P
s
P
p
.002 w
.44499 .59348 m .4637 .6095 L .44047 .61199 L p
1 g
F P
s
P
p
.002 w
.44047 .61199 m .41621 .59162 L .44499 .59348 L p
1 g
F P
s
P
p
.002 w
.56084 .26125 m .61838 .28081 L .62694 .30051 L p
1 g
F P
s
P
p
.002 w
.61838 .28081 m .56084 .26125 L .55164 .24707 L p
1 g
F P
s
P
p
.002 w
.48772 .24564 m .55164 .24707 L .56084 .26125 L p
1 g
F P
s
P
p
.002 w
.56988 .59866 m .58742 .58665 L .60607 .58783 L p
1 g
F P
s
P
p
.002 w
.62437 .56649 m .60607 .58783 L .58742 .58665 L p
1 g
F P
s
P
p
.002 w
.40363 .56466 m .41621 .59162 L .39059 .58517 L p
1 g
F P
s
P
p
.002 w
.39059 .58517 m .37509 .55306 L .40363 .56466 L p
1 g
F P
s
P
p
.002 w
.42655 .27757 m .36799 .31185 L .36759 .29531 L p
1 g
F P
s
P
p
.002 w
.36759 .29531 m .42345 .26246 L .42655 .27757 L p
1 g
F P
s
P
p
.002 w
.48872 .60163 m .50642 .60834 L .48946 .61907 L p
1 g
F P
s
P
p
.002 w
.48946 .61907 m .4637 .6095 L .48872 .60163 L p
1 g
F P
s
P
p
.002 w
.37234 .33255 m .32943 .37884 L .32589 .35771 L p
1 g
F P
s
P
p
.002 w
.32589 .35771 m .36799 .31185 L .37234 .33255 L p
1 g
F P
s
P
p
.002 w
.63203 .32471 m .67326 .35805 L .67278 .38405 L p
1 g
F P
s
P
p
.002 w
.67326 .35805 m .63203 .32471 L .62694 .30051 L p
1 g
F P
s
P
p
.002 w
.66717 .41215 m .68619 .44897 L .67358 .47357 L p
1 g
F P
s
P
p
.002 w
.68619 .44897 m .66717 .41215 L .67278 .38405 L p
1 g
F P
s
P
p
.002 w
.56084 .26125 m .49393 .25991 L .48772 .24564 L p
1 g
F P
s
P
p
.002 w
.42345 .26246 m .48772 .24564 L .49393 .25991 L p
1 g
F P
s
P
p
.002 w
.49393 .25991 m .42655 .27757 L .42345 .26246 L p
1 g
F P
s
P
p
.002 w
.35205 .42708 m .33116 .47453 L .31671 .45233 L p
1 g
F P
s
P
p
.002 w
.31671 .45233 m .33817 .4022 L .35205 .42708 L p
1 g
F P
s
P
p
.002 w
.58742 .58665 m .59996 .57186 L .62437 .56649 L p
1 g
F P
s
P
p
.002 w
.6336 .54307 m .62437 .56649 L .59996 .57186 L p
1 g
F P
s
P
p
.002 w
.62437 .56649 m .6336 .54307 L .65656 .52741 L p
1 g
F P
s
P
p
.002 w
.65553 .4975 m .65656 .52741 L .6336 .54307 L p
1 g
F P
s
P
p
.002 w
.65656 .52741 m .65553 .4975 L .67358 .47357 L p
1 g
F P
s
P
p
.002 w
.37582 .516 m .37509 .55306 L .35082 .53817 L p
1 g
F P
s
P
p
.002 w
.35082 .53817 m .35102 .49602 L .37582 .516 L p
1 g
F P
s
P
p
.002 w
.53449 .59288 m .54579 .59117 L .54914 .60672 L p
1 g
F P
s
P
p
.002 w
.54914 .60672 m .52726 .61007 L .53449 .59288 L p
1 g
F P
s
P
p
.002 w
.56988 .59866 m .54914 .60672 L .54579 .59117 L p
1 g
F P
s
P
p
.002 w
.47607 .59052 m .48872 .60163 L .4637 .6095 L p
1 g
F P
s
P
p
.002 w
.4637 .6095 m .44499 .59348 L .47607 .59052 L p
1 g
F P
s
P
p
.002 w
.54579 .59117 m .5565 .58699 L .56988 .59866 L p
1 g
F P
s
P
p
.002 w
.58742 .58665 m .56988 .59866 L .5565 .58699 L p
1 g
F P
s
P
p
.002 w
.56857 .281 m .62694 .30051 L .63203 .32471 L p
1 g
F P
s
P
p
.002 w
.62694 .30051 m .56857 .281 L .56084 .26125 L p
1 g
F P
s
P
p
.002 w
.52377 .59195 m .53449 .59288 L .52726 .61007 L p
1 g
F P
s
P
p
.002 w
.52726 .61007 m .50642 .60834 L .52377 .59195 L p
1 g
F P
s
P
p
.002 w
.4356 .57245 m .44499 .59348 L .41621 .59162 L p
1 g
F P
s
P
p
.002 w
.41621 .59162 m .40363 .56466 L .4356 .57245 L p
1 g
F P
s
P
p
.002 w
.49393 .25991 m .56084 .26125 L .56857 .281 L p
1 g
F P
s
P
p
.002 w
.5565 .58699 m .56551 .58078 L .58742 .58665 L p
1 g
F P
s
P
p
.002 w
.59996 .57186 m .58742 .58665 L .56551 .58078 L p
1 g
F P
s
P
p
.002 w
.6333 .35279 m .67278 .38405 L .66717 .41215 L p
1 g
F P
s
P
p
.002 w
.67278 .38405 m .6333 .35279 L .63203 .32471 L p
1 g
F P
s
P
p
.002 w
.65641 .44144 m .67358 .47357 L .65553 .4975 L p
1 g
F P
s
P
p
.002 w
.67358 .47357 m .65641 .44144 L .66717 .41215 L p
1 g
F P
s
P
p
.002 w
.38071 .35692 m .33817 .4022 L .32943 .37884 L p
1 g
F P
s
P
p
.002 w
.32943 .37884 m .37234 .33255 L .38071 .35692 L p
1 g
F P
s
P
p
.002 w
.51475 .58844 m .52377 .59195 L .50642 .60834 L p
1 g
F P
s
P
p
.002 w
.50642 .60834 m .48872 .60163 L .51475 .58844 L p
1 g
F P
s
P
p
.002 w
.43198 .29786 m .37234 .33255 L .36799 .31185 L p
1 g
F P
s
P
p
.002 w
.36799 .31185 m .42655 .27757 L .43198 .29786 L p
1 g
F P
s
P
p
.002 w
.40479 .53372 m .40363 .56466 L .37509 .55306 L p
1 g
F P
s
P
p
.002 w
.37509 .55306 m .37582 .516 L .40479 .53372 L p
1 g
F P
s
P
p
.002 w
.59996 .57186 m .60611 .55575 L .6336 .54307 L p
1 g
F P
s
P
p
.002 w
.63245 .51991 m .6336 .54307 L .60611 .55575 L p
1 g
F P
s
P
p
.002 w
.6336 .54307 m .63245 .51991 L .65553 .4975 L p
1 g
F P
s
P
p
.002 w
.37076 .45267 m .35102 .49602 L .33116 .47453 L p
1 g
F P
s
P
p
.002 w
.33116 .47453 m .35205 .42708 L .37076 .45267 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.56551 .58078 m .57187 .57316 L .59996 .57186 L p
1 g
F P
s
P
p
.002 w
.60611 .55575 m .59996 .57186 L .57187 .57316 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53185 .53923 L
s
P
p
.002 w
.46995 .57607 m .47607 .59052 L .44499 .59348 L p
1 g
F P
s
P
p
.002 w
.44499 .59348 m .4356 .57245 L .46964 .57604 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4682 .57502 L p
1 g
F P
s
P
p
.002 w
.46995 .57607 m .46964 .57604 L p
.46968 .57563 L 1 g
F P
s
P
p
.002 w
.46998 .57575 m .46995 .57607 L p
.46968 .57563 L 1 g
F P
s
P
p
.002 w
.46964 .57604 m .4356 .57245 L p
.45486 .56559 L 1 g
F P
s
P
p
.48921 .57862 m .4682 .57502 L .46998 .57575 L 1 g
F
P
p
.48921 .57862 m .46998 .57575 L .47034 .57585 L 1 g
F
P
p
.48921 .57862 m .47034 .57585 L .47751 .57766 L 1 g
F
P
p
.002 w
.46995 .57607 m .46998 .57575 L p
.47057 .57592 L 1 g
F P
s
P
p
.47034 .57585 m .47015 .57582 L .47104 .57605 L 1 g
F
P
p
.47034 .57585 m .47104 .57605 L .47751 .57766 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.47124 .55975 m .50631 .56706 L p
.47057 .57592 L 1 g
F P
s
P
p
.002 w
.46998 .57575 m .47124 .55975 L p
.47057 .57592 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50631 .56706 m .50548 .57531 L .47104 .57605 L p
1 g
F P
s
P
p
.002 w
.47104 .57605 m .46995 .57607 L p
.47057 .57592 L 1 g
F P
s
P
p
.47057 .57592 m .50631 .56706 L .47104 .57605 L 1 g
F
P
p
.47034 .57585 m .46998 .57575 L .47015 .57582 L 1 g
F
P
p
.002 w
.47607 .59052 m .46995 .57607 L .47104 .57605 L p
1 g
F P
s
P
p
.47607 .59052 m .47236 .57986 L .49332 .5816 L 1 g
F
P
p
.47236 .57986 m .47104 .57605 L .48907 .58054 L 1 g
F
P
p
.47236 .57986 m .48907 .58054 L .49332 .5816 L 1 g
F
P
p
.002 w
.50842 .5827 m .51475 .58844 L .48872 .60163 L p
1 g
F P
s
P
p
.002 w
.48872 .60163 m .47607 .59052 L .50842 .5827 L p
1 g
F P
s
P
p
.51079 .57862 m .49912 .58095 L .50787 .58131 L 1 g
F
P
p
.002 w
.51318 .58086 m .50842 .5827 L .50811 .58192 L p
1 g
F P
s
P
p
.002 w
.50811 .58192 m .50787 .58131 L p
.51097 .58105 L 1 g
F P
s
P
p
.50811 .58192 m .51097 .58105 L .51318 .58086 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58105 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .58105 L .51918 .57855 L 1 g
F
P
p
.002 w
.53655 .57323 m .51475 .58844 L p
.5172 .58297 L 1 g
F P
s
P
p
.5172 .58297 m .51918 .57855 L .53173 .57471 L 1 g
F
P
p
.5172 .58297 m .53173 .57471 L .53655 .57323 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .57471 L p
1 g
F P
s
P
p
.54854 .56129 m .53173 .57471 L .53712 .57164 L 1 g
F
P
p
.54854 .56129 m .53712 .57164 L .53853 .57083 L 1 g
F
P
p
.53128 .57265 m .51918 .57855 L .52066 .5781 L 1 g
F
P
p
.002 w
.51097 .58105 m .51079 .57862 L p
.50787 .58131 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.50842 .5827 m .47607 .59052 L p
.49491 .58078 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58054 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58054 L .49912 .58095 L 1 g
F
P
p
.002 w
.50548 .57531 m .50787 .58131 L p
.49491 .58078 L 1 g
F P
s
P
p
.002 w
.50787 .58131 m .50842 .5827 L p
.49491 .58078 L 1 g
F P
s
P
p
.44499 .59348 m .46964 .57604 L .46983 .57615 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47104 .57605 m .50548 .57531 L p
.49332 .5816 L 1 g
F P
s
P
p
.002 w
.48907 .58054 m .48889 .583 L p
.49912 .58095 L 1 g
F P
s
P
p
.002 w
.51475 .58844 m .50842 .5827 L .51318 .58086 L p
1 g
F P
s
P
p
.002 w
.51318 .58086 m .51918 .57855 L p
.51836 .58038 L 1 g
F P
s
P
p
.51475 .58844 m .51318 .58086 L .51836 .58038 L 1 g
F
P
p
.002 w
.51111 .583 m .511 .58144 L p
.49458 .5826 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .49028 .583 L p
.49458 .5826 L 1 g
F P
s
P
p
.002 w
.49028 .583 m .51111 .583 L p
.49458 .5826 L 1 g
F P
s
P
p
.002 w
.52377 .59195 m .51475 .58844 L .53655 .57323 L p
1 g
F P
s
P
p
.002 w
.53655 .57323 m .54092 .57018 L .53917 .5724 L p
1 g
F P
s
P
p
.002 w
.53917 .5724 m .52377 .59195 L p
.53655 .57323 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53174 .57475 L p
1 g
F P
s
P
p
.002 w
.53174 .57475 m .53173 .57473 L p
.53154 .57481 L 1 g
F P
s
P
p
.53154 .57481 m .51111 .583 L .53174 .57475 L 1 g
F
P
p
.002 w
.53173 .57473 m .53128 .57265 L p
.52064 .57811 L 1 g
F P
s
P
p
.52064 .57811 m .51111 .583 L .53173 .57473 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53925 .57042 m .54092 .57018 L .53712 .57164 L p
1 g
F P
s
P
p
.002 w
.54092 .57018 m .53655 .57323 L p
.53173 .57471 L 1 g
F P
s
P
p
.002 w
.51918 .57855 m .53712 .57164 L p
.53173 .57471 L 1 g
F P
s
P
p
.002 w
.53712 .57164 m .54092 .57018 L p
.53173 .57471 L 1 g
F P
s
P
p
.002 w
.54579 .59117 m .53449 .59288 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.5565 .58699 m .54579 .59117 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.56551 .58078 m .5565 .58699 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.53449 .59288 m .52377 .59195 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.57187 .57316 m .56551 .58078 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.57488 .56493 m .57187 .57316 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.57416 .55695 m .57488 .56493 L .54092 .57018 L closepath p
1 g
F P
s
P
p
.002 w
.56975 .55011 m .57416 .55695 L .54484 .56862 L p
1 g
F P
s
P
p
.002 w
.54484 .56862 m .54092 .57018 L .54703 .56592 L p
1 g
F P
s
P
p
.002 w
.54703 .56592 m .56975 .55011 L p
.54484 .56862 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54924 .56317 L p
1 g
F P
s
P
p
.56075 .54566 m .54924 .56317 L .54938 .563 L 1 g
F
P
p
.002 w
.56975 .55011 m .54703 .56592 L p
.54924 .56317 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56177 .54759 L p
1 g
F P
s
P
p
.002 w
.56316 .54586 m .56814 .54907 L p
.55827 .55643 L 1 g
F P
s
P
p
.56316 .54586 m .55827 .55643 L .56177 .54759 L 1 g
F
P
p
.56654 .52734 m .56177 .54759 L .5626 .5455 L 1 g
F
P
p
.002 w
.56319 .54352 m .58165 .51626 L p
.5626 .5455 L 1 g
F P
s
P
p
.002 w
.57166 .51371 m .58165 .51626 L .56787 .5366 L p
1 g
F P
s
P
p
.002 w
.56787 .5366 m .56319 .54352 L p
.56742 .52862 L 1 g
F P
s
P
p
.57166 .51371 m .56787 .5366 L .56742 .52862 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56742 .52862 L p
1 g
F P
s
P
p
.56515 .50826 m .56742 .52862 L .56692 .51972 L 1 g
F
P
p
.56654 .52734 m .5626 .5455 L .56319 .54352 L 1 g
F
P
p
.5643 .53962 m .56319 .54352 L .5642 .54015 L 1 g
F
P
p
.56654 .52734 m .56319 .54352 L .5643 .53962 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56975 .55011 m .5626 .5455 L p
.58165 .51626 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5665 .51239 m .57166 .51371 L p
.56737 .52778 L 1 g
F P
s
P
p
.002 w
.56319 .54352 m .56208 .54516 L p
.57166 .51371 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56619 .5095 L p
1 g
F P
s
P
p
.5695 .47661 m .56772 .5127 L .56666 .51049 L 1 g
F
P
p
.55661 .4905 m .56619 .5095 L .56334 .50353 L 1 g
F
P
p
.002 w
.55026 .47692 m .5695 .47661 L .56455 .49826 L p
1 g
F P
s
P
p
.002 w
.56455 .49826 m .56334 .50353 L p
.5573 .49123 L 1 g
F P
s
P
p
.55026 .47692 m .56455 .49826 L .5573 .49123 L 1 g
F
P
p
.55661 .4905 m .56334 .50353 L .56211 .50103 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56515 .50826 m .56692 .51972 L .5665 .51239 L 1 g
F
P
p
.002 w
.5665 .51239 m .56161 .51114 L .56334 .50353 L p
1 g
F P
s
P
p
.002 w
.56334 .50353 m .56484 .49699 L p
.56619 .5095 L 1 g
F P
s
P
p
.002 w
.56619 .5095 m .56515 .50826 L p
.5665 .51239 L 1 g
F P
s
P
p
.56619 .5095 m .5665 .51239 L .56334 .50353 L 1 g
F
P
p
.002 w
.56484 .49699 m .5695 .47661 L p
.5665 .51239 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55766 .49161 L p
1 g
F P
s
P
p
.002 w
.55766 .49161 m .55661 .4905 L p
.56253 .50182 L 1 g
F P
s
P
p
.56253 .50182 m .56713 .51061 L .55766 .49161 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5573 .49123 L p
1 g
F P
s
P
p
.54174 .47608 m .5573 .49123 L .5495 .48368 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53581 .47715 m .54265 .47704 L p
.56161 .51114 L 1 g
F P
s
P
p
.54174 .47608 m .5495 .48368 L .54265 .47704 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54265 .47704 m .53581 .47715 L .53539 .4735 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54241 .47681 L p
1 g
F P
s
P
p
.52214 .46667 m .54241 .47681 L .53539 .4735 L 1 g
F
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53539 .4735 m .53581 .47715 L p
.5167 .46624 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52238 .46707 L p
1 g
F P
s
P
p
.5 .4634 m .52238 .46707 L .50852 .46504 L 1 g
F
P
p
.49107 .45159 m .52238 .46707 L .5167 .46624 L 1 g
F
P
p
.52238 .46707 m .53539 .4735 L .5167 .46624 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48774 .45247 m .49107 .45159 L p
.5167 .46624 L 1 g
F P
s
P
p
.51369 .46579 m .5167 .46624 L .53581 .47715 L 1 g
F
P
p
.48774 .45247 m .5167 .46624 L .51369 .46579 L 1 g
F
P
p
.002 w
.5 .46379 m .5 .4634 L p
.50852 .46504 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.53581 .47715 m .50187 .48617 L .49298 .46497 L p
1 g
F P
s
P
p
.50739 .46256 m .53581 .47715 L .49298 .46497 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46401 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49298 .46497 m .50187 .48617 L p
.465 .47317 L 1 g
F P
s
P
p
.002 w
.45769 .4767 m .45826 .47608 L p
.46592 .47272 L 1 g
F P
s
P
p
.47763 .46706 m .49298 .46497 L .465 .47317 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47763 .46706 L p
1 g
F P
s
P
p
.002 w
.47763 .46706 m .47718 .46778 L p
.46592 .47272 L 1 g
F P
s
P
p
.45826 .47608 m .47763 .46706 L .46592 .47272 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.44902 .47388 m .45603 .47 L p
.465 .47317 L 1 g
F P
s
P
p
.45881 .47616 m .465 .47317 L .50187 .48617 L 1 g
F
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44902 .47388 m .465 .47317 L .45881 .47616 L 1 g
F
P
p
.45603 .47 m .47763 .46706 L .465 .47317 L 1 g
F
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.50187 .48617 m .47188 .50257 L .45408 .48022 L p
1 g
F P
s
P
p
.45836 .47605 m .50187 .48617 L .45408 .48022 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45749 .47692 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.434 .50927 m .43485 .50826 L p
.43753 .502 L 1 g
F P
s
P
p
.43128 .50227 m .4428 .49112 L .43737 .50232 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4428 .49112 L p
1 g
F P
s
P
p
.002 w
.4428 .49112 m .44166 .49233 L p
.43753 .502 L 1 g
F P
s
P
p
.43485 .50826 m .4428 .49112 L .43753 .502 L 1 g
F
P
p
.42032 .50219 m .44533 .48591 L .43128 .50227 L 1 g
F
P
p
.44339 .4905 m .45749 .47692 L .4497 .48445 L 1 g
F
P
p
.44533 .48591 m .45408 .48022 L .4428 .49112 L 1 g
F
P
p
.44533 .48591 m .4428 .49112 L .43128 .50227 L 1 g
F
P
p
.002 w
.45408 .48022 m .47188 .50257 L p
.43737 .50232 L 1 g
F P
s
P
p
.4428 .49112 m .45408 .48022 L .43737 .50232 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43366 .5123 m .42032 .50219 L p
.43477 .5023 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43382 .50949 L p
1 g
F P
s
P
p
.002 w
.40479 .53372 m .42032 .50219 L .43366 .5123 L p
1 g
F P
s
P
p
.40479 .53372 m .43366 .5123 L .43282 .52777 L 1 g
F
P
p
.002 w
.43382 .50949 m .43287 .51061 L p
.43322 .52041 L 1 g
F P
s
P
p
.43346 .52734 m .43382 .50949 L .43322 .52041 L 1 g
F
P
p
.002 w
.43181 .54613 m .40479 .53372 L p
.43264 .52781 L 1 g
F P
s
P
p
.43264 .52781 m .43282 .52777 L .43279 .52832 L 1 g
F
P
p
.43264 .52781 m .43279 .52832 L .43181 .54613 L 1 g
F
P
p
.43925 .54566 m .43561 .53846 L .4379 .5467 L 1 g
F
P
p
.002 w
.43698 .5485 m .43775 .547 L p
.43845 .54832 L 1 g
F P
s
P
p
.002 w
.43775 .547 m .4379 .5467 L p
.43821 .54761 L 1 g
F P
s
P
p
.43775 .547 m .43821 .54761 L .43845 .54832 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43821 .54761 L p
1 g
F P
s
P
p
.45146 .56129 m .43821 .54761 L .43949 .54933 L 1 g
F
P
p
.4356 .57245 m .43868 .55415 L .45364 .56602 L 1 g
F
P
p
.43868 .55415 m .43949 .54933 L .4509 .56279 L 1 g
F
P
p
.43868 .55415 m .4509 .56279 L .45364 .56602 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4509 .56279 L p
1 g
F P
s
P
p
.46872 .57265 m .4509 .56279 L .45983 .5691 L 1 g
F
P
p
.45146 .56129 m .43949 .54933 L .44452 .55526 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.4356 .57245 m .43698 .5485 L .43949 .54933 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.43949 .54933 m .47124 .55975 L p
.45364 .56602 L 1 g
F P
s
P
p
.002 w
.4509 .56279 m .45002 .56518 L p
.45983 .5691 L 1 g
F P
s
P
p
.44452 .55526 m .43949 .54933 L .44282 .55378 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44943 .52425 m .48 .54336 L p
.43845 .54832 L 1 g
F P
s
P
p
.002 w
.43821 .54761 m .43925 .54566 L p
.4379 .5467 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43698 .5485 m .43181 .54613 L p
.43622 .54065 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43279 .52832 L p
1 g
F P
s
P
p
.43925 .54566 m .43279 .52832 L .43561 .53846 L 1 g
F
P
p
.002 w
.44943 .52425 m .4379 .5467 L p
.43622 .54065 L 1 g
F P
s
P
p
.002 w
.4379 .5467 m .43698 .5485 L p
.43622 .54065 L 1 g
F P
s
P
p
.002 w
.43279 .52832 m .43346 .52734 L p
.43322 .52041 L 1 g
F P
s
P
p
.43282 .52777 m .44943 .52425 L .43181 .54613 L 1 g
F
P
p
.002 w
.43279 .52832 m .43146 .53025 L p
.43561 .53846 L 1 g
F P
s
P
p
.002 w
.4379 .5467 m .44943 .52425 L p
.43845 .54832 L 1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.48 .54336 m .47124 .55975 L .43698 .5485 L p
1 g
F P
s
P
p
.002 w
.43821 .54761 m .43743 .5491 L p
.44282 .55378 L 1 g
F P
s
P
p
.002 w
.43818 .54768 m .43821 .54761 L p
.4379 .5467 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43818 .54768 L p
1 g
F P
s
P
p
.43561 .53846 m .43146 .53025 L .43818 .54768 L 1 g
F
P
p
.002 w
.43172 .52988 m .43279 .52832 L p
.43311 .5173 L 1 g
F P
s
P
p
.43322 .52041 m .43311 .5173 L .43279 .52832 L 1 g
F
P
p
.002 w
.43366 .5123 m .44943 .52425 L p
.43282 .52777 L 1 g
F P
s
P
p
.002 w
.47188 .50257 m .44943 .52425 L .43366 .5123 L p
1 g
F P
s
P
p
.43477 .5023 m .47188 .50257 L .43366 .5123 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43172 .52988 L p
1 g
F P
s
P
p
.43311 .5173 m .43287 .51061 L .43172 .52988 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .434 .50927 L p
1 g
F P
s
P
p
.43753 .502 m .44166 .49233 L .434 .50927 L 1 g
F
P
p
.002 w
.45749 .47692 m .45698 .47747 L p
.4497 .48445 L 1 g
F P
s
P
p
.002 w
.42032 .50219 m .44902 .47388 L .45408 .48022 L p
1 g
F P
s
P
p
.002 w
.45408 .48022 m .44902 .47388 L p
.45836 .47605 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44187 .49212 L p
1 g
F P
s
P
p
.002 w
.44187 .49212 m .44339 .4905 L p
.45168 .48256 L 1 g
F P
s
P
p
.45168 .48256 m .45698 .47747 L .44187 .49212 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .4767 L p
1 g
F P
s
P
p
.46592 .47272 m .47718 .46778 L .45769 .4767 L 1 g
F
P
p
.002 w
.5 .46401 m .5 .46442 L p
.48819 .46562 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46401 L .48819 .46562 L 1 g
F
P
p
.002 w
.4773 .46759 m .47786 .46667 L p
.49045 .46539 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.45603 .47 m .48774 .45247 L .49298 .46497 L p
1 g
F P
s
P
p
.002 w
.49298 .46497 m .48774 .45247 L p
.50739 .46256 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4773 .46759 L p
1 g
F P
s
P
p
.49045 .46539 m .5 .46442 L .4773 .46759 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46379 L p
1 g
F P
s
P
p
.50852 .46504 m .52282 .46778 L .5 .46379 L 1 g
F
P
p
.002 w
.52238 .46707 m .52282 .46778 L p
.50852 .46504 L 1 g
F P
s
P
p
.53413 .47288 m .53539 .4735 L .53476 .4732 L 1 g
F
P
p
.52214 .46667 m .53539 .4735 L .53413 .47288 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.54265 .47704 m .55392 .48796 L .56161 .51114 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.49107 .45159 m .5317 .44081 L .53539 .4735 L p
1 g
F P
s
P
p
.002 w
.53539 .4735 m .53495 .46955 L p
.54241 .47681 L 1 g
F P
s
P
p
.54241 .47681 m .54265 .47704 L .53539 .4735 L 1 g
F
P
p
.002 w
.54241 .47681 m .54302 .47747 L p
.53476 .4732 L 1 g
F P
s
P
p
.002 w
.54241 .47682 m .54241 .47681 L p
.54265 .47704 L 1 g
F P
s
P
p
.002 w
.54241 .47681 m .54174 .47608 L p
.54265 .47704 L 1 g
F P
s
P
p
.002 w
.5695 .47661 m .54265 .47704 L p
.5317 .44081 L 1 g
F P
s
P
p
.002 w
.53495 .46955 m .5317 .44081 L p
.54265 .47704 L 1 g
F P
s
P
p
.002 w
.54265 .47704 m .55026 .47692 L p
.55392 .48796 L 1 g
F P
s
P
p
.002 w
.56334 .50353 m .56161 .51114 L p
.55026 .47692 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54241 .47682 L p
1 g
F P
s
P
p
.5495 .48368 m .55834 .49233 L .54241 .47682 L 1 g
F
P
p
.002 w
.5573 .49123 m .55834 .49233 L p
.5495 .48368 L 1 g
F P
s
P
p
.56211 .50103 m .56334 .50353 L .56253 .50182 L 1 g
F
P
p
.002 w
.56619 .5095 m .56713 .51061 L p
.56253 .50182 L 1 g
F P
s
P
p
.002 w
.58165 .51626 m .56772 .5127 L p
.5695 .47661 L 1 g
F P
s
P
p
.002 w
.56772 .5127 m .5665 .51239 L p
.56666 .51049 L 1 g
F P
s
P
p
.002 w
.56635 .50969 m .56619 .5095 L p
.5665 .51239 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56635 .50969 L p
1 g
F P
s
P
p
.56692 .51972 m .56854 .53025 L .56635 .50969 L 1 g
F
P
p
.002 w
.56161 .51114 m .5665 .51239 L p
.56208 .54516 L 1 g
F P
s
P
p
.5665 .51239 m .56737 .52778 L .56208 .54516 L 1 g
F
P
p
.002 w
.56742 .52862 m .56854 .53025 L p
.56692 .51972 L 1 g
F P
s
P
p
.5642 .54015 m .56319 .54352 L .56377 .54254 L 1 g
F
P
p
.56319 .54352 m .5626 .5455 L .56271 .54521 L 1 g
F
P
p
.56319 .54352 m .56271 .54521 L .56377 .54254 L 1 g
F
P
p
.002 w
.5626 .5455 m .56208 .54516 L .56319 .54352 L p
1 g
F P
s
P
p
.54854 .56129 m .53851 .57085 L .53863 .57078 L 1 g
F
P
p
.53928 .5704 m .53863 .57078 L .53925 .57043 L 1 g
F
P
p
.54854 .56129 m .53863 .57078 L .53928 .5704 L 1 g
F
P
p
.54854 .56129 m .53925 .57043 L .53963 .57019 L 1 g
F
P
p
.54854 .56129 m .5396 .57023 L .53987 .57005 L 1 g
F
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.50548 .57531 m .50631 .56706 L .53982 .57008 L p
1 g
F P
s
P
p
.002 w
.53982 .57008 m .54092 .57018 L .53925 .57042 L p
1 g
F P
s
P
p
.002 w
.53925 .57042 m .50548 .57531 L p
.53982 .57008 L 1 g
F P
s
P
p
.54854 .56129 m .53983 .5701 L .54006 .56995 L 1 g
F
P
p
.54854 .56129 m .54001 .57 L .54021 .56986 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.50631 .56706 m .51088 .55883 L .54014 .56988 L p
1 g
F P
s
P
p
.002 w
.54014 .56988 m .54092 .57018 L .53982 .57008 L p
1 g
F P
s
P
p
.002 w
.53982 .57008 m .50631 .56706 L p
.54014 .56988 L 1 g
F P
s
P
p
.53963 .57019 m .53925 .57043 L .5396 .57023 L 1 g
F
P
p
.53987 .57005 m .5396 .57023 L .53983 .5701 L 1 g
F
P
p
.54854 .56129 m .54015 .56992 L .54034 .56978 L 1 g
F
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.51088 .55883 m .51871 .55156 L .54039 .56973 L p
1 g
F P
s
P
p
.002 w
.54039 .56973 m .54092 .57018 L .54014 .56988 L p
1 g
F P
s
P
p
.002 w
.54014 .56988 m .51088 .55883 L p
.54039 .56973 L 1 g
F P
s
P
p
.54854 .56129 m .54028 .56984 L .54047 .56971 L 1 g
F
P
p
.002 w
.54062 .56957 m .54092 .57018 L .54039 .56973 L p
1 g
F P
s
P
p
.002 w
.54091 .56937 m .54092 .57018 L .54062 .56957 L p
1 g
F P
s
P
p
.002 w
.54138 .56903 m .54092 .57018 L .54091 .56937 L p
1 g
F P
s
P
p
.002 w
.54924 .56317 m .54854 .56129 L p
.5404 .56978 L 1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.51871 .55156 m .52896 .54608 L .54062 .56957 L p
1 g
F P
s
P
p
.002 w
.54039 .56973 m .51871 .55156 L p
.54062 .56957 L 1 g
F P
s
P
p
.54006 .56995 m .53983 .5701 L .54001 .57 L 1 g
F
P
p
.54021 .56986 m .54001 .57 L .54015 .56992 L 1 g
F
P
p
.002 w
.52896 .54608 m .54047 .54301 L .54091 .56937 L p
1 g
F P
s
P
p
.002 w
.54062 .56957 m .52896 .54608 L p
.54091 .56937 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54047 .54301 m .55194 .54269 L .54138 .56903 L p
1 g
F P
s
P
p
.002 w
.54091 .56937 m .54047 .54301 L p
.54138 .56903 L 1 g
F P
s
P
p
.54034 .56978 m .54015 .56992 L .54028 .56984 L 1 g
F
P
p
.54047 .56971 m .54028 .56984 L .5404 .56978 L 1 g
F
P
p
.56177 .54759 m .55827 .55643 L .54924 .56317 L 1 g
F
P
p
.002 w
.56814 .54907 m .56975 .55011 L p
.54924 .56317 L 1 g
F P
s
P
p
.56075 .54566 m .54925 .5632 L .55071 .56141 L 1 g
F
P
p
.55504 .55602 m .55071 .56141 L .5549 .55627 L 1 g
F
P
p
.56075 .54566 m .55071 .56141 L .55504 .55602 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55194 .54269 m .56208 .54516 L .54273 .56803 L p
1 g
F P
s
P
p
.002 w
.54273 .56803 m .54092 .57018 L .54138 .56903 L p
1 g
F P
s
P
p
.002 w
.54138 .56903 m .55194 .54269 L p
.54273 .56803 L 1 g
F P
s
P
p
.002 w
.56208 .54516 m .56316 .54586 L p
.5432 .56769 L 1 g
F P
s
P
p
.002 w
.54092 .57018 m .54273 .56803 L p
.5432 .56769 L 1 g
F P
s
P
p
.002 w
.54273 .56803 m .56208 .54516 L p
.5432 .56769 L 1 g
F P
s
P
p
.002 w
.54703 .56592 m .54092 .57018 L p
.56316 .54586 L 1 g
F P
s
P
p
.5404 .56978 m .5322 .57686 L .54972 .56447 L 1 g
F
P
p
.53851 .57085 m .53688 .5724 L .5404 .56978 L 1 g
F
P
p
.53688 .5724 m .5322 .57686 L .5404 .56978 L 1 g
F
P
p
.002 w
.56177 .54759 m .56257 .5491 L p
.56377 .54254 L 1 g
F P
s
P
p
.002 w
.54972 .56447 m .54924 .56317 L p
.5404 .56978 L 1 g
F P
s
P
p
.002 w
.54924 .56317 m .54925 .5632 L p
.54938 .563 L 1 g
F P
s
P
p
.002 w
.54925 .5632 m .54998 .56518 L p
.5549 .55627 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54972 .56447 L p
1 g
F P
s
P
p
.002 w
.50548 .57531 m .53925 .57042 L p
.51822 .57885 L 1 g
F P
s
P
p
.51318 .58086 m .51271 .58052 L .51822 .57885 L 1 g
F
P
p
.51271 .58052 m .50548 .57531 L .51822 .57885 L 1 g
F
P
p
.002 w
.53712 .57164 m .51318 .58086 L p
.53925 .57042 L 1 g
F P
s
P
p
.53853 .57083 m .53712 .57164 L .53851 .57085 L 1 g
F
P
p
.002 w
.53173 .57471 m .5322 .57686 L p
.53851 .57085 L 1 g
F P
s
P
p
.52066 .5781 m .51918 .57855 L .52064 .57811 L 1 g
F
P
p
.002 w
.50787 .58131 m .50548 .57531 L p
.51318 .58086 L 1 g
F P
s
P
p
.002 w
.51097 .58105 m .51111 .583 L p
.52064 .57811 L 1 g
F P
s
P
p
.002 w
.511 .58144 m .51097 .58105 L p
.50787 .58131 L 1 g
F P
s
P
p
.49912 .58095 m .48889 .583 L .511 .58144 L 1 g
F
P
p
.47751 .57766 m .47015 .57582 L .47386 .57736 L 1 g
F
P
p
.002 w
.4682 .57502 m .46872 .57265 L p
.45983 .5691 L 1 g
F P
s
P
p
.45486 .56559 m .47124 .55975 L .46964 .57604 L 1 g
F
P
p
.002 w
.46964 .57604 m .46995 .57607 L p
.46983 .57615 L 1 g
F P
s
P
p
.002 w
.4682 .57502 m .4678 .57686 L p
.47386 .57736 L 1 g
F P
s
P
p
.002 w
.47124 .55975 m .46998 .57575 L p
.46968 .57563 L 1 g
F P
s
P
p
.002 w
.46818 .57514 m .4682 .57502 L p
.45543 .56734 L 1 g
F P
s
P
p
.45983 .5691 m .45543 .56734 L .4682 .57502 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46818 .57514 L p
1 g
F P
s
P
p
.45543 .56734 m .45002 .56518 L .46818 .57514 L 1 g
F
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.56857 .281 m .50055 .27986 L .49393 .25991 L p
1 g
F P
s
P
p
.002 w
.42655 .27757 m .49393 .25991 L .50055 .27986 L p
1 g
F P
s
P
p
.002 w
.50055 .27986 m .43198 .29786 L .42655 .27757 L p
1 g
F P
s
P
p
.002 w
.64073 .47093 m .65553 .4975 L .63245 .51991 L p
1 g
F P
s
P
p
.002 w
.65553 .4975 m .64073 .47093 L .65641 .44144 L p
1 g
F P
s
P
p
.002 w
.57448 .30593 m .63203 .32471 L .6333 .35279 L p
1 g
F P
s
P
p
.002 w
.63203 .32471 m .57448 .30593 L .56857 .281 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.63055 .38391 m .66717 .41215 L .65641 .44144 L p
1 g
F P
s
P
p
.002 w
.66717 .41215 m .63055 .38391 L .6333 .35279 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.43698 .5485 m .4356 .57245 L .40363 .56466 L p
1 g
F P
s
P
p
.002 w
.40363 .56466 m .40479 .53372 L .43698 .5485 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.50055 .27986 m .56857 .281 L .57448 .30593 L p
1 g
F P
s
P
p
.002 w
.39297 .38422 m .35205 .42708 L .33817 .4022 L p
1 g
F P
s
P
p
.002 w
.33817 .4022 m .38071 .35692 L .39297 .38422 L p
1 g
F P
s
P
p
.002 w
.57187 .57316 m .57488 .56493 L .60611 .55575 L p
1 g
F P
s
P
p
.002 w
.60503 .53998 m .60611 .55575 L .57488 .56493 L p
1 g
F P
s
P
p
.002 w
.60611 .55575 m .60503 .53998 L .63245 .51991 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.39378 .47802 m .37582 .516 L .35102 .49602 L p
1 g
F P
s
P
p
.002 w
.35102 .49602 m .37076 .45267 L .39378 .47802 L p
1 g
F P
s
P
p
.004 w
.33037 .50044 m
.35274 .49122 L
s
P
p
.004 w
.35274 .49122 m
.36325 .48689 L
s
P
p
.004 w
.39132 .47532 m
.5 .43051 L
s
P
p
.004 w
.36325 .48689 m
.36434 .48644 L
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.43968 .32288 m .38071 .35692 L .37234 .33255 L p
1 g
F P
s
P
p
.002 w
.37234 .33255 m .43198 .29786 L .43968 .32288 L p
1 g
F P
s
P
p
.002 w
.62058 .49957 m .63245 .51991 L .60503 .53998 L p
1 g
F P
s
P
p
.002 w
.63245 .51991 m .62058 .49957 L .64073 .47093 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.62376 .41703 m .65641 .44144 L .64073 .47093 L p
1 g
F P
s
P
p
.002 w
.65641 .44144 m .62376 .41703 L .63055 .38391 L p
1 g
F P
s
P
p
.002 w
.57828 .33536 m .6333 .35279 L .63055 .38391 L p
1 g
F P
s
P
p
.002 w
.6333 .35279 m .57828 .33536 L .57448 .30593 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.57488 .56493 m .57416 .55695 L .60503 .53998 L p
1 g
F P
s
P
p
.002 w
.59664 .52629 m .60503 .53998 L .57416 .55695 L p
1 g
F P
s
P
p
.002 w
.60503 .53998 m .59664 .52629 L .62058 .49957 L p
1 g
F P
s
P
p
.002 w
.42032 .50219 m .40479 .53372 L .37582 .516 L p
1 g
F P
s
P
p
.002 w
.37582 .516 m .39378 .47802 L .42032 .50219 L p
1 g
F P
s
P
p
.002 w
.57448 .30593 m .50738 .30508 L .50055 .27986 L p
1 g
F P
s
P
p
.002 w
.43198 .29786 m .50055 .27986 L .50738 .30508 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.50738 .30508 m .43968 .32288 L .43198 .29786 L p
1 g
F P
s
P
p
.002 w
.40881 .41354 m .37076 .45267 L .35205 .42708 L p
1 g
F P
s
P
p
.002 w
.35205 .42708 m .39297 .38422 L .40881 .41354 L p
1 g
F P
s
P
p
.002 w
.57416 .55695 m .56975 .55011 L .59664 .52629 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.61308 .45097 m .64073 .47093 L .62058 .49957 L p
1 g
F P
s
P
p
.002 w
.64073 .47093 m .61308 .45097 L .62376 .41703 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.50738 .30508 m .57448 .30593 L .57828 .33536 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.44946 .35192 m .39297 .38422 L .38071 .35692 L p
1 g
F P
s
P
p
.002 w
.38071 .35692 m .43968 .32288 L .44946 .35192 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59887 .48447 m .62058 .49957 L .59664 .52629 L p
1 g
F P
s
P
p
.002 w
.62058 .49957 m .59887 .48447 L .61308 .45097 L p
1 g
F P
s
P
p
.002 w
.57974 .36838 m .63055 .38391 L .62376 .41703 L p
1 g
F P
s
P
p
.002 w
.63055 .38391 m .57974 .36838 L .57828 .33536 L p
1 g
F P
s
P
p
.002 w
.58165 .51626 m .59664 .52629 L .56975 .55011 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51088 .55883 m .50631 .56706 L .47124 .55975 L p
1 g
F P
s
P
p
.002 w
.59664 .52629 m .58165 .51626 L .59887 .48447 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.47124 .55975 m .48 .54336 L .51088 .55883 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42772 .44381 m .39378 .47802 L .37076 .45267 L p
1 g
F P
s
P
p
.002 w
.37076 .45267 m .40881 .41354 L .42772 .44381 L p
1 g
F P
s
P
p
.002 w
.56208 .54516 m .55194 .54269 L .56161 .51114 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51871 .55156 m .51088 .55883 L .48 .54336 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.57828 .33536 m .51417 .33488 L .50738 .30508 L p
1 g
F P
s
P
p
.002 w
.43968 .32288 m .50738 .30508 L .51417 .33488 L p
1 g
F P
s
P
p
.002 w
.57874 .40383 m .62376 .41703 L .61308 .45097 L p
1 g
F P
s
P
p
.002 w
.62376 .41703 m .57874 .40383 L .57974 .36838 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55194 .54269 m .54047 .54301 L .53876 .51164 L p
1 g
F P
s
P
p
.002 w
.53876 .51164 m .56161 .51114 L .55194 .54269 L p
1 g
F P
s
P
p
.002 w
.51417 .33488 m .44946 .35192 L .43968 .32288 L p
1 g
F P
s
P
p
.002 w
.51417 .33488 m .57828 .33536 L .57974 .36838 L p
1 g
F P
s
P
p
.002 w
.52896 .54608 m .51871 .55156 L .49541 .52878 L p
1 g
F P
s
P
p
.002 w
.48 .54336 m .49541 .52878 L .51871 .55156 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.54047 .54301 m .52896 .54608 L .51579 .51776 L p
1 g
F P
s
P
p
.002 w
.51579 .51776 m .53876 .51164 L .54047 .54301 L p
1 g
F P
s
P
p
.002 w
.49541 .52878 m .51579 .51776 L .52896 .54608 L p
1 g
F P
s
P
p
.002 w
.5695 .47661 m .59887 .48447 L .58165 .51626 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46101 .38401 m .40881 .41354 L .39297 .38422 L p
1 g
F P
s
P
p
.002 w
.39297 .38422 m .44946 .35192 L .46101 .38401 L p
1 g
F P
s
P
p
.002 w
.44902 .47388 m .42032 .50219 L .39378 .47802 L p
1 g
F P
s
P
p
.002 w
.39378 .47802 m .42772 .44381 L .44902 .47388 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.57529 .44037 m .61308 .45097 L .59887 .48447 L p
1 g
F P
s
P
p
.002 w
.61308 .45097 m .57529 .44037 L .57874 .40383 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49541 .52878 m .48 .54336 L .44943 .52425 L p
1 g
F P
s
P
p
.002 w
.59887 .48447 m .5695 .47661 L .57529 .44037 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44943 .52425 m .47188 .50257 L .49541 .52878 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.56161 .51114 m .53876 .51164 L .53581 .47715 L p
1 g
F P
s
P
p
.002 w
.52066 .36826 m .57974 .36838 L .57874 .40383 L p
1 g
F P
s
P
p
.002 w
.57974 .36838 m .52066 .36826 L .51417 .33488 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51579 .51776 m .49541 .52878 L .47188 .50257 L p
1 g
F P
s
P
p
.002 w
.44946 .35192 m .51417 .33488 L .52066 .36826 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.52066 .36826 m .46101 .38401 L .44946 .35192 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.47393 .41796 m .42772 .44381 L .40881 .41354 L p
1 g
F P
s
P
p
.002 w
.40881 .41354 m .46101 .38401 L .47393 .41796 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.53876 .51164 m .51579 .51776 L .50187 .48617 L p
1 g
F P
s
P
p
.002 w
.50187 .48617 m .53581 .47715 L .53876 .51164 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.47188 .50257 m .50187 .48617 L .51579 .51776 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5317 .44081 m .57529 .44037 L .5695 .47661 L p
1 g
F P
s
P
p
.002 w
.52658 .40403 m .57874 .40383 L .57529 .44037 L p
1 g
F P
s
P
p
.002 w
.57874 .40383 m .52658 .40403 L .52066 .36826 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57529 .44037 m .5317 .44081 L .52658 .40403 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.48774 .45247 m .44902 .47388 L .42772 .44381 L p
1 g
F P
s
P
p
.002 w
.42772 .44381 m .47393 .41796 L .48774 .45247 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.55466 .61707 m
.55764 .62723 L
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.46101 .38401 m .52066 .36826 L .52658 .40403 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.52658 .40403 m .47393 .41796 L .46101 .38401 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47393 .41796 m .52658 .40403 L .5317 .44081 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5317 .44081 m .48774 .45247 L .47393 .41796 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28254 .52016 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .56489 .65197 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.265891)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.265891)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45485 .46454 m .50239 .46753 L .50089 .43916 L p
1 g
F P
s
P
p
.002 w
.50089 .43916 m .45923 .43645 L .45485 .46454 L p
1 g
F P
s
P
p
.002 w
.54202 .43207 m .50089 .43916 L .50239 .46753 L p
1 g
F P
s
P
p
.002 w
.45923 .43645 m .50089 .43916 L .49938 .41064 L p
1 g
F P
s
P
p
.002 w
.50089 .43916 m .54202 .43207 L .53371 .40464 L p
1 g
F P
s
P
p
.002 w
.53371 .40464 m .49938 .41064 L .50089 .43916 L p
1 g
F P
s
P
p
.002 w
.49938 .41064 m .46459 .4083 L .45923 .43645 L p
1 g
F P
s
P
p
.002 w
.46459 .4083 m .49938 .41064 L .49788 .38247 L p
1 g
F P
s
P
p
.002 w
.49938 .41064 m .53371 .40464 L .52456 .37775 L p
1 g
F P
s
P
p
.002 w
.52456 .37775 m .49788 .38247 L .49938 .41064 L p
1 g
F P
s
P
p
.002 w
.45152 .49205 m .50384 .49523 L .50239 .46753 L p
1 g
F P
s
P
p
.002 w
.50239 .46753 m .45485 .46454 L .45152 .49205 L p
1 g
F P
s
P
p
.002 w
.54933 .45954 m .50239 .46753 L .50384 .49523 L p
1 g
F P
s
P
p
.002 w
.50239 .46753 m .54933 .45954 L .54202 .43207 L p
1 g
F P
s
P
p
.002 w
.41087 .45073 m .45485 .46454 L .45923 .43645 L p
1 g
F P
s
P
p
.002 w
.45923 .43645 m .4208 .4241 L .41087 .45073 L p
1 g
F P
s
P
p
.002 w
.4208 .4241 m .45923 .43645 L .46459 .4083 L p
1 g
F P
s
P
p
.002 w
.46459 .4083 m .43259 .39778 L .4208 .4241 L p
1 g
F P
s
P
p
.002 w
.43259 .39778 m .46459 .4083 L .47083 .3806 L p
1 g
F P
s
P
p
.002 w
.49788 .38247 m .47083 .3806 L .46459 .4083 L p
1 g
F P
s
P
p
.002 w
.57889 .41572 m .54202 .43207 L .54933 .45954 L p
1 g
F P
s
P
p
.002 w
.54202 .43207 m .57889 .41572 L .56438 .39079 L p
1 g
F P
s
P
p
.002 w
.56438 .39079 m .53371 .40464 L .54202 .43207 L p
1 g
F P
s
P
p
.002 w
.53371 .40464 m .56438 .39079 L .5483 .36684 L p
1 g
F P
s
P
p
.002 w
.5483 .36684 m .52456 .37775 L .53371 .40464 L p
1 g
F P
s
P
p
.002 w
.47083 .3806 m .49788 .38247 L .49641 .35517 L p
1 g
F P
s
P
p
.002 w
.49788 .38247 m .52456 .37775 L .51472 .35189 L p
1 g
F P
s
P
p
.002 w
.51472 .35189 m .49641 .35517 L .49788 .38247 L p
1 g
F P
s
P
p
.002 w
.40304 .47716 m .45152 .49205 L .45485 .46454 L p
1 g
F P
s
P
p
.002 w
.45485 .46454 m .41087 .45073 L .40304 .47716 L p
1 g
F P
s
P
p
.002 w
.50384 .49523 m .5555 .48656 L .54933 .45954 L p
1 g
F P
s
P
p
.002 w
.59155 .44116 m .54933 .45954 L .5555 .48656 L p
1 g
F P
s
P
p
.002 w
.54933 .45954 m .59155 .44116 L .57889 .41572 L p
1 g
F P
s
P
p
.002 w
.47083 .3806 m .44604 .37226 L .43259 .39778 L p
1 g
F P
s
P
p
.002 w
.44604 .37226 m .47083 .3806 L .47784 .35385 L p
1 g
F P
s
P
p
.002 w
.49641 .35517 m .47784 .35385 L .47083 .3806 L p
1 g
F P
s
P
p
.002 w
.52456 .37775 m .5483 .36684 L .53095 .34431 L p
1 g
F P
s
P
p
.002 w
.53095 .34431 m .51472 .35189 L .52456 .37775 L p
1 g
F P
s
P
p
.002 w
.44934 .51847 m .50521 .52174 L .50384 .49523 L p
1 g
F P
s
P
p
.002 w
.50384 .49523 m .45152 .49205 L .44934 .51847 L p
1 g
F P
s
P
p
.002 w
.5555 .48656 m .50384 .49523 L .50521 .52174 L p
1 g
F P
s
P
p
.002 w
.38925 .40299 m .4208 .4241 L .43259 .39778 L p
1 g
F P
s
P
p
.002 w
.43259 .39778 m .40651 .3799 L .38925 .40299 L p
1 g
F P
s
P
p
.002 w
.40651 .3799 m .43259 .39778 L .44604 .37226 L p
1 g
F P
s
P
p
.002 w
.47784 .35385 m .49641 .35517 L .495 .32927 L p
1 g
F P
s
P
p
.002 w
.49641 .35517 m .51472 .35189 L .50437 .32757 L p
1 g
F P
s
P
p
.002 w
.50437 .32757 m .495 .32927 L .49641 .35517 L p
1 g
F P
s
P
p
.002 w
.58836 .37025 m .56438 .39079 L .57889 .41572 L p
1 g
F P
s
P
p
.002 w
.56438 .39079 m .58836 .37025 L .5667 .35071 L p
1 g
F P
s
P
p
.002 w
.5667 .35071 m .5483 .36684 L .56438 .39079 L p
1 g
F P
s
P
p
.002 w
.39748 .50289 m .44934 .51847 L .45152 .49205 L p
1 g
F P
s
P
p
.002 w
.45152 .49205 m .40304 .47716 L .39748 .50289 L p
1 g
F P
s
P
p
.002 w
.50521 .52174 m .5604 .5126 L .5555 .48656 L p
1 g
F P
s
P
p
.002 w
.60209 .46664 m .5555 .48656 L .5604 .5126 L p
1 g
F P
s
P
p
.002 w
.5555 .48656 m .60209 .46664 L .59155 .44116 L p
1 g
F P
s
P
p
.002 w
.44604 .37226 m .42598 .35818 L .40651 .3799 L p
1 g
F P
s
P
p
.002 w
.42598 .35818 m .44604 .37226 L .46088 .34803 L p
1 g
F P
s
P
p
.002 w
.47784 .35385 m .46088 .34803 L .44604 .37226 L p
1 g
F P
s
P
p
.002 w
.37458 .427 m .41087 .45073 L .4208 .4241 L p
1 g
F P
s
P
p
.002 w
.4208 .4241 m .38925 .40299 L .37458 .427 L p
1 g
F P
s
P
p
.002 w
.46088 .34803 m .47784 .35385 L .4855 .32857 L p
1 g
F P
s
P
p
.002 w
.495 .32927 m .4855 .32857 L .47784 .35385 L p
1 g
F P
s
P
p
.002 w
.5483 .36684 m .5667 .35071 L .5434 .33314 L p
1 g
F P
s
P
p
.002 w
.5434 .33314 m .53095 .34431 L .5483 .36684 L p
1 g
F P
s
P
p
.002 w
.51472 .35189 m .53095 .34431 L .51263 .32365 L p
1 g
F P
s
P
p
.002 w
.51263 .32365 m .50437 .32757 L .51472 .35189 L p
1 g
F P
s
P
p
.002 w
.60794 .39139 m .57889 .41572 L .59155 .44116 L p
1 g
F P
s
P
p
.002 w
.57889 .41572 m .60794 .39139 L .58836 .37025 L p
1 g
F P
s
P
p
.002 w
.46088 .34803 m .44728 .33825 L .42598 .35818 L p
1 g
F P
s
P
p
.002 w
.44728 .33825 m .46088 .34803 L .47686 .32555 L p
1 g
F P
s
P
p
.002 w
.4855 .32857 m .47686 .32555 L .46088 .34803 L p
1 g
F P
s
P
p
.002 w
.44838 .54324 m .50649 .54654 L .50521 .52174 L p
1 g
F P
s
P
p
.002 w
.50521 .52174 m .44934 .51847 L .44838 .54324 L p
1 g
F P
s
P
p
.002 w
.5604 .5126 m .50521 .52174 L .50649 .54654 L p
1 g
F P
s
P
p
.002 w
.36283 .45148 m .40304 .47716 L .41087 .45073 L p
1 g
F P
s
P
p
.002 w
.41087 .45073 m .37458 .427 L .36283 .45148 L p
1 g
F P
s
P
p
.002 w
.53095 .34431 m .5434 .33314 L .51891 .3179 L p
1 g
F P
s
P
p
.002 w
.51891 .3179 m .51263 .32365 L .53095 .34431 L p
1 g
F P
s
P
p
.002 w
.62504 .41373 m .59155 .44116 L .60209 .46664 L p
1 g
F P
s
P
p
.002 w
.59155 .44116 m .62504 .41373 L .60794 .39139 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .4855 .32857 L .495 .32927 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .495 .32927 L .50437 .32757 L closepath p
1 g
F P
s
P
p
.002 w
.3944 .52735 m .44838 .54324 L .44934 .51847 L p
1 g
F P
s
P
p
.002 w
.44934 .51847 m .39748 .50289 L .3944 .52735 L p
1 g
F P
s
P
p
.002 w
.50649 .54654 m .5639 .53714 L .5604 .5126 L p
1 g
F P
s
P
p
.002 w
.61027 .49164 m .5604 .5126 L .5639 .53714 L p
1 g
F P
s
P
p
.002 w
.5604 .5126 m .61027 .49164 L .60209 .46664 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .47686 .32555 L .4855 .32857 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .50437 .32757 L .51263 .32365 L closepath p
1 g
F P
s
P
p
.002 w
.38915 .35616 m .40651 .3799 L .42598 .35818 L p
1 g
F P
s
P
p
.002 w
.42598 .35818 m .41283 .33962 L .38915 .35616 L p
1 g
F P
s
P
p
.002 w
.41283 .33962 m .42598 .35818 L .44728 .33825 L p
1 g
F P
s
P
p
.002 w
.57775 .33085 m .5667 .35071 L .58836 .37025 L p
1 g
F P
s
P
p
.002 w
.5667 .35071 m .57775 .33085 L .55072 .31949 L p
1 g
F P
s
P
p
.002 w
.55072 .31949 m .5434 .33314 L .5667 .35071 L p
1 g
F P
s
P
p
.002 w
.44728 .33825 m .4385 .32545 L .41283 .33962 L p
1 g
F P
s
P
p
.002 w
.4385 .32545 m .44728 .33825 L .46999 .3205 L p
1 g
F P
s
P
p
.002 w
.47686 .32555 m .46999 .3205 L .44728 .33825 L p
1 g
F P
s
P
p
.002 w
.36798 .37479 m .38925 .40299 L .40651 .3799 L p
1 g
F P
s
P
p
.002 w
.40651 .3799 m .38915 .35616 L .36798 .37479 L p
1 g
F P
s
P
p
.002 w
.5434 .33314 m .55072 .31949 L .52252 .31091 L p
1 g
F P
s
P
p
.002 w
.52252 .31091 m .51891 .3179 L .5434 .33314 L p
1 g
F P
s
P
p
.002 w
.60302 .34481 m .58836 .37025 L .60794 .39139 L p
1 g
F P
s
P
p
.002 w
.58836 .37025 m .60302 .34481 L .57775 .33085 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .46999 .3205 L .47686 .32555 L closepath p
1 g
F P
s
P
p
.002 w
.35434 .47591 m .39748 .50289 L .40304 .47716 L p
1 g
F P
s
P
p
.002 w
.40304 .47716 m .36283 .45148 L .35434 .47591 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .51263 .32365 L .51891 .3179 L closepath p
1 g
F P
s
P
p
.002 w
.63926 .43684 m .60209 .46664 L .61027 .49164 L p
1 g
F P
s
P
p
.002 w
.60209 .46664 m .63926 .43684 L .62504 .41373 L p
1 g
F P
s
P
p
.002 w
.46999 .3205 m .46564 .31394 L .4385 .32545 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .46564 .31394 L .46999 .3205 L closepath p
1 g
F P
s
P
p
.002 w
.34983 .39514 m .37458 .427 L .38925 .40299 L p
1 g
F P
s
P
p
.002 w
.38925 .40299 m .36798 .37479 L .34983 .39514 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .51891 .3179 L .52252 .31091 L closepath p
1 g
F P
s
P
p
.002 w
.62601 .3611 m .60794 .39139 L .62504 .41373 L p
1 g
F P
s
P
p
.002 w
.60794 .39139 m .62601 .3611 L .60302 .34481 L p
1 g
F P
s
P
p
.002 w
.44869 .56582 m .50763 .56906 L .50649 .54654 L p
1 g
F P
s
P
p
.002 w
.50649 .54654 m .44838 .54324 L .44869 .56582 L p
1 g
F P
s
P
p
.002 w
.5639 .53714 m .50649 .54654 L .50763 .56906 L p
1 g
F P
s
P
p
.002 w
.4356 .31092 m .4385 .32545 L .46564 .31394 L p
1 g
F P
s
P
p
.002 w
.46564 .31394 m .4643 .30655 L .4356 .31092 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .4643 .30655 L .46564 .31394 L closepath p
1 g
F P
s
P
p
.002 w
.52304 .30343 m .52252 .31091 L .55072 .31949 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .52252 .31091 L .52304 .30343 L closepath p
1 g
F P
s
P
p
.002 w
.4082 .31836 m .41283 .33962 L .4385 .32545 L p
1 g
F P
s
P
p
.002 w
.4385 .32545 m .4356 .31092 L .4082 .31836 L p
1 g
F P
s
P
p
.002 w
.55201 .30473 m .55072 .31949 L .57775 .33085 L p
1 g
F P
s
P
p
.002 w
.55072 .31949 m .55201 .30473 L .52304 .30343 L p
1 g
F P
s
P
p
.002 w
.39393 .55 m .44869 .56582 L .44838 .54324 L p
1 g
F P
s
P
p
.002 w
.44838 .54324 m .3944 .52735 L .39393 .55 L p
1 g
F P
s
P
p
.002 w
.50763 .56906 m .56588 .55964 L .5639 .53714 L p
1 g
F P
s
P
p
.002 w
.61584 .51566 m .5639 .53714 L .56588 .55964 L p
1 g
F P
s
P
p
.002 w
.5639 .53714 m .61584 .51566 L .61027 .49164 L p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .46616 .29914 L .4643 .30655 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .52304 .30343 L .52037 .29625 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .47105 .2925 L .46616 .29914 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .52037 .29625 L .51478 .29018 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .51478 .29018 L .50684 .28589 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .50684 .28589 L .49743 .28389 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .49743 .28389 L .48761 .28441 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .48761 .28441 L .47847 .2874 L closepath p
1 g
F P
s
P
p
.002 w
.49369 .30531 m .47847 .2874 L .47105 .2925 L closepath p
1 g
F P
s
P
p
.002 w
.33518 .41682 m .36283 .45148 L .37458 .427 L p
1 g
F P
s
P
p
.002 w
.37458 .427 m .34983 .39514 L .33518 .41682 L p
1 g
F P
s
P
p
.002 w
.3494 .49977 m .3944 .52735 L .39748 .50289 L p
1 g
F P
s
P
p
.002 w
.39748 .50289 m .35434 .47591 L .3494 .49977 L p
1 g
F P
s
P
p
.002 w
.38272 .32878 m .38915 .35616 L .41283 .33962 L p
1 g
F P
s
P
p
.002 w
.41283 .33962 m .4082 .31836 L .38272 .32878 L p
1 g
F P
s
P
p
.002 w
.65022 .46026 m .61027 .49164 L .61584 .51566 L p
1 g
F P
s
P
p
.002 w
.61027 .49164 m .65022 .46026 L .63926 .43684 L p
1 g
F P
s
P
p
.002 w
.64616 .37942 m .62504 .41373 L .63926 .43684 L p
1 g
F P
s
P
p
.002 w
.62504 .41373 m .64616 .37942 L .62601 .3611 L p
1 g
F P
s
P
p
.002 w
.58001 .30923 m .57775 .33085 L .60302 .34481 L p
1 g
F P
s
P
p
.002 w
.57775 .33085 m .58001 .30923 L .55201 .30473 L p
1 g
F P
s
P
p
.002 w
.43905 .2962 m .4356 .31092 L .4643 .30655 L p
1 g
F P
s
P
p
.002 w
.4643 .30655 m .46616 .29914 L .43905 .2962 L p
1 g
F P
s
P
p
.002 w
.52037 .29625 m .52304 .30343 L .55201 .30473 L p
1 g
F P
s
P
p
.002 w
.35975 .34202 m .36798 .37479 L .38915 .35616 L p
1 g
F P
s
P
p
.002 w
.38915 .35616 m .38272 .32878 L .35975 .34202 L p
1 g
F P
s
P
p
.002 w
.60641 .31689 m .60302 .34481 L .62601 .3611 L p
1 g
F P
s
P
p
.002 w
.60302 .34481 m .60641 .31689 L .58001 .30923 L p
1 g
F P
s
P
p
.002 w
.44862 .28292 m .43905 .2962 L .46616 .29914 L p
1 g
F P
s
P
p
.002 w
.46616 .29914 m .47105 .2925 L .44862 .28292 L p
1 g
F P
s
P
p
.002 w
.55201 .30473 m .54697 .29045 L .52037 .29625 L p
1 g
F P
s
P
p
.002 w
.51478 .29018 m .52037 .29625 L .54697 .29045 L p
1 g
F P
s
P
p
.002 w
.41295 .29664 m .4082 .31836 L .4356 .31092 L p
1 g
F P
s
P
p
.002 w
.4356 .31092 m .43905 .2962 L .41295 .29664 L p
1 g
F P
s
P
p
.002 w
.54697 .29045 m .55201 .30473 L .58001 .30923 L p
1 g
F P
s
P
p
.002 w
.32447 .43938 m .35434 .47591 L .36283 .45148 L p
1 g
F P
s
P
p
.002 w
.36283 .45148 m .33518 .41682 L .32447 .43938 L p
1 g
F P
s
P
p
.002 w
.45033 .58562 m .50861 .58874 L .50763 .56906 L p
1 g
F P
s
P
p
.002 w
.50763 .56906 m .44869 .56582 L .45033 .58562 L p
1 g
F P
s
P
p
.002 w
.56588 .55964 m .50763 .56906 L .50861 .58874 L p
1 g
F P
s
P
p
.002 w
.66296 .39945 m .63926 .43684 L .65022 .46026 L p
1 g
F P
s
P
p
.002 w
.63926 .43684 m .66296 .39945 L .64616 .37942 L p
1 g
F P
s
P
p
.002 w
.46336 .27264 m .44862 .28292 L .47105 .2925 L p
1 g
F P
s
P
p
.002 w
.47105 .2925 m .47847 .2874 L .46336 .27264 L p
1 g
F P
s
P
p
.002 w
.54697 .29045 m .53599 .27827 L .51478 .29018 L p
1 g
F P
s
P
p
.002 w
.50684 .28589 m .51478 .29018 L .53599 .27827 L p
1 g
F P
s
P
p
.002 w
.34825 .52249 m .39393 .55 L .3944 .52735 L p
1 g
F P
s
P
p
.002 w
.3944 .52735 m .3494 .49977 L .34825 .52249 L p
1 g
F P
s
P
p
.002 w
.33991 .35789 m .34983 .39514 L .36798 .37479 L p
1 g
F P
s
P
p
.002 w
.36798 .37479 m .35975 .34202 L .33991 .35789 L p
1 g
F P
s
P
p
.002 w
.56588 .55964 m .6186 .53815 L .61584 .51566 L p
1 g
F P
s
P
p
.002 w
.65757 .48348 m .61584 .51566 L .6186 .53815 L p
1 g
F P
s
P
p
.002 w
.61584 .51566 m .65757 .48348 L .65022 .46026 L p
1 g
F P
s
P
p
.002 w
.63059 .32764 m .62601 .3611 L .64616 .37942 L p
1 g
F P
s
P
p
.002 w
.62601 .3611 m .63059 .32764 L .60641 .31689 L p
1 g
F P
s
P
p
.002 w
.39621 .57025 m .45033 .58562 L .44869 .56582 L p
1 g
F P
s
P
p
.002 w
.44869 .56582 m .39393 .55 L .39621 .57025 L p
1 g
F P
s
P
p
.002 w
.48164 .2666 m .46336 .27264 L .47847 .2874 L p
1 g
F P
s
P
p
.002 w
.47847 .2874 m .48761 .28441 L .48164 .2666 L p
1 g
F P
s
P
p
.002 w
.53599 .27827 m .5202 .26961 L .50684 .28589 L p
1 g
F P
s
P
p
.002 w
.49743 .28389 m .50684 .28589 L .5202 .26961 L p
1 g
F P
s
P
p
.002 w
.38848 .30056 m .38272 .32878 L .4082 .31836 L p
1 g
F P
s
P
p
.002 w
.4082 .31836 m .41295 .29664 L .38848 .30056 L p
1 g
F P
s
P
p
.002 w
.50861 .58874 m .56622 .57951 L .56588 .55964 L p
1 g
F P
s
P
p
.002 w
.6186 .53815 m .56588 .55964 L .56622 .57951 L p
1 g
F P
s
P
p
.002 w
.5729 .28813 m .58001 .30923 L .60641 .31689 L p
1 g
F P
s
P
p
.002 w
.58001 .30923 m .5729 .28813 L .54697 .29045 L p
1 g
F P
s
P
p
.002 w
.50136 .26555 m .48164 .2666 L .48761 .28441 L p
1 g
F P
s
P
p
.002 w
.48761 .28441 m .49743 .28389 L .50136 .26555 L p
1 g
F P
s
P
p
.002 w
.5202 .26961 m .50136 .26555 L .49743 .28389 L p
1 g
F P
s
P
p
.002 w
.42689 .27689 m .41295 .29664 L .43905 .2962 L p
1 g
F P
s
P
p
.002 w
.43905 .2962 m .44862 .28292 L .42689 .27689 L p
1 g
F P
s
P
p
.002 w
.53599 .27827 m .54697 .29045 L .5729 .28813 L p
1 g
F P
s
P
p
.002 w
.31812 .46232 m .3494 .49977 L .35434 .47591 L p
1 g
F P
s
P
p
.002 w
.35434 .47591 m .32447 .43938 L .31812 .46232 L p
1 g
F P
s
P
p
.002 w
.67591 .42077 m .65022 .46026 L .65757 .48348 L p
1 g
F P
s
P
p
.002 w
.65022 .46026 m .67591 .42077 L .66296 .39945 L p
1 g
F P
s
P
p
.002 w
.32378 .37609 m .33518 .41682 L .34983 .39514 L p
1 g
F P
s
P
p
.002 w
.34983 .39514 m .33991 .35789 L .32378 .37609 L p
1 g
F P
s
P
p
.002 w
.65193 .34132 m .64616 .37942 L .66296 .39945 L p
1 g
F P
s
P
p
.002 w
.64616 .37942 m .65193 .34132 L .63059 .32764 L p
1 g
F P
s
P
p
.002 w
.36628 .30801 m .35975 .34202 L .38272 .32878 L p
1 g
F P
s
P
p
.002 w
.38272 .32878 m .38848 .30056 L .36628 .30801 L p
1 g
F P
s
P
p
.002 w
.59757 .28944 m .60641 .31689 L .63059 .32764 L p
1 g
F P
s
P
p
.002 w
.60641 .31689 m .59757 .28944 L .5729 .28813 L p
1 g
F P
s
P
p
.002 w
.44869 .26151 m .42689 .27689 L .44862 .28292 L p
1 g
F P
s
P
p
.002 w
.44862 .28292 m .46336 .27264 L .44869 .26151 L p
1 g
F P
s
P
p
.002 w
.5729 .28813 m .55686 .26997 L .53599 .27827 L p
1 g
F P
s
P
p
.002 w
.5202 .26961 m .53599 .27827 L .55686 .26997 L p
1 g
F P
s
P
p
.002 w
.45334 .60207 m .50941 .60501 L .50861 .58874 L p
1 g
F P
s
P
p
.002 w
.50861 .58874 m .45033 .58562 L .45334 .60207 L p
1 g
F P
s
P
p
.002 w
.56622 .57951 m .50861 .58874 L .50941 .60501 L p
1 g
F P
s
P
p
.002 w
.4064 .27472 m .38848 .30056 L .41295 .29664 L p
1 g
F P
s
P
p
.002 w
.41295 .29664 m .42689 .27689 L .4064 .27472 L p
1 g
F P
s
P
p
.002 w
.3511 .54348 m .39621 .57025 L .39393 .55 L p
1 g
F P
s
P
p
.002 w
.39393 .55 m .34825 .52249 L .3511 .54348 L p
1 g
F P
s
P
p
.002 w
.55686 .26997 m .5729 .28813 L .59757 .28944 L p
1 g
F P
s
P
p
.002 w
.56622 .57951 m .61835 .55853 L .6186 .53815 L p
1 g
F P
s
P
p
.002 w
.66101 .50597 m .6186 .53815 L .61835 .55853 L p
1 g
F P
s
P
p
.002 w
.6186 .53815 m .66101 .50597 L .65757 .48348 L p
1 g
F P
s
P
p
.002 w
.47594 .25244 m .44869 .26151 L .46336 .27264 L p
1 g
F P
s
P
p
.002 w
.46336 .27264 m .48164 .2666 L .47594 .25244 L p
1 g
F P
s
P
p
.002 w
.55686 .26997 m .53349 .25699 L .5202 .26961 L p
1 g
F P
s
P
p
.002 w
.50136 .26555 m .5202 .26961 L .53349 .25699 L p
1 g
F P
s
P
p
.002 w
.40132 .5875 m .45334 .60207 L .45033 .58562 L p
1 g
F P
s
P
p
.002 w
.45033 .58562 m .39621 .57025 L .40132 .5875 L p
1 g
F P
s
P
p
.002 w
.50941 .60501 m .56484 .5962 L .56622 .57951 L p
1 g
F P
s
P
p
.002 w
.61835 .55853 m .56622 .57951 L .56484 .5962 L p
1 g
F P
s
P
p
.002 w
.5054 .25087 m .47594 .25244 L .48164 .2666 L p
1 g
F P
s
P
p
.002 w
.48164 .2666 m .50136 .26555 L .5054 .25087 L p
1 g
F P
s
P
p
.002 w
.53349 .25699 m .5054 .25087 L .50136 .26555 L p
1 g
F P
s
P
p
.002 w
.31192 .39628 m .32447 .43938 L .33518 .41682 L p
1 g
F P
s
P
p
.002 w
.33518 .41682 m .32378 .37609 L .31192 .39628 L p
1 g
F P
s
P
p
.002 w
.31646 .48509 m .34825 .52249 L .3494 .49977 L p
1 g
F P
s
P
p
.002 w
.3494 .49977 m .31812 .46232 L .31646 .48509 L p
1 g
F P
s
P
p
.002 w
.34697 .31897 m .33991 .35789 L .35975 .34202 L p
1 g
F P
s
P
p
.002 w
.35975 .34202 m .36628 .30801 L .34697 .31897 L p
1 g
F P
s
P
p
.002 w
.66981 .35773 m .66296 .39945 L .67591 .42077 L p
1 g
F P
s
P
p
.002 w
.66296 .39945 m .66981 .35773 L .65193 .34132 L p
1 g
F P
s
P
p
.002 w
.68456 .44293 m .65757 .48348 L .66101 .50597 L p
1 g
F P
s
P
p
.002 w
.65757 .48348 m .68456 .44293 L .67591 .42077 L p
1 g
F P
s
P
p
.002 w
.62035 .2945 m .63059 .32764 L .65193 .34132 L p
1 g
F P
s
P
p
.002 w
.63059 .32764 m .62035 .2945 L .59757 .28944 L p
1 g
F P
s
P
p
.002 w
.43484 .25446 m .4064 .27472 L .42689 .27689 L p
1 g
F P
s
P
p
.002 w
.42689 .27689 m .44869 .26151 L .43484 .25446 L p
1 g
F P
s
P
p
.002 w
.59757 .28944 m .5769 .26564 L .55686 .26997 L p
1 g
F P
s
P
p
.002 w
.53349 .25699 m .55686 .26997 L .5769 .26564 L p
1 g
F P
s
P
p
.002 w
.38771 .27665 m .36628 .30801 L .38848 .30056 L p
1 g
F P
s
P
p
.002 w
.38848 .30056 m .4064 .27472 L .38771 .27665 L p
1 g
F P
s
P
p
.002 w
.5769 .26564 m .59757 .28944 L .62035 .2945 L p
1 g
F P
s
P
p
.002 w
.35808 .56212 m .40132 .5875 L .39621 .57025 L p
1 g
F P
s
P
p
.002 w
.39621 .57025 m .3511 .54348 L .35808 .56212 L p
1 g
F P
s
P
p
.002 w
.56484 .5962 m .61496 .57624 L .61835 .55853 L p
1 g
F P
s
P
p
.002 w
.66027 .52716 m .61835 .55853 L .61496 .57624 L p
1 g
F P
s
P
p
.002 w
.61835 .55853 m .66027 .52716 L .66101 .50597 L p
1 g
F P
s
P
p
.002 w
.4577 .61458 m .50999 .61727 L .50941 .60501 L p
1 g
F P
s
P
p
.002 w
.50941 .60501 m .45334 .60207 L .4577 .61458 L p
1 g
F P
s
P
p
.002 w
.56484 .5962 m .50941 .60501 L .50999 .61727 L p
1 g
F P
s
P
p
.002 w
.30482 .41802 m .31812 .46232 L .32447 .43938 L p
1 g
F P
s
P
p
.002 w
.32447 .43938 m .31192 .39628 L .30482 .41802 L p
1 g
F P
s
P
p
.002 w
.3312 .3333 m .32378 .37609 L .33991 .35789 L p
1 g
F P
s
P
p
.002 w
.33991 .35789 m .34697 .31897 L .3312 .3333 L p
1 g
F P
s
P
p
.002 w
.64061 .30335 m .65193 .34132 L .66981 .35773 L p
1 g
F P
s
P
p
.002 w
.65193 .34132 m .64061 .30335 L .62035 .2945 L p
1 g
F P
s
P
p
.002 w
.68364 .37656 m .67591 .42077 L .68456 .44293 L p
1 g
F P
s
P
p
.002 w
.67591 .42077 m .68364 .37656 L .66981 .35773 L p
1 g
F P
s
P
p
.002 w
.47065 .24247 m .43484 .25446 L .44869 .26151 L p
1 g
F P
s
P
p
.002 w
.44869 .26151 m .47594 .25244 L .47065 .24247 L p
1 g
F P
s
P
p
.002 w
.5769 .26564 m .54638 .24852 L .53349 .25699 L p
1 g
F P
s
P
p
.002 w
.5054 .25087 m .53349 .25699 L .54638 .24852 L p
1 g
F P
s
P
p
.002 w
.31977 .50708 m .3511 .54348 L .34825 .52249 L p
1 g
F P
s
P
p
.002 w
.34825 .52249 m .31646 .48509 L .31977 .50708 L p
1 g
F P
s
P
p
.002 w
.40929 .60115 m .4577 .61458 L .45334 .60207 L p
1 g
F P
s
P
p
.002 w
.45334 .60207 m .40132 .5875 L .40929 .60115 L p
1 g
F P
s
P
p
.002 w
.6885 .46541 m .66101 .50597 L .66027 .52716 L p
1 g
F P
s
P
p
.002 w
.66101 .50597 m .6885 .46541 L .68456 .44293 L p
1 g
F P
s
P
p
.002 w
.50999 .61727 m .56168 .60911 L .56484 .5962 L p
1 g
F P
s
P
p
.002 w
.61496 .57624 m .56484 .5962 L .56168 .60911 L p
1 g
F P
s
P
p
.002 w
.50945 .24041 m .47065 .24247 L .47594 .25244 L p
1 g
F P
s
P
p
.002 w
.47594 .25244 m .5054 .25087 L .50945 .24041 L p
1 g
F P
s
P
p
.002 w
.54638 .24852 m .50945 .24041 L .5054 .25087 L p
1 g
F P
s
P
p
.002 w
.3714 .28285 m .34697 .31897 L .36628 .30801 L p
1 g
F P
s
P
p
.002 w
.36628 .30801 m .38771 .27665 L .3714 .28285 L p
1 g
F P
s
P
p
.002 w
.59558 .26558 m .62035 .2945 L .64061 .30335 L p
1 g
F P
s
P
p
.002 w
.62035 .2945 m .59558 .26558 L .5769 .26564 L p
1 g
F P
s
P
p
.002 w
.42222 .25192 m .38771 .27665 L .4064 .27472 L p
1 g
F P
s
P
p
.002 w
.4064 .27472 m .43484 .25446 L .42222 .25192 L p
1 g
F P
s
P
p
.002 w
.54638 .24852 m .5769 .26564 L .59558 .26558 L p
1 g
F P
s
P
p
.002 w
.31956 .3508 m .31192 .39628 L .32378 .37609 L p
1 g
F P
s
P
p
.002 w
.32378 .37609 m .3312 .3333 L .31956 .3508 L p
1 g
F P
s
P
p
.002 w
.30291 .44078 m .31646 .48509 L .31812 .46232 L p
1 g
F P
s
P
p
.002 w
.31812 .46232 m .30482 .41802 L .30291 .44078 L p
1 g
F P
s
P
p
.002 w
.6577 .31595 m .66981 .35773 L .68364 .37656 L p
1 g
F P
s
P
p
.002 w
.66981 .35773 m .6577 .31595 L .64061 .30335 L p
1 g
F P
s
P
p
.002 w
.69289 .39745 m .68456 .44293 L .6885 .46541 L p
1 g
F P
s
P
p
.002 w
.68456 .44293 m .69289 .39745 L .68364 .37656 L p
1 g
F P
s
P
p
.002 w
.36921 .5778 m .40929 .60115 L .40132 .5875 L p
1 g
F P
s
P
p
.002 w
.40132 .5875 m .35808 .56212 L .36921 .5778 L p
1 g
F P
s
P
p
.002 w
.56168 .60911 m .60833 .59066 L .61496 .57624 L p
1 g
F P
s
P
p
.002 w
.65517 .54645 m .61496 .57624 L .60833 .59066 L p
1 g
F P
s
P
p
.002 w
.61496 .57624 m .65517 .54645 L .66027 .52716 L p
1 g
F P
s
P
p
.002 w
.32818 .52766 m .35808 .56212 L .3511 .54348 L p
1 g
F P
s
P
p
.002 w
.3511 .54348 m .31977 .50708 L .32818 .52766 L p
1 g
F P
s
P
p
.002 w
.4634 .62259 m .51032 .62498 L .50999 .61727 L p
1 g
F P
s
P
p
.002 w
.50999 .61727 m .4577 .61458 L .4634 .62259 L p
1 g
F P
s
P
p
.002 w
.56168 .60911 m .50999 .61727 L .51032 .62498 L p
1 g
F P
s
P
p
.002 w
.68742 .48765 m .66027 .52716 L .65517 .54645 L p
1 g
F P
s
P
p
.002 w
.66027 .52716 m .68742 .48765 L .6885 .46541 L p
1 g
F P
s
P
p
.002 w
.46594 .23723 m .42222 .25192 L .43484 .25446 L p
1 g
F P
s
P
p
.002 w
.43484 .25446 m .47065 .24247 L .46594 .23723 L p
1 g
F P
s
P
p
.002 w
.59558 .26558 m .55853 .24465 L .54638 .24852 L p
1 g
F P
s
P
p
.002 w
.50945 .24041 m .54638 .24852 L .55853 .24465 L p
1 g
F P
s
P
p
.002 w
.42007 .61064 m .4634 .62259 L .4577 .61458 L p
1 g
F P
s
P
p
.002 w
.4577 .61458 m .40929 .60115 L .42007 .61064 L p
1 g
F P
s
P
p
.002 w
.51032 .62498 m .5567 .61768 L .56168 .60911 L p
1 g
F P
s
P
p
.002 w
.60833 .59066 m .56168 .60911 L .5567 .61768 L p
1 g
F P
s
P
p
.002 w
.35805 .29339 m .3312 .3333 L .34697 .31897 L p
1 g
F P
s
P
p
.002 w
.34697 .31897 m .3714 .28285 L .35805 .29339 L p
1 g
F P
s
P
p
.002 w
.61232 .27002 m .64061 .30335 L .6577 .31595 L p
1 g
F P
s
P
p
.002 w
.64061 .30335 m .61232 .27002 L .59558 .26558 L p
1 g
F P
s
P
p
.002 w
.51343 .2347 m .46594 .23723 L .47065 .24247 L p
1 g
F P
s
P
p
.002 w
.47065 .24247 m .50945 .24041 L .51343 .2347 L p
1 g
F P
s
P
p
.002 w
.55853 .24465 m .51343 .2347 L .50945 .24041 L p
1 g
F P
s
P
p
.002 w
.41122 .25422 m .3714 .28285 L .38771 .27665 L p
1 g
F P
s
P
p
.002 w
.38771 .27665 m .42222 .25192 L .41122 .25422 L p
1 g
F P
s
P
p
.002 w
.55853 .24465 m .59558 .26558 L .61232 .27002 L p
1 g
F P
s
P
p
.002 w
.3126 .37114 m .30482 .41802 L .31192 .39628 L p
1 g
F P
s
P
p
.002 w
.31192 .39628 m .31956 .3508 L .3126 .37114 L p
1 g
F P
s
P
p
.002 w
.67101 .33214 m .68364 .37656 L .69289 .39745 L p
1 g
F P
s
P
p
.002 w
.68364 .37656 m .67101 .33214 L .6577 .31595 L p
1 g
F P
s
P
p
.002 w
.30648 .46398 m .31977 .50708 L .31646 .48509 L p
1 g
F P
s
P
p
.002 w
.31646 .48509 m .30291 .44078 L .30648 .46398 L p
1 g
F P
s
P
p
.002 w
.69709 .41991 m .6885 .46541 L .68742 .48765 L p
1 g
F P
s
P
p
.002 w
.6885 .46541 m .69709 .41991 L .69289 .39745 L p
1 g
F P
s
P
p
.002 w
.3844 .58991 m .42007 .61064 L .40929 .60115 L p
1 g
F P
s
P
p
.002 w
.40929 .60115 m .36921 .5778 L .3844 .58991 L p
1 g
F P
s
P
p
.002 w
.5567 .61768 m .59846 .60125 L .60833 .59066 L p
1 g
F P
s
P
p
.002 w
.64562 .56322 m .60833 .59066 L .59846 .60125 L p
1 g
F P
s
P
p
.002 w
.60833 .59066 m .64562 .56322 L .65517 .54645 L p
1 g
F P
s
P
p
.002 w
.3417 .54617 m .36921 .5778 L .35808 .56212 L p
1 g
F P
s
P
p
.002 w
.35808 .56212 m .32818 .52766 L .3417 .54617 L p
1 g
F P
s
P
p
.002 w
.6811 .50903 m .65517 .54645 L .64562 .56322 L p
1 g
F P
s
P
p
.002 w
.65517 .54645 m .6811 .50903 L .68742 .48765 L p
1 g
F P
s
P
p
.002 w
.47036 .6256 m .51037 .62763 L .51032 .62498 L p
1 g
F P
s
P
p
.002 w
.51032 .62498 m .4634 .62259 L .47036 .6256 L p
1 g
F P
s
P
p
.002 w
.5567 .61768 m .51032 .62498 L .51037 .62763 L p
1 g
F P
s
P
p
.002 w
.34822 .30821 m .31956 .3508 L .3312 .3333 L p
1 g
F P
s
P
p
.002 w
.3312 .3333 m .35805 .29339 L .34822 .30821 L p
1 g
F P
s
P
p
.002 w
.46198 .23716 m .41122 .25422 L .42222 .25192 L p
1 g
F P
s
P
p
.002 w
.42222 .25192 m .46594 .23723 L .46198 .23716 L p
1 g
F P
s
P
p
.002 w
.61232 .27002 m .56955 .24579 L .55853 .24465 L p
1 g
F P
s
P
p
.002 w
.51343 .2347 m .55853 .24465 L .56955 .24579 L p
1 g
F P
s
P
p
.002 w
.6577 .31595 m .62658 .2791 L .61232 .27002 L p
1 g
F P
s
P
p
.002 w
.62658 .2791 m .6577 .31595 L .67101 .33214 L p
1 g
F P
s
P
p
.002 w
.43353 .61545 m .47036 .6256 L .4634 .62259 L p
1 g
F P
s
P
p
.002 w
.4634 .62259 m .42007 .61064 L .43353 .61545 L p
1 g
F P
s
P
p
.002 w
.51037 .62763 m .54993 .62141 L .5567 .61768 L p
1 g
F P
s
P
p
.002 w
.59846 .60125 m .5567 .61768 L .54993 .62141 L p
1 g
F P
s
P
p
.002 w
.31075 .39385 m .30291 .44078 L .30482 .41802 L p
1 g
F P
s
P
p
.002 w
.30482 .41802 m .3126 .37114 L .31075 .39385 L p
1 g
F P
s
P
p
.004 w
.51071 .64304 m
.51205 .66959 L
s
P
p
.002 w
.69289 .39745 m .67997 .35164 L .67101 .33214 L p
1 g
F P
s
P
p
.002 w
.67997 .35164 m .69289 .39745 L .69709 .41991 L p
1 g
F P
s
P
p
.002 w
.40228 .26161 m .35805 .29339 L .3714 .28285 L p
1 g
F P
s
P
p
.002 w
.3714 .28285 m .41122 .25422 L .40228 .26161 L p
1 g
F P
s
P
p
.002 w
.31568 .48693 m .32818 .52766 L .31977 .50708 L p
1 g
F P
s
P
p
.002 w
.31977 .50708 m .30648 .46398 L .31568 .48693 L p
1 g
F P
s
P
p
.002 w
.56955 .24579 m .61232 .27002 L .62658 .2791 L p
1 g
F P
s
P
p
.002 w
.68742 .48765 m .69587 .44337 L .69709 .41991 L p
1 g
F P
s
P
p
.002 w
.69587 .44337 m .68742 .48765 L .6811 .50903 L p
1 g
F P
s
P
p
.002 w
.5172 .23422 m .46198 .23716 L .46594 .23723 L p
1 g
F P
s
P
p
.002 w
.46594 .23723 m .51343 .2347 L .5172 .23422 L p
1 g
F P
s
P
p
.002 w
.56955 .24579 m .5172 .23422 L .51343 .2347 L p
1 g
F P
s
P
p
.002 w
.36019 .56195 m .3844 .58991 L .36921 .5778 L p
1 g
F P
s
P
p
.002 w
.36921 .5778 m .3417 .54617 L .36019 .56195 L p
1 g
F P
s
P
p
.002 w
.59846 .60125 m .63164 .57688 L .64562 .56322 L p
1 g
F P
s
P
p
.002 w
.64562 .56322 m .66947 .52887 L .6811 .50903 L p
1 g
F P
s
P
p
.002 w
.66947 .52887 m .64562 .56322 L .63164 .57688 L p
1 g
F P
s
P
p
.002 w
.40342 .59791 m .43353 .61545 L .42007 .61064 L p
1 g
F P
s
P
p
.002 w
.42007 .61064 m .3844 .58991 L .40342 .59791 L p
1 g
F P
s
P
p
.002 w
.54993 .62141 m .58543 .60745 L .59846 .60125 L p
1 g
F P
s
P
p
.002 w
.63164 .57688 m .59846 .60125 L .58543 .60745 L p
1 g
F P
s
P
p
.002 w
.3424 .32711 m .3126 .37114 L .31956 .3508 L p
1 g
F P
s
P
p
.002 w
.31956 .3508 m .34822 .30821 L .3424 .32711 L p
1 g
F P
s
P
p
.002 w
.63779 .29281 m .67101 .33214 L .67997 .35164 L p
1 g
F P
s
P
p
.002 w
.67101 .33214 m .63779 .29281 L .62658 .2791 L p
1 g
F P
s
P
p
.002 w
.31433 .41833 m .30648 .46398 L .30291 .44078 L p
1 g
F P
s
P
p
.002 w
.30291 .44078 m .31075 .39385 L .31433 .41833 L p
1 g
F P
s
P
p
.002 w
.68408 .37404 m .69709 .41991 L .69587 .44337 L p
1 g
F P
s
P
p
.002 w
.69709 .41991 m .68408 .37404 L .67997 .35164 L p
1 g
F P
s
P
p
.002 w
.45893 .24261 m .40228 .26161 L .41122 .25422 L p
1 g
F P
s
P
p
.002 w
.41122 .25422 m .46198 .23716 L .45893 .24261 L p
1 g
F P
s
P
p
.002 w
.33049 .50892 m .3417 .54617 L .32818 .52766 L p
1 g
F P
s
P
p
.002 w
.32818 .52766 m .31568 .48693 L .33049 .50892 L p
1 g
F P
s
P
p
.002 w
.62658 .2791 m .57907 .25219 L .56955 .24579 L p
1 g
F P
s
P
p
.002 w
.5172 .23422 m .56955 .24579 L .57907 .25219 L p
1 g
F P
s
P
p
.002 w
.68902 .46719 m .6811 .50903 L .66947 .52887 L p
1 g
F P
s
P
p
.002 w
.6811 .50903 m .68902 .46719 L .69587 .44337 L p
1 g
F P
s
P
p
.002 w
.47847 .62319 m .51014 .6248 L .51037 .62763 L p
1 g
F P
s
P
p
.002 w
.51037 .62763 m .47036 .6256 L .47847 .62319 L p
1 g
F P
s
P
p
.002 w
.54993 .62141 m .51037 .62763 L .51014 .6248 L p
1 g
F P
s
P
p
.002 w
.39579 .27418 m .34822 .30821 L .35805 .29339 L p
1 g
F P
s
P
p
.002 w
.35805 .29339 m .40228 .26161 L .39579 .27418 L p
1 g
F P
s
P
p
.002 w
.57907 .25219 m .62658 .2791 L .63779 .29281 L p
1 g
F P
s
P
p
.002 w
.44943 .61516 m .47847 .62319 L .47036 .6256 L p
1 g
F P
s
P
p
.002 w
.47036 .6256 m .43353 .61545 L .44943 .61516 L p
1 g
F P
s
P
p
.002 w
.51014 .6248 m .54145 .61988 L .54993 .62141 L p
1 g
F P
s
P
p
.002 w
.58543 .60745 m .54993 .62141 L .54145 .61988 L p
1 g
F P
s
P
p
.002 w
.52064 .23932 m .45893 .24261 L .46198 .23716 L p
1 g
F P
s
P
p
.002 w
.46198 .23716 m .5172 .23422 L .52064 .23932 L p
1 g
F P
s
P
p
.002 w
.57907 .25219 m .52064 .23932 L .5172 .23422 L p
1 g
F P
s
P
p
.002 w
.38327 .57439 m .40342 .59791 L .3844 .58991 L p
1 g
F P
s
P
p
.002 w
.3844 .58991 m .36019 .56195 L .38327 .57439 L p
1 g
F P
s
P
p
.002 w
.58543 .60745 m .61342 .58685 L .63164 .57688 L p
1 g
F P
s
P
p
.002 w
.65262 .54653 m .63164 .57688 L .61342 .58685 L p
1 g
F P
s
P
p
.002 w
.63164 .57688 m .65262 .54653 L .66947 .52887 L p
1 g
F P
s
P
p
.002 w
.341 .3497 m .31075 .39385 L .3126 .37114 L p
1 g
F P
s
P
p
.002 w
.3126 .37114 m .3424 .32711 L .341 .3497 L p
1 g
F P
s
P
p
.002 w
.4259 .60134 m .44943 .61516 L .43353 .61545 L p
1 g
F P
s
P
p
.002 w
.43353 .61545 m .40342 .59791 L .4259 .60134 L p
1 g
F P
s
P
p
.002 w
.64544 .311 m .67997 .35164 L .68408 .37404 L p
1 g
F P
s
P
p
.002 w
.67997 .35164 m .64544 .311 L .63779 .29281 L p
1 g
F P
s
P
p
.002 w
.54145 .61988 m .56943 .60884 L .58543 .60745 L p
1 g
F P
s
P
p
.002 w
.61342 .58685 m .58543 .60745 L .56943 .60884 L p
1 g
F P
s
P
p
.002 w
.32347 .44389 m .31568 .48693 L .30648 .46398 L p
1 g
F P
s
P
p
.002 w
.30648 .46398 m .31433 .41833 L .32347 .44389 L p
1 g
F P
s
P
p
.002 w
.68299 .39879 m .69587 .44337 L .68902 .46719 L p
1 g
F P
s
P
p
.002 w
.69587 .44337 m .68299 .39879 L .68408 .37404 L p
1 g
F P
s
P
p
.002 w
.35064 .52919 m .36019 .56195 L .3417 .54617 L p
1 g
F P
s
P
p
.002 w
.3417 .54617 m .33049 .50892 L .35064 .52919 L p
1 g
F P
s
P
p
.002 w
.67649 .49063 m .66947 .52887 L .65262 .54653 L p
1 g
F P
s
P
p
.002 w
.66947 .52887 m .67649 .49063 L .68902 .46719 L p
1 g
F P
s
P
p
.002 w
.45694 .25378 m .39579 .27418 L .40228 .26161 L p
1 g
F P
s
P
p
.002 w
.40228 .26161 m .45893 .24261 L .45694 .25378 L p
1 g
F P
s
P
p
.002 w
.63779 .29281 m .5867 .26402 L .57907 .25219 L p
1 g
F P
s
P
p
.002 w
.52064 .23932 m .57907 .25219 L .5867 .26402 L p
1 g
F P
s
P
p
.002 w
.39211 .29185 m .3424 .32711 L .34822 .30821 L p
1 g
F P
s
P
p
.002 w
.34822 .30821 m .39579 .27418 L .39211 .29185 L p
1 g
F P
s
P
p
.002 w
.5867 .26402 m .63779 .29281 L .64544 .311 L p
1 g
F P
s
P
p
.002 w
.48755 .61509 m .5096 .61622 L .51014 .6248 L p
1 g
F P
s
P
p
.002 w
.51014 .6248 m .47847 .62319 L .48755 .61509 L p
1 g
F P
s
P
p
.002 w
.54145 .61988 m .51014 .6248 L .5096 .61622 L p
1 g
F P
s
P
p
.002 w
.46742 .60946 m .48755 .61509 L .47847 .62319 L p
1 g
F P
s
P
p
.002 w
.47847 .62319 m .44943 .61516 L .46742 .60946 L p
1 g
F P
s
P
p
.002 w
.5096 .61622 m .5314 .61278 L .54145 .61988 L p
1 g
F P
s
P
p
.002 w
.56943 .60884 m .54145 .61988 L .5314 .61278 L p
1 g
F P
s
P
p
.002 w
.4104 .58293 m .4259 .60134 L .40342 .59791 L p
1 g
F P
s
P
p
.002 w
.40342 .59791 m .38327 .57439 L .4104 .58293 L p
1 g
F P
s
P
p
.002 w
.56943 .60884 m .59129 .59263 L .61342 .58685 L p
1 g
F P
s
P
p
.002 w
.63085 .56133 m .61342 .58685 L .59129 .59263 L p
1 g
F P
s
P
p
.002 w
.61342 .58685 m .63085 .56133 L .65262 .54653 L p
1 g
F P
s
P
p
.002 w
.34429 .37542 m .31433 .41833 L .31075 .39385 L p
1 g
F P
s
P
p
.002 w
.31075 .39385 m .341 .3497 L .34429 .37542 L p
1 g
F P
s
P
p
.002 w
.33809 .4697 m .33049 .50892 L .31568 .48693 L p
1 g
F P
s
P
p
.002 w
.31568 .48693 m .32347 .44389 L .33809 .4697 L p
1 g
F P
s
P
p
.002 w
.64909 .33334 m .68408 .37404 L .68299 .39879 L p
1 g
F P
s
P
p
.002 w
.68408 .37404 m .64909 .33334 L .64544 .311 L p
1 g
F P
s
P
p
.002 w
.67648 .42519 m .68902 .46719 L .67649 .49063 L p
1 g
F P
s
P
p
.002 w
.68902 .46719 m .67648 .42519 L .68299 .39879 L p
1 g
F P
s
P
p
.002 w
.52363 .25023 m .45694 .25378 L .45893 .24261 L p
1 g
F P
s
P
p
.002 w
.45893 .24261 m .52064 .23932 L .52363 .25023 L p
1 g
F P
s
P
p
.002 w
.5867 .26402 m .52363 .25023 L .52064 .23932 L p
1 g
F P
s
P
p
.002 w
.37569 .547 m .38327 .57439 L .36019 .56195 L p
1 g
F P
s
P
p
.002 w
.36019 .56195 m .35064 .52919 L .37569 .547 L p
1 g
F P
s
P
p
.002 w
.65847 .51293 m .65262 .54653 L .63085 .56133 L p
1 g
F P
s
P
p
.002 w
.65262 .54653 m .65847 .51293 L .67649 .49063 L p
1 g
F P
s
P
p
.002 w
.45126 .59985 m .46742 .60946 L .44943 .61516 L p
1 g
F P
s
P
p
.002 w
.44943 .61516 m .4259 .60134 L .45126 .59985 L p
1 g
F P
s
P
p
.002 w
.5314 .61278 m .55079 .60507 L .56943 .60884 L p
1 g
F P
s
P
p
.002 w
.59129 .59263 m .56943 .60884 L .55079 .60507 L p
1 g
F P
s
P
p
.002 w
.39153 .3143 m .341 .3497 L .3424 .32711 L p
1 g
F P
s
P
p
.002 w
.3424 .32711 m .39211 .29185 L .39153 .3143 L p
1 g
F P
s
P
p
.002 w
.59208 .28121 m .64544 .311 L .64909 .33334 L p
1 g
F P
s
P
p
.002 w
.64544 .311 m .59208 .28121 L .5867 .26402 L p
1 g
F P
s
P
p
.002 w
.45615 .27066 m .39211 .29185 L .39579 .27418 L p
1 g
F P
s
P
p
.002 w
.39579 .27418 m .45694 .25378 L .45615 .27066 L p
1 g
F P
s
P
p
.002 w
.52363 .25023 m .5867 .26402 L .59208 .28121 L p
1 g
F P
s
P
p
.002 w
.35787 .49488 m .35064 .52919 L .33049 .50892 L p
1 g
F P
s
P
p
.002 w
.33049 .50892 m .33809 .4697 L .35787 .49488 L p
1 g
F P
s
P
p
.002 w
.66457 .45242 m .67649 .49063 L .65847 .51293 L p
1 g
F P
s
P
p
.002 w
.67649 .49063 m .66457 .45242 L .67648 .42519 L p
1 g
F P
s
P
p
.002 w
.44083 .58714 m .45126 .59985 L .4259 .60134 L p
1 g
F P
s
P
p
.002 w
.4259 .60134 m .4104 .58293 L .44083 .58714 L p
1 g
F P
s
P
p
.002 w
.35236 .4035 m .32347 .44389 L .31433 .41833 L p
1 g
F P
s
P
p
.002 w
.31433 .41833 m .34429 .37542 L .35236 .4035 L p
1 g
F P
s
P
p
.002 w
.55079 .60507 m .56578 .59382 L .59129 .59263 L p
1 g
F P
s
P
p
.002 w
.60465 .57269 m .59129 .59263 L .56578 .59382 L p
1 g
F P
s
P
p
.002 w
.59129 .59263 m .60465 .57269 L .63085 .56133 L p
1 g
F P
s
P
p
.002 w
.49736 .60119 m .50876 .60179 L .5096 .61622 L p
1 g
F P
s
P
p
.002 w
.5096 .61622 m .48755 .61509 L .49736 .60119 L p
1 g
F P
s
P
p
.002 w
.5314 .61278 m .5096 .61622 L .50876 .60179 L p
1 g
F P
s
P
p
.002 w
.64842 .35928 m .68299 .39879 L .67648 .42519 L p
1 g
F P
s
P
p
.002 w
.68299 .39879 m .64842 .35928 L .64909 .33334 L p
1 g
F P
s
P
p
.002 w
.40491 .56167 m .4104 .58293 L .38327 .57439 L p
1 g
F P
s
P
p
.002 w
.38327 .57439 m .37569 .547 L .40491 .56167 L p
1 g
F P
s
P
p
.002 w
.63534 .5333 m .63085 .56133 L .60465 .57269 L p
1 g
F P
s
P
p
.002 w
.63085 .56133 m .63534 .5333 L .65847 .51293 L p
1 g
F P
s
P
p
.002 w
.48701 .59826 m .49736 .60119 L .48755 .61509 L p
1 g
F P
s
P
p
.002 w
.48755 .61509 m .46742 .60946 L .48701 .59826 L p
1 g
F P
s
P
p
.002 w
.50876 .60179 m .52002 .6 L .5314 .61278 L p
1 g
F P
s
P
p
.002 w
.55079 .60507 m .5314 .61278 L .52002 .6 L p
1 g
F P
s
P
p
.002 w
.52605 .26694 m .45615 .27066 L .45694 .25378 L p
1 g
F P
s
P
p
.002 w
.45694 .25378 m .52363 .25023 L .52605 .26694 L p
1 g
F P
s
P
p
.002 w
.47879 .59328 m .48701 .59826 L .46742 .60946 L p
1 g
F P
s
P
p
.002 w
.46742 .60946 m .45126 .59985 L .47879 .59328 L p
1 g
F P
s
P
p
.002 w
.59208 .28121 m .52605 .26694 L .52363 .25023 L p
1 g
F P
s
P
p
.002 w
.52002 .6 m .52998 .59599 L .55079 .60507 L p
1 g
F P
s
P
p
.002 w
.56578 .59382 m .55079 .60507 L .52998 .59599 L p
1 g
F P
s
P
p
.002 w
.38226 .51852 m .37569 .547 L .35064 .52919 L p
1 g
F P
s
P
p
.002 w
.35064 .52919 m .35787 .49488 L .38226 .51852 L p
1 g
F P
s
P
p
.002 w
.64746 .47957 m .65847 .51293 L .63534 .5333 L p
1 g
F P
s
P
p
.002 w
.65847 .51293 m .64746 .47957 L .66457 .45242 L p
1 g
F P
s
P
p
.002 w
.39422 .341 m .34429 .37542 L .341 .3497 L p
1 g
F P
s
P
p
.002 w
.341 .3497 m .39153 .3143 L .39422 .341 L p
1 g
F P
s
P
p
.002 w
.5949 .30349 m .64909 .33334 L .64842 .35928 L p
1 g
F P
s
P
p
.002 w
.64909 .33334 m .5949 .30349 L .59208 .28121 L p
1 g
F P
s
P
p
.002 w
.3651 .43303 m .33809 .4697 L .32347 .44389 L p
1 g
F P
s
P
p
.002 w
.32347 .44389 m .35236 .4035 L .3651 .43303 L p
1 g
F P
s
P
p
.004 w
.31341 .43112 m
.3404 .43103 L
s
P
p
.002 w
.43739 .5726 m .44083 .58714 L .4104 .58293 L p
1 g
F P
s
P
p
.002 w
.4104 .58293 m .40491 .56167 L .43739 .5726 L p
1 g
F P
s
P
p
.002 w
.64325 .38807 m .67648 .42519 L .66457 .45242 L p
1 g
F P
s
P
p
.002 w
.67648 .42519 m .64325 .38807 L .64842 .35928 L p
1 g
F P
s
P
p
.002 w
.56578 .59382 m .57474 .58009 L .60465 .57269 L p
1 g
F P
s
P
p
.002 w
.60775 .55097 m .60465 .57269 L .57474 .58009 L p
1 g
F P
s
P
p
.002 w
.60465 .57269 m .60775 .55097 L .63534 .5333 L p
1 g
F P
s
P
p
.002 w
.4736 .58675 m .47879 .59328 L .45126 .59985 L p
1 g
F P
s
P
p
.002 w
.45126 .59985 m .44083 .58714 L .4736 .58675 L p
1 g
F P
s
P
p
.002 w
.52998 .59599 m .5376 .59018 L .56578 .59382 L p
1 g
F P
s
P
p
.002 w
.57474 .58009 m .56578 .59382 L .5376 .59018 L p
1 g
F P
s
P
p
.002 w
.45666 .293 m .39153 .3143 L .39211 .29185 L p
1 g
F P
s
P
p
.002 w
.39211 .29185 m .45615 .27066 L .45666 .293 L p
1 g
F P
s
P
p
.002 w
.52605 .26694 m .59208 .28121 L .5949 .30349 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50595 .54865 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.50876 .60179 m .49736 .60119 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.52002 .6 m .50876 .60179 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.49736 .60119 m .48701 .59826 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.52998 .59599 m .52002 .6 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.41047 .53975 m .40491 .56167 L .37569 .547 L p
1 g
F P
s
P
p
.002 w
.37569 .547 m .38226 .51852 L .41047 .53975 L p
1 g
F P
s
P
p
.002 w
.62563 .50567 m .63534 .5333 L .60775 .55097 L p
1 g
F P
s
P
p
.002 w
.63534 .5333 m .62563 .50567 L .64746 .47957 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.48701 .59826 m .47879 .59328 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.4736 .58675 m .47218 .58005 L p
.48974 .58084 L 1 g
F P
s
P
p
.002 w
.4986 .583 m .4736 .58675 L p
.48974 .58084 L 1 g
F P
s
P
p
.002 w
.48906 .58067 m .48921 .57862 L p
.47669 .57759 L 1 g
F P
s
P
p
.002 w
.48782 .58037 m .47203 .57935 L .47286 .57664 L p
1 g
F P
s
P
p
.47669 .57759 m .47627 .57756 L .48782 .58037 L 1 g
F
P
p
.47669 .57759 m .48782 .58037 L .48906 .58067 L 1 g
F
P
p
.002 w
.50646 .58131 m .50762 .58165 L .49716 .58097 L p
1 g
F P
s
P
p
.49919 .58105 m .49873 .58103 L .49918 .58105 L 1 g
F
P
p
.51079 .57862 m .49874 .58103 L .49919 .58105 L 1 g
F
P
p
.49874 .58103 m .49873 .58103 L .49919 .58105 L 1 g
F
P
p
.002 w
.50762 .58165 m .4986 .583 L p
.48974 .58084 L 1 g
F P
s
P
p
.002 w
.49716 .58097 m .50762 .58165 L p
.47218 .58005 L 1 g
F P
s
P
p
.002 w
.51097 .58105 m .51079 .57862 L p
.49895 .5811 L 1 g
F P
s
P
p
.49895 .5811 m .50138 .58116 L .51097 .58105 L 1 g
F
P
p
.49845 .5812 m .50226 .58126 L .51097 .58105 L 1 g
F
P
p
.49765 .58137 m .50318 .58135 L .51097 .58105 L 1 g
F
P
p
.49654 .5816 m .50423 .58141 L .51097 .58105 L 1 g
F
P
p
.49509 .5819 m .50545 .58143 L .51097 .58105 L 1 g
F
P
p
.002 w
.50709 .58133 m .50762 .58165 L .50646 .58131 L p
1 g
F P
s
P
p
.002 w
.50735 .58133 m .50762 .58165 L .50709 .58133 L p
1 g
F P
s
P
p
.002 w
.50752 .58133 m .50762 .58165 L .50735 .58133 L p
1 g
F P
s
P
p
.49338 .58226 m .50825 .58129 L .51097 .58105 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.47431 .57188 m .48025 .56515 L .50709 .58133 L p
1 g
F P
s
P
p
.002 w
.50646 .58131 m .47431 .57188 L p
.50709 .58133 L 1 g
F P
s
P
p
.49895 .5811 m .49845 .5812 L .50138 .58116 L 1 g
F
P
p
.49845 .5812 m .49765 .58137 L .50226 .58126 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48025 .56515 m .48924 .55994 L .50735 .58133 L p
1 g
F P
s
P
p
.002 w
.50709 .58133 m .48025 .56515 L p
.50735 .58133 L 1 g
F P
s
P
p
.002 w
.48924 .55994 m .50029 .55683 L .50752 .58133 L p
1 g
F P
s
P
p
.002 w
.50735 .58133 m .48924 .55994 L p
.50752 .58133 L 1 g
F P
s
P
p
.49765 .58137 m .49654 .5816 L .50318 .58135 L 1 g
F
P
p
.49654 .5816 m .49509 .5819 L .50423 .58141 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.50029 .55683 m .51215 .55621 L .50767 .58133 L p
1 g
F P
s
P
p
.002 w
.50767 .58133 m .50762 .58165 L .50752 .58133 L p
1 g
F P
s
P
p
.002 w
.50752 .58133 m .50029 .55683 L p
.50767 .58133 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51215 .55621 m .52348 .55813 L .50784 .58132 L p
1 g
F P
s
P
p
.002 w
.50784 .58132 m .50762 .58165 L .50767 .58133 L p
1 g
F P
s
P
p
.002 w
.50767 .58133 m .51215 .55621 L p
.50784 .58132 L 1 g
F P
s
P
p
.49509 .5819 m .49338 .58226 L .50545 .58143 L 1 g
F
P
p
.49338 .58226 m .49032 .5829 L .50825 .58129 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58105 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .58105 L .51098 .58105 L 1 g
F
P
p
.53128 .57265 m .51098 .58105 L .51162 .58085 L 1 g
F
P
p
.002 w
.54277 .57563 m .51127 .58102 L p
.51174 .58081 L 1 g
F P
s
P
p
.002 w
.54113 .57183 m .54277 .57563 L p
.52487 .57862 L 1 g
F P
s
P
p
.53173 .5747 m .52487 .57862 L .51174 .58081 L 1 g
F
P
p
.54113 .57183 m .52487 .57862 L .53173 .5747 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .5747 L p
1 g
F P
s
P
p
.54854 .56129 m .53173 .5747 L .53857 .57079 L 1 g
F
P
p
.002 w
.51079 .5811 m .54277 .57563 L p
.50881 .5817 L 1 g
F P
s
P
p
.52072 .57807 m .51098 .58112 L .51908 .57891 L 1 g
F
P
p
.53128 .57265 m .51162 .58085 L .52072 .57807 L 1 g
F
P
p
.51162 .58085 m .51098 .58112 L .52072 .57807 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54203 .58314 m .50881 .5817 L p
.51402 .58077 L 1 g
F P
s
P
p
.002 w
.54277 .57563 m .54252 .57814 L p
.51402 .58077 L 1 g
F P
s
P
p
.002 w
.54252 .57814 m .54203 .58314 L p
.51402 .58077 L 1 g
F P
s
P
p
.002 w
.5376 .59018 m .52998 .59599 L .50804 .58192 L p
1 g
F P
s
P
p
.002 w
.50831 .58184 m .5376 .59018 L p
.50804 .58192 L 1 g
F P
s
P
p
.002 w
.54203 .58314 m .5376 .59018 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54026 .56983 m .54113 .57183 L p
.53173 .5747 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .56319 L p
1 g
F P
s
P
p
.57076 .55094 m .54145 .57258 L .54741 .5654 L 1 g
F
P
p
.56075 .54566 m .54925 .56319 L .54947 .56292 L 1 g
F
P
p
.002 w
.56393 .5445 m .57076 .55094 L .55749 .5584 L p
1 g
F P
s
P
p
.002 w
.55749 .5584 m .54947 .56292 L p
.56166 .54738 L 1 g
F P
s
P
p
.56393 .5445 m .55749 .5584 L .56166 .54738 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56166 .54738 L p
1 g
F P
s
P
p
.56654 .52734 m .56166 .54738 L .56306 .54368 L 1 g
F
P
p
.002 w
.56802 .5268 m .58111 .51151 L p
.56774 .53534 L 1 g
F P
s
P
p
.56774 .53534 m .56306 .54368 L .56747 .52869 L 1 g
F
P
p
.56774 .53534 m .56747 .52869 L .56802 .5268 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .52869 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .52869 L .56742 .52751 L 1 g
F
P
p
.002 w
.56562 .50419 m .58111 .51151 L .57201 .52214 L p
1 g
F P
s
P
p
.002 w
.57201 .52214 m .56742 .52751 L p
.56601 .50928 L 1 g
F P
s
P
p
.56562 .50419 m .57201 .52214 L .56601 .50928 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56601 .50928 L p
1 g
F P
s
P
p
.55661 .4905 m .56601 .50928 L .56307 .50299 L 1 g
F
P
p
.002 w
.55683 .49009 m .56665 .46449 L p
.5636 .49733 L 1 g
F P
s
P
p
.5636 .49733 m .56307 .50299 L .55746 .4914 L 1 g
F
P
p
.5636 .49733 m .55746 .4914 L .55683 .49009 L 1 g
F
P
p
.55661 .4905 m .56307 .50299 L .56222 .50124 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.58111 .51151 m .56307 .50299 L p
.56665 .46449 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55359 .49852 m .56307 .50299 L p
.55781 .53873 L 1 g
F P
s
P
p
.002 w
.56307 .50299 m .56562 .50419 L p
.56497 .50705 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56307 .50299 m .56497 .50705 L .55781 .53873 L 1 g
F
P
p
.56515 .50826 m .56742 .52751 L .56671 .51841 L 1 g
F
P
p
.56654 .52734 m .56306 .54368 L .56436 .53925 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.57076 .55094 m .56306 .54368 L p
.58111 .51151 L 1 g
F P
s
P
p
.56075 .54566 m .54947 .56292 L .5554 .55536 L 1 g
F
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55005 .56259 m .57076 .55094 L p
.54741 .5654 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56193 .54789 L p
1 g
F P
s
P
p
.002 w
.56193 .54789 m .56075 .54566 L p
.55473 .55657 L 1 g
F P
s
P
p
.55473 .55657 m .54998 .56518 L .56193 .54789 L 1 g
F
P
p
.54741 .5654 m .54026 .56983 L .54925 .56319 L 1 g
F
P
p
.54741 .5654 m .54925 .56319 L .55005 .56259 L 1 g
F
P
p
.002 w
.55781 .53873 m .56306 .54368 L p
.53966 .56844 L 1 g
F P
s
P
p
.002 w
.56306 .54368 m .56393 .5445 L p
.56206 .54634 L 1 g
F P
s
P
p
.56306 .54368 m .56206 .54634 L .53966 .56844 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56828 .52988 L p
1 g
F P
s
P
p
.002 w
.56828 .52988 m .56654 .52734 L p
.56402 .54116 L 1 g
F P
s
P
p
.54854 .56129 m .53857 .57079 L .54026 .56983 L 1 g
F
P
p
.002 w
.54925 .56319 m .54854 .56129 L p
.54026 .56983 L 1 g
F P
s
P
p
.002 w
.54947 .56292 m .53966 .56844 L p
.56393 .5445 L 1 g
F P
s
P
p
.56402 .54116 m .56257 .5491 L .56828 .52988 L 1 g
F
P
p
.002 w
.56306 .54368 m .55781 .53873 L .56742 .52751 L p
1 g
F P
s
P
p
.002 w
.56742 .52751 m .56802 .5268 L p
.56747 .52869 L 1 g
F P
s
P
p
.56747 .52869 m .56306 .54368 L .56742 .52751 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5667 .51011 L p
1 g
F P
s
P
p
.002 w
.5667 .51011 m .56515 .50826 L p
.56716 .52133 L 1 g
F P
s
P
p
.56716 .52133 m .56854 .53025 L .5667 .51011 L 1 g
F
P
p
.002 w
.56742 .52751 m .55781 .53873 L p
.56562 .50419 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55786 .49183 L p
1 g
F P
s
P
p
.55661 .4905 m .56251 .50179 L .55967 .49571 L 1 g
F
P
p
.002 w
.55752 .49147 m .55661 .4905 L p
.55967 .49571 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55663 .4906 L 1 g
F
P
p
.54174 .47608 m .55663 .4906 L .54842 .48262 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55683 .49009 m .55663 .4906 L p
.54147 .4598 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55663 .4906 m .55359 .49852 L p
.5487 .48289 L 1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54147 .4598 m .55663 .4906 L .5487 .48289 L 1 g
F
P
p
.002 w
.55786 .49183 m .55752 .49147 L p
.55967 .49571 L 1 g
F P
s
P
p
.56251 .50179 m .56713 .51061 L .55786 .49183 L 1 g
F
P
p
.002 w
.56307 .50299 m .55359 .49852 L .55683 .49009 L p
1 g
F P
s
P
p
.55241 .48653 m .55663 .4906 L .55834 .49233 L 1 g
F
P
p
.002 w
.55746 .4914 m .55752 .49147 L p
.55663 .4906 L 1 g
F P
s
P
p
.002 w
.55752 .49147 m .55834 .49233 L p
.55663 .4906 L 1 g
F P
s
P
p
.54842 .48262 m .55663 .4906 L .55241 .48653 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.52358 .45648 m .54147 .4598 L p
.5487 .48289 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54214 .47652 L p
1 g
F P
s
P
p
.53572 .47348 m .5487 .48289 L .55359 .49852 L 1 g
F
P
p
.54214 .47652 m .5487 .48289 L .53572 .47348 L 1 g
F
P
p
.52214 .46667 m .54214 .47652 L .53085 .47118 L 1 g
F
P
p
.002 w
.55359 .49852 m .5203 .49252 L .5226 .46728 L p
1 g
F P
s
P
p
.52214 .46667 m .53085 .47118 L .5226 .46728 L 1 g
F
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5226 .46728 m .5203 .49252 L p
.50664 .46478 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46721 L p
1 g
F P
s
P
p
.5 .4634 m .52247 .46721 L .50925 .46518 L 1 g
F
P
p
.52247 .46721 m .5226 .46728 L .50664 .46478 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.48686 .46581 m .50664 .46478 L .5203 .49252 L 1 g
F
P
p
.47786 .46667 m .48791 .46565 L .47979 .46692 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47979 .46692 m .48528 .49437 L p
.45439 .47989 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45785 .47653 m .47979 .46692 L .45439 .47989 L 1 g
F
P
p
.002 w
.45785 .47653 m .45826 .47608 L p
.46548 .47291 L 1 g
F P
s
P
p
.47754 .4672 m .47979 .46692 L .45785 .47653 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46548 .47291 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46548 .47291 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45785 .47653 L p
1 g
F P
s
P
p
.44339 .4905 m .45785 .47653 L .44936 .48478 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.44339 .4905 m .44936 .48478 L .44519 .48883 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.43416 .49947 m .44267 .49127 L .43826 .50043 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44267 .49127 L p
1 g
F P
s
P
p
.43485 .50826 m .44267 .49127 L .43767 .50166 L 1 g
F
P
p
.002 w
.43403 .50923 m .43485 .50826 L p
.43767 .50166 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42697 .51965 m .40305 .49221 L p
.43509 .49969 L 1 g
F P
s
P
p
.002 w
.4333 .51578 m .42697 .51965 L p
.43509 .49969 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43374 .50959 L p
1 g
F P
s
P
p
.43346 .52734 m .43374 .50959 L .43323 .51681 L 1 g
F
P
p
.002 w
.42697 .51965 m .4333 .51578 L p
.4329 .52156 L 1 g
F P
s
P
p
.43314 .51813 m .43309 .51036 L .43299 .51382 L 1 g
F
P
p
.43346 .52734 m .43323 .51681 L .43314 .51813 L 1 g
F
P
p
.43323 .51681 m .43309 .51036 L .43314 .51813 L 1 g
F
P
p
.002 w
.43266 .52502 m .42697 .51965 L p
.4329 .52156 L 1 g
F P
s
P
p
.002 w
.41047 .53975 m .42697 .51965 L .43266 .52502 L p
1 g
F P
s
P
p
.41047 .53975 m .43161 .52572 L .43216 .54205 L 1 g
F
P
p
.43161 .52572 m .43266 .52502 L .43255 .52866 L 1 g
F
P
p
.43161 .52572 m .43255 .52866 L .43216 .54205 L 1 g
F
P
p
.002 w
.43846 .54715 m .43925 .54566 L p
.4358 .53885 L 1 g
F P
s
P
p
.43346 .52734 m .43312 .51747 L .4328 .52035 L 1 g
F
P
p
.002 w
.43174 .52985 m .43255 .52866 L p
.4328 .52035 L 1 g
F P
s
P
p
.002 w
.43255 .52866 m .43346 .52734 L p
.4328 .52035 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43255 .52866 L p
1 g
F P
s
P
p
.43216 .54205 m .43255 .52866 L .43699 .54256 L 1 g
F
P
p
.002 w
.43255 .52866 m .43146 .53025 L p
.4358 .53885 L 1 g
F P
s
P
p
.43925 .54566 m .43255 .52866 L .4358 .53885 L 1 g
F
P
p
.002 w
.43266 .52502 m .45303 .54426 L p
.43699 .54256 L 1 g
F P
s
P
p
.43255 .52866 m .43266 .52502 L .43699 .54256 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44153 .55775 m .41047 .53975 L p
.43521 .54237 L 1 g
F P
s
P
p
.45146 .56129 m .44318 .5541 L .44383 .55505 L 1 g
F
P
p
.45146 .56129 m .44383 .55505 L .44547 .557 L 1 g
F
P
p
.002 w
.4487 .56084 m .44153 .55775 L p
.44698 .55879 L 1 g
F P
s
P
p
.002 w
.45077 .56315 m .45146 .56129 L p
.44547 .557 L 1 g
F P
s
P
p
.002 w
.44153 .55775 m .44383 .55505 L p
.44698 .55879 L 1 g
F P
s
P
p
.44547 .557 m .44486 .55656 L .4487 .56084 L 1 g
F
P
p
.44547 .557 m .4487 .56084 L .45077 .56315 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44383 .55505 m .44153 .55775 L p
.43521 .54237 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.45303 .54426 m .48025 .56515 L p
.44698 .55879 L 1 g
F P
s
P
p
.002 w
.44383 .55505 m .45303 .54426 L p
.44698 .55879 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56315 L p
1 g
F P
s
P
p
.45888 .57218 m .45077 .56315 L .46412 .57208 L 1 g
F
P
p
.43739 .5726 m .44816 .5614 L .45888 .57218 L 1 g
F
P
p
.44816 .5614 m .4487 .56084 L .45077 .56315 L 1 g
F
P
p
.44816 .5614 m .45077 .56315 L .45888 .57218 L 1 g
F
P
p
.002 w
.46824 .57484 m .46872 .57265 L p
.45942 .56894 L 1 g
F P
s
P
p
.46872 .57265 m .45077 .56315 L .45942 .56894 L 1 g
F
P
p
.002 w
.47203 .57935 m .43739 .5726 L p
.46131 .57214 L 1 g
F P
s
P
p
.002 w
.47286 .57664 m .47203 .57935 L p
.46131 .57214 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.47431 .57188 m .47286 .57664 L p
.46131 .57214 L 1 g
F P
s
P
p
.002 w
.47218 .58005 m .47203 .57935 L .48782 .58037 L p
1 g
F P
s
P
p
.002 w
.48782 .58037 m .49716 .58097 L p
.48906 .58067 L 1 g
F P
s
P
p
.47218 .58005 m .48782 .58037 L .48906 .58067 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .4889 .58288 L p
1 g
F P
s
P
p
.002 w
.4889 .58288 m .48906 .58067 L p
.47824 .57873 L 1 g
F P
s
P
p
.47824 .57873 m .4678 .57686 L .4889 .58288 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46824 .57484 L p
1 g
F P
s
P
p
.45942 .56894 m .45002 .56518 L .46824 .57484 L 1 g
F
P
p
.002 w
.45077 .56315 m .45002 .56518 L p
.45942 .56894 L 1 g
F P
s
P
p
.002 w
.4487 .56084 m .47431 .57188 L p
.46412 .57208 L 1 g
F P
s
P
p
.45077 .56315 m .4487 .56084 L .46412 .57208 L 1 g
F
P
p
.002 w
.48025 .56515 m .47431 .57188 L .4487 .56084 L p
1 g
F P
s
P
p
.44698 .55879 m .48025 .56515 L .4487 .56084 L 1 g
F
P
p
.44547 .557 m .44383 .55505 L .44486 .55656 L 1 g
F
P
p
.002 w
.43739 .5726 m .44153 .55775 L .4487 .56084 L p
1 g
F P
s
P
p
.002 w
.45026 .56451 m .45077 .56315 L p
.44486 .55656 L 1 g
F P
s
P
p
.002 w
.45303 .54426 m .44383 .55505 L p
.43521 .54237 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45026 .56451 L p
1 g
F P
s
P
p
.44318 .5541 m .43743 .5491 L .45026 .56451 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43846 .54715 L p
1 g
F P
s
P
p
.4358 .53885 m .43146 .53025 L .43846 .54715 L 1 g
F
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.45287 .50384 m .47076 .53371 L p
.4329 .52156 L 1 g
F P
s
P
p
.002 w
.4333 .51578 m .45287 .50384 L p
.4329 .52156 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.47076 .53371 m .45303 .54426 L .43266 .52502 L p
1 g
F P
s
P
p
.4329 .52156 m .47076 .53371 L .43266 .52502 L 1 g
F
P
p
.002 w
.43374 .50959 m .43309 .51036 L p
.43323 .51681 L 1 g
F P
s
P
p
.002 w
.43309 .51036 m .43287 .51061 L p
.43299 .51382 L 1 g
F P
s
P
p
.002 w
.45287 .50384 m .4333 .51578 L p
.43509 .49969 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43174 .52985 L p
1 g
F P
s
P
p
.43312 .51747 m .43287 .51061 L .43174 .52985 L 1 g
F
P
p
.002 w
.44267 .49127 m .44166 .49233 L p
.43767 .50166 L 1 g
F P
s
P
p
.40305 .49221 m .44378 .48895 L .43416 .49947 L 1 g
F
P
p
.002 w
.44267 .49127 m .44339 .4905 L p
.44519 .48883 L 1 g
F P
s
P
p
.44378 .48895 m .44519 .48883 L .44267 .49127 L 1 g
F
P
p
.44378 .48895 m .44267 .49127 L .43416 .49947 L 1 g
F
P
p
.002 w
.44519 .48883 m .45287 .50384 L p
.43826 .50043 L 1 g
F P
s
P
p
.44267 .49127 m .44519 .48883 L .43826 .50043 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43403 .50923 L p
1 g
F P
s
P
p
.43767 .50166 m .44166 .49233 L .43403 .50923 L 1 g
F
P
p
.002 w
.44247 .49148 m .44267 .49127 L p
.44519 .48883 L 1 g
F P
s
P
p
.002 w
.40305 .49221 m .43626 .47138 L .44519 .48883 L p
1 g
F P
s
P
p
.002 w
.48528 .49437 m .45287 .50384 L .43626 .47138 L p
1 g
F P
s
P
p
.002 w
.45785 .47653 m .45698 .47747 L p
.44936 .48478 L 1 g
F P
s
P
p
.43788 .47214 m .46596 .46864 L .45785 .47653 L 1 g
F
P
p
.45257 .47903 m .45785 .47653 L .45439 .47989 L 1 g
F
P
p
.43788 .47214 m .45785 .47653 L .45257 .47903 L 1 g
F
P
p
.46596 .46864 m .47754 .4672 L .45785 .47653 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45785 .47653 L p
1 g
F P
s
P
p
.46548 .47291 m .47718 .46778 L .45785 .47653 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44247 .49148 L p
1 g
F P
s
P
p
.44936 .48478 m .45698 .47747 L .44247 .49148 L 1 g
F
P
p
.002 w
.47749 .46728 m .47754 .4672 L p
.47979 .46692 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.47979 .46692 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.5 .46375 m .50664 .46478 L .48686 .46581 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .46442 L p
.48791 .46565 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .48791 .46565 L 1 g
F
P
p
.002 w
.5 .46375 m .5 .4634 L p
.50925 .46518 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.47818 .45888 m .50097 .4636 L .48053 .46076 L 1 g
F
P
p
.50097 .4636 m .50664 .46478 L .5 .46375 L 1 g
F
P
p
.50097 .4636 m .5 .46375 L .48053 .46076 L 1 g
F
P
p
.002 w
.43626 .47138 m .47818 .45888 L .47979 .46692 L p
1 g
F P
s
P
p
.43626 .47138 m .47979 .46692 L .43788 .47214 L 1 g
F
P
p
.48053 .46076 m .5 .46375 L .48686 .46581 L 1 g
F
P
p
.002 w
.5203 .49252 m .48528 .49437 L .47818 .45888 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47749 .46728 L p
1 g
F P
s
P
p
.48791 .46565 m .5 .46442 L .47749 .46728 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.50925 .46518 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.47818 .45888 m .50309 .45756 L p
.50664 .46478 L 1 g
F P
s
P
p
.50309 .45756 m .52247 .46721 L .50664 .46478 L 1 g
F
P
p
.002 w
.52247 .46721 m .52282 .46778 L p
.50925 .46518 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52247 .46721 L p
.5226 .46728 L 1 g
F P
s
P
p
.002 w
.52247 .46721 m .52214 .46667 L p
.5226 .46728 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.50309 .45756 m .52358 .45648 L .5226 .46728 L p
1 g
F P
s
P
p
.002 w
.5226 .46728 m .52358 .45648 L p
.53572 .47348 L 1 g
F P
s
P
p
.53572 .47348 m .55359 .49852 L .5226 .46728 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52247 .46722 L p
1 g
F P
s
P
p
.53085 .47118 m .54302 .47747 L .52247 .46722 L 1 g
F
P
p
.002 w
.54214 .47652 m .54302 .47747 L p
.53085 .47118 L 1 g
F P
s
P
p
.52824 .46301 m .54214 .47652 L .53572 .47348 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.52358 .45648 m .5487 .48289 L .52824 .46301 L 1 g
F
P
p
.002 w
.54147 .4598 m .56665 .46449 L .55683 .49009 L p
1 g
F P
s
P
p
.56222 .50124 m .56307 .50299 L .56251 .50179 L 1 g
F
P
p
.002 w
.56601 .50928 m .56713 .51061 L p
.56251 .50179 L 1 g
F P
s
P
p
.56671 .51841 m .56742 .52751 L .56716 .52133 L 1 g
F
P
p
.002 w
.56747 .52869 m .56854 .53025 L p
.56716 .52133 L 1 g
F P
s
P
p
.56436 .53925 m .56306 .54368 L .56402 .54116 L 1 g
F
P
p
.002 w
.56166 .54738 m .56257 .5491 L p
.56402 .54116 L 1 g
F P
s
P
p
.5554 .55536 m .54947 .56292 L .55473 .55657 L 1 g
F
P
p
.002 w
.54026 .56983 m .53966 .56844 L .55005 .56259 L p
1 g
F P
s
P
p
.002 w
.54925 .56319 m .54998 .56518 L p
.55473 .55657 L 1 g
F P
s
P
p
.002 w
.54277 .57563 m .54145 .57258 L p
.57076 .55094 L 1 g
F P
s
P
p
.002 w
.54145 .57258 m .54026 .56983 L p
.54741 .5654 L 1 g
F P
s
P
p
.002 w
.54971 .56443 m .54925 .56319 L p
.54026 .56983 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54971 .56443 L p
1 g
F P
s
P
p
.53857 .57079 m .5322 .57686 L .54971 .56443 L 1 g
F
P
p
.002 w
.53966 .56844 m .54026 .56983 L p
.51174 .58081 L 1 g
F P
s
P
p
.54026 .56983 m .53173 .5747 L .51174 .58081 L 1 g
F
P
p
.002 w
.53173 .5747 m .5322 .57686 L p
.53857 .57079 L 1 g
F P
s
P
p
.002 w
.50854 .58127 m .53966 .56844 L p
.51174 .58081 L 1 g
F P
s
P
p
.51174 .58081 m .51127 .58102 L .51097 .58105 L 1 g
F
P
p
.51174 .58081 m .51097 .58105 L .50854 .58127 L 1 g
F
P
p
.51162 .58085 m .51097 .58105 L .51159 .58086 L 1 g
F
P
p
.51098 .58105 m .51097 .58105 L .51162 .58085 L 1 g
F
P
p
.002 w
.51097 .58105 m .51097 .58105 L p
.51098 .58105 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52348 .55813 m .533 .56237 L .50807 .5813 L p
1 g
F P
s
P
p
.002 w
.50807 .5813 m .50762 .58165 L .50784 .58132 L p
1 g
F P
s
P
p
.002 w
.50784 .58132 m .52348 .55813 L p
.50807 .5813 L 1 g
F P
s
P
p
.002 w
.533 .56237 m .53966 .56844 L .50854 .58127 L p
1 g
F P
s
P
p
.002 w
.50854 .58127 m .50762 .58165 L .50807 .5813 L p
1 g
F P
s
P
p
.002 w
.50807 .5813 m .533 .56237 L p
.50854 .58127 L 1 g
F P
s
P
p
.002 w
.51127 .58102 m .50762 .58165 L .50854 .58127 L p
1 g
F P
s
P
p
.002 w
.51097 .58105 m .51097 .58105 L p
.50908 .58122 L 1 g
F P
s
P
p
.50908 .58122 m .48985 .583 L .50914 .58122 L 1 g
F
P
p
.50908 .58122 m .50914 .58122 L .51097 .58105 L 1 g
F
P
p
.49032 .5829 m .48985 .583 L .51097 .58105 L 1 g
F
P
p
.002 w
.47431 .57188 m .50646 .58131 L p
.48782 .58037 L 1 g
F P
s
P
p
.002 w
.49716 .58097 m .48782 .58037 L p
.50646 .58131 L 1 g
F P
s
P
p
.002 w
.47286 .57664 m .47431 .57188 L p
.48782 .58037 L 1 g
F P
s
P
p
.47627 .57756 m .4678 .57686 L .48906 .58067 L 1 g
F
P
p
.002 w
.48889 .583 m .48985 .583 L p
.49918 .58105 L 1 g
F P
s
P
p
.49873 .58103 m .48889 .583 L .49918 .58105 L 1 g
F
P
p
.002 w
.50881 .5817 m .50762 .58165 L .51079 .5811 L p
1 g
F P
s
P
p
.002 w
.50804 .58192 m .50762 .58165 L .50831 .58184 L p
1 g
F P
s
P
p
.002 w
.47879 .59328 m .4736 .58675 L .50762 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.48985 .583 m .51111 .583 L .51097 .58105 L p
1 g
F P
s
P
p
.002 w
.51097 .58105 m .51098 .58112 L p
.51159 .58086 L 1 g
F P
s
P
p
.002 w
.51098 .58112 m .51111 .583 L p
.51908 .57891 L 1 g
F P
s
P
p
.002 w
.47203 .57935 m .4736 .58675 L .44083 .58714 L p
1 g
F P
s
P
p
.002 w
.44083 .58714 m .43739 .5726 L .47203 .57935 L p
1 g
F P
s
P
p
.002 w
.5376 .59018 m .54203 .58314 L .57474 .58009 L p
1 g
F P
s
P
p
.002 w
.57654 .56527 m .57474 .58009 L .54203 .58314 L p
1 g
F P
s
P
p
.002 w
.57474 .58009 m .57654 .56527 L .60775 .55097 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.38218 .46297 m .35787 .49488 L .33809 .4697 L p
1 g
F P
s
P
p
.002 w
.33809 .4697 m .3651 .43303 L .38218 .46297 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.63361 .41881 m .66457 .45242 L .64746 .47957 L p
1 g
F P
s
P
p
.002 w
.66457 .45242 m .63361 .41881 L .64325 .38807 L p
1 g
F P
s
P
p
.002 w
.52776 .28922 m .45666 .293 L .45615 .27066 L p
1 g
F P
s
P
p
.002 w
.45615 .27066 m .52605 .26694 L .52776 .28922 L p
1 g
F P
s
P
p
.002 w
.5949 .30349 m .52776 .28922 L .52605 .26694 L p
1 g
F P
s
P
p
.002 w
.40023 .37115 m .35236 .4035 L .34429 .37542 L p
1 g
F P
s
P
p
.002 w
.34429 .37542 m .39422 .341 L .40023 .37115 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.59492 .33034 m .64842 .35928 L .64325 .38807 L p
1 g
F P
s
P
p
.002 w
.64842 .35928 m .59492 .33034 L .5949 .30349 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.44153 .55775 m .43739 .5726 L .40491 .56167 L p
1 g
F P
s
P
p
.002 w
.40491 .56167 m .41047 .53975 L .44153 .55775 L p
1 g
F P
s
P
p
.002 w
.59976 .52976 m .60775 .55097 L .57654 .56527 L p
1 g
F P
s
P
p
.002 w
.60775 .55097 m .59976 .52976 L .62563 .50567 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.45852 .32027 m .39422 .341 L .39153 .3143 L p
1 g
F P
s
P
p
.002 w
.39153 .3143 m .45666 .293 L .45852 .32027 L p
1 g
F P
s
P
p
.002 w
.52776 .28922 m .5949 .30349 L .59492 .33034 L p
1 g
F P
s
P
p
.002 w
.54203 .58314 m .54277 .57563 L .57654 .56527 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.40305 .49221 m .38226 .51852 L .35787 .49488 L p
1 g
F P
s
P
p
.002 w
.35787 .49488 m .38218 .46297 L .40305 .49221 L p
1 g
F P
s
P
p
.002 w
.61972 .4504 m .64746 .47957 L .62563 .50567 L p
1 g
F P
s
P
p
.002 w
.64746 .47957 m .61972 .4504 L .63361 .41881 L p
1 g
F P
s
P
p
.002 w
.57076 .55094 m .57654 .56527 L .54277 .57563 L p
1 g
F P
s
P
p
.002 w
.57654 .56527 m .57076 .55094 L .59976 .52976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.40945 .40374 m .3651 .43303 L .35236 .4035 L p
1 g
F P
s
P
p
.002 w
.35236 .4035 m .40023 .37115 L .40945 .40374 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59203 .36097 m .64325 .38807 L .63361 .41881 L p
1 g
F P
s
P
p
.002 w
.64325 .38807 m .59203 .36097 L .59492 .33034 L p
1 g
F P
s
P
p
.002 w
.42697 .51965 m .41047 .53975 L .38226 .51852 L p
1 g
F P
s
P
p
.002 w
.38226 .51852 m .40305 .49221 L .42697 .51965 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.60201 .48169 m .62563 .50567 L .59976 .52976 L p
1 g
F P
s
P
p
.002 w
.62563 .50567 m .60201 .48169 L .61972 .4504 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.52867 .31654 m .45852 .32027 L .45666 .293 L p
1 g
F P
s
P
p
.002 w
.45666 .293 m .52776 .28922 L .52867 .31654 L p
1 g
F P
s
P
p
.002 w
.59492 .33034 m .52867 .31654 L .52776 .28922 L p
1 g
F P
s
P
p
.002 w
.53966 .56844 m .533 .56237 L .55781 .53873 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.004 w
.50813 .59182 m
.50816 .59249 L
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.58111 .51151 m .59976 .52976 L .57076 .55094 L p
1 g
F P
s
P
p
.002 w
.59976 .52976 m .58111 .51151 L .60201 .48169 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46171 .35166 m .40023 .37115 L .39422 .341 L p
1 g
F P
s
P
p
.002 w
.39422 .341 m .45852 .32027 L .46171 .35166 L p
1 g
F P
s
P
p
.002 w
.52867 .31654 m .59492 .33034 L .59203 .36097 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.48924 .55994 m .48025 .56515 L .45303 .54426 L p
1 g
F P
s
P
p
.002 w
.533 .56237 m .52348 .55813 L .53901 .53011 L p
1 g
F P
s
P
p
.002 w
.53901 .53011 m .55781 .53873 L .533 .56237 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4216 .43758 m .38218 .46297 L .3651 .43303 L p
1 g
F P
s
P
p
.002 w
.3651 .43303 m .40945 .40374 L .4216 .43758 L p
1 g
F P
s
P
p
.004 w
.38391 .43089 m
.38485 .43089 L
s
P
p
.004 w
.41916 .43078 m
.5 .43051 L
s
P
p
.004 w
.37481 .43092 m
.38391 .43089 L
s
P
p
.004 w
.3404 .43103 m
.37481 .43092 L
s
P
p
.002 w
.58623 .39437 m .63361 .41881 L .61972 .4504 L p
1 g
F P
s
P
p
.002 w
.63361 .41881 m .58623 .39437 L .59203 .36097 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.004 w
.50858 .60074 m
.50861 .60142 L
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.50029 .55683 m .48924 .55994 L .47076 .53371 L p
1 g
F P
s
P
p
.002 w
.45303 .54426 m .47076 .53371 L .48924 .55994 L p
1 g
F P
s
P
p
.002 w
.52348 .55813 m .51215 .55621 L .51644 .52617 L p
1 g
F P
s
P
p
.002 w
.51644 .52617 m .53901 .53011 L .52348 .55813 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.004 w
.50881 .60524 m
.50884 .60592 L
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51215 .55621 m .50029 .55683 L .49275 .52742 L p
1 g
F P
s
P
p
.002 w
.47076 .53371 m .49275 .52742 L .50029 .55683 L p
1 g
F P
s
P
p
.002 w
.49275 .52742 m .51644 .52617 L .51215 .55621 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55781 .53873 m .53901 .53011 L .55359 .49852 L p
1 g
F P
s
P
p
.002 w
.43626 .47138 m .40305 .49221 L .38218 .46297 L p
1 g
F P
s
P
p
.002 w
.38218 .46297 m .4216 .43758 L .43626 .47138 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.57767 .42932 m .61972 .4504 L .60201 .48169 L p
1 g
F P
s
P
p
.002 w
.61972 .4504 m .57767 .42932 L .58623 .39437 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.004 w
.50903 .60976 m
.50907 .61045 L
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.52872 .3481 m .46171 .35166 L .45852 .32027 L p
1 g
F P
s
P
p
.002 w
.45852 .32027 m .52867 .31654 L .52872 .3481 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59203 .36097 m .52872 .3481 L .52867 .31654 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46616 .3861 m .40945 .40374 L .40023 .37115 L p
1 g
F P
s
P
p
.002 w
.40023 .37115 m .46171 .35166 L .46616 .3861 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.52872 .3481 m .59203 .36097 L .58623 .39437 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.004 w
.50926 .61431 m
.5093 .615 L
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56665 .46449 m .60201 .48169 L .58111 .51151 L p
1 g
F P
s
P
p
.002 w
.60201 .48169 m .56665 .46449 L .57767 .42932 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.004 w
.50949 .61888 m
.50953 .61958 L
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.49275 .52742 m .47076 .53371 L .45287 .50384 L p
1 g
F P
s
P
p
.002 w
.53901 .53011 m .51644 .52617 L .5203 .49252 L p
1 g
F P
s
P
p
.002 w
.5203 .49252 m .55359 .49852 L .53901 .53011 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.004 w
.50972 .62348 m
.50976 .62418 L
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51644 .52617 m .49275 .52742 L .48528 .49437 L p
1 g
F P
s
P
p
.002 w
.45287 .50384 m .48528 .49437 L .49275 .52742 L p
1 g
F P
s
P
p
.002 w
.48528 .49437 m .5203 .49252 L .51644 .52617 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47172 .42231 m .4216 .43758 L .40945 .40374 L p
1 g
F P
s
P
p
.002 w
.40945 .40374 m .46616 .3861 L .47172 .42231 L p
1 g
F P
s
P
p
.002 w
.52787 .38283 m .58623 .39437 L .57767 .42932 L p
1 g
F P
s
P
p
.002 w
.58623 .39437 m .52787 .38283 L .52872 .3481 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.004 w
.50996 .62811 m
.50999 .62881 L
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.51019 .63276 m
.51071 .64304 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.52787 .38283 m .46616 .3861 L .46171 .35166 L p
1 g
F P
s
P
p
.002 w
.46171 .35166 m .52872 .3481 L .52787 .38283 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47818 .45888 m .43626 .47138 L .4216 .43758 L p
1 g
F P
s
P
p
.002 w
.4216 .43758 m .47172 .42231 L .47818 .45888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52614 .41943 m .57767 .42932 L .56665 .46449 L p
1 g
F P
s
P
p
.002 w
.57767 .42932 m .52614 .41943 L .52787 .38283 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56665 .46449 m .52358 .45648 L .52614 .41943 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52614 .41943 m .47172 .42231 L .46616 .3861 L p
1 g
F P
s
P
p
.002 w
.46616 .3861 m .52787 .38283 L .52614 .41943 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52358 .45648 m .47818 .45888 L .47172 .42231 L p
1 g
F P
s
P
p
.002 w
.47172 .42231 m .52614 .41943 L .52358 .45648 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .31341 .43112 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .51205 .66959 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.271318)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.271318)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45271 .45786 m .49866 .4708 L .50319 .4428 L p
1 g
F P
s
P
p
.002 w
.50319 .4428 m .46295 .4314 L .45271 .45786 L p
1 g
F P
s
P
p
.002 w
.54482 .44433 m .50319 .4428 L .49866 .4708 L p
1 g
F P
s
P
p
.002 w
.46295 .4314 m .50319 .4428 L .50763 .41457 L p
1 g
F P
s
P
p
.002 w
.50319 .4428 m .54482 .44433 L .54238 .41576 L p
1 g
F P
s
P
p
.002 w
.54238 .41576 m .50763 .41457 L .50319 .4428 L p
1 g
F P
s
P
p
.002 w
.50763 .41457 m .47405 .405 L .46295 .4314 L p
1 g
F P
s
P
p
.002 w
.47405 .405 m .50763 .41457 L .51191 .38663 L p
1 g
F P
s
P
p
.002 w
.50763 .41457 m .54238 .41576 L .53892 .38748 L p
1 g
F P
s
P
p
.002 w
.53892 .38748 m .51191 .38663 L .50763 .41457 L p
1 g
F P
s
P
p
.002 w
.42772 .4111 m .46295 .4314 L .47405 .405 L p
1 g
F P
s
P
p
.002 w
.47405 .405 m .44477 .38789 L .42772 .4111 L p
1 g
F P
s
P
p
.002 w
.44477 .38789 m .47405 .405 L .48581 .37915 L p
1 g
F P
s
P
p
.002 w
.51191 .38663 m .48581 .37915 L .47405 .405 L p
1 g
F P
s
P
p
.002 w
.41235 .43492 m .45271 .45786 L .46295 .4314 L p
1 g
F P
s
P
p
.002 w
.46295 .4314 m .42772 .4111 L .41235 .43492 L p
1 g
F P
s
P
p
.002 w
.44353 .48391 m .49413 .49807 L .49866 .4708 L p
1 g
F P
s
P
p
.002 w
.49866 .4708 m .45271 .45786 L .44353 .48391 L p
1 g
F P
s
P
p
.002 w
.54617 .47267 m .49866 .4708 L .49413 .49807 L p
1 g
F P
s
P
p
.002 w
.49866 .4708 m .54617 .47267 L .54482 .44433 L p
1 g
F P
s
P
p
.002 w
.57505 .40836 m .54238 .41576 L .54482 .44433 L p
1 g
F P
s
P
p
.002 w
.54238 .41576 m .57505 .40836 L .56423 .38155 L p
1 g
F P
s
P
p
.002 w
.56423 .38155 m .53892 .38748 L .54238 .41576 L p
1 g
F P
s
P
p
.002 w
.48581 .37915 m .51191 .38663 L .51593 .35947 L p
1 g
F P
s
P
p
.002 w
.51191 .38663 m .53892 .38748 L .53447 .36 L p
1 g
F P
s
P
p
.002 w
.53447 .36 m .51593 .35947 L .51191 .38663 L p
1 g
F P
s
P
p
.002 w
.58404 .43574 m .54482 .44433 L .54617 .47267 L p
1 g
F P
s
P
p
.002 w
.54482 .44433 m .58404 .43574 L .57505 .40836 L p
1 g
F P
s
P
p
.002 w
.48581 .37915 m .46315 .36573 L .44477 .38789 L p
1 g
F P
s
P
p
.002 w
.46315 .36573 m .48581 .37915 L .49802 .35431 L p
1 g
F P
s
P
p
.002 w
.51593 .35947 m .49802 .35431 L .48581 .37915 L p
1 g
F P
s
P
p
.002 w
.39896 .45891 m .44353 .48391 L .45271 .45786 L p
1 g
F P
s
P
p
.002 w
.45271 .45786 m .41235 .43492 L .39896 .45891 L p
1 g
F P
s
P
p
.002 w
.53892 .38748 m .56423 .38155 L .55178 .35583 L p
1 g
F P
s
P
p
.002 w
.55178 .35583 m .53447 .36 L .53892 .38748 L p
1 g
F P
s
P
p
.002 w
.49413 .49807 m .5464 .50027 L .54617 .47267 L p
1 g
F P
s
P
p
.002 w
.59104 .46318 m .54617 .47267 L .5464 .50027 L p
1 g
F P
s
P
p
.002 w
.54617 .47267 m .59104 .46318 L .58404 .43574 L p
1 g
F P
s
P
p
.002 w
.43559 .50905 m .48966 .52409 L .49413 .49807 L p
1 g
F P
s
P
p
.002 w
.49413 .49807 m .44353 .48391 L .43559 .50905 L p
1 g
F P
s
P
p
.002 w
.5464 .50027 m .49413 .49807 L .48966 .52409 L p
1 g
F P
s
P
p
.002 w
.40093 .38356 m .42772 .4111 L .44477 .38789 L p
1 g
F P
s
P
p
.002 w
.44477 .38789 m .42268 .36472 L .40093 .38356 L p
1 g
F P
s
P
p
.002 w
.42268 .36472 m .44477 .38789 L .46315 .36573 L p
1 g
F P
s
P
p
.002 w
.49802 .35431 m .51593 .35947 L .51963 .33362 L p
1 g
F P
s
P
p
.002 w
.51593 .35947 m .53447 .36 L .52912 .33387 L p
1 g
F P
s
P
p
.002 w
.52912 .33387 m .51963 .33362 L .51593 .35947 L p
1 g
F P
s
P
p
.002 w
.46315 .36573 m .44622 .34759 L .42268 .36472 L p
1 g
F P
s
P
p
.002 w
.44622 .34759 m .46315 .36573 L .48255 .34502 L p
1 g
F P
s
P
p
.002 w
.49802 .35431 m .48255 .34502 L .46315 .36573 L p
1 g
F P
s
P
p
.002 w
.38142 .40377 m .41235 .43492 L .42772 .4111 L p
1 g
F P
s
P
p
.002 w
.42772 .4111 m .40093 .38356 L .38142 .40377 L p
1 g
F P
s
P
p
.002 w
.48255 .34502 m .49802 .35431 L .51047 .33097 L p
1 g
F P
s
P
p
.002 w
.51963 .33362 m .51047 .33097 L .49802 .35431 L p
1 g
F P
s
P
p
.002 w
.38785 .48262 m .43559 .50905 L .44353 .48391 L p
1 g
F P
s
P
p
.002 w
.44353 .48391 m .39896 .45891 L .38785 .48262 L p
1 g
F P
s
P
p
.002 w
.60242 .39288 m .57505 .40836 L .58404 .43574 L p
1 g
F P
s
P
p
.002 w
.57505 .40836 m .60242 .39288 L .58529 .36932 L p
1 g
F P
s
P
p
.002 w
.58529 .36932 m .56423 .38155 L .57505 .40836 L p
1 g
F P
s
P
p
.002 w
.53447 .36 m .55178 .35583 L .53794 .33168 L p
1 g
F P
s
P
p
.002 w
.53794 .33168 m .52912 .33387 L .53447 .36 L p
1 g
F P
s
P
p
.002 w
.56423 .38155 m .58529 .36932 L .56608 .34731 L p
1 g
F P
s
P
p
.002 w
.56608 .34731 m .55178 .35583 L .56423 .38155 L p
1 g
F P
s
P
p
.002 w
.48966 .52409 m .5455 .52658 L .5464 .50027 L p
1 g
F P
s
P
p
.002 w
.59587 .49015 m .5464 .50027 L .5455 .52658 L p
1 g
F P
s
P
p
.002 w
.5464 .50027 m .59587 .49015 L .59104 .46318 L p
1 g
F P
s
P
p
.002 w
.61713 .41753 m .58404 .43574 L .59104 .46318 L p
1 g
F P
s
P
p
.002 w
.58404 .43574 m .61713 .41753 L .60242 .39288 L p
1 g
F P
s
P
p
.002 w
.48255 .34502 m .4711 .3325 L .44622 .34759 L p
1 g
F P
s
P
p
.002 w
.4711 .3325 m .48255 .34502 L .5026 .32618 L p
1 g
F P
s
P
p
.002 w
.51047 .33097 m .5026 .32618 L .48255 .34502 L p
1 g
F P
s
P
p
.002 w
.36458 .42495 m .39896 .45891 L .41235 .43492 L p
1 g
F P
s
P
p
.002 w
.41235 .43492 m .38142 .40377 L .36458 .42495 L p
1 g
F P
s
P
p
.002 w
.55178 .35583 m .56608 .34731 L .54516 .32727 L p
1 g
F P
s
P
p
.002 w
.54516 .32727 m .53794 .33168 L .55178 .35583 L p
1 g
F P
s
P
p
.002 w
.42909 .53277 m .48537 .54833 L .48966 .52409 L p
1 g
F P
s
P
p
.002 w
.48966 .52409 m .43559 .50905 L .42909 .53277 L p
1 g
F P
s
P
p
.002 w
.5455 .52658 m .48966 .52409 L .48537 .54833 L p
1 g
F P
s
P
p
.002 w
.62907 .44279 m .59104 .46318 L .59587 .49015 L p
1 g
F P
s
P
p
.002 w
.59104 .46318 m .62907 .44279 L .61713 .41753 L p
1 g
F P
s
P
p
.002 w
.41022 .33757 m .42268 .36472 L .44622 .34759 L p
1 g
F P
s
P
p
.002 w
.44622 .34759 m .43689 .32645 L .41022 .33757 L p
1 g
F P
s
P
p
.002 w
.43689 .32645 m .44622 .34759 L .4711 .3325 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .51047 .33097 L .51963 .33362 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .51963 .33362 L .52912 .33387 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .5026 .32618 L .51047 .33097 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .52912 .33387 L .53794 .33168 L closepath p
1 g
F P
s
P
p
.002 w
.38551 .35116 m .40093 .38356 L .42268 .36472 L p
1 g
F P
s
P
p
.002 w
.42268 .36472 m .41022 .33757 L .38551 .35116 L p
1 g
F P
s
P
p
.002 w
.37932 .50554 m .42909 .53277 L .43559 .50905 L p
1 g
F P
s
P
p
.002 w
.43559 .50905 m .38785 .48262 L .37932 .50554 L p
1 g
F P
s
P
p
.002 w
.4711 .3325 m .46494 .31799 L .43689 .32645 L p
1 g
F P
s
P
p
.002 w
.46494 .31799 m .4711 .3325 L .49683 .31975 L p
1 g
F P
s
P
p
.002 w
.5026 .32618 m .49683 .31975 L .4711 .3325 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .49683 .31975 L .5026 .32618 L closepath p
1 g
F P
s
P
p
.002 w
.35084 .44671 m .38785 .48262 L .39896 .45891 L p
1 g
F P
s
P
p
.002 w
.39896 .45891 m .36458 .42495 L .35084 .44671 L p
1 g
F P
s
P
p
.002 w
.59984 .35185 m .58529 .36932 L .60242 .39288 L p
1 g
F P
s
P
p
.002 w
.58529 .36932 m .59984 .35185 L .57582 .33524 L p
1 g
F P
s
P
p
.002 w
.57582 .33524 m .56608 .34731 L .58529 .36932 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .53794 .33168 L .54516 .32727 L closepath p
1 g
F P
s
P
p
.002 w
.56608 .34731 m .57582 .33524 L .55 .32107 L p
1 g
F P
s
P
p
.002 w
.55 .32107 m .54516 .32727 L .56608 .34731 L p
1 g
F P
s
P
p
.002 w
.48537 .54833 m .54344 .55106 L .5455 .52658 L p
1 g
F P
s
P
p
.002 w
.59838 .51612 m .5455 .52658 L .54344 .55106 L p
1 g
F P
s
P
p
.002 w
.5455 .52658 m .59838 .51612 L .59587 .49015 L p
1 g
F P
s
P
p
.002 w
.62158 .37058 m .60242 .39288 L .61713 .41753 L p
1 g
F P
s
P
p
.002 w
.60242 .39288 m .62158 .37058 L .59984 .35185 L p
1 g
F P
s
P
p
.002 w
.3633 .36698 m .38142 .40377 L .40093 .38356 L p
1 g
F P
s
P
p
.002 w
.40093 .38356 m .38551 .35116 L .3633 .36698 L p
1 g
F P
s
P
p
.002 w
.49683 .31975 m .49381 .31234 L .46494 .31799 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .49381 .31234 L .49683 .31975 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .54516 .32727 L .55 .32107 L closepath p
1 g
F P
s
P
p
.002 w
.63795 .46817 m .59587 .49015 L .59838 .51612 L p
1 g
F P
s
P
p
.002 w
.59587 .49015 m .63795 .46817 L .62907 .44279 L p
1 g
F P
s
P
p
.002 w
.64053 .39107 m .61713 .41753 L .62907 .44279 L p
1 g
F P
s
P
p
.002 w
.61713 .41753 m .64053 .39107 L .62158 .37058 L p
1 g
F P
s
P
p
.002 w
.43639 .30441 m .43689 .32645 L .46494 .31799 L p
1 g
F P
s
P
p
.002 w
.46494 .31799 m .46485 .30298 L .43639 .30441 L p
1 g
F P
s
P
p
.002 w
.46485 .30298 m .46494 .31799 L .49381 .31234 L p
1 g
F P
s
P
p
.002 w
.49381 .31234 m .49389 .30474 L .46485 .30298 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .49389 .30474 L .49381 .31234 L closepath p
1 g
F P
s
P
p
.002 w
.42421 .55453 m .48132 .57025 L .48537 .54833 L p
1 g
F P
s
P
p
.002 w
.48537 .54833 m .42909 .53277 L .42421 .55453 L p
1 g
F P
s
P
p
.002 w
.54344 .55106 m .48537 .54833 L .48132 .57025 L p
1 g
F P
s
P
p
.002 w
.55192 .31374 m .55 .32107 L .57582 .33524 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .55 .32107 L .55192 .31374 L closepath p
1 g
F P
s
P
p
.002 w
.34416 .38475 m .36458 .42495 L .38142 .40377 L p
1 g
F P
s
P
p
.002 w
.38142 .40377 m .3633 .36698 L .34416 .38475 L p
1 g
F P
s
P
p
.002 w
.40912 .30908 m .41022 .33757 L .43689 .32645 L p
1 g
F P
s
P
p
.002 w
.43689 .32645 m .43639 .30441 L .40912 .30908 L p
1 g
F P
s
P
p
.002 w
.57985 .32084 m .57582 .33524 L .59984 .35185 L p
1 g
F P
s
P
p
.002 w
.57582 .33524 m .57985 .32084 L .55192 .31374 L p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .49711 .29776 L .49389 .30474 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .55192 .31374 L .55066 .30607 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .50314 .29219 L .49711 .29776 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .55066 .30607 L .54633 .29888 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .54633 .29888 L .53936 .29299 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .53936 .29299 L .53054 .28907 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .53054 .28907 L .52083 .28757 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .52083 .28757 L .51135 .28865 L closepath p
1 g
F P
s
P
p
.002 w
.52292 .30962 m .51135 .28865 L .50314 .29219 L closepath p
1 g
F P
s
P
p
.002 w
.3406 .46859 m .37932 .50554 L .38785 .48262 L p
1 g
F P
s
P
p
.002 w
.38785 .48262 m .35084 .44671 L .3406 .46859 L p
1 g
F P
s
P
p
.002 w
.37365 .52717 m .42421 .55453 L .42909 .53277 L p
1 g
F P
s
P
p
.002 w
.42909 .53277 m .37932 .50554 L .37365 .52717 L p
1 g
F P
s
P
p
.002 w
.47098 .28908 m .46485 .30298 L .49389 .30474 L p
1 g
F P
s
P
p
.002 w
.49389 .30474 m .49711 .29776 L .47098 .28908 L p
1 g
F P
s
P
p
.002 w
.60611 .3308 m .59984 .35185 L .62158 .37058 L p
1 g
F P
s
P
p
.002 w
.59984 .35185 m .60611 .3308 L .57985 .32084 L p
1 g
F P
s
P
p
.002 w
.55066 .30607 m .55192 .31374 L .57985 .32084 L p
1 g
F P
s
P
p
.002 w
.48132 .57025 m .54022 .57315 L .54344 .55106 L p
1 g
F P
s
P
p
.002 w
.59846 .54052 m .54344 .55106 L .54022 .57315 L p
1 g
F P
s
P
p
.002 w
.54344 .55106 m .59846 .54052 L .59838 .51612 L p
1 g
F P
s
P
p
.002 w
.38366 .31695 m .38551 .35116 L .41022 .33757 L p
1 g
F P
s
P
p
.002 w
.41022 .33757 m .40912 .30908 L .38366 .31695 L p
1 g
F P
s
P
p
.002 w
.65622 .41294 m .62907 .44279 L .63795 .46817 L p
1 g
F P
s
P
p
.002 w
.62907 .44279 m .65622 .41294 L .64053 .39107 L p
1 g
F P
s
P
p
.002 w
.64351 .49311 m .59838 .51612 L .59846 .54052 L p
1 g
F P
s
P
p
.002 w
.59838 .51612 m .64351 .49311 L .63795 .46817 L p
1 g
F P
s
P
p
.002 w
.4451 .28385 m .43639 .30441 L .46485 .30298 L p
1 g
F P
s
P
p
.002 w
.46485 .30298 m .47098 .28908 L .4451 .28385 L p
1 g
F P
s
P
p
.002 w
.48282 .27789 m .47098 .28908 L .49711 .29776 L p
1 g
F P
s
P
p
.002 w
.49711 .29776 m .50314 .29219 L .48282 .27789 L p
1 g
F P
s
P
p
.002 w
.57985 .32084 m .57758 .30561 L .55066 .30607 L p
1 g
F P
s
P
p
.002 w
.54633 .29888 m .55066 .30607 L .57758 .30561 L p
1 g
F P
s
P
p
.002 w
.3286 .40415 m .35084 .44671 L .36458 .42495 L p
1 g
F P
s
P
p
.002 w
.36458 .42495 m .34416 .38475 L .3286 .40415 L p
1 g
F P
s
P
p
.002 w
.63011 .34347 m .62158 .37058 L .64053 .39107 L p
1 g
F P
s
P
p
.002 w
.62158 .37058 m .63011 .34347 L .60611 .3308 L p
1 g
F P
s
P
p
.002 w
.57758 .30561 m .57985 .32084 L .60611 .3308 L p
1 g
F P
s
P
p
.002 w
.49915 .27072 m .48282 .27789 L .50314 .29219 L p
1 g
F P
s
P
p
.002 w
.50314 .29219 m .51135 .28865 L .49915 .27072 L p
1 g
F P
s
P
p
.002 w
.36065 .32796 m .3633 .36698 L .38551 .35116 L p
1 g
F P
s
P
p
.002 w
.38551 .35116 m .38366 .31695 L .36065 .32796 L p
1 g
F P
s
P
p
.002 w
.57758 .30561 m .56911 .29124 L .54633 .29888 L p
1 g
F P
s
P
p
.002 w
.53936 .29299 m .54633 .29888 L .56911 .29124 L p
1 g
F P
s
P
p
.002 w
.42113 .5738 m .47763 .58929 L .48132 .57025 L p
1 g
F P
s
P
p
.002 w
.48132 .57025 m .42421 .55453 L .42113 .5738 L p
1 g
F P
s
P
p
.002 w
.54022 .57315 m .48132 .57025 L .47763 .58929 L p
1 g
F P
s
P
p
.002 w
.42004 .28229 m .40912 .30908 L .43639 .30441 L p
1 g
F P
s
P
p
.002 w
.43639 .30441 m .4451 .28385 L .42004 .28229 L p
1 g
F P
s
P
p
.002 w
.33422 .4901 m .37365 .52717 L .37932 .50554 L p
1 g
F P
s
P
p
.002 w
.37932 .50554 m .3406 .46859 L .33422 .4901 L p
1 g
F P
s
P
p
.002 w
.51814 .26849 m .49915 .27072 L .51135 .28865 L p
1 g
F P
s
P
p
.002 w
.51135 .28865 m .52083 .28757 L .51814 .26849 L p
1 g
F P
s
P
p
.002 w
.66822 .43574 m .63795 .46817 L .64351 .49311 L p
1 g
F P
s
P
p
.002 w
.63795 .46817 m .66822 .43574 L .65622 .41294 L p
1 g
F P
s
P
p
.002 w
.56911 .29124 m .55528 .2794 L .53936 .29299 L p
1 g
F P
s
P
p
.002 w
.53054 .28907 m .53936 .29299 L .55528 .2794 L p
1 g
F P
s
P
p
.002 w
.46241 .26714 m .4451 .28385 L .47098 .28908 L p
1 g
F P
s
P
p
.002 w
.47098 .28908 m .48282 .27789 L .46241 .26714 L p
1 g
F P
s
P
p
.002 w
.53761 .2715 m .51814 .26849 L .52083 .28757 L p
1 g
F P
s
P
p
.002 w
.52083 .28757 m .53054 .28907 L .53761 .2715 L p
1 g
F P
s
P
p
.002 w
.55528 .2794 m .53761 .2715 L .53054 .28907 L p
1 g
F P
s
P
p
.002 w
.37108 .54697 m .42113 .5738 L .42421 .55453 L p
1 g
F P
s
P
p
.002 w
.42421 .55453 m .37365 .52717 L .37108 .54697 L p
1 g
F P
s
P
p
.002 w
.60309 .30834 m .60611 .3308 L .63011 .34347 L p
1 g
F P
s
P
p
.002 w
.60611 .3308 m .60309 .30834 L .57758 .30561 L p
1 g
F P
s
P
p
.002 w
.65126 .35866 m .64053 .39107 L .65622 .41294 L p
1 g
F P
s
P
p
.002 w
.64053 .39107 m .65126 .35866 L .63011 .34347 L p
1 g
F P
s
P
p
.002 w
.56911 .29124 m .57758 .30561 L .60309 .30834 L p
1 g
F P
s
P
p
.002 w
.54022 .57315 m .59602 .56277 L .59846 .54052 L p
1 g
F P
s
P
p
.002 w
.64548 .51707 m .59846 .54052 L .59602 .56277 L p
1 g
F P
s
P
p
.002 w
.59846 .54052 m .64548 .51707 L .64351 .49311 L p
1 g
F P
s
P
p
.002 w
.47763 .58929 m .53586 .59226 L .54022 .57315 L p
1 g
F P
s
P
p
.002 w
.59602 .56277 m .54022 .57315 L .53586 .59226 L p
1 g
F P
s
P
p
.002 w
.31714 .42477 m .3406 .46859 L .35084 .44671 L p
1 g
F P
s
P
p
.002 w
.35084 .44671 m .3286 .40415 L .31714 .42477 L p
1 g
F P
s
P
p
.002 w
.34071 .34195 m .34416 .38475 L .3633 .36698 L p
1 g
F P
s
P
p
.002 w
.3633 .36698 m .36065 .32796 L .34071 .34195 L p
1 g
F P
s
P
p
.002 w
.39641 .28458 m .38366 .31695 L .40912 .30908 L p
1 g
F P
s
P
p
.002 w
.40912 .30908 m .42004 .28229 L .39641 .28458 L p
1 g
F P
s
P
p
.002 w
.48657 .25637 m .46241 .26714 L .48282 .27789 L p
1 g
F P
s
P
p
.002 w
.48282 .27789 m .49915 .27072 L .48657 .25637 L p
1 g
F P
s
P
p
.002 w
.60309 .30834 m .59076 .28699 L .56911 .29124 L p
1 g
F P
s
P
p
.002 w
.55528 .2794 m .56911 .29124 L .59076 .28699 L p
1 g
F P
s
P
p
.002 w
.62656 .31431 m .63011 .34347 L .65126 .35866 L p
1 g
F P
s
P
p
.002 w
.63011 .34347 m .62656 .31431 L .60309 .30834 L p
1 g
F P
s
P
p
.002 w
.67611 .45897 m .64351 .49311 L .64548 .51707 L p
1 g
F P
s
P
p
.002 w
.64351 .49311 m .67611 .45897 L .66822 .43574 L p
1 g
F P
s
P
p
.002 w
.44235 .26036 m .42004 .28229 L .4451 .28385 L p
1 g
F P
s
P
p
.002 w
.4451 .28385 m .46241 .26714 L .44235 .26036 L p
1 g
F P
s
P
p
.002 w
.66897 .3761 m .65622 .41294 L .66822 .43574 L p
1 g
F P
s
P
p
.002 w
.65622 .41294 m .66897 .3761 L .65126 .35866 L p
1 g
F P
s
P
p
.002 w
.33205 .51071 m .37108 .54697 L .37365 .52717 L p
1 g
F P
s
P
p
.002 w
.37365 .52717 m .33422 .4901 L .33205 .51071 L p
1 g
F P
s
P
p
.002 w
.51488 .25296 m .48657 .25637 L .49915 .27072 L p
1 g
F P
s
P
p
.002 w
.49915 .27072 m .51814 .26849 L .51488 .25296 L p
1 g
F P
s
P
p
.002 w
.59076 .28699 m .60309 .30834 L .62656 .31431 L p
1 g
F P
s
P
p
.002 w
.42 .59001 m .47438 .60487 L .47763 .58929 L p
1 g
F P
s
P
p
.002 w
.47763 .58929 m .42113 .5738 L .42 .59001 L p
1 g
F P
s
P
p
.002 w
.53586 .59226 m .47763 .58929 L .47438 .60487 L p
1 g
F P
s
P
p
.002 w
.59076 .28699 m .5703 .26929 L .55528 .2794 L p
1 g
F P
s
P
p
.002 w
.53761 .2715 m .55528 .2794 L .5703 .26929 L p
1 g
F P
s
P
p
.002 w
.32447 .35872 m .3286 .40415 L .34416 .38475 L p
1 g
F P
s
P
p
.002 w
.34416 .38475 m .34071 .34195 L .32447 .35872 L p
1 g
F P
s
P
p
.002 w
.37483 .29082 m .36065 .32796 L .38366 .31695 L p
1 g
F P
s
P
p
.002 w
.38366 .31695 m .39641 .28458 L .37483 .29082 L p
1 g
F P
s
P
p
.002 w
.54396 .25745 m .51488 .25296 L .51814 .26849 L p
1 g
F P
s
P
p
.002 w
.51814 .26849 m .53761 .2715 L .54396 .25745 L p
1 g
F P
s
P
p
.002 w
.5703 .26929 m .54396 .25745 L .53761 .2715 L p
1 g
F P
s
P
p
.002 w
.53586 .59226 m .59098 .58227 L .59602 .56277 L p
1 g
F P
s
P
p
.002 w
.6437 .53945 m .59602 .56277 L .59098 .58227 L p
1 g
F P
s
P
p
.002 w
.59602 .56277 m .6437 .53945 L .64548 .51707 L p
1 g
F P
s
P
p
.002 w
.37184 .56439 m .42 .59001 L .42113 .5738 L p
1 g
F P
s
P
p
.002 w
.42113 .5738 m .37108 .54697 L .37184 .56439 L p
1 g
F P
s
P
p
.002 w
.31024 .44617 m .33422 .4901 L .3406 .46859 L p
1 g
F P
s
P
p
.002 w
.3406 .46859 m .31714 .42477 L .31024 .44617 L p
1 g
F P
s
P
p
.002 w
.47438 .60487 m .53041 .60781 L .53586 .59226 L p
1 g
F P
s
P
p
.002 w
.59098 .58227 m .53586 .59226 L .53041 .60781 L p
1 g
F P
s
P
p
.002 w
.64737 .32352 m .65126 .35866 L .66897 .3761 L p
1 g
F P
s
P
p
.002 w
.65126 .35866 m .64737 .32352 L .62656 .31431 L p
1 g
F P
s
P
p
.002 w
.47389 .24611 m .44235 .26036 L .46241 .26714 L p
1 g
F P
s
P
p
.002 w
.46241 .26714 m .48657 .25637 L .47389 .24611 L p
1 g
F P
s
P
p
.002 w
.68268 .39546 m .66822 .43574 L .67611 .45897 L p
1 g
F P
s
P
p
.002 w
.66822 .43574 m .68268 .39546 L .66897 .3761 L p
1 g
F P
s
P
p
.002 w
.42316 .25789 m .39641 .28458 L .42004 .28229 L p
1 g
F P
s
P
p
.002 w
.42004 .28229 m .44235 .26036 L .42316 .25789 L p
1 g
F P
s
P
p
.002 w
.67955 .48211 m .64548 .51707 L .6437 .53945 L p
1 g
F P
s
P
p
.002 w
.64548 .51707 m .67955 .48211 L .67611 .45897 L p
1 g
F P
s
P
p
.002 w
.62656 .31431 m .61072 .28638 L .59076 .28699 L p
1 g
F P
s
P
p
.002 w
.5703 .26929 m .59076 .28699 L .61072 .28638 L p
1 g
F P
s
P
p
.002 w
.61072 .28638 m .62656 .31431 L .64737 .32352 L p
1 g
F P
s
P
p
.002 w
.35595 .30103 m .34071 .34195 L .36065 .32796 L p
1 g
F P
s
P
p
.002 w
.36065 .32796 m .37483 .29082 L .35595 .30103 L p
1 g
F P
s
P
p
.002 w
.31249 .37794 m .31714 .42477 L .3286 .40415 L p
1 g
F P
s
P
p
.002 w
.3286 .40415 m .32447 .35872 L .31249 .37794 L p
1 g
F P
s
P
p
.002 w
.33433 .52987 m .37184 .56439 L .37108 .54697 L p
1 g
F P
s
P
p
.002 w
.37108 .54697 m .33205 .51071 L .33433 .52987 L p
1 g
F P
s
P
p
.002 w
.51108 .24156 m .47389 .24611 L .48657 .25637 L p
1 g
F P
s
P
p
.002 w
.48657 .25637 m .51488 .25296 L .51108 .24156 L p
1 g
F P
s
P
p
.002 w
.61072 .28638 m .58401 .26309 L .5703 .26929 L p
1 g
F P
s
P
p
.002 w
.54396 .25745 m .5703 .26929 L .58401 .26309 L p
1 g
F P
s
P
p
.002 w
.30829 .46782 m .33205 .51071 L .33422 .4901 L p
1 g
F P
s
P
p
.002 w
.33422 .4901 m .31024 .44617 L .30829 .46782 L p
1 g
F P
s
P
p
.002 w
.42096 .6026 m .47169 .61642 L .47438 .60487 L p
1 g
F P
s
P
p
.002 w
.47438 .60487 m .42 .59001 L .42096 .6026 L p
1 g
F P
s
P
p
.002 w
.53041 .60781 m .47438 .60487 L .47169 .61642 L p
1 g
F P
s
P
p
.002 w
.53041 .60781 m .58335 .59841 L .59098 .58227 L p
1 g
F P
s
P
p
.002 w
.63801 .55963 m .59098 .58227 L .58335 .59841 L p
1 g
F P
s
P
p
.002 w
.59098 .58227 m .63801 .55963 L .6437 .53945 L p
1 g
F P
s
P
p
.002 w
.66488 .33588 m .66897 .3761 L .68268 .39546 L p
1 g
F P
s
P
p
.002 w
.66897 .3761 m .66488 .33588 L .64737 .32352 L p
1 g
F P
s
P
p
.002 w
.54939 .24746 m .51108 .24156 L .51488 .25296 L p
1 g
F P
s
P
p
.002 w
.51488 .25296 m .54396 .25745 L .54939 .24746 L p
1 g
F P
s
P
p
.002 w
.69188 .41635 m .67611 .45897 L .67955 .48211 L p
1 g
F P
s
P
p
.002 w
.67611 .45897 m .69188 .41635 L .68268 .39546 L p
1 g
F P
s
P
p
.002 w
.37609 .57885 m .42096 .6026 L .42 .59001 L p
1 g
F P
s
P
p
.002 w
.42 .59001 m .37184 .56439 L .37609 .57885 L p
1 g
F P
s
P
p
.002 w
.58401 .26309 m .54939 .24746 L .54396 .25745 L p
1 g
F P
s
P
p
.002 w
.40536 .26003 m .37483 .29082 L .39641 .28458 L p
1 g
F P
s
P
p
.002 w
.39641 .28458 m .42316 .25789 L .40536 .26003 L p
1 g
F P
s
P
p
.002 w
.46142 .24045 m .42316 .25789 L .44235 .26036 L p
1 g
F P
s
P
p
.002 w
.44235 .26036 m .47389 .24611 L .46142 .24045 L p
1 g
F P
s
P
p
.002 w
.47169 .61642 m .52393 .61922 L .53041 .60781 L p
1 g
F P
s
P
p
.002 w
.58335 .59841 m .53041 .60781 L .52393 .61922 L p
1 g
F P
s
P
p
.002 w
.67824 .50456 m .6437 .53945 L .63801 .55963 L p
1 g
F P
s
P
p
.002 w
.6437 .53945 m .67824 .50456 L .67955 .48211 L p
1 g
F P
s
P
p
.002 w
.64737 .32352 m .62842 .28961 L .61072 .28638 L p
1 g
F P
s
P
p
.002 w
.58401 .26309 m .61072 .28638 L .62842 .28961 L p
1 g
F P
s
P
p
.002 w
.62842 .28961 m .64737 .32352 L .66488 .33588 L p
1 g
F P
s
P
p
.002 w
.3404 .31515 m .32447 .35872 L .34071 .34195 L p
1 g
F P
s
P
p
.002 w
.34071 .34195 m .35595 .30103 L .3404 .31515 L p
1 g
F P
s
P
p
.002 w
.30531 .39923 m .31024 .44617 L .31714 .42477 L p
1 g
F P
s
P
p
.002 w
.31714 .42477 m .31249 .37794 L .30531 .39923 L p
1 g
F P
s
P
p
.002 w
.34126 .54698 m .37609 .57885 L .37184 .56439 L p
1 g
F P
s
P
p
.002 w
.37184 .56439 m .33433 .52987 L .34126 .54698 L p
1 g
F P
s
P
p
.002 w
.67849 .35122 m .68268 .39546 L .69188 .41635 L p
1 g
F P
s
P
p
.002 w
.68268 .39546 m .67849 .35122 L .66488 .33588 L p
1 g
F P
s
P
p
.002 w
.31157 .48915 m .33433 .52987 L .33205 .51071 L p
1 g
F P
s
P
p
.002 w
.33205 .51071 m .30829 .46782 L .31157 .48915 L p
1 g
F P
s
P
p
.002 w
.50683 .23483 m .46142 .24045 L .47389 .24611 L p
1 g
F P
s
P
p
.002 w
.47389 .24611 m .51108 .24156 L .50683 .23483 L p
1 g
F P
s
P
p
.002 w
.69612 .43829 m .67955 .48211 L .67824 .50456 L p
1 g
F P
s
P
p
.002 w
.67955 .48211 m .69612 .43829 L .69188 .41635 L p
1 g
F P
s
P
p
.002 w
.62842 .28961 m .59599 .26118 L .58401 .26309 L p
1 g
F P
s
P
p
.002 w
.54939 .24746 m .58401 .26309 L .59599 .26118 L p
1 g
F P
s
P
p
.002 w
.52393 .61922 m .57317 .61061 L .58335 .59841 L p
1 g
F P
s
P
p
.002 w
.62839 .577 m .58335 .59841 L .57317 .61061 L p
1 g
F P
s
P
p
.002 w
.58335 .59841 m .62839 .577 L .63801 .55963 L p
1 g
F P
s
P
p
.002 w
.38953 .26696 m .35595 .30103 L .37483 .29082 L p
1 g
F P
s
P
p
.002 w
.37483 .29082 m .40536 .26003 L .38953 .26696 L p
1 g
F P
s
P
p
.002 w
.42412 .61101 m .46966 .6234 L .47169 .61642 L p
1 g
F P
s
P
p
.002 w
.47169 .61642 m .42096 .6026 L .42412 .61101 L p
1 g
F P
s
P
p
.002 w
.52393 .61922 m .47169 .61642 L .46966 .6234 L p
1 g
F P
s
P
p
.002 w
.4495 .23981 m .40536 .26003 L .42316 .25789 L p
1 g
F P
s
P
p
.002 w
.42316 .25789 m .46142 .24045 L .4495 .23981 L p
1 g
F P
s
P
p
.002 w
.67201 .52569 m .63801 .55963 L .62839 .577 L p
1 g
F P
s
P
p
.002 w
.63801 .55963 m .67201 .52569 L .67824 .50456 L p
1 g
F P
s
P
p
.002 w
.5537 .24204 m .50683 .23483 L .51108 .24156 L p
1 g
F P
s
P
p
.002 w
.51108 .24156 m .54939 .24746 L .5537 .24204 L p
1 g
F P
s
P
p
.002 w
.38393 .58981 m .42412 .61101 L .42096 .6026 L p
1 g
F P
s
P
p
.002 w
.42096 .6026 m .37609 .57885 L .38393 .58981 L p
1 g
F P
s
P
p
.002 w
.59599 .26118 m .5537 .24204 L .54939 .24746 L p
1 g
F P
s
P
p
.002 w
.32879 .33297 m .31249 .37794 L .32447 .35872 L p
1 g
F P
s
P
p
.002 w
.32447 .35872 m .3404 .31515 L .32879 .33297 L p
1 g
F P
s
P
p
.002 w
.64327 .29682 m .66488 .33588 L .67849 .35122 L p
1 g
F P
s
P
p
.002 w
.66488 .33588 m .64327 .29682 L .62842 .28961 L p
1 g
F P
s
P
p
.002 w
.46966 .6234 m .51652 .62594 L .52393 .61922 L p
1 g
F P
s
P
p
.002 w
.57317 .61061 m .52393 .61922 L .51652 .62594 L p
1 g
F P
s
P
p
.002 w
.30335 .42208 m .30829 .46782 L .31024 .44617 L p
1 g
F P
s
P
p
.002 w
.31024 .44617 m .30531 .39923 L .30335 .42208 L p
1 g
F P
s
P
p
.002 w
.59599 .26118 m .62842 .28961 L .64327 .29682 L p
1 g
F P
s
P
p
.002 w
.68763 .3693 m .69188 .41635 L .69612 .43829 L p
1 g
F P
s
P
p
.002 w
.69188 .41635 m .68763 .3693 L .67849 .35122 L p
1 g
F P
s
P
p
.002 w
.69504 .46071 m .67824 .50456 L .67201 .52569 L p
1 g
F P
s
P
p
.002 w
.67824 .50456 m .69504 .46071 L .69612 .43829 L p
1 g
F P
s
P
p
.002 w
.32027 .50954 m .34126 .54698 L .33433 .52987 L p
1 g
F P
s
P
p
.002 w
.33433 .52987 m .31157 .48915 L .32027 .50954 L p
1 g
F P
s
P
p
.002 w
.35288 .56146 m .38393 .58981 L .37609 .57885 L p
1 g
F P
s
P
p
.002 w
.37609 .57885 m .34126 .54698 L .35288 .56146 L p
1 g
F P
s
P
p
.002 w
.37621 .27878 m .3404 .31515 L .35595 .30103 L p
1 g
F P
s
P
p
.002 w
.35595 .30103 m .38953 .26696 L .37621 .27878 L p
1 g
F P
s
P
p
.002 w
.50219 .23327 m .4495 .23981 L .46142 .24045 L p
1 g
F P
s
P
p
.002 w
.46142 .24045 m .50683 .23483 L .50219 .23327 L p
1 g
F P
s
P
p
.002 w
.51652 .62594 m .56056 .6183 L .57317 .61061 L p
1 g
F P
s
P
p
.002 w
.61487 .59092 m .57317 .61061 L .56056 .6183 L p
1 g
F P
s
P
p
.002 w
.57317 .61061 m .61487 .59092 L .62839 .577 L p
1 g
F P
s
P
p
.002 w
.64327 .29682 m .60581 .26389 L .59599 .26118 L p
1 g
F P
s
P
p
.002 w
.5537 .24204 m .59599 .26118 L .60581 .26389 L p
1 g
F P
s
P
p
.002 w
.32165 .35417 m .30531 .39923 L .31249 .37794 L p
1 g
F P
s
P
p
.002 w
.31249 .37794 m .32879 .33297 L .32165 .35417 L p
1 g
F P
s
P
p
.002 w
.66077 .54486 m .62839 .577 L .61487 .59092 L p
1 g
F P
s
P
p
.002 w
.62839 .577 m .66077 .54486 L .67201 .52569 L p
1 g
F P
s
P
p
.002 w
.43852 .24451 m .38953 .26696 L .40536 .26003 L p
1 g
F P
s
P
p
.002 w
.40536 .26003 m .4495 .23981 L .43852 .24451 L p
1 g
F P
s
P
p
.002 w
.42954 .61476 m .46838 .62532 L .46966 .6234 L p
1 g
F P
s
P
p
.002 w
.46966 .6234 m .42412 .61101 L .42954 .61476 L p
1 g
F P
s
P
p
.002 w
.51652 .62594 m .46966 .6234 L .46838 .62532 L p
1 g
F P
s
P
p
.002 w
.30693 .44588 m .31157 .48915 L .30829 .46782 L p
1 g
F P
s
P
p
.002 w
.30829 .46782 m .30335 .42208 L .30693 .44588 L p
1 g
F P
s
P
p
.002 w
.67849 .35122 m .65471 .30802 L .64327 .29682 L p
1 g
F P
s
P
p
.002 w
.65471 .30802 m .67849 .35122 L .68763 .3693 L p
1 g
F P
s
P
p
.004 w
.45605 .6623 m
.46094 .63649 L
s
P
p
.002 w
.5567 .24165 m .50219 .23327 L .50683 .23483 L p
1 g
F P
s
P
p
.002 w
.50683 .23483 m .5537 .24204 L .5567 .24165 L p
1 g
F P
s
P
p
.002 w
.39534 .59673 m .42954 .61476 L .42412 .61101 L p
1 g
F P
s
P
p
.002 w
.42412 .61101 m .38393 .58981 L .39534 .59673 L p
1 g
F P
s
P
p
.002 w
.60581 .26389 m .64327 .29682 L .65471 .30802 L p
1 g
F P
s
P
p
.002 w
.60581 .26389 m .5567 .24165 L .5537 .24204 L p
1 g
F P
s
P
p
.002 w
.46838 .62532 m .50833 .6275 L .51652 .62594 L p
1 g
F P
s
P
p
.002 w
.56056 .6183 m .51652 .62594 L .50833 .6275 L p
1 g
F P
s
P
p
.002 w
.69612 .43829 m .6918 .38973 L .68763 .3693 L p
1 g
F P
s
P
p
.002 w
.6918 .38973 m .69612 .43829 L .69504 .46071 L p
1 g
F P
s
P
p
.002 w
.67201 .52569 m .68842 .483 L .69504 .46071 L p
1 g
F P
s
P
p
.002 w
.68842 .483 m .67201 .52569 L .66077 .54486 L p
1 g
F P
s
P
p
.002 w
.33438 .52834 m .35288 .56146 L .34126 .54698 L p
1 g
F P
s
P
p
.002 w
.34126 .54698 m .32027 .50954 L .33438 .52834 L p
1 g
F P
s
P
p
.002 w
.36595 .29539 m .32879 .33297 L .3404 .31515 L p
1 g
F P
s
P
p
.002 w
.3404 .31515 m .37621 .27878 L .36595 .29539 L p
1 g
F P
s
P
p
.002 w
.36912 .57273 m .39534 .59673 L .38393 .58981 L p
1 g
F P
s
P
p
.002 w
.38393 .58981 m .35288 .56146 L .36912 .57273 L p
1 g
F P
s
P
p
.002 w
.31944 .37825 m .30335 .42208 L .30531 .39923 L p
1 g
F P
s
P
p
.002 w
.30531 .39923 m .32165 .35417 L .31944 .37825 L p
1 g
F P
s
P
p
.002 w
.49729 .23726 m .43852 .24451 L .4495 .23981 L p
1 g
F P
s
P
p
.002 w
.4495 .23981 m .50219 .23327 L .49729 .23726 L p
1 g
F P
s
P
p
.002 w
.56056 .6183 m .59765 .60083 L .61487 .59092 L p
1 g
F P
s
P
p
.002 w
.61487 .59092 m .64462 .56141 L .66077 .54486 L p
1 g
F P
s
P
p
.002 w
.64462 .56141 m .61487 .59092 L .59765 .60083 L p
1 g
F P
s
P
p
.002 w
.50833 .6275 m .54575 .62101 L .56056 .6183 L p
1 g
F P
s
P
p
.002 w
.59765 .60083 m .56056 .6183 L .54575 .62101 L p
1 g
F P
s
P
p
.002 w
.31619 .46996 m .32027 .50954 L .31157 .48915 L p
1 g
F P
s
P
p
.002 w
.31157 .48915 m .30693 .44588 L .31619 .46996 L p
1 g
F P
s
P
p
.002 w
.42885 .25477 m .37621 .27878 L .38953 .26696 L p
1 g
F P
s
P
p
.002 w
.38953 .26696 m .43852 .24451 L .42885 .25477 L p
1 g
F P
s
P
p
.002 w
.6622 .32314 m .68763 .3693 L .6918 .38973 L p
1 g
F P
s
P
p
.002 w
.68763 .3693 m .6622 .32314 L .65471 .30802 L p
1 g
F P
s
P
p
.002 w
.65471 .30802 m .61306 .27143 L .60581 .26389 L p
1 g
F P
s
P
p
.002 w
.5567 .24165 m .60581 .26389 L .61306 .27143 L p
1 g
F P
s
P
p
.002 w
.69062 .41202 m .69504 .46071 L .68842 .483 L p
1 g
F P
s
P
p
.002 w
.69504 .46071 m .69062 .41202 L .6918 .38973 L p
1 g
F P
s
P
p
.002 w
.43719 .61342 m .46794 .62178 L .46838 .62532 L p
1 g
F P
s
P
p
.002 w
.46838 .62532 m .42954 .61476 L .43719 .61342 L p
1 g
F P
s
P
p
.002 w
.50833 .6275 m .46838 .62532 L .46794 .62178 L p
1 g
F P
s
P
p
.002 w
.61306 .27143 m .65471 .30802 L .6622 .32314 L p
1 g
F P
s
P
p
.002 w
.67619 .50447 m .66077 .54486 L .64462 .56141 L p
1 g
F P
s
P
p
.002 w
.66077 .54486 m .67619 .50447 L .68842 .483 L p
1 g
F P
s
P
p
.002 w
.41022 .59916 m .43719 .61342 L .42954 .61476 L p
1 g
F P
s
P
p
.002 w
.42954 .61476 m .39534 .59673 L .41022 .59916 L p
1 g
F P
s
P
p
.002 w
.55822 .24664 m .49729 .23726 L .50219 .23327 L p
1 g
F P
s
P
p
.002 w
.50219 .23327 m .5567 .24165 L .55822 .24664 L p
1 g
F P
s
P
p
.002 w
.61306 .27143 m .55822 .24664 L .5567 .24165 L p
1 g
F P
s
P
p
.002 w
.46794 .62178 m .49956 .6235 L .50833 .6275 L p
1 g
F P
s
P
p
.002 w
.54575 .62101 m .50833 .6275 L .49956 .6235 L p
1 g
F P
s
P
p
.002 w
.35925 .31653 m .32165 .35417 L .32879 .33297 L p
1 g
F P
s
P
p
.002 w
.32879 .33297 m .36595 .29539 L .35925 .31653 L p
1 g
F P
s
P
p
.002 w
.35373 .54488 m .36912 .57273 L .35288 .56146 L p
1 g
F P
s
P
p
.002 w
.35288 .56146 m .33438 .52834 L .35373 .54488 L p
1 g
F P
s
P
p
.002 w
.32245 .40458 m .30693 .44588 L .30335 .42208 L p
1 g
F P
s
P
p
.002 w
.30335 .42208 m .31944 .37825 L .32245 .40458 L p
1 g
F P
s
P
p
.002 w
.38972 .58028 m .41022 .59916 L .39534 .59673 L p
1 g
F P
s
P
p
.002 w
.39534 .59673 m .36912 .57273 L .38972 .58028 L p
1 g
F P
s
P
p
.002 w
.33108 .49354 m .33438 .52834 L .32027 .50954 L p
1 g
F P
s
P
p
.002 w
.32027 .50954 m .31619 .46996 L .33108 .49354 L p
1 g
F P
s
P
p
.002 w
.54575 .62101 m .57702 .60621 L .59765 .60083 L p
1 g
F P
s
P
p
.002 w
.62381 .57472 m .59765 .60083 L .57702 .60621 L p
1 g
F P
s
P
p
.002 w
.59765 .60083 m .62381 .57472 L .64462 .56141 L p
1 g
F P
s
P
p
.002 w
.66528 .34193 m .6918 .38973 L .69062 .41202 L p
1 g
F P
s
P
p
.002 w
.6918 .38973 m .66528 .34193 L .6622 .32314 L p
1 g
F P
s
P
p
.002 w
.49956 .6235 m .52904 .61834 L .54575 .62101 L p
1 g
F P
s
P
p
.002 w
.57702 .60621 m .54575 .62101 L .52904 .61834 L p
1 g
F P
s
P
p
.002 w
.49226 .24704 m .42885 .25477 L .43852 .24451 L p
1 g
F P
s
P
p
.002 w
.43852 .24451 m .49729 .23726 L .49226 .24704 L p
1 g
F P
s
P
p
.002 w
.42088 .27058 m .36595 .29539 L .37621 .27878 L p
1 g
F P
s
P
p
.002 w
.37621 .27878 m .42885 .25477 L .42088 .27058 L p
1 g
F P
s
P
p
.002 w
.68385 .43556 m .68842 .483 L .67619 .50447 L p
1 g
F P
s
P
p
.002 w
.68842 .483 m .68385 .43556 L .69062 .41202 L p
1 g
F P
s
P
p
.002 w
.6622 .32314 m .61734 .28388 L .61306 .27143 L p
1 g
F P
s
P
p
.002 w
.55822 .24664 m .61306 .27143 L .61734 .28388 L p
1 g
F P
s
P
p
.002 w
.65848 .52442 m .64462 .56141 L .62381 .57472 L p
1 g
F P
s
P
p
.002 w
.64462 .56141 m .65848 .52442 L .67619 .50447 L p
1 g
F P
s
P
p
.002 w
.61734 .28388 m .6622 .32314 L .66528 .34193 L p
1 g
F P
s
P
p
.002 w
.35651 .34173 m .31944 .37825 L .32165 .35417 L p
1 g
F P
s
P
p
.002 w
.32165 .35417 m .35925 .31653 L .35651 .34173 L p
1 g
F P
s
P
p
.002 w
.44701 .60671 m .46842 .61254 L .46794 .62178 L p
1 g
F P
s
P
p
.002 w
.46794 .62178 m .43719 .61342 L .44701 .60671 L p
1 g
F P
s
P
p
.002 w
.49956 .6235 m .46794 .62178 L .46842 .61254 L p
1 g
F P
s
P
p
.002 w
.3308 .43238 m .31619 .46996 L .30693 .44588 L p
1 g
F P
s
P
p
.002 w
.30693 .44588 m .32245 .40458 L .3308 .43238 L p
1 g
F P
s
P
p
.002 w
.42831 .59677 m .44701 .60671 L .43719 .61342 L p
1 g
F P
s
P
p
.002 w
.43719 .61342 m .41022 .59916 L .42831 .59677 L p
1 g
F P
s
P
p
.002 w
.37792 .55851 m .38972 .58028 L .36912 .57273 L p
1 g
F P
s
P
p
.002 w
.36912 .57273 m .35373 .54488 L .37792 .55851 L p
1 g
F P
s
P
p
.002 w
.5581 .25719 m .49226 .24704 L .49729 .23726 L p
1 g
F P
s
P
p
.002 w
.49729 .23726 m .55822 .24664 L .5581 .25719 L p
1 g
F P
s
P
p
.002 w
.46842 .61254 m .49043 .61372 L .49956 .6235 L p
1 g
F P
s
P
p
.002 w
.52904 .61834 m .49956 .6235 L .49043 .61372 L p
1 g
F P
s
P
p
.002 w
.61734 .28388 m .5581 .25719 L .55822 .24664 L p
1 g
F P
s
P
p
.002 w
.35133 .51582 m .35373 .54488 L .33438 .52834 L p
1 g
F P
s
P
p
.002 w
.33438 .52834 m .33108 .49354 L .35133 .51582 L p
1 g
F P
s
P
p
.002 w
.52904 .61834 m .55346 .60666 L .57702 .60621 L p
1 g
F P
s
P
p
.002 w
.59879 .58421 m .57702 .60621 L .55346 .60666 L p
1 g
F P
s
P
p
.002 w
.57702 .60621 m .59879 .58421 L .62381 .57472 L p
1 g
F P
s
P
p
.002 w
.66362 .36399 m .69062 .41202 L .68385 .43556 L p
1 g
F P
s
P
p
.002 w
.69062 .41202 m .66362 .36399 L .66528 .34193 L p
1 g
F P
s
P
p
.002 w
.67147 .45965 m .67619 .50447 L .65848 .52442 L p
1 g
F P
s
P
p
.002 w
.67619 .50447 m .67147 .45965 L .68385 .43556 L p
1 g
F P
s
P
p
.002 w
.41423 .58367 m .42831 .59677 L .41022 .59916 L p
1 g
F P
s
P
p
.002 w
.41022 .59916 m .38972 .58028 L .41423 .58367 L p
1 g
F P
s
P
p
.002 w
.41499 .29174 m .35925 .31653 L .36595 .29539 L p
1 g
F P
s
P
p
.002 w
.36595 .29539 m .42088 .27058 L .41499 .29174 L p
1 g
F P
s
P
p
.002 w
.63565 .54213 m .62381 .57472 L .59879 .58421 L p
1 g
F P
s
P
p
.002 w
.62381 .57472 m .63565 .54213 L .65848 .52442 L p
1 g
F P
s
P
p
.002 w
.49043 .61372 m .51085 .61008 L .52904 .61834 L p
1 g
F P
s
P
p
.002 w
.55346 .60666 m .52904 .61834 L .51085 .61008 L p
1 g
F P
s
P
p
.002 w
.48725 .26267 m .42088 .27058 L .42885 .25477 L p
1 g
F P
s
P
p
.002 w
.42885 .25477 m .49226 .24704 L .48725 .26267 L p
1 g
F P
s
P
p
.002 w
.3444 .46074 m .33108 .49354 L .31619 .46996 L p
1 g
F P
s
P
p
.002 w
.31619 .46996 m .3308 .43238 L .3444 .46074 L p
1 g
F P
s
P
p
.002 w
.35799 .37032 m .32245 .40458 L .31944 .37825 L p
1 g
F P
s
P
p
.002 w
.31944 .37825 m .35651 .34173 L .35799 .37032 L p
1 g
F P
s
P
p
.002 w
.66528 .34193 m .61834 .30115 L .61734 .28388 L p
1 g
F P
s
P
p
.002 w
.5581 .25719 m .61734 .28388 L .61834 .30115 L p
1 g
F P
s
P
p
.002 w
.61834 .30115 m .66528 .34193 L .66362 .36399 L p
1 g
F P
s
P
p
.002 w
.40633 .56869 m .41423 .58367 L .38972 .58028 L p
1 g
F P
s
P
p
.002 w
.38972 .58028 m .37792 .55851 L .40633 .56869 L p
1 g
F P
s
P
p
.002 w
.37642 .53601 m .37792 .55851 L .35373 .54488 L p
1 g
F P
s
P
p
.002 w
.35373 .54488 m .35133 .51582 L .37642 .53601 L p
1 g
F P
s
P
p
.002 w
.45879 .5945 m .46985 .59752 L .46842 .61254 L p
1 g
F P
s
P
p
.002 w
.46842 .61254 m .44701 .60671 L .45879 .5945 L p
1 g
F P
s
P
p
.002 w
.49043 .61372 m .46842 .61254 L .46985 .59752 L p
1 g
F P
s
P
p
.002 w
.65365 .48349 m .65848 .52442 L .63565 .54213 L p
1 g
F P
s
P
p
.002 w
.65848 .52442 m .65365 .48349 L .67147 .45965 L p
1 g
F P
s
P
p
.002 w
.51085 .61008 m .52761 .60193 L .55346 .60666 L p
1 g
F P
s
P
p
.002 w
.5702 .58942 m .55346 .60666 L .52761 .60193 L p
1 g
F P
s
P
p
.002 w
.55346 .60666 m .5702 .58942 L .59879 .58421 L p
1 g
F P
s
P
p
.002 w
.44917 .58934 m .45879 .5945 L .44701 .60671 L p
1 g
F P
s
P
p
.002 w
.44701 .60671 m .42831 .59677 L .44917 .58934 L p
1 g
F P
s
P
p
.002 w
.65702 .38874 m .68385 .43556 L .67147 .45965 L p
1 g
F P
s
P
p
.002 w
.68385 .43556 m .65702 .38874 L .66362 .36399 L p
1 g
F P
s
P
p
.002 w
.55626 .27333 m .48725 .26267 L .49226 .24704 L p
1 g
F P
s
P
p
.002 w
.49226 .24704 m .5581 .25719 L .55626 .27333 L p
1 g
F P
s
P
p
.002 w
.46985 .59752 m .48122 .59811 L .49043 .61372 L p
1 g
F P
s
P
p
.002 w
.51085 .61008 m .49043 .61372 L .48122 .59811 L p
1 g
F P
s
P
p
.002 w
.61834 .30115 m .55626 .27333 L .5581 .25719 L p
1 g
F P
s
P
p
.002 w
.60827 .55692 m .59879 .58421 L .5702 .58942 L p
1 g
F P
s
P
p
.002 w
.59879 .58421 m .60827 .55692 L .63565 .54213 L p
1 g
F P
s
P
p
.002 w
.41147 .31778 m .35651 .34173 L .35925 .31653 L p
1 g
F P
s
P
p
.002 w
.35925 .31653 m .41499 .29174 L .41147 .31778 L p
1 g
F P
s
P
p
.002 w
.44202 .58259 m .44917 .58934 L .42831 .59677 L p
1 g
F P
s
P
p
.002 w
.42831 .59677 m .41423 .58367 L .44202 .58259 L p
1 g
F P
s
P
p
.002 w
.36293 .48868 m .35133 .51582 L .33108 .49354 L p
1 g
F P
s
P
p
.002 w
.33108 .49354 m .3444 .46074 L .36293 .48868 L p
1 g
F P
s
P
p
.002 w
.48122 .59811 m .49171 .5962 L .51085 .61008 L p
1 g
F P
s
P
p
.002 w
.52761 .60193 m .51085 .61008 L .49171 .5962 L p
1 g
F P
s
P
p
.002 w
.36383 .40139 m .3308 .43238 L .32245 .40458 L p
1 g
F P
s
P
p
.002 w
.32245 .40458 m .35799 .37032 L .36383 .40139 L p
1 g
F P
s
P
p
.002 w
.48244 .28394 m .41499 .29174 L .42088 .27058 L p
1 g
F P
s
P
p
.002 w
.42088 .27058 m .48725 .26267 L .48244 .28394 L p
1 g
F P
s
P
p
.002 w
.4056 .55334 m .40633 .56869 L .37792 .55851 L p
1 g
F P
s
P
p
.002 w
.37792 .55851 m .37642 .53601 L .4056 .55334 L p
1 g
F P
s
P
p
.002 w
.61584 .32292 m .66362 .36399 L .65702 .38874 L p
1 g
F P
s
P
p
.002 w
.66362 .36399 m .61584 .32292 L .61834 .30115 L p
1 g
F P
s
P
p
.002 w
.63083 .50624 m .63565 .54213 L .60827 .55692 L p
1 g
F P
s
P
p
.002 w
.63565 .54213 m .63083 .50624 L .65365 .48349 L p
1 g
F P
s
P
p
.002 w
.43811 .57492 m .44202 .58259 L .41423 .58367 L p
1 g
F P
s
P
p
.002 w
.41423 .58367 m .40633 .56869 L .43811 .57492 L p
1 g
F P
s
P
p
.002 w
.55626 .27333 m .61834 .30115 L .61584 .32292 L p
1 g
F P
s
P
p
.002 w
.64549 .41545 m .67147 .45965 L .65365 .48349 L p
1 g
F P
s
P
p
.002 w
.67147 .45965 m .64549 .41545 L .65702 .38874 L p
1 g
F P
s
P
p
.002 w
.52761 .60193 m .53889 .59 L .5702 .58942 L p
1 g
F P
s
P
p
.002 w
.57716 .56818 m .5702 .58942 L .53889 .59 L p
1 g
F P
s
P
p
.002 w
.5702 .58942 m .57716 .56818 L .60827 .55692 L p
1 g
F P
s
P
p
.002 w
.49171 .5962 m .50024 .59196 L .52761 .60193 L p
1 g
F P
s
P
p
.002 w
.53889 .59 m .52761 .60193 L .50024 .59196 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.47833 .5448 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.38583 .5152 m .37642 .53601 L .35133 .51582 L p
1 g
F P
s
P
p
.002 w
.35133 .51582 m .36293 .48868 L .38583 .5152 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.46985 .59752 m .45879 .5945 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.48122 .59811 m .46985 .59752 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.37392 .43391 m .3444 .46074 L .3308 .43238 L p
1 g
F P
s
P
p
.002 w
.3308 .43238 m .36383 .40139 L .37392 .43391 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.45879 .5945 m .44917 .58934 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.41057 .34799 m .35799 .37032 L .35651 .34173 L p
1 g
F P
s
P
p
.002 w
.35651 .34173 m .41147 .31778 L .41057 .34799 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.49171 .5962 m .48122 .59811 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.55265 .29482 m .48244 .28394 L .48725 .26267 L p
1 g
F P
s
P
p
.002 w
.48725 .26267 m .55626 .27333 L .55265 .29482 L p
1 g
F P
s
P
p
.002 w
.61584 .32292 m .55265 .29482 L .55626 .27333 L p
1 g
F P
s
P
p
.002 w
.43791 .56715 m .43811 .57492 L .40633 .56869 L p
1 g
F P
s
P
p
.002 w
.40633 .56869 m .4056 .55334 L .43791 .56715 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44917 .58934 m .44202 .58259 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.60369 .52705 m .60827 .55692 L .57716 .56818 L p
1 g
F P
s
P
p
.002 w
.60827 .55692 m .60369 .52705 L .63083 .50624 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50024 .59196 m .49171 .5962 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.50024 .59196 m .50586 .58582 L .53889 .59 L p
1 g
F P
s
P
p
.002 w
.54332 .57545 m .53889 .59 L .50586 .58582 L p
1 g
F P
s
P
p
.002 w
.53889 .59 m .54332 .57545 L .57716 .56818 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.44202 .58259 m .43811 .57492 L .47108 .57683 L p
1 g
F P
s
P
p
.002 w
.43811 .57492 m .43791 .56715 L .47224 .57689 L closepath p
1 g
F P
s
P
p
.002 w
.43791 .56715 m .4415 .56012 L .45407 .56697 L p
1 g
F P
s
P
p
.002 w
.46632 .57366 m .45407 .56697 L p
.45309 .56479 L 1 g
F P
s
P
p
.002 w
.45407 .56697 m .46632 .57366 L p
.45846 .57186 L 1 g
F P
s
P
p
.002 w
.47037 .57636 m .43791 .56715 L p
.46297 .57289 L 1 g
F P
s
P
p
.46297 .57289 m .46632 .57366 L .46822 .57493 L 1 g
F
P
p
.46297 .57289 m .46822 .57493 L .47037 .57636 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46822 .57493 L p
1 g
F P
s
P
p
.48921 .57862 m .46822 .57493 L .47099 .576 L 1 g
F
P
p
.48921 .57862 m .47099 .576 L .47153 .5762 L 1 g
F
P
p
.48921 .57862 m .47149 .5762 L .47181 .57631 L 1 g
F
P
p
.48921 .57862 m .47177 .5763 L .472 .57638 L 1 g
F
P
p
.002 w
.46822 .57493 m .46872 .57265 L p
.45896 .56875 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45074 .56321 L p
1 g
F P
s
P
p
.002 w
.45407 .56697 m .4415 .56012 L .44363 .55844 L p
1 g
F P
s
P
p
.44363 .55844 m .45074 .56321 L .45407 .56697 L 1 g
F
P
p
.46872 .57265 m .45074 .56321 L .45906 .56879 L 1 g
F
P
p
.002 w
.45074 .56321 m .45146 .56129 L p
.4433 .5542 L 1 g
F P
s
P
p
.002 w
.4415 .56012 m .41234 .5393 L p
.44149 .55163 L 1 g
F P
s
P
p
.002 w
.44534 .5571 m .4415 .56012 L p
.44149 .55163 L 1 g
F P
s
P
p
.4433 .5542 m .44105 .55225 L .44534 .5571 L 1 g
F
P
p
.4433 .5542 m .44534 .5571 L .45074 .56321 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43841 .54725 L p
1 g
F P
s
P
p
.002 w
.41234 .5393 m .42536 .52872 L p
.43841 .54725 L 1 g
F P
s
P
p
.43962 .55084 m .43841 .54725 L .44149 .55163 L 1 g
F
P
p
.41234 .5393 m .43841 .54725 L .43962 .55084 L 1 g
F
P
p
.002 w
.43841 .54725 m .43925 .54566 L p
.43521 .53767 L 1 g
F P
s
P
p
.002 w
.43587 .53974 m .42602 .52818 L p
.43402 .5339 L 1 g
F P
s
P
p
.43521 .53767 m .43508 .53741 L .43587 .53974 L 1 g
F
P
p
.43521 .53767 m .43587 .53974 L .43841 .54725 L 1 g
F
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.45146 .56129 m .43841 .54725 L .4433 .5542 L 1 g
F
P
p
.44149 .55163 m .4382 .54664 L .44853 .55461 L 1 g
F
P
p
.002 w
.42602 .52818 m .43587 .53974 L p
.4382 .54664 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43242 .52886 L p
1 g
F P
s
P
p
.002 w
.42602 .52818 m .43158 .5262 L p
.43242 .52886 L 1 g
F P
s
P
p
.43227 .53265 m .43242 .52886 L .43402 .5339 L 1 g
F
P
p
.42602 .52818 m .43242 .52886 L .43227 .53265 L 1 g
F
P
p
.002 w
.43242 .52886 m .43346 .52734 L p
.43317 .51889 L 1 g
F P
s
P
p
.002 w
.42602 .52818 m .40559 .49851 L p
.43355 .51459 L 1 g
F P
s
P
p
.002 w
.43253 .52586 m .42602 .52818 L p
.43355 .51459 L 1 g
F P
s
P
p
.002 w
.40559 .49851 m .43377 .4881 L .4355 .4931 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.40559 .49851 m .4355 .4931 L .43404 .50922 L 1 g
F
P
p
.43195 .51367 m .43404 .50922 L .43355 .51459 L 1 g
F
P
p
.40559 .49851 m .43404 .50922 L .43195 .51367 L 1 g
F
P
p
.002 w
.43404 .50922 m .43485 .50826 L p
.4384 .49996 L 1 g
F P
s
P
p
.002 w
.43809 .50059 m .43377 .4881 L p
.44095 .49472 L 1 g
F P
s
P
p
.4384 .49996 m .43851 .49971 L .43809 .50059 L 1 g
F
P
p
.4384 .49996 m .43809 .50059 L .43404 .50922 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43404 .50922 L p
1 g
F P
s
P
p
.002 w
.43404 .50922 m .43287 .51061 L p
.43317 .51889 L 1 g
F P
s
P
p
.43346 .52734 m .43404 .50922 L .43317 .51889 L 1 g
F
P
p
.43355 .51459 m .43404 .50922 L .44527 .52133 L 1 g
F
P
p
.002 w
.4355 .4931 m .43809 .50059 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.002 w
.43377 .4881 m .44459 .48723 L p
.44258 .49136 L 1 g
F P
s
P
p
.44 .49385 m .44258 .49136 L .44095 .49472 L 1 g
F
P
p
.43377 .4881 m .44258 .49136 L .44 .49385 L 1 g
F
P
p
.002 w
.44258 .49136 m .44228 .49168 L p
.44053 .49558 L 1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .44053 .49558 L 1 g
F
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45004 .48413 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46719 .48541 m .44706 .48703 L p
.45682 .47754 L 1 g
F P
s
P
p
.45004 .48413 m .45134 .48288 L .44706 .48703 L 1 g
F
P
p
.45004 .48413 m .44706 .48703 L .44258 .49136 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44258 .49136 m .46719 .48541 L .44095 .49472 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45776 .47663 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45682 .47754 m .45776 .47663 L .46719 .48541 L 1 g
F
P
p
.002 w
.45776 .47663 m .45826 .47608 L p
.468 .47181 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47763 .46706 m .50183 .49092 L .46729 .47216 L 1 g
F
P
p
.002 w
.47763 .46706 m .47786 .46667 L p
.48584 .46586 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46379 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46379 L .48584 .46586 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46709 L p
1 g
F P
s
P
p
.51685 .46634 m .5334 .50395 L .50956 .46537 L 1 g
F
P
p
.5 .4634 m .52239 .46709 L .51414 .46598 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55808 .52282 m .5334 .50395 L .5476 .48185 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.002 w
.58478 .49795 m .56804 .51354 L p
.56573 .50727 L 1 g
F P
s
P
p
.002 w
.55316 .47322 m .56278 .48074 L p
.56573 .50727 L 1 g
F P
s
P
p
.002 w
.56278 .48074 m .58478 .49795 L p
.56573 .50727 L 1 g
F P
s
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56683 .51916 L 1 g
F P
s
P
p
.58478 .49795 m .56791 .53739 L .56739 .52857 L 1 g
F
P
p
.002 w
.56658 .5149 m .57248 .5094 L p
.56739 .52857 L 1 g
F P
s
P
p
.002 w
.57248 .5094 m .58478 .49795 L p
.56739 .52857 L 1 g
F P
s
P
p
.002 w
.56739 .52857 m .56654 .52734 L p
.56454 .53827 L 1 g
F P
s
P
p
.002 w
.57313 .54513 m .56037 .55081 L p
.56157 .5472 L 1 g
F P
s
P
p
.002 w
.56585 .53434 m .56827 .53793 L p
.56157 .5472 L 1 g
F P
s
P
p
.002 w
.56827 .53793 m .57313 .54513 L p
.56157 .5472 L 1 g
F P
s
P
p
.002 w
.56157 .5472 m .56075 .54566 L p
.55547 .55523 L 1 g
F P
s
P
p
.57313 .54513 m .5425 .57128 L .54918 .56301 L 1 g
F
P
p
.002 w
.55829 .55174 m .57229 .5455 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.57229 .5455 m .57313 .54513 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.54332 .57545 m .5425 .57128 L p
.57313 .54513 L 1 g
F P
s
P
p
.002 w
.54918 .56301 m .54854 .56129 L p
.53934 .57005 L 1 g
F P
s
P
p
.002 w
.54332 .57545 m .52823 .57671 L p
.53171 .57462 L 1 g
F P
s
P
p
.002 w
.54195 .5685 m .54248 .57119 L p
.53171 .57462 L 1 g
F P
s
P
p
.002 w
.54248 .57119 m .54332 .57545 L p
.53171 .57462 L 1 g
F P
s
P
p
.002 w
.53171 .57462 m .53128 .57265 L p
.52077 .57804 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53175 .57478 L p
1 g
F P
s
P
p
.002 w
.52823 .57671 m .54332 .57545 L p
.52403 .57901 L 1 g
F P
s
P
p
.002 w
.53175 .57478 m .5322 .57686 L p
.53796 .57138 L 1 g
F P
s
P
p
.54854 .56129 m .53175 .57478 L .53796 .57138 L 1 g
F
P
p
.002 w
.5241 .57705 m .52823 .57671 L p
.51596 .5805 L 1 g
F P
s
P
p
.52403 .57901 m .51596 .5805 L .52823 .57671 L 1 g
F
P
p
.51596 .5805 m .50688 .58217 L .51096 .58096 L 1 g
F
P
p
.51596 .5805 m .51096 .58096 L .5241 .57705 L 1 g
F
P
p
.002 w
.50586 .58582 m .50688 .58217 L p
.54332 .57545 L 1 g
F P
s
P
p
.002 w
.51096 .58096 m .51079 .57862 L p
.49881 .58101 L 1 g
F P
s
P
p
.002 w
.50586 .58582 m .48606 .58056 L p
.48714 .5806 L 1 g
F P
s
P
p
.49881 .58101 m .50712 .58131 L .51096 .58096 L 1 g
F
P
p
.48921 .57862 m .47195 .57637 L .47214 .57643 L 1 g
F
P
p
.48921 .57862 m .47208 .57643 L .47226 .57648 L 1 g
F
P
p
.48921 .57862 m .4722 .57647 L .47237 .57652 L 1 g
F
P
p
.48921 .57862 m .47229 .57651 L .47247 .57655 L 1 g
F
P
p
.48921 .57862 m .47238 .57654 L .4766 .57758 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47224 .57689 m .47413 .57697 L p
.48714 .5806 L 1 g
F P
s
P
p
.002 w
.48606 .58056 m .47224 .57689 L p
.48714 .5806 L 1 g
F P
s
P
p
.002 w
.50612 .58489 m .50586 .58582 L p
.48714 .5806 L 1 g
F P
s
P
p
.48906 .58067 m .48714 .5806 L .47413 .57697 L 1 g
F
P
p
.50612 .58489 m .48714 .5806 L .48906 .58067 L 1 g
F
P
p
.002 w
.50712 .58131 m .50612 .58489 L p
.48906 .58067 L 1 g
F P
s
P
p
.52077 .57804 m .5241 .57705 L .53171 .57462 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58069 L p
1 g
F P
s
P
p
.002 w
.50586 .58582 m .50024 .59196 L .47845 .58024 L p
1 g
F P
s
P
p
.002 w
.48606 .58056 m .50586 .58582 L p
.47845 .58024 L 1 g
F P
s
P
p
.002 w
.48906 .58069 m .48889 .583 L p
.49844 .58109 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58069 L .49844 .58109 L 1 g
F
P
p
.002 w
.47845 .58024 m .47224 .57689 L .48606 .58056 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51098 .58124 L p
1 g
F P
s
P
p
.53128 .57265 m .51098 .58124 L .52039 .57824 L 1 g
F
P
p
.53934 .57005 m .54195 .5685 L .54918 .56301 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54195 .5685 m .53171 .57462 L .50793 .5784 L 1 g
F
P
p
.002 w
.52823 .57671 m .5241 .57705 L p
.53171 .57462 L 1 g
F P
s
P
p
.002 w
.5241 .57705 m .50793 .5784 L p
.53171 .57462 L 1 g
F P
s
P
p
.002 w
.51098 .58124 m .51111 .583 L p
.52039 .57824 L 1 g
F P
s
P
p
.002 w
.50793 .5784 m .5241 .57705 L p
.51096 .58096 L 1 g
F P
s
P
p
.002 w
.50688 .58217 m .50712 .58131 L p
.51096 .58096 L 1 g
F P
s
P
p
.002 w
.50712 .58131 m .50793 .5784 L p
.51096 .58096 L 1 g
F P
s
P
p
.48896 .58298 m .48889 .583 L .50713 .58131 L 1 g
F
P
p
.50712 .58131 m .50713 .58131 L .51096 .58096 L 1 g
F
P
p
.48896 .58298 m .50713 .58131 L .50712 .58131 L 1 g
F
P
p
.002 w
.47143 .57705 m .44202 .58259 L p
.47108 .57683 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47413 .57697 m .50793 .5784 L .50712 .58131 L p
1 g
F P
s
P
p
.50712 .58131 m .48906 .58067 L .47413 .57697 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58145 L p
1 g
F P
s
P
p
.002 w
.511 .58145 m .51096 .58096 L p
.50713 .58131 L 1 g
F P
s
P
p
.50713 .58131 m .48889 .583 L .511 .58145 L 1 g
F
P
p
.49881 .58101 m .48896 .58298 L .50712 .58131 L 1 g
F
P
p
.52077 .57804 m .52039 .57824 L .5241 .57705 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57462 L p
1 g
F P
s
P
p
.52039 .57824 m .51111 .583 L .53171 .57462 L 1 g
F
P
p
.53934 .57005 m .53722 .57208 L .54195 .5685 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54022 .55979 m .54195 .5685 L p
.50793 .5784 L 1 g
F P
s
P
p
.55547 .55523 m .55829 .55174 L .56157 .5472 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5425 .57128 m .54022 .55979 L .55829 .55174 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56301 L p
1 g
F P
s
P
p
.53722 .57208 m .5322 .57686 L .54918 .56301 L 1 g
F
P
p
.55547 .55523 m .5545 .55698 L .55829 .55174 L 1 g
F
P
p
.56454 .53827 m .56585 .53434 L .56739 .52857 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56214 .54829 L p
1 g
F P
s
P
p
.56654 .52734 m .56214 .54829 L .56397 .54142 L 1 g
F
P
p
.56683 .51916 m .56658 .5149 L .56595 .50921 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56824 .52982 L p
1 g
F P
s
P
p
.56515 .50826 m .56824 .52982 L .56764 .52439 L 1 g
F
P
p
.55661 .4905 m .56595 .50921 L .5604 .49774 L 1 g
F
P
p
.55316 .47322 m .56119 .49499 L .55435 .48526 L 1 g
F
P
p
.56119 .49499 m .56804 .51354 L .55718 .49111 L 1 g
F
P
p
.56119 .49499 m .55718 .49111 L .55435 .48526 L 1 g
F
P
p
.002 w
.55797 .49194 m .55661 .4905 L p
.55673 .49073 L 1 g
F P
s
P
p
.55673 .49073 m .56713 .51061 L .55797 .49194 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55797 .49194 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.55469 .4887 m .56595 .50921 L .55808 .52282 L 1 g
F
P
p
.55718 .49111 m .56595 .50921 L .55469 .4887 L 1 g
F
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.55469 .4887 m .55808 .52282 L .5476 .48185 L 1 g
F
P
p
.54989 .48406 m .55797 .49194 L .55272 .48683 L 1 g
F
P
p
.54174 .47608 m .55126 .48539 L .54989 .48406 L 1 g
F
P
p
.55126 .48539 m .55797 .49194 L .54989 .48406 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55718 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55718 .49111 L .55126 .48539 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55435 .48526 m .55718 .49111 L .55469 .4887 L 1 g
F
P
p
.002 w
.56804 .51354 m .56658 .5149 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.56658 .5149 m .55808 .52282 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.56824 .52982 m .56854 .53025 L p
.56764 .52439 L 1 g
F P
s
P
p
.002 w
.55808 .52282 m .56658 .5149 L p
.56739 .52857 L 1 g
F P
s
P
p
.002 w
.56791 .53739 m .56585 .53434 L p
.56739 .52857 L 1 g
F P
s
P
p
.002 w
.56585 .53434 m .55808 .52282 L p
.56739 .52857 L 1 g
F P
s
P
p
.002 w
.56214 .54829 m .56257 .5491 L p
.56397 .54142 L 1 g
F P
s
P
p
.002 w
.56037 .55081 m .54022 .55979 L p
.56585 .53434 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56157 .5472 L p
1 g
F P
s
P
p
.5545 .55698 m .54998 .56518 L .56157 .5472 L 1 g
F
P
p
.56454 .53827 m .56397 .54142 L .56585 .53434 L 1 g
F
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55808 .52282 m .56585 .53434 L p
.54022 .55979 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56739 .52857 L p
1 g
F P
s
P
p
.56397 .54142 m .56257 .5491 L .56739 .52857 L 1 g
F
P
p
.56683 .51916 m .56764 .52439 L .56658 .5149 L 1 g
F
P
p
.002 w
.57313 .54513 m .56791 .53739 L p
.58478 .49795 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56764 .52439 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.5604 .49774 L 1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5476 .48185 m .5334 .50395 L p
.53507 .47319 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54226 .47665 L p
1 g
F P
s
P
p
.52214 .46667 m .54226 .47665 L .53027 .47088 L 1 g
F
P
p
.53526 .46983 m .54226 .47665 L .53507 .47319 L 1 g
F
P
p
.54226 .47665 m .5476 .48185 L .53507 .47319 L 1 g
F
P
p
.51685 .46634 m .52344 .46759 L .5334 .50395 L 1 g
F
P
p
.002 w
.52239 .46709 m .52214 .46667 L p
.53027 .47088 L 1 g
F P
s
P
p
.52344 .46759 m .53526 .46983 L .53507 .47319 L 1 g
F
P
p
.52344 .46759 m .53507 .47319 L .5334 .50395 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5461 .47026 m .55316 .47322 L p
.51685 .46634 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52239 .46709 L p
1 g
F P
s
P
p
.53027 .47088 m .54302 .47747 L .52239 .46709 L 1 g
F
P
p
.002 w
.54226 .47665 m .54302 .47747 L p
.53027 .47088 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.5476 .48185 m .55316 .47322 L p
.55469 .4887 L 1 g
F P
s
P
p
.002 w
.55718 .49111 m .55797 .49194 L p
.55126 .48539 L 1 g
F P
s
P
p
.002 w
.55797 .49194 m .55834 .49233 L p
.55272 .48683 L 1 g
F P
s
P
p
.002 w
.55316 .47322 m .5476 .48185 L p
.53526 .46983 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51236 .45614 m .5461 .47026 L p
.51685 .46634 L 1 g
F P
s
P
p
.51178 .46567 m .52266 .46754 L .51442 .46617 L 1 g
F
P
p
.5 .4634 m .51414 .46598 L .51178 .46567 L 1 g
F
P
p
.51414 .46598 m .52266 .46754 L .51178 .46567 L 1 g
F
P
p
.002 w
.52239 .46709 m .52266 .46754 L p
.51414 .46598 L 1 g
F P
s
P
p
.002 w
.5334 .50395 m .50183 .49092 L .50956 .46537 L p
1 g
F P
s
P
p
.002 w
.50956 .46537 m .50183 .49092 L p
.47636 .45987 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50956 .46537 m .51236 .45614 L p
.51685 .46634 L 1 g
F P
s
P
p
.002 w
.46746 .44904 m .51236 .45614 L .50956 .46537 L p
1 g
F P
s
P
p
.46746 .44904 m .50956 .46537 L .47636 .45987 L 1 g
F
P
p
.002 w
.52266 .46754 m .52282 .46778 L p
.51442 .46617 L 1 g
F P
s
P
p
.002 w
.5 .46379 m .5 .46442 L p
.48584 .46586 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47741 .46742 L p
1 g
F P
s
P
p
.002 w
.47741 .46742 m .47718 .46778 L p
.46858 .47156 L 1 g
F P
s
P
p
.45826 .47608 m .47741 .46742 L .46858 .47156 L 1 g
F
P
p
.42422 .45279 m .46733 .46733 L .45776 .47663 L 1 g
F
P
p
.45644 .47725 m .45776 .47663 L .45682 .47754 L 1 g
F
P
p
.42422 .45279 m .45776 .47663 L .45644 .47725 L 1 g
F
P
p
.46746 .44904 m .48092 .46544 L .47763 .46706 L 1 g
F
P
p
.468 .47181 m .46729 .47216 L .45776 .47663 L 1 g
F
P
p
.002 w
.46729 .47216 m .46732 .46857 L p
.47763 .46706 L 1 g
F P
s
P
p
.002 w
.46732 .46857 m .46746 .44904 L p
.47763 .46706 L 1 g
F P
s
P
p
.48092 .46544 m .48176 .46646 L .47763 .46706 L 1 g
F
P
p
.48176 .46646 m .50183 .49092 L .47763 .46706 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47763 .46706 L p
1 g
F P
s
P
p
.48584 .46586 m .5 .46442 L .47763 .46706 L 1 g
F
P
p
.468 .47181 m .46858 .47156 L .46729 .47216 L 1 g
F
P
p
.002 w
.50183 .49092 m .46719 .48541 L .46729 .47216 L p
1 g
F P
s
P
p
.002 w
.46733 .46733 m .46729 .47216 L p
.45776 .47663 L 1 g
F P
s
P
p
.002 w
.46729 .47216 m .46719 .48541 L p
.45776 .47663 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45776 .47663 L p
1 g
F P
s
P
p
.46858 .47156 m .47718 .46778 L .45776 .47663 L 1 g
F
P
p
.002 w
.45776 .47663 m .45741 .47701 L p
.45292 .48133 L 1 g
F P
s
P
p
.44339 .4905 m .45776 .47663 L .45292 .48133 L 1 g
F
P
p
.002 w
.42422 .45279 m .46746 .44904 L .46733 .46733 L p
1 g
F P
s
P
p
.44339 .4905 m .45741 .47701 L .45134 .48288 L 1 g
F
P
p
.002 w
.44459 .48723 m .44706 .48703 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44706 .48703 m .46719 .48541 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.45741 .47701 m .45698 .47747 L p
.45134 .48288 L 1 g
F P
s
P
p
.002 w
.43377 .4881 m .42422 .45279 L p
.45682 .47754 L 1 g
F P
s
P
p
.002 w
.44706 .48703 m .43377 .4881 L p
.45682 .47754 L 1 g
F P
s
P
p
.002 w
.44228 .49168 m .44166 .49233 L p
.43851 .49971 L 1 g
F P
s
P
p
.43485 .50826 m .44228 .49168 L .43851 .49971 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44258 .49136 L p
1 g
F P
s
P
p
.45134 .48288 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.002 w
.46719 .48541 m .46794 .51964 L p
.44095 .49472 L 1 g
F P
s
P
p
.002 w
.43809 .50059 m .44527 .52133 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.46794 .51964 m .44527 .52133 L .43809 .50059 L p
1 g
F P
s
P
p
.44095 .49472 m .46794 .51964 L .43809 .50059 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43404 .50922 L p
1 g
F P
s
P
p
.43851 .49971 m .44166 .49233 L .43404 .50922 L 1 g
F
P
p
.43925 .54566 m .43242 .52886 L .43317 .53124 L 1 g
F
P
p
.43925 .54566 m .43226 .52908 L .43508 .53741 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43242 .52886 m .44527 .52133 L .43402 .5339 L 1 g
F
P
p
.002 w
.43158 .5262 m .43253 .52586 L p
.43242 .52886 L 1 g
F P
s
P
p
.43317 .51889 m .43253 .52586 L .43242 .52886 L 1 g
F
P
p
.002 w
.43253 .52586 m .44527 .52133 L p
.43242 .52886 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43224 .52912 L p
1 g
F P
s
P
p
.002 w
.43224 .52912 m .43242 .52886 L p
.43248 .52651 L 1 g
F P
s
P
p
.43248 .52651 m .43287 .51061 L .43224 .52912 L 1 g
F
P
p
.43317 .51889 m .433 .51408 L .43253 .52586 L 1 g
F
P
p
.002 w
.44527 .52133 m .43253 .52586 L p
.43355 .51459 L 1 g
F P
s
P
p
.433 .51408 m .43287 .51061 L .43242 .52886 L 1 g
F
P
p
.002 w
.43242 .52886 m .43226 .52908 L p
.43317 .53124 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44527 .52133 m .45827 .55126 L p
.43402 .5339 L 1 g
F P
s
P
p
.002 w
.43587 .53974 m .44853 .55461 L p
.4382 .54664 L 1 g
F P
s
P
p
.002 w
.43226 .52908 m .43146 .53025 L p
.43508 .53741 L 1 g
F P
s
P
p
.002 w
.45827 .55126 m .44853 .55461 L .43587 .53974 L p
1 g
F P
s
P
p
.43402 .5339 m .45827 .55126 L .43587 .53974 L 1 g
F
P
p
.002 w
.42536 .52872 m .42602 .52818 L p
.44149 .55163 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43841 .54725 L p
1 g
F P
s
P
p
.43508 .53741 m .43146 .53025 L .43841 .54725 L 1 g
F
P
p
.002 w
.43841 .54725 m .43743 .5491 L p
.4433 .5542 L 1 g
F P
s
P
p
.002 w
.44853 .55461 m .44534 .5571 L p
.44149 .55163 L 1 g
F P
s
P
p
.002 w
.44534 .5571 m .44853 .55461 L p
.45407 .56697 L 1 g
F P
s
P
p
.002 w
.45074 .56321 m .45002 .56518 L p
.45906 .56879 L 1 g
F P
s
P
p
.002 w
.44363 .55844 m .44534 .5571 L p
.45074 .56321 L 1 g
F P
s
P
p
.002 w
.44853 .55461 m .45827 .55126 L .47195 .57636 L p
1 g
F P
s
P
p
.002 w
.47195 .57636 m .47224 .57689 L .47149 .57619 L p
1 g
F P
s
P
p
.002 w
.47149 .57619 m .44853 .55461 L p
.47195 .57636 L 1 g
F P
s
P
p
.002 w
.47149 .57619 m .47224 .57689 L .46968 .57549 L p
1 g
F P
s
P
p
.47153 .5762 m .47099 .576 L .47149 .5762 L 1 g
F
P
p
.47181 .57631 m .47149 .5762 L .47177 .5763 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45827 .55126 m .46966 .55048 L .4722 .57645 L p
1 g
F P
s
P
p
.002 w
.4722 .57645 m .47224 .57689 L .47195 .57636 L p
1 g
F P
s
P
p
.002 w
.47195 .57636 m .45827 .55126 L p
.4722 .57645 L 1 g
F P
s
P
p
.002 w
.46966 .55048 m .4814 .55236 L .47239 .57651 L p
1 g
F P
s
P
p
.002 w
.47239 .57651 m .47224 .57689 L .4722 .57645 L p
1 g
F P
s
P
p
.002 w
.4722 .57645 m .46966 .55048 L p
.47239 .57651 L 1 g
F P
s
P
p
.472 .57638 m .47177 .5763 L .47195 .57637 L 1 g
F
P
p
.47214 .57643 m .47195 .57637 L .47208 .57643 L 1 g
F
P
p
.002 w
.4814 .55236 m .49216 .55669 L .47257 .57656 L p
1 g
F P
s
P
p
.002 w
.47257 .57656 m .47224 .57689 L .47239 .57651 L p
1 g
F P
s
P
p
.002 w
.47239 .57651 m .4814 .55236 L p
.47257 .57656 L 1 g
F P
s
P
p
.002 w
.49216 .55669 m .50073 .56298 L .47279 .57663 L p
1 g
F P
s
P
p
.002 w
.47279 .57663 m .47224 .57689 L .47257 .57656 L p
1 g
F P
s
P
p
.002 w
.47257 .57656 m .49216 .55669 L p
.47279 .57663 L 1 g
F P
s
P
p
.47226 .57648 m .47208 .57643 L .4722 .57647 L 1 g
F
P
p
.47237 .57652 m .4722 .57647 L .47229 .57651 L 1 g
F
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.50073 .56298 m .50618 .5705 L .47314 .57672 L p
1 g
F P
s
P
p
.002 w
.47314 .57672 m .47224 .57689 L .47279 .57663 L p
1 g
F P
s
P
p
.002 w
.47279 .57663 m .50073 .56298 L p
.47314 .57672 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.50618 .5705 m .50793 .5784 L .47413 .57697 L p
1 g
F P
s
P
p
.002 w
.47413 .57697 m .47224 .57689 L .47314 .57672 L p
1 g
F P
s
P
p
.002 w
.47314 .57672 m .50618 .5705 L p
.47413 .57697 L 1 g
F P
s
P
p
.47247 .57655 m .47229 .57651 L .47238 .57654 L 1 g
F
P
p
.4766 .57758 m .47238 .57654 L .47466 .57742 L 1 g
F
P
p
.002 w
.44853 .55461 m .47149 .57619 L p
.46632 .57366 L 1 g
F P
s
P
p
.002 w
.46968 .57549 m .46632 .57366 L p
.47149 .57619 L 1 g
F P
s
P
p
.002 w
.46632 .57366 m .47224 .57689 L .47037 .57636 L p
1 g
F P
s
P
p
.002 w
.47108 .57683 m .47224 .57689 L .47143 .57705 L p
1 g
F P
s
P
p
.47466 .57742 m .46968 .57549 L .4678 .57686 L 1 g
F
P
p
.002 w
.46822 .57493 m .46822 .57494 L p
.46968 .57549 L 1 g
F P
s
P
p
.002 w
.46822 .57494 m .4678 .57686 L p
.46968 .57549 L 1 g
F P
s
P
p
.002 w
.46821 .57501 m .46822 .57494 L p
.45726 .56807 L 1 g
F P
s
P
p
.002 w
.46822 .57494 m .46822 .57493 L p
.46807 .57483 L 1 g
F P
s
P
p
.46807 .57483 m .45726 .56807 L .46822 .57494 L 1 g
F
P
p
.45309 .56479 m .44853 .55461 L .46632 .57366 L 1 g
F
P
p
.002 w
.45073 .56326 m .45074 .56321 L p
.44002 .55134 L 1 g
F P
s
P
p
.44105 .55225 m .44002 .55134 L .45074 .56321 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45073 .56326 L p
1 g
F P
s
P
p
.44002 .55134 m .43743 .5491 L .45073 .56326 L 1 g
F
P
p
.43791 .56715 m .45407 .56697 L .45846 .57186 L 1 g
F
P
p
.45896 .56875 m .45726 .56807 L .46822 .57493 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46821 .57501 L p
1 g
F P
s
P
p
.45726 .56807 m .45002 .56518 L .46821 .57501 L 1 g
F
P
p
.002 w
.47801 .3104 m .41147 .31778 L .41499 .29174 L p
1 g
F P
s
P
p
.002 w
.41499 .29174 m .48244 .28394 L .47801 .3104 L p
1 g
F P
s
P
p
.002 w
.62927 .44323 m .65365 .48349 L .63083 .50624 L p
1 g
F P
s
P
p
.002 w
.65365 .48349 m .62927 .44323 L .64549 .41545 L p
1 g
F P
s
P
p
.002 w
.41234 .5393 m .4056 .55334 L .37642 .53601 L p
1 g
F P
s
P
p
.002 w
.37642 .53601 m .38583 .5152 L .41234 .5393 L p
1 g
F P
s
P
p
.002 w
.60973 .34867 m .65702 .38874 L .64549 .41545 L p
1 g
F P
s
P
p
.002 w
.65702 .38874 m .60973 .34867 L .61584 .32292 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.388 .46669 m .36293 .48868 L .3444 .46074 L p
1 g
F P
s
P
p
.002 w
.3444 .46074 m .37392 .43391 L .388 .46669 L p
1 g
F P
s
P
p
.002 w
.55265 .29482 m .61584 .32292 L .60973 .34867 L p
1 g
F P
s
P
p
.002 w
.57313 .54513 m .57716 .56818 L .54332 .57545 L p
1 g
F P
s
P
p
.002 w
.57716 .56818 m .57313 .54513 L .60369 .52705 L p
1 g
F P
s
P
p
.002 w
.4415 .56012 m .43791 .56715 L .4056 .55334 L p
1 g
F P
s
P
p
.002 w
.4056 .55334 m .41234 .5393 L .4415 .56012 L p
1 g
F P
s
P
p
.002 w
.41242 .38137 m .36383 .40139 L .35799 .37032 L p
1 g
F P
s
P
p
.002 w
.35799 .37032 m .41057 .34799 L .41242 .38137 L p
1 g
F P
s
P
p
.002 w
.6088 .47107 m .63083 .50624 L .60369 .52705 L p
1 g
F P
s
P
p
.002 w
.63083 .50624 m .6088 .47107 L .62927 .44323 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40559 .49851 m .38583 .5152 L .36293 .48868 L p
1 g
F P
s
P
p
.002 w
.36293 .48868 m .388 .46669 L .40559 .49851 L p
1 g
F P
s
P
p
.002 w
.50793 .5784 m .50618 .5705 L .54022 .55979 L p
1 g
F P
s
P
p
.002 w
.5473 .32117 m .47801 .3104 L .48244 .28394 L p
1 g
F P
s
P
p
.002 w
.48244 .28394 m .55265 .29482 L .5473 .32117 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.60008 .37762 m .64549 .41545 L .62927 .44323 L p
1 g
F P
s
P
p
.002 w
.64549 .41545 m .60008 .37762 L .60973 .34867 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60973 .34867 m .5473 .32117 L .55265 .29482 L p
1 g
F P
s
P
p
.002 w
.47415 .34127 m .41057 .34799 L .41147 .31778 L p
1 g
F P
s
P
p
.002 w
.41147 .31778 m .47801 .3104 L .47415 .34127 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.42602 .52818 m .41234 .5393 L .38583 .5152 L p
1 g
F P
s
P
p
.002 w
.38583 .5152 m .40559 .49851 L .42602 .52818 L p
1 g
F P
s
P
p
.002 w
.58478 .49795 m .60369 .52705 L .57313 .54513 L p
1 g
F P
s
P
p
.002 w
.60369 .52705 m .58478 .49795 L .6088 .47107 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.50618 .5705 m .50073 .56298 L .5297 .54476 L p
1 g
F P
s
P
p
.002 w
.5297 .54476 m .54022 .55979 L .50618 .5705 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41701 .41675 m .37392 .43391 L .36383 .40139 L p
1 g
F P
s
P
p
.002 w
.36383 .40139 m .41242 .38137 L .41701 .41675 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.5473 .32117 m .60973 .34867 L .60008 .37762 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.54022 .55979 m .5297 .54476 L .55808 .52282 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.50073 .56298 m .49216 .55669 L .5128 .53211 L p
1 g
F P
s
P
p
.002 w
.5128 .53211 m .5297 .54476 L .50073 .56298 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58714 .40881 m .62927 .44323 L .6088 .47107 L p
1 g
F P
s
P
p
.002 w
.62927 .44323 m .58714 .40881 L .60008 .37762 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.46966 .55048 m .45827 .55126 L .44527 .52133 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.49216 .55669 m .4814 .55236 L .49138 .52338 L p
1 g
F P
s
P
p
.002 w
.49138 .52338 m .5128 .53211 L .49216 .55669 L p
1 g
F P
s
P
p
.002 w
.42422 .45279 m .388 .46669 L .37392 .43391 L p
1 g
F P
s
P
p
.002 w
.37392 .43391 m .41701 .41675 L .42422 .45279 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4814 .55236 m .46966 .55048 L .46794 .51964 L p
1 g
F P
s
P
p
.002 w
.44527 .52133 m .46794 .51964 L .46966 .55048 L p
1 g
F P
s
P
p
.002 w
.46794 .51964 m .49138 .52338 L .4814 .55236 L p
1 g
F P
s
P
p
.002 w
.54035 .3516 m .47415 .34127 L .47801 .3104 L p
1 g
F P
s
P
p
.002 w
.47801 .3104 m .5473 .32117 L .54035 .3516 L p
1 g
F P
s
P
p
.002 w
.47101 .37553 m .41242 .38137 L .41057 .34799 L p
1 g
F P
s
P
p
.002 w
.41057 .34799 m .47415 .34127 L .47101 .37553 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.60008 .37762 m .54035 .3516 L .5473 .32117 L p
1 g
F P
s
P
p
.002 w
.5297 .54476 m .5128 .53211 L .5334 .50395 L p
1 g
F P
s
P
p
.002 w
.5334 .50395 m .55808 .52282 L .5297 .54476 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.43377 .4881 m .40559 .49851 L .388 .46669 L p
1 g
F P
s
P
p
.002 w
.388 .46669 m .42422 .45279 L .43377 .4881 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5713 .44109 m .6088 .47107 L .58478 .49795 L p
1 g
F P
s
P
p
.002 w
.6088 .47107 m .5713 .44109 L .58714 .40881 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54035 .3516 m .60008 .37762 L .58714 .40881 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.58478 .49795 m .55316 .47322 L .5713 .44109 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.5128 .53211 m .49138 .52338 L .50183 .49092 L p
1 g
F P
s
P
p
.002 w
.50183 .49092 m .5334 .50395 L .5128 .53211 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.46875 .41192 m .41701 .41675 L .41242 .38137 L p
1 g
F P
s
P
p
.002 w
.41242 .38137 m .47101 .37553 L .46875 .41192 L p
1 g
F P
s
P
p
.004 w
.46882 .41081 m
.5 .43051 L
s
P
p
.004 w
.428 .38501 m
.43385 .3887 L
s
P
p
.004 w
.39195 .36222 m
.428 .38501 L
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49138 .52338 m .46794 .51964 L .46719 .48541 L p
1 g
F P
s
P
p
.002 w
.46719 .48541 m .50183 .49092 L .49138 .52338 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.532 .38509 m .47101 .37553 L .47415 .34127 L p
1 g
F P
s
P
p
.002 w
.47415 .34127 m .54035 .3516 L .532 .38509 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.004 w
.46094 .63649 m
.46286 .62636 L
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.532 .38509 m .58714 .40881 L .5713 .44109 L p
1 g
F P
s
P
p
.002 w
.58714 .40881 m .532 .38509 L .54035 .3516 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.46746 .44904 m .42422 .45279 L .41701 .41675 L p
1 g
F P
s
P
p
.002 w
.41701 .41675 m .46875 .41192 L .46746 .44904 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52255 .42039 m .5713 .44109 L .55316 .47322 L p
1 g
F P
s
P
p
.002 w
.5713 .44109 m .52255 .42039 L .532 .38509 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55316 .47322 m .51236 .45614 L .52255 .42039 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.52255 .42039 m .46875 .41192 L .47101 .37553 L p
1 g
F P
s
P
p
.002 w
.47101 .37553 m .532 .38509 L .52255 .42039 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51236 .45614 m .46746 .44904 L .46875 .41192 L p
1 g
F P
s
P
p
.002 w
.46875 .41192 m .52255 .42039 L .51236 .45614 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .39195 .36222 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .45605 .6623 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.276744)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.276744)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46262 .43697 m .49983 .45627 L .50973 .4295 L p
1 g
F P
s
P
p
.002 w
.50973 .4295 m .47872 .41337 L .46262 .43697 L p
1 g
F P
s
P
p
.002 w
.54359 .43714 m .50973 .4295 L .49983 .45627 L p
1 g
F P
s
P
p
.002 w
.47872 .41337 m .50973 .4295 L .5194 .40272 L p
1 g
F P
s
P
p
.002 w
.50973 .4295 m .54359 .43714 L .5457 .40858 L p
1 g
F P
s
P
p
.002 w
.5457 .40858 m .5194 .40272 L .50973 .4295 L p
1 g
F P
s
P
p
.002 w
.44734 .46055 m .48989 .48257 L .49983 .45627 L p
1 g
F P
s
P
p
.002 w
.49983 .45627 m .46262 .43697 L .44734 .46055 L p
1 g
F P
s
P
p
.002 w
.54042 .46556 m .49983 .45627 L .48989 .48257 L p
1 g
F P
s
P
p
.002 w
.49983 .45627 m .54042 .46556 L .54359 .43714 L p
1 g
F P
s
P
p
.002 w
.43221 .40938 m .46262 .43697 L .47872 .41337 L p
1 g
F P
s
P
p
.002 w
.47872 .41337 m .4535 .39025 L .43221 .40938 L p
1 g
F P
s
P
p
.002 w
.4535 .39025 m .47872 .41337 L .49534 .39018 L p
1 g
F P
s
P
p
.002 w
.5194 .40272 m .49534 .39018 L .47872 .41337 L p
1 g
F P
s
P
p
.002 w
.49534 .39018 m .5194 .40272 L .52867 .37643 L p
1 g
F P
s
P
p
.002 w
.5194 .40272 m .5457 .40858 L .54671 .38039 L p
1 g
F P
s
P
p
.002 w
.54671 .38039 m .52867 .37643 L .5194 .40272 L p
1 g
F P
s
P
p
.002 w
.41242 .42917 m .44734 .46055 L .46262 .43697 L p
1 g
F P
s
P
p
.002 w
.46262 .43697 m .43221 .40938 L .41242 .42917 L p
1 g
F P
s
P
p
.002 w
.49534 .39018 m .47586 .37215 L .4535 .39025 L p
1 g
F P
s
P
p
.002 w
.47586 .37215 m .49534 .39018 L .51218 .36781 L p
1 g
F P
s
P
p
.002 w
.52867 .37643 m .51218 .36781 L .49534 .39018 L p
1 g
F P
s
P
p
.002 w
.57711 .43547 m .54359 .43714 L .54042 .46556 L p
1 g
F P
s
P
p
.002 w
.54359 .43714 m .57711 .43547 L .57167 .4071 L p
1 g
F P
s
P
p
.002 w
.57167 .4071 m .5457 .40858 L .54359 .43714 L p
1 g
F P
s
P
p
.002 w
.5457 .40858 m .57167 .4071 L .56447 .37926 L p
1 g
F P
s
P
p
.002 w
.56447 .37926 m .54671 .38039 L .5457 .40858 L p
1 g
F P
s
P
p
.002 w
.43315 .48368 m .48007 .5079 L .48989 .48257 L p
1 g
F P
s
P
p
.002 w
.48989 .48257 m .44734 .46055 L .43315 .48368 L p
1 g
F P
s
P
p
.002 w
.53625 .49332 m .48989 .48257 L .48007 .5079 L p
1 g
F P
s
P
p
.002 w
.48989 .48257 m .53625 .49332 L .54042 .46556 L p
1 g
F P
s
P
p
.002 w
.58068 .46384 m .54042 .46556 L .53625 .49332 L p
1 g
F P
s
P
p
.002 w
.54042 .46556 m .58068 .46384 L .57711 .43547 L p
1 g
F P
s
P
p
.002 w
.39451 .44928 m .43315 .48368 L .44734 .46055 L p
1 g
F P
s
P
p
.002 w
.44734 .46055 m .41242 .42917 L .39451 .44928 L p
1 g
F P
s
P
p
.002 w
.51218 .36781 m .52867 .37643 L .53737 .3511 L p
1 g
F P
s
P
p
.002 w
.52867 .37643 m .54671 .38039 L .54658 .3531 L p
1 g
F P
s
P
p
.002 w
.54658 .3531 m .53737 .3511 L .52867 .37643 L p
1 g
F P
s
P
p
.002 w
.41161 .3759 m .43221 .40938 L .4535 .39025 L p
1 g
F P
s
P
p
.002 w
.4535 .39025 m .4366 .36224 L .41161 .3759 L p
1 g
F P
s
P
p
.002 w
.4366 .36224 m .4535 .39025 L .47586 .37215 L p
1 g
F P
s
P
p
.002 w
.47586 .37215 m .46297 .35034 L .4366 .36224 L p
1 g
F P
s
P
p
.002 w
.46297 .35034 m .47586 .37215 L .4989 .35539 L p
1 g
F P
s
P
p
.002 w
.51218 .36781 m .4989 .35539 L .47586 .37215 L p
1 g
F P
s
P
p
.002 w
.4989 .35539 m .51218 .36781 L .52894 .34669 L p
1 g
F P
s
P
p
.002 w
.53737 .3511 m .52894 .34669 L .51218 .36781 L p
1 g
F P
s
P
p
.002 w
.54671 .38039 m .56447 .37926 L .55563 .35246 L p
1 g
F P
s
P
p
.002 w
.55563 .35246 m .54658 .3531 L .54671 .38039 L p
1 g
F P
s
P
p
.002 w
.38852 .39109 m .41242 .42917 L .43221 .40938 L p
1 g
F P
s
P
p
.002 w
.43221 .40938 m .41161 .3759 L .38852 .39109 L p
1 g
F P
s
P
p
.002 w
.48007 .5079 m .53113 .51989 L .53625 .49332 L p
1 g
F P
s
P
p
.002 w
.5823 .49166 m .53625 .49332 L .53113 .51989 L p
1 g
F P
s
P
p
.002 w
.53625 .49332 m .5823 .49166 L .58068 .46384 L p
1 g
F P
s
P
p
.002 w
.4989 .35539 m .49023 .34041 L .46297 .35034 L p
1 g
F P
s
P
p
.002 w
.49023 .34041 m .4989 .35539 L .5222 .34032 L p
1 g
F P
s
P
p
.002 w
.52894 .34669 m .5222 .34032 L .4989 .35539 L p
1 g
F P
s
P
p
.002 w
.59471 .39832 m .57167 .4071 L .57711 .43547 L p
1 g
F P
s
P
p
.002 w
.57167 .4071 m .59471 .39832 L .58013 .37309 L p
1 g
F P
s
P
p
.002 w
.58013 .37309 m .56447 .37926 L .57167 .4071 L p
1 g
F P
s
P
p
.002 w
.607 .42444 m .57711 .43547 L .58068 .46384 L p
1 g
F P
s
P
p
.002 w
.57711 .43547 m .607 .42444 L .59471 .39832 L p
1 g
F P
s
P
p
.002 w
.42037 .50591 m .47057 .53177 L .48007 .5079 L p
1 g
F P
s
P
p
.002 w
.48007 .5079 m .43315 .48368 L .42037 .50591 L p
1 g
F P
s
P
p
.002 w
.53113 .51989 m .48007 .5079 L .47057 .53177 L p
1 g
F P
s
P
p
.002 w
.56447 .37926 m .58013 .37309 L .56356 .34925 L p
1 g
F P
s
P
p
.002 w
.56356 .34925 m .55563 .35246 L .56447 .37926 L p
1 g
F P
s
P
p
.002 w
.37888 .46932 m .42037 .50591 L .43315 .48368 L p
1 g
F P
s
P
p
.002 w
.43315 .48368 m .39451 .44928 L .37888 .46932 L p
1 g
F P
s
P
p
.002 w
.61675 .45096 m .58068 .46384 L .5823 .49166 L p
1 g
F P
s
P
p
.002 w
.58068 .46384 m .61675 .45096 L .607 .42444 L p
1 g
F P
s
P
p
.002 w
.36783 .40752 m .39451 .44928 L .41242 .42917 L p
1 g
F P
s
P
p
.002 w
.41242 .42917 m .38852 .39109 L .36783 .40752 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .52894 .34669 L .53737 .3511 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .53737 .3511 L .54658 .3531 L closepath p
1 g
F P
s
P
p
.002 w
.42995 .33197 m .4366 .36224 L .46297 .35034 L p
1 g
F P
s
P
p
.002 w
.46297 .35034 m .45812 .32687 L .42995 .33197 L p
1 g
F P
s
P
p
.002 w
.45812 .32687 m .46297 .35034 L .49023 .34041 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .5222 .34032 L .52894 .34669 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .54658 .3531 L .55563 .35246 L closepath p
1 g
F P
s
P
p
.002 w
.49023 .34041 m .48712 .32437 L .45812 .32687 L p
1 g
F P
s
P
p
.002 w
.48712 .32437 m .49023 .34041 L .51785 .33266 L p
1 g
F P
s
P
p
.002 w
.5222 .34032 m .51785 .33266 L .49023 .34041 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .51785 .33266 L .5222 .34032 L closepath p
1 g
F P
s
P
p
.002 w
.40318 .3396 m .41161 .3759 L .4366 .36224 L p
1 g
F P
s
P
p
.002 w
.4366 .36224 m .42995 .33197 L .40318 .3396 L p
1 g
F P
s
P
p
.002 w
.47057 .53177 m .52515 .54473 L .53113 .51989 L p
1 g
F P
s
P
p
.002 w
.5819 .51839 m .53113 .51989 L .52515 .54473 L p
1 g
F P
s
P
p
.002 w
.53113 .51989 m .5819 .51839 L .5823 .49166 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .55563 .35246 L .56356 .34925 L closepath p
1 g
F P
s
P
p
.002 w
.59201 .36245 m .58013 .37309 L .59471 .39832 L p
1 g
F P
s
P
p
.002 w
.58013 .37309 m .59201 .36245 L .56951 .34376 L p
1 g
F P
s
P
p
.002 w
.56951 .34376 m .56356 .34925 L .58013 .37309 L p
1 g
F P
s
P
p
.002 w
.51785 .33266 m .51637 .3245 L .48712 .32437 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .51637 .3245 L .51785 .33266 L closepath p
1 g
F P
s
P
p
.002 w
.61236 .38293 m .59471 .39832 L .607 .42444 L p
1 g
F P
s
P
p
.002 w
.59471 .39832 m .61236 .38293 L .59201 .36245 L p
1 g
F P
s
P
p
.002 w
.62372 .47735 m .5823 .49166 L .5819 .51839 L p
1 g
F P
s
P
p
.002 w
.5823 .49166 m .62372 .47735 L .61675 .45096 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .56356 .34925 L .56951 .34376 L closepath p
1 g
F P
s
P
p
.002 w
.3784 .34966 m .38852 .39109 L .41161 .3759 L p
1 g
F P
s
P
p
.002 w
.41161 .3759 m .40318 .3396 L .3784 .34966 L p
1 g
F P
s
P
p
.002 w
.40928 .52679 m .46159 .55367 L .47057 .53177 L p
1 g
F P
s
P
p
.002 w
.47057 .53177 m .42037 .50591 L .40928 .52679 L p
1 g
F P
s
P
p
.002 w
.52515 .54473 m .47057 .53177 L .46159 .55367 L p
1 g
F P
s
P
p
.002 w
.46207 .30416 m .45812 .32687 L .48712 .32437 L p
1 g
F P
s
P
p
.002 w
.48712 .32437 m .49003 .30895 L .46207 .30416 L p
1 g
F P
s
P
p
.002 w
.49003 .30895 m .48712 .32437 L .51637 .3245 L p
1 g
F P
s
P
p
.002 w
.35003 .42491 m .37888 .46932 L .39451 .44928 L p
1 g
F P
s
P
p
.002 w
.39451 .44928 m .36783 .40752 L .35003 .42491 L p
1 g
F P
s
P
p
.002 w
.63011 .40484 m .607 .42444 L .61675 .45096 L p
1 g
F P
s
P
p
.002 w
.607 .42444 m .63011 .40484 L .61236 .38293 L p
1 g
F P
s
P
p
.002 w
.51637 .3245 m .51796 .31671 L .49003 .30895 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .51796 .31671 L .51637 .3245 L closepath p
1 g
F P
s
P
p
.002 w
.36593 .48886 m .40928 .52679 L .42037 .50591 L p
1 g
F P
s
P
p
.002 w
.42037 .50591 m .37888 .46932 L .36593 .48886 L p
1 g
F P
s
P
p
.002 w
.57281 .33659 m .56951 .34376 L .59201 .36245 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .56951 .34376 L .57281 .33659 L closepath p
1 g
F P
s
P
p
.002 w
.43465 .30249 m .42995 .33197 L .45812 .32687 L p
1 g
F P
s
P
p
.002 w
.45812 .32687 m .46207 .30416 L .43465 .30249 L p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .53816 .30342 L .52946 .30554 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .52946 .30554 L .52247 .31015 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .52247 .31015 L .51796 .31671 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .57281 .33659 L .57309 .32847 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .57309 .32847 L .57026 .3203 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .57026 .3203 L .56462 .31299 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .56462 .31299 L .55678 .30736 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .55678 .30736 L .54762 .30405 L closepath p
1 g
F P
s
P
p
.002 w
.5453 .32725 m .54762 .30405 L .53816 .30342 L closepath p
1 g
F P
s
P
p
.002 w
.59875 .34835 m .59201 .36245 L .61236 .38293 L p
1 g
F P
s
P
p
.002 w
.59201 .36245 m .59875 .34835 L .57281 .33659 L p
1 g
F P
s
P
p
.002 w
.49878 .29584 m .49003 .30895 L .51796 .31671 L p
1 g
F P
s
P
p
.002 w
.51796 .31671 m .52247 .31015 L .49878 .29584 L p
1 g
F P
s
P
p
.002 w
.46159 .55367 m .51839 .56731 L .52515 .54473 L p
1 g
F P
s
P
p
.002 w
.57943 .54347 m .52515 .54473 L .51839 .56731 L p
1 g
F P
s
P
p
.002 w
.52515 .54473 m .57943 .54347 L .5819 .51839 L p
1 g
F P
s
P
p
.002 w
.3562 .36201 m .36783 .40752 L .38852 .39109 L p
1 g
F P
s
P
p
.002 w
.38852 .39109 m .3784 .34966 L .3562 .36201 L p
1 g
F P
s
P
p
.002 w
.64486 .42773 m .61675 .45096 L .62372 .47735 L p
1 g
F P
s
P
p
.002 w
.61675 .45096 m .64486 .42773 L .63011 .40484 L p
1 g
F P
s
P
p
.002 w
.57309 .32847 m .57281 .33659 L .59875 .34835 L p
1 g
F P
s
P
p
.002 w
.62769 .50305 m .5819 .51839 L .57943 .54347 L p
1 g
F P
s
P
p
.002 w
.5819 .51839 m .62769 .50305 L .62372 .47735 L p
1 g
F P
s
P
p
.002 w
.40838 .30405 m .40318 .3396 L .42995 .33197 L p
1 g
F P
s
P
p
.002 w
.42995 .33197 m .43465 .30249 L .40838 .30405 L p
1 g
F P
s
P
p
.002 w
.47469 .28469 m .46207 .30416 L .49003 .30895 L p
1 g
F P
s
P
p
.002 w
.49003 .30895 m .49878 .29584 L .47469 .28469 L p
1 g
F P
s
P
p
.002 w
.62257 .36236 m .61236 .38293 L .63011 .40484 L p
1 g
F P
s
P
p
.002 w
.61236 .38293 m .62257 .36236 L .59875 .34835 L p
1 g
F P
s
P
p
.002 w
.51254 .28655 m .49878 .29584 L .52247 .31015 L p
1 g
F P
s
P
p
.002 w
.52247 .31015 m .52946 .30554 L .51254 .28655 L p
1 g
F P
s
P
p
.002 w
.59875 .34835 m .5995 .33228 L .57309 .32847 L p
1 g
F P
s
P
p
.002 w
.57026 .3203 m .57309 .32847 L .5995 .33228 L p
1 g
F P
s
P
p
.002 w
.33562 .4429 m .36593 .48886 L .37888 .46932 L p
1 g
F P
s
P
p
.002 w
.37888 .46932 m .35003 .42491 L .33562 .4429 L p
1 g
F P
s
P
p
.002 w
.52985 .2822 m .51254 .28655 L .52946 .30554 L p
1 g
F P
s
P
p
.002 w
.52946 .30554 m .53816 .30342 L .52985 .2822 L p
1 g
F P
s
P
p
.002 w
.5995 .33228 m .59875 .34835 L .62257 .36236 L p
1 g
F P
s
P
p
.002 w
.40017 .54581 m .45332 .57308 L .46159 .55367 L p
1 g
F P
s
P
p
.002 w
.46159 .55367 m .40928 .52679 L .40017 .54581 L p
1 g
F P
s
P
p
.002 w
.51839 .56731 m .46159 .55367 L .45332 .57308 L p
1 g
F P
s
P
p
.002 w
.5995 .33228 m .59403 .31599 L .57026 .3203 L p
1 g
F P
s
P
p
.002 w
.56462 .31299 m .57026 .3203 L .59403 .31599 L p
1 g
F P
s
P
p
.002 w
.45071 .27703 m .43465 .30249 L .46207 .30416 L p
1 g
F P
s
P
p
.002 w
.46207 .30416 m .47469 .28469 L .45071 .27703 L p
1 g
F P
s
P
p
.002 w
.65619 .45116 m .62372 .47735 L .62769 .50305 L p
1 g
F P
s
P
p
.002 w
.62372 .47735 m .65619 .45116 L .64486 .42773 L p
1 g
F P
s
P
p
.002 w
.35604 .50749 m .40017 .54581 L .40928 .52679 L p
1 g
F P
s
P
p
.002 w
.40928 .52679 m .36593 .48886 L .35604 .50749 L p
1 g
F P
s
P
p
.002 w
.6437 .37835 m .63011 .40484 L .64486 .42773 L p
1 g
F P
s
P
p
.002 w
.63011 .40484 m .6437 .37835 L .62257 .36236 L p
1 g
F P
s
P
p
.002 w
.54879 .28338 m .52985 .2822 L .53816 .30342 L p
1 g
F P
s
P
p
.002 w
.53816 .30342 m .54762 .30405 L .54879 .28338 L p
1 g
F P
s
P
p
.002 w
.38385 .30892 m .3784 .34966 L .40318 .3396 L p
1 g
F P
s
P
p
.002 w
.40318 .3396 m .40838 .30405 L .38385 .30892 L p
1 g
F P
s
P
p
.002 w
.59403 .31599 m .58284 .30132 L .56462 .31299 L p
1 g
F P
s
P
p
.002 w
.55678 .30736 m .56462 .31299 L .58284 .30132 L p
1 g
F P
s
P
p
.002 w
.33715 .37646 m .35003 .42491 L .36783 .40752 L p
1 g
F P
s
P
p
.002 w
.36783 .40752 m .3562 .36201 L .33715 .37646 L p
1 g
F P
s
P
p
.002 w
.49487 .27076 m .47469 .28469 L .49878 .29584 L p
1 g
F P
s
P
p
.002 w
.49878 .29584 m .51254 .28655 L .49487 .27076 L p
1 g
F P
s
P
p
.002 w
.56716 .29001 m .54879 .28338 L .54762 .30405 L p
1 g
F P
s
P
p
.002 w
.54762 .30405 m .55678 .30736 L .56716 .29001 L p
1 g
F P
s
P
p
.002 w
.58284 .30132 m .56716 .29001 L .55678 .30736 L p
1 g
F P
s
P
p
.002 w
.45332 .57308 m .51096 .58706 L .51839 .56731 L p
1 g
F P
s
P
p
.002 w
.57487 .56631 m .51839 .56731 L .51096 .58706 L p
1 g
F P
s
P
p
.002 w
.51839 .56731 m .57487 .56631 L .57943 .54347 L p
1 g
F P
s
P
p
.002 w
.62847 .52752 m .57943 .54347 L .57487 .56631 L p
1 g
F P
s
P
p
.002 w
.57943 .54347 m .62847 .52752 L .62769 .50305 L p
1 g
F P
s
P
p
.002 w
.62257 .36236 m .62395 .33868 L .5995 .33228 L p
1 g
F P
s
P
p
.002 w
.59403 .31599 m .5995 .33228 L .62395 .33868 L p
1 g
F P
s
P
p
.002 w
.62395 .33868 m .62257 .36236 L .6437 .37835 L p
1 g
F P
s
P
p
.002 w
.42738 .27316 m .40838 .30405 L .43465 .30249 L p
1 g
F P
s
P
p
.002 w
.43465 .30249 m .45071 .27703 L .42738 .27316 L p
1 g
F P
s
P
p
.002 w
.52052 .26415 m .49487 .27076 L .51254 .28655 L p
1 g
F P
s
P
p
.002 w
.51254 .28655 m .52985 .2822 L .52052 .26415 L p
1 g
F P
s
P
p
.002 w
.66162 .39606 m .64486 .42773 L .65619 .45116 L p
1 g
F P
s
P
p
.002 w
.64486 .42773 m .66162 .39606 L .6437 .37835 L p
1 g
F P
s
P
p
.002 w
.36171 .31711 m .3562 .36201 L .3784 .34966 L p
1 g
F P
s
P
p
.002 w
.3784 .34966 m .38385 .30892 L .36171 .31711 L p
1 g
F P
s
P
p
.002 w
.32507 .46112 m .35604 .50749 L .36593 .48886 L p
1 g
F P
s
P
p
.002 w
.36593 .48886 m .33562 .4429 L .32507 .46112 L p
1 g
F P
s
P
p
.002 w
.66376 .47462 m .62769 .50305 L .62847 .52752 L p
1 g
F P
s
P
p
.002 w
.62769 .50305 m .66376 .47462 L .65619 .45116 L p
1 g
F P
s
P
p
.002 w
.47682 .25866 m .45071 .27703 L .47469 .28469 L p
1 g
F P
s
P
p
.002 w
.47469 .28469 m .49487 .27076 L .47682 .25866 L p
1 g
F P
s
P
p
.002 w
.62395 .33868 m .61605 .31449 L .59403 .31599 L p
1 g
F P
s
P
p
.002 w
.58284 .30132 m .59403 .31599 L .61605 .31449 L p
1 g
F P
s
P
p
.002 w
.39334 .5625 m .44597 .58946 L .45332 .57308 L p
1 g
F P
s
P
p
.002 w
.45332 .57308 m .40017 .54581 L .39334 .5625 L p
1 g
F P
s
P
p
.002 w
.51096 .58706 m .45332 .57308 L .44597 .58946 L p
1 g
F P
s
P
p
.002 w
.32184 .39275 m .33562 .4429 L .35003 .42491 L p
1 g
F P
s
P
p
.002 w
.35003 .42491 m .33715 .37646 L .32184 .39275 L p
1 g
F P
s
P
p
.002 w
.54873 .26582 m .52052 .26415 L .52985 .2822 L p
1 g
F P
s
P
p
.002 w
.52985 .2822 m .54879 .28338 L .54873 .26582 L p
1 g
F P
s
P
p
.002 w
.34958 .52474 m .39334 .5625 L .40017 .54581 L p
1 g
F P
s
P
p
.002 w
.40017 .54581 m .35604 .50749 L .34958 .52474 L p
1 g
F P
s
P
p
.002 w
.64583 .34762 m .6437 .37835 L .66162 .39606 L p
1 g
F P
s
P
p
.002 w
.6437 .37835 m .64583 .34762 L .62395 .33868 L p
1 g
F P
s
P
p
.002 w
.61605 .31449 m .59952 .29262 L .58284 .30132 L p
1 g
F P
s
P
p
.002 w
.56716 .29001 m .58284 .30132 L .59952 .29262 L p
1 g
F P
s
P
p
.002 w
.61605 .31449 m .62395 .33868 L .64583 .34762 L p
1 g
F P
s
P
p
.002 w
.57616 .2757 m .54873 .26582 L .54879 .28338 L p
1 g
F P
s
P
p
.002 w
.54879 .28338 m .56716 .29001 L .57616 .2757 L p
1 g
F P
s
P
p
.002 w
.51096 .58706 m .56824 .58631 L .57487 .56631 L p
1 g
F P
s
P
p
.002 w
.62594 .55014 m .57487 .56631 L .56824 .58631 L p
1 g
F P
s
P
p
.002 w
.57487 .56631 m .62594 .55014 L .62847 .52752 L p
1 g
F P
s
P
p
.002 w
.59952 .29262 m .57616 .2757 L .56716 .29001 L p
1 g
F P
s
P
p
.002 w
.40527 .27333 m .38385 .30892 L .40838 .30405 L p
1 g
F P
s
P
p
.002 w
.40838 .30405 m .42738 .27316 L .40527 .27333 L p
1 g
F P
s
P
p
.002 w
.44597 .58946 m .50299 .6034 L .51096 .58706 L p
1 g
F P
s
P
p
.002 w
.56824 .58631 m .51096 .58706 L .50299 .6034 L p
1 g
F P
s
P
p
.002 w
.67579 .41513 m .65619 .45116 L .66376 .47462 L p
1 g
F P
s
P
p
.002 w
.65619 .45116 m .67579 .41513 L .66162 .39606 L p
1 g
F P
s
P
p
.002 w
.34259 .32856 m .33715 .37646 L .3562 .36201 L p
1 g
F P
s
P
p
.002 w
.3562 .36201 m .36171 .31711 L .34259 .32856 L p
1 g
F P
s
P
p
.002 w
.51032 .24985 m .47682 .25866 L .49487 .27076 L p
1 g
F P
s
P
p
.002 w
.49487 .27076 m .52052 .26415 L .51032 .24985 L p
1 g
F P
s
P
p
.002 w
.66724 .49757 m .62847 .52752 L .62594 .55014 L p
1 g
F P
s
P
p
.002 w
.62847 .52752 m .66724 .49757 L .66376 .47462 L p
1 g
F P
s
P
p
.002 w
.45879 .25072 m .42738 .27316 L .45071 .27703 L p
1 g
F P
s
P
p
.002 w
.45071 .27703 m .47682 .25866 L .45879 .25072 L p
1 g
F P
s
P
p
.002 w
.31881 .47915 m .34958 .52474 L .35604 .50749 L p
1 g
F P
s
P
p
.002 w
.35604 .50749 m .32507 .46112 L .31881 .47915 L p
1 g
F P
s
P
p
.002 w
.64583 .34762 m .63574 .31599 L .61605 .31449 L p
1 g
F P
s
P
p
.002 w
.59952 .29262 m .61605 .31449 L .63574 .31599 L p
1 g
F P
s
P
p
.002 w
.31081 .41058 m .32507 .46112 L .33562 .4429 L p
1 g
F P
s
P
p
.002 w
.33562 .4429 m .32184 .39275 L .31081 .41058 L p
1 g
F P
s
P
p
.002 w
.66454 .35899 m .66162 .39606 L .67579 .41513 L p
1 g
F P
s
P
p
.002 w
.66162 .39606 m .66454 .35899 L .64583 .34762 L p
1 g
F P
s
P
p
.002 w
.54738 .25196 m .51032 .24985 L .52052 .26415 L p
1 g
F P
s
P
p
.002 w
.52052 .26415 m .54873 .26582 L .54738 .25196 L p
1 g
F P
s
P
p
.002 w
.63574 .31599 m .64583 .34762 L .66454 .35899 L p
1 g
F P
s
P
p
.002 w
.38907 .57633 m .43977 .60227 L .44597 .58946 L p
1 g
F P
s
P
p
.002 w
.44597 .58946 m .39334 .5625 L .38907 .57633 L p
1 g
F P
s
P
p
.002 w
.50299 .6034 m .44597 .58946 L .43977 .60227 L p
1 g
F P
s
P
p
.002 w
.38499 .27773 m .36171 .31711 L .38385 .30892 L p
1 g
F P
s
P
p
.002 w
.38385 .30892 m .40527 .27333 L .38499 .27773 L p
1 g
F P
s
P
p
.002 w
.68571 .43517 m .66376 .47462 L .66724 .49757 L p
1 g
F P
s
P
p
.002 w
.66376 .47462 m .68571 .43517 L .67579 .41513 L p
1 g
F P
s
P
p
.002 w
.3469 .54011 m .38907 .57633 L .39334 .5625 L p
1 g
F P
s
P
p
.002 w
.39334 .5625 m .34958 .52474 L .3469 .54011 L p
1 g
F P
s
P
p
.002 w
.63574 .31599 m .61418 .28723 L .59952 .29262 L p
1 g
F P
s
P
p
.002 w
.57616 .2757 m .59952 .29262 L .61418 .28723 L p
1 g
F P
s
P
p
.002 w
.50299 .6034 m .55958 .60289 L .56824 .58631 L p
1 g
F P
s
P
p
.002 w
.62 .5703 m .56824 .58631 L .55958 .60289 L p
1 g
F P
s
P
p
.002 w
.56824 .58631 m .62 .5703 L .62594 .55014 L p
1 g
F P
s
P
p
.002 w
.32712 .34314 m .32184 .39275 L .33715 .37646 L p
1 g
F P
s
P
p
.002 w
.33715 .37646 m .34259 .32856 L .32712 .34314 L p
1 g
F P
s
P
p
.002 w
.58349 .26494 m .54738 .25196 L .54873 .26582 L p
1 g
F P
s
P
p
.002 w
.54873 .26582 m .57616 .2757 L .58349 .26494 L p
1 g
F P
s
P
p
.002 w
.61418 .28723 m .58349 .26494 L .57616 .2757 L p
1 g
F P
s
P
p
.002 w
.43977 .60227 m .49465 .61577 L .50299 .6034 L p
1 g
F P
s
P
p
.002 w
.55958 .60289 m .50299 .6034 L .49465 .61577 L p
1 g
F P
s
P
p
.002 w
.44122 .24733 m .40527 .27333 L .42738 .27316 L p
1 g
F P
s
P
p
.002 w
.42738 .27316 m .45879 .25072 L .44122 .24733 L p
1 g
F P
s
P
p
.002 w
.49946 .23984 m .45879 .25072 L .47682 .25866 L p
1 g
F P
s
P
p
.002 w
.47682 .25866 m .51032 .24985 L .49946 .23984 L p
1 g
F P
s
P
p
.002 w
.66636 .51943 m .62594 .55014 L .62 .5703 L p
1 g
F P
s
P
p
.002 w
.62594 .55014 m .66636 .51943 L .66724 .49757 L p
1 g
F P
s
P
p
.002 w
.67946 .37265 m .67579 .41513 L .68571 .43517 L p
1 g
F P
s
P
p
.002 w
.67579 .41513 m .67946 .37265 L .66454 .35899 L p
1 g
F P
s
P
p
.002 w
.31725 .49651 m .3469 .54011 L .34958 .52474 L p
1 g
F P
s
P
p
.002 w
.34958 .52474 m .31881 .47915 L .31725 .49651 L p
1 g
F P
s
P
p
.002 w
.30456 .42955 m .31881 .47915 L .32507 .46112 L p
1 g
F P
s
P
p
.002 w
.32507 .46112 m .31081 .41058 L .30456 .42955 L p
1 g
F P
s
P
p
.002 w
.66454 .35899 m .65252 .32059 L .63574 .31599 L p
1 g
F P
s
P
p
.002 w
.61418 .28723 m .63574 .31599 L .65252 .32059 L p
1 g
F P
s
P
p
.002 w
.36716 .28645 m .34259 .32856 L .36171 .31711 L p
1 g
F P
s
P
p
.002 w
.36171 .31711 m .38499 .27773 L .36716 .28645 L p
1 g
F P
s
P
p
.002 w
.65252 .32059 m .66454 .35899 L .67946 .37265 L p
1 g
F P
s
P
p
.002 w
.69094 .45573 m .66724 .49757 L .66636 .51943 L p
1 g
F P
s
P
p
.002 w
.66724 .49757 m .69094 .45573 L .68571 .43517 L p
1 g
F P
s
P
p
.002 w
.5447 .24234 m .49946 .23984 L .51032 .24985 L p
1 g
F P
s
P
p
.002 w
.51032 .24985 m .54738 .25196 L .5447 .24234 L p
1 g
F P
s
P
p
.002 w
.38761 .5868 m .43494 .61098 L .43977 .60227 L p
1 g
F P
s
P
p
.002 w
.43977 .60227 m .38907 .57633 L .38761 .5868 L p
1 g
F P
s
P
p
.002 w
.49465 .61577 m .43977 .60227 L .43494 .61098 L p
1 g
F P
s
P
p
.002 w
.31587 .36061 m .31081 .41058 L .32184 .39275 L p
1 g
F P
s
P
p
.002 w
.32184 .39275 m .32712 .34314 L .31587 .36061 L p
1 g
F P
s
P
p
.002 w
.49465 .61577 m .549 .61545 L .55958 .60289 L p
1 g
F P
s
P
p
.002 w
.61063 .58738 m .55958 .60289 L .549 .61545 L p
1 g
F P
s
P
p
.002 w
.55958 .60289 m .61063 .58738 L .62 .5703 L p
1 g
F P
s
P
p
.002 w
.65252 .32059 m .62635 .28549 L .61418 .28723 L p
1 g
F P
s
P
p
.002 w
.58349 .26494 m .61418 .28723 L .62635 .28549 L p
1 g
F P
s
P
p
.002 w
.34827 .55311 m .38761 .5868 L .38907 .57633 L p
1 g
F P
s
P
p
.002 w
.38907 .57633 m .3469 .54011 L .34827 .55311 L p
1 g
F P
s
P
p
.002 w
.42461 .24884 m .38499 .27773 L .40527 .27333 L p
1 g
F P
s
P
p
.002 w
.40527 .27333 m .44122 .24733 L .42461 .24884 L p
1 g
F P
s
P
p
.002 w
.66094 .5396 m .62 .5703 L .61063 .58738 L p
1 g
F P
s
P
p
.002 w
.62 .5703 m .66094 .5396 L .66636 .51943 L p
1 g
F P
s
P
p
.002 w
.48817 .23465 m .44122 .24733 L .45879 .25072 L p
1 g
F P
s
P
p
.002 w
.45879 .25072 m .49946 .23984 L .48817 .23465 L p
1 g
F P
s
P
p
.002 w
.58887 .25821 m .5447 .24234 L .54738 .25196 L p
1 g
F P
s
P
p
.002 w
.54738 .25196 m .58349 .26494 L .58887 .25821 L p
1 g
F P
s
P
p
.002 w
.43494 .61098 m .48611 .62363 L .49465 .61577 L p
1 g
F P
s
P
p
.002 w
.549 .61545 m .49465 .61577 L .48611 .62363 L p
1 g
F P
s
P
p
.002 w
.62635 .28549 m .58887 .25821 L .58349 .26494 L p
1 g
F P
s
P
p
.002 w
.69004 .38835 m .68571 .43517 L .69094 .45573 L p
1 g
F P
s
P
p
.002 w
.68571 .43517 m .69004 .38835 L .67946 .37265 L p
1 g
F P
s
P
p
.002 w
.35239 .29948 m .32712 .34314 L .34259 .32856 L p
1 g
F P
s
P
p
.002 w
.34259 .32856 m .36716 .28645 L .35239 .29948 L p
1 g
F P
s
P
p
.002 w
.30351 .44922 m .31725 .49651 L .31881 .47915 L p
1 g
F P
s
P
p
.002 w
.31881 .47915 m .30456 .42955 L .30351 .44922 L p
1 g
F P
s
P
p
.002 w
.67946 .37265 m .66579 .32835 L .65252 .32059 L p
1 g
F P
s
P
p
.002 w
.62635 .28549 m .65252 .32059 L .66579 .32835 L p
1 g
F P
s
P
p
.002 w
.32067 .5127 m .34827 .55311 L .3469 .54011 L p
1 g
F P
s
P
p
.002 w
.3469 .54011 m .31725 .49651 L .32067 .5127 L p
1 g
F P
s
P
p
.002 w
.66579 .32835 m .67946 .37265 L .69004 .38835 L p
1 g
F P
s
P
p
.002 w
.69112 .4763 m .66636 .51943 L .66094 .5396 L p
1 g
F P
s
P
p
.002 w
.66636 .51943 m .69112 .4763 L .69094 .45573 L p
1 g
F P
s
P
p
.002 w
.3094 .38063 m .30456 .42955 L .31081 .41058 L p
1 g
F P
s
P
p
.002 w
.31081 .41058 m .31587 .36061 L .3094 .38063 L p
1 g
F P
s
P
p
.002 w
.54066 .23751 m .48817 .23465 L .49946 .23984 L p
1 g
F P
s
P
p
.002 w
.49946 .23984 m .5447 .24234 L .54066 .23751 L p
1 g
F P
s
P
p
.002 w
.40947 .2555 m .36716 .28645 L .38499 .27773 L p
1 g
F P
s
P
p
.002 w
.38499 .27773 m .42461 .24884 L .40947 .2555 L p
1 g
F P
s
P
p
.002 w
.48611 .62363 m .53667 .62343 L .549 .61545 L p
1 g
F P
s
P
p
.002 w
.59789 .60079 m .549 .61545 L .53667 .62343 L p
1 g
F P
s
P
p
.002 w
.549 .61545 m .59789 .60079 L .61063 .58738 L p
1 g
F P
s
P
p
.002 w
.38919 .59341 m .43169 .61512 L .43494 .61098 L p
1 g
F P
s
P
p
.002 w
.43494 .61098 m .38761 .5868 L .38919 .59341 L p
1 g
F P
s
P
p
.002 w
.48611 .62363 m .43494 .61098 L .43169 .61512 L p
1 g
F P
s
P
p
.002 w
.65089 .55745 m .61063 .58738 L .59789 .60079 L p
1 g
F P
s
P
p
.002 w
.61063 .58738 m .65089 .55745 L .66094 .5396 L p
1 g
F P
s
P
p
.002 w
.66579 .32835 m .63555 .28767 L .62635 .28549 L p
1 g
F P
s
P
p
.002 w
.58887 .25821 m .62635 .28549 L .63555 .28767 L p
1 g
F P
s
P
p
.002 w
.47675 .23471 m .42461 .24884 L .44122 .24733 L p
1 g
F P
s
P
p
.002 w
.44122 .24733 m .48817 .23465 L .47675 .23471 L p
1 g
F P
s
P
p
.002 w
.35391 .56325 m .38919 .59341 L .38761 .5868 L p
1 g
F P
s
P
p
.002 w
.38761 .5868 m .34827 .55311 L .35391 .56325 L p
1 g
F P
s
P
p
.002 w
.69574 .40579 m .69094 .45573 L .69112 .4763 L p
1 g
F P
s
P
p
.002 w
.69094 .45573 m .69574 .40579 L .69004 .38835 L p
1 g
F P
s
P
p
.002 w
.59202 .25596 m .54066 .23751 L .5447 .24234 L p
1 g
F P
s
P
p
.002 w
.5447 .24234 m .58887 .25821 L .59202 .25596 L p
1 g
F P
s
P
p
.002 w
.43169 .61512 m .4776 .62649 L .48611 .62363 L p
1 g
F P
s
P
p
.002 w
.53667 .62343 m .48611 .62363 L .4776 .62649 L p
1 g
F P
s
P
p
.002 w
.34127 .31669 m .31587 .36061 L .32712 .34314 L p
1 g
F P
s
P
p
.002 w
.32712 .34314 m .35239 .29948 L .34127 .31669 L p
1 g
F P
s
P
p
.002 w
.63555 .28767 m .59202 .25596 L .58887 .25821 L p
1 g
F P
s
P
p
.002 w
.30796 .46906 m .32067 .5127 L .31725 .49651 L p
1 g
F P
s
P
p
.002 w
.31725 .49651 m .30351 .44922 L .30796 .46906 L p
1 g
F P
s
P
p
.002 w
.68597 .49629 m .66094 .5396 L .65089 .55745 L p
1 g
F P
s
P
p
.002 w
.66094 .5396 m .68597 .49629 L .69112 .4763 L p
1 g
F P
s
P
p
.002 w
.675 .33925 m .69004 .38835 L .69574 .40579 L p
1 g
F P
s
P
p
.002 w
.69004 .38835 m .675 .33925 L .66579 .32835 L p
1 g
F P
s
P
p
.002 w
.63555 .28767 m .66579 .32835 L .675 .33925 L p
1 g
F P
s
P
p
.002 w
.32927 .5272 m .35391 .56325 L .34827 .55311 L p
1 g
F P
s
P
p
.002 w
.34827 .55311 m .32067 .5127 L .32927 .5272 L p
1 g
F P
s
P
p
.002 w
.30813 .40275 m .30351 .44922 L .30456 .42955 L p
1 g
F P
s
P
p
.002 w
.30456 .42955 m .3094 .38063 L .30813 .40275 L p
1 g
F P
s
P
p
.002 w
.39633 .2674 m .35239 .29948 L .36716 .28645 L p
1 g
F P
s
P
p
.002 w
.36716 .28645 m .40947 .2555 L .39633 .2674 L p
1 g
F P
s
P
p
.002 w
.5353 .23791 m .47675 .23471 L .48817 .23465 L p
1 g
F P
s
P
p
.002 w
.48817 .23465 m .54066 .23751 L .5353 .23791 L p
1 g
F P
s
P
p
.002 w
.4776 .62649 m .52282 .62634 L .53667 .62343 L p
1 g
F P
s
P
p
.002 w
.53667 .62343 m .58195 .60993 L .59789 .60079 L p
1 g
F P
s
P
p
.002 w
.58195 .60993 m .53667 .62343 L .52282 .62634 L p
1 g
F P
s
P
p
.002 w
.59789 .60079 m .63627 .57235 L .65089 .55745 L p
1 g
F P
s
P
p
.002 w
.63627 .57235 m .59789 .60079 L .58195 .60993 L p
1 g
F P
s
P
p
.002 w
.69112 .4763 m .69615 .42457 L .69574 .40579 L p
1 g
F P
s
P
p
.002 w
.69615 .42457 m .69112 .4763 L .68597 .49629 L p
1 g
F P
s
P
p
.002 w
.46551 .24036 m .40947 .2555 L .42461 .24884 L p
1 g
F P
s
P
p
.002 w
.42461 .24884 m .47675 .23471 L .46551 .24036 L p
1 g
F P
s
P
p
.002 w
.39395 .59573 m .43021 .61425 L .43169 .61512 L p
1 g
F P
s
P
p
.002 w
.43169 .61512 m .38919 .59341 L .39395 .59573 L p
1 g
F P
s
P
p
.002 w
.4776 .62649 m .43169 .61512 L .43021 .61425 L p
1 g
F P
s
P
p
.002 w
.675 .33925 m .64134 .29395 L .63555 .28767 L p
1 g
F P
s
P
p
.002 w
.59202 .25596 m .63555 .28767 L .64134 .29395 L p
1 g
F P
s
P
p
.002 w
.33434 .33775 m .3094 .38063 L .31587 .36061 L p
1 g
F P
s
P
p
.002 w
.31587 .36061 m .34127 .31669 L .33434 .33775 L p
1 g
F P
s
P
p
.002 w
.36393 .57005 m .39395 .59573 L .38919 .59341 L p
1 g
F P
s
P
p
.002 w
.38919 .59341 m .35391 .56325 L .36393 .57005 L p
1 g
F P
s
P
p
.002 w
.65089 .55745 m .67538 .5151 L .68597 .49629 L p
1 g
F P
s
P
p
.002 w
.67538 .5151 m .65089 .55745 L .63627 .57235 L p
1 g
F P
s
P
p
.002 w
.59272 .25854 m .5353 .23791 L .54066 .23751 L p
1 g
F P
s
P
p
.002 w
.54066 .23751 m .59202 .25596 L .59272 .25854 L p
1 g
F P
s
P
p
.002 w
.43021 .61425 m .46935 .62394 L .4776 .62649 L p
1 g
F P
s
P
p
.002 w
.52282 .62634 m .4776 .62649 L .46935 .62394 L p
1 g
F P
s
P
p
.002 w
.31808 .48848 m .32927 .5272 L .32067 .5127 L p
1 g
F P
s
P
p
.002 w
.32067 .5127 m .30796 .46906 L .31808 .48848 L p
1 g
F P
s
P
p
.002 w
.69574 .40579 m .67963 .35317 L .675 .33925 L p
1 g
F P
s
P
p
.002 w
.67963 .35317 m .69574 .40579 L .69615 .42457 L p
1 g
F P
s
P
p
.002 w
.64134 .29395 m .59272 .25854 L .59202 .25596 L p
1 g
F P
s
P
p
.002 w
.64134 .29395 m .675 .33925 L .67963 .35317 L p
1 g
F P
s
P
p
.002 w
.31236 .42639 m .30796 .46906 L .30351 .44922 L p
1 g
F P
s
P
p
.002 w
.30351 .44922 m .30813 .40275 L .31236 .42639 L p
1 g
F P
s
P
p
.002 w
.3431 .53948 m .36393 .57005 L .35391 .56325 L p
1 g
F P
s
P
p
.002 w
.35391 .56325 m .32927 .5272 L .3431 .53948 L p
1 g
F P
s
P
p
.002 w
.38572 .28447 m .34127 .31669 L .35239 .29948 L p
1 g
F P
s
P
p
.002 w
.35239 .29948 m .39633 .2674 L .38572 .28447 L p
1 g
F P
s
P
p
.002 w
.69095 .4442 m .68597 .49629 L .67538 .5151 L p
1 g
F P
s
P
p
.002 w
.68597 .49629 m .69095 .4442 L .69615 .42457 L p
1 g
F P
s
P
p
.002 w
.52282 .62634 m .5631 .61431 L .58195 .60993 L p
1 g
F P
s
P
p
.002 w
.61725 .58371 m .58195 .60993 L .5631 .61431 L p
1 g
F P
s
P
p
.002 w
.58195 .60993 m .61725 .58371 L .63627 .57235 L p
1 g
F P
s
P
p
.002 w
.52869 .24388 m .46551 .24036 L .47675 .23471 L p
1 g
F P
s
P
p
.002 w
.47675 .23471 m .5353 .23791 L .52869 .24388 L p
1 g
F P
s
P
p
.002 w
.46935 .62394 m .50777 .62379 L .52282 .62634 L p
1 g
F P
s
P
p
.002 w
.5631 .61431 m .52282 .62634 L .50777 .62379 L p
1 g
F P
s
P
p
.002 w
.45482 .25176 m .39633 .2674 L .40947 .2555 L p
1 g
F P
s
P
p
.002 w
.40947 .2555 m .46551 .24036 L .45482 .25176 L p
1 g
F P
s
P
p
.002 w
.33202 .36221 m .30813 .40275 L .3094 .38063 L p
1 g
F P
s
P
p
.002 w
.3094 .38063 m .33434 .33775 L .33202 .36221 L p
1 g
F P
s
P
p
.002 w
.65937 .5321 m .63627 .57235 L .61725 .58371 L p
1 g
F P
s
P
p
.002 w
.63627 .57235 m .65937 .5321 L .67538 .5151 L p
1 g
F P
s
P
p
.002 w
.40197 .5934 m .43067 .60807 L .43021 .61425 L p
1 g
F P
s
P
p
.002 w
.43021 .61425 m .39395 .59573 L .40197 .5934 L p
1 g
F P
s
P
p
.002 w
.46935 .62394 m .43021 .61425 L .43067 .60807 L p
1 g
F P
s
P
p
.002 w
.67963 .35317 m .64333 .30442 L .64134 .29395 L p
1 g
F P
s
P
p
.002 w
.59272 .25854 m .64134 .29395 L .64333 .30442 L p
1 g
F P
s
P
p
.002 w
.37828 .57309 m .40197 .5934 L .39395 .59573 L p
1 g
F P
s
P
p
.002 w
.39395 .59573 m .36393 .57005 L .37828 .57309 L p
1 g
F P
s
P
p
.002 w
.67928 .36986 m .69615 .42457 L .69095 .4442 L p
1 g
F P
s
P
p
.002 w
.69615 .42457 m .67928 .36986 L .67963 .35317 L p
1 g
F P
s
P
p
.002 w
.33383 .50684 m .3431 .53948 L .32927 .5272 L p
1 g
F P
s
P
p
.002 w
.32927 .5272 m .31808 .48848 L .33383 .50684 L p
1 g
F P
s
P
p
.002 w
.32222 .45087 m .31808 .48848 L .30796 .46906 L p
1 g
F P
s
P
p
.002 w
.30796 .46906 m .31236 .42639 L .32222 .45087 L p
1 g
F P
s
P
p
.002 w
.43067 .60807 m .46163 .61572 L .46935 .62394 L p
1 g
F P
s
P
p
.002 w
.50777 .62379 m .46935 .62394 L .46163 .61572 L p
1 g
F P
s
P
p
.002 w
.59076 .2662 m .52869 .24388 L .5353 .23791 L p
1 g
F P
s
P
p
.002 w
.5353 .23791 m .59272 .25854 L .59076 .2662 L p
1 g
F P
s
P
p
.002 w
.64333 .30442 m .67963 .35317 L .67928 .36986 L p
1 g
F P
s
P
p
.002 w
.64333 .30442 m .59076 .2662 L .59272 .25854 L p
1 g
F P
s
P
p
.002 w
.37811 .30643 m .33434 .33775 L .34127 .31669 L p
1 g
F P
s
P
p
.002 w
.34127 .31669 m .38572 .28447 L .37811 .30643 L p
1 g
F P
s
P
p
.002 w
.362 .54902 m .37828 .57309 L .36393 .57005 L p
1 g
F P
s
P
p
.002 w
.36393 .57005 m .3431 .53948 L .362 .54902 L p
1 g
F P
s
P
p
.002 w
.68001 .4641 m .67538 .5151 L .65937 .5321 L p
1 g
F P
s
P
p
.002 w
.67538 .5151 m .68001 .4641 L .69095 .4442 L p
1 g
F P
s
P
p
.002 w
.50777 .62379 m .54176 .61354 L .5631 .61431 L p
1 g
F P
s
P
p
.002 w
.59423 .591 m .5631 .61431 L .54176 .61354 L p
1 g
F P
s
P
p
.002 w
.5631 .61431 m .59423 .591 L .61725 .58371 L p
1 g
F P
s
P
p
.002 w
.3346 .3894 m .31236 .42639 L .30813 .40275 L p
1 g
F P
s
P
p
.002 w
.30813 .40275 m .33202 .36221 L .3346 .3894 L p
1 g
F P
s
P
p
.002 w
.46163 .61572 m .4919 .61554 L .50777 .62379 L p
1 g
F P
s
P
p
.002 w
.54176 .61354 m .50777 .62379 L .4919 .61554 L p
1 g
F P
s
P
p
.002 w
.44505 .26889 m .38572 .28447 L .39633 .2674 L p
1 g
F P
s
P
p
.002 w
.39633 .2674 m .45482 .25176 L .44505 .26889 L p
1 g
F P
s
P
p
.002 w
.52096 .25559 m .45482 .25176 L .46551 .24036 L p
1 g
F P
s
P
p
.002 w
.46551 .24036 m .52869 .24388 L .52096 .25559 L p
1 g
F P
s
P
p
.002 w
.63822 .54666 m .61725 .58371 L .59423 .591 L p
1 g
F P
s
P
p
.002 w
.61725 .58371 m .63822 .54666 L .65937 .5321 L p
1 g
F P
s
P
p
.002 w
.67365 .38896 m .69095 .4442 L .68001 .4641 L p
1 g
F P
s
P
p
.002 w
.69095 .4442 m .67365 .38896 L .67928 .36986 L p
1 g
F P
s
P
p
.002 w
.35495 .5235 m .362 .54902 L .3431 .53948 L p
1 g
F P
s
P
p
.002 w
.3431 .53948 m .33383 .50684 L .35495 .5235 L p
1 g
F P
s
P
p
.002 w
.33761 .47539 m .33383 .50684 L .31808 .48848 L p
1 g
F P
s
P
p
.002 w
.31808 .48848 m .32222 .45087 L .33761 .47539 L p
1 g
F P
s
P
p
.002 w
.67928 .36986 m .64121 .31901 L .64333 .30442 L p
1 g
F P
s
P
p
.002 w
.59076 .2662 m .64333 .30442 L .64121 .31901 L p
1 g
F P
s
P
p
.002 w
.4132 .5862 m .43318 .59642 L .43067 .60807 L p
1 g
F P
s
P
p
.002 w
.43067 .60807 m .40197 .5934 L .4132 .5862 L p
1 g
F P
s
P
p
.002 w
.46163 .61572 m .43067 .60807 L .43318 .59642 L p
1 g
F P
s
P
p
.002 w
.39678 .57206 m .4132 .5862 L .40197 .5934 L p
1 g
F P
s
P
p
.002 w
.40197 .5934 m .37828 .57309 L .39678 .57206 L p
1 g
F P
s
P
p
.002 w
.3739 .33279 m .33202 .36221 L .33434 .33775 L p
1 g
F P
s
P
p
.002 w
.33434 .33775 m .37811 .30643 L .3739 .33279 L p
1 g
F P
s
P
p
.002 w
.64121 .31901 m .67928 .36986 L .67365 .38896 L p
1 g
F P
s
P
p
.002 w
.43318 .59642 m .45472 .60171 L .46163 .61572 L p
1 g
F P
s
P
p
.002 w
.4919 .61554 m .46163 .61572 L .45472 .60171 L p
1 g
F P
s
P
p
.002 w
.66341 .48364 m .65937 .5321 L .63822 .54666 L p
1 g
F P
s
P
p
.002 w
.65937 .5321 m .66341 .48364 L .68001 .4641 L p
1 g
F P
s
P
p
.002 w
.58605 .27902 m .52096 .25559 L .52869 .24388 L p
1 g
F P
s
P
p
.002 w
.52869 .24388 m .59076 .2662 L .58605 .27902 L p
1 g
F P
s
P
p
.002 w
.4919 .61554 m .51849 .60737 L .54176 .61354 L p
1 g
F P
s
P
p
.002 w
.56775 .59379 m .54176 .61354 L .51849 .60737 L p
1 g
F P
s
P
p
.002 w
.54176 .61354 m .56775 .59379 L .59423 .591 L p
1 g
F P
s
P
p
.002 w
.64121 .31901 m .58605 .27902 L .59076 .2662 L p
1 g
F P
s
P
p
.002 w
.3422 .41852 m .32222 .45087 L .31236 .42639 L p
1 g
F P
s
P
p
.002 w
.31236 .42639 m .3346 .3894 L .3422 .41852 L p
1 g
F P
s
P
p
.002 w
.38562 .55537 m .39678 .57206 L .37828 .57309 L p
1 g
F P
s
P
p
.002 w
.37828 .57309 m .362 .54902 L .38562 .55537 L p
1 g
F P
s
P
p
.002 w
.61238 .55818 m .59423 .591 L .56775 .59379 L p
1 g
F P
s
P
p
.002 w
.59423 .591 m .61238 .55818 L .63822 .54666 L p
1 g
F P
s
P
p
.002 w
.4366 .29147 m .37811 .30643 L .38572 .28447 L p
1 g
F P
s
P
p
.002 w
.38572 .28447 m .44505 .26889 L .4366 .29147 L p
1 g
F P
s
P
p
.002 w
.45472 .60171 m .4757 .60151 L .4919 .61554 L p
1 g
F P
s
P
p
.002 w
.51849 .60737 m .4919 .61554 L .4757 .60151 L p
1 g
F P
s
P
p
.002 w
.51229 .27299 m .44505 .26889 L .45482 .25176 L p
1 g
F P
s
P
p
.002 w
.45482 .25176 m .52096 .25559 L .51229 .27299 L p
1 g
F P
s
P
p
.002 w
.66266 .40995 m .68001 .4641 L .66341 .48364 L p
1 g
F P
s
P
p
.002 w
.68001 .4641 m .66266 .40995 L .67365 .38896 L p
1 g
F P
s
P
p
.002 w
.35821 .49911 m .35495 .5235 L .33383 .50684 L p
1 g
F P
s
P
p
.002 w
.33383 .50684 m .33761 .47539 L .35821 .49911 L p
1 g
F P
s
P
p
.002 w
.38096 .53781 m .38562 .55537 L .362 .54902 L p
1 g
F P
s
P
p
.002 w
.362 .54902 m .35495 .5235 L .38096 .53781 L p
1 g
F P
s
P
p
.002 w
.3734 .3628 m .3346 .3894 L .33202 .36221 L p
1 g
F P
s
P
p
.002 w
.33202 .36221 m .3739 .33279 L .3734 .3628 L p
1 g
F P
s
P
p
.002 w
.64145 .50214 m .63822 .54666 L .61238 .55818 L p
1 g
F P
s
P
p
.002 w
.63822 .54666 m .64145 .50214 L .66341 .48364 L p
1 g
F P
s
P
p
.002 w
.67365 .38896 m .63479 .33749 L .64121 .31901 L p
1 g
F P
s
P
p
.002 w
.58605 .27902 m .64121 .31901 L .63479 .33749 L p
1 g
F P
s
P
p
.002 w
.35473 .44859 m .33761 .47539 L .32222 .45087 L p
1 g
F P
s
P
p
.002 w
.32222 .45087 m .3422 .41852 L .35473 .44859 L p
1 g
F P
s
P
p
.002 w
.42747 .57406 m .43778 .57935 L .43318 .59642 L p
1 g
F P
s
P
p
.002 w
.43318 .59642 m .4132 .5862 L .42747 .57406 L p
1 g
F P
s
P
p
.002 w
.45472 .60171 m .43318 .59642 L .43778 .57935 L p
1 g
F P
s
P
p
.002 w
.63479 .33749 m .67365 .38896 L .66266 .40995 L p
1 g
F P
s
P
p
.002 w
.41904 .56675 m .42747 .57406 L .4132 .5862 L p
1 g
F P
s
P
p
.002 w
.4132 .5862 m .39678 .57206 L .41904 .56675 L p
1 g
F P
s
P
p
.002 w
.4757 .60151 m .49396 .59576 L .51849 .60737 L p
1 g
F P
s
P
p
.002 w
.53855 .5918 m .51849 .60737 L .49396 .59576 L p
1 g
F P
s
P
p
.002 w
.51849 .60737 m .53855 .5918 L .56775 .59379 L p
1 g
F P
s
P
p
.002 w
.43778 .57935 m .44891 .58206 L .45472 .60171 L p
1 g
F P
s
P
p
.002 w
.4757 .60151 m .45472 .60171 L .44891 .58206 L p
1 g
F P
s
P
p
.002 w
.58257 .56615 m .56775 .59379 L .53855 .5918 L p
1 g
F P
s
P
p
.002 w
.56775 .59379 m .58257 .56615 L .61238 .55818 L p
1 g
F P
s
P
p
.002 w
.57856 .2969 m .51229 .27299 L .52096 .25559 L p
1 g
F P
s
P
p
.002 w
.52096 .25559 m .58605 .27902 L .57856 .2969 L p
1 g
F P
s
P
p
.002 w
.41338 .55816 m .41904 .56675 L .39678 .57206 L p
1 g
F P
s
P
p
.002 w
.39678 .57206 m .38562 .55537 L .41338 .55816 L p
1 g
F P
s
P
p
.002 w
.63479 .33749 m .57856 .2969 L .58605 .27902 L p
1 g
F P
s
P
p
.002 w
.42983 .31896 m .3739 .33279 L .37811 .30643 L p
1 g
F P
s
P
p
.002 w
.37811 .30643 m .4366 .29147 L .42983 .31896 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.44891 .58206 m .45969 .5819 L .4757 .60151 L p
1 g
F P
s
P
p
.002 w
.49396 .59576 m .4757 .60151 L .45969 .5819 L p
1 g
F P
s
P
p
.002 w
.38345 .52119 m .38096 .53781 L .35495 .5235 L p
1 g
F P
s
P
p
.002 w
.35495 .5235 m .35821 .49911 L .38345 .52119 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.64642 .43221 m .66341 .48364 L .64145 .50214 L p
1 g
F P
s
P
p
.002 w
.66341 .48364 m .64642 .43221 L .66266 .40995 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50296 .29579 m .4366 .29147 L .44505 .26889 L p
1 g
F P
s
P
p
.002 w
.44505 .26889 m .51229 .27299 L .50296 .29579 L p
1 g
F P
s
P
p
.002 w
.37676 .39551 m .3422 .41852 L .3346 .3894 L p
1 g
F P
s
P
p
.002 w
.3346 .3894 m .3734 .3628 L .37676 .39551 L p
1 g
F P
s
P
p
.002 w
.6147 .5189 m .61238 .55818 L .58257 .56615 L p
1 g
F P
s
P
p
.002 w
.61238 .55818 m .6147 .5189 L .64145 .50214 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.41112 .54918 m .41338 .55816 L .38562 .55537 L p
1 g
F P
s
P
p
.002 w
.38562 .55537 m .38096 .53781 L .41112 .54918 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45685 .52887 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37185 .47857 m .35821 .49911 L .33761 .47539 L p
1 g
F P
s
P
p
.002 w
.33761 .47539 m .35473 .44859 L .37185 .47857 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.49396 .59576 m .50756 .58493 L .53855 .5918 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .57438 L p
1 g
F P
s
P
p
.54971 .57018 m .51171 .58585 L .52225 .57979 L 1 g
F
P
p
.54854 .56129 m .53166 .57438 L .53903 .57014 L 1 g
F
P
p
.002 w
.5499 .56279 m .54971 .57018 L .54335 .57016 L p
1 g
F P
s
P
p
.002 w
.54335 .57016 m .53903 .57014 L p
.54926 .56322 L 1 g
F P
s
P
p
.5499 .56279 m .54335 .57016 L .54926 .56322 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56322 L p
1 g
F P
s
P
p
.56075 .54566 m .54926 .56322 L .54991 .56247 L 1 g
F
P
p
.002 w
.56755 .53883 m .58399 .53326 L p
.55841 .55518 L 1 g
F P
s
P
p
.55841 .55518 m .54991 .56247 L .56146 .54699 L 1 g
F
P
p
.55841 .55518 m .56146 .54699 L .56755 .53883 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56146 .54699 L p
1 g
F P
s
P
p
.56654 .52734 m .56146 .54699 L .56405 .54001 L 1 g
F
P
p
.002 w
.5735 .50508 m .58399 .53326 L .5679 .53871 L p
1 g
F P
s
P
p
.002 w
.5679 .53871 m .56405 .54001 L p
.56722 .52832 L 1 g
F P
s
P
p
.5735 .50508 m .5679 .53871 L .56722 .52832 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56722 .52832 L p
1 g
F P
s
P
p
.56515 .50826 m .56722 .52832 L .56644 .5166 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.57113 .4987 m .5735 .50508 L p
.56647 .51711 L 1 g
F P
s
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56644 .5166 L 1 g
F P
s
P
p
.566 .51004 m .56647 .51711 L .55036 .54465 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.57113 .4987 m .56757 .51275 L .56616 .50968 L 1 g
F
P
p
.55661 .4905 m .56595 .50921 L .56333 .50352 L 1 g
F
P
p
.002 w
.54541 .46719 m .57113 .4987 L .56739 .50101 L p
1 g
F P
s
P
p
.002 w
.56739 .50101 m .56333 .50352 L p
.55724 .49117 L 1 g
F P
s
P
p
.54541 .46719 m .56739 .50101 L .55724 .49117 L 1 g
F
P
p
.55661 .4905 m .56333 .50352 L .56192 .50065 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55036 .54465 m .53999 .51797 L .56333 .50352 L p
1 g
F P
s
P
p
.002 w
.56333 .50352 m .57113 .4987 L p
.56616 .50968 L 1 g
F P
s
P
p
.56616 .50968 m .55036 .54465 L .56333 .50352 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55805 .49203 L p
1 g
F P
s
P
p
.002 w
.55805 .49203 m .55661 .4905 L p
.56272 .50218 L 1 g
F P
s
P
p
.56272 .50218 m .56713 .51061 L .55805 .49203 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55724 .49117 L p
1 g
F P
s
P
p
.54174 .47608 m .55724 .49117 L .54843 .48263 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56333 .50352 m .53999 .51797 L p
.5442 .47853 L 1 g
F P
s
P
p
.002 w
.54229 .47668 m .54174 .47608 L p
.54843 .48263 L 1 g
F P
s
P
p
.54541 .46719 m .55724 .49117 L .5442 .47853 L 1 g
F
P
p
.55724 .49117 m .56333 .50352 L .5442 .47853 L 1 g
F
P
p
.002 w
.54492 .46659 m .54541 .46719 L p
.53999 .51797 L 1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53999 .51797 m .51945 .49329 L .53744 .47443 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54229 .47668 L p
1 g
F P
s
P
p
.52214 .46667 m .54229 .47668 L .53744 .47443 L 1 g
F
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53744 .47443 m .51945 .49329 L p
.51354 .46577 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52235 .46703 L p
1 g
F P
s
P
p
.5 .4634 m .52235 .46703 L .50888 .46511 L 1 g
F
P
p
.51281 .46235 m .52235 .46703 L .51354 .46577 L 1 g
F
P
p
.52235 .46703 m .53744 .47443 L .51354 .46577 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51945 .49329 m .49101 .47365 L .49582 .46455 L p
1 g
F P
s
P
p
.5 .46384 m .51945 .49329 L .49582 .46455 L 1 g
F
P
p
.002 w
.5 .46384 m .5 .4634 L p
.50888 .46511 L 1 g
F P
s
P
p
.51267 .46169 m .51354 .46577 L .5 .46384 L 1 g
F
P
p
.51354 .46577 m .51945 .49329 L .5 .46384 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46384 L p
1 g
F P
s
P
p
.50888 .46511 m .52282 .46778 L .5 .46384 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46395 L .48895 .46554 L 1 g
F
P
p
.002 w
.46559 .4254 m .50824 .44105 L .49582 .46455 L p
1 g
F P
s
P
p
.002 w
.49582 .46455 m .49101 .47365 L p
.48689 .46584 L 1 g
F P
s
P
p
.002 w
.47755 .46719 m .47786 .46667 L p
.48895 .46554 L 1 g
F P
s
P
p
.46559 .4254 m .49582 .46455 L .48689 .46584 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49101 .47365 m .4758 .46805 L p
.48689 .46584 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47755 .46719 L p
1 g
F P
s
P
p
.002 w
.49101 .47365 m .47422 .50461 L p
.46283 .47425 L 1 g
F P
s
P
p
.002 w
.4758 .46805 m .49101 .47365 L p
.46283 .47425 L 1 g
F P
s
P
p
.45826 .47608 m .47755 .46719 L .4758 .46805 L 1 g
F
P
p
.46723 .47215 m .4758 .46805 L .46993 .47096 L 1 g
F
P
p
.45826 .47608 m .4758 .46805 L .46723 .47215 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47422 .50461 m .4519 .49636 L .45489 .47942 L p
1 g
F P
s
P
p
.45569 .47865 m .47422 .50461 L .45489 .47942 L 1 g
F
P
p
.46283 .47425 m .47422 .50461 L .45569 .47865 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45769 .4767 L p
1 g
F P
s
P
p
.44339 .4905 m .45769 .4767 L .45489 .47942 L 1 g
F
P
p
.44339 .4905 m .45489 .47942 L .45009 .48408 L 1 g
F
P
p
.002 w
.42464 .45833 m .45806 .46152 L .45489 .47942 L p
1 g
F P
s
P
p
.002 w
.45489 .47942 m .4519 .49636 L p
.44597 .48808 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44064 .49522 m .4388 .49503 L p
.44255 .49139 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44255 .49139 L p
1 g
F P
s
P
p
.002 w
.42922 .49406 m .44064 .49522 L p
.4355 .50605 L 1 g
F P
s
P
p
.43485 .50826 m .44255 .49139 L .44064 .49522 L 1 g
F
P
p
.43851 .49969 m .44064 .49522 L .43922 .49805 L 1 g
F
P
p
.43485 .50826 m .44064 .49522 L .43851 .49969 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43343 .51497 m .43279 .51178 L p
.43363 .51276 L 1 g
F P
s
P
p
.002 w
.43279 .51178 m .42922 .49406 L p
.43443 .50399 L 1 g
F P
s
P
p
.43443 .50399 m .4355 .50605 L .43394 .50934 L 1 g
F
P
p
.43443 .50399 m .43394 .50934 L .43279 .51178 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43394 .50934 L p
1 g
F P
s
P
p
.43346 .52734 m .43394 .50934 L .43343 .51497 L 1 g
F
P
p
.43346 .52734 m .43343 .51497 L .43315 .51837 L 1 g
F
P
p
.002 w
.40884 .49791 m .42922 .49406 L .43343 .51497 L p
1 g
F P
s
P
p
.40884 .49791 m .43343 .51497 L .43269 .52386 L 1 g
F
P
p
.002 w
.42562 .52922 m .40884 .49791 L p
.43269 .52386 L 1 g
F P
s
P
p
.002 w
.43234 .52802 m .42562 .52922 L p
.43269 .52386 L 1 g
F P
s
P
p
.43346 .52734 m .43314 .51816 L .43238 .52648 L 1 g
F
P
p
.002 w
.43207 .53878 m .42562 .52922 L .43201 .52808 L p
1 g
F P
s
P
p
.002 w
.43201 .52808 m .43234 .52802 L p
.43232 .529 L 1 g
F P
s
P
p
.43201 .52808 m .43232 .529 L .43207 .53878 L 1 g
F
P
p
.002 w
.43838 .54731 m .43925 .54566 L p
.43514 .53753 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44445 .55714 m .43207 .53878 L p
.43217 .53849 L 1 g
F P
s
P
p
.002 w
.45074 .56322 m .45146 .56129 L p
.44529 .55704 L 1 g
F P
s
P
p
.002 w
.44536 .55713 m .44445 .55714 L .44519 .55691 L p
1 g
F P
s
P
p
.44529 .55704 m .44528 .55703 L .44532 .55708 L 1 g
F
P
p
.44529 .55704 m .44532 .55708 L .45074 .56322 L 1 g
F
P
p
.44528 .55703 m .44548 .55727 L .45074 .56322 L 1 g
F
P
p
.45146 .56129 m .44311 .55404 L .44386 .5551 L 1 g
F
P
p
.45146 .56129 m .44386 .5551 L .44432 .55574 L 1 g
F
P
p
.45146 .56129 m .44431 .55573 L .44457 .55609 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44386 .5551 m .44445 .55714 L p
.43217 .53849 L 1 g
F P
s
P
p
.002 w
.41754 .53386 m .42562 .52922 L .43891 .54893 L p
1 g
F P
s
P
p
.002 w
.43891 .54893 m .44445 .55714 L .44053 .55375 L p
1 g
F P
s
P
p
.002 w
.44053 .55375 m .41754 .53386 L p
.43891 .54893 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43838 .54731 L p
1 g
F P
s
P
p
.002 w
.43838 .54731 m .43743 .5491 L p
.44311 .55404 L 1 g
F P
s
P
p
.45146 .56129 m .43838 .54731 L .44311 .55404 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43232 .529 L p
1 g
F P
s
P
p
.43217 .53849 m .43383 .53357 L .43838 .54731 L 1 g
F
P
p
.43925 .54566 m .43232 .529 L .43514 .53753 L 1 g
F
P
p
.002 w
.43232 .529 m .43346 .52734 L p
.43238 .52648 L 1 g
F P
s
P
p
.002 w
.43234 .52802 m .43593 .52739 L p
.43207 .53878 L 1 g
F P
s
P
p
.002 w
.43232 .529 m .43146 .53025 L p
.43514 .53753 L 1 g
F P
s
P
p
.002 w
.43593 .52739 m .44386 .5551 L p
.43838 .54731 L 1 g
F P
s
P
p
.43383 .53357 m .43593 .52739 L .43838 .54731 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43837 .54732 L p
1 g
F P
s
P
p
.002 w
.43837 .54732 m .43838 .54731 L p
.43833 .54719 L 1 g
F P
s
P
p
.43833 .54719 m .43146 .53025 L .43837 .54732 L 1 g
F
P
p
.002 w
.43593 .52739 m .44732 .52861 L .44455 .55607 L p
1 g
F P
s
P
p
.002 w
.44455 .55607 m .44445 .55714 L .44386 .5551 L p
1 g
F P
s
P
p
.002 w
.44386 .5551 m .43593 .52739 L p
.44455 .55607 L 1 g
F P
s
P
p
.44432 .55574 m .44386 .5551 L .44431 .55573 L 1 g
F
P
p
.44457 .55609 m .44431 .55573 L .44455 .55608 L 1 g
F
P
p
.45146 .56129 m .44455 .55608 L .44474 .55633 L 1 g
F
P
p
.45146 .56129 m .44471 .55631 L .44519 .55691 L 1 g
F
P
p
.002 w
.44732 .52861 m .45852 .53277 L .44484 .55646 L p
1 g
F P
s
P
p
.002 w
.44484 .55646 m .44445 .55714 L .44455 .55607 L p
1 g
F P
s
P
p
.002 w
.44455 .55607 m .44732 .52861 L p
.44484 .55646 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45852 .53277 m .46825 .53938 L .44502 .55671 L p
1 g
F P
s
P
p
.002 w
.44502 .55671 m .44445 .55714 L .44484 .55646 L p
1 g
F P
s
P
p
.002 w
.44484 .55646 m .45852 .53277 L p
.44502 .55671 L 1 g
F P
s
P
p
.44474 .55633 m .44455 .55608 L .44471 .55631 L 1 g
F
P
p
.44519 .55691 m .44471 .55631 L .44509 .55685 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46825 .53938 m .47543 .54771 L .44519 .55691 L p
1 g
F P
s
P
p
.002 w
.44519 .55691 m .44445 .55714 L .44502 .55671 L p
1 g
F P
s
P
p
.002 w
.44502 .55671 m .46825 .53938 L p
.44519 .55691 L 1 g
F P
s
P
p
.45146 .56129 m .44509 .55685 L .44522 .55699 L 1 g
F
P
p
.002 w
.47543 .54771 m .47927 .5568 L .44536 .55713 L p
1 g
F P
s
P
p
.002 w
.44519 .55691 m .47543 .54771 L p
.44536 .55713 L 1 g
F P
s
P
p
.44526 .55702 m .4467 .55868 L .45074 .56322 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47927 .5568 m .47938 .56564 L .44561 .55742 L p
1 g
F P
s
P
p
.002 w
.44561 .55742 m .44445 .55714 L .44536 .55713 L p
1 g
F P
s
P
p
.002 w
.44536 .55713 m .47927 .5568 L p
.44561 .55742 L 1 g
F P
s
P
p
.44528 .55703 m .44526 .55702 L .44548 .55727 L 1 g
F
P
p
.002 w
.4461 .55799 m .44445 .55714 L .44561 .55742 L p
1 g
F P
s
P
p
.44526 .55702 m .44517 .55696 L .4467 .55868 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47938 .56564 m .47581 .57327 L .4461 .55799 L p
1 g
F P
s
P
p
.002 w
.44561 .55742 m .47938 .56564 L p
.4461 .55799 L 1 g
F P
s
P
p
.002 w
.46899 .57888 m .46173 .57245 L p
.46822 .57492 L 1 g
F P
s
P
p
.002 w
.47204 .57637 m .4713 .57698 L p
.46822 .57492 L 1 g
F P
s
P
p
.002 w
.4713 .57698 m .46899 .57888 L p
.46822 .57492 L 1 g
F P
s
P
p
.002 w
.46822 .57492 m .46872 .57265 L p
.45906 .56879 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46812 .5754 L p
1 g
F P
s
P
p
.002 w
.46899 .57888 m .47204 .57637 L p
.48906 .58059 L 1 g
F P
s
P
p
.50486 .5845 m .47634 .58003 L .48906 .58059 L 1 g
F
P
p
.47634 .58003 m .46899 .57888 L .48906 .58059 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.50756 .58493 m .50486 .5845 L .49548 .58087 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58059 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58059 L .49666 .58093 L 1 g
F
P
p
.002 w
.50944 .58112 m .50756 .58493 L .49666 .58093 L p
1 g
F P
s
P
p
.49908 .58096 m .49666 .58093 L .49879 .58102 L 1 g
F
P
p
.51079 .57862 m .49666 .58093 L .49908 .58096 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58095 L p
1 g
F P
s
P
p
.54971 .57018 m .52248 .57971 L .52097 .57778 L 1 g
F
P
p
.002 w
.54493 .57016 m .54971 .57018 L p
.52097 .57778 L 1 g
F P
s
P
p
.002 w
.50756 .58493 m .50944 .58112 L p
.52248 .57971 L 1 g
F P
s
P
p
.53128 .57265 m .51096 .58095 L .52182 .5775 L 1 g
F
P
p
.51079 .57862 m .49879 .58102 L .507 .58138 L 1 g
F
P
p
.002 w
.51096 .58095 m .51079 .57862 L p
.507 .58138 L 1 g
F P
s
P
p
.002 w
.50944 .58112 m .5149 .57003 L p
.52097 .57778 L 1 g
F P
s
P
p
.52248 .57971 m .51096 .58095 L .52097 .57778 L 1 g
F
P
p
.51096 .58095 m .50944 .58112 L .52097 .57778 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53166 .57438 L p
1 g
F P
s
P
p
.002 w
.53166 .57438 m .53128 .57265 L p
.52182 .5775 L 1 g
F P
s
P
p
.52182 .5775 m .51111 .583 L .53166 .57438 L 1 g
F
P
p
.002 w
.51096 .58095 m .51111 .583 L p
.52182 .5775 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53903 .57014 m .54493 .57016 L p
.53166 .57438 L 1 g
F P
s
P
p
.58399 .53326 m .57834 .53935 L .54991 .56247 L 1 g
F
P
p
.002 w
.54971 .57018 m .5499 .56279 L p
.57834 .53935 L 1 g
F P
s
P
p
.002 w
.5499 .56279 m .54991 .56247 L p
.57834 .53935 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .54957 .56407 L p
.53809 .57253 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53531 .57482 L p
.53809 .57253 L 1 g
F P
s
P
p
.002 w
.53531 .57482 m .54998 .56518 L p
.53809 .57253 L 1 g
F P
s
P
p
.002 w
.54957 .56407 m .54854 .56129 L p
.5396 .56981 L 1 g
F P
s
P
p
.5396 .56981 m .5322 .57686 L .54957 .56407 L 1 g
F
P
p
.002 w
.5149 .57003 m .53903 .57014 L p
.52097 .57778 L 1 g
F P
s
P
p
.53166 .57438 m .52097 .57778 L .53903 .57014 L 1 g
F
P
p
.002 w
.51101 .58156 m .51096 .58095 L p
.507 .58138 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.5149 .57003 m .50944 .58112 L p
.47581 .57327 L 1 g
F P
s
P
p
.002 w
.49666 .58093 m .47581 .57327 L p
.50944 .58112 L 1 g
F P
s
P
p
.002 w
.47581 .57327 m .49666 .58093 L p
.49548 .58087 L 1 g
F P
s
P
p
.002 w
.49666 .58093 m .50756 .58493 L p
.49548 .58087 L 1 g
F P
s
P
p
.48921 .57862 m .46812 .5754 L .4771 .57762 L 1 g
F
P
p
.002 w
.49396 .59576 m .46899 .57888 L p
.50486 .5845 L 1 g
F P
s
P
p
.002 w
.4889 .5828 m .48906 .58059 L p
.47484 .57744 L 1 g
F P
s
P
p
.002 w
.48906 .58059 m .48921 .57862 L p
.4771 .57762 L 1 g
F P
s
P
p
.4771 .57762 m .47484 .57744 L .48906 .58059 L 1 g
F
P
p
.002 w
.50756 .58493 m .50732 .58511 L p
.50486 .5845 L 1 g
F P
s
P
p
.002 w
.50732 .58511 m .49396 .59576 L p
.50486 .5845 L 1 g
F P
s
P
p
.002 w
.47204 .57637 m .47581 .57327 L p
.50486 .5845 L 1 g
F P
s
P
p
.002 w
.48906 .58059 m .48889 .583 L p
.49879 .58102 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51101 .58156 L p
1 g
F P
s
P
p
.49879 .58102 m .48889 .583 L .51101 .58156 L 1 g
F
P
p
.002 w
.46812 .5754 m .4678 .57686 L p
.4771 .57762 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45074 .56322 L p
1 g
F P
s
P
p
.002 w
.45312 .56482 m .46173 .57245 L p
.45074 .56322 L 1 g
F P
s
P
p
.002 w
.46173 .57245 m .46899 .57888 L p
.4613 .57228 L 1 g
F P
s
P
p
.4613 .57228 m .45074 .56322 L .46173 .57245 L 1 g
F
P
p
.002 w
.46899 .57888 m .46565 .57996 L p
.45074 .56322 L 1 g
F P
s
P
p
.002 w
.45969 .5819 m .46899 .57888 L .49396 .59576 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .46687 .58109 L p
.48857 .58297 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .48793 .58272 L p
.48857 .58297 L 1 g
F P
s
P
p
.002 w
.48793 .58272 m .4678 .57686 L p
.48857 .58297 L 1 g
F P
s
P
p
.002 w
.45074 .56322 m .45074 .56323 L p
.45082 .56327 L 1 g
F P
s
P
p
.46872 .57265 m .45074 .56322 L .45082 .56327 L 1 g
F
P
p
.46872 .57265 m .45082 .56327 L .45906 .56879 L 1 g
F
P
p
.45082 .56327 m .45074 .56323 L .45312 .56482 L 1 g
F
P
p
.45082 .56327 m .45312 .56482 L .45906 .56879 L 1 g
F
P
p
.002 w
.46565 .57996 m .45969 .5819 L p
.4494 .56231 L 1 g
F P
s
P
p
.45074 .56322 m .4494 .56231 L .44862 .56084 L 1 g
F
P
p
.46565 .57996 m .4494 .56231 L .45074 .56322 L 1 g
F
P
p
.002 w
.44862 .56084 m .45312 .56482 L p
.45074 .56322 L 1 g
F P
s
P
p
.47204 .57637 m .46822 .57492 L .44862 .56084 L 1 g
F
P
p
.002 w
.46173 .57245 m .45312 .56482 L p
.46822 .57492 L 1 g
F P
s
P
p
.002 w
.45312 .56482 m .44862 .56084 L p
.46822 .57492 L 1 g
F P
s
P
p
.002 w
.44445 .55714 m .44862 .56084 L p
.4494 .56231 L 1 g
F P
s
P
p
.002 w
.45969 .5819 m .44638 .56028 L p
.4494 .56231 L 1 g
F P
s
P
p
.002 w
.44638 .56028 m .44445 .55714 L p
.4494 .56231 L 1 g
F P
s
P
p
.002 w
.45074 .56323 m .45002 .56518 L p
.45895 .56875 L 1 g
F P
s
P
p
.45906 .56879 m .45312 .56482 L .45895 .56875 L 1 g
F
P
p
.45312 .56482 m .45074 .56323 L .45895 .56875 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46822 .57492 L p
1 g
F P
s
P
p
.45906 .56879 m .45002 .56518 L .46822 .57492 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .4889 .5828 L p
1 g
F P
s
P
p
.47484 .57744 m .4678 .57686 L .4889 .5828 L 1 g
F
P
p
.002 w
.47581 .57327 m .47204 .57637 L p
.44862 .56084 L 1 g
F P
s
P
p
.002 w
.44862 .56084 m .44445 .55714 L .4461 .55799 L p
1 g
F P
s
P
p
.002 w
.4461 .55799 m .47581 .57327 L p
.44862 .56084 L 1 g
F P
s
P
p
.44522 .55699 m .44509 .55685 L .44517 .55696 L 1 g
F
P
p
.002 w
.45034 .5643 m .45074 .56322 L p
.44517 .55696 L 1 g
F P
s
P
p
.002 w
.43778 .57935 m .42747 .57406 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.44891 .58206 m .43778 .57935 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.42747 .57406 m .41904 .56675 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.45969 .5819 m .44891 .58206 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.41904 .56675 m .41338 .55816 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.41338 .55816 m .41112 .54918 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.41112 .54918 m .41253 .54078 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.41253 .54078 m .41754 .53386 L .44445 .55714 L closepath p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45034 .5643 L p
1 g
F P
s
P
p
.44311 .55404 m .43743 .5491 L .45034 .5643 L 1 g
F
P
p
.43514 .53753 m .43146 .53025 L .43838 .54731 L 1 g
F
P
p
.002 w
.43213 .52928 m .43232 .529 L p
.43238 .52648 L 1 g
F P
s
P
p
.002 w
.43343 .51497 m .43593 .52739 L p
.43269 .52386 L 1 g
F P
s
P
p
.002 w
.43301 .51045 m .43485 .50826 L p
.43922 .49805 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.4355 .50605 m .44732 .52861 L .43363 .51276 L 1 g
F
P
p
.43394 .50934 m .43363 .51276 L .43279 .51178 L 1 g
F
P
p
.4355 .50605 m .43363 .51276 L .43394 .50934 L 1 g
F
P
p
.43314 .51816 m .43343 .51497 L .43287 .51061 L 1 g
F
P
p
.002 w
.43394 .50934 m .43389 .5094 L p
.43343 .51497 L 1 g
F P
s
P
p
.002 w
.43389 .5094 m .43287 .51061 L p
.43343 .51497 L 1 g
F P
s
P
p
.43315 .51837 m .43343 .51497 L .43314 .51816 L 1 g
F
P
p
.002 w
.43593 .52739 m .43234 .52802 L p
.43269 .52386 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43213 .52928 L p
1 g
F P
s
P
p
.43314 .51816 m .43287 .51061 L .43213 .52928 L 1 g
F
P
p
.002 w
.44732 .52861 m .43593 .52739 L .43343 .51497 L p
1 g
F P
s
P
p
.43363 .51276 m .44732 .52861 L .43343 .51497 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4519 .49636 m .44732 .52861 L p
.4355 .50605 L 1 g
F P
s
P
p
.002 w
.44064 .49522 m .4519 .49636 L p
.4355 .50605 L 1 g
F P
s
P
p
.43922 .49805 m .44064 .49522 L .44166 .49233 L 1 g
F
P
p
.002 w
.44255 .49139 m .44234 .49161 L p
.44064 .49522 L 1 g
F P
s
P
p
.002 w
.44234 .49161 m .44166 .49233 L p
.44064 .49522 L 1 g
F P
s
P
p
.002 w
.4388 .49503 m .42922 .49406 L p
.44382 .48885 L 1 g
F P
s
P
p
.002 w
.4519 .49636 m .44064 .49522 L p
.44597 .48808 L 1 g
F P
s
P
p
.44597 .48808 m .44064 .49522 L .44255 .49139 L 1 g
F
P
p
.002 w
.44214 .49183 m .44255 .49139 L p
.45107 .48314 L 1 g
F P
s
P
p
.002 w
.44255 .49139 m .44339 .4905 L p
.45009 .48408 L 1 g
F P
s
P
p
.45009 .48408 m .45107 .48314 L .44255 .49139 L 1 g
F
P
p
.44597 .48808 m .44255 .49139 L .44382 .48885 L 1 g
F
P
p
.44255 .49139 m .4388 .49503 L .44382 .48885 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43301 .51045 L p
1 g
F P
s
P
p
.43922 .49805 m .44166 .49233 L .43301 .51045 L 1 g
F
P
p
.42464 .45833 m .45489 .47942 L .44597 .48808 L 1 g
F
P
p
.46283 .47425 m .45569 .47865 L .45769 .4767 L 1 g
F
P
p
.45107 .48314 m .45489 .47942 L .45698 .47747 L 1 g
F
P
p
.002 w
.45769 .4767 m .45762 .47678 L p
.45489 .47942 L 1 g
F P
s
P
p
.002 w
.45762 .47678 m .45698 .47747 L p
.45489 .47942 L 1 g
F P
s
P
p
.45009 .48408 m .45489 .47942 L .45107 .48314 L 1 g
F
P
p
.002 w
.42922 .49406 m .42464 .45833 L p
.44597 .48808 L 1 g
F P
s
P
p
.45769 .4767 m .45569 .47865 L .45516 .47791 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44214 .49183 L p
1 g
F P
s
P
p
.45107 .48314 m .45698 .47747 L .44214 .49183 L 1 g
F
P
p
.002 w
.45489 .47942 m .45516 .47791 L p
.45569 .47865 L 1 g
F P
s
P
p
.002 w
.45714 .47731 m .45826 .47608 L p
.46993 .47096 L 1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45516 .47791 m .45806 .46152 L p
.46283 .47425 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45806 .46152 m .4758 .46805 L p
.46283 .47425 L 1 g
F P
s
P
p
.46993 .47096 m .4758 .46805 L .47718 .46778 L 1 g
F
P
p
.48689 .46584 m .4758 .46805 L .47755 .46719 L 1 g
F
P
p
.002 w
.47755 .46719 m .47752 .46723 L p
.4758 .46805 L 1 g
F P
s
P
p
.002 w
.47752 .46723 m .47718 .46778 L p
.4758 .46805 L 1 g
F P
s
P
p
.002 w
.4746 .46761 m .45806 .46152 L p
.48181 .46508 L 1 g
F P
s
P
p
.48689 .46584 m .47755 .46719 L .48181 .46508 L 1 g
F
P
p
.47755 .46719 m .4746 .46761 L .48181 .46508 L 1 g
F
P
p
.002 w
.4758 .46805 m .4746 .46761 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45714 .47731 L p
1 g
F P
s
P
p
.46993 .47096 m .47718 .46778 L .45714 .47731 L 1 g
F
P
p
.002 w
.47723 .4677 m .47755 .46719 L p
.49153 .46528 L 1 g
F P
s
P
p
.48895 .46554 m .49153 .46528 L .47755 .46719 L 1 g
F
P
p
.002 w
.5 .46395 m .5 .46442 L p
.48895 .46554 L 1 g
F P
s
P
p
.002 w
.45806 .46152 m .46559 .4254 L p
.48689 .46584 L 1 g
F P
s
P
p
.002 w
.49582 .46455 m .50824 .44105 L p
.51267 .46169 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47723 .4677 L p
1 g
F P
s
P
p
.49153 .46528 m .5 .46442 L .47723 .4677 L 1 g
F
P
p
.002 w
.52235 .46703 m .52282 .46778 L p
.50888 .46511 L 1 g
F P
s
P
p
.53147 .4715 m .53744 .47443 L .53446 .47305 L 1 g
F
P
p
.52214 .46667 m .53744 .47443 L .53147 .4715 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.50824 .44105 m .54492 .46659 L .53744 .47443 L p
1 g
F P
s
P
p
.54388 .47742 m .53999 .51797 L .53744 .47443 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.50824 .44105 m .53744 .47443 L .51281 .46235 L 1 g
F
P
p
.002 w
.53744 .47443 m .54492 .46659 L p
.54388 .47742 L 1 g
F P
s
P
p
.002 w
.54229 .47668 m .54302 .47747 L p
.53446 .47305 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54229 .47668 L p
1 g
F P
s
P
p
.54843 .48263 m .55834 .49233 L .54229 .47668 L 1 g
F
P
p
.002 w
.55724 .49117 m .55834 .49233 L p
.54843 .48263 L 1 g
F P
s
P
p
.56192 .50065 m .56333 .50352 L .56272 .50218 L 1 g
F
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.56272 .50218 L 1 g
F P
s
P
p
.56616 .50968 m .56647 .51711 L .566 .51004 L 1 g
F
P
p
.56757 .51275 m .56647 .51711 L .56616 .50968 L 1 g
F
P
p
.56654 .52734 m .56405 .54001 L .56459 .53804 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54991 .56247 m .55036 .54465 L .56405 .54001 L p
1 g
F P
s
P
p
.002 w
.56405 .54001 m .56755 .53883 L p
.56146 .54699 L 1 g
F P
s
P
p
.56075 .54566 m .54991 .56247 L .55594 .55439 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.56146 .54699 m .54991 .56247 L .56405 .54001 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56798 .52944 L p
1 g
F P
s
P
p
.002 w
.56798 .52944 m .56654 .52734 L p
.56439 .53909 L 1 g
F P
s
P
p
.56439 .53909 m .56257 .5491 L .56798 .52944 L 1 g
F
P
p
.002 w
.56405 .54001 m .55036 .54465 L p
.5735 .50508 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56644 .5166 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.002 w
.56722 .52832 m .56854 .53025 L p
.56644 .5166 L 1 g
F P
s
P
p
.56459 .53804 m .56405 .54001 L .56439 .53909 L 1 g
F
P
p
.002 w
.56146 .54699 m .56257 .5491 L p
.56439 .53909 L 1 g
F P
s
P
p
.55594 .55439 m .54991 .56247 L .55436 .55725 L 1 g
F
P
p
.54854 .56129 m .53903 .57014 L .53981 .56961 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55036 .54465 m .5499 .56279 L p
.5149 .57003 L 1 g
F P
s
P
p
.002 w
.53903 .57014 m .5149 .57003 L p
.5499 .56279 L 1 g
F P
s
P
p
.002 w
.54926 .56322 m .54998 .56518 L p
.55436 .55725 L 1 g
F P
s
P
p
.53981 .56961 m .53903 .57014 L .5396 .56981 L 1 g
F
P
p
.002 w
.53166 .57438 m .5322 .57686 L p
.5396 .56981 L 1 g
F P
s
P
p
.002 w
.54971 .57018 m .53855 .5918 L .51171 .58585 L p
1 g
F P
s
P
p
.002 w
.51171 .58585 m .50756 .58493 L p
.52225 .57979 L 1 g
F P
s
P
p
.002 w
.53855 .5918 m .54971 .57018 L .58257 .56615 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62407 .35942 m .66266 .40995 L .64642 .43221 L p
1 g
F P
s
P
p
.002 w
.66266 .40995 m .62407 .35942 L .63479 .33749 L p
1 g
F P
s
P
p
.002 w
.57856 .2969 m .63479 .33749 L .62407 .35942 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.41253 .54078 m .41112 .54918 L .38096 .53781 L p
1 g
F P
s
P
p
.002 w
.38096 .53781 m .38345 .52119 L .41253 .54078 L p
1 g
F P
s
P
p
.002 w
.42506 .35055 m .3734 .3628 L .3739 .33279 L p
1 g
F P
s
P
p
.002 w
.3739 .33279 m .42983 .31896 L .42506 .35055 L p
1 g
F P
s
P
p
.002 w
.58399 .53326 m .58257 .56615 L .54971 .57018 L p
1 g
F P
s
P
p
.002 w
.58257 .56615 m .58399 .53326 L .6147 .5189 L p
1 g
F P
s
P
p
.002 w
.6253 .45497 m .64145 .50214 L .6147 .5189 L p
1 g
F P
s
P
p
.002 w
.64145 .50214 m .6253 .45497 L .64642 .43221 L p
1 g
F P
s
P
p
.002 w
.38395 .42977 m .35473 .44859 L .3422 .41852 L p
1 g
F P
s
P
p
.002 w
.3422 .41852 m .37676 .39551 L .38395 .42977 L p
1 g
F P
s
P
p
.002 w
.56843 .31948 m .50296 .29579 L .51229 .27299 L p
1 g
F P
s
P
p
.002 w
.51229 .27299 m .57856 .2969 L .56843 .31948 L p
1 g
F P
s
P
p
.002 w
.39304 .50735 m .38345 .52119 L .35821 .49911 L p
1 g
F P
s
P
p
.002 w
.35821 .49911 m .37185 .47857 L .39304 .50735 L p
1 g
F P
s
P
p
.002 w
.62407 .35942 m .56843 .31948 L .57856 .2969 L p
1 g
F P
s
P
p
.002 w
.49325 .32341 m .42983 .31896 L .4366 .29147 L p
1 g
F P
s
P
p
.002 w
.4366 .29147 m .50296 .29579 L .49325 .32341 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.41754 .53386 m .41253 .54078 L .38345 .52119 L p
1 g
F P
s
P
p
.002 w
.38345 .52119 m .39304 .50735 L .41754 .53386 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.60923 .38419 m .64642 .43221 L .6253 .45497 L p
1 g
F P
s
P
p
.002 w
.64642 .43221 m .60923 .38419 L .62407 .35942 L p
1 g
F P
s
P
p
.002 w
.39477 .46434 m .37185 .47857 L .35473 .44859 L p
1 g
F P
s
P
p
.002 w
.35473 .44859 m .38395 .42977 L .39477 .46434 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59992 .47742 m .6147 .5189 L .58399 .53326 L p
1 g
F P
s
P
p
.002 w
.6147 .5189 m .59992 .47742 L .6253 .45497 L p
1 g
F P
s
P
p
.002 w
.47581 .57327 m .47938 .56564 L .5149 .57003 L p
1 g
F P
s
P
p
.002 w
.42252 .38518 m .37676 .39551 L .3734 .3628 L p
1 g
F P
s
P
p
.002 w
.3734 .3628 m .42506 .35055 L .42252 .38518 L p
1 g
F P
s
P
p
.002 w
.56843 .31948 m .62407 .35942 L .60923 .38419 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.51501 .55259 m .5149 .57003 L .47938 .56564 L p
1 g
F P
s
P
p
.002 w
.5149 .57003 m .51501 .55259 L .55036 .54465 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40884 .49791 m .39304 .50735 L .37185 .47857 L p
1 g
F P
s
P
p
.002 w
.37185 .47857 m .39477 .46434 L .40884 .49791 L p
1 g
F P
s
P
p
.002 w
.47938 .56564 m .47927 .5568 L .51501 .55259 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.55588 .34614 m .49325 .32341 L .50296 .29579 L p
1 g
F P
s
P
p
.002 w
.50296 .29579 m .56843 .31948 L .55588 .34614 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.58399 .53326 m .57113 .4987 L .59992 .47742 L p
1 g
F P
s
P
p
.002 w
.42562 .52922 m .41754 .53386 L .39304 .50735 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.48354 .35499 m .42506 .35055 L .42983 .31896 L p
1 g
F P
s
P
p
.002 w
.42983 .31896 m .49325 .32341 L .48354 .35499 L p
1 g
F P
s
P
p
.002 w
.39304 .50735 m .40884 .49791 L .42562 .52922 L p
1 g
F P
s
P
p
.002 w
.60923 .38419 m .55588 .34614 L .56843 .31948 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42237 .42157 m .38395 .42977 L .37676 .39551 L p
1 g
F P
s
P
p
.002 w
.37676 .39551 m .42252 .38518 L .42237 .42157 L p
1 g
F P
s
P
p
.002 w
.47927 .5568 m .47543 .54771 L .50768 .53451 L p
1 g
F P
s
P
p
.002 w
.50768 .53451 m .51501 .55259 L .47927 .5568 L p
1 g
F P
s
P
p
.002 w
.59066 .41096 m .6253 .45497 L .59992 .47742 L p
1 g
F P
s
P
p
.002 w
.6253 .45497 m .59066 .41096 L .60923 .38419 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.53999 .51797 m .55036 .54465 L .51501 .55259 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.51501 .55259 m .50768 .53451 L .53999 .51797 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.47543 .54771 m .46825 .53938 L .49357 .51786 L p
1 g
F P
s
P
p
.002 w
.49357 .51786 m .50768 .53451 L .47543 .54771 L p
1 g
F P
s
P
p
.002 w
.55588 .34614 m .60923 .38419 L .59066 .41096 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.42464 .45833 m .39477 .46434 L .38395 .42977 L p
1 g
F P
s
P
p
.002 w
.38395 .42977 m .42237 .42157 L .42464 .45833 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.46825 .53938 m .45852 .53277 L .47422 .50461 L p
1 g
F P
s
P
p
.002 w
.47422 .50461 m .49357 .51786 L .46825 .53938 L p
1 g
F P
s
P
p
.002 w
.42922 .49406 m .40884 .49791 L .39477 .46434 L p
1 g
F P
s
P
p
.002 w
.45852 .53277 m .44732 .52861 L .4519 .49636 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.39477 .46434 m .42464 .45833 L .42922 .49406 L p
1 g
F P
s
P
p
.002 w
.56896 .43879 m .59992 .47742 L .57113 .4987 L p
1 g
F P
s
P
p
.002 w
.59992 .47742 m .56896 .43879 L .59066 .41096 L p
1 g
F P
s
P
p
.002 w
.4519 .49636 m .47422 .50461 L .45852 .53277 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.47419 .38942 m .42252 .38518 L .42506 .35055 L p
1 g
F P
s
P
p
.002 w
.42506 .35055 m .48354 .35499 L .47419 .38942 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54131 .37603 m .48354 .35499 L .49325 .32341 L p
1 g
F P
s
P
p
.002 w
.49325 .32341 m .55588 .34614 L .54131 .37603 L p
1 g
F P
s
P
p
.002 w
.50768 .53451 m .49357 .51786 L .51945 .49329 L p
1 g
F P
s
P
p
.002 w
.51945 .49329 m .53999 .51797 L .50768 .53451 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.59066 .41096 m .54131 .37603 L .55588 .34614 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57113 .4987 m .54492 .46659 L .56896 .43879 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.54131 .37603 m .59066 .41096 L .56896 .43879 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.46559 .4254 m .42237 .42157 L .42252 .38518 L p
1 g
F P
s
P
p
.002 w
.42252 .38518 m .47419 .38942 L .46559 .4254 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.49357 .51786 m .47422 .50461 L .49101 .47365 L p
1 g
F P
s
P
p
.002 w
.49101 .47365 m .51945 .49329 L .49357 .51786 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45806 .46152 m .42464 .45833 L .42237 .42157 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.42237 .42157 m .46559 .4254 L .45806 .46152 L p
1 g
F P
s
P
p
.002 w
.52522 .40808 m .47419 .38942 L .48354 .35499 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5006 .39907 L
s
P
p
.002 w
.48354 .35499 m .54131 .37603 L .52522 .40808 L p
1 g
F P
s
P
p
.004 w
.50118 .36841 m
.50184 .33363 L
s
P
p
.004 w
.50112 .37135 m
.50113 .37086 L
s
P
p
.004 w
.50113 .37086 m
.50118 .36841 L
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52522 .40808 m .56896 .43879 L .54492 .46659 L p
1 g
F P
s
P
p
.002 w
.56896 .43879 m .52522 .40808 L .54131 .37603 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.004 w
.41167 .63184 m
.4216 .6092 L
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.004 w
.4216 .6092 m
.42576 .59974 L
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54492 .46659 m .50824 .44105 L .52522 .40808 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50824 .44105 m .46559 .4254 L .47419 .38942 L p
1 g
F P
s
P
p
.002 w
.47419 .38942 m .52522 .40808 L .50824 .44105 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .50184 .33363 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .41167 .63184 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.282171)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.282171)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47277 .42837 m .50044 .44979 L .51465 .42499 L p
1 g
F P
s
P
p
.002 w
.51465 .42499 m .49322 .40839 L .47277 .42837 L p
1 g
F P
s
P
p
.002 w
.53967 .43492 m .51465 .42499 L .50044 .44979 L p
1 g
F P
s
P
p
.002 w
.49322 .40839 m .51465 .42499 L .52853 .40026 L p
1 g
F P
s
P
p
.002 w
.51465 .42499 m .53967 .43492 L .54567 .407 L p
1 g
F P
s
P
p
.002 w
.54567 .407 m .52853 .40026 L .51465 .42499 L p
1 g
F P
s
P
p
.002 w
.4529 .44848 m .48617 .47421 L .50044 .44979 L p
1 g
F P
s
P
p
.002 w
.50044 .44979 m .47277 .42837 L .4529 .44848 L p
1 g
F P
s
P
p
.002 w
.53272 .46269 m .50044 .44979 L .48617 .47421 L p
1 g
F P
s
P
p
.002 w
.50044 .44979 m .53272 .46269 L .53967 .43492 L p
1 g
F P
s
P
p
.002 w
.45239 .40049 m .47277 .42837 L .49322 .40839 L p
1 g
F P
s
P
p
.002 w
.49322 .40839 m .47753 .38675 L .45239 .40049 L p
1 g
F P
s
P
p
.002 w
.47753 .38675 m .49322 .40839 L .51388 .3889 L p
1 g
F P
s
P
p
.002 w
.52853 .40026 m .51388 .3889 L .49322 .40839 L p
1 g
F P
s
P
p
.002 w
.42826 .41506 m .4529 .44848 L .47277 .42837 L p
1 g
F P
s
P
p
.002 w
.47277 .42837 m .45239 .40049 L .42826 .41506 L p
1 g
F P
s
P
p
.002 w
.56583 .43712 m .53967 .43492 L .53272 .46269 L p
1 g
F P
s
P
p
.002 w
.53967 .43492 m .56583 .43712 L .56354 .4084 L p
1 g
F P
s
P
p
.002 w
.56354 .4084 m .54567 .407 L .53967 .43492 L p
1 g
F P
s
P
p
.002 w
.51388 .3889 m .52853 .40026 L .54185 .37605 L p
1 g
F P
s
P
p
.002 w
.52853 .40026 m .54567 .407 L .55059 .37946 L p
1 g
F P
s
P
p
.002 w
.55059 .37946 m .54185 .37605 L .52853 .40026 L p
1 g
F P
s
P
p
.002 w
.51388 .3889 m .50321 .37406 L .47753 .38675 L p
1 g
F P
s
P
p
.002 w
.50321 .37406 m .51388 .3889 L .53438 .37025 L p
1 g
F P
s
P
p
.002 w
.54185 .37605 m .53438 .37025 L .51388 .3889 L p
1 g
F P
s
P
p
.002 w
.43398 .46836 m .4721 .49781 L .48617 .47421 L p
1 g
F P
s
P
p
.002 w
.48617 .47421 m .4529 .44848 L .43398 .46836 L p
1 g
F P
s
P
p
.002 w
.52494 .48983 m .48617 .47421 L .4721 .49781 L p
1 g
F P
s
P
p
.002 w
.48617 .47421 m .52494 .48983 L .53272 .46269 L p
1 g
F P
s
P
p
.002 w
.56651 .46575 m .53272 .46269 L .52494 .48983 L p
1 g
F P
s
P
p
.002 w
.53272 .46269 m .56651 .46575 L .56583 .43712 L p
1 g
F P
s
P
p
.002 w
.4414 .3688 m .45239 .40049 L .47753 .38675 L p
1 g
F P
s
P
p
.002 w
.47753 .38675 m .46921 .36218 L .4414 .3688 L p
1 g
F P
s
P
p
.002 w
.46921 .36218 m .47753 .38675 L .50321 .37406 L p
1 g
F P
s
P
p
.002 w
.40561 .43018 m .43398 .46836 L .4529 .44848 L p
1 g
F P
s
P
p
.002 w
.4529 .44848 m .42826 .41506 L .40561 .43018 L p
1 g
F P
s
P
p
.002 w
.54567 .407 m .56354 .4084 L .55969 .38012 L p
1 g
F P
s
P
p
.002 w
.55969 .38012 m .55059 .37946 L .54567 .407 L p
1 g
F P
s
P
p
.002 w
.41477 .377 m .42826 .41506 L .45239 .40049 L p
1 g
F P
s
P
p
.002 w
.45239 .40049 m .4414 .3688 L .41477 .377 L p
1 g
F P
s
P
p
.002 w
.50321 .37406 m .49765 .35725 L .46921 .36218 L p
1 g
F P
s
P
p
.002 w
.49765 .35725 m .50321 .37406 L .52898 .36267 L p
1 g
F P
s
P
p
.002 w
.53438 .37025 m .52898 .36267 L .50321 .37406 L p
1 g
F P
s
P
p
.002 w
.4721 .49781 m .51646 .51582 L .52494 .48983 L p
1 g
F P
s
P
p
.002 w
.56558 .49375 m .52494 .48983 L .51646 .51582 L p
1 g
F P
s
P
p
.002 w
.52494 .48983 m .56558 .49375 L .56651 .46575 L p
1 g
F P
s
P
p
.002 w
.59047 .43126 m .56583 .43712 L .56651 .46575 L p
1 g
F P
s
P
p
.002 w
.56583 .43712 m .59047 .43126 L .5803 .40426 L p
1 g
F P
s
P
p
.002 w
.5803 .40426 m .56354 .4084 L .56583 .43712 L p
1 g
F P
s
P
p
.002 w
.56354 .4084 m .5803 .40426 L .56818 .37794 L p
1 g
F P
s
P
p
.002 w
.56818 .37794 m .55969 .38012 L .56354 .4084 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .53438 .37025 L .54185 .37605 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .54185 .37605 L .55059 .37946 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .52898 .36267 L .53438 .37025 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .55059 .37946 L .55969 .38012 L closepath p
1 g
F P
s
P
p
.002 w
.41637 .48764 m .45849 .52013 L .4721 .49781 L p
1 g
F P
s
P
p
.002 w
.4721 .49781 m .43398 .46836 L .41637 .48764 L p
1 g
F P
s
P
p
.002 w
.51646 .51582 m .4721 .49781 L .45849 .52013 L p
1 g
F P
s
P
p
.002 w
.46925 .33715 m .46921 .36218 L .49765 .35725 L p
1 g
F P
s
P
p
.002 w
.49765 .35725 m .49785 .3402 L .46925 .33715 L p
1 g
F P
s
P
p
.002 w
.49785 .3402 m .49765 .35725 L .52621 .3541 L p
1 g
F P
s
P
p
.002 w
.52898 .36267 m .52621 .3541 L .49765 .35725 L p
1 g
F P
s
P
p
.002 w
.38985 .38666 m .40561 .43018 L .42826 .41506 L p
1 g
F P
s
P
p
.002 w
.42826 .41506 m .41477 .377 L .38985 .38666 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .52621 .3541 L .52898 .36267 L closepath p
1 g
F P
s
P
p
.002 w
.44114 .33638 m .4414 .3688 L .46921 .36218 L p
1 g
F P
s
P
p
.002 w
.46921 .36218 m .46925 .33715 L .44114 .33638 L p
1 g
F P
s
P
p
.002 w
.59849 .45845 m .56651 .46575 L .56558 .49375 L p
1 g
F P
s
P
p
.002 w
.56651 .46575 m .59849 .45845 L .59047 .43126 L p
1 g
F P
s
P
p
.002 w
.38488 .44557 m .41637 .48764 L .43398 .46836 L p
1 g
F P
s
P
p
.002 w
.43398 .46836 m .40561 .43018 L .38488 .44557 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .55969 .38012 L .56818 .37794 L closepath p
1 g
F P
s
P
p
.002 w
.52621 .3541 m .52639 .34545 L .49785 .3402 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .52639 .34545 L .52621 .3541 L closepath p
1 g
F P
s
P
p
.002 w
.59418 .39491 m .5803 .40426 L .59047 .43126 L p
1 g
F P
s
P
p
.002 w
.5803 .40426 m .59418 .39491 L .57516 .37313 L p
1 g
F P
s
P
p
.002 w
.57516 .37313 m .56818 .37794 L .5803 .40426 L p
1 g
F P
s
P
p
.002 w
.41409 .33794 m .41477 .377 L .4414 .3688 L p
1 g
F P
s
P
p
.002 w
.4414 .3688 m .44114 .33638 L .41409 .33794 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .56818 .37794 L .57516 .37313 L closepath p
1 g
F P
s
P
p
.002 w
.45849 .52013 m .50743 .54015 L .51646 .51582 L p
1 g
F P
s
P
p
.002 w
.563 .52058 m .51646 .51582 L .50743 .54015 L p
1 g
F P
s
P
p
.002 w
.51646 .51582 m .563 .52058 L .56558 .49375 L p
1 g
F P
s
P
p
.002 w
.50387 .32471 m .49785 .3402 L .52639 .34545 L p
1 g
F P
s
P
p
.002 w
.52639 .34545 m .52953 .33765 L .50387 .32471 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .52953 .33765 L .52639 .34545 L closepath p
1 g
F P
s
P
p
.002 w
.47785 .31427 m .46925 .33715 L .49785 .3402 L p
1 g
F P
s
P
p
.002 w
.49785 .3402 m .50387 .32471 L .47785 .31427 L p
1 g
F P
s
P
p
.002 w
.61101 .41775 m .59047 .43126 L .59849 .45845 L p
1 g
F P
s
P
p
.002 w
.59047 .43126 m .61101 .41775 L .59418 .39491 L p
1 g
F P
s
P
p
.002 w
.60416 .48528 m .56558 .49375 L .563 .52058 L p
1 g
F P
s
P
p
.002 w
.56558 .49375 m .60416 .48528 L .59849 .45845 L p
1 g
F P
s
P
p
.002 w
.36718 .39762 m .38488 .44557 L .40561 .43018 L p
1 g
F P
s
P
p
.002 w
.40561 .43018 m .38985 .38666 L .36718 .39762 L p
1 g
F P
s
P
p
.002 w
.57985 .36618 m .57516 .37313 L .59418 .39491 L p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .57516 .37313 L .57985 .36618 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .56139 .32894 L .55217 .32691 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .55217 .32691 L .54315 .32782 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .54315 .32782 L .53532 .33154 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .53532 .33154 L .52953 .33765 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .57985 .36618 L .58172 .35783 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .58172 .35783 L .58053 .34899 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .58053 .34899 L .57641 .34063 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .57641 .34063 L .56978 .33369 L closepath p
1 g
F P
s
P
p
.002 w
.55434 .3528 m .56978 .33369 L .56139 .32894 L closepath p
1 g
F P
s
P
p
.002 w
.5152 .31249 m .50387 .32471 L .52953 .33765 L p
1 g
F P
s
P
p
.002 w
.52953 .33765 m .53532 .33154 L .5152 .31249 L p
1 g
F P
s
P
p
.002 w
.45199 .30658 m .44114 .33638 L .46925 .33715 L p
1 g
F P
s
P
p
.002 w
.46925 .33715 m .47785 .31427 L .45199 .30658 L p
1 g
F P
s
P
p
.002 w
.40045 .50592 m .44561 .54071 L .45849 .52013 L p
1 g
F P
s
P
p
.002 w
.45849 .52013 m .41637 .48764 L .40045 .50592 L p
1 g
F P
s
P
p
.002 w
.50743 .54015 m .45849 .52013 L .44561 .54071 L p
1 g
F P
s
P
p
.002 w
.38868 .34188 m .38985 .38666 L .41477 .377 L p
1 g
F P
s
P
p
.002 w
.41477 .377 m .41409 .33794 L .38868 .34188 L p
1 g
F P
s
P
p
.002 w
.60361 .38127 m .59418 .39491 L .61101 .41775 L p
1 g
F P
s
P
p
.002 w
.59418 .39491 m .60361 .38127 L .57985 .36618 L p
1 g
F P
s
P
p
.002 w
.36656 .46096 m .40045 .50592 L .41637 .48764 L p
1 g
F P
s
P
p
.002 w
.41637 .48764 m .38488 .44557 L .36656 .46096 L p
1 g
F P
s
P
p
.002 w
.62531 .44121 m .59849 .45845 L .60416 .48528 L p
1 g
F P
s
P
p
.002 w
.59849 .45845 m .62531 .44121 L .61101 .41775 L p
1 g
F P
s
P
p
.002 w
.58172 .35783 m .57985 .36618 L .60361 .38127 L p
1 g
F P
s
P
p
.002 w
.53067 .30495 m .5152 .31249 L .53532 .33154 L p
1 g
F P
s
P
p
.002 w
.53532 .33154 m .54315 .32782 L .53067 .30495 L p
1 g
F P
s
P
p
.002 w
.49435 .29608 m .47785 .31427 L .50387 .32471 L p
1 g
F P
s
P
p
.002 w
.50387 .32471 m .5152 .31249 L .49435 .29608 L p
1 g
F P
s
P
p
.002 w
.60361 .38127 m .60749 .36475 L .58172 .35783 L p
1 g
F P
s
P
p
.002 w
.58053 .34899 m .58172 .35783 L .60749 .36475 L p
1 g
F P
s
P
p
.002 w
.44561 .54071 m .498 .56229 L .50743 .54015 L p
1 g
F P
s
P
p
.002 w
.55881 .54569 m .50743 .54015 L .498 .56229 L p
1 g
F P
s
P
p
.002 w
.50743 .54015 m .55881 .54569 L .563 .52058 L p
1 g
F P
s
P
p
.002 w
.60732 .51124 m .563 .52058 L .55881 .54569 L p
1 g
F P
s
P
p
.002 w
.563 .52058 m .60732 .51124 L .60416 .48528 L p
1 g
F P
s
P
p
.002 w
.42681 .30187 m .41409 .33794 L .44114 .33638 L p
1 g
F P
s
P
p
.002 w
.44114 .33638 m .45199 .30658 L .42681 .30187 L p
1 g
F P
s
P
p
.002 w
.54863 .30303 m .53067 .30495 L .54315 .32782 L p
1 g
F P
s
P
p
.002 w
.54315 .32782 m .55217 .32691 L .54863 .30303 L p
1 g
F P
s
P
p
.002 w
.62514 .39782 m .61101 .41775 L .62531 .44121 L p
1 g
F P
s
P
p
.002 w
.61101 .41775 m .62514 .39782 L .60361 .38127 L p
1 g
F P
s
P
p
.002 w
.60749 .36475 m .60527 .34714 L .58053 .34899 L p
1 g
F P
s
P
p
.002 w
.57641 .34063 m .58053 .34899 L .60527 .34714 L p
1 g
F P
s
P
p
.002 w
.60749 .36475 m .60361 .38127 L .62514 .39782 L p
1 g
F P
s
P
p
.002 w
.56707 .30701 m .54863 .30303 L .55217 .32691 L p
1 g
F P
s
P
p
.002 w
.55217 .32691 m .56139 .32894 L .56707 .30701 L p
1 g
F P
s
P
p
.002 w
.34731 .4097 m .36656 .46096 L .38488 .44557 L p
1 g
F P
s
P
p
.002 w
.38488 .44557 m .36718 .39762 L .34731 .4097 L p
1 g
F P
s
P
p
.002 w
.6367 .46483 m .60416 .48528 L .60732 .51124 L p
1 g
F P
s
P
p
.002 w
.60416 .48528 m .6367 .46483 L .62531 .44121 L p
1 g
F P
s
P
p
.002 w
.60527 .34714 m .5971 .33042 L .57641 .34063 L p
1 g
F P
s
P
p
.002 w
.56978 .33369 m .57641 .34063 L .5971 .33042 L p
1 g
F P
s
P
p
.002 w
.47319 .28271 m .45199 .30658 L .47785 .31427 L p
1 g
F P
s
P
p
.002 w
.47785 .31427 m .49435 .29608 L .47319 .28271 L p
1 g
F P
s
P
p
.002 w
.36549 .34817 m .36718 .39762 L .38985 .38666 L p
1 g
F P
s
P
p
.002 w
.38985 .38666 m .38868 .34188 L .36549 .34817 L p
1 g
F P
s
P
p
.002 w
.58387 .3165 m .56707 .30701 L .56139 .32894 L p
1 g
F P
s
P
p
.002 w
.56139 .32894 m .56978 .33369 L .58387 .3165 L p
1 g
F P
s
P
p
.002 w
.51713 .28474 m .49435 .29608 L .5152 .31249 L p
1 g
F P
s
P
p
.002 w
.5152 .31249 m .53067 .30495 L .51713 .28474 L p
1 g
F P
s
P
p
.002 w
.5971 .33042 m .58387 .3165 L .56978 .33369 L p
1 g
F P
s
P
p
.002 w
.38661 .52279 m .43375 .55908 L .44561 .54071 L p
1 g
F P
s
P
p
.002 w
.44561 .54071 m .40045 .50592 L .38661 .52279 L p
1 g
F P
s
P
p
.002 w
.498 .56229 m .44561 .54071 L .43375 .55908 L p
1 g
F P
s
P
p
.002 w
.35113 .476 m .38661 .52279 L .40045 .50592 L p
1 g
F P
s
P
p
.002 w
.40045 .50592 m .36656 .46096 L .35113 .476 L p
1 g
F P
s
P
p
.002 w
.64392 .41552 m .62531 .44121 L .6367 .46483 L p
1 g
F P
s
P
p
.002 w
.62531 .44121 m .64392 .41552 L .62514 .39782 L p
1 g
F P
s
P
p
.002 w
.62514 .39782 m .63109 .37348 L .60749 .36475 L p
1 g
F P
s
P
p
.002 w
.60527 .34714 m .60749 .36475 L .63109 .37348 L p
1 g
F P
s
P
p
.002 w
.40288 .30034 m .38868 .34188 L .41409 .33794 L p
1 g
F P
s
P
p
.002 w
.41409 .33794 m .42681 .30187 L .40288 .30034 L p
1 g
F P
s
P
p
.002 w
.54375 .28172 m .51713 .28474 L .53067 .30495 L p
1 g
F P
s
P
p
.002 w
.53067 .30495 m .54863 .30303 L .54375 .28172 L p
1 g
F P
s
P
p
.002 w
.498 .56229 m .55302 .56849 L .55881 .54569 L p
1 g
F P
s
P
p
.002 w
.60783 .53573 m .55881 .54569 L .55302 .56849 L p
1 g
F P
s
P
p
.002 w
.55881 .54569 m .60783 .53573 L .60732 .51124 L p
1 g
F P
s
P
p
.002 w
.63109 .37348 m .62514 .39782 L .64392 .41552 L p
1 g
F P
s
P
p
.002 w
.43375 .55908 m .48837 .58171 L .498 .56229 L p
1 g
F P
s
P
p
.002 w
.55302 .56849 m .498 .56229 L .48837 .58171 L p
1 g
F P
s
P
p
.002 w
.45216 .2728 m .42681 .30187 L .45199 .30658 L p
1 g
F P
s
P
p
.002 w
.45199 .30658 m .47319 .28271 L .45216 .2728 L p
1 g
F P
s
P
p
.002 w
.63109 .37348 m .62798 .34736 L .60527 .34714 L p
1 g
F P
s
P
p
.002 w
.5971 .33042 m .60527 .34714 L .62798 .34736 L p
1 g
F P
s
P
p
.002 w
.64487 .48812 m .60732 .51124 L .60783 .53573 L p
1 g
F P
s
P
p
.002 w
.60732 .51124 m .64487 .48812 L .6367 .46483 L p
1 g
F P
s
P
p
.002 w
.50277 .2677 m .47319 .28271 L .49435 .29608 L p
1 g
F P
s
P
p
.002 w
.49435 .29608 m .51713 .28474 L .50277 .2677 L p
1 g
F P
s
P
p
.002 w
.57121 .28757 m .54375 .28172 L .54863 .30303 L p
1 g
F P
s
P
p
.002 w
.54863 .30303 m .56707 .30701 L .57121 .28757 L p
1 g
F P
s
P
p
.002 w
.34512 .35678 m .34731 .4097 L .36718 .39762 L p
1 g
F P
s
P
p
.002 w
.36718 .39762 m .36549 .34817 L .34512 .35678 L p
1 g
F P
s
P
p
.002 w
.33079 .42268 m .35113 .476 L .36656 .46096 L p
1 g
F P
s
P
p
.002 w
.36656 .46096 m .34731 .4097 L .33079 .42268 L p
1 g
F P
s
P
p
.002 w
.62798 .34736 m .61594 .32245 L .5971 .33042 L p
1 g
F P
s
P
p
.002 w
.58387 .3165 m .5971 .33042 L .61594 .32245 L p
1 g
F P
s
P
p
.002 w
.59626 .30169 m .57121 .28757 L .56707 .30701 L p
1 g
F P
s
P
p
.002 w
.56707 .30701 m .58387 .3165 L .59626 .30169 L p
1 g
F P
s
P
p
.002 w
.65948 .43404 m .6367 .46483 L .64487 .48812 L p
1 g
F P
s
P
p
.002 w
.6367 .46483 m .65948 .43404 L .64392 .41552 L p
1 g
F P
s
P
p
.002 w
.61594 .32245 m .59626 .30169 L .58387 .3165 L p
1 g
F P
s
P
p
.002 w
.3808 .30217 m .36549 .34817 L .38868 .34188 L p
1 g
F P
s
P
p
.002 w
.38868 .34188 m .40288 .30034 L .3808 .30217 L p
1 g
F P
s
P
p
.002 w
.64392 .41552 m .65195 .3839 L .63109 .37348 L p
1 g
F P
s
P
p
.002 w
.62798 .34736 m .63109 .37348 L .65195 .3839 L p
1 g
F P
s
P
p
.002 w
.37525 .53784 m .42321 .57473 L .43375 .55908 L p
1 g
F P
s
P
p
.002 w
.43375 .55908 m .38661 .52279 L .37525 .53784 L p
1 g
F P
s
P
p
.002 w
.48837 .58171 m .43375 .55908 L .42321 .57473 L p
1 g
F P
s
P
p
.002 w
.65195 .3839 m .64392 .41552 L .65948 .43404 L p
1 g
F P
s
P
p
.002 w
.33905 .49036 m .37525 .53784 L .38661 .52279 L p
1 g
F P
s
P
p
.002 w
.38661 .52279 m .35113 .476 L .33905 .49036 L p
1 g
F P
s
P
p
.002 w
.53758 .26359 m .50277 .2677 L .51713 .28474 L p
1 g
F P
s
P
p
.002 w
.51713 .28474 m .54375 .28172 L .53758 .26359 L p
1 g
F P
s
P
p
.002 w
.48837 .58171 m .54569 .58842 L .55302 .56849 L p
1 g
F P
s
P
p
.002 w
.60558 .5582 m .55302 .56849 L .54569 .58842 L p
1 g
F P
s
P
p
.002 w
.55302 .56849 m .60558 .5582 L .60783 .53573 L p
1 g
F P
s
P
p
.002 w
.43175 .26672 m .40288 .30034 L .42681 .30187 L p
1 g
F P
s
P
p
.002 w
.42681 .30187 m .45216 .2728 L .43175 .26672 L p
1 g
F P
s
P
p
.002 w
.48788 .25437 m .45216 .2728 L .47319 .28271 L p
1 g
F P
s
P
p
.002 w
.47319 .28271 m .50277 .2677 L .48788 .25437 L p
1 g
F P
s
P
p
.002 w
.64952 .51056 m .60783 .53573 L .60558 .5582 L p
1 g
F P
s
P
p
.002 w
.60783 .53573 m .64952 .51056 L .64487 .48812 L p
1 g
F P
s
P
p
.002 w
.42321 .57473 m .47871 .59785 L .48837 .58171 L p
1 g
F P
s
P
p
.002 w
.54569 .58842 m .48837 .58171 L .47871 .59785 L p
1 g
F P
s
P
p
.002 w
.65195 .3839 m .64808 .34974 L .62798 .34736 L p
1 g
F P
s
P
p
.002 w
.61594 .32245 m .62798 .34736 L .64808 .34974 L p
1 g
F P
s
P
p
.002 w
.32818 .36762 m .33079 .42268 L .34731 .4097 L p
1 g
F P
s
P
p
.002 w
.34731 .4097 m .34512 .35678 L .32818 .36762 L p
1 g
F P
s
P
p
.002 w
.57363 .27116 m .53758 .26359 L .54375 .28172 L p
1 g
F P
s
P
p
.002 w
.54375 .28172 m .57121 .28757 L .57363 .27116 L p
1 g
F P
s
P
p
.002 w
.31817 .43631 m .33905 .49036 L .35113 .476 L p
1 g
F P
s
P
p
.002 w
.35113 .476 m .33079 .42268 L .31817 .43631 L p
1 g
F P
s
P
p
.002 w
.67133 .45298 m .64487 .48812 L .64952 .51056 L p
1 g
F P
s
P
p
.002 w
.64487 .48812 m .67133 .45298 L .65948 .43404 L p
1 g
F P
s
P
p
.002 w
.36116 .30746 m .34512 .35678 L .36549 .34817 L p
1 g
F P
s
P
p
.002 w
.36549 .34817 m .3808 .30217 L .36116 .30746 L p
1 g
F P
s
P
p
.002 w
.64808 .34974 m .63241 .31703 L .61594 .32245 L p
1 g
F P
s
P
p
.002 w
.59626 .30169 m .61594 .32245 L .63241 .31703 L p
1 g
F P
s
P
p
.002 w
.65948 .43404 m .66949 .39583 L .65195 .3839 L p
1 g
F P
s
P
p
.002 w
.64808 .34974 m .65195 .3839 L .66949 .39583 L p
1 g
F P
s
P
p
.002 w
.66949 .39583 m .65948 .43404 L .67133 .45298 L p
1 g
F P
s
P
p
.002 w
.60658 .28971 m .57363 .27116 L .57121 .28757 L p
1 g
F P
s
P
p
.002 w
.57121 .28757 m .59626 .30169 L .60658 .28971 L p
1 g
F P
s
P
p
.002 w
.63241 .31703 m .60658 .28971 L .59626 .30169 L p
1 g
F P
s
P
p
.002 w
.41246 .26479 m .3808 .30217 L .40288 .30034 L p
1 g
F P
s
P
p
.002 w
.40288 .30034 m .43175 .26672 L .41246 .26479 L p
1 g
F P
s
P
p
.002 w
.5302 .2492 m .48788 .25437 L .50277 .2677 L p
1 g
F P
s
P
p
.002 w
.50277 .2677 m .53758 .26359 L .5302 .2492 L p
1 g
F P
s
P
p
.002 w
.36673 .55062 m .4143 .58718 L .42321 .57473 L p
1 g
F P
s
P
p
.002 w
.42321 .57473 m .37525 .53784 L .36673 .55062 L p
1 g
F P
s
P
p
.002 w
.47871 .59785 m .42321 .57473 L .4143 .58718 L p
1 g
F P
s
P
p
.002 w
.47871 .59785 m .53692 .60489 L .54569 .58842 L p
1 g
F P
s
P
p
.002 w
.60049 .57802 m .54569 .58842 L .53692 .60489 L p
1 g
F P
s
P
p
.002 w
.54569 .58842 m .60049 .57802 L .60558 .5582 L p
1 g
F P
s
P
p
.002 w
.33078 .50366 m .36673 .55062 L .37525 .53784 L p
1 g
F P
s
P
p
.002 w
.37525 .53784 m .33905 .49036 L .33078 .50366 L p
1 g
F P
s
P
p
.002 w
.47278 .24526 m .43175 .26672 L .45216 .2728 L p
1 g
F P
s
P
p
.002 w
.45216 .2728 m .48788 .25437 L .47278 .24526 L p
1 g
F P
s
P
p
.002 w
.65037 .53158 m .60558 .5582 L .60049 .57802 L p
1 g
F P
s
P
p
.002 w
.60558 .5582 m .65037 .53158 L .64952 .51056 L p
1 g
F P
s
P
p
.002 w
.66949 .39583 m .66499 .35433 L .64808 .34974 L p
1 g
F P
s
P
p
.002 w
.63241 .31703 m .64808 .34974 L .66499 .35433 L p
1 g
F P
s
P
p
.002 w
.4143 .58718 m .46926 .61017 L .47871 .59785 L p
1 g
F P
s
P
p
.002 w
.53692 .60489 m .47871 .59785 L .46926 .61017 L p
1 g
F P
s
P
p
.002 w
.31527 .38053 m .31817 .43631 L .33079 .42268 L p
1 g
F P
s
P
p
.002 w
.33079 .42268 m .32818 .36762 L .31527 .38053 L p
1 g
F P
s
P
p
.002 w
.67903 .47194 m .64952 .51056 L .65037 .53158 L p
1 g
F P
s
P
p
.002 w
.64952 .51056 m .67903 .47194 L .67133 .45298 L p
1 g
F P
s
P
p
.002 w
.5742 .25836 m .5302 .2492 L .53758 .26359 L p
1 g
F P
s
P
p
.002 w
.53758 .26359 m .57363 .27116 L .5742 .25836 L p
1 g
F P
s
P
p
.002 w
.34458 .31626 m .32818 .36762 L .34512 .35678 L p
1 g
F P
s
P
p
.002 w
.34512 .35678 m .36116 .30746 L .34458 .31626 L p
1 g
F P
s
P
p
.002 w
.30997 .45029 m .33078 .50366 L .33905 .49036 L p
1 g
F P
s
P
p
.002 w
.33905 .49036 m .31817 .43631 L .30997 .45029 L p
1 g
F P
s
P
p
.002 w
.68313 .40909 m .67133 .45298 L .67903 .47194 L p
1 g
F P
s
P
p
.002 w
.67133 .45298 m .68313 .40909 L .66949 .39583 L p
1 g
F P
s
P
p
.002 w
.66499 .35433 m .66949 .39583 L .68313 .40909 L p
1 g
F P
s
P
p
.002 w
.66499 .35433 m .646 .31441 L .63241 .31703 L p
1 g
F P
s
P
p
.002 w
.60658 .28971 m .63241 .31703 L .646 .31441 L p
1 g
F P
s
P
p
.002 w
.39486 .26728 m .36116 .30746 L .3808 .30217 L p
1 g
F P
s
P
p
.002 w
.3808 .30217 m .41246 .26479 L .39486 .26728 L p
1 g
F P
s
P
p
.002 w
.61447 .28101 m .5742 .25836 L .57363 .27116 L p
1 g
F P
s
P
p
.002 w
.57363 .27116 m .60658 .28971 L .61447 .28101 L p
1 g
F P
s
P
p
.002 w
.5217 .23913 m .47278 .24526 L .48788 .25437 L p
1 g
F P
s
P
p
.002 w
.48788 .25437 m .5302 .2492 L .5217 .23913 L p
1 g
F P
s
P
p
.002 w
.646 .31441 m .61447 .28101 L .60658 .28971 L p
1 g
F P
s
P
p
.002 w
.45785 .24083 m .41246 .26479 L .43175 .26672 L p
1 g
F P
s
P
p
.002 w
.43175 .26672 m .47278 .24526 L .45785 .24083 L p
1 g
F P
s
P
p
.002 w
.46926 .61017 m .52684 .61731 L .53692 .60489 L p
1 g
F P
s
P
p
.002 w
.59254 .5946 m .53692 .60489 L .52684 .61731 L p
1 g
F P
s
P
p
.002 w
.53692 .60489 m .59254 .5946 L .60049 .57802 L p
1 g
F P
s
P
p
.002 w
.64723 .55061 m .60049 .57802 L .59254 .5946 L p
1 g
F P
s
P
p
.002 w
.60049 .57802 m .64723 .55061 L .65037 .53158 L p
1 g
F P
s
P
p
.002 w
.36145 .56071 m .40732 .59595 L .4143 .58718 L p
1 g
F P
s
P
p
.002 w
.4143 .58718 m .36673 .55062 L .36145 .56071 L p
1 g
F P
s
P
p
.002 w
.46926 .61017 m .4143 .58718 L .40732 .59595 L p
1 g
F P
s
P
p
.002 w
.32675 .51552 m .36145 .56071 L .36673 .55062 L p
1 g
F P
s
P
p
.002 w
.36673 .55062 m .33078 .50366 L .32675 .51552 L p
1 g
F P
s
P
p
.002 w
.68219 .49045 m .65037 .53158 L .64723 .55061 L p
1 g
F P
s
P
p
.002 w
.65037 .53158 m .68219 .49045 L .67903 .47194 L p
1 g
F P
s
P
p
.002 w
.68313 .40909 m .67812 .36114 L .66499 .35433 L p
1 g
F P
s
P
p
.002 w
.646 .31441 m .66499 .35433 L .67812 .36114 L p
1 g
F P
s
P
p
.002 w
.30693 .39528 m .30997 .45029 L .31817 .43631 L p
1 g
F P
s
P
p
.002 w
.31817 .43631 m .31527 .38053 L .30693 .39528 L p
1 g
F P
s
P
p
.002 w
.40732 .59595 m .46026 .61816 L .46926 .61017 L p
1 g
F P
s
P
p
.002 w
.52684 .61731 m .46926 .61017 L .46026 .61816 L p
1 g
F P
s
P
p
.002 w
.33167 .32851 m .31527 .38053 L .32818 .36762 L p
1 g
F P
s
P
p
.002 w
.32818 .36762 m .34458 .31626 L .33167 .32851 L p
1 g
F P
s
P
p
.002 w
.69233 .42341 m .67903 .47194 L .68219 .49045 L p
1 g
F P
s
P
p
.002 w
.67903 .47194 m .69233 .42341 L .68313 .40909 L p
1 g
F P
s
P
p
.002 w
.57277 .24969 m .5217 .23913 L .5302 .2492 L p
1 g
F P
s
P
p
.002 w
.5302 .2492 m .5742 .25836 L .57277 .24969 L p
1 g
F P
s
P
p
.002 w
.30664 .46427 m .32675 .51552 L .33078 .50366 L p
1 g
F P
s
P
p
.002 w
.33078 .50366 m .30997 .45029 L .30664 .46427 L p
1 g
F P
s
P
p
.002 w
.67812 .36114 m .68313 .40909 L .69233 .42341 L p
1 g
F P
s
P
p
.002 w
.3795 .27438 m .34458 .31626 L .36116 .30746 L p
1 g
F P
s
P
p
.002 w
.36116 .30746 m .39486 .26728 L .3795 .27438 L p
1 g
F P
s
P
p
.002 w
.67812 .36114 m .65619 .31483 L .646 .31441 L p
1 g
F P
s
P
p
.002 w
.61447 .28101 m .646 .31441 L .65619 .31483 L p
1 g
F P
s
P
p
.002 w
.51226 .23392 m .45785 .24083 L .47278 .24526 L p
1 g
F P
s
P
p
.002 w
.47278 .24526 m .5217 .23913 L .51226 .23392 L p
1 g
F P
s
P
p
.002 w
.4435 .24147 m .39486 .26728 L .41246 .26479 L p
1 g
F P
s
P
p
.002 w
.41246 .26479 m .45785 .24083 L .4435 .24147 L p
1 g
F P
s
P
p
.002 w
.61958 .276 m .57277 .24969 L .5742 .25836 L p
1 g
F P
s
P
p
.002 w
.5742 .25836 m .61447 .28101 L .61958 .276 L p
1 g
F P
s
P
p
.002 w
.65619 .31483 m .61958 .276 L .61447 .28101 L p
1 g
F P
s
P
p
.002 w
.52684 .61731 m .58178 .60733 L .59254 .5946 L p
1 g
F P
s
P
p
.002 w
.63996 .56705 m .59254 .5946 L .58178 .60733 L p
1 g
F P
s
P
p
.002 w
.59254 .5946 m .63996 .56705 L .64723 .55061 L p
1 g
F P
s
P
p
.002 w
.46026 .61816 m .51563 .62513 L .52684 .61731 L p
1 g
F P
s
P
p
.002 w
.58178 .60733 m .52684 .61731 L .51563 .62513 L p
1 g
F P
s
P
p
.002 w
.35972 .56766 m .40257 .60057 L .40732 .59595 L p
1 g
F P
s
P
p
.002 w
.40732 .59595 m .36145 .56071 L .35972 .56766 L p
1 g
F P
s
P
p
.002 w
.46026 .61816 m .40732 .59595 L .40257 .60057 L p
1 g
F P
s
P
p
.002 w
.68047 .50799 m .64723 .55061 L .63996 .56705 L p
1 g
F P
s
P
p
.002 w
.64723 .55061 m .68047 .50799 L .68219 .49045 L p
1 g
F P
s
P
p
.002 w
.32732 .52554 m .35972 .56766 L .36145 .56071 L p
1 g
F P
s
P
p
.002 w
.36145 .56071 m .32675 .51552 L .32732 .52554 L p
1 g
F P
s
P
p
.002 w
.30365 .41158 m .30664 .46427 L .30997 .45029 L p
1 g
F P
s
P
p
.002 w
.30997 .45029 m .30693 .39528 L .30365 .41158 L p
1 g
F P
s
P
p
.002 w
.69233 .42341 m .68689 .37013 L .67812 .36114 L p
1 g
F P
s
P
p
.002 w
.65619 .31483 m .67812 .36114 L .68689 .37013 L p
1 g
F P
s
P
p
.002 w
.32299 .34408 m .30693 .39528 L .31527 .38053 L p
1 g
F P
s
P
p
.002 w
.31527 .38053 m .33167 .32851 L .32299 .34408 L p
1 g
F P
s
P
p
.002 w
.69661 .43847 m .68219 .49045 L .68047 .50799 L p
1 g
F P
s
P
p
.002 w
.68219 .49045 m .69661 .43847 L .69233 .42341 L p
1 g
F P
s
P
p
.002 w
.40257 .60057 m .45197 .62133 L .46026 .61816 L p
1 g
F P
s
P
p
.002 w
.51563 .62513 m .46026 .61816 L .45197 .62133 L p
1 g
F P
s
P
p
.002 w
.68689 .37013 m .69233 .42341 L .69661 .43847 L p
1 g
F P
s
P
p
.002 w
.56925 .24567 m .51226 .23392 L .5217 .23913 L p
1 g
F P
s
P
p
.002 w
.5217 .23913 m .57277 .24969 L .56925 .24567 L p
1 g
F P
s
P
p
.002 w
.36694 .28613 m .33167 .32851 L .34458 .31626 L p
1 g
F P
s
P
p
.002 w
.34458 .31626 m .3795 .27438 L .36694 .28613 L p
1 g
F P
s
P
p
.002 w
.30858 .47787 m .32732 .52554 L .32675 .51552 L p
1 g
F P
s
P
p
.002 w
.32675 .51552 m .30664 .46427 L .30858 .47787 L p
1 g
F P
s
P
p
.002 w
.43017 .24746 m .3795 .27438 L .39486 .26728 L p
1 g
F P
s
P
p
.002 w
.39486 .26728 m .4435 .24147 L .43017 .24746 L p
1 g
F P
s
P
p
.002 w
.50208 .23401 m .4435 .24147 L .45785 .24083 L p
1 g
F P
s
P
p
.002 w
.45785 .24083 m .51226 .23392 L .50208 .23401 L p
1 g
F P
s
P
p
.002 w
.68689 .37013 m .66249 .31847 L .65619 .31483 L p
1 g
F P
s
P
p
.002 w
.61958 .276 m .65619 .31483 L .66249 .31847 L p
1 g
F P
s
P
p
.002 w
.51563 .62513 m .56834 .61566 L .58178 .60733 L p
1 g
F P
s
P
p
.002 w
.62853 .58032 m .58178 .60733 L .56834 .61566 L p
1 g
F P
s
P
p
.002 w
.58178 .60733 m .62853 .58032 L .63996 .56705 L p
1 g
F P
s
P
p
.002 w
.62159 .27508 m .56925 .24567 L .57277 .24969 L p
1 g
F P
s
P
p
.002 w
.57277 .24969 m .61958 .276 L .62159 .27508 L p
1 g
F P
s
P
p
.002 w
.45197 .62133 m .50354 .62786 L .51563 .62513 L p
1 g
F P
s
P
p
.002 w
.56834 .61566 m .51563 .62513 L .50354 .62786 L p
1 g
F P
s
P
p
.002 w
.66249 .31847 m .62159 .27508 L .61958 .276 L p
1 g
F P
s
P
p
.002 w
.63996 .56705 m .67365 .52402 L .68047 .50799 L p
1 g
F P
s
P
p
.002 w
.67365 .52402 m .63996 .56705 L .62853 .58032 L p
1 g
F P
s
P
p
.002 w
.36185 .57109 m .40033 .60064 L .40257 .60057 L p
1 g
F P
s
P
p
.002 w
.40257 .60057 m .35972 .56766 L .36185 .57109 L p
1 g
F P
s
P
p
.002 w
.45197 .62133 m .40257 .60057 L .40033 .60064 L p
1 g
F P
s
P
p
.002 w
.33278 .5333 m .36185 .57109 L .35972 .56766 L p
1 g
F P
s
P
p
.002 w
.35972 .56766 m .32732 .52554 L .33278 .5333 L p
1 g
F P
s
P
p
.002 w
.31903 .36269 m .30365 .41158 L .30693 .39528 L p
1 g
F P
s
P
p
.002 w
.30693 .39528 m .32299 .34408 L .31903 .36269 L p
1 g
F P
s
P
p
.002 w
.30583 .42904 m .30858 .47787 L .30664 .46427 L p
1 g
F P
s
P
p
.002 w
.30664 .46427 m .30365 .41158 L .30583 .42904 L p
1 g
F P
s
P
p
.002 w
.68047 .50799 m .69554 .4539 L .69661 .43847 L p
1 g
F P
s
P
p
.002 w
.69554 .4539 m .68047 .50799 L .67365 .52402 L p
1 g
F P
s
P
p
.002 w
.69661 .43847 m .69081 .38117 L .68689 .37013 L p
1 g
F P
s
P
p
.002 w
.66249 .31847 m .68689 .37013 L .69081 .38117 L p
1 g
F P
s
P
p
.002 w
.69081 .38117 m .69661 .43847 L .69554 .4539 L p
1 g
F P
s
P
p
.002 w
.40033 .60064 m .44467 .61928 L .45197 .62133 L p
1 g
F P
s
P
p
.002 w
.50354 .62786 m .45197 .62133 L .44467 .61928 L p
1 g
F P
s
P
p
.002 w
.35772 .30247 m .32299 .34408 L .33167 .32851 L p
1 g
F P
s
P
p
.002 w
.33167 .32851 m .36694 .28613 L .35772 .30247 L p
1 g
F P
s
P
p
.002 w
.56362 .24672 m .50208 .23401 L .51226 .23392 L p
1 g
F P
s
P
p
.002 w
.51226 .23392 m .56925 .24567 L .56362 .24672 L p
1 g
F P
s
P
p
.002 w
.31605 .49068 m .33278 .5333 L .32732 .52554 L p
1 g
F P
s
P
p
.002 w
.32732 .52554 m .30858 .47787 L .31605 .49068 L p
1 g
F P
s
P
p
.002 w
.41831 .25895 m .36694 .28613 L .3795 .27438 L p
1 g
F P
s
P
p
.002 w
.3795 .27438 m .43017 .24746 L .41831 .25895 L p
1 g
F P
s
P
p
.002 w
.4914 .23974 m .43017 .24746 L .4435 .24147 L p
1 g
F P
s
P
p
.002 w
.4435 .24147 m .50208 .23401 L .4914 .23974 L p
1 g
F P
s
P
p
.002 w
.50354 .62786 m .55245 .61909 L .56834 .61566 L p
1 g
F P
s
P
p
.002 w
.56834 .61566 m .61304 .58984 L .62853 .58032 L p
1 g
F P
s
P
p
.002 w
.61304 .58984 m .56834 .61566 L .55245 .61909 L p
1 g
F P
s
P
p
.002 w
.69081 .38117 m .66446 .32545 L .66249 .31847 L p
1 g
F P
s
P
p
.002 w
.62159 .27508 m .66249 .31847 L .66446 .32545 L p
1 g
F P
s
P
p
.002 w
.66164 .538 m .62853 .58032 L .61304 .58984 L p
1 g
F P
s
P
p
.002 w
.62853 .58032 m .66164 .538 L .67365 .52402 L p
1 g
F P
s
P
p
.002 w
.62023 .27854 m .56362 .24672 L .56925 .24567 L p
1 g
F P
s
P
p
.002 w
.56925 .24567 m .62159 .27508 L .62023 .27854 L p
1 g
F P
s
P
p
.002 w
.44467 .61928 m .49084 .62512 L .50354 .62786 L p
1 g
F P
s
P
p
.002 w
.55245 .61909 m .50354 .62786 L .49084 .62512 L p
1 g
F P
s
P
p
.002 w
.66446 .32545 m .62023 .27854 L .62159 .27508 L p
1 g
F P
s
P
p
.002 w
.32018 .38393 m .30583 .42904 L .30365 .41158 L p
1 g
F P
s
P
p
.002 w
.30365 .41158 m .31903 .36269 L .32018 .38393 L p
1 g
F P
s
P
p
.002 w
.68886 .46927 m .67365 .52402 L .66164 .538 L p
1 g
F P
s
P
p
.002 w
.67365 .52402 m .68886 .46927 L .69554 .4539 L p
1 g
F P
s
P
p
.002 w
.31371 .44719 m .31605 .49068 L .30858 .47787 L p
1 g
F P
s
P
p
.002 w
.30858 .47787 m .30583 .42904 L .31371 .44719 L p
1 g
F P
s
P
p
.002 w
.36801 .57065 m .40084 .59586 L .40033 .60064 L p
1 g
F P
s
P
p
.002 w
.40033 .60064 m .36185 .57109 L .36801 .57065 L p
1 g
F P
s
P
p
.002 w
.44467 .61928 m .40033 .60064 L .40084 .59586 L p
1 g
F P
s
P
p
.002 w
.34328 .53845 m .36801 .57065 L .36185 .57109 L p
1 g
F P
s
P
p
.002 w
.36185 .57109 m .33278 .5333 L .34328 .53845 L p
1 g
F P
s
P
p
.002 w
.69554 .4539 m .68944 .39409 L .69081 .38117 L p
1 g
F P
s
P
p
.002 w
.66446 .32545 m .69081 .38117 L .68944 .39409 L p
1 g
F P
s
P
p
.002 w
.35232 .32312 m .31903 .36269 L .32299 .34408 L p
1 g
F P
s
P
p
.002 w
.32299 .34408 m .35772 .30247 L .35232 .32312 L p
1 g
F P
s
P
p
.002 w
.68944 .39409 m .69554 .4539 L .68886 .46927 L p
1 g
F P
s
P
p
.002 w
.40084 .59586 m .43864 .61173 L .44467 .61928 L p
1 g
F P
s
P
p
.002 w
.49084 .62512 m .44467 .61928 L .43864 .61173 L p
1 g
F P
s
P
p
.002 w
.5559 .25314 m .4914 .23974 L .50208 .23401 L p
1 g
F P
s
P
p
.002 w
.50208 .23401 m .56362 .24672 L .5559 .25314 L p
1 g
F P
s
P
p
.002 w
.4084 .2759 m .35772 .30247 L .36694 .28613 L p
1 g
F P
s
P
p
.002 w
.36694 .28613 m .41831 .25895 L .4084 .2759 L p
1 g
F P
s
P
p
.002 w
.32915 .50224 m .34328 .53845 L .33278 .5333 L p
1 g
F P
s
P
p
.002 w
.33278 .5333 m .31605 .49068 L .32915 .50224 L p
1 g
F P
s
P
p
.002 w
.48054 .25128 m .41831 .25895 L .43017 .24746 L p
1 g
F P
s
P
p
.002 w
.43017 .24746 m .4914 .23974 L .48054 .25128 L p
1 g
F P
s
P
p
.002 w
.49084 .62512 m .53444 .61722 L .55245 .61909 L p
1 g
F P
s
P
p
.002 w
.59373 .59513 m .55245 .61909 L .53444 .61722 L p
1 g
F P
s
P
p
.002 w
.55245 .61909 m .59373 .59513 L .61304 .58984 L p
1 g
F P
s
P
p
.002 w
.64452 .54938 m .61304 .58984 L .59373 .59513 L p
1 g
F P
s
P
p
.002 w
.61304 .58984 m .64452 .54938 L .66164 .538 L p
1 g
F P
s
P
p
.002 w
.68944 .39409 m .66177 .33576 L .66446 .32545 L p
1 g
F P
s
P
p
.002 w
.62023 .27854 m .66446 .32545 L .66177 .33576 L p
1 g
F P
s
P
p
.002 w
.43864 .61173 m .47789 .61664 L .49084 .62512 L p
1 g
F P
s
P
p
.002 w
.53444 .61722 m .49084 .62512 L .47789 .61664 L p
1 g
F P
s
P
p
.002 w
.61531 .28657 m .5559 .25314 L .56362 .24672 L p
1 g
F P
s
P
p
.002 w
.56362 .24672 m .62023 .27854 L .61531 .28657 L p
1 g
F P
s
P
p
.002 w
.32666 .40725 m .31371 .44719 L .30583 .42904 L p
1 g
F P
s
P
p
.002 w
.30583 .42904 m .32018 .38393 L .32666 .40725 L p
1 g
F P
s
P
p
.002 w
.67643 .48408 m .66164 .538 L .64452 .54938 L p
1 g
F P
s
P
p
.002 w
.66164 .538 m .67643 .48408 L .68886 .46927 L p
1 g
F P
s
P
p
.002 w
.66177 .33576 m .61531 .28657 L .62023 .27854 L p
1 g
F P
s
P
p
.002 w
.32734 .46549 m .32915 .50224 L .31605 .49068 L p
1 g
F P
s
P
p
.002 w
.31605 .49068 m .31371 .44719 L .32734 .46549 L p
1 g
F P
s
P
p
.002 w
.35111 .34764 m .32018 .38393 L .31903 .36269 L p
1 g
F P
s
P
p
.002 w
.31903 .36269 m .35232 .32312 L .35111 .34764 L p
1 g
F P
s
P
p
.002 w
.68886 .46927 m .68251 .40858 L .68944 .39409 L p
1 g
F P
s
P
p
.002 w
.66177 .33576 m .68944 .39409 L .68251 .40858 L p
1 g
F P
s
P
p
.002 w
.37829 .5661 m .40426 .58605 L .40084 .59586 L p
1 g
F P
s
P
p
.002 w
.40084 .59586 m .36801 .57065 L .37829 .5661 L p
1 g
F P
s
P
p
.002 w
.43864 .61173 m .40084 .59586 L .40426 .58605 L p
1 g
F P
s
P
p
.002 w
.68251 .40858 m .68886 .46927 L .67643 .48408 L p
1 g
F P
s
P
p
.002 w
.35879 .54064 m .37829 .5661 L .36801 .57065 L p
1 g
F P
s
P
p
.002 w
.36801 .57065 m .34328 .53845 L .35879 .54064 L p
1 g
F P
s
P
p
.002 w
.40087 .29804 m .35232 .32312 L .35772 .30247 L p
1 g
F P
s
P
p
.002 w
.35772 .30247 m .4084 .2759 L .40087 .29804 L p
1 g
F P
s
P
p
.002 w
.40426 .58605 m .43416 .59857 L .43864 .61173 L p
1 g
F P
s
P
p
.002 w
.47789 .61664 m .43864 .61173 L .43416 .59857 L p
1 g
F P
s
P
p
.002 w
.5462 .26507 m .48054 .25128 L .4914 .23974 L p
1 g
F P
s
P
p
.002 w
.4914 .23974 m .5559 .25314 L .5462 .26507 L p
1 g
F P
s
P
p
.002 w
.34778 .5121 m .35879 .54064 L .34328 .53845 L p
1 g
F P
s
P
p
.002 w
.34328 .53845 m .32915 .50224 L .34778 .5121 L p
1 g
F P
s
P
p
.002 w
.46985 .26859 m .4084 .2759 L .41831 .25895 L p
1 g
F P
s
P
p
.002 w
.41831 .25895 m .48054 .25128 L .46985 .26859 L p
1 g
F P
s
P
p
.002 w
.47789 .61664 m .51477 .60983 L .53444 .61722 L p
1 g
F P
s
P
p
.002 w
.571 .59579 m .53444 .61722 L .51477 .60983 L p
1 g
F P
s
P
p
.002 w
.53444 .61722 m .571 .59579 L .59373 .59513 L p
1 g
F P
s
P
p
.002 w
.62257 .55765 m .59373 .59513 L .571 .59579 L p
1 g
F P
s
P
p
.002 w
.59373 .59513 m .62257 .55765 L .64452 .54938 L p
1 g
F P
s
P
p
.002 w
.68251 .40858 m .65419 .34929 L .66177 .33576 L p
1 g
F P
s
P
p
.002 w
.61531 .28657 m .66177 .33576 L .65419 .34929 L p
1 g
F P
s
P
p
.002 w
.43416 .59857 m .4651 .60235 L .47789 .61664 L p
1 g
F P
s
P
p
.002 w
.51477 .60983 m .47789 .61664 L .4651 .60235 L p
1 g
F P
s
P
p
.002 w
.65835 .49784 m .64452 .54938 L .62257 .55765 L p
1 g
F P
s
P
p
.002 w
.64452 .54938 m .65835 .49784 L .67643 .48408 L p
1 g
F P
s
P
p
.002 w
.33851 .43196 m .32734 .46549 L .31371 .44719 L p
1 g
F P
s
P
p
.002 w
.31371 .44719 m .32666 .40725 L .33851 .43196 L p
1 g
F P
s
P
p
.002 w
.60677 .29919 m .5462 .26507 L .5559 .25314 L p
1 g
F P
s
P
p
.002 w
.5559 .25314 m .61531 .28657 L .60677 .29919 L p
1 g
F P
s
P
p
.002 w
.35433 .37536 m .32666 .40725 L .32018 .38393 L p
1 g
F P
s
P
p
.002 w
.32018 .38393 m .35111 .34764 L .35433 .37536 L p
1 g
F P
s
P
p
.002 w
.34655 .48331 m .34778 .5121 L .32915 .50224 L p
1 g
F P
s
P
p
.002 w
.32915 .50224 m .32734 .46549 L .34655 .48331 L p
1 g
F P
s
P
p
.002 w
.65419 .34929 m .60677 .29919 L .61531 .28657 L p
1 g
F P
s
P
p
.002 w
.66991 .42427 m .67643 .48408 L .65835 .49784 L p
1 g
F P
s
P
p
.002 w
.67643 .48408 m .66991 .42427 L .68251 .40858 L p
1 g
F P
s
P
p
.002 w
.65419 .34929 m .68251 .40858 L .66991 .42427 L p
1 g
F P
s
P
p
.002 w
.3926 .55734 m .41066 .57122 L .40426 .58605 L p
1 g
F P
s
P
p
.002 w
.40426 .58605 m .37829 .5661 L .3926 .55734 L p
1 g
F P
s
P
p
.002 w
.43416 .59857 m .40426 .58605 L .41066 .57122 L p
1 g
F P
s
P
p
.002 w
.3961 .32486 m .35111 .34764 L .35232 .32312 L p
1 g
F P
s
P
p
.002 w
.35232 .32312 m .40087 .29804 L .3961 .32486 L p
1 g
F P
s
P
p
.002 w
.37911 .53963 m .3926 .55734 L .37829 .5661 L p
1 g
F P
s
P
p
.002 w
.37829 .5661 m .35879 .54064 L .37911 .53963 L p
1 g
F P
s
P
p
.002 w
.41066 .57122 m .43145 .57989 L .43416 .59857 L p
1 g
F P
s
P
p
.002 w
.4651 .60235 m .43416 .59857 L .43145 .57989 L p
1 g
F P
s
P
p
.002 w
.53475 .28243 m .46985 .26859 L .48054 .25128 L p
1 g
F P
s
P
p
.002 w
.48054 .25128 m .5462 .26507 L .53475 .28243 L p
1 g
F P
s
P
p
.002 w
.4651 .60235 m .494 .59685 L .51477 .60983 L p
1 g
F P
s
P
p
.002 w
.54545 .59156 m .51477 .60983 L .494 .59685 L p
1 g
F P
s
P
p
.002 w
.51477 .60983 m .54545 .59156 L .571 .59579 L p
1 g
F P
s
P
p
.002 w
.59628 .56239 m .571 .59579 L .54545 .59156 L p
1 g
F P
s
P
p
.002 w
.571 .59579 m .59628 .56239 L .62257 .55765 L p
1 g
F P
s
P
p
.002 w
.45971 .29139 m .40087 .29804 L .4084 .2759 L p
1 g
F P
s
P
p
.002 w
.4084 .2759 m .46985 .26859 L .45971 .29139 L p
1 g
F P
s
P
p
.002 w
.37159 .51985 m .37911 .53963 L .35879 .54064 L p
1 g
F P
s
P
p
.002 w
.35879 .54064 m .34778 .5121 L .37159 .51985 L p
1 g
F P
s
P
p
.002 w
.63496 .51002 m .62257 .55765 L .59628 .56239 L p
1 g
F P
s
P
p
.002 w
.62257 .55765 m .63496 .51002 L .65835 .49784 L p
1 g
F P
s
P
p
.002 w
.35553 .45726 m .34655 .48331 L .32734 .46549 L p
1 g
F P
s
P
p
.002 w
.32734 .46549 m .33851 .43196 L .35553 .45726 L p
1 g
F P
s
P
p
.002 w
.43145 .57989 m .4529 .58242 L .4651 .60235 L p
1 g
F P
s
P
p
.002 w
.494 .59685 m .4651 .60235 L .4529 .58242 L p
1 g
F P
s
P
p
.002 w
.36204 .40544 m .33851 .43196 L .32666 .40725 L p
1 g
F P
s
P
p
.002 w
.32666 .40725 m .35433 .37536 L .36204 .40544 L p
1 g
F P
s
P
p
.002 w
.66991 .42427 m .64171 .36577 L .65419 .34929 L p
1 g
F P
s
P
p
.002 w
.60677 .29919 m .65419 .34929 L .64171 .36577 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.37091 .50003 m .37159 .51985 L .34778 .5121 L p
1 g
F P
s
P
p
.002 w
.34778 .5121 m .34655 .48331 L .37091 .50003 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.65176 .44068 m .65835 .49784 L .63496 .51002 L p
1 g
F P
s
P
p
.002 w
.65835 .49784 m .65176 .44068 L .66991 .42427 L p
1 g
F P
s
P
p
.002 w
.59469 .31626 m .53475 .28243 L .5462 .26507 L p
1 g
F P
s
P
p
.002 w
.5462 .26507 m .60677 .29919 L .59469 .31626 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.39437 .35559 m .35433 .37536 L .35111 .34764 L p
1 g
F P
s
P
p
.002 w
.35111 .34764 m .3961 .32486 L .39437 .35559 L p
1 g
F P
s
P
p
.002 w
.64171 .36577 m .66991 .42427 L .65176 .44068 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.64171 .36577 m .59469 .31626 L .60677 .29919 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.494 .59685 m .51783 .58237 L .54545 .59156 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53163 .57424 L p
1 g
F P
s
P
p
.56641 .56328 m .51855 .58261 L .52067 .58125 L 1 g
F
P
p
.54854 .56129 m .53163 .57424 L .54177 .56774 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51783 .58237 m .52077 .5783 L p
.56641 .56328 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58078 L p
1 g
F P
s
P
p
.51783 .58237 m .48175 .58624 L .50732 .58146 L 1 g
F
P
p
.53128 .57265 m .51095 .58078 L .51357 .58029 L 1 g
F
P
p
.002 w
.52077 .5783 m .51783 .58237 L .51357 .58029 L p
1 g
F P
s
P
p
.51623 .57956 m .51357 .58029 L .51535 .57996 L 1 g
F
P
p
.53128 .57265 m .51357 .58029 L .51623 .57956 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4728 .57849 m .47486 .5772 L p
.48251 .57892 L 1 g
F P
s
P
p
.002 w
.48908 .58039 m .48921 .57862 L p
.47652 .57758 L 1 g
F P
s
P
p
.002 w
.51095 .58078 m .51079 .57862 L p
.50089 .5806 L 1 g
F P
s
P
p
.50732 .58146 m .49638 .58052 L .51095 .58078 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58039 L p
1 g
F P
s
P
p
.002 w
.48175 .58624 m .47469 .58013 L p
.50732 .58146 L 1 g
F P
s
P
p
.50732 .58146 m .47469 .58013 L .49638 .58052 L 1 g
F
P
p
.002 w
.48908 .58039 m .48889 .583 L p
.50089 .5806 L 1 g
F P
s
P
p
.51079 .57862 m .48908 .58039 L .50089 .5806 L 1 g
F
P
p
.002 w
.47469 .58013 m .4728 .57849 L p
.49638 .58052 L 1 g
F P
s
P
p
.51095 .58078 m .4728 .57849 L .51357 .58029 L 1 g
F
P
p
.49638 .58052 m .4728 .57849 L .51095 .58078 L 1 g
F
P
p
.002 w
.51357 .58029 m .51783 .58237 L p
.50732 .58146 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58078 L p
1 g
F P
s
P
p
.50089 .5806 m .48889 .583 L .51095 .58078 L 1 g
F
P
p
.002 w
.4728 .57849 m .4529 .58242 L .44563 .56604 L p
1 g
F P
s
P
p
.002 w
.44563 .56604 m .44175 .55727 L p
.45149 .56393 L 1 g
F P
s
P
p
.45751 .57065 m .44563 .56604 L .45149 .56393 L 1 g
F
P
p
.002 w
.45078 .56313 m .45146 .56129 L p
.44314 .55406 L 1 g
F P
s
P
p
.002 w
.44495 .55661 m .44175 .55727 L .43864 .5477 L p
1 g
F P
s
P
p
.44314 .55406 m .44101 .55221 L .44495 .55661 L 1 g
F
P
p
.44314 .55406 m .44495 .55661 L .45078 .56313 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.47652 .57758 m .475 .57745 L .48908 .58039 L 1 g
F
P
p
.4728 .57849 m .46638 .5741 L .46824 .57483 L 1 g
F
P
p
.002 w
.4702 .57559 m .47143 .57696 L p
.46824 .57483 L 1 g
F P
s
P
p
.002 w
.47143 .57696 m .4728 .57849 L p
.46824 .57483 L 1 g
F P
s
P
p
.002 w
.46824 .57483 m .46872 .57265 L p
.45949 .56896 L 1 g
F P
s
P
p
.4728 .57849 m .44563 .56604 L .46638 .5741 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46823 .5749 L p
1 g
F P
s
P
p
.002 w
.47486 .5772 m .4728 .57849 L .4702 .57559 L p
1 g
F P
s
P
p
.002 w
.46823 .5749 m .4678 .57686 L p
.47574 .57751 L 1 g
F P
s
P
p
.48921 .57862 m .46823 .5749 L .47574 .57751 L 1 g
F
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48905 .56836 m .47486 .5772 L p
.45191 .55517 L 1 g
F P
s
P
p
.46638 .5741 m .45149 .56393 L .4584 .56823 L 1 g
F
P
p
.46872 .57265 m .45078 .56313 L .45949 .56896 L 1 g
F
P
p
.46824 .57483 m .4584 .56823 L .4702 .57559 L 1 g
F
P
p
.46638 .5741 m .4584 .56823 L .46824 .57483 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56313 L p
1 g
F P
s
P
p
.002 w
.45191 .55517 m .4702 .57559 L p
.45149 .56393 L 1 g
F P
s
P
p
.002 w
.44175 .55727 m .44495 .55661 L p
.45149 .56393 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43837 .54732 L p
1 g
F P
s
P
p
.002 w
.43864 .5477 m .44175 .55727 L p
.44152 .55682 L 1 g
F P
s
P
p
.44152 .55682 m .43162 .53767 L .43837 .54732 L 1 g
F
P
p
.44152 .55682 m .43837 .54732 L .43864 .5477 L 1 g
F
P
p
.002 w
.44175 .55727 m .43073 .55603 L .43162 .53767 L p
1 g
F P
s
P
p
.002 w
.43837 .54732 m .43925 .54566 L p
.43511 .53748 L 1 g
F P
s
P
p
.45146 .56129 m .43837 .54732 L .442 .55251 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43231 .52901 L p
1 g
F P
s
P
p
.43925 .54566 m .43231 .52901 L .43511 .53748 L 1 g
F
P
p
.002 w
.43244 .52648 m .43211 .52759 L p
.4338 .50963 L 1 g
F P
s
P
p
.4351 .49577 m .43393 .50936 L .4338 .50963 L 1 g
F
P
p
.43393 .50936 m .43244 .52648 L .4338 .50963 L 1 g
F
P
p
.002 w
.43211 .52759 m .42995 .49447 L .4351 .49577 L p
1 g
F P
s
P
p
.002 w
.43393 .50936 m .43485 .50826 L p
.43901 .49853 L 1 g
F P
s
P
p
.43346 .52734 m .43315 .51835 L .43303 .51968 L 1 g
F
P
p
.002 w
.43231 .52901 m .43346 .52734 L p
.43303 .5196 L 1 g
F P
s
P
p
.43303 .5196 m .43301 .51933 L .43279 .52236 L 1 g
F
P
p
.43303 .5196 m .43279 .52236 L .43231 .52901 L 1 g
F
P
p
.43301 .51933 m .43252 .52551 L .43231 .52901 L 1 g
F
P
p
.43295 .51819 m .4325 .52532 L .43231 .52901 L 1 g
F
P
p
.4329 .5173 m .43243 .52611 L .43231 .52901 L 1 g
F
P
p
.002 w
.43238 .52726 m .43211 .52759 L .43244 .52648 L p
1 g
F P
s
P
p
.43284 .51621 m .43238 .52685 L .43231 .52901 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.44124 .49731 m .45166 .50332 L .43238 .52726 L p
1 g
F P
s
P
p
.002 w
.43244 .52648 m .44124 .49731 L p
.43238 .52726 L 1 g
F P
s
P
p
.43277 .51504 m .43235 .52757 L .43231 .52901 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45166 .50332 m .46005 .51183 L .43236 .52745 L p
1 g
F P
s
P
p
.002 w
.43236 .52745 m .43211 .52759 L .43238 .52726 L p
1 g
F P
s
P
p
.002 w
.43238 .52726 m .45166 .50332 L p
.43236 .52745 L 1 g
F P
s
P
p
.43301 .51933 m .43295 .51819 L .43252 .52551 L 1 g
F
P
p
.43295 .51819 m .4329 .5173 L .4325 .52532 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46547 .52187 m .46733 .53232 L .43235 .52763 L p
1 g
F P
s
P
p
.002 w
.43235 .52763 m .43211 .52759 L .43235 .52755 L p
1 g
F P
s
P
p
.002 w
.43235 .52755 m .46547 .52187 L p
.43235 .52763 L 1 g
F P
s
P
p
.43271 .514 m .43233 .52827 L .43231 .52901 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.46733 .53232 m .46546 .54201 L .43235 .5277 L p
1 g
F P
s
P
p
.002 w
.43235 .5277 m .43211 .52759 L .43235 .52763 L p
1 g
F P
s
P
p
.002 w
.43235 .52763 m .46733 .53232 L p
.43235 .5277 L 1 g
F P
s
P
p
.4329 .5173 m .43284 .51621 L .43243 .52611 L 1 g
F
P
p
.43284 .51621 m .43277 .51504 L .43238 .52685 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46546 .54201 m .46012 .5499 L .43234 .52778 L p
1 g
F P
s
P
p
.002 w
.43234 .52778 m .43211 .52759 L .43235 .5277 L p
1 g
F P
s
P
p
.002 w
.43235 .5277 m .46546 .54201 L p
.43234 .52778 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.46012 .5499 m .45191 .55517 L .43234 .52791 L p
1 g
F P
s
P
p
.002 w
.43234 .52791 m .43211 .52759 L .43234 .52778 L p
1 g
F P
s
P
p
.002 w
.43234 .52778 m .46012 .5499 L p
.43234 .52791 L 1 g
F P
s
P
p
.43277 .51504 m .43271 .514 L .43235 .52757 L 1 g
F
P
p
.45146 .56129 m .43773 .54854 L .44101 .55221 L 1 g
F
P
p
.002 w
.43864 .5477 m .43233 .52827 L p
.44495 .55661 L 1 g
F P
s
P
p
.002 w
.43233 .52827 m .43211 .52759 L p
.43233 .5281 L 1 g
F P
s
P
p
.44495 .55661 m .43233 .52827 L .43233 .5281 L 1 g
F
P
p
.002 w
.43211 .52759 m .43234 .52791 L p
.43233 .5281 L 1 g
F P
s
P
p
.002 w
.43235 .52755 m .43211 .52759 L .43236 .52745 L p
1 g
F P
s
P
p
.002 w
.43211 .52759 m .43233 .52827 L p
.43233 .52829 L 1 g
F P
s
P
p
.002 w
.43162 .53767 m .43207 .5283 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.43207 .5283 m .43211 .52759 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.42 .55158 m .4107 .54442 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.43073 .55603 m .42 .55158 L .43195 .52791 L p
1 g
F P
s
P
p
.002 w
.43195 .52791 m .43211 .52759 L .43207 .5283 L p
1 g
F P
s
P
p
.002 w
.43207 .5283 m .43073 .55603 L p
.43195 .52791 L 1 g
F P
s
P
p
.002 w
.43231 .52901 m .43231 .52902 L p
.43511 .53748 L 1 g
F P
s
P
p
.002 w
.43231 .52902 m .43146 .53025 L p
.43497 .53719 L 1 g
F P
s
P
p
.43511 .53748 m .43231 .52902 L .43497 .53719 L 1 g
F
P
p
.002 w
.4107 .54442 m .40378 .53528 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.40378 .53528 m .39998 .52511 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.39998 .52511 m .39974 .51499 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.39974 .51499 m .40312 .50599 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.40312 .50599 m .40979 .4991 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.41907 .4951 m .42995 .49447 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.40979 .4991 m .41907 .4951 L .43211 .52759 L closepath p
1 g
F P
s
P
p
.002 w
.43268 .51337 m .43146 .53025 L .43231 .52902 L p
1 g
F P
s
P
p
.002 w
.43231 .52902 m .43231 .52901 L p
.43233 .52827 L 1 g
F P
s
P
p
.43233 .52827 m .43268 .51337 L .43231 .52902 L 1 g
F
P
p
.43271 .514 m .43268 .51337 L .43233 .52827 L 1 g
F
P
p
.002 w
.45191 .55517 m .44495 .55661 L p
.43233 .5281 L 1 g
F P
s
P
p
.002 w
.43234 .52791 m .45191 .55517 L p
.43233 .5281 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44249 .49145 L p
1 g
F P
s
P
p
.43485 .50826 m .44249 .49145 L .44095 .49455 L 1 g
F
P
p
.002 w
.42994 .45887 m .45237 .46439 L .44476 .48691 L p
1 g
F P
s
P
p
.42994 .45887 m .44476 .48691 L .44249 .49145 L 1 g
F
P
p
.44018 .4937 m .44249 .49145 L .44062 .49521 L 1 g
F
P
p
.42994 .45887 m .44249 .49145 L .44018 .4937 L 1 g
F
P
p
.002 w
.42995 .49447 m .42994 .45887 L p
.44062 .49521 L 1 g
F P
s
P
p
.002 w
.43976 .49694 m .42995 .49447 L p
.44062 .49521 L 1 g
F P
s
P
p
.43485 .50826 m .44218 .49179 L .43901 .49853 L 1 g
F
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44249 .49145 m .44339 .4905 L p
.45013 .48404 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.45205 .48218 m .45166 .50332 L .44357 .49041 L 1 g
F
P
p
.45013 .48404 m .45099 .48322 L .44357 .49041 L 1 g
F
P
p
.45013 .48404 m .44357 .49041 L .44249 .49145 L 1 g
F
P
p
.002 w
.45166 .50332 m .44124 .49731 L .44357 .49041 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44062 .49521 m .44249 .49145 L .44124 .49731 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45767 .47673 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45767 .47673 m .47311 .47631 L .45205 .48218 L 1 g
F
P
p
.002 w
.45767 .47673 m .45826 .47608 L p
.46907 .47134 L 1 g
F P
s
P
p
.002 w
.47311 .47631 m .46658 .47256 L p
.472 .46991 L 1 g
F P
s
P
p
.46907 .47134 m .47086 .47055 L .46658 .47256 L 1 g
F
P
p
.46907 .47134 m .46658 .47256 L .45767 .47673 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.46512 .43005 m .49565 .44753 L .48192 .46506 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.472 .46991 m .47754 .4672 L .47311 .47631 L 1 g
F
P
p
.002 w
.48057 .46678 m .47311 .47631 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.48973 .49325 m .47311 .47631 L .48057 .46678 L p
1 g
F P
s
P
p
.49341 .46482 m .48973 .49325 L .48057 .46678 L 1 g
F
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.49178 .46525 L 1 g
F P
s
P
p
.002 w
.52002 .47253 m .48973 .49325 L p
.49341 .46482 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .49176 .46508 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51841 .41813 m .54974 .45045 L .52642 .46778 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54215 .47652 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56583 .50907 L p
1 g
F P
s
P
p
.56924 .48853 m .57464 .52769 L .56583 .50907 L 1 g
F
P
p
.56463 .49545 m .56583 .50907 L .56157 .50005 L 1 g
F
P
p
.56924 .48853 m .56583 .50907 L .56463 .49545 L 1 g
F
P
p
.002 w
.56583 .50907 m .56515 .50826 L p
.56657 .51746 L 1 g
F P
s
P
p
.55661 .4905 m .56583 .50907 L .56123 .49934 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56134 .54678 L p
1 g
F P
s
P
p
.57484 .52767 m .57334 .53042 L .56535 .53519 L 1 g
F
P
p
.57334 .53042 m .55598 .56227 L .56134 .54678 L 1 g
F
P
p
.57334 .53042 m .56134 .54678 L .56535 .53519 L 1 g
F
P
p
.002 w
.56134 .54678 m .56075 .54566 L p
.55647 .55342 L 1 g
F P
s
P
p
.56654 .52734 m .56134 .54678 L .56483 .53671 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .563 L p
1 g
F P
s
P
p
.56075 .54566 m .54918 .563 L .54998 .56215 L 1 g
F
P
p
.56205 .56286 m .54236 .57022 L .54918 .563 L 1 g
F
P
p
.002 w
.55037 .56173 m .55106 .5618 L p
.54918 .563 L 1 g
F P
s
P
p
.002 w
.55106 .5618 m .56205 .56286 L p
.54918 .563 L 1 g
F P
s
P
p
.002 w
.54918 .563 m .54854 .56129 L p
.54217 .56749 L 1 g
F P
s
P
p
.56075 .54566 m .54998 .56215 L .55647 .55342 L 1 g
F
P
p
.54998 .56215 m .54927 .56324 L .55037 .56173 L 1 g
F
P
p
.54998 .56215 m .55037 .56173 L .55647 .55342 L 1 g
F
P
p
.54236 .57022 m .53163 .57424 L .54918 .563 L 1 g
F
P
p
.002 w
.56205 .56286 m .56641 .56328 L p
.52077 .5783 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53322 .57619 L p
.54217 .56749 L 1 g
F P
s
P
p
.54854 .56129 m .54177 .56774 L .54217 .56749 L 1 g
F
P
p
.54177 .56774 m .5322 .57686 L .54217 .56749 L 1 g
F
P
p
.53128 .57265 m .51535 .57996 L .51892 .57899 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.54918 .563 m .52077 .5783 L .55037 .56173 L 1 g
F
P
p
.53163 .57424 m .52077 .5783 L .54918 .563 L 1 g
F
P
p
.002 w
.54927 .56324 m .54918 .563 L p
.53322 .57619 L 1 g
F P
s
P
p
.54217 .56749 m .53322 .57619 L .54918 .563 L 1 g
F
P
p
.002 w
.52077 .5783 m .53387 .56014 L .55037 .56173 L p
1 g
F P
s
P
p
.002 w
.54918 .563 m .54927 .56324 L p
.54998 .56215 L 1 g
F P
s
P
p
.56134 .54678 m .55812 .5561 L .554 .55678 L 1 g
F
P
p
.002 w
.55598 .56227 m .55106 .5618 L p
.55812 .5561 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55106 .5618 m .53387 .56014 L p
.55812 .5561 L 1 g
F P
s
P
p
.002 w
.54927 .56324 m .54998 .56518 L p
.55647 .55342 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56756 .52882 L p
1 g
F P
s
P
p
.56515 .50826 m .56756 .52882 L .56756 .52871 L 1 g
F
P
p
.56515 .50826 m .56757 .52884 L .56657 .51746 L 1 g
F
P
p
.002 w
.56257 .5491 m .56285 .54823 L p
.56494 .5364 L 1 g
F P
s
P
p
.56654 .52734 m .56483 .53671 L .56494 .5364 L 1 g
F
P
p
.56483 .53671 m .56257 .5491 L .56494 .5364 L 1 g
F
P
p
.56764 .53337 m .56535 .53519 L .56756 .52882 L 1 g
F
P
p
.57484 .52767 m .56764 .53337 L .56756 .52882 L 1 g
F
P
p
.002 w
.56757 .52884 m .56756 .52882 L p
.56285 .54823 L 1 g
F P
s
P
p
.002 w
.56756 .52882 m .56654 .52734 L p
.56494 .5364 L 1 g
F P
s
P
p
.56494 .5364 m .56285 .54823 L .56756 .52882 L 1 g
F
P
p
.002 w
.56755 .52865 m .56762 .52864 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56762 .52864 m .57484 .52767 L p
.56756 .52882 L 1 g
F P
s
P
p
.56756 .52882 m .53387 .56014 L .56755 .52865 L 1 g
F
P
p
.56535 .53519 m .53387 .56014 L .56756 .52882 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53387 .56014 m .54007 .53235 L .56755 .52865 L p
1 g
F P
s
P
p
.002 w
.56756 .52882 m .56757 .52884 L p
.56756 .52871 L 1 g
F P
s
P
p
.56583 .50907 m .57016 .51823 L .56678 .51981 L 1 g
F
P
p
.002 w
.57464 .52769 m .56762 .52864 L p
.57016 .51823 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56762 .52864 m .54007 .53235 L p
.57016 .51823 L 1 g
F P
s
P
p
.002 w
.56757 .52884 m .56854 .53025 L p
.56657 .51746 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56157 .50005 m .56583 .50907 L .54007 .53235 L 1 g
F
P
p
.56583 .50907 m .56678 .51981 L .54007 .53235 L 1 g
F
P
p
.002 w
.56285 .54823 m .56854 .53025 L .56757 .52884 L p
1 g
F P
s
P
p
.56535 .53519 m .56134 .54678 L .53387 .56014 L 1 g
F
P
p
.56134 .54678 m .554 .55678 L .53387 .56014 L 1 g
F
P
p
.002 w
.53322 .57619 m .54998 .56518 L .54927 .56324 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56134 .54678 L p
1 g
F P
s
P
p
.55647 .55342 m .54998 .56518 L .56134 .54678 L 1 g
F
P
p
.002 w
.56134 .54678 m .56257 .5491 L p
.56483 .53671 L 1 g
F P
s
P
p
.002 w
.57484 .52767 m .56641 .56328 L .55598 .56227 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56583 .50907 L p
1 g
F P
s
P
p
.56657 .51746 m .56854 .53025 L .56583 .50907 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.55661 .4905 m .56123 .49934 L .55819 .49292 L 1 g
F
P
p
.002 w
.5574 .49134 m .55661 .4905 L p
.55819 .49292 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5574 .49134 L p
1 g
F P
s
P
p
.5424 .47677 m .55 .48415 L .53537 .50198 L 1 g
F
P
p
.002 w
.56843 .48886 m .55878 .49268 L p
.55234 .48131 L 1 g
F P
s
P
p
.002 w
.55878 .49268 m .55819 .49292 L p
.5574 .49134 L 1 g
F P
s
P
p
.55234 .48131 m .55878 .49268 L .5574 .49134 L 1 g
F
P
p
.54174 .47608 m .5574 .49134 L .54791 .48212 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55819 .49292 m .53537 .50198 L p
.55234 .48131 L 1 g
F P
s
P
p
.002 w
.5575 .49144 m .5574 .49134 L p
.55819 .49292 L 1 g
F P
s
P
p
.002 w
.55819 .49292 m .56924 .48853 L p
.56157 .50005 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .5575 .49144 L p
1 g
F P
s
P
p
.56123 .49934 m .56713 .51061 L .5575 .49144 L 1 g
F
P
p
.002 w
.54215 .47652 m .54174 .47608 L p
.54791 .48212 L 1 g
F P
s
P
p
.52214 .46667 m .54215 .47652 L .53175 .47165 L 1 g
F
P
p
.002 w
.53537 .50198 m .52002 .47253 L .52529 .46861 L p
1 g
F P
s
P
p
.52214 .46667 m .53175 .47165 L .52529 .46861 L 1 g
F
P
p
.002 w
.52529 .46861 m .52002 .47253 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52247 .46722 L p
.52529 .46861 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.52529 .46861 L 1 g
F P
s
P
p
.51985 .46685 m .52247 .46722 L .52002 .47253 L 1 g
F
P
p
.002 w
.52642 .46778 m .52529 .46861 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.52529 .46861 m .54974 .45045 L p
.54243 .47666 L 1 g
F P
s
P
p
.54243 .47666 m .53537 .50198 L .52529 .46861 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52253 .46732 L p
1 g
F P
s
P
p
.53175 .47165 m .54302 .47747 L .52253 .46732 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54215 .47652 L p
1 g
F P
s
P
p
.54791 .48212 m .55834 .49233 L .54215 .47652 L 1 g
F
P
p
.002 w
.5574 .49134 m .55834 .49233 L p
.54791 .48212 L 1 g
F P
s
P
p
.54243 .47666 m .55234 .48131 L .55 .48415 L 1 g
F
P
p
.54243 .47666 m .55 .48415 L .5424 .47677 L 1 g
F
P
p
.002 w
.54007 .53235 m .53537 .50198 L .55819 .49292 L p
1 g
F P
s
P
p
.56157 .50005 m .54007 .53235 L .55819 .49292 L 1 g
F
P
p
.002 w
.56583 .50907 m .56713 .51061 L p
.56123 .49934 L 1 g
F P
s
P
p
.002 w
.56924 .48853 m .57484 .52767 L .57464 .52769 L p
1 g
F P
s
P
p
.002 w
.54215 .47652 m .54302 .47747 L p
.53175 .47165 L 1 g
F P
s
P
p
.002 w
.54974 .45045 m .56924 .48853 L .56843 .48886 L p
1 g
F P
s
P
p
.54974 .45045 m .56843 .48886 L .54243 .47666 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.5 .4634 m .52247 .46722 L .51821 .46662 L 1 g
F
P
p
.51841 .41813 m .52642 .46778 L .51985 .46685 L 1 g
F
P
p
.002 w
.49565 .44753 m .51841 .41813 L p
.51985 .46685 L 1 g
F P
s
P
p
.002 w
.52002 .47253 m .51364 .46598 L p
.51985 .46685 L 1 g
F P
s
P
p
.5 .4634 m .52258 .4674 L .51237 .46578 L 1 g
F
P
p
.002 w
.51364 .46598 m .49565 .44753 L p
.51985 .46685 L 1 g
F P
s
P
p
.5 .46382 m .52002 .47253 L .49341 .46482 L 1 g
F
P
p
.002 w
.5 .46382 m .5 .4634 L p
.51237 .46578 L 1 g
F P
s
P
p
.002 w
.51004 .46229 m .51364 .46598 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.51364 .46598 m .52002 .47253 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46382 L p
1 g
F P
s
P
p
.51237 .46578 m .52282 .46778 L .5 .46382 L 1 g
F
P
p
.002 w
.52258 .4674 m .52282 .46778 L p
.51281 .46586 L 1 g
F P
s
P
p
.51237 .46578 m .51364 .46598 L .51281 .46586 L 1 g
F
P
p
.51364 .46598 m .52258 .4674 L .51281 .46586 L 1 g
F
P
p
.002 w
.52247 .46722 m .52258 .4674 L p
.51821 .46662 L 1 g
F P
s
P
p
.002 w
.49565 .44753 m .51004 .46229 L p
.5 .46382 L 1 g
F P
s
P
p
.49367 .46282 m .5 .46382 L .49341 .46482 L 1 g
F
P
p
.49565 .44753 m .5 .46382 L .49367 .46282 L 1 g
F
P
p
.002 w
.5 .46382 m .5 .46413 L p
.49176 .46508 L 1 g
F P
s
P
p
.002 w
.5 .46413 m .5 .46442 L p
.49178 .46525 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46413 L .49178 .46525 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.46512 .43005 m .48192 .46506 L .47754 .4672 L 1 g
F
P
p
.45826 .47608 m .47754 .4672 L .47173 .47004 L 1 g
F
P
p
.47168 .468 m .47754 .4672 L .472 .46991 L 1 g
F
P
p
.46512 .43005 m .47754 .4672 L .47168 .468 L 1 g
F
P
p
.002 w
.48057 .46678 m .49565 .44753 L p
.49341 .46482 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47751 .46725 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47754 .4672 L p
.47923 .46699 L 1 g
F P
s
P
p
.47923 .46699 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.49178 .46525 m .5 .46442 L .47754 .4672 L 1 g
F
P
p
.002 w
.48192 .46506 m .48057 .46678 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47734 .46752 L p
.47173 .47004 L 1 g
F P
s
P
p
.002 w
.47734 .46752 m .47718 .46778 L p
.47086 .47055 L 1 g
F P
s
P
p
.45826 .47608 m .47734 .46752 L .47086 .47055 L 1 g
F
P
p
.002 w
.45237 .46439 m .46368 .47089 L p
.45767 .47673 L 1 g
F P
s
P
p
.44339 .4905 m .45767 .47673 L .45478 .47953 L 1 g
F
P
p
.002 w
.47311 .47631 m .45166 .50332 L p
.45205 .48218 L 1 g
F P
s
P
p
.44339 .4905 m .45751 .4769 L .45099 .48322 L 1 g
F
P
p
.4521 .47933 m .45767 .47673 L .45205 .48218 L 1 g
F
P
p
.45237 .46439 m .45767 .47673 L .4521 .47933 L 1 g
F
P
p
.002 w
.45237 .46439 m .46512 .43005 L p
.472 .46991 L 1 g
F P
s
P
p
.002 w
.46658 .47256 m .45237 .46439 L p
.472 .46991 L 1 g
F P
s
P
p
.002 w
.46368 .47089 m .46658 .47256 L p
.45767 .47673 L 1 g
F P
s
P
p
.002 w
.46658 .47256 m .47311 .47631 L p
.45767 .47673 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45767 .47673 L p
1 g
F P
s
P
p
.47086 .47055 m .47718 .46778 L .45767 .47673 L 1 g
F
P
p
.002 w
.45767 .47673 m .45751 .4769 L p
.45478 .47953 L 1 g
F P
s
P
p
.002 w
.44476 .48691 m .44357 .49041 L p
.44249 .49145 L 1 g
F P
s
P
p
.002 w
.44357 .49041 m .44124 .49731 L p
.44249 .49145 L 1 g
F P
s
P
p
.002 w
.45751 .4769 m .45698 .47747 L p
.45099 .48322 L 1 g
F P
s
P
p
.002 w
.44357 .49041 m .45237 .46439 L p
.45205 .48218 L 1 g
F P
s
P
p
.002 w
.4351 .49577 m .43976 .49694 L p
.43393 .50936 L 1 g
F P
s
P
p
.002 w
.44218 .49179 m .44166 .49233 L p
.43929 .49788 L 1 g
F P
s
P
p
.43976 .49694 m .44218 .49179 L .43929 .49788 L 1 g
F
P
p
.002 w
.44249 .49145 m .44218 .49179 L p
.44095 .49455 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44249 .49145 L p
1 g
F P
s
P
p
.45099 .48322 m .45698 .47747 L .44249 .49145 L 1 g
F
P
p
.43901 .49853 m .43976 .49694 L .43929 .49788 L 1 g
F
P
p
.002 w
.44124 .49731 m .43976 .49694 L p
.44062 .49521 L 1 g
F P
s
P
p
.002 w
.44124 .49731 m .43244 .52648 L p
.43393 .50936 L 1 g
F P
s
P
p
.002 w
.43976 .49694 m .44124 .49731 L p
.43393 .50936 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43393 .50936 L p
1 g
F P
s
P
p
.43901 .49853 m .44166 .49233 L .43393 .50936 L 1 g
F
P
p
.43303 .51968 m .43311 .51721 L .43299 .51887 L 1 g
F
P
p
.43315 .51835 m .43311 .51721 L .43303 .51968 L 1 g
F
P
p
.002 w
.46005 .51183 m .46547 .52187 L .43235 .52755 L p
1 g
F P
s
P
p
.002 w
.43236 .52745 m .46005 .51183 L p
.43235 .52755 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43268 .51337 L p
.43299 .51887 L 1 g
F P
s
P
p
.43311 .51721 m .43287 .51061 L .43299 .51887 L 1 g
F
P
p
.43864 .5477 m .43837 .54732 L .43233 .52829 L 1 g
F
P
p
.002 w
.43233 .52827 m .43864 .5477 L p
.43233 .52829 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43837 .54732 L p
1 g
F P
s
P
p
.43511 .53748 m .43146 .53025 L .43837 .54732 L 1 g
F
P
p
.002 w
.43837 .54732 m .43773 .54854 L p
.442 .55251 L 1 g
F P
s
P
p
.002 w
.44495 .55661 m .45191 .55517 L p
.45149 .56393 L 1 g
F P
s
P
p
.46638 .5741 m .45751 .57065 L .45149 .56393 L 1 g
F
P
p
.002 w
.45078 .56313 m .45002 .56518 L p
.45949 .56896 L 1 g
F P
s
P
p
.002 w
.4702 .57559 m .45191 .55517 L p
.47486 .5772 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46824 .57483 L p
1 g
F P
s
P
p
.45949 .56896 m .45002 .56518 L .46824 .57483 L 1 g
F
P
p
.475 .57745 m .4678 .57686 L .4777 .5785 L 1 g
F
P
p
.475 .57745 m .4777 .5785 L .48908 .58039 L 1 g
F
P
p
.002 w
.43773 .54854 m .43743 .5491 L p
.44101 .55221 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56313 L p
1 g
F P
s
P
p
.44101 .55221 m .43743 .5491 L .45078 .56313 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .4889 .58285 L p
1 g
F P
s
P
p
.002 w
.4889 .58285 m .48908 .58039 L p
.4777 .5785 L 1 g
F P
s
P
p
.4777 .5785 m .4678 .57686 L .4889 .58285 L 1 g
F
P
p
.002 w
.48905 .56836 m .51357 .58029 L p
.48251 .57892 L 1 g
F P
s
P
p
.002 w
.47486 .5772 m .48905 .56836 L p
.48251 .57892 L 1 g
F P
s
P
p
.51535 .57996 m .51104 .58194 L .51731 .57959 L 1 g
F
P
p
.51535 .57996 m .51731 .57959 L .51892 .57899 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53387 .56014 m .52077 .5783 L p
.48905 .56836 L 1 g
F P
s
P
p
.002 w
.51357 .58029 m .48905 .56836 L p
.52077 .5783 L 1 g
F P
s
P
p
.002 w
.51095 .58078 m .51104 .58194 L p
.51535 .57996 L 1 g
F P
s
P
p
.002 w
.51783 .58237 m .494 .59685 L .48175 .58624 L p
1 g
F P
s
P
p
.002 w
.51104 .58194 m .51111 .583 L p
.51892 .57899 L 1 g
F P
s
P
p
.002 w
.53163 .57424 m .5322 .57686 L p
.54177 .56774 L 1 g
F P
s
P
p
.002 w
.56641 .56328 m .54545 .59156 L .51855 .58261 L p
1 g
F P
s
P
p
.002 w
.51855 .58261 m .51783 .58237 L p
.52067 .58125 L 1 g
F P
s
P
p
.002 w
.54545 .59156 m .56641 .56328 L .59628 .56239 L p
1 g
F P
s
P
p
.004 w
.49026 .44444 m
.5 .43051 L
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.4107 .54442 m .42 .55158 L .41066 .57122 L p
1 g
F P
s
P
p
.002 w
.41066 .57122 m .3926 .55734 L .4107 .54442 L p
1 g
F P
s
P
p
.004 w
.39139 .58582 m
.40378 .5681 L
s
P
p
.002 w
.43145 .57989 m .41066 .57122 L .42 .55158 L p
1 g
F P
s
P
p
.002 w
.4529 .58242 m .4728 .57849 L .494 .59685 L p
1 g
F P
s
P
p
.002 w
.40378 .53528 m .4107 .54442 L .3926 .55734 L p
1 g
F P
s
P
p
.002 w
.3926 .55734 m .37911 .53963 L .40378 .53528 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.45051 .31911 m .3961 .32486 L .40087 .29804 L p
1 g
F P
s
P
p
.002 w
.40087 .29804 m .45971 .29139 L .45051 .31911 L p
1 g
F P
s
P
p
.002 w
.52185 .3049 m .45971 .29139 L .46985 .26859 L p
1 g
F P
s
P
p
.002 w
.46985 .26859 m .53475 .28243 L .52185 .3049 L p
1 g
F P
s
P
p
.002 w
.42 .55158 m .43073 .55603 L .43145 .57989 L p
1 g
F P
s
P
p
.002 w
.4529 .58242 m .43145 .57989 L .43073 .55603 L p
1 g
F P
s
P
p
.002 w
.60683 .52011 m .59628 .56239 L .56641 .56328 L p
1 g
F P
s
P
p
.002 w
.59628 .56239 m .60683 .52011 L .63496 .51002 L p
1 g
F P
s
P
p
.002 w
.39998 .52511 m .40378 .53528 L .37911 .53963 L p
1 g
F P
s
P
p
.002 w
.37911 .53963 m .37159 .51985 L .39998 .52511 L p
1 g
F P
s
P
p
.002 w
.3773 .48224 m .37091 .50003 L .34655 .48331 L p
1 g
F P
s
P
p
.002 w
.34655 .48331 m .35553 .45726 L .3773 .48224 L p
1 g
F P
s
P
p
.002 w
.37412 .43685 m .35553 .45726 L .33851 .43196 L p
1 g
F P
s
P
p
.002 w
.33851 .43196 m .36204 .40544 L .37412 .43685 L p
1 g
F P
s
P
p
.002 w
.43073 .55603 m .44175 .55727 L .4529 .58242 L p
1 g
F P
s
P
p
.002 w
.62846 .45727 m .63496 .51002 L .60683 .52011 L p
1 g
F P
s
P
p
.002 w
.63496 .51002 m .62846 .45727 L .65176 .44068 L p
1 g
F P
s
P
p
.002 w
.39974 .51499 m .39998 .52511 L .37159 .51985 L p
1 g
F P
s
P
p
.002 w
.37159 .51985 m .37091 .50003 L .39974 .51499 L p
1 g
F P
s
P
p
.002 w
.65176 .44068 m .62448 .38477 L .64171 .36577 L p
1 g
F P
s
P
p
.002 w
.59469 .31626 m .64171 .36577 L .62448 .38477 L p
1 g
F P
s
P
p
.002 w
.39586 .38923 m .36204 .40544 L .35433 .37536 L p
1 g
F P
s
P
p
.002 w
.35433 .37536 m .39437 .35559 L .39586 .38923 L p
1 g
F P
s
P
p
.002 w
.62448 .38477 m .65176 .44068 L .62846 .45727 L p
1 g
F P
s
P
p
.002 w
.5793 .3374 m .52185 .3049 L .53475 .28243 L p
1 g
F P
s
P
p
.002 w
.53475 .28243 m .59469 .31626 L .5793 .3374 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.56641 .56328 m .57484 .52767 L .60683 .52011 L p
1 g
F P
s
P
p
.002 w
.62448 .38477 m .5793 .3374 L .59469 .31626 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51794 .41874 L
s
P
p
.002 w
.44263 .3509 m .39437 .35559 L .3961 .32486 L p
1 g
F P
s
P
p
.002 w
.3961 .32486 m .45051 .31911 L .44263 .3509 L p
1 g
F P
s
P
p
.002 w
.39022 .46846 m .3773 .48224 L .35553 .45726 L p
1 g
F P
s
P
p
.002 w
.35553 .45726 m .37412 .43685 L .39022 .46846 L p
1 g
F P
s
P
p
.002 w
.40312 .50599 m .39974 .51499 L .37091 .50003 L p
1 g
F P
s
P
p
.002 w
.37091 .50003 m .3773 .48224 L .40312 .50599 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.50792 .33187 m .45051 .31911 L .45971 .29139 L p
1 g
F P
s
P
p
.002 w
.45971 .29139 m .52185 .3049 L .50792 .33187 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40059 .42458 m .37412 .43685 L .36204 .40544 L p
1 g
F P
s
P
p
.002 w
.36204 .40544 m .39586 .38923 L .40059 .42458 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60064 .47343 m .60683 .52011 L .57484 .52767 L p
1 g
F P
s
P
p
.002 w
.60683 .52011 m .60064 .47343 L .62846 .45727 L p
1 g
F P
s
P
p
.002 w
.45191 .55517 m .46012 .5499 L .48905 .56836 L p
1 g
F P
s
P
p
.002 w
.49981 .55299 m .48905 .56836 L .46012 .5499 L p
1 g
F P
s
P
p
.002 w
.48905 .56836 m .49981 .55299 L .53387 .56014 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.54007 .53235 m .53387 .56014 L .49981 .55299 L p
1 g
F P
s
P
p
.002 w
.40979 .4991 m .40312 .50599 L .3773 .48224 L p
1 g
F P
s
P
p
.002 w
.3773 .48224 m .39022 .46846 L .40979 .4991 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.62846 .45727 m .60294 .40572 L .62448 .38477 L p
1 g
F P
s
P
p
.002 w
.5793 .3374 m .62448 .38477 L .60294 .40572 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60294 .40572 m .62846 .45727 L .60064 .47343 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43641 .38567 m .39586 .38923 L .39437 .35559 L p
1 g
F P
s
P
p
.002 w
.39437 .35559 m .44263 .3509 L .43641 .38567 L p
1 g
F P
s
P
p
.002 w
.56103 .362 m .50792 .33187 L .52185 .3049 L p
1 g
F P
s
P
p
.002 w
.52185 .3049 m .5793 .3374 L .56103 .362 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.40842 .46033 m .39022 .46846 L .37412 .43685 L p
1 g
F P
s
P
p
.002 w
.37412 .43685 m .40059 .42458 L .40842 .46033 L p
1 g
F P
s
P
p
.002 w
.46012 .5499 m .46546 .54201 L .49981 .55299 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.57484 .52767 m .56924 .48853 L .60064 .47343 L p
1 g
F P
s
P
p
.002 w
.50377 .53393 m .49981 .55299 L .46546 .54201 L p
1 g
F P
s
P
p
.002 w
.49981 .55299 m .50377 .53393 L .54007 .53235 L p
1 g
F P
s
P
p
.002 w
.60294 .40572 m .56103 .362 L .5793 .3374 L p
1 g
F P
s
P
p
.002 w
.49346 .36247 m .44263 .3509 L .45051 .31911 L p
1 g
F P
s
P
p
.002 w
.45051 .31911 m .50792 .33187 L .49346 .36247 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46546 .54201 m .46733 .53232 L .50377 .53393 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.41907 .4951 m .40979 .4991 L .39022 .46846 L p
1 g
F P
s
P
p
.002 w
.39022 .46846 m .40842 .46033 L .41907 .4951 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43212 .42213 m .40059 .42458 L .39586 .38923 L p
1 g
F P
s
P
p
.002 w
.39586 .38923 m .43641 .38567 L .43212 .42213 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.53537 .50198 m .54007 .53235 L .50377 .53393 L p
1 g
F P
s
P
p
.002 w
.57773 .42789 m .60064 .47343 L .56924 .48853 L p
1 g
F P
s
P
p
.002 w
.60064 .47343 m .57773 .42789 L .60294 .40572 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46733 .53232 m .46547 .52187 L .50033 .51323 L p
1 g
F P
s
P
p
.002 w
.50033 .51323 m .50377 .53393 L .46733 .53232 L p
1 g
F P
s
P
p
.002 w
.56103 .362 m .60294 .40572 L .57773 .42789 L p
1 g
F P
s
P
p
.004 w
.51859 .41831 m
.56722 .38639 L
s
P
p
.004 w
.57947 .37834 m
.61465 .35525 L
s
P
p
.002 w
.42995 .49447 m .41907 .4951 L .40842 .46033 L p
1 g
F P
s
P
p
.002 w
.50377 .53393 m .50033 .51323 L .53537 .50198 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42994 .45887 m .40842 .46033 L .40059 .42458 L p
1 g
F P
s
P
p
.002 w
.40059 .42458 m .43212 .42213 L .42994 .45887 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54049 .38924 m .49346 .36247 L .50792 .33187 L p
1 g
F P
s
P
p
.002 w
.50792 .33187 m .56103 .362 L .54049 .38924 L p
1 g
F P
s
P
p
.002 w
.479 .39562 m .43641 .38567 L .44263 .3509 L p
1 g
F P
s
P
p
.002 w
.44263 .3509 m .49346 .36247 L .479 .39562 L p
1 g
F P
s
P
p
.002 w
.46547 .52187 m .46005 .51183 L .48973 .49325 L p
1 g
F P
s
P
p
.002 w
.48973 .49325 m .50033 .51323 L .46547 .52187 L p
1 g
F P
s
P
p
.002 w
.40842 .46033 m .42994 .45887 L .42995 .49447 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57773 .42789 m .54049 .38924 L .56103 .362 L p
1 g
F P
s
P
p
.004 w
.57374 .38211 m
.57947 .37834 L
s
P
p
.004 w
.57084 .38401 m
.57374 .38211 L
s
P
p
.004 w
.57026 .38439 m
.57084 .38401 L
s
P
p
.002 w
.46005 .51183 m .45166 .50332 L .47311 .47631 L p
1 g
F P
s
P
p
.002 w
.47311 .47631 m .48973 .49325 L .46005 .51183 L p
1 g
F P
s
P
p
.002 w
.56924 .48853 m .54974 .45045 L .57773 .42789 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.50033 .51323 m .48973 .49325 L .52002 .47253 L p
1 g
F P
s
P
p
.002 w
.52002 .47253 m .53537 .50198 L .50033 .51323 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.46512 .43005 m .43212 .42213 L .43641 .38567 L p
1 g
F P
s
P
p
.002 w
.43641 .38567 m .479 .39562 L .46512 .43005 L p
1 g
F P
s
P
p
.002 w
.54049 .38924 m .57773 .42789 L .54974 .45045 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.45237 .46439 m .42994 .45887 L .43212 .42213 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.43212 .42213 m .46512 .43005 L .45237 .46439 L p
1 g
F P
s
P
p
.002 w
.51841 .41813 m .479 .39562 L .49346 .36247 L p
1 g
F P
s
P
p
.002 w
.49346 .36247 m .54049 .38924 L .51841 .41813 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54974 .45045 m .51841 .41813 L .54049 .38924 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49565 .44753 m .46512 .43005 L .479 .39562 L p
1 g
F P
s
P
p
.002 w
.479 .39562 m .51841 .41813 L .49565 .44753 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.40378 .5681 m
.4087 .56106 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .61465 .35525 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39139 .58582 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.287597)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.287597)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47774 .42619 m .49643 .44582 L .51392 .42322 L p
1 g
F P
s
P
p
.002 w
.51392 .42322 m .50117 .40983 L .47774 .42619 L p
1 g
F P
s
P
p
.002 w
.53004 .43215 m .51392 .42322 L .49643 .44582 L p
1 g
F P
s
P
p
.002 w
.50117 .40983 m .51392 .42322 L .53113 .40073 L p
1 g
F P
s
P
p
.002 w
.51392 .42322 m .53004 .43215 L .53933 .40525 L p
1 g
F P
s
P
p
.002 w
.53933 .40525 m .53113 .40073 L .51392 .42322 L p
1 g
F P
s
P
p
.002 w
.45476 .44272 m .47898 .46812 L .49643 .44582 L p
1 g
F P
s
P
p
.002 w
.49643 .44582 m .47774 .42619 L .45476 .44272 L p
1 g
F P
s
P
p
.002 w
.52005 .45895 m .49643 .44582 L .47898 .46812 L p
1 g
F P
s
P
p
.002 w
.49643 .44582 m .52005 .45895 L .53004 .43215 L p
1 g
F P
s
P
p
.002 w
.46587 .40206 m .47774 .42619 L .50117 .40983 L p
1 g
F P
s
P
p
.002 w
.50117 .40983 m .49313 .39335 L .46587 .40206 L p
1 g
F P
s
P
p
.002 w
.49313 .39335 m .50117 .40983 L .52465 .39391 L p
1 g
F P
s
P
p
.002 w
.53113 .40073 m .52465 .39391 L .50117 .40983 L p
1 g
F P
s
P
p
.002 w
.43929 .4115 m .45476 .44272 L .47774 .42619 L p
1 g
F P
s
P
p
.002 w
.47774 .42619 m .46587 .40206 L .43929 .4115 L p
1 g
F P
s
P
p
.002 w
.54788 .43566 m .53004 .43215 L .52005 .45895 L p
1 g
F P
s
P
p
.002 w
.53004 .43215 m .54788 .43566 L .5484 .40699 L p
1 g
F P
s
P
p
.002 w
.5484 .40699 m .53933 .40525 L .53004 .43215 L p
1 g
F P
s
P
p
.002 w
.47898 .46812 m .50952 .48519 L .52005 .45895 L p
1 g
F P
s
P
p
.002 w
.5462 .46422 m .52005 .45895 L .50952 .48519 L p
1 g
F P
s
P
p
.002 w
.52005 .45895 m .5462 .46422 L .54788 .43566 L p
1 g
F P
s
P
p
.002 w
.4621 .37584 m .46587 .40206 L .49313 .39335 L p
1 g
F P
s
P
p
.002 w
.49313 .39335 m .49066 .37548 L .4621 .37584 L p
1 g
F P
s
P
p
.002 w
.49066 .37548 m .49313 .39335 L .52059 .38553 L p
1 g
F P
s
P
p
.002 w
.52465 .39391 m .52059 .38553 L .49313 .39335 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .52465 .39391 L .53113 .40073 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .53113 .40073 L .53933 .40525 L closepath p
1 g
F P
s
P
p
.002 w
.43266 .45912 m .46187 .48972 L .47898 .46812 L p
1 g
F P
s
P
p
.002 w
.47898 .46812 m .45476 .44272 L .43266 .45912 L p
1 g
F P
s
P
p
.002 w
.50952 .48519 m .47898 .46812 L .46187 .48972 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .52059 .38553 L .52465 .39391 L closepath p
1 g
F P
s
P
p
.002 w
.43423 .37754 m .43929 .4115 L .46587 .40206 L p
1 g
F P
s
P
p
.002 w
.46587 .40206 m .4621 .37584 L .43423 .37754 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .53933 .40525 L .5484 .40699 L closepath p
1 g
F P
s
P
p
.002 w
.4139 .42153 m .43266 .45912 L .45476 .44272 L p
1 g
F P
s
P
p
.002 w
.45476 .44272 m .43929 .4115 L .4139 .42153 L p
1 g
F P
s
P
p
.002 w
.56557 .43334 m .54788 .43566 L .5462 .46422 L p
1 g
F P
s
P
p
.002 w
.54788 .43566 m .56557 .43334 L .55736 .40576 L p
1 g
F P
s
P
p
.002 w
.55736 .40576 m .5484 .40699 L .54788 .43566 L p
1 g
F P
s
P
p
.002 w
.52059 .38553 m .51938 .37645 L .49066 .37548 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .51938 .37645 L .52059 .38553 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .5484 .40699 L .55736 .40576 L closepath p
1 g
F P
s
P
p
.002 w
.46187 .48972 m .49865 .51036 L .50952 .48519 L p
1 g
F P
s
P
p
.002 w
.54338 .49215 m .50952 .48519 L .49865 .51036 L p
1 g
F P
s
P
p
.002 w
.50952 .48519 m .54338 .49215 L .5462 .46422 L p
1 g
F P
s
P
p
.002 w
.46693 .35024 m .4621 .37584 L .49066 .37548 L p
1 g
F P
s
P
p
.002 w
.49066 .37548 m .49407 .3581 L .46693 .35024 L p
1 g
F P
s
P
p
.002 w
.49407 .3581 m .49066 .37548 L .51938 .37645 L p
1 g
F P
s
P
p
.002 w
.57222 .46097 m .5462 .46422 L .54338 .49215 L p
1 g
F P
s
P
p
.002 w
.5462 .46422 m .57222 .46097 L .56557 .43334 L p
1 g
F P
s
P
p
.002 w
.51938 .37645 m .52117 .36766 L .49407 .3581 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .52117 .36766 L .51938 .37645 L closepath p
1 g
F P
s
P
p
.002 w
.56526 .40167 m .55736 .40576 L .56557 .43334 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .55736 .40576 L .56526 .40167 L closepath p
1 g
F P
s
P
p
.002 w
.40758 .38058 m .4139 .42153 L .43929 .4115 L p
1 g
F P
s
P
p
.002 w
.43929 .4115 m .43423 .37754 L .40758 .38058 L p
1 g
F P
s
P
p
.002 w
.58124 .42537 m .56557 .43334 L .57222 .46097 L p
1 g
F P
s
P
p
.002 w
.56557 .43334 m .58124 .42537 L .56526 .40167 L p
1 g
F P
s
P
p
.002 w
.50307 .34306 m .49407 .3581 L .52117 .36766 L p
1 g
F P
s
P
p
.002 w
.52117 .36766 m .52578 .3601 L .50307 .34306 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .52578 .3601 L .52117 .36766 L closepath p
1 g
F P
s
P
p
.002 w
.44028 .34427 m .43423 .37754 L .4621 .37584 L p
1 g
F P
s
P
p
.002 w
.4621 .37584 m .46693 .35024 L .44028 .34427 L p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .56699 .3609 L .55943 .35508 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .55943 .35508 L .55054 .35192 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .55054 .35192 L .5413 .35175 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .5413 .35175 L .53274 .35459 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .53274 .35459 L .52578 .3601 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .56526 .40167 L .57123 .39513 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .57123 .39513 L .57461 .38685 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .57461 .38685 L .57502 .37772 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .57502 .37772 L .57239 .36874 L closepath p
1 g
F P
s
P
p
.002 w
.54774 .37875 m .57239 .36874 L .56699 .3609 L closepath p
1 g
F P
s
P
p
.002 w
.41186 .47507 m .44542 .51019 L .46187 .48972 L p
1 g
F P
s
P
p
.002 w
.46187 .48972 m .43266 .45912 L .41186 .47507 L p
1 g
F P
s
P
p
.002 w
.49865 .51036 m .46187 .48972 L .44542 .51019 L p
1 g
F P
s
P
p
.002 w
.57123 .39513 m .56526 .40167 L .58124 .42537 L p
1 g
F P
s
P
p
.002 w
.48003 .32799 m .46693 .35024 L .49407 .3581 L p
1 g
F P
s
P
p
.002 w
.49407 .3581 m .50307 .34306 L .48003 .32799 L p
1 g
F P
s
P
p
.002 w
.39019 .43194 m .41186 .47507 L .43266 .45912 L p
1 g
F P
s
P
p
.002 w
.43266 .45912 m .4139 .42153 L .39019 .43194 L p
1 g
F P
s
P
p
.002 w
.51678 .33203 m .50307 .34306 L .52578 .3601 L p
1 g
F P
s
P
p
.002 w
.52578 .3601 m .53274 .35459 L .51678 .33203 L p
1 g
F P
s
P
p
.002 w
.49865 .51036 m .53946 .51893 L .54338 .49215 L p
1 g
F P
s
P
p
.002 w
.57717 .48815 m .54338 .49215 L .53946 .51893 L p
1 g
F P
s
P
p
.002 w
.54338 .49215 m .57717 .48815 L .57222 .46097 L p
1 g
F P
s
P
p
.002 w
.59538 .44942 m .57222 .46097 L .57717 .48815 L p
1 g
F P
s
P
p
.002 w
.57222 .46097 m .59538 .44942 L .58124 .42537 L p
1 g
F P
s
P
p
.002 w
.58124 .42537 m .59318 .41253 L .57123 .39513 L p
1 g
F P
s
P
p
.002 w
.57461 .38685 m .57123 .39513 L .59318 .41253 L p
1 g
F P
s
P
p
.002 w
.44542 .51019 m .48764 .53398 L .49865 .51036 L p
1 g
F P
s
P
p
.002 w
.53946 .51893 m .49865 .51036 L .48764 .53398 L p
1 g
F P
s
P
p
.002 w
.59318 .41253 m .58124 .42537 L .59538 .44942 L p
1 g
F P
s
P
p
.002 w
.53375 .32629 m .51678 .33203 L .53274 .35459 L p
1 g
F P
s
P
p
.002 w
.53274 .35459 m .5413 .35175 L .53375 .32629 L p
1 g
F P
s
P
p
.002 w
.41463 .34034 m .40758 .38058 L .43423 .37754 L p
1 g
F P
s
P
p
.002 w
.43423 .37754 m .44028 .34427 L .41463 .34034 L p
1 g
F P
s
P
p
.002 w
.59318 .41253 m .60001 .39614 L .57461 .38685 L p
1 g
F P
s
P
p
.002 w
.57502 .37772 m .57461 .38685 L .60001 .39614 L p
1 g
F P
s
P
p
.002 w
.38271 .38492 m .39019 .43194 L .4139 .42153 L p
1 g
F P
s
P
p
.002 w
.4139 .42153 m .40758 .38058 L .38271 .38492 L p
1 g
F P
s
P
p
.002 w
.45708 .31521 m .44028 .34427 L .46693 .35024 L p
1 g
F P
s
P
p
.002 w
.46693 .35024 m .48003 .32799 L .45708 .31521 L p
1 g
F P
s
P
p
.002 w
.50014 .31156 m .48003 .32799 L .50307 .34306 L p
1 g
F P
s
P
p
.002 w
.50307 .34306 m .51678 .33203 L .50014 .31156 L p
1 g
F P
s
P
p
.002 w
.55214 .32653 m .53375 .32629 L .5413 .35175 L p
1 g
F P
s
P
p
.002 w
.5413 .35175 m .55054 .35192 L .55214 .32653 L p
1 g
F P
s
P
p
.002 w
.60001 .39614 m .60093 .37799 L .57502 .37772 L p
1 g
F P
s
P
p
.002 w
.57239 .36874 m .57502 .37772 L .60093 .37799 L p
1 g
F P
s
P
p
.002 w
.56989 .33279 m .55214 .32653 L .55054 .35192 L p
1 g
F P
s
P
p
.002 w
.55054 .35192 m .55943 .35508 L .56989 .33279 L p
1 g
F P
s
P
p
.002 w
.59538 .44942 m .61313 .43061 L .59318 .41253 L p
1 g
F P
s
P
p
.002 w
.60001 .39614 m .59318 .41253 L .61313 .43061 L p
1 g
F P
s
P
p
.002 w
.60093 .37799 m .59574 .36007 L .57239 .36874 L p
1 g
F P
s
P
p
.002 w
.56699 .3609 m .57239 .36874 L .59574 .36007 L p
1 g
F P
s
P
p
.002 w
.585 .34441 m .56989 .33279 L .55943 .35508 L p
1 g
F P
s
P
p
.002 w
.55943 .35508 m .56699 .3609 L .585 .34441 L p
1 g
F P
s
P
p
.002 w
.53946 .51893 m .58028 .51434 L .57717 .48815 L p
1 g
F P
s
P
p
.002 w
.60737 .47336 m .57717 .48815 L .58028 .51434 L p
1 g
F P
s
P
p
.002 w
.57717 .48815 m .60737 .47336 L .59538 .44942 L p
1 g
F P
s
P
p
.002 w
.3928 .49025 m .42999 .52913 L .44542 .51019 L p
1 g
F P
s
P
p
.002 w
.44542 .51019 m .41186 .47507 L .3928 .49025 L p
1 g
F P
s
P
p
.002 w
.48764 .53398 m .44542 .51019 L .42999 .52913 L p
1 g
F P
s
P
p
.002 w
.59574 .36007 m .585 .34441 L .56699 .3609 L p
1 g
F P
s
P
p
.002 w
.48764 .53398 m .53449 .54401 L .53946 .51893 L p
1 g
F P
s
P
p
.002 w
.58028 .51434 m .53946 .51893 L .53449 .54401 L p
1 g
F P
s
P
p
.002 w
.61313 .43061 m .59538 .44942 L .60737 .47336 L p
1 g
F P
s
P
p
.002 w
.36868 .44257 m .3928 .49025 L .41186 .47507 L p
1 g
F P
s
P
p
.002 w
.41186 .47507 m .39019 .43194 L .36868 .44257 L p
1 g
F P
s
P
p
.002 w
.5252 .30289 m .50014 .31156 L .51678 .33203 L p
1 g
F P
s
P
p
.002 w
.51678 .33203 m .53375 .32629 L .5252 .30289 L p
1 g
F P
s
P
p
.002 w
.42999 .52913 m .47668 .55555 L .48764 .53398 L p
1 g
F P
s
P
p
.002 w
.53449 .54401 m .48764 .53398 L .47668 .55555 L p
1 g
F P
s
P
p
.002 w
.48313 .29362 m .45708 .31521 L .48003 .32799 L p
1 g
F P
s
P
p
.002 w
.48003 .32799 m .50014 .31156 L .48313 .29362 L p
1 g
F P
s
P
p
.002 w
.43471 .30506 m .41463 .34034 L .44028 .34427 L p
1 g
F P
s
P
p
.002 w
.44028 .34427 m .45708 .31521 L .43471 .30506 L p
1 g
F P
s
P
p
.002 w
.39054 .3386 m .38271 .38492 L .40758 .38058 L p
1 g
F P
s
P
p
.002 w
.40758 .38058 m .41463 .34034 L .39054 .3386 L p
1 g
F P
s
P
p
.002 w
.61313 .43061 m .6234 .40647 L .60001 .39614 L p
1 g
F P
s
P
p
.002 w
.60093 .37799 m .60001 .39614 L .6234 .40647 L p
1 g
F P
s
P
p
.002 w
.55247 .30313 m .5252 .30289 L .53375 .32629 L p
1 g
F P
s
P
p
.002 w
.53375 .32629 m .55214 .32653 L .55247 .30313 L p
1 g
F P
s
P
p
.002 w
.36018 .39052 m .36868 .44257 L .39019 .43194 L p
1 g
F P
s
P
p
.002 w
.39019 .43194 m .38271 .38492 L .36018 .39052 L p
1 g
F P
s
P
p
.002 w
.60737 .47336 m .63064 .44906 L .61313 .43061 L p
1 g
F P
s
P
p
.002 w
.6234 .40647 m .61313 .43061 L .63064 .44906 L p
1 g
F P
s
P
p
.002 w
.6234 .40647 m .6249 .37957 L .60093 .37799 L p
1 g
F P
s
P
p
.002 w
.59574 .36007 m .60093 .37799 L .6249 .37957 L p
1 g
F P
s
P
p
.002 w
.58028 .51434 m .6169 .49671 L .60737 .47336 L p
1 g
F P
s
P
p
.002 w
.63064 .44906 m .60737 .47336 L .6169 .49671 L p
1 g
F P
s
P
p
.002 w
.53449 .54401 m .58145 .539 L .58028 .51434 L p
1 g
F P
s
P
p
.002 w
.6169 .49671 m .58028 .51434 L .58145 .539 L p
1 g
F P
s
P
p
.002 w
.57887 .31237 m .55247 .30313 L .55214 .32653 L p
1 g
F P
s
P
p
.002 w
.55214 .32653 m .56989 .33279 L .57887 .31237 L p
1 g
F P
s
P
p
.002 w
.47668 .55555 m .52853 .56685 L .53449 .54401 L p
1 g
F P
s
P
p
.002 w
.58145 .539 m .53449 .54401 L .52853 .56685 L p
1 g
F P
s
P
p
.002 w
.6249 .37957 m .61729 .35294 L .59574 .36007 L p
1 g
F P
s
P
p
.002 w
.585 .34441 m .59574 .36007 L .61729 .35294 L p
1 g
F P
s
P
p
.002 w
.51578 .28213 m .48313 .29362 L .50014 .31156 L p
1 g
F P
s
P
p
.002 w
.50014 .31156 m .5252 .30289 L .51578 .28213 L p
1 g
F P
s
P
p
.002 w
.60135 .32963 m .57887 .31237 L .56989 .33279 L p
1 g
F P
s
P
p
.002 w
.56989 .33279 m .585 .34441 L .60135 .32963 L p
1 g
F P
s
P
p
.002 w
.37594 .50435 m .4159 .5461 L .42999 .52913 L p
1 g
F P
s
P
p
.002 w
.42999 .52913 m .3928 .49025 L .37594 .50435 L p
1 g
F P
s
P
p
.002 w
.47668 .55555 m .42999 .52913 L .4159 .5461 L p
1 g
F P
s
P
p
.002 w
.61729 .35294 m .60135 .32963 L .585 .34441 L p
1 g
F P
s
P
p
.002 w
.34991 .45318 m .37594 .50435 L .3928 .49025 L p
1 g
F P
s
P
p
.002 w
.3928 .49025 m .36868 .44257 L .34991 .45318 L p
1 g
F P
s
P
p
.002 w
.4661 .2787 m .43471 .30506 L .45708 .31521 L p
1 g
F P
s
P
p
.002 w
.45708 .31521 m .48313 .29362 L .4661 .2787 L p
1 g
F P
s
P
p
.002 w
.4134 .29783 m .39054 .3386 L .41463 .34034 L p
1 g
F P
s
P
p
.002 w
.41463 .34034 m .43471 .30506 L .4134 .29783 L p
1 g
F P
s
P
p
.002 w
.63064 .44906 m .64424 .41766 L .6234 .40647 L p
1 g
F P
s
P
p
.002 w
.6249 .37957 m .6234 .40647 L .64424 .41766 L p
1 g
F P
s
P
p
.002 w
.36858 .33916 m .36018 .39052 L .38271 .38492 L p
1 g
F P
s
P
p
.002 w
.38271 .38492 m .39054 .3386 L .36858 .33916 L p
1 g
F P
s
P
p
.002 w
.4159 .5461 m .46601 .57455 L .47668 .55555 L p
1 g
F P
s
P
p
.002 w
.52853 .56685 m .47668 .55555 L .46601 .57455 L p
1 g
F P
s
P
p
.002 w
.55147 .28229 m .51578 .28213 L .5252 .30289 L p
1 g
F P
s
P
p
.002 w
.5252 .30289 m .55247 .30313 L .55147 .28229 L p
1 g
F P
s
P
p
.002 w
.34056 .39731 m .34991 .45318 L .36868 .44257 L p
1 g
F P
s
P
p
.002 w
.36868 .44257 m .36018 .39052 L .34056 .39731 L p
1 g
F P
s
P
p
.002 w
.6169 .49671 m .64528 .46749 L .63064 .44906 L p
1 g
F P
s
P
p
.002 w
.64424 .41766 m .63064 .44906 L .64528 .46749 L p
1 g
F P
s
P
p
.002 w
.58145 .539 m .62371 .51898 L .6169 .49671 L p
1 g
F P
s
P
p
.002 w
.64528 .46749 m .6169 .49671 L .62371 .51898 L p
1 g
F P
s
P
p
.002 w
.64424 .41766 m .64637 .38251 L .6249 .37957 L p
1 g
F P
s
P
p
.002 w
.61729 .35294 m .6249 .37957 L .64637 .38251 L p
1 g
F P
s
P
p
.002 w
.52853 .56685 m .58057 .56156 L .58145 .539 L p
1 g
F P
s
P
p
.002 w
.62371 .51898 m .58145 .539 L .58057 .56156 L p
1 g
F P
s
P
p
.002 w
.58611 .29433 m .55147 .28229 L .55247 .30313 L p
1 g
F P
s
P
p
.002 w
.55247 .30313 m .57887 .31237 L .58611 .29433 L p
1 g
F P
s
P
p
.002 w
.50566 .26455 m .4661 .2787 L .48313 .29362 L p
1 g
F P
s
P
p
.002 w
.48313 .29362 m .51578 .28213 L .50566 .26455 L p
1 g
F P
s
P
p
.002 w
.46601 .57455 m .52166 .58687 L .52853 .56685 L p
1 g
F P
s
P
p
.002 w
.58057 .56156 m .52853 .56685 L .52166 .58687 L p
1 g
F P
s
P
p
.002 w
.64637 .38251 m .6365 .34758 L .61729 .35294 L p
1 g
F P
s
P
p
.002 w
.60135 .32963 m .61729 .35294 L .6365 .34758 L p
1 g
F P
s
P
p
.002 w
.44941 .26725 m .4134 .29783 L .43471 .30506 L p
1 g
F P
s
P
p
.002 w
.43471 .30506 m .4661 .2787 L .44941 .26725 L p
1 g
F P
s
P
p
.002 w
.61562 .31698 m .58611 .29433 L .57887 .31237 L p
1 g
F P
s
P
p
.002 w
.57887 .31237 m .60135 .32963 L .61562 .31698 L p
1 g
F P
s
P
p
.002 w
.39367 .29383 m .36858 .33916 L .39054 .3386 L p
1 g
F P
s
P
p
.002 w
.39054 .3386 m .4134 .29783 L .39367 .29383 L p
1 g
F P
s
P
p
.002 w
.36171 .517 m .40351 .56064 L .4159 .5461 L p
1 g
F P
s
P
p
.002 w
.4159 .5461 m .37594 .50435 L .36171 .517 L p
1 g
F P
s
P
p
.002 w
.46601 .57455 m .4159 .5461 L .40351 .56064 L p
1 g
F P
s
P
p
.002 w
.6365 .34758 m .61562 .31698 L .60135 .32963 L p
1 g
F P
s
P
p
.002 w
.3344 .46356 m .36171 .517 L .37594 .50435 L p
1 g
F P
s
P
p
.002 w
.37594 .50435 m .34991 .45318 L .3344 .46356 L p
1 g
F P
s
P
p
.002 w
.64528 .46749 m .66199 .4295 L .64424 .41766 L p
1 g
F P
s
P
p
.002 w
.64637 .38251 m .64424 .41766 L .66199 .4295 L p
1 g
F P
s
P
p
.002 w
.34933 .34212 m .34056 .39731 L .36018 .39052 L p
1 g
F P
s
P
p
.002 w
.36018 .39052 m .36858 .33916 L .34933 .34212 L p
1 g
F P
s
P
p
.002 w
.40351 .56064 m .45587 .59046 L .46601 .57455 L p
1 g
F P
s
P
p
.002 w
.52166 .58687 m .46601 .57455 L .45587 .59046 L p
1 g
F P
s
P
p
.002 w
.5491 .2646 m .50566 .26455 L .51578 .28213 L p
1 g
F P
s
P
p
.002 w
.51578 .28213 m .55147 .28229 L .5491 .2646 L p
1 g
F P
s
P
p
.002 w
.62371 .51898 m .6566 .48551 L .64528 .46749 L p
1 g
F P
s
P
p
.002 w
.66199 .4295 m .64528 .46749 L .6566 .48551 L p
1 g
F P
s
P
p
.002 w
.32444 .40521 m .3344 .46356 L .34991 .45318 L p
1 g
F P
s
P
p
.002 w
.34991 .45318 m .34056 .39731 L .32444 .40521 L p
1 g
F P
s
P
p
.002 w
.58057 .56156 m .62753 .53963 L .62371 .51898 L p
1 g
F P
s
P
p
.002 w
.6566 .48551 m .62371 .51898 L .62753 .53963 L p
1 g
F P
s
P
p
.002 w
.52166 .58687 m .57758 .58143 L .58057 .56156 L p
1 g
F P
s
P
p
.002 w
.62753 .53963 m .58057 .56156 L .57758 .58143 L p
1 g
F P
s
P
p
.002 w
.66199 .4295 m .66475 .38678 L .64637 .38251 L p
1 g
F P
s
P
p
.002 w
.6365 .34758 m .64637 .38251 L .66475 .38678 L p
1 g
F P
s
P
p
.002 w
.49504 .25071 m .44941 .26725 L .4661 .2787 L p
1 g
F P
s
P
p
.002 w
.4661 .2787 m .50566 .26455 L .49504 .25071 L p
1 g
F P
s
P
p
.002 w
.59136 .2792 m .5491 .2646 L .55147 .28229 L p
1 g
F P
s
P
p
.002 w
.55147 .28229 m .58611 .29433 L .59136 .2792 L p
1 g
F P
s
P
p
.002 w
.45587 .59046 m .51401 .60349 L .52166 .58687 L p
1 g
F P
s
P
p
.002 w
.57758 .58143 m .52166 .58687 L .51401 .60349 L p
1 g
F P
s
P
p
.002 w
.43347 .25971 m .39367 .29383 L .4134 .29783 L p
1 g
F P
s
P
p
.002 w
.4134 .29783 m .44941 .26725 L .43347 .25971 L p
1 g
F P
s
P
p
.002 w
.66475 .38678 m .65283 .34419 L .6365 .34758 L p
1 g
F P
s
P
p
.002 w
.61562 .31698 m .6365 .34758 L .65283 .34419 L p
1 g
F P
s
P
p
.002 w
.37606 .29331 m .34933 .34212 L .36858 .33916 L p
1 g
F P
s
P
p
.002 w
.36858 .33916 m .39367 .29383 L .37606 .29331 L p
1 g
F P
s
P
p
.002 w
.62739 .30683 m .59136 .2792 L .58611 .29433 L p
1 g
F P
s
P
p
.002 w
.58611 .29433 m .61562 .31698 L .62739 .30683 L p
1 g
F P
s
P
p
.002 w
.6566 .48551 m .6761 .44176 L .66199 .4295 L p
1 g
F P
s
P
p
.002 w
.66475 .38678 m .66199 .4295 L .6761 .44176 L p
1 g
F P
s
P
p
.002 w
.35059 .52785 m .3932 .5723 L .40351 .56064 L p
1 g
F P
s
P
p
.002 w
.40351 .56064 m .36171 .517 L .35059 .52785 L p
1 g
F P
s
P
p
.002 w
.45587 .59046 m .40351 .56064 L .3932 .5723 L p
1 g
F P
s
P
p
.002 w
.65283 .34419 m .62739 .30683 L .61562 .31698 L p
1 g
F P
s
P
p
.002 w
.33338 .34753 m .32444 .40521 L .34056 .39731 L p
1 g
F P
s
P
p
.002 w
.34056 .39731 m .34933 .34212 L .33338 .34753 L p
1 g
F P
s
P
p
.002 w
.32268 .47345 m .35059 .52785 L .36171 .517 L p
1 g
F P
s
P
p
.002 w
.36171 .517 m .3344 .46356 L .32268 .47345 L p
1 g
F P
s
P
p
.002 w
.3932 .5723 m .44652 .60275 L .45587 .59046 L p
1 g
F P
s
P
p
.002 w
.51401 .60349 m .45587 .59046 L .44652 .60275 L p
1 g
F P
s
P
p
.002 w
.62753 .53963 m .66419 .5027 L .6566 .48551 L p
1 g
F P
s
P
p
.002 w
.6761 .44176 m .6566 .48551 L .66419 .5027 L p
1 g
F P
s
P
p
.002 w
.54533 .25063 m .49504 .25071 L .50566 .26455 L p
1 g
F P
s
P
p
.002 w
.50566 .26455 m .5491 .2646 L .54533 .25063 L p
1 g
F P
s
P
p
.002 w
.57758 .58143 m .62812 .55811 L .62753 .53963 L p
1 g
F P
s
P
p
.002 w
.66419 .5027 m .62753 .53963 L .62812 .55811 L p
1 g
F P
s
P
p
.002 w
.31239 .41408 m .32268 .47345 L .3344 .46356 L p
1 g
F P
s
P
p
.002 w
.3344 .46356 m .32444 .40521 L .31239 .41408 L p
1 g
F P
s
P
p
.002 w
.51401 .60349 m .57244 .59802 L .57758 .58143 L p
1 g
F P
s
P
p
.002 w
.62812 .55811 m .57758 .58143 L .57244 .59802 L p
1 g
F P
s
P
p
.002 w
.6761 .44176 m .67945 .39236 L .66475 .38678 L p
1 g
F P
s
P
p
.002 w
.65283 .34419 m .66475 .38678 L .67945 .39236 L p
1 g
F P
s
P
p
.002 w
.48415 .24115 m .43347 .25971 L .44941 .26725 L p
1 g
F P
s
P
p
.002 w
.44941 .26725 m .49504 .25071 L .48415 .24115 L p
1 g
F P
s
P
p
.002 w
.59439 .26751 m .54533 .25063 L .5491 .2646 L p
1 g
F P
s
P
p
.002 w
.5491 .2646 m .59136 .2792 L .59439 .26751 L p
1 g
F P
s
P
p
.002 w
.41873 .25648 m .37606 .29331 L .39367 .29383 L p
1 g
F P
s
P
p
.002 w
.39367 .29383 m .43347 .25971 L .41873 .25648 L p
1 g
F P
s
P
p
.002 w
.44652 .60275 m .50569 .61614 L .51401 .60349 L p
1 g
F P
s
P
p
.002 w
.57244 .59802 m .51401 .60349 L .50569 .61614 L p
1 g
F P
s
P
p
.002 w
.36113 .29647 m .33338 .34753 L .34933 .34212 L p
1 g
F P
s
P
p
.002 w
.34933 .34212 m .37606 .29331 L .36113 .29647 L p
1 g
F P
s
P
p
.002 w
.67945 .39236 m .66573 .34297 L .65283 .34419 L p
1 g
F P
s
P
p
.002 w
.62739 .30683 m .65283 .34419 L .66573 .34297 L p
1 g
F P
s
P
p
.002 w
.66419 .5027 m .68604 .45418 L .6761 .44176 L p
1 g
F P
s
P
p
.002 w
.67945 .39236 m .6761 .44176 L .68604 .45418 L p
1 g
F P
s
P
p
.002 w
.63623 .29957 m .59439 .26751 L .59136 .2792 L p
1 g
F P
s
P
p
.002 w
.59136 .2792 m .62739 .30683 L .63623 .29957 L p
1 g
F P
s
P
p
.002 w
.32133 .3554 m .31239 .41408 L .32444 .40521 L p
1 g
F P
s
P
p
.002 w
.32444 .40521 m .33338 .34753 L .32133 .3554 L p
1 g
F P
s
P
p
.002 w
.34302 .53653 m .38533 .58065 L .3932 .5723 L p
1 g
F P
s
P
p
.002 w
.3932 .5723 m .35059 .52785 L .34302 .53653 L p
1 g
F P
s
P
p
.002 w
.44652 .60275 m .3932 .5723 L .38533 .58065 L p
1 g
F P
s
P
p
.002 w
.66573 .34297 m .63623 .29957 L .62739 .30683 L p
1 g
F P
s
P
p
.002 w
.31526 .48259 m .34302 .53653 L .35059 .52785 L p
1 g
F P
s
P
p
.002 w
.35059 .52785 m .32268 .47345 L .31526 .48259 L p
1 g
F P
s
P
p
.002 w
.62812 .55811 m .66768 .51859 L .66419 .5027 L p
1 g
F P
s
P
p
.002 w
.68604 .45418 m .66419 .5027 L .66768 .51859 L p
1 g
F P
s
P
p
.002 w
.54019 .24097 m .48415 .24115 L .49504 .25071 L p
1 g
F P
s
P
p
.002 w
.49504 .25071 m .54533 .25063 L .54019 .24097 L p
1 g
F P
s
P
p
.002 w
.38533 .58065 m .43823 .61091 L .44652 .60275 L p
1 g
F P
s
P
p
.002 w
.50569 .61614 m .44652 .60275 L .43823 .61091 L p
1 g
F P
s
P
p
.002 w
.57244 .59802 m .6253 .57386 L .62812 .55811 L p
1 g
F P
s
P
p
.002 w
.66768 .51859 m .62812 .55811 L .6253 .57386 L p
1 g
F P
s
P
p
.002 w
.30497 .42376 m .31526 .48259 L .32268 .47345 L p
1 g
F P
s
P
p
.002 w
.32268 .47345 m .31239 .41408 L .30497 .42376 L p
1 g
F P
s
P
p
.002 w
.50569 .61614 m .56515 .61074 L .57244 .59802 L p
1 g
F P
s
P
p
.002 w
.6253 .57386 m .57244 .59802 L .56515 .61074 L p
1 g
F P
s
P
p
.002 w
.47325 .23638 m .41873 .25648 L .43347 .25971 L p
1 g
F P
s
P
p
.002 w
.43347 .25971 m .48415 .24115 L .47325 .23638 L p
1 g
F P
s
P
p
.002 w
.68604 .45418 m .6899 .39919 L .67945 .39236 L p
1 g
F P
s
P
p
.002 w
.66573 .34297 m .67945 .39236 L .6899 .39919 L p
1 g
F P
s
P
p
.002 w
.40562 .2579 m .36113 .29647 L .37606 .29331 L p
1 g
F P
s
P
p
.002 w
.37606 .29331 m .41873 .25648 L .40562 .2579 L p
1 g
F P
s
P
p
.002 w
.59497 .25976 m .54019 .24097 L .54533 .25063 L p
1 g
F P
s
P
p
.002 w
.54533 .25063 m .59439 .26751 L .59497 .25976 L p
1 g
F P
s
P
p
.002 w
.43823 .61091 m .49688 .62429 L .50569 .61614 L p
1 g
F P
s
P
p
.002 w
.56515 .61074 m .50569 .61614 L .49688 .62429 L p
1 g
F P
s
P
p
.002 w
.34943 .30345 m .32133 .3554 L .33338 .34753 L p
1 g
F P
s
P
p
.002 w
.33338 .34753 m .36113 .29647 L .34943 .30345 L p
1 g
F P
s
P
p
.002 w
.6899 .39919 m .67467 .34408 L .66573 .34297 L p
1 g
F P
s
P
p
.002 w
.63623 .29957 m .66573 .34297 L .67467 .34408 L p
1 g
F P
s
P
p
.002 w
.66768 .51859 m .69132 .46645 L .68604 .45418 L p
1 g
F P
s
P
p
.002 w
.6899 .39919 m .68604 .45418 L .69132 .46645 L p
1 g
F P
s
P
p
.002 w
.31373 .36566 m .30497 .42376 L .31239 .41408 L p
1 g
F P
s
P
p
.002 w
.31239 .41408 m .32133 .3554 L .31373 .36566 L p
1 g
F P
s
P
p
.002 w
.64173 .29558 m .59497 .25976 L .59439 .26751 L p
1 g
F P
s
P
p
.002 w
.59439 .26751 m .63623 .29957 L .64173 .29558 L p
1 g
F P
s
P
p
.002 w
.33941 .54268 m .38025 .58526 L .38533 .58065 L p
1 g
F P
s
P
p
.002 w
.38533 .58065 m .34302 .53653 L .33941 .54268 L p
1 g
F P
s
P
p
.002 w
.43823 .61091 m .38533 .58065 L .38025 .58526 L p
1 g
F P
s
P
p
.002 w
.67467 .34408 m .64173 .29558 L .63623 .29957 L p
1 g
F P
s
P
p
.002 w
.6253 .57386 m .66673 .53269 L .66768 .51859 L p
1 g
F P
s
P
p
.002 w
.69132 .46645 m .66768 .51859 L .66673 .53269 L p
1 g
F P
s
P
p
.002 w
.3126 .49068 m .33941 .54268 L .34302 .53653 L p
1 g
F P
s
P
p
.002 w
.34302 .53653 m .31526 .48259 L .3126 .49068 L p
1 g
F P
s
P
p
.002 w
.53371 .23613 m .47325 .23638 L .48415 .24115 L p
1 g
F P
s
P
p
.002 w
.48415 .24115 m .54019 .24097 L .53371 .23613 L p
1 g
F P
s
P
p
.002 w
.56515 .61074 m .61895 .58631 L .6253 .57386 L p
1 g
F P
s
P
p
.002 w
.66673 .53269 m .6253 .57386 L .61895 .58631 L p
1 g
F P
s
P
p
.002 w
.38025 .58526 m .43127 .61448 L .43823 .61091 L p
1 g
F P
s
P
p
.002 w
.49688 .62429 m .43823 .61091 L .43127 .61448 L p
1 g
F P
s
P
p
.002 w
.49688 .62429 m .55579 .61903 L .56515 .61074 L p
1 g
F P
s
P
p
.002 w
.61895 .58631 m .56515 .61074 L .55579 .61903 L p
1 g
F P
s
P
p
.002 w
.30265 .43403 m .3126 .49068 L .31526 .48259 L p
1 g
F P
s
P
p
.002 w
.31526 .48259 m .30497 .42376 L .30265 .43403 L p
1 g
F P
s
P
p
.002 w
.46264 .23683 m .40562 .2579 L .41873 .25648 L p
1 g
F P
s
P
p
.002 w
.41873 .25648 m .47325 .23638 L .46264 .23683 L p
1 g
F P
s
P
p
.002 w
.69132 .46645 m .69557 .40717 L .6899 .39919 L p
1 g
F P
s
P
p
.002 w
.67467 .34408 m .6899 .39919 L .69557 .40717 L p
1 g
F P
s
P
p
.002 w
.39462 .26421 m .34943 .30345 L .36113 .29647 L p
1 g
F P
s
P
p
.002 w
.36113 .29647 m .40562 .2579 L .39462 .26421 L p
1 g
F P
s
P
p
.002 w
.59293 .25642 m .53371 .23613 L .54019 .24097 L p
1 g
F P
s
P
p
.002 w
.54019 .24097 m .59497 .25976 L .59293 .25642 L p
1 g
F P
s
P
p
.002 w
.43127 .61448 m .48779 .62741 L .49688 .62429 L p
1 g
F P
s
P
p
.002 w
.55579 .61903 m .49688 .62429 L .48779 .62741 L p
1 g
F P
s
P
p
.002 w
.34148 .31429 m .31373 .36566 L .32133 .3554 L p
1 g
F P
s
P
p
.002 w
.32133 .3554 m .34943 .30345 L .34148 .31429 L p
1 g
F P
s
P
p
.002 w
.66673 .53269 m .69152 .47822 L .69132 .46645 L p
1 g
F P
s
P
p
.002 w
.69557 .40717 m .69132 .46645 L .69152 .47822 L p
1 g
F P
s
P
p
.002 w
.69557 .40717 m .67914 .34763 L .67467 .34408 L p
1 g
F P
s
P
p
.002 w
.64173 .29558 m .67467 .34408 L .67914 .34763 L p
1 g
F P
s
P
p
.002 w
.31106 .37817 m .30265 .43403 L .30497 .42376 L p
1 g
F P
s
P
p
.002 w
.30497 .42376 m .31373 .36566 L .31106 .37817 L p
1 g
F P
s
P
p
.002 w
.64353 .29517 m .59293 .25642 L .59497 .25976 L p
1 g
F P
s
P
p
.002 w
.59497 .25976 m .64173 .29558 L .64353 .29517 L p
1 g
F P
s
P
p
.002 w
.61895 .58631 m .6611 .54453 L .66673 .53269 L p
1 g
F P
s
P
p
.002 w
.69152 .47822 m .66673 .53269 L .6611 .54453 L p
1 g
F P
s
P
p
.002 w
.34012 .54598 m .37828 .58576 L .38025 .58526 L p
1 g
F P
s
P
p
.002 w
.38025 .58526 m .33941 .54268 L .34012 .54598 L p
1 g
F P
s
P
p
.002 w
.43127 .61448 m .38025 .58526 L .37828 .58576 L p
1 g
F P
s
P
p
.002 w
.67914 .34763 m .64353 .29517 L .64173 .29558 L p
1 g
F P
s
P
p
.002 w
.31509 .49743 m .34012 .54598 L .33941 .54268 L p
1 g
F P
s
P
p
.002 w
.33941 .54268 m .3126 .49068 L .31509 .49743 L p
1 g
F P
s
P
p
.002 w
.526 .23656 m .46264 .23683 L .47325 .23638 L p
1 g
F P
s
P
p
.002 w
.47325 .23638 m .53371 .23613 L .526 .23656 L p
1 g
F P
s
P
p
.002 w
.55579 .61903 m .60902 .59493 L .61895 .58631 L p
1 g
F P
s
P
p
.002 w
.6611 .54453 m .61895 .58631 L .60902 .59493 L p
1 g
F P
s
P
p
.002 w
.37828 .58576 m .42594 .61305 L .43127 .61448 L p
1 g
F P
s
P
p
.002 w
.48779 .62741 m .43127 .61448 L .42594 .61305 L p
1 g
F P
s
P
p
.002 w
.48779 .62741 m .54447 .62239 L .55579 .61903 L p
1 g
F P
s
P
p
.002 w
.60902 .59493 m .55579 .61903 L .54447 .62239 L p
1 g
F P
s
P
p
.002 w
.45264 .24281 m .39462 .26421 L .40562 .2579 L p
1 g
F P
s
P
p
.002 w
.40562 .2579 m .46264 .23683 L .45264 .24281 L p
1 g
F P
s
P
p
.002 w
.30583 .44463 m .31509 .49743 L .3126 .49068 L p
1 g
F P
s
P
p
.002 w
.3126 .49068 m .30265 .43403 L .30583 .44463 L p
1 g
F P
s
P
p
.002 w
.69152 .47822 m .69598 .41615 L .69557 .40717 L p
1 g
F P
s
P
p
.002 w
.67914 .34763 m .69557 .40717 L .69598 .41615 L p
1 g
F P
s
P
p
.002 w
.38618 .27554 m .34148 .31429 L .34943 .30345 L p
1 g
F P
s
P
p
.002 w
.34943 .30345 m .39462 .26421 L .38618 .27554 L p
1 g
F P
s
P
p
.002 w
.33775 .32888 m .31106 .37817 L .31373 .36566 L p
1 g
F P
s
P
p
.002 w
.31373 .36566 m .34148 .31429 L .33775 .32888 L p
1 g
F P
s
P
p
.002 w
.42594 .61305 m .47866 .62512 L .48779 .62741 L p
1 g
F P
s
P
p
.002 w
.54447 .62239 m .48779 .62741 L .47866 .62512 L p
1 g
F P
s
P
p
.002 w
.58816 .25789 m .526 .23656 L .53371 .23613 L p
1 g
F P
s
P
p
.002 w
.53371 .23613 m .59293 .25642 L .58816 .25789 L p
1 g
F P
s
P
p
.002 w
.6611 .54453 m .68631 .48914 L .69152 .47822 L p
1 g
F P
s
P
p
.002 w
.69598 .41615 m .69152 .47822 L .68631 .48914 L p
1 g
F P
s
P
p
.002 w
.69598 .41615 m .67873 .3537 L .67914 .34763 L p
1 g
F P
s
P
p
.002 w
.64353 .29517 m .67914 .34763 L .67873 .3537 L p
1 g
F P
s
P
p
.002 w
.31371 .39269 m .30583 .44463 L .30265 .43403 L p
1 g
F P
s
P
p
.002 w
.30265 .43403 m .31106 .37817 L .31371 .39269 L p
1 g
F P
s
P
p
.002 w
.60902 .59493 m .65067 .55362 L .6611 .54453 L p
1 g
F P
s
P
p
.002 w
.68631 .48914 m .6611 .54453 L .65067 .55362 L p
1 g
F P
s
P
p
.002 w
.64131 .29861 m .58816 .25789 L .59293 .25642 L p
1 g
F P
s
P
p
.002 w
.59293 .25642 m .64353 .29517 L .64131 .29861 L p
1 g
F P
s
P
p
.002 w
.34543 .54613 m .37969 .58186 L .37828 .58576 L p
1 g
F P
s
P
p
.002 w
.37828 .58576 m .34012 .54598 L .34543 .54613 L p
1 g
F P
s
P
p
.002 w
.42594 .61305 m .37828 .58576 L .37969 .58186 L p
1 g
F P
s
P
p
.002 w
.54447 .62239 m .59558 .59921 L .60902 .59493 L p
1 g
F P
s
P
p
.002 w
.65067 .55362 m .60902 .59493 L .59558 .59921 L p
1 g
F P
s
P
p
.002 w
.67873 .3537 m .64131 .29861 L .64353 .29517 L p
1 g
F P
s
P
p
.002 w
.51721 .24261 m .45264 .24281 L .46264 .23683 L p
1 g
F P
s
P
p
.002 w
.46264 .23683 m .526 .23656 L .51721 .24261 L p
1 g
F P
s
P
p
.002 w
.32299 .50256 m .34543 .54613 L .34012 .54598 L p
1 g
F P
s
P
p
.002 w
.34012 .54598 m .31509 .49743 L .32299 .50256 L p
1 g
F P
s
P
p
.002 w
.37969 .58186 m .42248 .60635 L .42594 .61305 L p
1 g
F P
s
P
p
.002 w
.47866 .62512 m .42594 .61305 L .42248 .60635 L p
1 g
F P
s
P
p
.002 w
.47866 .62512 m .53141 .6204 L .54447 .62239 L p
1 g
F P
s
P
p
.002 w
.59558 .59921 m .54447 .62239 L .53141 .6204 L p
1 g
F P
s
P
p
.002 w
.44361 .25448 m .38618 .27554 L .39462 .26421 L p
1 g
F P
s
P
p
.002 w
.39462 .26421 m .45264 .24281 L .44361 .25448 L p
1 g
F P
s
P
p
.002 w
.31476 .45526 m .32299 .50256 L .31509 .49743 L p
1 g
F P
s
P
p
.002 w
.31509 .49743 m .30583 .44463 L .31476 .45526 L p
1 g
F P
s
P
p
.002 w
.38072 .29183 m .33775 .32888 L .34148 .31429 L p
1 g
F P
s
P
p
.002 w
.34148 .31429 m .38618 .27554 L .38072 .29183 L p
1 g
F P
s
P
p
.002 w
.68631 .48914 m .69079 .42593 L .69598 .41615 L p
1 g
F P
s
P
p
.002 w
.67873 .3537 m .69598 .41615 L .69079 .42593 L p
1 g
F P
s
P
p
.002 w
.33861 .34702 m .31371 .39269 L .31106 .37817 L p
1 g
F P
s
P
p
.002 w
.31106 .37817 m .33775 .32888 L .33861 .34702 L p
1 g
F P
s
P
p
.002 w
.42248 .60635 m .46975 .61712 L .47866 .62512 L p
1 g
F P
s
P
p
.002 w
.53141 .6204 m .47866 .62512 L .46975 .61712 L p
1 g
F P
s
P
p
.002 w
.58062 .26443 m .51721 .24261 L .526 .23656 L p
1 g
F P
s
P
p
.002 w
.526 .23656 m .58816 .25789 L .58062 .26443 L p
1 g
F P
s
P
p
.002 w
.65067 .55362 m .67551 .49881 L .68631 .48914 L p
1 g
F P
s
P
p
.002 w
.69079 .42593 m .68631 .48914 L .67551 .49881 L p
1 g
F P
s
P
p
.002 w
.32192 .40889 m .31476 .45526 L .30583 .44463 L p
1 g
F P
s
P
p
.002 w
.30583 .44463 m .31371 .39269 L .32192 .40889 L p
1 g
F P
s
P
p
.002 w
.59558 .59921 m .63547 .5595 L .65067 .55362 L p
1 g
F P
s
P
p
.002 w
.67551 .49881 m .65067 .55362 L .63547 .5595 L p
1 g
F P
s
P
p
.002 w
.69079 .42593 m .67312 .36225 L .67873 .3537 L p
1 g
F P
s
P
p
.002 w
.64131 .29861 m .67873 .3537 L .67312 .36225 L p
1 g
F P
s
P
p
.002 w
.53141 .6204 m .57885 .59878 L .59558 .59921 L p
1 g
F P
s
P
p
.002 w
.63547 .5595 m .59558 .59921 L .57885 .59878 L p
1 g
F P
s
P
p
.002 w
.63488 .30603 m .58062 .26443 L .58816 .25789 L p
1 g
F P
s
P
p
.002 w
.58816 .25789 m .64131 .29861 L .63488 .30603 L p
1 g
F P
s
P
p
.002 w
.50755 .25443 m .44361 .25448 L .45264 .24281 L p
1 g
F P
s
P
p
.002 w
.45264 .24281 m .51721 .24261 L .50755 .25443 L p
1 g
F P
s
P
p
.002 w
.35546 .54292 m .38467 .57338 L .37969 .58186 L p
1 g
F P
s
P
p
.002 w
.37969 .58186 m .34543 .54613 L .35546 .54292 L p
1 g
F P
s
P
p
.002 w
.42248 .60635 m .37969 .58186 L .38467 .57338 L p
1 g
F P
s
P
p
.002 w
.67312 .36225 m .63488 .30603 L .64131 .29861 L p
1 g
F P
s
P
p
.002 w
.3364 .50579 m .35546 .54292 L .34543 .54613 L p
1 g
F P
s
P
p
.002 w
.34543 .54613 m .32299 .50256 L .3364 .50579 L p
1 g
F P
s
P
p
.002 w
.46975 .61712 m .51691 .61281 L .53141 .6204 L p
1 g
F P
s
P
p
.002 w
.57885 .59878 m .53141 .6204 L .51691 .61281 L p
1 g
F P
s
P
p
.002 w
.4359 .27181 m .38072 .29183 L .38618 .27554 L p
1 g
F P
s
P
p
.002 w
.38618 .27554 m .44361 .25448 L .4359 .27181 L p
1 g
F P
s
P
p
.002 w
.38467 .57338 m .42115 .59422 L .42248 .60635 L p
1 g
F P
s
P
p
.002 w
.46975 .61712 m .42248 .60635 L .42115 .59422 L p
1 g
F P
s
P
p
.002 w
.3786 .31283 m .33861 .34702 L .33775 .32888 L p
1 g
F P
s
P
p
.002 w
.33775 .32888 m .38072 .29183 L .3786 .31283 L p
1 g
F P
s
P
p
.002 w
.3295 .46559 m .3364 .50579 L .32299 .50256 L p
1 g
F P
s
P
p
.002 w
.32299 .50256 m .31476 .45526 L .3295 .46559 L p
1 g
F P
s
P
p
.002 w
.67551 .49881 m .6798 .43624 L .69079 .42593 L p
1 g
F P
s
P
p
.002 w
.67312 .36225 m .69079 .42593 L .6798 .43624 L p
1 g
F P
s
P
p
.002 w
.34429 .36828 m .32192 .40889 L .31371 .39269 L p
1 g
F P
s
P
p
.002 w
.31371 .39269 m .33861 .34702 L .34429 .36828 L p
1 g
F P
s
P
p
.002 w
.42115 .59422 m .46137 .60331 L .46975 .61712 L p
1 g
F P
s
P
p
.002 w
.51691 .61281 m .46975 .61712 L .46137 .60331 L p
1 g
F P
s
P
p
.002 w
.57038 .27617 m .50755 .25443 L .51721 .24261 L p
1 g
F P
s
P
p
.002 w
.51721 .24261 m .58062 .26443 L .57038 .27617 L p
1 g
F P
s
P
p
.002 w
.63547 .5595 m .65913 .50685 L .67551 .49881 L p
1 g
F P
s
P
p
.002 w
.6798 .43624 m .67551 .49881 L .65913 .50685 L p
1 g
F P
s
P
p
.002 w
.57885 .59878 m .6157 .56182 L .63547 .5595 L p
1 g
F P
s
P
p
.002 w
.65913 .50685 m .63547 .5595 L .6157 .56182 L p
1 g
F P
s
P
p
.002 w
.33573 .42632 m .3295 .46559 L .31476 .45526 L p
1 g
F P
s
P
p
.002 w
.31476 .45526 m .32192 .40889 L .33573 .42632 L p
1 g
F P
s
P
p
.002 w
.6798 .43624 m .66217 .37317 L .67312 .36225 L p
1 g
F P
s
P
p
.002 w
.63488 .30603 m .67312 .36225 L .66217 .37317 L p
1 g
F P
s
P
p
.002 w
.51691 .61281 m .55916 .59337 L .57885 .59878 L p
1 g
F P
s
P
p
.002 w
.6157 .56182 m .57885 .59878 L .55916 .59337 L p
1 g
F P
s
P
p
.002 w
.4973 .27198 m .4359 .27181 L .44361 .25448 L p
1 g
F P
s
P
p
.002 w
.44361 .25448 m .50755 .25443 L .4973 .27198 L p
1 g
F P
s
P
p
.002 w
.62419 .31745 m .57038 .27617 L .58062 .26443 L p
1 g
F P
s
P
p
.002 w
.58062 .26443 m .63488 .30603 L .62419 .31745 L p
1 g
F P
s
P
p
.002 w
.37021 .53624 m .39327 .56031 L .38467 .57338 L p
1 g
F P
s
P
p
.002 w
.38467 .57338 m .35546 .54292 L .37021 .53624 L p
1 g
F P
s
P
p
.002 w
.42115 .59422 m .38467 .57338 L .39327 .56031 L p
1 g
F P
s
P
p
.002 w
.66217 .37317 m .62419 .31745 L .63488 .30603 L p
1 g
F P
s
P
p
.002 w
.35521 .50691 m .37021 .53624 L .35546 .54292 L p
1 g
F P
s
P
p
.002 w
.35546 .54292 m .3364 .50579 L .35521 .50691 L p
1 g
F P
s
P
p
.002 w
.46137 .60331 m .50137 .59952 L .51691 .61281 L p
1 g
F P
s
P
p
.002 w
.55916 .59337 m .51691 .61281 L .50137 .59952 L p
1 g
F P
s
P
p
.002 w
.42984 .29453 m .3786 .31283 L .38072 .29183 L p
1 g
F P
s
P
p
.002 w
.38072 .29183 m .4359 .27181 L .42984 .29453 L p
1 g
F P
s
P
p
.002 w
.39327 .56031 m .4221 .57674 L .42115 .59422 L p
1 g
F P
s
P
p
.002 w
.46137 .60331 m .42115 .59422 L .4221 .57674 L p
1 g
F P
s
P
p
.002 w
.38006 .33807 m .34429 .36828 L .33861 .34702 L p
1 g
F P
s
P
p
.002 w
.33861 .34702 m .3786 .31283 L .38006 .33807 L p
1 g
F P
s
P
p
.002 w
.34988 .47523 m .35521 .50691 L .3364 .50579 L p
1 g
F P
s
P
p
.002 w
.3364 .50579 m .3295 .46559 L .34988 .47523 L p
1 g
F P
s
P
p
.002 w
.65913 .50685 m .66303 .44677 L .6798 .43624 L p
1 g
F P
s
P
p
.002 w
.66217 .37317 m .6798 .43624 L .66303 .44677 L p
1 g
F P
s
P
p
.004 w
.66989 .42285 m
.69977 .4215 L
s
P
p
.002 w
.35485 .39211 m .33573 .42632 L .32192 .40889 L p
1 g
F P
s
P
p
.002 w
.32192 .40889 m .34429 .36828 L .35485 .39211 L p
1 g
F P
s
P
p
.002 w
.4221 .57674 m .45383 .58382 L .46137 .60331 L p
1 g
F P
s
P
p
.002 w
.50137 .59952 m .46137 .60331 L .45383 .58382 L p
1 g
F P
s
P
p
.002 w
.6157 .56182 m .6374 .5129 L .65913 .50685 L p
1 g
F P
s
P
p
.002 w
.66303 .44677 m .65913 .50685 L .6374 .5129 L p
1 g
F P
s
P
p
.002 w
.55763 .29301 m .4973 .27198 L .50755 .25443 L p
1 g
F P
s
P
p
.002 w
.50755 .25443 m .57038 .27617 L .55763 .29301 L p
1 g
F P
s
P
p
.002 w
.55916 .59337 m .59179 .56028 L .6157 .56182 L p
1 g
F P
s
P
p
.002 w
.6374 .5129 m .6157 .56182 L .59179 .56028 L p
1 g
F P
s
P
p
.002 w
.35495 .44443 m .34988 .47523 L .3295 .46559 L p
1 g
F P
s
P
p
.002 w
.3295 .46559 m .33573 .42632 L .35495 .44443 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50137 .59952 m .53702 .58288 L .55916 .59337 L p
1 g
F P
s
P
p
.002 w
.59179 .56028 m .55916 .59337 L .53702 .58288 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.66303 .44677 m .64592 .38623 L .66217 .37317 L p
1 g
F P
s
P
p
.002 w
.62419 .31745 m .66217 .37317 L .64592 .38623 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.48678 .29494 m .42984 .29453 L .4359 .27181 L p
1 g
F P
s
P
p
.002 w
.4359 .27181 m .4973 .27198 L .48678 .29494 L p
1 g
F P
s
P
p
.002 w
.60934 .33272 m .55763 .29301 L .57038 .27617 L p
1 g
F P
s
P
p
.002 w
.57038 .27617 m .62419 .31745 L .60934 .33272 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.42574 .32209 m .38006 .33807 L .3786 .31283 L p
1 g
F P
s
P
p
.002 w
.3786 .31283 m .42984 .29453 L .42574 .32209 L p
1 g
F P
s
P
p
.002 w
.45383 .58382 m .48526 .5807 L .50137 .59952 L p
1 g
F P
s
P
p
.002 w
.45383 .58382 m .44968 .56774 L p
.46923 .57486 L 1 g
F P
s
P
p
.002 w
.47944 .58128 m .45383 .58382 L p
.46923 .57486 L 1 g
F P
s
P
p
.002 w
.46836 .57431 m .46872 .57265 L p
.46045 .56935 L 1 g
F P
s
P
p
.48921 .57862 m .47798 .5777 L .47997 .5784 L 1 g
F
P
p
.002 w
.48526 .5807 m .47944 .58128 L p
.46923 .57486 L 1 g
F P
s
P
p
.48526 .5807 m .44968 .56774 L .48327 .57956 L 1 g
F
P
p
.002 w
.48904 .58091 m .48921 .57862 L p
.47997 .5784 L 1 g
F P
s
P
p
.002 w
.48487 .58012 m .48526 .5807 L p
.48327 .57956 L 1 g
F P
s
P
p
.47997 .5784 m .48546 .58033 L .48904 .58091 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58091 L p
1 g
F P
s
P
p
.002 w
.50137 .59952 m .48556 .58105 L p
.48865 .58093 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58091 L .50181 .58042 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58006 L p
1 g
F P
s
P
p
.002 w
.53702 .58288 m .52777 .5872 L p
.5 .58269 L 1 g
F P
s
P
p
.53702 .58288 m .5 .58269 L .50471 .58156 L 1 g
F
P
p
.53702 .58288 m .48904 .58091 L .48971 .58088 L 1 g
F
P
p
.53128 .57265 m .5109 .58006 L .52208 .57737 L 1 g
F
P
p
.002 w
.5109 .58006 m .51079 .57862 L p
.50181 .58042 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.53128 .57265 m .52208 .57737 L .52673 .57625 L 1 g
F
P
p
.002 w
.55327 .56618 m .53702 .58288 L .52783 .57696 L p
1 g
F P
s
P
p
.002 w
.52783 .57696 m .52673 .57625 L p
.53166 .57438 L 1 g
F P
s
P
p
.55327 .56618 m .52783 .57696 L .53166 .57438 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .57438 L p
1 g
F P
s
P
p
.54854 .56129 m .53166 .57438 L .5424 .56715 L 1 g
F
P
p
.002 w
.53166 .57438 m .53128 .57265 L p
.52673 .57625 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54905 .56266 m .54854 .56129 L p
.5424 .56715 L 1 g
F P
s
P
p
.002 w
.52673 .57625 m .51311 .56747 L p
.54336 .5665 L 1 g
F P
s
P
p
.55327 .56618 m .53166 .57438 L .54336 .5665 L 1 g
F
P
p
.53166 .57438 m .52673 .57625 L .54336 .5665 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56438 .55476 m .55327 .56618 L p
.54578 .56642 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54905 .56266 L p
1 g
F P
s
P
p
.56075 .54566 m .54905 .56266 L .55537 .55541 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.55361 .55743 m .54578 .56642 L .51311 .56747 L 1 g
F
P
p
.56438 .55476 m .54578 .56642 L .55361 .55743 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.56075 .54566 m .55537 .55541 L .55776 .55267 L 1 g
F
P
p
.002 w
.57814 .52252 m .56438 .55476 L .55964 .55327 L p
1 g
F P
s
P
p
.002 w
.55964 .55327 m .55776 .55267 L p
.56152 .54711 L 1 g
F P
s
P
p
.57814 .52252 m .55964 .55327 L .56152 .54711 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56152 .54711 L p
1 g
F P
s
P
p
.56654 .52734 m .56152 .54711 L .56502 .53565 L 1 g
F
P
p
.002 w
.56152 .54711 m .56075 .54566 L p
.55776 .55267 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56725 .52837 m .56654 .52734 L p
.56502 .53565 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56725 .52837 L p
1 g
F P
s
P
p
.56731 .52815 m .56724 .52833 L .56724 .52819 L 1 g
F
P
p
.57814 .52252 m .56152 .54711 L .56731 .52815 L 1 g
F
P
p
.56515 .50826 m .56725 .52837 L .56683 .51915 L 1 g
F
P
p
.56152 .54711 m .55776 .55267 L .56731 .52815 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.58013 .51785 m .57814 .52252 L p
.53431 .54529 L 1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.56515 .50826 m .56683 .51915 L .56674 .51726 L 1 g
F
P
p
.5821 .47607 m .56807 .5137 L .56446 .49596 L 1 g
F
P
p
.56807 .5137 m .56674 .51726 L .56587 .50912 L 1 g
F
P
p
.56807 .5137 m .56587 .50912 L .56446 .49596 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56587 .50912 L p
1 g
F P
s
P
p
.55661 .4905 m .56587 .50912 L .56058 .49809 L 1 g
F
P
p
.002 w
.56587 .50912 m .56515 .50826 L p
.56674 .51726 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56674 .51726 m .54636 .51637 L p
.56128 .49955 L 1 g
F P
s
P
p
.56446 .49596 m .56587 .50912 L .56128 .49955 L 1 g
F
P
p
.56587 .50912 m .56674 .51726 L .56128 .49955 L 1 g
F
P
p
.002 w
.55727 .4912 m .55661 .4905 L p
.56058 .49809 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54636 .51637 m .54764 .48379 L .54922 .48343 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55727 .4912 L p
1 g
F P
s
P
p
.54174 .47608 m .55727 .4912 L .55116 .48531 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.56342 .49714 m .54636 .51637 L .54922 .48343 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55727 .4912 L p
1 g
F P
s
P
p
.56058 .49809 m .56713 .51061 L .55727 .4912 L 1 g
F
P
p
.002 w
.54922 .48343 m .54764 .48379 L p
.54823 .48247 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47675 L p
1 g
F P
s
P
p
.54008 .47565 m .54764 .48379 L .52581 .46877 L 1 g
F
P
p
.52214 .46667 m .54235 .47675 L .53132 .47142 L 1 g
F
P
p
.002 w
.54683 .48111 m .54764 .48379 L p
.54008 .47565 L 1 g
F P
s
P
p
.54235 .47675 m .54008 .47565 L .52915 .46388 L 1 g
F
P
p
.54683 .48111 m .54008 .47565 L .54235 .47675 L 1 g
F
P
p
.002 w
.54764 .48379 m .5114 .4899 L p
.52581 .46877 L 1 g
F P
s
P
p
.002 w
.52241 .46712 m .52214 .46667 L p
.53132 .47142 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5114 .4899 m .50454 .46769 L .50924 .46536 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46712 L .51237 .46578 L 1 g
F
P
p
.52656 .46768 m .5114 .4899 L .50924 .46536 L 1 g
F
P
p
.5 .4634 m .5133 .46596 L .51306 .46592 L 1 g
F
P
p
.002 w
.50924 .46536 m .50454 .46769 L p
.50539 .46479 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .4634 L p
.51306 .46592 L 1 g
F P
s
P
p
.002 w
.50454 .46769 m .50219 .46432 L p
.50539 .46479 L 1 g
F P
s
P
p
.51306 .46592 m .5224 .46772 L .50219 .46432 L 1 g
F
P
p
.51306 .46592 m .50219 .46432 L .5 .46395 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.49085 .44809 m .51778 .42245 L p
.50539 .46479 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50219 .46432 m .49085 .44809 L p
.50539 .46479 L 1 g
F P
s
P
p
.002 w
.51778 .42245 m .53779 .45121 L .50924 .46536 L p
1 g
F P
s
P
p
.51778 .42245 m .50924 .46536 L .50539 .46479 L 1 g
F
P
p
.002 w
.52282 .46778 m .5224 .46772 L p
.51306 .46592 L 1 g
F P
s
P
p
.5133 .46596 m .52282 .46778 L .51306 .46592 L 1 g
F
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50219 .46432 m .50454 .46769 L p
.49486 .46469 L 1 g
F P
s
P
p
.50219 .46432 m .49486 .46469 L .5 .46395 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.49486 .46469 m .50454 .46769 L .48034 .46677 L 1 g
F
P
p
.002 w
.5 .46395 m .5 .46442 L p
.48886 .46555 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46395 L .48886 .46555 L 1 g
F
P
p
.002 w
.50454 .46769 m .47125 .48296 L p
.48034 .46677 L 1 g
F P
s
P
p
.002 w
.47756 .46717 m .47786 .46667 L p
.48886 .46555 L 1 g
F P
s
P
p
.48349 .46117 m .49486 .46469 L .48034 .46677 L 1 g
F
P
p
.5 .46395 m .49486 .46469 L .48349 .46117 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47125 .48296 m .46463 .47353 L p
.4811 .46543 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44022 .49601 m .4392 .49644 L .4407 .49505 L p
1 g
F P
s
P
p
.002 w
.4392 .49644 m .4465 .48195 L p
.44745 .48151 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4407 .49505 m .4392 .49644 L p
.44133 .49258 L 1 g
F P
s
P
p
.44745 .48151 m .44249 .49146 L .44133 .49258 L 1 g
F
P
p
.44249 .49146 m .4407 .49505 L .44133 .49258 L 1 g
F
P
p
.002 w
.42088 .52133 m .4392 .49644 L .43821 .50024 L p
1 g
F P
s
P
p
.002 w
.44325 .49079 m .44238 .49164 L p
.43485 .50826 L 1 g
F P
s
P
p
.002 w
.44238 .49164 m .44235 .49167 L p
.44215 .49211 L 1 g
F P
s
P
p
.43485 .50826 m .44238 .49164 L .44215 .49211 L 1 g
F
P
p
.43485 .50826 m .44235 .49167 L .44205 .49228 L 1 g
F
P
p
.43485 .50826 m .4423 .49171 L .44196 .49243 L 1 g
F
P
p
.43485 .50826 m .44226 .49176 L .44189 .49251 L 1 g
F
P
p
.43485 .50826 m .44221 .4918 L .44187 .49251 L 1 g
F
P
p
.43485 .50826 m .44217 .49184 L .44191 .4924 L 1 g
F
P
p
.43485 .50826 m .44214 .49187 L .44201 .49215 L 1 g
F
P
p
.43485 .50826 m .44213 .49188 L .43904 .49846 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.47125 .48296 m .47478 .49418 L .44003 .49639 L p
1 g
F P
s
P
p
.002 w
.44003 .49639 m .4392 .49644 L .44022 .49601 L p
1 g
F P
s
P
p
.002 w
.44022 .49601 m .47125 .48296 L p
.44003 .49639 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.47478 .49418 m .47452 .50548 L .43992 .49662 L p
1 g
F P
s
P
p
.002 w
.43992 .49662 m .4392 .49644 L .44003 .49639 L p
1 g
F P
s
P
p
.002 w
.44003 .49639 m .47478 .49418 L p
.43992 .49662 L 1 g
F P
s
P
p
.002 w
.44235 .49167 m .4423 .49171 L p
.44205 .49228 L 1 g
F P
s
P
p
.002 w
.4423 .49171 m .44226 .49176 L p
.44196 .49243 L 1 g
F P
s
P
p
.002 w
.47452 .50548 m .47053 .51563 L .43982 .49682 L p
1 g
F P
s
P
p
.002 w
.43982 .49682 m .4392 .49644 L .43992 .49662 L p
1 g
F P
s
P
p
.002 w
.43992 .49662 m .47452 .50548 L p
.43982 .49682 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.47053 .51563 m .46327 .52353 L .43972 .49703 L p
1 g
F P
s
P
p
.002 w
.43972 .49703 m .4392 .49644 L .43982 .49682 L p
1 g
F P
s
P
p
.002 w
.43982 .49682 m .47053 .51563 L p
.43972 .49703 L 1 g
F P
s
P
p
.002 w
.44226 .49176 m .44221 .4918 L p
.44189 .49251 L 1 g
F P
s
P
p
.002 w
.44221 .4918 m .44217 .49184 L p
.44187 .49251 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.46327 .52353 m .45357 .52834 L .43959 .49731 L p
1 g
F P
s
P
p
.002 w
.43959 .49731 m .4392 .49644 L .43972 .49703 L p
1 g
F P
s
P
p
.002 w
.43972 .49703 m .46327 .52353 L p
.43959 .49731 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.45357 .52834 m .44248 .52959 L .43934 .49784 L p
1 g
F P
s
P
p
.002 w
.43934 .49784 m .4392 .49644 L .43959 .49731 L p
1 g
F P
s
P
p
.002 w
.43959 .49731 m .45357 .52834 L p
.43934 .49784 L 1 g
F P
s
P
p
.002 w
.44217 .49184 m .44214 .49187 L p
.44191 .4924 L 1 g
F P
s
P
p
.002 w
.44214 .49187 m .44213 .49188 L p
.44201 .49215 L 1 g
F P
s
P
p
.002 w
.43821 .50024 m .4392 .49644 L .43934 .49784 L p
1 g
F P
s
P
p
.002 w
.42675 .52465 m .42088 .52133 L p
.4343 .50499 L 1 g
F P
s
P
p
.43392 .50936 m .4343 .50499 L .43821 .50024 L 1 g
F
P
p
.42675 .52465 m .4343 .50499 L .43392 .50936 L 1 g
F
P
p
.43346 .52734 m .43315 .51832 L .43297 .5203 L 1 g
F
P
p
.43346 .52734 m .43297 .5203 L .43236 .52742 L 1 g
F
P
p
.002 w
.43118 .52716 m .43176 .52729 L p
.43232 .5294 L 1 g
F P
s
P
p
.002 w
.43176 .52729 m .43236 .52742 L p
.43233 .52899 L 1 g
F P
s
P
p
.43232 .5294 m .43176 .52729 L .43233 .52899 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43233 .52899 L p
1 g
F P
s
P
p
.43925 .54566 m .43233 .52899 L .43531 .53787 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45073 .56324 m .45146 .56129 L p
.44358 .55445 L 1 g
F P
s
P
p
.44358 .55445 m .44608 .55797 L .45073 .56324 L 1 g
F
P
p
.002 w
.42545 .5542 m .42958 .5347 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.44672 .55887 m .44201 .55784 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.44201 .55784 m .42545 .5542 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.43844 .54719 m .43925 .54566 L p
.43531 .53787 L 1 g
F P
s
P
p
.44608 .55797 m .44768 .55999 L .45073 .56324 L 1 g
F
P
p
.44097 .55218 m .44672 .55887 L .44608 .55797 L 1 g
F
P
p
.44672 .55887 m .44768 .55999 L .44608 .55797 L 1 g
F
P
p
.002 w
.42958 .5347 m .43118 .52716 L p
.43232 .52948 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44743 .55903 m .44672 .55887 L p
.43232 .52948 L 1 g
F P
s
P
p
.43232 .5294 m .43232 .52948 L .43118 .52716 L 1 g
F
P
p
.44743 .55903 m .43232 .52948 L .43232 .5294 L 1 g
F
P
p
.002 w
.4322 .52917 m .43222 .52915 L p
.43236 .52742 L 1 g
F P
s
P
p
.002 w
.43236 .52742 m .43118 .52716 L .43297 .5203 L p
1 g
F P
s
P
p
.43236 .52742 m .43297 .5203 L .43237 .52726 L 1 g
F
P
p
.43236 .52742 m .43237 .52726 L .4322 .52917 L 1 g
F
P
p
.002 w
.43306 .51039 m .43392 .50936 L p
.43931 .49784 L 1 g
F P
s
P
p
.002 w
.43392 .50936 m .43485 .50826 L p
.43904 .49846 L 1 g
F P
s
P
p
.43904 .49846 m .43931 .49784 L .43392 .50936 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43392 .50936 L p
1 g
F P
s
P
p
.002 w
.43118 .52716 m .42675 .52465 L p
.43392 .50936 L 1 g
F P
s
P
p
.002 w
.43297 .5203 m .43118 .52716 L p
.43392 .50936 L 1 g
F P
s
P
p
.002 w
.43392 .50936 m .43287 .51061 L p
.43315 .51832 L 1 g
F P
s
P
p
.43346 .52734 m .43392 .50936 L .43315 .51832 L 1 g
F
P
p
.002 w
.43821 .50024 m .43297 .5203 L p
.43392 .50936 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .4322 .52917 L p
.43251 .52058 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43267 .51349 L p
.43251 .52058 L 1 g
F P
s
P
p
.002 w
.43267 .51349 m .43146 .53025 L p
.43251 .52058 L 1 g
F P
s
P
p
.44672 .55887 m .43213 .53829 L .43232 .52948 L 1 g
F
P
p
.43213 .53829 m .42958 .5347 L .43232 .52948 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43844 .54719 L p
1 g
F P
s
P
p
.43531 .53787 m .43146 .53025 L .43844 .54719 L 1 g
F
P
p
.44358 .55445 m .44097 .55218 L .44608 .55797 L 1 g
F
P
p
.002 w
.42545 .5542 m .44672 .55887 L p
.45383 .58382 L 1 g
F P
s
P
p
.002 w
.44768 .55999 m .45383 .58382 L p
.44672 .55887 L 1 g
F P
s
P
p
.44097 .55218 m .43763 .54927 L .44768 .55999 L 1 g
F
P
p
.002 w
.44672 .55887 m .44743 .55903 L .44768 .55999 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45073 .56324 L p
1 g
F P
s
P
p
.46836 .57431 m .45755 .57051 L .45166 .56382 L 1 g
F
P
p
.002 w
.44968 .56774 m .44768 .55999 L p
.45755 .57051 L 1 g
F P
s
P
p
.46872 .57265 m .45073 .56324 L .46045 .56935 L 1 g
F
P
p
.002 w
.44768 .55999 m .44743 .55903 L p
.45755 .57051 L 1 g
F P
s
P
p
.002 w
.45073 .56324 m .45002 .56518 L p
.46045 .56935 L 1 g
F P
s
P
p
.48327 .57956 m .46836 .57431 L .44743 .55903 L 1 g
F
P
p
.46836 .57431 m .45166 .56382 L .44743 .55903 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45073 .56324 L p
1 g
F P
s
P
p
.43763 .54927 m .43743 .5491 L .45073 .56324 L 1 g
F
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44248 .52959 m .44743 .55903 L p
.43232 .5294 L 1 g
F P
s
P
p
.002 w
.43233 .52899 m .43346 .52734 L p
.43236 .52742 L 1 g
F P
s
P
p
.002 w
.43236 .52742 m .44248 .52959 L p
.43232 .5294 L 1 g
F P
s
P
p
.002 w
.43233 .52899 m .43146 .53025 L p
.43531 .53787 L 1 g
F P
s
P
p
.002 w
.43222 .52915 m .43233 .52899 L p
.43236 .52742 L 1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44248 .52959 m .43236 .52742 L p
.43821 .50024 L 1 g
F P
s
P
p
.002 w
.43297 .5203 m .43821 .50024 L p
.43236 .52742 L 1 g
F P
s
P
p
.43315 .51832 m .43287 .51061 L .4322 .52917 L 1 g
F
P
p
.002 w
.43934 .49784 m .44248 .52959 L p
.43821 .50024 L 1 g
F P
s
P
p
.002 w
.44213 .49188 m .44166 .49233 L p
.43904 .49846 L 1 g
F P
s
P
p
.002 w
.44331 .49066 m .44339 .4905 L p
.44249 .49146 L 1 g
F P
s
P
p
.002 w
.44249 .49146 m .44339 .4905 L p
.45038 .4838 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46302 .47428 m .4407 .49505 L p
.44249 .49146 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45761 .47679 L p
1 g
F P
s
P
p
.44339 .4905 m .45761 .47679 L .45038 .4838 L 1 g
F
P
p
.44745 .48151 m .45761 .47679 L .44249 .49146 L 1 g
F
P
p
.45761 .47679 m .46302 .47428 L .44249 .49146 L 1 g
F
P
p
.002 w
.45761 .47679 m .45698 .47747 L p
.45038 .4838 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44249 .49146 L p
1 g
F P
s
P
p
.45038 .4838 m .45698 .47747 L .44249 .49146 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43301 .51046 L p
1 g
F P
s
P
p
.002 w
.43301 .51046 m .43306 .51039 L p
.43355 .50937 L 1 g
F P
s
P
p
.43355 .50937 m .44166 .49233 L .43301 .51046 L 1 g
F
P
p
.43931 .49784 m .44166 .49233 L .43306 .51039 L 1 g
F
P
p
.002 w
.47125 .48296 m .44022 .49601 L p
.46302 .47428 L 1 g
F P
s
P
p
.002 w
.4407 .49505 m .46302 .47428 L p
.44022 .49601 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47727 .46763 L p
1 g
F P
s
P
p
.45826 .47608 m .47727 .46763 L .47646 .46801 L 1 g
F
P
p
.45826 .47608 m .47726 .46766 L .47382 .46926 L 1 g
F
P
p
.002 w
.46463 .47353 m .47125 .48296 L p
.46302 .47428 L 1 g
F P
s
P
p
.002 w
.4573 .47713 m .45826 .47608 L p
.46914 .47131 L 1 g
F P
s
P
p
.002 w
.46302 .47428 m .46431 .47308 L .46463 .47353 L p
1 g
F P
s
P
p
.002 w
.47727 .46763 m .47726 .46766 L p
.47646 .46801 L 1 g
F P
s
P
p
.002 w
.47726 .46766 m .47718 .46778 L p
.47382 .46926 L 1 g
F P
s
P
p
.002 w
.45472 .46563 m .46431 .47308 L .46302 .47428 L p
1 g
F P
s
P
p
.002 w
.4465 .48195 m .45472 .46563 L p
.46302 .47428 L 1 g
F P
s
P
p
.002 w
.46431 .47308 m .49085 .44809 L p
.4811 .46543 L 1 g
F P
s
P
p
.002 w
.46463 .47353 m .46431 .47308 L p
.4811 .46543 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4573 .47713 L p
1 g
F P
s
P
p
.46914 .47131 m .47718 .46778 L .4573 .47713 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46717 L p
1 g
F P
s
P
p
.48886 .46555 m .5 .46442 L .47756 .46717 L 1 g
F
P
p
.002 w
.5224 .46772 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.002 w
.49085 .44809 m .50219 .46432 L p
.48349 .46117 L 1 g
F P
s
P
p
.002 w
.50924 .46536 m .53779 .45121 L p
.52656 .46768 L 1 g
F P
s
P
p
.002 w
.52241 .46712 m .52282 .46778 L p
.51237 .46578 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52241 .46712 L p
1 g
F P
s
P
p
.53132 .47142 m .54302 .47747 L .52241 .46712 L 1 g
F
P
p
.002 w
.54235 .47675 m .54302 .47747 L p
.53132 .47142 L 1 g
F P
s
P
p
.52915 .46388 m .54008 .47565 L .52581 .46877 L 1 g
F
P
p
.54174 .47608 m .55264 .48675 L .54683 .48111 L 1 g
F
P
p
.002 w
.54235 .47675 m .54174 .47608 L p
.54683 .48111 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53779 .45121 m .54683 .48111 L p
.52915 .46388 L 1 g
F P
s
P
p
.002 w
.54246 .47687 m .54235 .47675 L p
.54683 .48111 L 1 g
F P
s
P
p
.002 w
.54764 .48379 m .53779 .45121 L .56967 .43418 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54246 .47687 L p
1 g
F P
s
P
p
.55264 .48675 m .55834 .49233 L .54246 .47687 L 1 g
F
P
p
.002 w
.56967 .43418 m .5821 .47607 L .54922 .48343 L p
1 g
F P
s
P
p
.56967 .43418 m .54922 .48343 L .54823 .48247 L 1 g
F
P
p
.002 w
.54922 .48343 m .5821 .47607 L p
.56342 .49714 L 1 g
F P
s
P
p
.002 w
.55727 .4912 m .55834 .49233 L p
.55116 .48531 L 1 g
F P
s
P
p
.002 w
.56587 .50912 m .56713 .51061 L p
.56058 .49809 L 1 g
F P
s
P
p
.002 w
.5664 .50975 m .56587 .50912 L p
.56674 .51726 L 1 g
F P
s
P
p
.002 w
.5821 .47607 m .58013 .51785 L .56674 .51726 L p
1 g
F P
s
P
p
.002 w
.53431 .54529 m .54636 .51637 L .56674 .51726 L p
1 g
F P
s
P
p
.002 w
.56674 .51726 m .58013 .51785 L p
.56712 .52564 L 1 g
F P
s
P
p
.56712 .52564 m .53431 .54529 L .56674 .51726 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5664 .50975 L p
1 g
F P
s
P
p
.56683 .51915 m .56854 .53025 L .5664 .50975 L 1 g
F
P
p
.002 w
.56725 .52837 m .56854 .53025 L p
.56683 .51915 L 1 g
F P
s
P
p
.002 w
.55776 .55267 m .53431 .54529 L p
.56724 .52819 L 1 g
F P
s
P
p
.56724 .52833 m .55776 .55267 L .56724 .52819 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56725 .52837 L p
1 g
F P
s
P
p
.56502 .53565 m .56257 .5491 L .56725 .52837 L 1 g
F
P
p
.002 w
.56152 .54711 m .56257 .5491 L p
.56502 .53565 L 1 g
F P
s
P
p
.002 w
.56193 .54788 m .56152 .54711 L p
.55776 .55267 L 1 g
F P
s
P
p
.002 w
.51311 .56747 m .53431 .54529 L .55776 .55267 L p
1 g
F P
s
P
p
.002 w
.55776 .55267 m .56438 .55476 L p
.55361 .55743 L 1 g
F P
s
P
p
.55361 .55743 m .51311 .56747 L .55776 .55267 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56193 .54788 L p
1 g
F P
s
P
p
.55537 .55541 m .54998 .56518 L .56193 .54788 L 1 g
F
P
p
.002 w
.54905 .56266 m .54998 .56518 L p
.55537 .55541 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54905 .56266 L p
1 g
F P
s
P
p
.5424 .56715 m .5322 .57686 L .54905 .56266 L 1 g
F
P
p
.002 w
.53166 .57438 m .5322 .57686 L p
.5424 .56715 L 1 g
F P
s
P
p
.002 w
.5318 .57503 m .53166 .57438 L p
.52673 .57625 L 1 g
F P
s
P
p
.002 w
.48526 .5807 m .51311 .56747 L .52673 .57625 L p
1 g
F P
s
P
p
.002 w
.52673 .57625 m .53702 .58288 L p
.50484 .58152 L 1 g
F P
s
P
p
.50484 .58152 m .48526 .5807 L .52673 .57625 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5318 .57503 L p
1 g
F P
s
P
p
.52208 .57737 m .51111 .583 L .5318 .57503 L 1 g
F
P
p
.002 w
.5109 .58006 m .51111 .583 L p
.52208 .57737 L 1 g
F P
s
P
p
.50471 .58156 m .5 .58269 L .48904 .58091 L 1 g
F
P
p
.48971 .58088 m .48904 .58091 L .48859 .58084 L 1 g
F
P
p
.002 w
.52777 .5872 m .50137 .59952 L p
.48859 .58084 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58006 L p
1 g
F P
s
P
p
.50181 .58042 m .48889 .583 L .5109 .58006 L 1 g
F
P
p
.002 w
.48904 .58091 m .48889 .583 L p
.50181 .58042 L 1 g
F P
s
P
p
.48859 .58084 m .48865 .58093 L .48526 .5807 L 1 g
F
P
p
.002 w
.48556 .58105 m .48526 .5807 L p
.48865 .58093 L 1 g
F P
s
P
p
.002 w
.51311 .56747 m .48589 .5804 L p
.46913 .55674 L 1 g
F P
s
P
p
.002 w
.48589 .5804 m .48526 .5807 L .48487 .58012 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48487 .58012 m .46913 .55674 L p
.48589 .5804 L 1 g
F P
s
P
p
.48487 .58012 m .47247 .57822 L .48546 .58033 L 1 g
F
P
p
.47997 .5784 m .4784 .57836 L .48487 .58012 L 1 g
F
P
p
.4784 .57836 m .47247 .57822 L .48487 .58012 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44743 .55903 m .46913 .55674 L .48487 .58012 L p
1 g
F P
s
P
p
.48327 .57956 m .44743 .55903 L .48487 .58012 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46836 .57431 L p
1 g
F P
s
P
p
.46045 .56935 m .45002 .56518 L .46836 .57431 L 1 g
F
P
p
.002 w
.4678 .57686 m .47247 .57822 L p
.47997 .5784 L 1 g
F P
s
P
p
.47798 .5777 m .4678 .57686 L .47997 .5784 L 1 g
F
P
p
.002 w
.47247 .57822 m .48889 .583 L .48904 .58091 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.38942 .52611 m .40543 .54283 L .39327 .56031 L p
1 g
F P
s
P
p
.004 w
.46481 .46867 m
.5 .43051 L
s
P
p
.002 w
.39327 .56031 m .37021 .53624 L .38942 .52611 L p
1 g
F P
s
P
p
.002 w
.4221 .57674 m .39327 .56031 L .40543 .54283 L p
1 g
F P
s
P
p
.002 w
.64592 .38623 m .60934 .33272 L .62419 .31745 L p
1 g
F P
s
P
p
.002 w
.38521 .36685 m .35485 .39211 L .34429 .36828 L p
1 g
F P
s
P
p
.002 w
.34429 .36828 m .38006 .33807 L .38521 .36685 L p
1 g
F P
s
P
p
.002 w
.37907 .50575 m .38942 .52611 L .37021 .53624 L p
1 g
F P
s
P
p
.002 w
.37021 .53624 m .35521 .50691 L .37907 .50575 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.40543 .54283 m .42545 .5542 L .4221 .57674 L p
1 g
F P
s
P
p
.002 w
.45383 .58382 m .4221 .57674 L .42545 .5542 L p
1 g
F P
s
P
p
.002 w
.37012 .41777 m .35495 .44443 L .33573 .42632 L p
1 g
F P
s
P
p
.002 w
.33573 .42632 m .35485 .39211 L .37012 .41777 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.6374 .5129 m .64075 .45718 L .66303 .44677 L p
1 g
F P
s
P
p
.002 w
.64592 .38623 m .66303 .44677 L .64075 .45718 L p
1 g
F P
s
P
p
.002 w
.37548 .48382 m .37907 .50575 L .35521 .50691 L p
1 g
F P
s
P
p
.002 w
.35521 .50691 m .34988 .47523 L .37548 .48382 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.59179 .56028 m .61081 .51665 L .6374 .5129 L p
1 g
F P
s
P
p
.002 w
.64075 .45718 m .6374 .5129 L .61081 .51665 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.53702 .58288 m .56438 .55476 L .59179 .56028 L p
1 g
F P
s
P
p
.002 w
.61081 .51665 m .59179 .56028 L .56438 .55476 L p
1 g
F P
s
P
p
.002 w
.54269 .31461 m .48678 .29494 L .4973 .27198 L p
1 g
F P
s
P
p
.002 w
.4973 .27198 m .55763 .29301 L .54269 .31461 L p
1 g
F P
s
P
p
.002 w
.37912 .46261 m .37548 .48382 L .34988 .47523 L p
1 g
F P
s
P
p
.002 w
.34988 .47523 m .35495 .44443 L .37912 .46261 L p
1 g
F P
s
P
p
.002 w
.47637 .32273 m .42574 .32209 L .42984 .29453 L p
1 g
F P
s
P
p
.002 w
.42984 .29453 m .48678 .29494 L .47637 .32273 L p
1 g
F P
s
P
p
.002 w
.64075 .45718 m .62467 .40108 L .64592 .38623 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50977 .43007 L
s
P
p
.002 w
.60934 .33272 m .64592 .38623 L .62467 .40108 L p
1 g
F P
s
P
p
.002 w
.42382 .35367 m .38521 .36685 L .38006 .33807 L p
1 g
F P
s
P
p
.002 w
.38006 .33807 m .42574 .32209 L .42382 .35367 L p
1 g
F P
s
P
p
.002 w
.39402 .39824 m .37012 .41777 L .35485 .39211 L p
1 g
F P
s
P
p
.002 w
.35485 .39211 m .38521 .36685 L .39402 .39824 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59065 .35149 m .54269 .31461 L .55763 .29301 L p
1 g
F P
s
P
p
.002 w
.55763 .29301 m .60934 .33272 L .59065 .35149 L p
1 g
F P
s
P
p
.002 w
.41265 .51273 m .42088 .52133 L .40543 .54283 L p
1 g
F P
s
P
p
.002 w
.40543 .54283 m .38942 .52611 L .41265 .51273 L p
1 g
F P
s
P
p
.002 w
.42545 .5542 m .40543 .54283 L .42088 .52133 L p
1 g
F P
s
P
p
.002 w
.62467 .40108 m .59065 .35149 L .60934 .33272 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.40736 .50225 m .41265 .51273 L .38942 .52611 L p
1 g
F P
s
P
p
.002 w
.38942 .52611 m .37907 .50575 L .40736 .50225 L p
1 g
F P
s
P
p
.002 w
.38972 .44437 m .37912 .46261 L .35495 .44443 L p
1 g
F P
s
P
p
.002 w
.35495 .44443 m .37012 .41777 L .38972 .44437 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.42088 .52133 m .43118 .52716 L .42545 .5542 L p
1 g
F P
s
P
p
.002 w
.61081 .51665 m .6135 .46708 L .64075 .45718 L p
1 g
F P
s
P
p
.002 w
.62467 .40108 m .64075 .45718 L .6135 .46708 L p
1 g
F P
s
P
p
.004 w
.52268 .42949 m
.62061 .42507 L
s
P
p
.004 w
.63951 .42422 m
.66989 .42285 L
s
P
p
.002 w
.40558 .491 m .40736 .50225 L .37907 .50575 L p
1 g
F P
s
P
p
.002 w
.37907 .50575 m .37548 .48382 L .40558 .491 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.56438 .55476 m .58013 .51785 L .61081 .51665 L p
1 g
F P
s
P
p
.002 w
.6135 .46708 m .61081 .51665 L .58013 .51785 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46913 .55674 m .44743 .55903 L .44248 .52959 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46913 .55674 m .48823 .54748 L .51311 .56747 L p
1 g
F P
s
P
p
.002 w
.53431 .54529 m .51311 .56747 L .48823 .54748 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.52602 .34038 m .47637 .32273 L .48678 .29494 L p
1 g
F P
s
P
p
.002 w
.48678 .29494 m .54269 .31461 L .52602 .34038 L p
1 g
F P
s
P
p
.002 w
.40753 .48017 m .40558 .491 L .37548 .48382 L p
1 g
F P
s
P
p
.002 w
.37548 .48382 m .37912 .46261 L .40753 .48017 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.46646 .35447 m .42382 .35367 L .42574 .32209 L p
1 g
F P
s
P
p
.002 w
.42574 .32209 m .47637 .32273 L .46646 .35447 L p
1 g
F P
s
P
p
.002 w
.42423 .38822 m .39402 .39824 L .38521 .36685 L p
1 g
F P
s
P
p
.002 w
.38521 .36685 m .42382 .35367 L .42423 .38822 L p
1 g
F P
s
P
p
.002 w
.40625 .43113 m .38972 .44437 L .37012 .41777 L p
1 g
F P
s
P
p
.002 w
.37012 .41777 m .39402 .39824 L .40625 .43113 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44248 .52959 m .45357 .52834 L .46913 .55674 L p
1 g
F P
s
P
p
.002 w
.48823 .54748 m .46913 .55674 L .45357 .52834 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.6135 .46708 m .59898 .41726 L .62467 .40108 L p
1 g
F P
s
P
p
.004 w
.6246 .42489 m
.63951 .42422 L
s
P
p
.004 w
.62359 .42494 m
.6246 .42489 L
s
P
p
.002 w
.59065 .35149 m .62467 .40108 L .59898 .41726 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41302 .47093 m .40753 .48017 L .37912 .46261 L p
1 g
F P
s
P
p
.002 w
.37912 .46261 m .38972 .44437 L .41302 .47093 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.56864 .37321 m .52602 .34038 L .54269 .31461 L p
1 g
F P
s
P
p
.002 w
.54269 .31461 m .59065 .35149 L .56864 .37321 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42088 .52133 m .41265 .51273 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.59898 .41726 m .56864 .37321 L .59065 .35149 L p
1 g
F P
s
P
p
.002 w
.41265 .51273 m .40736 .50225 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.48823 .54748 m .50264 .53211 L .53431 .54529 L p
1 g
F P
s
P
p
.002 w
.54636 .51637 m .53431 .54529 L .50264 .53211 L p
1 g
F P
s
P
p
.002 w
.58013 .51785 m .5821 .47607 L .6135 .46708 L p
1 g
F P
s
P
p
.002 w
.59898 .41726 m .6135 .46708 L .5821 .47607 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45357 .52834 m .46327 .52353 L .48823 .54748 L p
1 g
F P
s
P
p
.002 w
.50264 .53211 m .48823 .54748 L .46327 .52353 L p
1 g
F P
s
P
p
.002 w
.40736 .50225 m .40558 .491 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.40558 .491 m .40753 .48017 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.4215 .46429 m .41302 .47093 L .38972 .44437 L p
1 g
F P
s
P
p
.002 w
.38972 .44437 m .40625 .43113 L .4215 .46429 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.427 .42446 m .40625 .43113 L .39402 .39824 L p
1 g
F P
s
P
p
.002 w
.39402 .39824 m .42423 .38822 L .427 .42446 L p
1 g
F P
s
P
p
.002 w
.50821 .3695 m .46646 .35447 L .47637 .32273 L p
1 g
F P
s
P
p
.002 w
.47637 .32273 m .52602 .34038 L .50821 .3695 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45745 .38907 m .42423 .38822 L .42382 .35367 L p
1 g
F P
s
P
p
.002 w
.42382 .35367 m .46646 .35447 L .45745 .38907 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.40753 .48017 m .41302 .47093 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.46327 .52353 m .47053 .51563 L .50264 .53211 L p
1 g
F P
s
P
p
.002 w
.5107 .51221 m .50264 .53211 L .47053 .51563 L p
1 g
F P
s
P
p
.002 w
.50264 .53211 m .5107 .51221 L .54636 .51637 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5821 .47607 m .56967 .43418 L .59898 .41726 L p
1 g
F P
s
P
p
.002 w
.56864 .37321 m .59898 .41726 L .56967 .43418 L p
1 g
F P
s
P
p
.002 w
.41302 .47093 m .4215 .46429 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.44355 .46146 m .45472 .46563 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.43206 .461 m .44355 .46146 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.4215 .46429 m .43206 .461 L .4392 .49644 L closepath p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54764 .48379 m .54636 .51637 L .5107 .51221 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54405 .39716 m .50821 .3695 L .52602 .34038 L p
1 g
F P
s
P
p
.002 w
.52602 .34038 m .56864 .37321 L .54405 .39716 L p
1 g
F P
s
P
p
.002 w
.43206 .461 m .4215 .46429 L .40625 .43113 L p
1 g
F P
s
P
p
.002 w
.40625 .43113 m .427 .42446 L .43206 .461 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47053 .51563 m .47452 .50548 L .5107 .51221 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56967 .43418 m .54405 .39716 L .56864 .37321 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.44972 .4252 m .427 .42446 L .42423 .38822 L p
1 g
F P
s
P
p
.002 w
.42423 .38822 m .45745 .38907 L .44972 .4252 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48991 .4009 m .45745 .38907 L .46646 .35447 L p
1 g
F P
s
P
p
.002 w
.46646 .35447 m .50821 .3695 L .48991 .4009 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.5114 .4899 m .5107 .51221 L .47452 .50548 L p
1 g
F P
s
P
p
.002 w
.5107 .51221 m .5114 .4899 L .54764 .48379 L p
1 g
F P
s
P
p
.002 w
.47452 .50548 m .47478 .49418 L .5114 .4899 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.44355 .46146 m .43206 .461 L .427 .42446 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.427 .42446 m .44972 .4252 L .44355 .46146 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54405 .39716 m .56967 .43418 L .53779 .45121 L p
1 g
F P
s
P
p
.002 w
.47478 .49418 m .47125 .48296 L .50454 .46769 L p
1 g
F P
s
P
p
.002 w
.50454 .46769 m .5114 .4899 L .47478 .49418 L p
1 g
F P
s
P
p
.002 w
.45472 .46563 m .44355 .46146 L .44972 .4252 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.51778 .42245 m .48991 .4009 L .50821 .3695 L p
1 g
F P
s
P
p
.002 w
.50821 .3695 m .54405 .39716 L .51778 .42245 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.47184 .43337 m .44972 .4252 L .45745 .38907 L p
1 g
F P
s
P
p
.002 w
.45745 .38907 m .48991 .4009 L .47184 .43337 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.46431 .47308 m .45472 .46563 L .47184 .43337 L p
1 g
F P
s
P
p
.002 w
.44972 .4252 m .47184 .43337 L .45472 .46563 L p
1 g
F P
s
P
p
.002 w
.47184 .43337 m .49085 .44809 L .46431 .47308 L p
1 g
F P
s
P
p
.002 w
.53779 .45121 m .51778 .42245 L .54405 .39716 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.49085 .44809 m .47184 .43337 L .48991 .4009 L p
1 g
F P
s
P
p
.002 w
.48991 .4009 m .51778 .42245 L .49085 .44809 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.4021 .53667 m
.41991 .51736 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .69977 .4215 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4021 .53667 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.293023)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.293023)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45179 .43655 m .46788 .45844 L .48771 .43822 L p
1 g
F P
s
P
p
.002 w
.48771 .43822 m .47678 .42332 L .45179 .43655 L p
1 g
F P
s
P
p
.002 w
.50277 .44894 m .48771 .43822 L .46788 .45844 L p
1 g
F P
s
P
p
.002 w
.47678 .42332 m .48771 .43822 L .50777 .41787 L p
1 g
F P
s
P
p
.002 w
.48771 .43822 m .50277 .44894 L .51541 .4233 L p
1 g
F P
s
P
p
.002 w
.51541 .4233 m .50777 .41787 L .48771 .43822 L p
1 g
F P
s
P
p
.002 w
.50777 .41787 m .50224 .41032 L .47678 .42332 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .50224 .41032 L .50777 .41787 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .50777 .41787 L .51541 .4233 L closepath p
1 g
F P
s
P
p
.002 w
.52434 .42602 m .51541 .4233 L .50277 .44894 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .51541 .4233 L .52434 .42602 L closepath p
1 g
F P
s
P
p
.002 w
.46788 .45844 m .49003 .47421 L .50277 .44894 L p
1 g
F P
s
P
p
.002 w
.5204 .45434 m .50277 .44894 L .49003 .47421 L p
1 g
F P
s
P
p
.002 w
.50277 .44894 m .5204 .45434 L .52434 .42602 L p
1 g
F P
s
P
p
.002 w
.47117 .40581 m .47678 .42332 L .50224 .41032 L p
1 g
F P
s
P
p
.002 w
.50224 .41032 m .49942 .40144 L .47117 .40581 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .49942 .40144 L .50224 .41032 L closepath p
1 g
F P
s
P
p
.002 w
.44347 .4108 m .45179 .43655 L .47678 .42332 L p
1 g
F P
s
P
p
.002 w
.47678 .42332 m .47117 .40581 L .44347 .4108 L p
1 g
F P
s
P
p
.002 w
.53362 .42574 m .52434 .42602 L .5204 .45434 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .52434 .42602 L .53362 .42574 L closepath p
1 g
F P
s
P
p
.002 w
.47149 .38753 m .47117 .40581 L .49942 .40144 L p
1 g
F P
s
P
p
.002 w
.49942 .40144 m .49961 .39219 L .47149 .38753 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .49961 .39219 L .49942 .40144 L closepath p
1 g
F P
s
P
p
.002 w
.49003 .47421 m .51594 .48221 L .5204 .45434 L p
1 g
F P
s
P
p
.002 w
.53873 .45384 m .5204 .45434 L .51594 .48221 L p
1 g
F P
s
P
p
.002 w
.5204 .45434 m .53873 .45384 L .53362 .42574 L p
1 g
F P
s
P
p
.002 w
.54225 .42247 m .53362 .42574 L .53873 .45384 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .53362 .42574 L .54225 .42247 L closepath p
1 g
F P
s
P
p
.002 w
.44384 .38387 m .44347 .4108 L .47117 .40581 L p
1 g
F P
s
P
p
.002 w
.47117 .40581 m .47149 .38753 L .44384 .38387 L p
1 g
F P
s
P
p
.002 w
.47775 .37042 m .47149 .38753 L .49961 .39219 L p
1 g
F P
s
P
p
.002 w
.49961 .39219 m .50282 .38356 L .47775 .37042 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .50282 .38356 L .49961 .39219 L closepath p
1 g
F P
s
P
p
.002 w
.42772 .44977 m .44865 .47818 L .46788 .45844 L p
1 g
F P
s
P
p
.002 w
.46788 .45844 m .45179 .43655 L .42772 .44977 L p
1 g
F P
s
P
p
.002 w
.49003 .47421 m .46788 .45844 L .44865 .47818 L p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .55449 .39028 L .55025 .38187 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .55025 .38187 L .54352 .37522 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .54352 .37522 L .53503 .37107 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .53503 .37107 L .52572 .36987 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .52572 .36987 L .51661 .37175 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .51661 .37175 L .50869 .37649 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .50869 .37649 L .50282 .38356 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .54225 .42247 L .54928 .41656 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .54928 .41656 L .55396 .40863 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .55396 .40863 L .55577 .39954 L closepath p
1 g
F P
s
P
p
.002 w
.5277 .39777 m .55577 .39954 L .55449 .39028 L closepath p
1 g
F P
s
P
p
.002 w
.53873 .45384 m .55581 .44744 L .54225 .42247 L p
1 g
F P
s
P
p
.002 w
.54928 .41656 m .54225 .42247 L .55581 .44744 L p
1 g
F P
s
P
p
.002 w
.44865 .47818 m .47741 .49867 L .49003 .47421 L p
1 g
F P
s
P
p
.002 w
.51594 .48221 m .49003 .47421 L .47741 .49867 L p
1 g
F P
s
P
p
.002 w
.51594 .48221 m .54293 .48155 L .53873 .45384 L p
1 g
F P
s
P
p
.002 w
.55581 .44744 m .53873 .45384 L .54293 .48155 L p
1 g
F P
s
P
p
.002 w
.48932 .35636 m .47775 .37042 L .50282 .38356 L p
1 g
F P
s
P
p
.002 w
.50282 .38356 m .50869 .37649 L .48932 .35636 L p
1 g
F P
s
P
p
.002 w
.41683 .41633 m .42772 .44977 L .45179 .43655 L p
1 g
F P
s
P
p
.002 w
.45179 .43655 m .44347 .4108 L .41683 .41633 L p
1 g
F P
s
P
p
.002 w
.55581 .44744 m .5698 .4358 L .54928 .41656 L p
1 g
F P
s
P
p
.002 w
.55396 .40863 m .54928 .41656 L .5698 .4358 L p
1 g
F P
s
P
p
.002 w
.45295 .35862 m .44384 .38387 L .47149 .38753 L p
1 g
F P
s
P
p
.002 w
.47149 .38753 m .47775 .37042 L .45295 .35862 L p
1 g
F P
s
P
p
.002 w
.47741 .49867 m .51105 .50912 L .51594 .48221 L p
1 g
F P
s
P
p
.002 w
.54293 .48155 m .51594 .48221 L .51105 .50912 L p
1 g
F P
s
P
p
.002 w
.50499 .34689 m .48932 .35636 L .50869 .37649 L p
1 g
F P
s
P
p
.002 w
.50869 .37649 m .51661 .37175 L .50499 .34689 L p
1 g
F P
s
P
p
.002 w
.5698 .4358 m .57915 .42013 L .55396 .40863 L p
1 g
F P
s
P
p
.002 w
.55577 .39954 m .55396 .40863 L .57915 .42013 L p
1 g
F P
s
P
p
.002 w
.54293 .48155 m .56814 .47223 L .55581 .44744 L p
1 g
F P
s
P
p
.002 w
.5698 .4358 m .55581 .44744 L .56814 .47223 L p
1 g
F P
s
P
p
.002 w
.41718 .38132 m .41683 .41633 L .44347 .4108 L p
1 g
F P
s
P
p
.002 w
.44347 .4108 m .44384 .38387 L .41718 .38132 L p
1 g
F P
s
P
p
.002 w
.52308 .34309 m .50499 .34689 L .51661 .37175 L p
1 g
F P
s
P
p
.002 w
.51661 .37175 m .52572 .36987 L .52308 .34309 L p
1 g
F P
s
P
p
.002 w
.57915 .42013 m .5828 .40209 L .55577 .39954 L p
1 g
F P
s
P
p
.002 w
.55449 .39028 m .55577 .39954 L .5828 .40209 L p
1 g
F P
s
P
p
.002 w
.46994 .33778 m .45295 .35862 L .47775 .37042 L p
1 g
F P
s
P
p
.002 w
.47775 .37042 m .48932 .35636 L .46994 .33778 L p
1 g
F P
s
P
p
.002 w
.54161 .34543 m .52308 .34309 L .52572 .36987 L p
1 g
F P
s
P
p
.002 w
.52572 .36987 m .53503 .37107 L .54161 .34543 L p
1 g
F P
s
P
p
.002 w
.51105 .50912 m .54613 .50837 L .54293 .48155 L p
1 g
F P
s
P
p
.002 w
.56814 .47223 m .54293 .48155 L .54613 .50837 L p
1 g
F P
s
P
p
.002 w
.55025 .38187 m .55449 .39028 L .58031 .38368 L p
1 g
F P
s
P
p
.002 w
.5828 .40209 m .58031 .38368 L .55449 .39028 L p
1 g
F P
s
P
p
.002 w
.55851 .35367 m .54161 .34543 L .53503 .37107 L p
1 g
F P
s
P
p
.002 w
.53503 .37107 m .54352 .37522 L .55851 .35367 L p
1 g
F P
s
P
p
.002 w
.58031 .38368 m .57191 .36691 L .55025 .38187 L p
1 g
F P
s
P
p
.002 w
.54352 .37522 m .55025 .38187 L .57191 .36691 L p
1 g
F P
s
P
p
.002 w
.56814 .47223 m .58885 .45515 L .5698 .4358 L p
1 g
F P
s
P
p
.002 w
.57915 .42013 m .5698 .4358 L .58885 .45515 L p
1 g
F P
s
P
p
.002 w
.40504 .46272 m .43038 .49705 L .44865 .47818 L p
1 g
F P
s
P
p
.002 w
.44865 .47818 m .42772 .44977 L .40504 .46272 L p
1 g
F P
s
P
p
.002 w
.47741 .49867 m .44865 .47818 L .43038 .49705 L p
1 g
F P
s
P
p
.002 w
.57191 .36691 m .55851 .35367 L .54352 .37522 L p
1 g
F P
s
P
p
.002 w
.43038 .49705 m .46514 .52184 L .47741 .49867 L p
1 g
F P
s
P
p
.002 w
.51105 .50912 m .47741 .49867 L .46514 .52184 L p
1 g
F P
s
P
p
.002 w
.42891 .3484 m .41718 .38132 L .44384 .38387 L p
1 g
F P
s
P
p
.002 w
.44384 .38387 m .45295 .35862 L .42891 .3484 L p
1 g
F P
s
P
p
.002 w
.39177 .42232 m .40504 .46272 L .42772 .44977 L p
1 g
F P
s
P
p
.002 w
.42772 .44977 m .41683 .41633 L .39177 .42232 L p
1 g
F P
s
P
p
.002 w
.49306 .32368 m .46994 .33778 L .48932 .35636 L p
1 g
F P
s
P
p
.002 w
.48932 .35636 m .50499 .34689 L .49306 .32368 L p
1 g
F P
s
P
p
.002 w
.46514 .52184 m .5058 .53454 L .51105 .50912 L p
1 g
F P
s
P
p
.002 w
.54613 .50837 m .51105 .50912 L .5058 .53454 L p
1 g
F P
s
P
p
.002 w
.58885 .45515 m .60277 .43205 L .57915 .42013 L p
1 g
F P
s
P
p
.002 w
.5828 .40209 m .57915 .42013 L .60277 .43205 L p
1 g
F P
s
P
p
.002 w
.54613 .50837 m .57897 .49638 L .56814 .47223 L p
1 g
F P
s
P
p
.002 w
.58885 .45515 m .56814 .47223 L .57897 .49638 L p
1 g
F P
s
P
p
.002 w
.51982 .31797 m .49306 .32368 L .50499 .34689 L p
1 g
F P
s
P
p
.002 w
.50499 .34689 m .52308 .34309 L .51982 .31797 L p
1 g
F P
s
P
p
.002 w
.39206 .37993 m .39177 .42232 L .41683 .41633 L p
1 g
F P
s
P
p
.002 w
.41683 .41633 m .41718 .38132 L .39206 .37993 L p
1 g
F P
s
P
p
.002 w
.45094 .32114 m .42891 .3484 L .45295 .35862 L p
1 g
F P
s
P
p
.002 w
.45295 .35862 m .46994 .33778 L .45094 .32114 L p
1 g
F P
s
P
p
.002 w
.60277 .43205 m .60828 .4054 L .5828 .40209 L p
1 g
F P
s
P
p
.002 w
.58031 .38368 m .5828 .40209 L .60828 .4054 L p
1 g
F P
s
P
p
.002 w
.54729 .32137 m .51982 .31797 L .52308 .34309 L p
1 g
F P
s
P
p
.002 w
.52308 .34309 m .54161 .34543 L .54729 .32137 L p
1 g
F P
s
P
p
.002 w
.5058 .53454 m .54825 .53376 L .54613 .50837 L p
1 g
F P
s
P
p
.002 w
.57897 .49638 m .54613 .50837 L .54825 .53376 L p
1 g
F P
s
P
p
.002 w
.57897 .49638 m .60605 .47424 L .58885 .45515 L p
1 g
F P
s
P
p
.002 w
.60277 .43205 m .58885 .45515 L .60605 .47424 L p
1 g
F P
s
P
p
.002 w
.57191 .36691 m .58031 .38368 L .60466 .3781 L p
1 g
F P
s
P
p
.002 w
.60828 .4054 m .60466 .3781 L .58031 .38368 L p
1 g
F P
s
P
p
.002 w
.57237 .33357 m .54729 .32137 L .54161 .34543 L p
1 g
F P
s
P
p
.002 w
.54161 .34543 m .55851 .35367 L .57237 .33357 L p
1 g
F P
s
P
p
.002 w
.60466 .3781 m .59224 .35322 L .57191 .36691 L p
1 g
F P
s
P
p
.002 w
.55851 .35367 m .57191 .36691 L .59224 .35322 L p
1 g
F P
s
P
p
.002 w
.38423 .47516 m .41345 .51467 L .43038 .49705 L p
1 g
F P
s
P
p
.002 w
.43038 .49705 m .40504 .46272 L .38423 .47516 L p
1 g
F P
s
P
p
.002 w
.46514 .52184 m .43038 .49705 L .41345 .51467 L p
1 g
F P
s
P
p
.002 w
.40611 .34 m .39206 .37993 L .41718 .38132 L p
1 g
F P
s
P
p
.002 w
.41718 .38132 m .42891 .3484 L .40611 .34 L p
1 g
F P
s
P
p
.002 w
.59224 .35322 m .57237 .33357 L .55851 .35367 L p
1 g
F P
s
P
p
.002 w
.48103 .30262 m .45094 .32114 L .46994 .33778 L p
1 g
F P
s
P
p
.002 w
.46994 .33778 m .49306 .32368 L .48103 .30262 L p
1 g
F P
s
P
p
.002 w
.41345 .51467 m .45347 .54324 L .46514 .52184 L p
1 g
F P
s
P
p
.002 w
.5058 .53454 m .46514 .52184 L .45347 .54324 L p
1 g
F P
s
P
p
.002 w
.36883 .42864 m .38423 .47516 L .40504 .46272 L p
1 g
F P
s
P
p
.002 w
.40504 .46272 m .39177 .42232 L .36883 .42864 L p
1 g
F P
s
P
p
.002 w
.60605 .47424 m .62433 .44419 L .60277 .43205 L p
1 g
F P
s
P
p
.002 w
.60828 .4054 m .60277 .43205 L .62433 .44419 L p
1 g
F P
s
P
p
.002 w
.54825 .53376 m .58807 .51939 L .57897 .49638 L p
1 g
F P
s
P
p
.002 w
.60605 .47424 m .57897 .49638 L .58807 .51939 L p
1 g
F P
s
P
p
.002 w
.45347 .54324 m .50029 .55795 L .5058 .53454 L p
1 g
F P
s
P
p
.002 w
.54825 .53376 m .5058 .53454 L .50029 .55795 L p
1 g
F P
s
P
p
.002 w
.51598 .29505 m .48103 .30262 L .49306 .32368 L p
1 g
F P
s
P
p
.002 w
.49306 .32368 m .51982 .31797 L .51598 .29505 L p
1 g
F P
s
P
p
.002 w
.36902 .37979 m .36883 .42864 L .39177 .42232 L p
1 g
F P
s
P
p
.002 w
.39177 .42232 m .39206 .37993 L .36902 .37979 L p
1 g
F P
s
P
p
.002 w
.43269 .30684 m .40611 .34 L .42891 .3484 L p
1 g
F P
s
P
p
.002 w
.42891 .3484 m .45094 .32114 L .43269 .30684 L p
1 g
F P
s
P
p
.002 w
.62433 .44419 m .63165 .40941 L .60828 .4054 L p
1 g
F P
s
P
p
.002 w
.60466 .3781 m .60828 .4054 L .63165 .40941 L p
1 g
F P
s
P
p
.002 w
.50029 .55795 m .5492 .55718 L .54825 .53376 L p
1 g
F P
s
P
p
.002 w
.58807 .51939 m .54825 .53376 L .5492 .55718 L p
1 g
F P
s
P
p
.002 w
.55193 .29943 m .51598 .29505 L .51982 .31797 L p
1 g
F P
s
P
p
.002 w
.51982 .31797 m .54729 .32137 L .55193 .29943 L p
1 g
F P
s
P
p
.002 w
.58807 .51939 m .621 .49269 L .60605 .47424 L p
1 g
F P
s
P
p
.002 w
.62433 .44419 m .60605 .47424 L .621 .49269 L p
1 g
F P
s
P
p
.002 w
.63165 .40941 m .62701 .3737 L .60466 .3781 L p
1 g
F P
s
P
p
.002 w
.59224 .35322 m .60466 .3781 L .62701 .3737 L p
1 g
F P
s
P
p
.002 w
.58479 .31537 m .55193 .29943 L .54729 .32137 L p
1 g
F P
s
P
p
.002 w
.54729 .32137 m .57237 .33357 L .58479 .31537 L p
1 g
F P
s
P
p
.002 w
.38506 .33367 m .36902 .37979 L .39206 .37993 L p
1 g
F P
s
P
p
.002 w
.39206 .37993 m .40611 .34 L .38506 .33367 L p
1 g
F P
s
P
p
.002 w
.46915 .28423 m .43269 .30684 L .45094 .32114 L p
1 g
F P
s
P
p
.002 w
.45094 .32114 m .48103 .30262 L .46915 .28423 L p
1 g
F P
s
P
p
.002 w
.62701 .3737 m .6108 .34111 L .59224 .35322 L p
1 g
F P
s
P
p
.002 w
.57237 .33357 m .59224 .35322 L .6108 .34111 L p
1 g
F P
s
P
p
.002 w
.36576 .48682 m .39824 .53065 L .41345 .51467 L p
1 g
F P
s
P
p
.002 w
.41345 .51467 m .38423 .47516 L .36576 .48682 L p
1 g
F P
s
P
p
.002 w
.45347 .54324 m .41345 .51467 L .39824 .53065 L p
1 g
F P
s
P
p
.002 w
.6108 .34111 m .58479 .31537 L .57237 .33357 L p
1 g
F P
s
P
p
.002 w
.39824 .53065 m .44266 .56237 L .45347 .54324 L p
1 g
F P
s
P
p
.002 w
.50029 .55795 m .45347 .54324 L .44266 .56237 L p
1 g
F P
s
P
p
.002 w
.34857 .4352 m .36576 .48682 L .38423 .47516 L p
1 g
F P
s
P
p
.002 w
.38423 .47516 m .36883 .42864 L .34857 .4352 L p
1 g
F P
s
P
p
.002 w
.621 .49269 m .64332 .45631 L .62433 .44419 L p
1 g
F P
s
P
p
.002 w
.63165 .40941 m .62433 .44419 L .64332 .45631 L p
1 g
F P
s
P
p
.002 w
.5492 .55718 m .59518 .54076 L .58807 .51939 L p
1 g
F P
s
P
p
.002 w
.621 .49269 m .58807 .51939 L .59518 .54076 L p
1 g
F P
s
P
p
.002 w
.44266 .56237 m .49462 .57878 L .50029 .55795 L p
1 g
F P
s
P
p
.002 w
.5492 .55718 m .50029 .55795 L .49462 .57878 L p
1 g
F P
s
P
p
.002 w
.51162 .2749 m .46915 .28423 L .48103 .30262 L p
1 g
F P
s
P
p
.002 w
.48103 .30262 m .51598 .29505 L .51162 .2749 L p
1 g
F P
s
P
p
.002 w
.41562 .29527 m .38506 .33367 L .40611 .34 L p
1 g
F P
s
P
p
.002 w
.40611 .34 m .43269 .30684 L .41562 .29527 L p
1 g
F P
s
P
p
.002 w
.34863 .38094 m .34857 .4352 L .36883 .42864 L p
1 g
F P
s
P
p
.002 w
.36883 .42864 m .36902 .37979 L .34863 .38094 L p
1 g
F P
s
P
p
.002 w
.64332 .45631 m .65234 .41407 L .63165 .40941 L p
1 g
F P
s
P
p
.002 w
.62701 .3737 m .63165 .40941 L .65234 .41407 L p
1 g
F P
s
P
p
.002 w
.49462 .57878 m .54893 .57806 L .5492 .55718 L p
1 g
F P
s
P
p
.002 w
.59518 .54076 m .5492 .55718 L .54893 .57806 L p
1 g
F P
s
P
p
.002 w
.59518 .54076 m .63329 .51009 L .621 .49269 L p
1 g
F P
s
P
p
.002 w
.64332 .45631 m .621 .49269 L .63329 .51009 L p
1 g
F P
s
P
p
.002 w
.55538 .28015 m .51162 .2749 L .51598 .29505 L p
1 g
F P
s
P
p
.002 w
.51598 .29505 m .55193 .29943 L .55538 .28015 L p
1 g
F P
s
P
p
.002 w
.6108 .34111 m .62701 .3737 L .64679 .37062 L p
1 g
F P
s
P
p
.002 w
.65234 .41407 m .64679 .37062 L .62701 .3737 L p
1 g
F P
s
P
p
.002 w
.36631 .32963 m .34863 .38094 L .36902 .37979 L p
1 g
F P
s
P
p
.002 w
.36902 .37979 m .38506 .33367 L .36631 .32963 L p
1 g
F P
s
P
p
.002 w
.45768 .26901 m .41562 .29527 L .43269 .30684 L p
1 g
F P
s
P
p
.002 w
.43269 .30684 m .46915 .28423 L .45768 .26901 L p
1 g
F P
s
P
p
.002 w
.59542 .29954 m .55538 .28015 L .55193 .29943 L p
1 g
F P
s
P
p
.002 w
.55193 .29943 m .58479 .31537 L .59542 .29954 L p
1 g
F P
s
P
p
.002 w
.64679 .37062 m .6271 .33091 L .6108 .34111 L p
1 g
F P
s
P
p
.002 w
.58479 .31537 m .6108 .34111 L .6271 .33091 L p
1 g
F P
s
P
p
.002 w
.35015 .4974 m .38516 .54457 L .39824 .53065 L p
1 g
F P
s
P
p
.002 w
.39824 .53065 m .36576 .48682 L .35015 .4974 L p
1 g
F P
s
P
p
.002 w
.44266 .56237 m .39824 .53065 L .38516 .54457 L p
1 g
F P
s
P
p
.002 w
.6271 .33091 m .59542 .29954 L .58479 .31537 L p
1 g
F P
s
P
p
.002 w
.38516 .54457 m .43298 .57874 L .44266 .56237 L p
1 g
F P
s
P
p
.002 w
.49462 .57878 m .44266 .56237 L .43298 .57874 L p
1 g
F P
s
P
p
.002 w
.33155 .44185 m .35015 .4974 L .36576 .48682 L p
1 g
F P
s
P
p
.002 w
.36576 .48682 m .34857 .4352 L .33155 .44185 L p
1 g
F P
s
P
p
.002 w
.63329 .51009 m .65921 .46814 L .64332 .45631 L p
1 g
F P
s
P
p
.002 w
.65234 .41407 m .64332 .45631 L .65921 .46814 L p
1 g
F P
s
P
p
.002 w
.54893 .57806 m .60006 .55996 L .59518 .54076 L p
1 g
F P
s
P
p
.002 w
.63329 .51009 m .59518 .54076 L .60006 .55996 L p
1 g
F P
s
P
p
.002 w
.43298 .57874 m .48889 .59648 L .49462 .57878 L p
1 g
F P
s
P
p
.002 w
.54893 .57806 m .49462 .57878 L .48889 .59648 L p
1 g
F P
s
P
p
.002 w
.50681 .25811 m .45768 .26901 L .46915 .28423 L p
1 g
F P
s
P
p
.002 w
.46915 .28423 m .51162 .2749 L .50681 .25811 L p
1 g
F P
s
P
p
.002 w
.40016 .28684 m .36631 .32963 L .38506 .33367 L p
1 g
F P
s
P
p
.002 w
.38506 .33367 m .41562 .29527 L .40016 .28684 L p
1 g
F P
s
P
p
.002 w
.33148 .38342 m .33155 .44185 L .34857 .4352 L p
1 g
F P
s
P
p
.002 w
.34857 .4352 m .34863 .38094 L .33148 .38342 L p
1 g
F P
s
P
p
.002 w
.65921 .46814 m .66978 .41931 L .65234 .41407 L p
1 g
F P
s
P
p
.002 w
.64679 .37062 m .65234 .41407 L .66978 .41931 L p
1 g
F P
s
P
p
.002 w
.60006 .55996 m .64253 .526 L .63329 .51009 L p
1 g
F P
s
P
p
.002 w
.65921 .46814 m .63329 .51009 L .64253 .526 L p
1 g
F P
s
P
p
.002 w
.48889 .59648 m .54739 .59582 L .54893 .57806 L p
1 g
F P
s
P
p
.002 w
.60006 .55996 m .54893 .57806 L .54739 .59582 L p
1 g
F P
s
P
p
.002 w
.55751 .26411 m .50681 .25811 L .51162 .2749 L p
1 g
F P
s
P
p
.002 w
.51162 .2749 m .55538 .28015 L .55751 .26411 L p
1 g
F P
s
P
p
.002 w
.66978 .41931 m .66345 .36899 L .64679 .37062 L p
1 g
F P
s
P
p
.002 w
.6271 .33091 m .64679 .37062 L .66345 .36899 L p
1 g
F P
s
P
p
.002 w
.35038 .3281 m .33148 .38342 L .34863 .38094 L p
1 g
F P
s
P
p
.002 w
.34863 .38094 m .36631 .32963 L .35038 .3281 L p
1 g
F P
s
P
p
.002 w
.44691 .25748 m .40016 .28684 L .41562 .29527 L p
1 g
F P
s
P
p
.002 w
.41562 .29527 m .45768 .26901 L .44691 .25748 L p
1 g
F P
s
P
p
.002 w
.60395 .28656 m .55751 .26411 L .55538 .28015 L p
1 g
F P
s
P
p
.002 w
.55538 .28015 m .59542 .29954 L .60395 .28656 L p
1 g
F P
s
P
p
.002 w
.66345 .36899 m .64068 .32294 L .6271 .33091 L p
1 g
F P
s
P
p
.002 w
.59542 .29954 m .6271 .33091 L .64068 .32294 L p
1 g
F P
s
P
p
.002 w
.3379 .50662 m .3746 .55602 L .38516 .54457 L p
1 g
F P
s
P
p
.002 w
.38516 .54457 m .35015 .4974 L .3379 .50662 L p
1 g
F P
s
P
p
.002 w
.43298 .57874 m .38516 .54457 L .3746 .55602 L p
1 g
F P
s
P
p
.002 w
.64068 .32294 m .60395 .28656 L .59542 .29954 L p
1 g
F P
s
P
p
.002 w
.3746 .55602 m .42469 .59182 L .43298 .57874 L p
1 g
F P
s
P
p
.002 w
.48889 .59648 m .43298 .57874 L .42469 .59182 L p
1 g
F P
s
P
p
.002 w
.64253 .526 m .6715 .47941 L .65921 .46814 L p
1 g
F P
s
P
p
.002 w
.66978 .41931 m .65921 .46814 L .6715 .47941 L p
1 g
F P
s
P
p
.002 w
.54739 .59582 m .6025 .57646 L .60006 .55996 L p
1 g
F P
s
P
p
.002 w
.64253 .526 m .60006 .55996 L .6025 .57646 L p
1 g
F P
s
P
p
.002 w
.31833 .44846 m .3379 .50662 L .35015 .4974 L p
1 g
F P
s
P
p
.002 w
.35015 .4974 m .33155 .44185 L .31833 .44846 L p
1 g
F P
s
P
p
.002 w
.42469 .59182 m .48325 .61046 L .48889 .59648 L p
1 g
F P
s
P
p
.002 w
.54739 .59582 m .48889 .59648 L .48325 .61046 L p
1 g
F P
s
P
p
.002 w
.50163 .24523 m .44691 .25748 L .45768 .26901 L p
1 g
F P
s
P
p
.002 w
.45768 .26901 m .50681 .25811 L .50163 .24523 L p
1 g
F P
s
P
p
.002 w
.38676 .2819 m .35038 .3281 L .36631 .32963 L p
1 g
F P
s
P
p
.002 w
.36631 .32963 m .40016 .28684 L .38676 .2819 L p
1 g
F P
s
P
p
.002 w
.31815 .38725 m .31833 .44846 L .33155 .44185 L p
1 g
F P
s
P
p
.002 w
.33155 .44185 m .33148 .38342 L .31815 .38725 L p
1 g
F P
s
P
p
.002 w
.6715 .47941 m .68338 .42505 L .66978 .41931 L p
1 g
F P
s
P
p
.002 w
.66345 .36899 m .66978 .41931 L .68338 .42505 L p
1 g
F P
s
P
p
.002 w
.6025 .57646 m .64835 .53997 L .64253 .526 L p
1 g
F P
s
P
p
.002 w
.6715 .47941 m .64253 .526 L .64835 .53997 L p
1 g
F P
s
P
p
.002 w
.48325 .61046 m .54452 .60987 L .54739 .59582 L p
1 g
F P
s
P
p
.002 w
.6025 .57646 m .54739 .59582 L .54452 .60987 L p
1 g
F P
s
P
p
.002 w
.5582 .25187 m .50163 .24523 L .50681 .25811 L p
1 g
F P
s
P
p
.002 w
.50681 .25811 m .55751 .26411 L .5582 .25187 L p
1 g
F P
s
P
p
.002 w
.68338 .42505 m .67641 .36893 L .66345 .36899 L p
1 g
F P
s
P
p
.002 w
.64068 .32294 m .66345 .36899 L .67641 .36893 L p
1 g
F P
s
P
p
.002 w
.43713 .25014 m .38676 .2819 L .40016 .28684 L p
1 g
F P
s
P
p
.002 w
.40016 .28684 m .44691 .25748 L .43713 .25014 L p
1 g
F P
s
P
p
.002 w
.33785 .32927 m .31815 .38725 L .33148 .38342 L p
1 g
F P
s
P
p
.002 w
.33148 .38342 m .35038 .3281 L .33785 .32927 L p
1 g
F P
s
P
p
.002 w
.61004 .2769 m .5582 .25187 L .55751 .26411 L p
1 g
F P
s
P
p
.002 w
.55751 .26411 m .60395 .28656 L .61004 .2769 L p
1 g
F P
s
P
p
.002 w
.67641 .36893 m .65104 .31752 L .64068 .32294 L p
1 g
F P
s
P
p
.002 w
.60395 .28656 m .64068 .32294 L .65104 .31752 L p
1 g
F P
s
P
p
.002 w
.32949 .51418 m .36697 .56457 L .3746 .55602 L p
1 g
F P
s
P
p
.002 w
.3746 .55602 m .3379 .50662 L .32949 .51418 L p
1 g
F P
s
P
p
.002 w
.42469 .59182 m .3746 .55602 L .36697 .56457 L p
1 g
F P
s
P
p
.002 w
.65104 .31752 m .61004 .2769 L .60395 .28656 L p
1 g
F P
s
P
p
.002 w
.36697 .56457 m .41808 .60112 L .42469 .59182 L p
1 g
F P
s
P
p
.002 w
.48325 .61046 m .42469 .59182 L .41808 .60112 L p
1 g
F P
s
P
p
.002 w
.64835 .53997 m .67969 .48981 L .6715 .47941 L p
1 g
F P
s
P
p
.002 w
.68338 .42505 m .6715 .47941 L .67969 .48981 L p
1 g
F P
s
P
p
.002 w
.54452 .60987 m .60229 .5897 L .6025 .57646 L p
1 g
F P
s
P
p
.002 w
.64835 .53997 m .6025 .57646 L .60229 .5897 L p
1 g
F P
s
P
p
.002 w
.30947 .45485 m .32949 .51418 L .3379 .50662 L p
1 g
F P
s
P
p
.002 w
.3379 .50662 m .31833 .44846 L .30947 .45485 L p
1 g
F P
s
P
p
.002 w
.41808 .60112 m .47783 .62019 L .48325 .61046 L p
1 g
F P
s
P
p
.002 w
.54452 .60987 m .48325 .61046 L .47783 .62019 L p
1 g
F P
s
P
p
.002 w
.49619 .23684 m .43713 .25014 L .44691 .25748 L p
1 g
F P
s
P
p
.002 w
.44691 .25748 m .50163 .24523 L .49619 .23684 L p
1 g
F P
s
P
p
.002 w
.37589 .28079 m .33785 .32927 L .35038 .3281 L p
1 g
F P
s
P
p
.002 w
.35038 .3281 m .38676 .2819 L .37589 .28079 L p
1 g
F P
s
P
p
.002 w
.30921 .39241 m .30947 .45485 L .31833 .44846 L p
1 g
F P
s
P
p
.002 w
.31833 .44846 m .31815 .38725 L .30921 .39241 L p
1 g
F P
s
P
p
.002 w
.67969 .48981 m .6926 .43117 L .68338 .42505 L p
1 g
F P
s
P
p
.002 w
.67641 .36893 m .68338 .42505 L .6926 .43117 L p
1 g
F P
s
P
p
.002 w
.60229 .5897 m .65039 .55156 L .64835 .53997 L p
1 g
F P
s
P
p
.002 w
.67969 .48981 m .64835 .53997 L .65039 .55156 L p
1 g
F P
s
P
p
.002 w
.47783 .62019 m .54034 .61965 L .54452 .60987 L p
1 g
F P
s
P
p
.002 w
.60229 .5897 m .54452 .60987 L .54034 .61965 L p
1 g
F P
s
P
p
.002 w
.55733 .24397 m .49619 .23684 L .50163 .24523 L p
1 g
F P
s
P
p
.002 w
.50163 .24523 m .5582 .25187 L .55733 .24397 L p
1 g
F P
s
P
p
.002 w
.42866 .24744 m .37589 .28079 L .38676 .2819 L p
1 g
F P
s
P
p
.002 w
.38676 .2819 m .43713 .25014 L .42866 .24744 L p
1 g
F P
s
P
p
.002 w
.6926 .43117 m .68513 .37054 L .67641 .36893 L p
1 g
F P
s
P
p
.002 w
.65104 .31752 m .67641 .36893 L .68513 .37054 L p
1 g
F P
s
P
p
.002 w
.32923 .33325 m .30921 .39241 L .31815 .38725 L p
1 g
F P
s
P
p
.002 w
.31815 .38725 m .33785 .32927 L .32923 .33325 L p
1 g
F P
s
P
p
.002 w
.61339 .27102 m .55733 .24397 L .5582 .25187 L p
1 g
F P
s
P
p
.002 w
.5582 .25187 m .61004 .2769 L .61339 .27102 L p
1 g
F P
s
P
p
.002 w
.68513 .37054 m .65773 .31495 L .65104 .31752 L p
1 g
F P
s
P
p
.002 w
.61004 .2769 m .65104 .31752 L .65773 .31495 L p
1 g
F P
s
P
p
.002 w
.32538 .51977 m .36264 .56983 L .36697 .56457 L p
1 g
F P
s
P
p
.002 w
.36697 .56457 m .32949 .51418 L .32538 .51977 L p
1 g
F P
s
P
p
.002 w
.41808 .60112 m .36697 .56457 L .36264 .56983 L p
1 g
F P
s
P
p
.002 w
.65773 .31495 m .61339 .27102 L .61004 .2769 L p
1 g
F P
s
P
p
.002 w
.65039 .55156 m .68331 .49903 L .67969 .48981 L p
1 g
F P
s
P
p
.002 w
.6926 .43117 m .67969 .48981 L .68331 .49903 L p
1 g
F P
s
P
p
.002 w
.54034 .61965 m .59929 .59915 L .60229 .5897 L p
1 g
F P
s
P
p
.002 w
.65039 .55156 m .60229 .5897 L .59929 .59915 L p
1 g
F P
s
P
p
.002 w
.36264 .56983 m .41343 .60616 L .41808 .60112 L p
1 g
F P
s
P
p
.002 w
.47783 .62019 m .41808 .60112 L .41343 .60616 L p
1 g
F P
s
P
p
.002 w
.30546 .46084 m .32538 .51977 L .32949 .51418 L p
1 g
F P
s
P
p
.002 w
.32949 .51418 m .30947 .45485 L .30546 .46084 L p
1 g
F P
s
P
p
.002 w
.41343 .60616 m .47279 .62513 L .47783 .62019 L p
1 g
F P
s
P
p
.002 w
.54034 .61965 m .47783 .62019 L .47279 .62513 L p
1 g
F P
s
P
p
.002 w
.49062 .23344 m .42866 .24744 L .43713 .25014 L p
1 g
F P
s
P
p
.002 w
.43713 .25014 m .49619 .23684 L .49062 .23344 L p
1 g
F P
s
P
p
.002 w
.36799 .28378 m .32923 .33325 L .33785 .32927 L p
1 g
F P
s
P
p
.002 w
.33785 .32927 m .37589 .28079 L .36799 .28378 L p
1 g
F P
s
P
p
.002 w
.30518 .39885 m .30546 .46084 L .30947 .45485 L p
1 g
F P
s
P
p
.002 w
.30947 .45485 m .30921 .39241 L .30518 .39885 L p
1 g
F P
s
P
p
.002 w
.68331 .49903 m .69691 .43753 L .6926 .43117 L p
1 g
F P
s
P
p
.002 w
.68513 .37054 m .6926 .43117 L .69691 .43753 L p
1 g
F P
s
P
p
.002 w
.59929 .59915 m .64838 .5603 L .65039 .55156 L p
1 g
F P
s
P
p
.002 w
.68331 .49903 m .65039 .55156 L .64838 .5603 L p
1 g
F P
s
P
p
.002 w
.47279 .62513 m .53487 .62463 L .54034 .61965 L p
1 g
F P
s
P
p
.002 w
.59929 .59915 m .54034 .61965 L .53487 .62463 L p
1 g
F P
s
P
p
.002 w
.55482 .24091 m .49062 .23344 L .49619 .23684 L p
1 g
F P
s
P
p
.002 w
.49619 .23684 m .55733 .24397 L .55482 .24091 L p
1 g
F P
s
P
p
.002 w
.42182 .24974 m .36799 .28378 L .37589 .28079 L p
1 g
F P
s
P
p
.002 w
.37589 .28079 m .42866 .24744 L .42182 .24974 L p
1 g
F P
s
P
p
.002 w
.32503 .34013 m .30518 .39885 L .30921 .39241 L p
1 g
F P
s
P
p
.002 w
.30921 .39241 m .32923 .33325 L .32503 .34013 L p
1 g
F P
s
P
p
.002 w
.69691 .43753 m .68909 .37388 L .68513 .37054 L p
1 g
F P
s
P
p
.002 w
.65773 .31495 m .68513 .37054 L .68909 .37388 L p
1 g
F P
s
P
p
.002 w
.61373 .26933 m .55482 .24091 L .55733 .24397 L p
1 g
F P
s
P
p
.002 w
.55733 .24397 m .61339 .27102 L .61373 .26933 L p
1 g
F P
s
P
p
.002 w
.68909 .37388 m .66031 .31549 L .65773 .31495 L p
1 g
F P
s
P
p
.002 w
.61339 .27102 m .65773 .31495 L .66031 .31549 L p
1 g
F P
s
P
p
.002 w
.32597 .52311 m .36195 .57144 L .36264 .56983 L p
1 g
F P
s
P
p
.002 w
.36264 .56983 m .32538 .51977 L .32597 .52311 L p
1 g
F P
s
P
p
.002 w
.41343 .60616 m .36264 .56983 L .36195 .57144 L p
1 g
F P
s
P
p
.004 w
.70168 .50156 m
.71817 .50737 L
s
P
p
.004 w
.71817 .50737 m
.73596 .51364 L
s
P
p
.002 w
.66031 .31549 m .61373 .26933 L .61339 .27102 L p
1 g
F P
s
P
p
.002 w
.64838 .5603 m .68198 .50673 L .68331 .49903 L p
1 g
F P
s
P
p
.002 w
.69691 .43753 m .68331 .49903 L .68198 .50673 L p
1 g
F P
s
P
p
.002 w
.53487 .62463 m .59339 .60431 L .59929 .59915 L p
1 g
F P
s
P
p
.002 w
.64838 .5603 m .59929 .59915 L .59339 .60431 L p
1 g
F P
s
P
p
.002 w
.36195 .57144 m .41099 .60652 L .41343 .60616 L p
1 g
F P
s
P
p
.002 w
.47279 .62513 m .41343 .60616 L .41099 .60652 L p
1 g
F P
s
P
p
.002 w
.30675 .46624 m .32597 .52311 L .32538 .51977 L p
1 g
F P
s
P
p
.002 w
.32538 .51977 m .30546 .46084 L .30675 .46624 L p
1 g
F P
s
P
p
.002 w
.48508 .23546 m .42182 .24974 L .42866 .24744 L p
1 g
F P
s
P
p
.002 w
.42866 .24744 m .49062 .23344 L .48508 .23546 L p
1 g
F P
s
P
p
.002 w
.41099 .60652 m .46828 .62483 L .47279 .62513 L p
1 g
F P
s
P
p
.002 w
.53487 .62463 m .47279 .62513 L .46828 .62483 L p
1 g
F P
s
P
p
.002 w
.36349 .29105 m .32503 .34013 L .32923 .33325 L p
1 g
F P
s
P
p
.002 w
.32923 .33325 m .36799 .28378 L .36349 .29105 L p
1 g
F P
s
P
p
.002 w
.30648 .40646 m .30675 .46624 L .30546 .46084 L p
1 g
F P
s
P
p
.002 w
.30546 .46084 m .30518 .39885 L .30648 .40646 L p
1 g
F P
s
P
p
.002 w
.68198 .50673 m .69586 .44397 L .69691 .43753 L p
1 g
F P
s
P
p
.002 w
.68909 .37388 m .69691 .43753 L .69586 .44397 L p
1 g
F P
s
P
p
.002 w
.59339 .60431 m .6421 .56576 L .64838 .5603 L p
1 g
F P
s
P
p
.002 w
.68198 .50673 m .64838 .5603 L .6421 .56576 L p
1 g
F P
s
P
p
.002 w
.46828 .62483 m .52817 .62435 L .53487 .62463 L p
1 g
F P
s
P
p
.002 w
.59339 .60431 m .53487 .62463 L .52817 .62435 L p
1 g
F P
s
P
p
.002 w
.55065 .2431 m .48508 .23546 L .49062 .23344 L p
1 g
F P
s
P
p
.002 w
.49062 .23344 m .55482 .24091 L .55065 .2431 L p
1 g
F P
s
P
p
.002 w
.41693 .25731 m .36349 .29105 L .36799 .28378 L p
1 g
F P
s
P
p
.002 w
.36799 .28378 m .42182 .24974 L .41693 .25731 L p
1 g
F P
s
P
p
.002 w
.32565 .34989 m .30648 .40646 L .30518 .39885 L p
1 g
F P
s
P
p
.002 w
.30518 .39885 m .32503 .34013 L .32565 .34989 L p
1 g
F P
s
P
p
.002 w
.69586 .44397 m .68786 .37898 L .68909 .37388 L p
1 g
F P
s
P
p
.002 w
.66031 .31549 m .68909 .37388 L .68786 .37898 L p
1 g
F P
s
P
p
.002 w
.61084 .27215 m .55065 .2431 L .55482 .24091 L p
1 g
F P
s
P
p
.002 w
.55482 .24091 m .61373 .26933 L .61084 .27215 L p
1 g
F P
s
P
p
.002 w
.68786 .37898 m .65845 .31932 L .66031 .31549 L p
1 g
F P
s
P
p
.002 w
.61373 .26933 m .66031 .31549 L .65845 .31932 L p
1 g
F P
s
P
p
.002 w
.6421 .56576 m .67542 .5126 L .68198 .50673 L p
1 g
F P
s
P
p
.002 w
.69586 .44397 m .68198 .50673 L .67542 .5126 L p
1 g
F P
s
P
p
.002 w
.52817 .62435 m .58457 .60474 L .59339 .60431 L p
1 g
F P
s
P
p
.002 w
.6421 .56576 m .59339 .60431 L .58457 .60474 L p
1 g
F P
s
P
p
.002 w
.33156 .52396 m .36516 .56911 L .36195 .57144 L p
1 g
F P
s
P
p
.002 w
.36195 .57144 m .32597 .52311 L .33156 .52396 L p
1 g
F P
s
P
p
.002 w
.41099 .60652 m .36195 .57144 L .36516 .56911 L p
1 g
F P
s
P
p
.002 w
.65845 .31932 m .61084 .27215 L .61373 .26933 L p
1 g
F P
s
P
p
.002 w
.36516 .56911 m .41098 .60188 L .41099 .60652 L p
1 g
F P
s
P
p
.002 w
.46828 .62483 m .41099 .60652 L .41098 .60188 L p
1 g
F P
s
P
p
.002 w
.31364 .47086 m .33156 .52396 L .32597 .52311 L p
1 g
F P
s
P
p
.002 w
.32597 .52311 m .30675 .46624 L .31364 .47086 L p
1 g
F P
s
P
p
.002 w
.47972 .24319 m .41693 .25731 L .42182 .24974 L p
1 g
F P
s
P
p
.002 w
.42182 .24974 m .48508 .23546 L .47972 .24319 L p
1 g
F P
s
P
p
.002 w
.36275 .30267 m .32565 .34989 L .32503 .34013 L p
1 g
F P
s
P
p
.002 w
.32503 .34013 m .36349 .29105 L .36275 .30267 L p
1 g
F P
s
P
p
.002 w
.41098 .60188 m .46448 .61897 L .46828 .62483 L p
1 g
F P
s
P
p
.002 w
.52817 .62435 m .46828 .62483 L .46448 .61897 L p
1 g
F P
s
P
p
.002 w
.31344 .4151 m .31364 .47086 L .30675 .46624 L p
1 g
F P
s
P
p
.002 w
.30675 .46624 m .30648 .40646 L .31344 .4151 L p
1 g
F P
s
P
p
.002 w
.67542 .5126 m .68914 .45031 L .69586 .44397 L p
1 g
F P
s
P
p
.002 w
.68786 .37898 m .69586 .44397 L .68914 .45031 L p
1 g
F P
s
P
p
.002 w
.58457 .60474 m .63146 .56756 L .6421 .56576 L p
1 g
F P
s
P
p
.002 w
.67542 .5126 m .6421 .56576 L .63146 .56756 L p
1 g
F P
s
P
p
.002 w
.46448 .61897 m .52037 .61848 L .52817 .62435 L p
1 g
F P
s
P
p
.002 w
.58457 .60474 m .52817 .62435 L .52037 .61848 L p
1 g
F P
s
P
p
.002 w
.54483 .25083 m .47972 .24319 L .48508 .23546 L p
1 g
F P
s
P
p
.002 w
.48508 .23546 m .55065 .2431 L .54483 .25083 L p
1 g
F P
s
P
p
.002 w
.41425 .27026 m .36275 .30267 L .36349 .29105 L p
1 g
F P
s
P
p
.002 w
.36349 .29105 m .41693 .25731 L .41425 .27026 L p
1 g
F P
s
P
p
.002 w
.33138 .36242 m .31344 .4151 L .30648 .40646 L p
1 g
F P
s
P
p
.002 w
.30648 .40646 m .32565 .34989 L .33138 .36242 L p
1 g
F P
s
P
p
.002 w
.65845 .31932 m .68786 .37898 L .68115 .38579 L p
1 g
F P
s
P
p
.002 w
.68914 .45031 m .68115 .38579 L .68786 .37898 L p
1 g
F P
s
P
p
.002 w
.6046 .27971 m .54483 .25083 L .55065 .2431 L p
1 g
F P
s
P
p
.002 w
.55065 .2431 m .61084 .27215 L .6046 .27971 L p
1 g
F P
s
P
p
.002 w
.63146 .56756 m .66348 .51633 L .67542 .5126 L p
1 g
F P
s
P
p
.002 w
.68914 .45031 m .67542 .5126 L .66348 .51633 L p
1 g
F P
s
P
p
.002 w
.52037 .61848 m .57292 .60013 L .58457 .60474 L p
1 g
F P
s
P
p
.002 w
.63146 .56756 m .58457 .60474 L .57292 .60013 L p
1 g
F P
s
P
p
.002 w
.68115 .38579 m .6519 .32656 L .65845 .31932 L p
1 g
F P
s
P
p
.002 w
.61084 .27215 m .65845 .31932 L .6519 .32656 L p
1 g
F P
s
P
p
.002 w
.3423 .52211 m .37243 .56264 L .36516 .56911 L p
1 g
F P
s
P
p
.002 w
.36516 .56911 m .33156 .52396 L .3423 .52211 L p
1 g
F P
s
P
p
.002 w
.41098 .60188 m .36516 .56911 L .37243 .56264 L p
1 g
F P
s
P
p
.002 w
.6519 .32656 m .6046 .27971 L .61084 .27215 L p
1 g
F P
s
P
p
.002 w
.37243 .56264 m .41356 .59204 L .41098 .60188 L p
1 g
F P
s
P
p
.002 w
.46448 .61897 m .41098 .60188 L .41356 .59204 L p
1 g
F P
s
P
p
.002 w
.32628 .47449 m .3423 .52211 L .33156 .52396 L p
1 g
F P
s
P
p
.002 w
.33156 .52396 m .31364 .47086 L .32628 .47449 L p
1 g
F P
s
P
p
.002 w
.47474 .25676 m .41425 .27026 L .41693 .25731 L p
1 g
F P
s
P
p
.002 w
.41693 .25731 m .47972 .24319 L .47474 .25676 L p
1 g
F P
s
P
p
.002 w
.36601 .31852 m .33138 .36242 L .32565 .34989 L p
1 g
F P
s
P
p
.002 w
.32565 .34989 m .36275 .30267 L .36601 .31852 L p
1 g
F P
s
P
p
.002 w
.41356 .59204 m .46156 .60734 L .46448 .61897 L p
1 g
F P
s
P
p
.002 w
.52037 .61848 m .46448 .61897 L .46156 .60734 L p
1 g
F P
s
P
p
.002 w
.32619 .42455 m .32628 .47449 L .31364 .47086 L p
1 g
F P
s
P
p
.002 w
.31364 .47086 m .31344 .4151 L .32619 .42455 L p
1 g
F P
s
P
p
.002 w
.66348 .51633 m .6766 .45633 L .68914 .45031 L p
1 g
F P
s
P
p
.004 w
.68596 .49602 m
.70168 .50156 L
s
P
p
.002 w
.68115 .38579 m .68914 .45031 L .6766 .45633 L p
1 g
F P
s
P
p
.002 w
.57292 .60013 m .61653 .56543 L .63146 .56756 L p
1 g
F P
s
P
p
.002 w
.66348 .51633 m .63146 .56756 L .61653 .56543 L p
1 g
F P
s
P
p
.002 w
.46156 .60734 m .51164 .60683 L .52037 .61848 L p
1 g
F P
s
P
p
.002 w
.57292 .60013 m .52037 .61848 L .51164 .60683 L p
1 g
F P
s
P
p
.002 w
.53744 .2642 m .47474 .25676 L .47972 .24319 L p
1 g
F P
s
P
p
.002 w
.47972 .24319 m .54483 .25083 L .53744 .2642 L p
1 g
F P
s
P
p
.002 w
.41401 .28848 m .36601 .31852 L .36275 .30267 L p
1 g
F P
s
P
p
.002 w
.36275 .30267 m .41425 .27026 L .41401 .28848 L p
1 g
F P
s
P
p
.002 w
.34235 .37746 m .32619 .42455 L .31344 .4151 L p
1 g
F P
s
P
p
.002 w
.31344 .4151 m .33138 .36242 L .34235 .37746 L p
1 g
F P
s
P
p
.002 w
.6766 .45633 m .6688 .39421 L .68115 .38579 L p
1 g
F P
s
P
p
.002 w
.6519 .32656 m .68115 .38579 L .6688 .39421 L p
1 g
F P
s
P
p
.002 w
.595 .29205 m .53744 .2642 L .54483 .25083 L p
1 g
F P
s
P
p
.002 w
.54483 .25083 m .6046 .27971 L .595 .29205 L p
1 g
F P
s
P
p
.002 w
.61653 .56543 m .64622 .51767 L .66348 .51633 L p
1 g
F P
s
P
p
.002 w
.6766 .45633 m .66348 .51633 L .64622 .51767 L p
1 g
F P
s
P
p
.002 w
.51164 .60683 m .55865 .59031 L .57292 .60013 L p
1 g
F P
s
P
p
.002 w
.61653 .56543 m .57292 .60013 L .55865 .59031 L p
1 g
F P
s
P
p
.002 w
.6688 .39421 m .64058 .33718 L .6519 .32656 L p
1 g
F P
s
P
p
.002 w
.6046 .27971 m .6519 .32656 L .64058 .33718 L p
1 g
F P
s
P
p
.002 w
.35817 .51747 m .38379 .55198 L .37243 .56264 L p
1 g
F P
s
P
p
.002 w
.37243 .56264 m .3423 .52211 L .35817 .51747 L p
1 g
F P
s
P
p
.002 w
.41356 .59204 m .37243 .56264 L .38379 .55198 L p
1 g
F P
s
P
p
.002 w
.64058 .33718 m .595 .29205 L .6046 .27971 L p
1 g
F P
s
P
p
.002 w
.38379 .55198 m .41881 .57701 L .41356 .59204 L p
1 g
F P
s
P
p
.002 w
.46156 .60734 m .41356 .59204 L .41881 .57701 L p
1 g
F P
s
P
p
.002 w
.3446 .47695 m .35817 .51747 L .3423 .52211 L p
1 g
F P
s
P
p
.002 w
.3423 .52211 m .32628 .47449 L .3446 .47695 L p
1 g
F P
s
P
p
.002 w
.37342 .33833 m .34235 .37746 L .33138 .36242 L p
1 g
F P
s
P
p
.002 w
.33138 .36242 m .36601 .31852 L .37342 .33833 L p
1 g
F P
s
P
p
.002 w
.47032 .27606 m .41401 .28848 L .41425 .27026 L p
1 g
F P
s
P
p
.002 w
.41425 .27026 m .47474 .25676 L .47032 .27606 L p
1 g
F P
s
P
p
.002 w
.41881 .57701 m .45967 .58998 L .46156 .60734 L p
1 g
F P
s
P
p
.002 w
.51164 .60683 m .46156 .60734 L .45967 .58998 L p
1 g
F P
s
P
p
.002 w
.34463 .43453 m .3446 .47695 L .32628 .47449 L p
1 g
F P
s
P
p
.002 w
.32628 .47449 m .32619 .42455 L .34463 .43453 L p
1 g
F P
s
P
p
.002 w
.64622 .51767 m .65829 .46181 L .6766 .45633 L p
1 g
F P
s
P
p
.004 w
.66647 .48916 m
.68596 .49602 L
s
P
p
.002 w
.6688 .39421 m .6766 .45633 L .65829 .46181 L p
1 g
F P
s
P
p
.002 w
.55865 .59031 m .59755 .55918 L .61653 .56543 L p
1 g
F P
s
P
p
.002 w
.64622 .51767 m .61653 .56543 L .59755 .55918 L p
1 g
F P
s
P
p
.002 w
.45967 .58998 m .50223 .58946 L .51164 .60683 L p
1 g
F P
s
P
p
.002 w
.55865 .59031 m .51164 .60683 L .50223 .58946 L p
1 g
F P
s
P
p
.002 w
.52863 .28309 m .47032 .27606 L .47474 .25676 L p
1 g
F P
s
P
p
.002 w
.47474 .25676 m .53744 .2642 L .52863 .28309 L p
1 g
F P
s
P
p
.002 w
.41636 .31165 m .37342 .33833 L .36601 .31852 L p
1 g
F P
s
P
p
.002 w
.36601 .31852 m .41401 .28848 L .41636 .31165 L p
1 g
F P
s
P
p
.002 w
.35847 .39464 m .34463 .43453 L .32619 .42455 L p
1 g
F P
s
P
p
.002 w
.32619 .42455 m .34235 .37746 L .35847 .39464 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.65829 .46181 m .65091 .40403 L .6688 .39421 L p
1 g
F P
s
P
p
.002 w
.64058 .33718 m .6688 .39421 L .65091 .40403 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.58217 .30905 m .52863 .28309 L .53744 .2642 L p
1 g
F P
s
P
p
.002 w
.53744 .2642 m .595 .29205 L .58217 .30905 L p
1 g
F P
s
P
p
.002 w
.50223 .58946 m .54209 .57533 L .55865 .59031 L p
1 g
F P
s
P
p
.002 w
.59755 .55918 m .55865 .59031 L .54209 .57533 L p
1 g
F P
s
P
p
.002 w
.59755 .55918 m .62393 .51643 L .64622 .51767 L p
1 g
F P
s
P
p
.002 w
.65829 .46181 m .64622 .51767 L .62393 .51643 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.64569 .48184 L
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.65091 .40403 m .62458 .35102 L .64058 .33718 L p
1 g
F P
s
P
p
.002 w
.595 .29205 m .64058 .33718 L .62458 .35102 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37891 .51003 m .39909 .53726 L .38379 .55198 L p
1 g
F P
s
P
p
.002 w
.38379 .55198 m .35817 .51747 L .37891 .51003 L p
1 g
F P
s
P
p
.002 w
.41881 .57701 m .38379 .55198 L .39909 .53726 L p
1 g
F P
s
P
p
.002 w
.62458 .35102 m .58217 .30905 L .595 .29205 L p
1 g
F P
s
P
p
.002 w
.39909 .53726 m .42671 .55698 L .41881 .57701 L p
1 g
F P
s
P
p
.002 w
.45967 .58998 m .41881 .57701 L .42671 .55698 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.36829 .47809 m .37891 .51003 L .35817 .51747 L p
1 g
F P
s
P
p
.002 w
.35817 .51747 m .3446 .47695 L .36829 .47809 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.38492 .3616 m .35847 .39464 L .34235 .37746 L p
1 g
F P
s
P
p
.002 w
.34235 .37746 m .37342 .33833 L .38492 .3616 L p
1 g
F P
s
P
p
.002 w
.46665 .30072 m .41636 .31165 L .41401 .28848 L p
1 g
F P
s
P
p
.002 w
.41401 .28848 m .47032 .27606 L .46665 .30072 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.42671 .55698 m .45214 .56501 L p
.45967 .58998 L 1 g
F P
s
P
p
.002 w
.45214 .56501 m .45373 .56552 L p
.45415 .56724 L 1 g
F P
s
P
p
.45967 .58998 m .45214 .56501 L .45415 .56724 L 1 g
F
P
p
.002 w
.45075 .56319 m .45146 .56129 L p
.44515 .55581 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45075 .56319 L p
1 g
F P
s
P
p
.002 w
.45373 .56552 m .45214 .56501 L p
.45161 .56385 L 1 g
F P
s
P
p
.002 w
.42671 .55698 m .43363 .54064 L p
.43851 .54706 L 1 g
F P
s
P
p
.002 w
.45214 .56501 m .44411 .56248 L p
.43851 .54706 L 1 g
F P
s
P
p
.002 w
.44411 .56248 m .42671 .55698 L p
.43851 .54706 L 1 g
F P
s
P
p
.002 w
.43851 .54706 m .43925 .54566 L p
.43487 .53699 L 1 g
F P
s
P
p
.002 w
.435 .53742 m .42671 .55698 L p
.43236 .52903 L 1 g
F P
s
P
p
.43487 .53699 m .43479 .53684 L .435 .53742 L 1 g
F
P
p
.43487 .53699 m .435 .53742 L .43851 .54706 L 1 g
F
P
p
.43346 .52734 m .43317 .51897 L .43311 .51968 L 1 g
F
P
p
.002 w
.43234 .52902 m .41799 .51877 L .4275 .50936 L p
1 g
F P
s
P
p
.002 w
.4275 .50936 m .43453 .5024 L p
.43396 .50932 L 1 g
F P
s
P
p
.42973 .51837 m .4275 .50936 L .43396 .50932 L 1 g
F
P
p
.002 w
.43396 .50932 m .43485 .50826 L p
.43905 .49845 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43235 .52896 L p
1 g
F P
s
P
p
.43925 .54566 m .43235 .52896 L .43324 .53256 L 1 g
F
P
p
.43925 .54566 m .43324 .53256 L .43479 .53684 L 1 g
F
P
p
.002 w
.45899 .56918 m .45967 .58998 L p
.45373 .56552 L 1 g
F P
s
P
p
.46872 .57265 m .45075 .56319 L .45673 .56786 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.45214 .56501 m .43851 .54706 L .43712 .53242 L 1 g
F
P
p
.002 w
.43363 .54064 m .435 .53742 L p
.43851 .54706 L 1 g
F P
s
P
p
.002 w
.435 .53742 m .43712 .53242 L p
.43851 .54706 L 1 g
F P
s
P
p
.43479 .53684 m .43324 .53256 L .43382 .53491 L 1 g
F
P
p
.43235 .52896 m .42973 .51837 L .43396 .50932 L 1 g
F
P
p
.43234 .52902 m .4275 .50936 L .43235 .52896 L 1 g
F
P
p
.002 w
.43234 .52897 m .43235 .52896 L p
.43276 .51216 L 1 g
F P
s
P
p
.002 w
.43235 .52896 m .43346 .52734 L p
.43311 .51968 L 1 g
F P
s
P
p
.43311 .51968 m .43276 .51216 L .43235 .52896 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.4328 .48737 m .43979 .49686 L p
.41799 .51877 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44249 .49146 L p
1 g
F P
s
P
p
.002 w
.4328 .48737 m .44805 .4803 L p
.44249 .49146 L 1 g
F P
s
P
p
.002 w
.43979 .49686 m .4386 .49523 L p
.44249 .49146 L 1 g
F P
s
P
p
.002 w
.4386 .49523 m .4328 .48737 L p
.44249 .49146 L 1 g
F P
s
P
p
.002 w
.44249 .49146 m .4422 .49176 L p
.44107 .4943 L 1 g
F P
s
P
p
.43485 .50826 m .44249 .49146 L .44107 .4943 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44249 .49146 m .44339 .4905 L p
.45038 .48381 L 1 g
F P
s
P
p
.43485 .50826 m .4422 .49176 L .44174 .49274 L 1 g
F
P
p
.002 w
.43949 .49749 m .41799 .51877 L p
.43979 .49686 L 1 g
F P
s
P
p
.43485 .50826 m .44215 .49182 L .43905 .49845 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.43979 .49686 m .44249 .49146 L .46191 .47479 L 1 g
F
P
p
.43979 .49686 m .46191 .47479 L .46246 .47453 L 1 g
F
P
p
.002 w
.46119 .50761 m .44975 .50405 L .46367 .47397 L p
1 g
F P
s
P
p
.002 w
.48404 .50329 m .47304 .50736 L .46441 .47362 L p
1 g
F P
s
P
p
.002 w
.4989 .48579 m .49298 .49584 L .46491 .47338 L p
1 g
F P
s
P
p
.002 w
.45761 .47679 m .45826 .47608 L p
.46927 .47125 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.48991 .46544 L 1 g
F P
s
P
p
.002 w
.49964 .46406 m .50112 .47421 L p
.48829 .46568 L 1 g
F P
s
P
p
.48991 .46544 m .48994 .46544 L .48829 .46568 L 1 g
F
P
p
.48991 .46544 m .48829 .46568 L .47754 .4672 L 1 g
F
P
p
.002 w
.48829 .46568 m .46894 .47142 L p
.47754 .4672 L 1 g
F P
s
P
p
.46894 .47142 m .46968 .47107 L .4684 .47168 L 1 g
F
P
p
.46927 .47125 m .46927 .47125 L .46894 .47142 L 1 g
F
P
p
.46927 .47125 m .46968 .47107 L .46894 .47142 L 1 g
F
P
p
.002 w
.50112 .47421 m .46594 .47288 L p
.48829 .46568 L 1 g
F P
s
P
p
.46927 .47125 m .4684 .47168 L .45761 .47679 L 1 g
F
P
p
.002 w
.46894 .47142 m .48829 .46568 L p
.46594 .47288 L 1 g
F P
s
P
p
.46968 .47107 m .46847 .47166 L .46783 .47196 L 1 g
F
P
p
.46872 .47153 m .46783 .47196 L .45761 .47679 L 1 g
F
P
p
.46968 .47107 m .46783 .47196 L .46872 .47153 L 1 g
F
P
p
.002 w
.50112 .47421 m .4989 .48579 L .46526 .47321 L p
1 g
F P
s
P
p
.47011 .47089 m .46814 .47183 L .45761 .47679 L 1 g
F
P
p
.47071 .47062 m .46758 .47211 L .45761 .47679 L 1 g
F
P
p
.002 w
.46594 .47288 m .50112 .47421 L p
.46526 .47321 L 1 g
F P
s
P
p
.47147 .47029 m .46661 .47258 L .45761 .47679 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47726 .46766 L p
1 g
F P
s
P
p
.45826 .47608 m .47726 .46766 L .47376 .46928 L 1 g
F
P
p
.002 w
.46526 .47321 m .4989 .48579 L p
.46491 .47338 L 1 g
F P
s
P
p
.002 w
.49298 .49584 m .48404 .50329 L .46465 .47351 L p
1 g
F P
s
P
p
.002 w
.46491 .47338 m .49298 .49584 L p
.46465 .47351 L 1 g
F P
s
P
p
.002 w
.46465 .47351 m .48404 .50329 L p
.46441 .47362 L 1 g
F P
s
P
p
.47235 .4699 m .46503 .47333 L .45761 .47679 L 1 g
F
P
p
.002 w
.45941 .47504 m .4642 .47282 L p
.46191 .47479 L 1 g
F P
s
P
p
.44249 .49146 m .45761 .47679 L .46191 .47479 L 1 g
F
P
p
.45761 .47679 m .45941 .47504 L .46191 .47479 L 1 g
F
P
p
.002 w
.47726 .46766 m .47718 .46778 L p
.47376 .46928 L 1 g
F P
s
P
p
.002 w
.46526 .47321 m .4642 .47282 L .46594 .47288 L p
1 g
F P
s
P
p
.002 w
.46594 .47288 m .4642 .47282 L .46894 .47142 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.4994 .46238 m .53469 .45092 L p
.52104 .46039 L 1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46716 L p
1 g
F P
s
P
p
.51317 .46586 m .50112 .47421 L .5 .464 L 1 g
F
P
p
.5 .4634 m .52244 .46716 L .51168 .46564 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53349 .49698 m .5379 .47473 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56619 .5095 L p
1 g
F P
s
P
p
.57263 .52381 m .56619 .5095 L .56664 .506 L 1 g
F
P
p
.002 w
.56548 .50792 m .56606 .50696 L p
.56619 .5095 L 1 g
F P
s
P
p
.002 w
.56606 .50696 m .56664 .506 L p
.56619 .5095 L 1 g
F P
s
P
p
.002 w
.56619 .5095 m .56515 .50826 L p
.56665 .51801 L 1 g
F P
s
P
p
.55661 .4905 m .56619 .5095 L .56548 .50792 L 1 g
F
P
p
.55661 .4905 m .56548 .50792 L .56426 .50535 L 1 g
F
P
p
.57337 .47291 m .56426 .50535 L .55402 .48459 L 1 g
F
P
p
.56233 .50144 m .56426 .50535 L .56307 .50286 L 1 g
F
P
p
.55661 .4905 m .56426 .50535 L .56233 .50144 L 1 g
F
P
p
.002 w
.57337 .47291 m .56664 .506 L .56426 .50535 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.52175 .51666 m .53349 .49698 L .56426 .50535 L p
1 g
F P
s
P
p
.002 w
.56426 .50535 m .56664 .506 L p
.56478 .50644 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56478 .50644 m .52175 .51666 L .56426 .50535 L 1 g
F
P
p
.002 w
.56664 .506 m .56548 .50792 L p
.56478 .50644 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55776 .49173 L p
1 g
F P
s
P
p
.002 w
.55776 .49173 m .55661 .4905 L p
.56307 .50286 L 1 g
F P
s
P
p
.56307 .50286 m .56713 .51061 L .55776 .49173 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55729 .49122 L p
1 g
F P
s
P
p
.002 w
.56426 .50535 m .53349 .49698 L p
.55182 .48592 L 1 g
F P
s
P
p
.54174 .47608 m .55729 .49122 L .54933 .48352 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55402 .48459 m .55729 .49122 L .55182 .48592 L 1 g
F
P
p
.55729 .49122 m .56426 .50535 L .55182 .48592 L 1 g
F
P
p
.56307 .50286 m .56548 .50792 L .56404 .50471 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54941 .53451 m .52175 .51666 L p
.56478 .50644 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56721 .52832 L p
1 g
F P
s
P
p
.56515 .50826 m .56721 .52832 L .56665 .51801 L 1 g
F
P
p
.002 w
.54941 .53451 m .56548 .50792 L p
.56619 .5095 L 1 g
F P
s
P
p
.57263 .52381 m .5671 .52636 L .56619 .5095 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.5671 .52636 m .54941 .53451 L .56619 .5095 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.59713 .51253 m .57496 .54881 L .5633 .54228 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56148 .54703 L p
1 g
F P
s
P
p
.57496 .54881 m .56006 .55074 L .56148 .54703 L 1 g
F
P
p
.002 w
.5633 .54228 m .56465 .54304 L p
.56148 .54703 L 1 g
F P
s
P
p
.002 w
.56465 .54304 m .57496 .54881 L p
.56148 .54703 L 1 g
F P
s
P
p
.002 w
.56148 .54703 m .56075 .54566 L p
.55662 .55316 L 1 g
F P
s
P
p
.56654 .52734 m .56148 .54703 L .56266 .54395 L 1 g
F
P
p
.56654 .52734 m .5618 .54764 L .56477 .53704 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54905 .56267 L p
1 g
F P
s
P
p
.56075 .54566 m .54905 .56267 L .55662 .55316 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56148 .54703 m .52371 .55543 L .5633 .54228 L 1 g
F
P
p
.56006 .55074 m .55837 .55095 L .56148 .54703 L 1 g
F
P
p
.55837 .55095 m .52371 .55543 L .56148 .54703 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.57496 .54881 m .54209 .57533 L .538 .5709 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .5744 L p
1 g
F P
s
P
p
.002 w
.54209 .57533 m .50814 .58737 L p
.53166 .5744 L 1 g
F P
s
P
p
.53362 .57385 m .53166 .5744 L .53289 .57372 L 1 g
F
P
p
.54209 .57533 m .53166 .5744 L .53362 .57385 L 1 g
F
P
p
.002 w
.53166 .5744 m .53128 .57265 L p
.52334 .57672 L 1 g
F P
s
P
p
.54854 .56129 m .53166 .5744 L .53584 .57209 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .5802 L p
1 g
F P
s
P
p
.53146 .57445 m .52146 .57959 L .51824 .57815 L 1 g
F
P
p
.002 w
.50223 .58946 m .49856 .58092 L p
.52146 .57959 L 1 g
F P
s
P
p
.53128 .57265 m .51091 .5802 L .52334 .57672 L 1 g
F
P
p
.002 w
.51091 .5802 m .51079 .57862 L p
.49958 .58086 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58019 L p
1 g
F P
s
P
p
.50223 .58946 m .45928 .57789 L .48337 .57975 L 1 g
F
P
p
.51079 .57862 m .48909 .58019 L .49908 .58096 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45893 .56716 m .49243 .56666 L .49856 .58092 L p
1 g
F P
s
P
p
.50223 .58946 m .48337 .57975 L .48909 .58019 L 1 g
F
P
p
.002 w
.48909 .58019 m .48921 .57862 L p
.48135 .57798 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46837 .57426 L p
1 g
F P
s
P
p
.48921 .57862 m .46837 .57426 L .48135 .57798 L 1 g
F
P
p
.48909 .58019 m .45893 .56716 L .49856 .58092 L 1 g
F
P
p
.48337 .57975 m .47815 .57706 L .48909 .58019 L 1 g
F
P
p
.47815 .57706 m .45893 .56716 L .48909 .58019 L 1 g
F
P
p
.46872 .57265 m .4576 .56821 L .45899 .56918 L 1 g
F
P
p
.002 w
.46837 .57426 m .46872 .57265 L p
.45899 .56918 L 1 g
F P
s
P
p
.48337 .57975 m .47769 .57931 L .45893 .56716 L 1 g
F
P
p
.002 w
.45928 .57789 m .45899 .56918 L p
.47769 .57931 L 1 g
F P
s
P
p
.002 w
.45899 .56918 m .45893 .56716 L p
.47769 .57931 L 1 g
F P
s
P
p
.002 w
.46809 .57552 m .46837 .57426 L p
.45899 .56918 L 1 g
F P
s
P
p
.002 w
.46837 .57426 m .4678 .57686 L p
.48135 .57798 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58019 L p
1 g
F P
s
P
p
.48135 .57798 m .4678 .57686 L .48909 .58019 L 1 g
F
P
p
.002 w
.49856 .58092 m .49953 .58318 L p
.48909 .58019 L 1 g
F P
s
P
p
.002 w
.49953 .58318 m .50223 .58946 L p
.48909 .58019 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51103 .58188 L p
1 g
F P
s
P
p
.002 w
.51103 .58188 m .51091 .5802 L p
.50272 .58124 L 1 g
F P
s
P
p
.50272 .58124 m .48889 .583 L .51103 .58188 L 1 g
F
P
p
.002 w
.48909 .58019 m .48889 .583 L p
.49908 .58096 L 1 g
F P
s
P
p
.002 w
.50223 .58946 m .45967 .58998 L .45928 .57789 L p
1 g
F P
s
P
p
.002 w
.49856 .58092 m .49243 .56666 L p
.52146 .57959 L 1 g
F P
s
P
p
.002 w
.51091 .5802 m .51111 .583 L p
.52334 .57672 L 1 g
F P
s
P
p
.53289 .57372 m .53146 .57445 L .49243 .56666 L 1 g
F
P
p
.53146 .57445 m .51824 .57815 L .49243 .56666 L 1 g
F
P
p
.49958 .58086 m .48889 .583 L .51091 .5802 L 1 g
F
P
p
.002 w
.50814 .58737 m .50223 .58946 L p
.53289 .57372 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53166 .5744 L p
1 g
F P
s
P
p
.52334 .57672 m .51111 .583 L .53166 .5744 L 1 g
F
P
p
.002 w
.538 .5709 m .54209 .57533 L p
.53289 .57372 L 1 g
F P
s
P
p
.54854 .56129 m .53189 .57545 L .54009 .56934 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.49243 .56666 m .52371 .55543 L .538 .5709 L p
1 g
F P
s
P
p
.53289 .57372 m .49243 .56666 L .538 .5709 L 1 g
F
P
p
.002 w
.53189 .57545 m .5322 .57686 L p
.53909 .5703 L 1 g
F P
s
P
p
.57496 .54881 m .538 .5709 L .56615 .54995 L 1 g
F
P
p
.54009 .56934 m .538 .5709 L .53909 .5703 L 1 g
F
P
p
.538 .5709 m .53189 .57545 L .53909 .5703 L 1 g
F
P
p
.002 w
.53166 .5744 m .53189 .57545 L p
.53584 .57209 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.538 .5709 m .52371 .55543 L p
.56615 .54995 L 1 g
F P
s
P
p
.002 w
.54905 .56267 m .54998 .56518 L p
.55662 .55316 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56148 .54703 L p
1 g
F P
s
P
p
.55662 .55316 m .54998 .56518 L .56148 .54703 L 1 g
F
P
p
.002 w
.56148 .54703 m .5618 .54764 L p
.56266 .54395 L 1 g
F P
s
P
p
.002 w
.52371 .55543 m .54941 .53451 L .5633 .54228 L p
1 g
F P
s
P
p
.59713 .51253 m .5633 .54228 L .56785 .52602 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.5633 .54228 m .54941 .53451 L p
.56785 .52602 L 1 g
F P
s
P
p
.002 w
.5618 .54764 m .56257 .5491 L p
.56477 .53704 L 1 g
F P
s
P
p
.002 w
.56721 .52832 m .56854 .53025 L p
.56665 .51801 L 1 g
F P
s
P
p
.002 w
.56548 .50792 m .54941 .53451 L p
.56478 .50644 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56619 .5095 L p
1 g
F P
s
P
p
.56665 .51801 m .56854 .53025 L .56619 .5095 L 1 g
F
P
p
.002 w
.56619 .5095 m .56713 .51061 L p
.56404 .50471 L 1 g
F P
s
P
p
.002 w
.56664 .506 m .59713 .51253 L p
.57263 .52381 L 1 g
F P
s
P
p
.55182 .48592 m .53349 .49698 L .54239 .47679 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54239 .47679 L p
1 g
F P
s
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.54933 .48352 L 1 g
F P
s
P
p
.54933 .48352 m .55834 .49233 L .54239 .47679 L 1 g
F
P
p
.52214 .46667 m .54239 .47679 L .53947 .47545 L 1 g
F
P
p
.52214 .46667 m .54123 .47634 L .53457 .4731 L 1 g
F
P
p
.002 w
.53349 .49698 m .4989 .48579 L p
.53731 .47444 L 1 g
F P
s
P
p
.002 w
.5379 .47473 m .53349 .49698 L p
.53731 .47444 L 1 g
F P
s
P
p
.54123 .47634 m .53689 .47424 L .53457 .4731 L 1 g
F
P
p
.002 w
.4989 .48579 m .50112 .47421 L .53689 .47424 L p
1 g
F P
s
P
p
.002 w
.53689 .47424 m .53799 .47424 L p
.53731 .47444 L 1 g
F P
s
P
p
.53731 .47444 m .4989 .48579 L .53689 .47424 L 1 g
F
P
p
.002 w
.53689 .47424 m .50112 .47421 L p
.51317 .46586 L 1 g
F P
s
P
p
.5159 .46396 m .52244 .46716 L .51317 .46586 L 1 g
F
P
p
.52244 .46716 m .53689 .47424 L .51317 .46586 L 1 g
F
P
p
.002 w
.50112 .47421 m .49964 .46406 L p
.5 .464 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .464 L p
1 g
F P
s
P
p
.002 w
.5 .464 m .5 .4634 L p
.51168 .46564 L 1 g
F P
s
P
p
.51168 .46564 m .52282 .46778 L .5 .464 L 1 g
F
P
p
.002 w
.54263 .47705 m .54302 .47747 L p
.53495 .4733 L 1 g
F P
s
P
p
.53457 .4731 m .53689 .47424 L .53495 .4733 L 1 g
F
P
p
.53689 .47424 m .54263 .47705 L .53495 .4733 L 1 g
F
P
p
.54123 .47634 m .54263 .47705 L .53689 .47424 L 1 g
F
P
p
.002 w
.53799 .47424 m .5379 .47473 L p
.53731 .47444 L 1 g
F P
s
P
p
.002 w
.5379 .47473 m .53799 .47424 L p
.54155 .47598 L 1 g
F P
s
P
p
.55633 .4832 m .54239 .47679 L .54155 .47598 L 1 g
F
P
p
.54239 .47679 m .5379 .47473 L .54155 .47598 L 1 g
F
P
p
.55633 .4832 m .55182 .48592 L .54239 .47679 L 1 g
F
P
p
.002 w
.55729 .49122 m .55834 .49233 L p
.54933 .48352 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54263 .47705 L p
.53947 .47545 L 1 g
F P
s
P
p
.002 w
.53799 .47424 m .57337 .47291 L p
.55633 .4832 L 1 g
F P
s
P
p
.002 w
.53469 .45092 m .53799 .47424 L .53689 .47424 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.53469 .45092 m .53689 .47424 L .5159 .46396 L 1 g
F
P
p
.002 w
.52244 .46716 m .52282 .46778 L p
.51168 .46564 L 1 g
F P
s
P
p
.52104 .46039 m .51317 .46586 L .5 .464 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .464 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .464 L .49964 .46406 L 1 g
F
P
p
.002 w
.49964 .46406 m .4994 .46238 L p
.52104 .46039 L 1 g
F P
s
P
p
.002 w
.5 .464 m .5 .46402 L p
.49964 .46406 L 1 g
F P
s
P
p
.002 w
.5 .46402 m .5 .46442 L p
.48994 .46544 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46402 L .48994 .46544 L 1 g
F
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46894 .47142 m .4642 .47282 L p
.47585 .46744 L 1 g
F P
s
P
p
.49699 .45766 m .47754 .4672 L .47585 .46744 L 1 g
F
P
p
.47754 .4672 m .46894 .47142 L .47585 .46744 L 1 g
F
P
p
.002 w
.48829 .46568 m .4994 .46238 L .49964 .46406 L p
1 g
F P
s
P
p
.002 w
.49699 .45766 m .4994 .46238 L .48829 .46568 L p
1 g
F P
s
P
p
.49699 .45766 m .48829 .46568 L .47754 .4672 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47754 .4672 L p
1 g
F P
s
P
p
.48994 .46544 m .5 .46442 L .47754 .4672 L 1 g
F
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.4642 .47282 m .49389 .45159 L .49699 .45766 L p
1 g
F P
s
P
p
.002 w
.46491 .47338 m .4642 .47282 L .46526 .47321 L p
1 g
F P
s
P
p
.46968 .47107 m .47011 .47089 L .46847 .47166 L 1 g
F
P
p
.47011 .47089 m .47071 .47062 L .46814 .47183 L 1 g
F
P
p
.002 w
.46465 .47351 m .4642 .47282 L .46491 .47338 L p
1 g
F P
s
P
p
.002 w
.46441 .47362 m .4642 .47282 L .46465 .47351 L p
1 g
F P
s
P
p
.47071 .47062 m .47147 .47029 L .46758 .47211 L 1 g
F
P
p
.47147 .47029 m .47235 .4699 L .46661 .47258 L 1 g
F
P
p
.002 w
.47304 .50736 m .46119 .50761 L .46412 .47376 L p
1 g
F P
s
P
p
.002 w
.46412 .47376 m .4642 .47282 L .46441 .47362 L p
1 g
F P
s
P
p
.002 w
.46441 .47362 m .47304 .50736 L p
.46412 .47376 L 1 g
F P
s
P
p
.002 w
.46367 .47397 m .4642 .47282 L .46412 .47376 L p
1 g
F P
s
P
p
.002 w
.46412 .47376 m .46119 .50761 L p
.46367 .47397 L 1 g
F P
s
P
p
.47235 .4699 m .47318 .46954 L .46503 .47333 L 1 g
F
P
p
.002 w
.46367 .47397 m .44975 .50405 L p
.46251 .47451 L 1 g
F P
s
P
p
.47318 .46954 m .47376 .46928 L .46251 .47451 L 1 g
F
P
p
.47318 .46954 m .46251 .47451 L .45761 .47679 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44975 .50405 m .43994 .49705 L .46251 .47451 L p
1 g
F P
s
P
p
.002 w
.46251 .47451 m .4642 .47282 L .46367 .47397 L p
1 g
F P
s
P
p
.002 w
.4642 .47282 m .43994 .49705 L .43979 .49686 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45761 .47679 L p
1 g
F P
s
P
p
.47376 .46928 m .47718 .46778 L .45761 .47679 L 1 g
F
P
p
.46246 .47453 m .46191 .47479 L .4642 .47282 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45761 .47679 L p
1 g
F P
s
P
p
.44339 .4905 m .45761 .47679 L .45038 .48381 L 1 g
F
P
p
.002 w
.44805 .4803 m .45941 .47504 L p
.44249 .49146 L 1 g
F P
s
P
p
.002 w
.45761 .47679 m .45698 .47747 L p
.45038 .48381 L 1 g
F P
s
P
p
.002 w
.4422 .49176 m .44215 .49182 L p
.44174 .49274 L 1 g
F P
s
P
p
.002 w
.43453 .5024 m .43949 .49749 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.44215 .49182 m .44166 .49233 L p
.43905 .49845 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44249 .49146 L p
1 g
F P
s
P
p
.45038 .48381 m .45698 .47747 L .44249 .49146 L 1 g
F
P
p
.002 w
.43979 .49686 m .43994 .49705 L .43949 .49749 L p
1 g
F P
s
P
p
.43234 .52902 m .43396 .50932 L .43994 .49705 L 1 g
F
P
p
.002 w
.43949 .49749 m .43994 .49705 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43396 .50932 L p
1 g
F P
s
P
p
.43905 .49845 m .44166 .49233 L .43396 .50932 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43712 .53242 m .43234 .52902 L p
.43994 .49705 L 1 g
F P
s
P
p
.002 w
.41799 .51877 m .43234 .52902 L p
.42671 .55698 L 1 g
F P
s
P
p
.002 w
.43234 .52902 m .43236 .52903 L p
.43234 .52915 L 1 g
F P
s
P
p
.42671 .55698 m .43234 .52902 L .43234 .52915 L 1 g
F
P
p
.002 w
.43235 .52896 m .43146 .53025 L p
.43382 .53491 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43276 .51216 L p
.43311 .51968 L 1 g
F P
s
P
p
.43317 .51897 m .43287 .51061 L .43311 .51968 L 1 g
F
P
p
.002 w
.43276 .51216 m .43146 .53025 L .43234 .52897 L p
1 g
F P
s
P
p
.002 w
.43236 .52903 m .43712 .53242 L .435 .53742 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43851 .54706 L p
1 g
F P
s
P
p
.43479 .53684 m .43146 .53025 L .43851 .54706 L 1 g
F
P
p
.002 w
.45075 .56319 m .45002 .56518 L p
.45673 .56786 L 1 g
F P
s
P
p
.002 w
.45893 .56716 m .45373 .56552 L p
.43712 .53242 L 1 g
F P
s
P
p
.45373 .56552 m .45161 .56385 L .43712 .53242 L 1 g
F
P
p
.002 w
.45068 .56339 m .45075 .56319 L p
.43915 .55059 L 1 g
F P
s
P
p
.44515 .55581 m .43915 .55059 L .45075 .56319 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45068 .56339 L p
1 g
F P
s
P
p
.43915 .55059 m .43743 .5491 L .45068 .56339 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46809 .57552 L p
1 g
F P
s
P
p
.4576 .56821 m .45002 .56518 L .46809 .57552 L 1 g
F
P
p
.002 w
.45373 .56552 m .45893 .56716 L .45899 .56918 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.36842 .44472 m .36829 .47809 L .3446 .47695 L p
1 g
F P
s
P
p
.002 w
.3446 .47695 m .34463 .43453 L .36842 .44472 L p
1 g
F P
s
P
p
.002 w
.54209 .57533 m .57496 .54881 L .59755 .55918 L p
1 g
F P
s
P
p
.002 w
.62393 .51643 m .59755 .55918 L .57496 .54881 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.62393 .51643 m .63453 .46654 L .65829 .46181 L p
1 g
F P
s
P
p
.004 w
.64788 .48261 m
.64905 .48302 L
s
P
p
.004 w
.64905 .48302 m
.65492 .48509 L
s
P
p
.004 w
.65492 .48509 m
.66647 .48916 L
s
P
p
.002 w
.65091 .40403 m .65829 .46181 L .63453 .46654 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51866 .30711 m .46665 .30072 L .47032 .27606 L p
1 g
F P
s
P
p
.002 w
.47032 .27606 m .52863 .28309 L .51866 .30711 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.42135 .33918 m .38492 .3616 L .37342 .33833 L p
1 g
F P
s
P
p
.002 w
.37342 .33833 m .41636 .31165 L .42135 .33918 L p
1 g
F P
s
P
p
.002 w
.37942 .41344 m .36842 .44472 L .34463 .43453 L p
1 g
F P
s
P
p
.002 w
.34463 .43453 m .35847 .39464 L .37942 .41344 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.62458 .35102 m .65091 .40403 L .62781 .415 L p
1 g
F P
s
P
p
.002 w
.63453 .46654 m .62781 .415 L .65091 .40403 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.57496 .54881 m .59713 .51253 L .62393 .51643 L p
1 g
F P
s
P
p
.002 w
.63453 .46654 m .62393 .51643 L .59713 .51253 L p
1 g
F P
s
P
p
.002 w
.56639 .33032 m .51866 .30711 L .52863 .28309 L p
1 g
F P
s
P
p
.002 w
.52863 .28309 m .58217 .30905 L .56639 .33032 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62781 .415 m .60424 .36775 L .62458 .35102 L p
1 g
F P
s
P
p
.002 w
.58217 .30905 m .62458 .35102 L .60424 .36775 L p
1 g
F P
s
P
p
.002 w
.40404 .49991 m .41799 .51877 L .39909 .53726 L p
1 g
F P
s
P
p
.002 w
.39909 .53726 m .37891 .51003 L .40404 .49991 L p
1 g
F P
s
P
p
.002 w
.42671 .55698 m .39909 .53726 L .41799 .51877 L p
1 g
F P
s
P
p
.002 w
.60424 .36775 m .56639 .33032 L .58217 .30905 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.40029 .38763 m .37942 .41344 L .35847 .39464 L p
1 g
F P
s
P
p
.002 w
.35847 .39464 m .38492 .3616 L .40029 .38763 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4639 .3301 m .42135 .33918 L .41636 .31165 L p
1 g
F P
s
P
p
.002 w
.41636 .31165 m .46665 .30072 L .4639 .3301 L p
1 g
F P
s
P
p
.002 w
.39675 .4778 m .40404 .49991 L .37891 .51003 L p
1 g
F P
s
P
p
.002 w
.37891 .51003 m .36829 .47809 L .39675 .4778 L p
1 g
F P
s
P
p
.002 w
.43712 .53242 m .45942 .53942 L .45893 .56716 L p
1 g
F P
s
P
p
.002 w
.49243 .56666 m .45893 .56716 L .45942 .53942 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.39692 .45476 m .39675 .4778 L .36829 .47809 L p
1 g
F P
s
P
p
.002 w
.36829 .47809 m .36842 .44472 L .39692 .45476 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.59713 .51253 m .60593 .4703 L .63453 .46654 L p
1 g
F P
s
P
p
.002 w
.62781 .415 m .63453 .46654 L .60593 .4703 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.45942 .53942 m .48258 .53901 L .49243 .56666 L p
1 g
F P
s
P
p
.002 w
.52371 .55543 m .49243 .56666 L .48258 .53901 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4289 .37022 m .40029 .38763 L .38492 .3616 L p
1 g
F P
s
P
p
.002 w
.38492 .3616 m .42135 .33918 L .4289 .37022 L p
1 g
F P
s
P
p
.002 w
.50784 .33562 m .4639 .3301 L .46665 .30072 L p
1 g
F P
s
P
p
.002 w
.46665 .30072 m .51866 .30711 L .50784 .33562 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.40461 .43323 m .39692 .45476 L .36842 .44472 L p
1 g
F P
s
P
p
.002 w
.36842 .44472 m .37942 .41344 L .40461 .43323 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60593 .4703 m .6001 .42676 L .62781 .415 L p
1 g
F P
s
P
p
.002 w
.60424 .36775 m .62781 .415 L .6001 .42676 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48258 .53901 m .50413 .53116 L .52371 .55543 L p
1 g
F P
s
P
p
.002 w
.54941 .53451 m .52371 .55543 L .50413 .53116 L p
1 g
F P
s
P
p
.002 w
.60593 .4703 m .59713 .51253 L .56664 .506 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.54813 .35528 m .50784 .33562 L .51866 .30711 L p
1 g
F P
s
P
p
.002 w
.51866 .30711 m .56639 .33032 L .54813 .35528 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41907 .41555 m .40461 .43323 L .37942 .41344 L p
1 g
F P
s
P
p
.002 w
.37942 .41344 m .40029 .38763 L .41907 .41555 L p
1 g
F P
s
P
p
.002 w
.6001 .42676 m .58011 .38688 L .60424 .36775 L p
1 g
F P
s
P
p
.002 w
.56639 .33032 m .60424 .36775 L .58011 .38688 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.46222 .36326 m .4289 .37022 L .42135 .33918 L p
1 g
F P
s
P
p
.002 w
.42135 .33918 m .4639 .3301 L .46222 .36326 L p
1 g
F P
s
P
p
.002 w
.41799 .51877 m .40404 .49991 L .4328 .48737 L p
1 g
F P
s
P
p
.002 w
.58011 .38688 m .54813 .35528 L .56639 .33032 L p
1 g
F P
s
P
p
.002 w
.43994 .49705 m .44975 .50405 L .43712 .53242 L p
1 g
F P
s
P
p
.002 w
.45942 .53942 m .43712 .53242 L .44975 .50405 L p
1 g
F P
s
P
p
.002 w
.4291 .47604 m .4328 .48737 L .40404 .49991 L p
1 g
F P
s
P
p
.002 w
.40404 .49991 m .39675 .4778 L .4291 .47604 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44975 .50405 m .46119 .50761 L .45942 .53942 L p
1 g
F P
s
P
p
.002 w
.48258 .53901 m .45942 .53942 L .46119 .50761 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.50413 .53116 m .52175 .51666 L .54941 .53451 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42924 .46425 m .4291 .47604 L .39675 .4778 L p
1 g
F P
s
P
p
.002 w
.39675 .4778 m .39692 .45476 L .42924 .46425 L p
1 g
F P
s
P
p
.002 w
.56664 .506 m .57337 .47291 L .60593 .4703 L p
1 g
F P
s
P
p
.002 w
.6001 .42676 m .60593 .4703 L .57337 .47291 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.46119 .50761 m .47304 .50736 L .48258 .53901 L p
1 g
F P
s
P
p
.002 w
.50413 .53116 m .48258 .53901 L .47304 .50736 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.4388 .40369 m .41907 .41555 L .40029 .38763 L p
1 g
F P
s
P
p
.002 w
.40029 .38763 m .4289 .37022 L .4388 .40369 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.49655 .36768 m .46222 .36326 L .4639 .3301 L p
1 g
F P
s
P
p
.002 w
.4639 .3301 m .50784 .33562 L .49655 .36768 L p
1 g
F P
s
P
p
.002 w
.43322 .45328 m .42924 .46425 L .39692 .45476 L p
1 g
F P
s
P
p
.002 w
.39692 .45476 m .40461 .43323 L .43322 .45328 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.47304 .50736 m .48404 .50329 L .50413 .53116 L p
1 g
F P
s
P
p
.002 w
.52175 .51666 m .50413 .53116 L .48404 .50329 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.58011 .38688 m .6001 .42676 L .56869 .43889 L p
1 g
F P
s
P
p
.002 w
.57337 .47291 m .56869 .43889 L .6001 .42676 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44065 .44431 m .43322 .45328 L .40461 .43323 L p
1 g
F P
s
P
p
.002 w
.40461 .43323 m .41907 .41555 L .44065 .44431 L p
1 g
F P
s
P
p
.002 w
.528 .38308 m .49655 .36768 L .50784 .33562 L p
1 g
F P
s
P
p
.002 w
.50784 .33562 m .54813 .35528 L .528 .38308 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.46169 .39902 m .4388 .40369 L .4289 .37022 L p
1 g
F P
s
P
p
.002 w
.4289 .37022 m .46222 .36326 L .46169 .39902 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.56869 .43889 m .553 .40776 L .58011 .38688 L p
1 g
F P
s
P
p
.002 w
.54813 .35528 m .58011 .38688 L .553 .40776 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.553 .40776 m .528 .38308 L .54813 .35528 L p
1 g
F P
s
P
p
.002 w
.48404 .50329 m .49298 .49584 L .52175 .51666 L p
1 g
F P
s
P
p
.002 w
.53349 .49698 m .52175 .51666 L .49298 .49584 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.4328 .48737 m .4291 .47604 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56869 .43889 m .57337 .47291 L .53799 .47424 L p
1 g
F P
s
P
p
.002 w
.4291 .47604 m .42924 .46425 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45072 .43834 m .44065 .44431 L .41907 .41555 L p
1 g
F P
s
P
p
.002 w
.41907 .41555 m .4388 .40369 L .45072 .43834 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42924 .46425 m .43322 .45328 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.48522 .40213 m .46169 .39902 L .46222 .36326 L p
1 g
F P
s
P
p
.002 w
.46222 .36326 m .49655 .36768 L .48522 .40213 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49298 .49584 m .4989 .48579 L .53349 .49698 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.43322 .45328 m .44065 .44431 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.53799 .47424 m .53469 .45092 L .56869 .43889 L p
1 g
F P
s
P
p
.002 w
.553 .40776 m .56869 .43889 L .53469 .45092 L p
1 g
F P
s
P
p
.002 w
.46236 .43602 m .45072 .43834 L .4388 .40369 L p
1 g
F P
s
P
p
.002 w
.4388 .40369 m .46169 .39902 L .46236 .43602 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.50675 .41271 m .48522 .40213 L .49655 .36768 L p
1 g
F P
s
P
p
.002 w
.49655 .36768 m .528 .38308 L .50675 .41271 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.44065 .44431 m .45072 .43834 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.53469 .45092 m .52388 .42961 L .553 .40776 L p
1 g
F P
s
P
p
.002 w
.528 .38308 m .553 .40776 L .52388 .42961 L p
1 g
F P
s
P
p
.002 w
.4852 .44302 m .49389 .45159 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.004 w
.4875 .44529 m
.5 .43051 L
s
P
p
.002 w
.47429 .43764 m .4852 .44302 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.46236 .43602 m .47429 .43764 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.45072 .43834 m .46236 .43602 L .4642 .47282 L closepath p
1 g
F P
s
P
p
.002 w
.52388 .42961 m .50675 .41271 L .528 .38308 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.47429 .43764 m .46236 .43602 L .46169 .39902 L p
1 g
F P
s
P
p
.002 w
.46169 .39902 m .48522 .40213 L .47429 .43764 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52388 .42961 m .53469 .45092 L .4994 .46238 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.4852 .44302 m .47429 .43764 L .48522 .40213 L p
1 g
F P
s
P
p
.002 w
.48522 .40213 m .50675 .41271 L .4852 .44302 L p
1 g
F P
s
P
p
.002 w
.4994 .46238 m .49389 .45159 L .52388 .42961 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.50675 .41271 m .52388 .42961 L .49389 .45159 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.004 w
.46305 .47418 m
.4642 .47282 L
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.49389 .45159 m .4852 .44302 L .50675 .41271 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.44208 .49897 m
.46305 .47418 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .73596 .51364 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .44208 .49897 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.29845)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.29845)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48666 .46015 m .50513 .46151 L .5026 .43314 L p
1 g
F P
s
P
p
.002 w
.5026 .43314 m .49325 .43245 L .48666 .46015 L p
1 g
F P
s
P
p
.002 w
.51166 .43079 m .5026 .43314 L .50513 .46151 L p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .49325 .43245 L .5026 .43314 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .5026 .43314 L .51166 .43079 L closepath p
1 g
F P
s
P
p
.002 w
.46961 .45295 m .48666 .46015 L .49325 .43245 L p
1 g
F P
s
P
p
.002 w
.49325 .43245 m .48463 .4288 L .46961 .45295 L p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .48463 .4288 L .49325 .43245 L closepath p
1 g
F P
s
P
p
.002 w
.50513 .46151 m .52305 .45687 L .51166 .43079 L p
1 g
F P
s
P
p
.002 w
.51948 .42565 m .51166 .43079 L .52305 .45687 L p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .51166 .43079 L .51948 .42565 L closepath p
1 g
F P
s
P
p
.002 w
.45581 .44066 m .46961 .45295 L .48463 .4288 L p
1 g
F P
s
P
p
.002 w
.48463 .4288 m .47767 .42257 L .45581 .44066 L p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .47767 .42257 L .48463 .4288 L closepath p
1 g
F P
s
P
p
.002 w
.52305 .45687 m .53852 .44674 L .51948 .42565 L p
1 g
F P
s
P
p
.002 w
.52519 .41828 m .51948 .42565 L .53852 .44674 L p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .51948 .42565 L .52519 .41828 L closepath p
1 g
F P
s
P
p
.002 w
.44676 .42459 m .45581 .44066 L .47767 .42257 L p
1 g
F P
s
P
p
.002 w
.47767 .42257 m .47312 .41444 L .44676 .42459 L p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .47312 .41444 L .47767 .42257 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .52819 .40946 L .52814 .40014 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .52814 .40014 L .52503 .39134 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .52503 .39134 L .51921 .38401 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .51921 .38401 L .51128 .37896 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .51128 .37896 L .50213 .37673 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .50213 .37673 L .49275 .37759 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .49275 .37759 L .48416 .38142 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .48416 .38142 L .4773 .38781 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .4773 .38781 L .47291 .39606 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .47291 .39606 L .47147 .40527 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .47147 .40527 L .47312 .41444 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .40472 m .52519 .41828 L .52819 .40946 L closepath p
1 g
F P
s
P
p
.002 w
.53852 .44674 m .54986 .43218 L .52519 .41828 L p
1 g
F P
s
P
p
.002 w
.52819 .40946 m .52519 .41828 L .54986 .43218 L p
1 g
F P
s
P
p
.002 w
.44344 .40644 m .44676 .42459 L .47312 .41444 L p
1 g
F P
s
P
p
.002 w
.47312 .41444 m .47147 .40527 L .44344 .40644 L p
1 g
F P
s
P
p
.002 w
.48033 .48733 m .50755 .48932 L .50513 .46151 L p
1 g
F P
s
P
p
.002 w
.50513 .46151 m .48666 .46015 L .48033 .48733 L p
1 g
F P
s
P
p
.002 w
.52305 .45687 m .50513 .46151 L .50755 .48932 L p
1 g
F P
s
P
p
.002 w
.4552 .47675 m .48033 .48733 L .48666 .46015 L p
1 g
F P
s
P
p
.002 w
.48666 .46015 m .46961 .45295 L .4552 .47675 L p
1 g
F P
s
P
p
.002 w
.50755 .48932 m .53396 .48251 L .52305 .45687 L p
1 g
F P
s
P
p
.002 w
.53852 .44674 m .52305 .45687 L .53396 .48251 L p
1 g
F P
s
P
p
.002 w
.52814 .40014 m .52819 .40946 L .55584 .41473 L p
1 g
F P
s
P
p
.002 w
.54986 .43218 m .55584 .41473 L .52819 .40946 L p
1 g
F P
s
P
p
.002 w
.43483 .45867 m .4552 .47675 L .46961 .45295 L p
1 g
F P
s
P
p
.002 w
.46961 .45295 m .45581 .44066 L .43483 .45867 L p
1 g
F P
s
P
p
.002 w
.44625 .38817 m .44344 .40644 L .47147 .40527 L p
1 g
F P
s
P
p
.002 w
.47147 .40527 m .47291 .39606 L .44625 .38817 L p
1 g
F P
s
P
p
.002 w
.55584 .41473 m .55579 .39626 L .52814 .40014 L p
1 g
F P
s
P
p
.002 w
.52503 .39134 m .52814 .40014 L .55579 .39626 L p
1 g
F P
s
P
p
.002 w
.53396 .48251 m .55678 .46761 L .53852 .44674 L p
1 g
F P
s
P
p
.002 w
.54986 .43218 m .53852 .44674 L .55678 .46761 L p
1 g
F P
s
P
p
.002 w
.45492 .37178 m .44625 .38817 L .47291 .39606 L p
1 g
F P
s
P
p
.002 w
.47291 .39606 m .4773 .38781 L .45492 .37178 L p
1 g
F P
s
P
p
.002 w
.42142 .43499 m .43483 .45867 L .45581 .44066 L p
1 g
F P
s
P
p
.002 w
.45581 .44066 m .44676 .42459 L .42142 .43499 L p
1 g
F P
s
P
p
.002 w
.55579 .39626 m .54967 .37879 L .52503 .39134 L p
1 g
F P
s
P
p
.002 w
.51921 .38401 m .52503 .39134 L .54967 .37879 L p
1 g
F P
s
P
p
.002 w
.46852 .35905 m .45492 .37178 L .4773 .38781 L p
1 g
F P
s
P
p
.002 w
.4773 .38781 m .48416 .38142 L .46852 .35905 L p
1 g
F P
s
P
p
.002 w
.55678 .46761 m .57355 .44617 L .54986 .43218 L p
1 g
F P
s
P
p
.002 w
.55584 .41473 m .54986 .43218 L .57355 .44617 L p
1 g
F P
s
P
p
.002 w
.54967 .37879 m .53813 .36421 L .51921 .38401 L p
1 g
F P
s
P
p
.002 w
.51128 .37896 m .51921 .38401 L .53813 .36421 L p
1 g
F P
s
P
p
.002 w
.48558 .35142 m .46852 .35905 L .48416 .38142 L p
1 g
F P
s
P
p
.002 w
.48416 .38142 m .49275 .37759 L .48558 .35142 L p
1 g
F P
s
P
p
.002 w
.53813 .36421 m .52241 .35415 L .51128 .37896 L p
1 g
F P
s
P
p
.002 w
.50213 .37673 m .51128 .37896 L .52241 .35415 L p
1 g
F P
s
P
p
.002 w
.50423 .34972 m .48558 .35142 L .49275 .37759 L p
1 g
F P
s
P
p
.002 w
.49275 .37759 m .50213 .37673 L .50423 .34972 L p
1 g
F P
s
P
p
.002 w
.41645 .40821 m .42142 .43499 L .44676 .42459 L p
1 g
F P
s
P
p
.002 w
.44676 .42459 m .44344 .40644 L .41645 .40821 L p
1 g
F P
s
P
p
.002 w
.52241 .35415 m .50423 .34972 L .50213 .37673 L p
1 g
F P
s
P
p
.002 w
.55579 .39626 m .55584 .41473 L .58244 .42044 L p
1 g
F P
s
P
p
.002 w
.57355 .44617 m .58244 .42044 L .55584 .41473 L p
1 g
F P
s
P
p
.002 w
.47441 .51348 m .50981 .51606 L .50755 .48932 L p
1 g
F P
s
P
p
.002 w
.50755 .48932 m .48033 .48733 L .47441 .51348 L p
1 g
F P
s
P
p
.002 w
.53396 .48251 m .50755 .48932 L .50981 .51606 L p
1 g
F P
s
P
p
.002 w
.4417 .49974 m .47441 .51348 L .48033 .48733 L p
1 g
F P
s
P
p
.002 w
.48033 .48733 m .4552 .47675 L .4417 .49974 L p
1 g
F P
s
P
p
.002 w
.42053 .38121 m .41645 .40821 L .44344 .40644 L p
1 g
F P
s
P
p
.002 w
.44344 .40644 m .44625 .38817 L .42053 .38121 L p
1 g
F P
s
P
p
.002 w
.50981 .51606 m .54419 .50723 L .53396 .48251 L p
1 g
F P
s
P
p
.002 w
.55678 .46761 m .53396 .48251 L .54419 .50723 L p
1 g
F P
s
P
p
.002 w
.41513 .47626 m .4417 .49974 L .4552 .47675 L p
1 g
F P
s
P
p
.002 w
.4552 .47675 m .43483 .45867 L .41513 .47626 L p
1 g
F P
s
P
p
.002 w
.58244 .42044 m .58244 .39317 L .55579 .39626 L p
1 g
F P
s
P
p
.002 w
.54967 .37879 m .55579 .39626 L .58244 .39317 L p
1 g
F P
s
P
p
.002 w
.54419 .50723 m .57391 .48788 L .55678 .46761 L p
1 g
F P
s
P
p
.002 w
.57355 .44617 m .55678 .46761 L .57391 .48788 L p
1 g
F P
s
P
p
.002 w
.43329 .35693 m .42053 .38121 L .44625 .38817 L p
1 g
F P
s
P
p
.002 w
.44625 .38817 m .45492 .37178 L .43329 .35693 L p
1 g
F P
s
P
p
.002 w
.39759 .44545 m .41513 .47626 L .43483 .45867 L p
1 g
F P
s
P
p
.002 w
.43483 .45867 m .42142 .43499 L .39759 .44545 L p
1 g
F P
s
P
p
.002 w
.58244 .39317 m .57347 .36732 L .54967 .37879 L p
1 g
F P
s
P
p
.002 w
.53813 .36421 m .54967 .37879 L .57347 .36732 L p
1 g
F P
s
P
p
.002 w
.45339 .33807 m .43329 .35693 L .45492 .37178 L p
1 g
F P
s
P
p
.002 w
.45492 .37178 m .46852 .35905 L .45339 .33807 L p
1 g
F P
s
P
p
.002 w
.57391 .48788 m .59581 .46 L .57355 .44617 L p
1 g
F P
s
P
p
.002 w
.58244 .42044 m .57355 .44617 L .59581 .46 L p
1 g
F P
s
P
p
.002 w
.57347 .36732 m .55644 .34572 L .53813 .36421 L p
1 g
F P
s
P
p
.002 w
.52241 .35415 m .53813 .36421 L .55644 .34572 L p
1 g
F P
s
P
p
.002 w
.47864 .32674 m .45339 .33807 L .46852 .35905 L p
1 g
F P
s
P
p
.002 w
.46852 .35905 m .48558 .35142 L .47864 .32674 L p
1 g
F P
s
P
p
.002 w
.39102 .41056 m .39759 .44545 L .42142 .43499 L p
1 g
F P
s
P
p
.002 w
.42142 .43499 m .41645 .40821 L .39102 .41056 L p
1 g
F P
s
P
p
.002 w
.55644 .34572 m .53319 .33079 L .52241 .35415 L p
1 g
F P
s
P
p
.002 w
.50423 .34972 m .52241 .35415 L .53319 .33079 L p
1 g
F P
s
P
p
.002 w
.50626 .32421 m .47864 .32674 L .48558 .35142 L p
1 g
F P
s
P
p
.002 w
.48558 .35142 m .50423 .34972 L .50626 .32421 L p
1 g
F P
s
P
p
.002 w
.53319 .33079 m .50626 .32421 L .50423 .34972 L p
1 g
F P
s
P
p
.002 w
.59581 .46 m .60748 .42651 L .58244 .42044 L p
1 g
F P
s
P
p
.002 w
.58244 .39317 m .58244 .42044 L .60748 .42651 L p
1 g
F P
s
P
p
.002 w
.46901 .53808 m .51188 .5412 L .50981 .51606 L p
1 g
F P
s
P
p
.002 w
.50981 .51606 m .47441 .51348 L .46901 .53808 L p
1 g
F P
s
P
p
.002 w
.54419 .50723 m .50981 .51606 L .51188 .5412 L p
1 g
F P
s
P
p
.002 w
.39626 .37533 m .39102 .41056 L .41645 .40821 L p
1 g
F P
s
P
p
.002 w
.41645 .40821 m .42053 .38121 L .39626 .37533 L p
1 g
F P
s
P
p
.002 w
.42936 .52148 m .46901 .53808 L .47441 .51348 L p
1 g
F P
s
P
p
.002 w
.47441 .51348 m .4417 .49974 L .42936 .52148 L p
1 g
F P
s
P
p
.002 w
.51188 .5412 m .55352 .53053 L .54419 .50723 L p
1 g
F P
s
P
p
.002 w
.57391 .48788 m .54419 .50723 L .55352 .53053 L p
1 g
F P
s
P
p
.002 w
.60748 .42651 m .60757 .39095 L .58244 .39317 L p
1 g
F P
s
P
p
.002 w
.57347 .36732 m .58244 .39317 L .60757 .39095 L p
1 g
F P
s
P
p
.002 w
.39713 .49308 m .42936 .52148 L .4417 .49974 L p
1 g
F P
s
P
p
.002 w
.4417 .49974 m .41513 .47626 L .39713 .49308 L p
1 g
F P
s
P
p
.002 w
.41286 .3436 m .39626 .37533 L .42053 .38121 L p
1 g
F P
s
P
p
.002 w
.42053 .38121 m .43329 .35693 L .41286 .3436 L p
1 g
F P
s
P
p
.002 w
.55352 .53053 m .58956 .50714 L .57391 .48788 L p
1 g
F P
s
P
p
.002 w
.59581 .46 m .57391 .48788 L .58956 .50714 L p
1 g
F P
s
P
p
.002 w
.37578 .45578 m .39713 .49308 L .41513 .47626 L p
1 g
F P
s
P
p
.002 w
.41513 .47626 m .39759 .44545 L .37578 .45578 L p
1 g
F P
s
P
p
.002 w
.60757 .39095 m .59593 .35717 L .57347 .36732 L p
1 g
F P
s
P
p
.002 w
.55644 .34572 m .57347 .36732 L .59593 .35717 L p
1 g
F P
s
P
p
.002 w
.43907 .31891 m .41286 .3436 L .43329 .35693 L p
1 g
F P
s
P
p
.002 w
.43329 .35693 m .45339 .33807 L .43907 .31891 L p
1 g
F P
s
P
p
.002 w
.58956 .50714 m .61617 .47341 L .59581 .46 L p
1 g
F P
s
P
p
.002 w
.60748 .42651 m .59581 .46 L .61617 .47341 L p
1 g
F P
s
P
p
.002 w
.59593 .35717 m .57375 .32892 L .55644 .34572 L p
1 g
F P
s
P
p
.002 w
.53319 .33079 m .55644 .34572 L .57375 .32892 L p
1 g
F P
s
P
p
.002 w
.36772 .41347 m .37578 .45578 L .39759 .44545 L p
1 g
F P
s
P
p
.002 w
.39759 .44545 m .39102 .41056 L .36772 .41347 L p
1 g
F P
s
P
p
.002 w
.47207 .30406 m .43907 .31891 L .45339 .33807 L p
1 g
F P
s
P
p
.002 w
.45339 .33807 m .47864 .32674 L .47207 .30406 L p
1 g
F P
s
P
p
.002 w
.57375 .32892 m .54339 .30938 L .53319 .33079 L p
1 g
F P
s
P
p
.002 w
.50626 .32421 m .53319 .33079 L .54339 .30938 L p
1 g
F P
s
P
p
.002 w
.50818 .30076 m .47207 .30406 L .47864 .32674 L p
1 g
F P
s
P
p
.002 w
.47864 .32674 m .50626 .32421 L .50818 .30076 L p
1 g
F P
s
P
p
.002 w
.54339 .30938 m .50818 .30076 L .50626 .32421 L p
1 g
F P
s
P
p
.002 w
.61617 .47341 m .63042 .43282 L .60748 .42651 L p
1 g
F P
s
P
p
.002 w
.60757 .39095 m .60748 .42651 L .63042 .43282 L p
1 g
F P
s
P
p
.002 w
.37398 .37068 m .36772 .41347 L .39102 .41056 L p
1 g
F P
s
P
p
.002 w
.39102 .41056 m .39626 .37533 L .37398 .37068 L p
1 g
F P
s
P
p
.002 w
.46424 .5606 m .51371 .56419 L .51188 .5412 L p
1 g
F P
s
P
p
.002 w
.51188 .5412 m .46901 .53808 L .46424 .5606 L p
1 g
F P
s
P
p
.002 w
.55352 .53053 m .51188 .5412 L .51371 .56419 L p
1 g
F P
s
P
p
.002 w
.41849 .54149 m .46424 .5606 L .46901 .53808 L p
1 g
F P
s
P
p
.002 w
.46901 .53808 m .42936 .52148 L .41849 .54149 L p
1 g
F P
s
P
p
.002 w
.51371 .56419 m .56175 .55191 L .55352 .53053 L p
1 g
F P
s
P
p
.002 w
.58956 .50714 m .55352 .53053 L .56175 .55191 L p
1 g
F P
s
P
p
.002 w
.63042 .43282 m .63062 .38966 L .60757 .39095 L p
1 g
F P
s
P
p
.002 w
.59593 .35717 m .60757 .39095 L .63062 .38966 L p
1 g
F P
s
P
p
.002 w
.38124 .50877 m .41849 .54149 L .42936 .52148 L p
1 g
F P
s
P
p
.002 w
.42936 .52148 m .39713 .49308 L .38124 .50877 L p
1 g
F P
s
P
p
.002 w
.39407 .33209 m .37398 .37068 L .39626 .37533 L p
1 g
F P
s
P
p
.002 w
.39626 .37533 m .41286 .3436 L .39407 .33209 L p
1 g
F P
s
P
p
.002 w
.56175 .55191 m .60337 .52497 L .58956 .50714 L p
1 g
F P
s
P
p
.002 w
.61617 .47341 m .58956 .50714 L .60337 .52497 L p
1 g
F P
s
P
p
.002 w
.35651 .46575 m .38124 .50877 L .39713 .49308 L p
1 g
F P
s
P
p
.002 w
.39713 .49308 m .37578 .45578 L .35651 .46575 L p
1 g
F P
s
P
p
.002 w
.63062 .38966 m .61658 .34861 L .59593 .35717 L p
1 g
F P
s
P
p
.002 w
.57375 .32892 m .59593 .35717 L .61658 .34861 L p
1 g
F P
s
P
p
.002 w
.4259 .30203 m .39407 .33209 L .41286 .3436 L p
1 g
F P
s
P
p
.002 w
.41286 .3436 m .43907 .31891 L .4259 .30203 L p
1 g
F P
s
P
p
.002 w
.60337 .52497 m .63415 .48609 L .61617 .47341 L p
1 g
F P
s
P
p
.002 w
.63042 .43282 m .61617 .47341 L .63415 .48609 L p
1 g
F P
s
P
p
.002 w
.61658 .34861 m .58967 .31423 L .57375 .32892 L p
1 g
F P
s
P
p
.002 w
.54339 .30938 m .57375 .32892 L .58967 .31423 L p
1 g
F P
s
P
p
.002 w
.3471 .4169 m .35651 .46575 L .37578 .45578 L p
1 g
F P
s
P
p
.002 w
.37578 .45578 m .36772 .41347 L .3471 .4169 L p
1 g
F P
s
P
p
.002 w
.46601 .28394 m .4259 .30203 L .43907 .31891 L p
1 g
F P
s
P
p
.002 w
.43907 .31891 m .47207 .30406 L .46601 .28394 L p
1 g
F P
s
P
p
.002 w
.58967 .31423 m .55277 .29042 L .54339 .30938 L p
1 g
F P
s
P
p
.002 w
.50818 .30076 m .54339 .30938 L .55277 .29042 L p
1 g
F P
s
P
p
.002 w
.50995 .27991 m .46601 .28394 L .47207 .30406 L p
1 g
F P
s
P
p
.002 w
.47207 .30406 m .50818 .30076 L .50995 .27991 L p
1 g
F P
s
P
p
.002 w
.55277 .29042 m .50995 .27991 L .50818 .30076 L p
1 g
F P
s
P
p
.002 w
.63062 .38966 m .63042 .43282 L .6507 .43925 L p
1 g
F P
s
P
p
.002 w
.63415 .48609 m .6507 .43925 L .63042 .43282 L p
1 g
F P
s
P
p
.002 w
.35424 .36743 m .3471 .4169 L .36772 .41347 L p
1 g
F P
s
P
p
.002 w
.36772 .41347 m .37398 .37068 L .35424 .36743 L p
1 g
F P
s
P
p
.002 w
.46025 .58049 m .51524 .58447 L .51371 .56419 L p
1 g
F P
s
P
p
.002 w
.51371 .56419 m .46424 .5606 L .46025 .58049 L p
1 g
F P
s
P
p
.002 w
.56175 .55191 m .51371 .56419 L .51524 .58447 L p
1 g
F P
s
P
p
.002 w
.40936 .55928 m .46025 .58049 L .46424 .5606 L p
1 g
F P
s
P
p
.002 w
.46424 .5606 m .41849 .54149 L .40936 .55928 L p
1 g
F P
s
P
p
.002 w
.51524 .58447 m .56865 .57084 L .56175 .55191 L p
1 g
F P
s
P
p
.002 w
.60337 .52497 m .56175 .55191 L .56865 .57084 L p
1 g
F P
s
P
p
.002 w
.6507 .43925 m .65103 .38938 L .63062 .38966 L p
1 g
F P
s
P
p
.002 w
.61658 .34861 m .63062 .38966 L .65103 .38938 L p
1 g
F P
s
P
p
.002 w
.3679 .52295 m .40936 .55928 L .41849 .54149 L p
1 g
F P
s
P
p
.002 w
.41849 .54149 m .38124 .50877 L .3679 .52295 L p
1 g
F P
s
P
p
.002 w
.3774 .32275 m .35424 .36743 L .37398 .37068 L p
1 g
F P
s
P
p
.002 w
.37398 .37068 m .39407 .33209 L .3774 .32275 L p
1 g
F P
s
P
p
.002 w
.56865 .57084 m .61496 .54094 L .60337 .52497 L p
1 g
F P
s
P
p
.002 w
.63415 .48609 m .60337 .52497 L .61496 .54094 L p
1 g
F P
s
P
p
.002 w
.34031 .47515 m .3679 .52295 L .38124 .50877 L p
1 g
F P
s
P
p
.002 w
.38124 .50877 m .35651 .46575 L .34031 .47515 L p
1 g
F P
s
P
p
.002 w
.65103 .38938 m .63489 .34188 L .61658 .34861 L p
1 g
F P
s
P
p
.002 w
.58967 .31423 m .61658 .34861 L .63489 .34188 L p
1 g
F P
s
P
p
.002 w
.41419 .28791 m .3774 .32275 L .39407 .33209 L p
1 g
F P
s
P
p
.002 w
.39407 .33209 m .4259 .30203 L .41419 .28791 L p
1 g
F P
s
P
p
.002 w
.61496 .54094 m .64926 .49775 L .63415 .48609 L p
1 g
F P
s
P
p
.002 w
.6507 .43925 m .63415 .48609 L .64926 .49775 L p
1 g
F P
s
P
p
.002 w
.63489 .34188 m .60381 .30205 L .58967 .31423 L p
1 g
F P
s
P
p
.002 w
.55277 .29042 m .58967 .31423 L .60381 .30205 L p
1 g
F P
s
P
p
.002 w
.32974 .4208 m .34031 .47515 L .35651 .46575 L p
1 g
F P
s
P
p
.002 w
.35651 .46575 m .3471 .4169 L .32974 .4208 L p
1 g
F P
s
P
p
.002 w
.46063 .26693 m .41419 .28791 L .4259 .30203 L p
1 g
F P
s
P
p
.002 w
.4259 .30203 m .46601 .28394 L .46063 .26693 L p
1 g
F P
s
P
p
.002 w
.60381 .30205 m .56112 .27444 L .55277 .29042 L p
1 g
F P
s
P
p
.002 w
.50995 .27991 m .55277 .29042 L .56112 .27444 L p
1 g
F P
s
P
p
.002 w
.51153 .26225 m .46063 .26693 L .46601 .28394 L p
1 g
F P
s
P
p
.002 w
.46601 .28394 m .50995 .27991 L .51153 .26225 L p
1 g
F P
s
P
p
.002 w
.56112 .27444 m .51153 .26225 L .50995 .27991 L p
1 g
F P
s
P
p
.002 w
.65103 .38938 m .6507 .43925 L .66776 .44567 L p
1 g
F P
s
P
p
.002 w
.64926 .49775 m .66776 .44567 L .6507 .43925 L p
1 g
F P
s
P
p
.002 w
.3376 .3657 m .32974 .4208 L .3471 .4169 L p
1 g
F P
s
P
p
.002 w
.3471 .4169 m .35424 .36743 L .3376 .3657 L p
1 g
F P
s
P
p
.002 w
.45714 .59717 m .51642 .60146 L .51524 .58447 L p
1 g
F P
s
P
p
.002 w
.51524 .58447 m .46025 .58049 L .45714 .59717 L p
1 g
F P
s
P
p
.002 w
.56865 .57084 m .51524 .58447 L .51642 .60146 L p
1 g
F P
s
P
p
.002 w
.40228 .57435 m .45714 .59717 L .46025 .58049 L p
1 g
F P
s
P
p
.002 w
.46025 .58049 m .40936 .55928 L .40228 .57435 L p
1 g
F P
s
P
p
.002 w
.51642 .60146 m .57401 .58679 L .56865 .57084 L p
1 g
F P
s
P
p
.002 w
.61496 .54094 m .56865 .57084 L .57401 .58679 L p
1 g
F P
s
P
p
.002 w
.66776 .44567 m .66823 .39016 L .65103 .38938 L p
1 g
F P
s
P
p
.002 w
.63489 .34188 m .65103 .38938 L .66823 .39016 L p
1 g
F P
s
P
p
.002 w
.35753 .53523 m .40228 .57435 L .40936 .55928 L p
1 g
F P
s
P
p
.002 w
.40936 .55928 m .3679 .52295 L .35753 .53523 L p
1 g
F P
s
P
p
.002 w
.36333 .31589 m .3376 .3657 L .35424 .36743 L p
1 g
F P
s
P
p
.002 w
.35424 .36743 m .3774 .32275 L .36333 .31589 L p
1 g
F P
s
P
p
.002 w
.57401 .58679 m .62397 .5546 L .61496 .54094 L p
1 g
F P
s
P
p
.002 w
.64926 .49775 m .61496 .54094 L .62397 .5546 L p
1 g
F P
s
P
p
.002 w
.32771 .48371 m .35753 .53523 L .3679 .52295 L p
1 g
F P
s
P
p
.002 w
.3679 .52295 m .34031 .47515 L .32771 .48371 L p
1 g
F P
s
P
p
.002 w
.66823 .39016 m .65033 .33723 L .63489 .34188 L p
1 g
F P
s
P
p
.002 w
.60381 .30205 m .63489 .34188 L .65033 .33723 L p
1 g
F P
s
P
p
.002 w
.40431 .27701 m .36333 .31589 L .3774 .32275 L p
1 g
F P
s
P
p
.002 w
.3774 .32275 m .41419 .28791 L .40431 .27701 L p
1 g
F P
s
P
p
.002 w
.62397 .5546 m .66101 .50808 L .64926 .49775 L p
1 g
F P
s
P
p
.002 w
.66776 .44567 m .64926 .49775 L .66101 .50808 L p
1 g
F P
s
P
p
.002 w
.65033 .33723 m .61575 .2928 L .60381 .30205 L p
1 g
F P
s
P
p
.002 w
.56112 .27444 m .60381 .30205 L .61575 .2928 L p
1 g
F P
s
P
p
.002 w
.31622 .42511 m .32771 .48371 L .34031 .47515 L p
1 g
F P
s
P
p
.002 w
.34031 .47515 m .32974 .4208 L .31622 .42511 L p
1 g
F P
s
P
p
.002 w
.45609 .25358 m .40431 .27701 L .41419 .28791 L p
1 g
F P
s
P
p
.002 w
.41419 .28791 m .46063 .26693 L .45609 .25358 L p
1 g
F P
s
P
p
.002 w
.61575 .2928 m .56816 .26197 L .56112 .27444 L p
1 g
F P
s
P
p
.002 w
.51153 .26225 m .56112 .27444 L .56816 .26197 L p
1 g
F P
s
P
p
.002 w
.51286 .24836 m .45609 .25358 L .46063 .26693 L p
1 g
F P
s
P
p
.002 w
.46063 .26693 m .51153 .26225 L .51286 .24836 L p
1 g
F P
s
P
p
.002 w
.66101 .50808 m .68104 .45193 L .66776 .44567 L p
1 g
F P
s
P
p
.002 w
.66823 .39016 m .66776 .44567 L .68104 .45193 L p
1 g
F P
s
P
p
.002 w
.56816 .26197 m .51286 .24836 L .51153 .26225 L p
1 g
F P
s
P
p
.002 w
.32463 .36563 m .31622 .42511 L .32974 .4208 L p
1 g
F P
s
P
p
.002 w
.32974 .4208 m .3376 .3657 L .32463 .36563 L p
1 g
F P
s
P
p
.002 w
.45506 .61009 m .51722 .61458 L .51642 .60146 L p
1 g
F P
s
P
p
.002 w
.51642 .60146 m .45714 .59717 L .45506 .61009 L p
1 g
F P
s
P
p
.002 w
.57401 .58679 m .51642 .60146 L .51722 .61458 L p
1 g
F P
s
P
p
.002 w
.39751 .58619 m .45506 .61009 L .45714 .59717 L p
1 g
F P
s
P
p
.002 w
.45714 .59717 m .40228 .57435 L .39751 .58619 L p
1 g
F P
s
P
p
.002 w
.51722 .61458 m .57762 .59922 L .57401 .58679 L p
1 g
F P
s
P
p
.002 w
.62397 .5546 m .57401 .58679 L .57762 .59922 L p
1 g
F P
s
P
p
.002 w
.68104 .45193 m .68163 .39203 L .66823 .39016 L p
1 g
F P
s
P
p
.002 w
.65033 .33723 m .66823 .39016 L .68163 .39203 L p
1 g
F P
s
P
p
.002 w
.35055 .5452 m .39751 .58619 L .40228 .57435 L p
1 g
F P
s
P
p
.002 w
.40228 .57435 m .35753 .53523 L .35055 .5452 L p
1 g
F P
s
P
p
.002 w
.35235 .31182 m .32463 .36563 L .3376 .3657 L p
1 g
F P
s
P
p
.002 w
.3376 .3657 m .36333 .31589 L .35235 .31182 L p
1 g
F P
s
P
p
.002 w
.57762 .59922 m .63003 .5655 L .62397 .5546 L p
1 g
F P
s
P
p
.002 w
.66101 .50808 m .62397 .5546 L .63003 .5655 L p
1 g
F P
s
P
p
.002 w
.31922 .4912 m .35055 .5452 L .35753 .53523 L p
1 g
F P
s
P
p
.002 w
.35753 .53523 m .32771 .48371 L .31922 .4912 L p
1 g
F P
s
P
p
.002 w
.68163 .39203 m .66237 .33488 L .65033 .33723 L p
1 g
F P
s
P
p
.002 w
.61575 .2928 m .65033 .33723 L .66237 .33488 L p
1 g
F P
s
P
p
.002 w
.39659 .26979 m .35235 .31182 L .36333 .31589 L p
1 g
F P
s
P
p
.002 w
.36333 .31589 m .40431 .27701 L .39659 .26979 L p
1 g
F P
s
P
p
.002 w
.63003 .5655 m .66892 .51674 L .66101 .50808 L p
1 g
F P
s
P
p
.002 w
.68104 .45193 m .66101 .50808 L .66892 .51674 L p
1 g
F P
s
P
p
.002 w
.66237 .33488 m .62506 .28686 L .61575 .2928 L p
1 g
F P
s
P
p
.002 w
.56816 .26197 m .61575 .2928 L .62506 .28686 L p
1 g
F P
s
P
p
.002 w
.30711 .42973 m .31922 .4912 L .32771 .48371 L p
1 g
F P
s
P
p
.002 w
.32771 .48371 m .31622 .42511 L .30711 .42973 L p
1 g
F P
s
P
p
.002 w
.45254 .24444 m .39659 .26979 L .40431 .27701 L p
1 g
F P
s
P
p
.002 w
.40431 .27701 m .45609 .25358 L .45254 .24444 L p
1 g
F P
s
P
p
.002 w
.62506 .28686 m .57367 .25352 L .56816 .26197 L p
1 g
F P
s
P
p
.002 w
.51286 .24836 m .56816 .26197 L .57367 .25352 L p
1 g
F P
s
P
p
.002 w
.5139 .23879 m .45254 .24444 L .45609 .25358 L p
1 g
F P
s
P
p
.002 w
.45609 .25358 m .51286 .24836 L .5139 .23879 L p
1 g
F P
s
P
p
.002 w
.66892 .51674 m .68999 .45787 L .68104 .45193 L p
1 g
F P
s
P
p
.002 w
.68163 .39203 m .68104 .45193 L .68999 .45787 L p
1 g
F P
s
P
p
.002 w
.57367 .25352 m .5139 .23879 L .51286 .24836 L p
1 g
F P
s
P
p
.002 w
.31588 .36732 m .30711 .42973 L .31622 .42511 L p
1 g
F P
s
P
p
.002 w
.31622 .42511 m .32463 .36563 L .31588 .36732 L p
1 g
F P
s
P
p
.002 w
.4541 .61869 m .51758 .62327 L .51722 .61458 L p
1 g
F P
s
P
p
.002 w
.51722 .61458 m .45506 .61009 L .4541 .61869 L p
1 g
F P
s
P
p
.002 w
.57762 .59922 m .51722 .61458 L .51758 .62327 L p
1 g
F P
s
P
p
.002 w
.39531 .5943 m .4541 .61869 L .45506 .61009 L p
1 g
F P
s
P
p
.002 w
.45506 .61009 m .39751 .58619 L .39531 .5943 L p
1 g
F P
s
P
p
.002 w
.68999 .45787 m .69067 .39503 L .68163 .39203 L p
1 g
F P
s
P
p
.002 w
.66237 .33488 m .68163 .39203 L .69067 .39503 L p
1 g
F P
s
P
p
.002 w
.51758 .62327 m .57927 .6076 L .57762 .59922 L p
1 g
F P
s
P
p
.002 w
.63003 .5655 m .57762 .59922 L .57927 .6076 L p
1 g
F P
s
P
p
.002 w
.34734 .55246 m .39531 .5943 L .39751 .58619 L p
1 g
F P
s
P
p
.002 w
.39751 .58619 m .35055 .5452 L .34734 .55246 L p
1 g
F P
s
P
p
.002 w
.34494 .31082 m .31588 .36732 L .32463 .36563 L p
1 g
F P
s
P
p
.002 w
.32463 .36563 m .35235 .31182 L .34494 .31082 L p
1 g
F P
s
P
p
.002 w
.57927 .6076 m .63281 .57318 L .63003 .5655 L p
1 g
F P
s
P
p
.002 w
.66892 .51674 m .63003 .5655 L .63281 .57318 L p
1 g
F P
s
P
p
.002 w
.31532 .49734 m .34734 .55246 L .35055 .5452 L p
1 g
F P
s
P
p
.002 w
.35055 .5452 m .31922 .4912 L .31532 .49734 L p
1 g
F P
s
P
p
.002 w
.69067 .39503 m .67049 .33503 L .66237 .33488 L p
1 g
F P
s
P
p
.002 w
.62506 .28686 m .66237 .33488 L .67049 .33503 L p
1 g
F P
s
P
p
.002 w
.39138 .26666 m .34494 .31082 L .35235 .31182 L p
1 g
F P
s
P
p
.002 w
.35235 .31182 m .39659 .26979 L .39138 .26666 L p
1 g
F P
s
P
p
.002 w
.63281 .57318 m .67255 .52342 L .66892 .51674 L p
1 g
F P
s
P
p
.002 w
.68999 .45787 m .66892 .51674 L .67255 .52342 L p
1 g
F P
s
P
p
.002 w
.67049 .33503 m .63135 .2846 L .62506 .28686 L p
1 g
F P
s
P
p
.002 w
.57367 .25352 m .62506 .28686 L .63135 .2846 L p
1 g
F P
s
P
p
.002 w
.30292 .43458 m .31532 .49734 L .31922 .4912 L p
1 g
F P
s
P
p
.002 w
.31922 .4912 m .30711 .42973 L .30292 .43458 L p
1 g
F P
s
P
p
.002 w
.45014 .24003 m .39138 .26666 L .39659 .26979 L p
1 g
F P
s
P
p
.002 w
.39659 .26979 m .45254 .24444 L .45014 .24003 L p
1 g
F P
s
P
p
.002 w
.63135 .2846 m .57739 .24957 L .57367 .25352 L p
1 g
F P
s
P
p
.002 w
.5139 .23879 m .57367 .25352 L .57739 .24957 L p
1 g
F P
s
P
p
.002 w
.67255 .52342 m .6941 .46331 L .68999 .45787 L p
1 g
F P
s
P
p
.002 w
.69067 .39503 m .68999 .45787 L .6941 .46331 L p
1 g
F P
s
P
p
.002 w
.5146 .23409 m .45014 .24003 L .45254 .24444 L p
1 g
F P
s
P
p
.002 w
.45254 .24444 m .5139 .23879 L .5146 .23409 L p
1 g
F P
s
P
p
.002 w
.57739 .24957 m .5146 .23409 L .5139 .23879 L p
1 g
F P
s
P
p
.002 w
.31185 .37083 m .30292 .43458 L .30711 .42973 L p
1 g
F P
s
P
p
.002 w
.30711 .42973 m .31588 .36732 L .31185 .37083 L p
1 g
F P
s
P
p
.002 w
.45437 .62246 m .51748 .62702 L .51758 .62327 L p
1 g
F P
s
P
p
.002 w
.51758 .62327 m .4541 .61869 L .45437 .62246 L p
1 g
F P
s
P
p
.002 w
.57927 .6076 m .51758 .62327 L .51748 .62702 L p
1 g
F P
s
P
p
.002 w
.39593 .59822 m .45437 .62246 L .4541 .61869 L p
1 g
F P
s
P
p
.002 w
.4541 .61869 m .39531 .5943 L .39593 .59822 L p
1 g
F P
s
P
p
.002 w
.6941 .46331 m .69482 .39914 L .69067 .39503 L p
1 g
F P
s
P
p
.002 w
.67049 .33503 m .69067 .39503 L .69482 .39914 L p
1 g
F P
s
P
p
.002 w
.51748 .62702 m .5788 .61144 L .57927 .6076 L p
1 g
F P
s
P
p
.002 w
.63281 .57318 m .57927 .6076 L .5788 .61144 L p
1 g
F P
s
P
p
.002 w
.34824 .55665 m .39593 .59822 L .39531 .5943 L p
1 g
F P
s
P
p
.002 w
.39531 .5943 m .34734 .55246 L .34824 .55665 L p
1 g
F P
s
P
p
.002 w
.34153 .31311 m .31185 .37083 L .31588 .36732 L p
1 g
F P
s
P
p
.002 w
.31588 .36732 m .34494 .31082 L .34153 .31311 L p
1 g
F P
s
P
p
.002 w
.5788 .61144 m .63202 .57724 L .63281 .57318 L p
1 g
F P
s
P
p
.002 w
.67255 .52342 m .63281 .57318 L .63202 .57724 L p
1 g
F P
s
P
p
.002 w
.31641 .50189 m .34824 .55665 L .34734 .55246 L p
1 g
F P
s
P
p
.002 w
.34734 .55246 m .31532 .49734 L .31641 .50189 L p
1 g
F P
s
P
p
.002 w
.69482 .39914 m .67423 .33785 L .67049 .33503 L p
1 g
F P
s
P
p
.002 w
.63135 .2846 m .67049 .33503 L .67423 .33785 L p
1 g
F P
s
P
p
.002 w
.38898 .26799 m .34153 .31311 L .34494 .31082 L p
1 g
F P
s
P
p
.002 w
.34494 .31082 m .39138 .26666 L .38898 .26799 L p
1 g
F P
s
P
p
.002 w
.63202 .57724 m .67153 .52779 L .67255 .52342 L p
1 g
F P
s
P
p
.004 w
.67244 .57131 m
.71716 .60783 L
s
P
p
.002 w
.6941 .46331 m .67255 .52342 L .67153 .52779 L p
1 g
F P
s
P
p
.002 w
.67423 .33785 m .63425 .28632 L .63135 .2846 L p
1 g
F P
s
P
p
.002 w
.57739 .24957 m .63135 .2846 L .63425 .28632 L p
1 g
F P
s
P
p
.002 w
.3041 .43953 m .31641 .50189 L .31532 .49734 L p
1 g
F P
s
P
p
.002 w
.31532 .49734 m .30292 .43458 L .3041 .43953 L p
1 g
F P
s
P
p
.002 w
.44903 .24077 m .38898 .26799 L .39138 .26666 L p
1 g
F P
s
P
p
.002 w
.39138 .26666 m .45014 .24003 L .44903 .24077 L p
1 g
F P
s
P
p
.002 w
.63425 .28632 m .5791 .25052 L .57739 .24957 L p
1 g
F P
s
P
p
.002 w
.5146 .23409 m .57739 .24957 L .5791 .25052 L p
1 g
F P
s
P
p
.002 w
.67153 .52779 m .69294 .46807 L .6941 .46331 L p
1 g
F P
s
P
p
.002 w
.69482 .39914 m .6941 .46331 L .69294 .46807 L p
1 g
F P
s
P
p
.002 w
.51492 .2347 m .44903 .24077 L .45014 .24003 L p
1 g
F P
s
P
p
.002 w
.45014 .24003 m .5146 .23409 L .51492 .2347 L p
1 g
F P
s
P
p
.002 w
.5791 .25052 m .51492 .2347 L .5146 .23409 L p
1 g
F P
s
P
p
.002 w
.31298 .37619 m .3041 .43953 L .30292 .43458 L p
1 g
F P
s
P
p
.002 w
.30292 .43458 m .31185 .37083 L .31298 .37619 L p
1 g
F P
s
P
p
.002 w
.45594 .62098 m .51688 .62538 L .51748 .62702 L p
1 g
F P
s
P
p
.002 w
.51748 .62702 m .45437 .62246 L .45594 .62098 L p
1 g
F P
s
P
p
.002 w
.5788 .61144 m .51748 .62702 L .51688 .62538 L p
1 g
F P
s
P
p
.002 w
.39952 .59757 m .45594 .62098 L .45437 .62246 L p
1 g
F P
s
P
p
.002 w
.45437 .62246 m .39593 .59822 L .39952 .59757 L p
1 g
F P
s
P
p
.002 w
.69294 .46807 m .69365 .40432 L .69482 .39914 L p
1 g
F P
s
P
p
.002 w
.67423 .33785 m .69482 .39914 L .69365 .40432 L p
1 g
F P
s
P
p
.002 w
.51688 .62538 m .57608 .61034 L .5788 .61144 L p
1 g
F P
s
P
p
.002 w
.63202 .57724 m .5788 .61144 L .57608 .61034 L p
1 g
F P
s
P
p
.002 w
.3535 .55744 m .39952 .59757 L .39593 .59822 L p
1 g
F P
s
P
p
.002 w
.39593 .59822 m .34824 .55665 L .3535 .55744 L p
1 g
F P
s
P
p
.002 w
.34249 .31885 m .31298 .37619 L .31185 .37083 L p
1 g
F P
s
P
p
.002 w
.31185 .37083 m .34153 .31311 L .34249 .31885 L p
1 g
F P
s
P
p
.002 w
.57608 .61034 m .62745 .57732 L .63202 .57724 L p
1 g
F P
s
P
p
.002 w
.67153 .52779 m .63202 .57724 L .62745 .57732 L p
1 g
F P
s
P
p
.002 w
.32281 .50459 m .3535 .55744 L .34824 .55665 L p
1 g
F P
s
P
p
.002 w
.34824 .55665 m .31641 .50189 L .32281 .50459 L p
1 g
F P
s
P
p
.002 w
.69365 .40432 m .67318 .34343 L .67423 .33785 L p
1 g
F P
s
P
p
.002 w
.63425 .28632 m .67423 .33785 L .67318 .34343 L p
1 g
F P
s
P
p
.002 w
.38965 .27404 m .34249 .31885 L .34153 .31311 L p
1 g
F P
s
P
p
.002 w
.34153 .31311 m .38898 .26799 L .38965 .27404 L p
1 g
F P
s
P
p
.002 w
.62745 .57732 m .66556 .52958 L .67153 .52779 L p
1 g
F P
s
P
p
.002 w
.69294 .46807 m .67153 .52779 L .66556 .52958 L p
1 g
F P
s
P
p
.002 w
.67318 .34343 m .63343 .29224 L .63425 .28632 L p
1 g
F P
s
P
p
.002 w
.5791 .25052 m .63425 .28632 L .63343 .29224 L p
1 g
F P
s
P
p
.002 w
.31096 .44443 m .32281 .50459 L .31641 .50189 L p
1 g
F P
s
P
p
.002 w
.31641 .50189 m .3041 .43953 L .31096 .44443 L p
1 g
F P
s
P
p
.002 w
.44934 .247 m .38965 .27404 L .38898 .26799 L p
1 g
F P
s
P
p
.002 w
.38898 .26799 m .44903 .24077 L .44934 .247 L p
1 g
F P
s
P
p
.002 w
.63343 .29224 m .57861 .25668 L .5791 .25052 L p
1 g
F P
s
P
p
.002 w
.51492 .2347 m .5791 .25052 L .57861 .25668 L p
1 g
F P
s
P
p
.002 w
.66556 .52958 m .68619 .47196 L .69294 .46807 L p
1 g
F P
s
P
p
.002 w
.69365 .40432 m .69294 .46807 L .68619 .47196 L p
1 g
F P
s
P
p
.002 w
.51483 .24097 m .44934 .247 L .44903 .24077 L p
1 g
F P
s
P
p
.002 w
.44903 .24077 m .51492 .2347 L .51483 .24097 L p
1 g
F P
s
P
p
.002 w
.57861 .25668 m .51483 .24097 L .51492 .2347 L p
1 g
F P
s
P
p
.002 w
.31958 .38336 m .31096 .44443 L .3041 .43953 L p
1 g
F P
s
P
p
.002 w
.3041 .43953 m .31298 .37619 L .31958 .38336 L p
1 g
F P
s
P
p
.002 w
.45885 .61393 m .51576 .61804 L .51688 .62538 L p
1 g
F P
s
P
p
.002 w
.51688 .62538 m .45594 .62098 L .45885 .61393 L p
1 g
F P
s
P
p
.002 w
.57608 .61034 m .51688 .62538 L .51576 .61804 L p
1 g
F P
s
P
p
.002 w
.40618 .59206 m .45885 .61393 L .45594 .62098 L p
1 g
F P
s
P
p
.002 w
.45594 .62098 m .39952 .59757 L .40618 .59206 L p
1 g
F P
s
P
p
.002 w
.68619 .47196 m .68683 .41048 L .69365 .40432 L p
1 g
F P
s
P
p
.002 w
.67318 .34343 m .69365 .40432 L .68683 .41048 L p
1 g
F P
s
P
p
.002 w
.51576 .61804 m .57105 .60398 L .57608 .61034 L p
1 g
F P
s
P
p
.002 w
.62745 .57732 m .57608 .61034 L .57105 .60398 L p
1 g
F P
s
P
p
.002 w
.36324 .55458 m .40618 .59206 L .39952 .59757 L p
1 g
F P
s
P
p
.002 w
.39952 .59757 m .3535 .55744 L .36324 .55458 L p
1 g
F P
s
P
p
.002 w
.34807 .32809 m .31958 .38336 L .31298 .37619 L p
1 g
F P
s
P
p
.002 w
.31298 .37619 m .34249 .31885 L .34807 .32809 L p
1 g
F P
s
P
p
.002 w
.57105 .60398 m .61899 .57314 L .62745 .57732 L p
1 g
F P
s
P
p
.002 w
.66556 .52958 m .62745 .57732 L .61899 .57314 L p
1 g
F P
s
P
p
.002 w
.33465 .50524 m .36324 .55458 L .3535 .55744 L p
1 g
F P
s
P
p
.002 w
.3535 .55744 m .32281 .50459 L .33465 .50524 L p
1 g
F P
s
P
p
.002 w
.68683 .41048 m .66704 .35178 L .67318 .34343 L p
1 g
F P
s
P
p
.002 w
.63343 .29224 m .67318 .34343 L .66704 .35178 L p
1 g
F P
s
P
p
.002 w
.39358 .28492 m .34807 .32809 L .34249 .31885 L p
1 g
F P
s
P
p
.002 w
.34249 .31885 m .38965 .27404 L .39358 .28492 L p
1 g
F P
s
P
p
.002 w
.61899 .57314 m .65452 .52857 L .66556 .52958 L p
1 g
F P
s
P
p
.004 w
.65482 .55693 m
.67244 .57131 L
s
P
p
.002 w
.68619 .47196 m .66556 .52958 L .65452 .52857 L p
1 g
F P
s
P
p
.002 w
.66704 .35178 m .62868 .30245 L .63343 .29224 L p
1 g
F P
s
P
p
.002 w
.57861 .25668 m .63343 .29224 L .62868 .30245 L p
1 g
F P
s
P
p
.002 w
.32367 .44913 m .33465 .50524 L .32281 .50459 L p
1 g
F P
s
P
p
.002 w
.32281 .50459 m .31096 .44443 L .32367 .44913 L p
1 g
F P
s
P
p
.002 w
.45115 .25887 m .39358 .28492 L .38965 .27404 L p
1 g
F P
s
P
p
.002 w
.38965 .27404 m .44934 .247 L .45115 .25887 L p
1 g
F P
s
P
p
.002 w
.62868 .30245 m .5758 .2682 L .57861 .25668 L p
1 g
F P
s
P
p
.002 w
.51483 .24097 m .57861 .25668 L .5758 .2682 L p
1 g
F P
s
P
p
.002 w
.68683 .41048 m .68619 .47196 L .67371 .47481 L p
1 g
F P
s
P
p
.002 w
.65452 .52857 m .67371 .47481 L .68619 .47196 L p
1 g
F P
s
P
p
.002 w
.51429 .25307 m .45115 .25887 L .44934 .247 L p
1 g
F P
s
P
p
.002 w
.44934 .247 m .51483 .24097 L .51429 .25307 L p
1 g
F P
s
P
p
.002 w
.5758 .2682 m .51429 .25307 L .51483 .24097 L p
1 g
F P
s
P
p
.002 w
.33178 .39222 m .32367 .44913 L .31096 .44443 L p
1 g
F P
s
P
p
.002 w
.31096 .44443 m .31958 .38336 L .33178 .39222 L p
1 g
F P
s
P
p
.002 w
.46309 .60118 m .51413 .60487 L .51576 .61804 L p
1 g
F P
s
P
p
.002 w
.51576 .61804 m .45885 .61393 L .46309 .60118 L p
1 g
F P
s
P
p
.002 w
.57105 .60398 m .51576 .61804 L .51413 .60487 L p
1 g
F P
s
P
p
.002 w
.41588 .58155 m .46309 .60118 L .45885 .61393 L p
1 g
F P
s
P
p
.002 w
.45885 .61393 m .40618 .59206 L .41588 .58155 L p
1 g
F P
s
P
p
.002 w
.67371 .47481 m .67423 .41748 L .68683 .41048 L p
1 g
F P
s
P
p
.002 w
.66704 .35178 m .68683 .41048 L .67423 .41748 L p
1 g
F P
s
P
p
.002 w
.51413 .60487 m .5637 .59225 L .57105 .60398 L p
1 g
F P
s
P
p
.002 w
.61899 .57314 m .57105 .60398 L .5637 .59225 L p
1 g
F P
s
P
p
.002 w
.37744 .54792 m .41588 .58155 L .40618 .59206 L p
1 g
F P
s
P
p
.002 w
.40618 .59206 m .36324 .55458 L .37744 .54792 L p
1 g
F P
s
P
p
.002 w
.3584 .34076 m .33178 .39222 L .31958 .38336 L p
1 g
F P
s
P
p
.002 w
.31958 .38336 m .34807 .32809 L .3584 .34076 L p
1 g
F P
s
P
p
.002 w
.5637 .59225 m .60666 .56457 L .61899 .57314 L p
1 g
F P
s
P
p
.002 w
.65452 .52857 m .61899 .57314 L .60666 .56457 L p
1 g
F P
s
P
p
.002 w
.67423 .41748 m .65571 .36281 L .66704 .35178 L p
1 g
F P
s
P
p
.002 w
.62868 .30245 m .66704 .35178 L .65571 .36281 L p
1 g
F P
s
P
p
.002 w
.35189 .5037 m .37744 .54792 L .36324 .55458 L p
1 g
F P
s
P
p
.002 w
.36324 .55458 m .33465 .50524 L .35189 .5037 L p
1 g
F P
s
P
p
.002 w
.40084 .30057 m .3584 .34076 L .34807 .32809 L p
1 g
F P
s
P
p
.002 w
.34807 .32809 m .39358 .28492 L .40084 .30057 L p
1 g
F P
s
P
p
.002 w
.60666 .56457 m .63844 .5246 L .65452 .52857 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.6293 .53609 L
s
P
p
.004 w
.63791 .54312 m
.63899 .544 L
s
P
p
.004 w
.63899 .544 m
.64433 .54836 L
s
P
p
.004 w
.64433 .54836 m
.65482 .55693 L
s
P
p
.002 w
.67371 .47481 m .65452 .52857 L .63844 .5246 L p
1 g
F P
s
P
p
.002 w
.65571 .36281 m .61991 .31689 L .62868 .30245 L p
1 g
F P
s
P
p
.002 w
.5758 .2682 m .62868 .30245 L .61991 .31689 L p
1 g
F P
s
P
p
.002 w
.34215 .45346 m .35189 .5037 L .33465 .50524 L p
1 g
F P
s
P
p
.002 w
.33465 .50524 m .32367 .44913 L .34215 .45346 L p
1 g
F P
s
P
p
.002 w
.45449 .27635 m .40084 .30057 L .39358 .28492 L p
1 g
F P
s
P
p
.002 w
.39358 .28492 m .45115 .25887 L .45449 .27635 L p
1 g
F P
s
P
p
.002 w
.63844 .5246 m .65554 .47644 L .67371 .47481 L p
1 g
F P
s
P
p
.002 w
.67423 .41748 m .67371 .47481 L .65554 .47644 L p
1 g
F P
s
P
p
.002 w
.61991 .31689 m .57062 .28503 L .5758 .2682 L p
1 g
F P
s
P
p
.002 w
.51429 .25307 m .5758 .2682 L .57062 .28503 L p
1 g
F P
s
P
p
.002 w
.51331 .27095 m .45449 .27635 L .45115 .25887 L p
1 g
F P
s
P
p
.002 w
.45115 .25887 m .51429 .25307 L .51331 .27095 L p
1 g
F P
s
P
p
.002 w
.57062 .28503 m .51331 .27095 L .51429 .25307 L p
1 g
F P
s
P
p
.002 w
.3495 .40257 m .34215 .45346 L .32367 .44913 L p
1 g
F P
s
P
p
.002 w
.32367 .44913 m .33178 .39222 L .3495 .40257 L p
1 g
F P
s
P
p
.002 w
.46861 .58281 m .51201 .58595 L .51413 .60487 L p
1 g
F P
s
P
p
.002 w
.51413 .60487 m .46309 .60118 L .46861 .58281 L p
1 g
F P
s
P
p
.002 w
.5637 .59225 m .51413 .60487 L .51201 .58595 L p
1 g
F P
s
P
p
.002 w
.65554 .47644 m .65591 .42515 L .67423 .41748 L p
1 g
F P
s
P
p
.002 w
.65571 .36281 m .67423 .41748 L .65591 .42515 L p
1 g
F P
s
P
p
.002 w
.42849 .56609 m .46861 .58281 L .46309 .60118 L p
1 g
F P
s
P
p
.002 w
.46309 .60118 m .41588 .58155 L .42849 .56609 L p
1 g
F P
s
P
p
.002 w
.51201 .58595 m .55416 .5752 L .5637 .59225 L p
1 g
F P
s
P
p
.002 w
.60666 .56457 m .5637 .59225 L .55416 .5752 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.39586 .53747 m .42849 .56609 L .41588 .58155 L p
1 g
F P
s
P
p
.002 w
.41588 .58155 m .37744 .54792 L .39586 .53747 L p
1 g
F P
s
P
p
.002 w
.37339 .3566 m .3495 .40257 L .33178 .39222 L p
1 g
F P
s
P
p
.002 w
.33178 .39222 m .3584 .34076 L .37339 .3566 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.55416 .5752 m .59064 .55163 L .60666 .56457 L p
1 g
F P
s
P
p
.002 w
.63844 .5246 m .60666 .56457 L .59064 .55163 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.65591 .42515 m .63926 .37629 L .65571 .36281 L p
1 g
F P
s
P
p
.002 w
.61991 .31689 m .65571 .36281 L .63926 .37629 L p
1 g
F P
s
P
p
.002 w
.37425 .49988 m .39586 .53747 L .37744 .54792 L p
1 g
F P
s
P
p
.002 w
.37744 .54792 m .35189 .5037 L .37425 .49988 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.41137 .32075 m .37339 .3566 L .3584 .34076 L p
1 g
F P
s
P
p
.002 w
.3584 .34076 m .40084 .30057 L .41137 .32075 L p
1 g
F P
s
P
p
.002 w
.59064 .55163 m .61757 .51764 L .63844 .5246 L p
1 g
F P
s
P
p
.002 w
.65554 .47644 m .63844 .5246 L .61757 .51764 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.36608 .45725 m .37425 .49988 L .35189 .5037 L p
1 g
F P
s
P
p
.002 w
.35189 .5037 m .34215 .45346 L .36608 .45725 L p
1 g
F P
s
P
p
.002 w
.63926 .37629 m .60719 .3353 L .61991 .31689 L p
1 g
F P
s
P
p
.002 w
.57062 .28503 m .61991 .31689 L .60719 .3353 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.45933 .29914 m .41137 .32075 L .40084 .30057 L p
1 g
F P
s
P
p
.002 w
.40084 .30057 m .45449 .27635 L .45933 .29914 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.65591 .42515 m .65554 .47644 L .632 .47674 L p
1 g
F P
s
P
p
.002 w
.61757 .51764 m .632 .47674 L .65554 .47644 L p
1 g
F P
s
P
p
.002 w
.60719 .3353 m .56311 .30688 L .57062 .28503 L p
1 g
F P
s
P
p
.002 w
.51331 .27095 m .57062 .28503 L .56311 .30688 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51189 .29433 m .45933 .29914 L .45449 .27635 L p
1 g
F P
s
P
p
.002 w
.45449 .27635 m .51331 .27095 L .51189 .29433 L p
1 g
F P
s
P
p
.002 w
.56311 .30688 m .51189 .29433 L .51331 .27095 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.37241 .41412 m .36608 .45725 L .34215 .45346 L p
1 g
F P
s
P
p
.002 w
.34215 .45346 m .3495 .40257 L .37241 .41412 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.632 .47674 m .63221 .43325 L .65591 .42515 L p
1 g
F P
s
P
p
.002 w
.63926 .37629 m .65591 .42515 L .63221 .43325 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51148 .58084 m .51201 .58595 L p
.50621 .58172 L 1 g
F P
s
P
p
.50621 .58172 m .50472 .58063 L .51095 .58083 L 1 g
F
P
p
.50621 .58172 m .51095 .58083 L .51148 .58084 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58083 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58083 L .51146 .58073 L 1 g
F
P
p
.55416 .5752 m .52305 .57923 L .54046 .57104 L 1 g
F
P
p
.52305 .57923 m .51146 .58073 L .53158 .57401 L 1 g
F
P
p
.52305 .57923 m .53158 .57401 L .54046 .57104 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53158 .57401 L p
1 g
F P
s
P
p
.54854 .56129 m .53158 .57401 L .54168 .56783 L 1 g
F
P
p
.53128 .57265 m .51146 .58073 L .52312 .57684 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55416 .5752 m .51201 .58595 L .51146 .58073 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51146 .58073 m .50946 .56163 L p
.53776 .57022 L 1 g
F P
s
P
p
.54046 .57104 m .53158 .57401 L .53776 .57022 L 1 g
F
P
p
.53158 .57401 m .51146 .58073 L .53776 .57022 L 1 g
F
P
p
.54854 .56129 m .54168 .56783 L .54821 .56383 L 1 g
F
P
p
.59064 .55163 m .5487 .56369 L .56229 .55253 L 1 g
F
P
p
.5487 .56369 m .54821 .56383 L .54919 .56304 L 1 g
F
P
p
.5487 .56369 m .54919 .56304 L .56229 .55253 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.002 w
.59064 .55163 m .55416 .5752 L .54821 .56383 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .55629 .55375 L 1 g
F
P
p
.002 w
.54919 .56304 m .54854 .56129 L p
.54821 .56383 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56145 .54698 m .56075 .54566 L p
.55629 .55375 L 1 g
F P
s
P
p
.002 w
.54821 .56383 m .54263 .55315 L p
.5571 .55269 L 1 g
F P
s
P
p
.56229 .55253 m .54919 .56304 L .5571 .55269 L 1 g
F
P
p
.54919 .56304 m .54821 .56383 L .5571 .55269 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.57131 .53456 m .59064 .55163 L p
.55931 .55262 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56145 .54698 L p
1 g
F P
s
P
p
.56654 .52734 m .56145 .54698 L .56433 .53942 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5645 .53897 m .57131 .53456 L p
.55931 .55262 L 1 g
F P
s
P
p
.002 w
.57131 .53456 m .5645 .53897 L p
.56615 .53359 L 1 g
F P
s
P
p
.56654 .52734 m .56428 .53969 L .56707 .53058 L 1 g
F
P
p
.59244 .50779 m .56762 .53008 L .57198 .51064 L 1 g
F
P
p
.56762 .53008 m .56707 .53058 L .56752 .52877 L 1 g
F
P
p
.56762 .53008 m .56752 .52877 L .57198 .51064 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56752 .52877 L p
1 g
F P
s
P
p
.002 w
.59244 .50779 m .57131 .53456 L .56707 .53058 L p
1 g
F P
s
P
p
.56515 .50826 m .56752 .52877 L .56667 .51812 L 1 g
F
P
p
.002 w
.56752 .52877 m .56654 .52734 L p
.56707 .53058 L 1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56596 .50923 m .56515 .50826 L p
.56667 .51812 L 1 g
F P
s
P
p
.002 w
.56707 .53058 m .54924 .5138 L p
.56614 .51145 L 1 g
F P
s
P
p
.57198 .51064 m .56752 .52877 L .56614 .51145 L 1 g
F
P
p
.56752 .52877 m .56707 .53058 L .56614 .51145 L 1 g
F
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56378 .49529 m .59244 .50779 L p
.56694 .51134 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56596 .50923 L p
1 g
F P
s
P
p
.55661 .4905 m .56596 .50923 L .56247 .50171 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56108 .49872 m .56378 .49529 L p
.56694 .51134 L 1 g
F P
s
P
p
.002 w
.56378 .49529 m .56108 .49872 L p
.55907 .49464 L 1 g
F P
s
P
p
.55661 .4905 m .56386 .50436 L .55806 .49258 L 1 g
F
P
p
.57147 .47309 m .5583 .49222 L .55033 .47713 L 1 g
F
P
p
.5583 .49222 m .55806 .49258 L .55748 .49143 L 1 g
F
P
p
.5583 .49222 m .55748 .49143 L .55033 .47713 L 1 g
F
P
p
.002 w
.55748 .49143 m .55661 .4905 L p
.55806 .49258 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55748 .49143 L p
1 g
F P
s
P
p
.002 w
.5575 .49145 m .55748 .49143 L p
.55806 .49258 L 1 g
F P
s
P
p
.002 w
.57147 .47309 m .56378 .49529 L .55806 .49258 L p
1 g
F P
s
P
p
.54174 .47608 m .55748 .49143 L .54999 .48416 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55806 .49258 m .53257 .48052 L p
.54399 .47834 L 1 g
F P
s
P
p
.002 w
.54236 .47676 m .54174 .47608 L p
.54999 .48416 L 1 g
F P
s
P
p
.55033 .47713 m .55748 .49143 L .54399 .47834 L 1 g
F
P
p
.55748 .49143 m .55806 .49258 L .54399 .47834 L 1 g
F
P
p
.002 w
.52517 .49 m .53257 .48052 L .55806 .49258 L p
1 g
F P
s
P
p
.002 w
.55806 .49258 m .56378 .49529 L p
.55907 .49464 L 1 g
F P
s
P
p
.55907 .49464 m .52517 .49 L .55806 .49258 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .5575 .49145 L p
1 g
F P
s
P
p
.56386 .50436 m .56713 .51061 L .5575 .49145 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53646 .46917 m .57147 .47309 L p
.54525 .4781 L 1 g
F P
s
P
p
.002 w
.53257 .48052 m .53503 .47335 L p
.54525 .4781 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54236 .47676 L p
1 g
F P
s
P
p
.52214 .46667 m .54236 .47676 L .53526 .47346 L 1 g
F
P
p
.002 w
.53257 .48052 m .49999 .46401 L .50398 .46458 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .51216 .46574 L 1 g
F
P
p
.52244 .4672 m .53257 .48052 L .50398 .46458 L 1 g
F
P
p
.002 w
.50334 .49962 m .49125 .49873 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.51506 .4966 m .50334 .49962 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.53257 .48052 m .52517 .49 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .53257 .48052 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.52517 .49 m .51506 .4966 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .52517 .49 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.49999 .46401 m .51506 .4966 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.49999 .46401 m .50334 .49962 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46401 L p
1 g
F P
s
P
p
.002 w
.5 .46401 m .5 .4634 L p
.51216 .46574 L 1 g
F P
s
P
p
.51216 .46574 m .52282 .46778 L .5 .46401 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .5364 .45719 L .53641 .45779 L p
1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53547 .47357 L 1 g
F P
s
P
p
.002 w
.53641 .45779 m .53646 .46917 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L p
.53641 .45779 L 1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.5 .46401 m .5 .46401 L p
.5 .46401 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46401 L .5 .46401 L 1 g
F
P
p
.002 w
.49125 .49873 m .4801 .49404 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .49125 .49873 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.4801 .49404 m .47109 .48604 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .4801 .49404 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.47109 .48604 m .46519 .47558 L .49998 .46401 L p
1 g
F P
s
P
p
.002 w
.49998 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .47109 .48604 L p
.49998 .46401 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49998 .46401 m .46519 .47558 L .4648 .47344 L p
1 g
F P
s
P
p
.45826 .47608 m .46921 .47128 L .4648 .47344 L 1 g
F
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4648 .47344 m .46519 .47558 L .456 .47835 L p
1 g
F P
s
P
p
.45762 .47678 m .4648 .47344 L .456 .47835 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45762 .47678 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43909 .4984 m .43775 .49605 L p
.44172 .49308 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44257 .49137 L p
1 g
F P
s
P
p
.43485 .50826 m .44257 .49137 L .43909 .4984 L 1 g
F
P
p
.002 w
.4317 .5141 m .41809 .5234 L p
.43446 .50392 L 1 g
F P
s
P
p
.43446 .50392 m .43909 .4984 L .43394 .50934 L 1 g
F
P
p
.43446 .50392 m .43394 .50934 L .4317 .5141 L 1 g
F
P
p
.43485 .50826 m .43909 .4984 L .43885 .49892 L 1 g
F
P
p
.002 w
.43328 .51013 m .43485 .50826 L p
.43893 .49873 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43394 .50934 L p
1 g
F P
s
P
p
.43346 .52734 m .43394 .50934 L .43361 .5128 L 1 g
F
P
p
.002 w
.43217 .5358 m .41809 .5234 L .42908 .51589 L p
1 g
F P
s
P
p
.002 w
.42908 .51589 m .43361 .5128 L p
.43262 .52856 L 1 g
F P
s
P
p
.43217 .5358 m .42908 .51589 L .43262 .52856 L 1 g
F
P
p
.43925 .54566 m .43512 .5375 L .43546 .53869 L 1 g
F
P
p
.002 w
.43972 .55124 m .42849 .56609 L p
.43465 .54188 L 1 g
F P
s
P
p
.43465 .54188 m .43546 .53869 L .43838 .5473 L 1 g
F
P
p
.43465 .54188 m .43838 .5473 L .43972 .55124 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46861 .58281 m .46843 .58273 L p
.45822 .56754 L 1 g
F P
s
P
p
.46861 .58281 m .45822 .56754 L .45837 .56764 L 1 g
F
P
p
.002 w
.46843 .58273 m .42849 .56609 L .438 .55352 L p
1 g
F P
s
P
p
.002 w
.438 .55352 m .44044 .55029 L p
.451 .56253 L 1 g
F P
s
P
p
.46843 .58273 m .438 .55352 L .451 .56253 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .451 .56253 L p
1 g
F P
s
P
p
.46872 .57265 m .451 .56253 L .46133 .5697 L 1 g
F
P
p
.002 w
.451 .56253 m .45146 .56129 L p
.44533 .55596 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43838 .5473 L p
1 g
F P
s
P
p
.002 w
.44044 .55029 m .43972 .55124 L p
.43838 .5473 L 1 g
F P
s
P
p
.002 w
.43838 .5473 m .43743 .5491 L p
.44286 .55382 L 1 g
F P
s
P
p
.45146 .56129 m .43838 .5473 L .44286 .55382 L 1 g
F
P
p
.002 w
.43838 .5473 m .43925 .54566 L p
.43546 .53869 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43262 .52856 L p
1 g
F P
s
P
p
.43925 .54566 m .43262 .52856 L .43512 .5375 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44371 .54596 m .43546 .53869 L p
.44345 .50608 L 1 g
F P
s
P
p
.002 w
.43546 .53869 m .43217 .5358 L p
.4336 .53204 L 1 g
F P
s
P
p
.43546 .53869 m .4336 .53204 L .44345 .50608 L 1 g
F
P
p
.43346 .52734 m .43361 .5128 L .43319 .51954 L 1 g
F
P
p
.002 w
.43203 .52942 m .43346 .52734 L p
.43313 .51786 L 1 g
F P
s
P
p
.002 w
.43361 .5128 m .44345 .50608 L p
.43217 .5358 L 1 g
F P
s
P
p
.002 w
.43262 .52856 m .43146 .53025 L p
.43512 .5375 L 1 g
F P
s
P
p
.002 w
.43546 .53869 m .44371 .54596 L .44044 .55029 L p
1 g
F P
s
P
p
.43838 .5473 m .43546 .53869 L .44044 .55029 L 1 g
F
P
p
.002 w
.44044 .55029 m .44371 .54596 L p
.46843 .58273 L 1 g
F P
s
P
p
.002 w
.46831 .57454 m .46872 .57265 L p
.46133 .5697 L 1 g
F P
s
P
p
.002 w
.47068 .5755 m .46861 .58281 L p
.46104 .5716 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46823 .57488 L p
1 g
F P
s
P
p
.002 w
.51201 .58595 m .46861 .58281 L .46954 .57951 L p
1 g
F P
s
P
p
.002 w
.46954 .57951 m .47068 .5755 L p
.489 .58013 L 1 g
F P
s
P
p
.51201 .58595 m .46954 .57951 L .489 .58013 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58013 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58013 L .50129 .58052 L 1 g
F
P
p
.48921 .57862 m .46823 .57488 L .48012 .57787 L 1 g
F
P
p
.51201 .58595 m .47068 .5755 L .51191 .58588 L 1 g
F
P
p
.002 w
.4889 .58286 m .48921 .57862 L p
.47565 .57751 L 1 g
F P
s
P
p
.002 w
.51095 .58083 m .51079 .57862 L p
.50129 .58052 L 1 g
F P
s
P
p
.002 w
.47068 .5755 m .47529 .55915 L p
.51191 .58588 L 1 g
F P
s
P
p
.002 w
.4891 .58013 m .48889 .583 L p
.50129 .58052 L 1 g
F P
s
P
p
.002 w
.46823 .57488 m .4678 .57686 L p
.48012 .57787 L 1 g
F P
s
P
p
.002 w
.44371 .54596 m .47529 .55915 L .47068 .5755 L p
1 g
F P
s
P
p
.46104 .5716 m .44371 .54596 L .47068 .5755 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .4889 .58286 L p
1 g
F P
s
P
p
.47565 .57751 m .4678 .57686 L .4889 .58286 L 1 g
F
P
p
.002 w
.451 .56253 m .45002 .56518 L p
.46133 .5697 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46831 .57454 L p
1 g
F P
s
P
p
.46133 .5697 m .45002 .56518 L .46831 .57454 L 1 g
F
P
p
.45837 .56764 m .45822 .56754 L .44371 .54596 L 1 g
F
P
p
.002 w
.45025 .56455 m .451 .56253 L p
.44286 .55382 L 1 g
F P
s
P
p
.44533 .55596 m .44286 .55382 L .451 .56253 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45025 .56455 L p
1 g
F P
s
P
p
.44286 .55382 m .43743 .5491 L .45025 .56455 L 1 g
F
P
p
.002 w
.43804 .54794 m .43838 .5473 L p
.43546 .53869 L 1 g
F P
s
P
p
.002 w
.41809 .5234 m .43546 .53869 L p
.42849 .56609 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43804 .54794 L p
1 g
F P
s
P
p
.43512 .5375 m .43146 .53025 L .43804 .54794 L 1 g
F
P
p
.43319 .51954 m .43361 .5128 L .43313 .51786 L 1 g
F
P
p
.002 w
.43909 .4984 m .44345 .50608 L .43361 .5128 L p
1 g
F P
s
P
p
.002 w
.43361 .5128 m .4317 .5141 L p
.43394 .50934 L 1 g
F P
s
P
p
.43394 .50934 m .43909 .4984 L .43361 .5128 L 1 g
F
P
p
.002 w
.43394 .50934 m .43287 .51061 L p
.43313 .51786 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43203 .52942 L p
1 g
F P
s
P
p
.43313 .51786 m .43287 .51061 L .43203 .52942 L 1 g
F
P
p
.43885 .49892 m .43909 .4984 L .43893 .49873 L 1 g
F
P
p
.002 w
.43183 .48564 m .43909 .4984 L p
.41809 .5234 L 1 g
F P
s
P
p
.002 w
.456 .47835 m .46519 .47558 L p
.44172 .49308 L 1 g
F P
s
P
p
.43775 .49605 m .44257 .49137 L .44172 .49308 L 1 g
F
P
p
.44257 .49137 m .456 .47835 L .44172 .49308 L 1 g
F
P
p
.002 w
.44257 .49137 m .44166 .49233 L p
.43893 .49873 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43328 .51013 L p
1 g
F P
s
P
p
.43893 .49873 m .44166 .49233 L .43328 .51013 L 1 g
F
P
p
.002 w
.44345 .50608 m .43909 .4984 L p
.46519 .47558 L 1 g
F P
s
P
p
.43909 .4984 m .44172 .49308 L .46519 .47558 L 1 g
F
P
p
.44339 .4905 m .45762 .47678 L .4508 .4834 L 1 g
F
P
p
.002 w
.44236 .4916 m .44339 .4905 L p
.4508 .4834 L 1 g
F P
s
P
p
.002 w
.43775 .49605 m .43183 .48564 L .456 .47835 L p
1 g
F P
s
P
p
.4508 .4834 m .456 .47835 L .45698 .47747 L 1 g
F
P
p
.002 w
.45762 .47678 m .4576 .4768 L p
.456 .47835 L 1 g
F P
s
P
p
.002 w
.4576 .4768 m .45698 .47747 L p
.456 .47835 L 1 g
F P
s
P
p
.002 w
.45101 .47986 m .43183 .48564 L p
.45876 .47568 L 1 g
F P
s
P
p
.002 w
.45762 .47678 m .45826 .47608 L p
.4648 .47344 L 1 g
F P
s
P
p
.4648 .47344 m .47754 .4672 L .49998 .46401 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46921 .47128 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46921 .47128 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.46401 .46911 m .46304 .46379 L p
.48423 .46392 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46401 L .49999 .46401 L 1 g
F
P
p
.48985 .46545 m .49999 .46401 L .49132 .4653 L 1 g
F
P
p
.47786 .46667 m .49999 .46401 L .48985 .46545 L 1 g
F
P
p
.002 w
.47737 .46747 m .47786 .46667 L p
.49207 .46522 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.47754 .4672 m .48423 .46392 L .49998 .46401 L 1 g
F
P
p
.46401 .46911 m .48423 .46392 L .47754 .4672 L 1 g
F
P
p
.45876 .47568 m .4648 .47344 L .45762 .47678 L 1 g
F
P
p
.45876 .47568 m .45762 .47678 L .45101 .47986 L 1 g
F
P
p
.002 w
.456 .47835 m .45101 .47986 L p
.45762 .47678 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44236 .4916 L p
1 g
F P
s
P
p
.4508 .4834 m .45698 .47747 L .44236 .4916 L 1 g
F
P
p
.002 w
.45732 .4771 m .45762 .47678 L p
.4648 .47344 L 1 g
F P
s
P
p
.002 w
.46304 .46379 m .4648 .47344 L p
.43183 .48564 L 1 g
F P
s
P
p
.002 w
.4648 .47344 m .46401 .46911 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45732 .4771 L p
1 g
F P
s
P
p
.46921 .47128 m .47718 .46778 L .45732 .4771 L 1 g
F
P
p
.002 w
.46304 .46379 m .49999 .46401 L .49998 .46401 L p
1 g
F P
s
P
p
.49132 .4653 m .49999 .46401 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46401 m .5 .46401 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.5 .46401 m .5 .46442 L p
.49999 .46401 L 1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.49999 .46401 m .49999 .46401 L .49999 .46401 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47737 .46747 L p
1 g
F P
s
P
p
.49207 .46522 m .5 .46442 L .47737 .46747 L 1 g
F
P
p
.002 w
.50398 .46458 m .52244 .46719 L p
.52244 .4672 L 1 g
F P
s
P
p
.002 w
.53503 .47335 m .53257 .48052 L p
.52244 .46719 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52282 .46778 L p
.51216 .46574 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52246 .4672 L p
1 g
F P
s
P
p
.53547 .47357 m .54302 .47747 L .52246 .4672 L 1 g
F
P
p
.002 w
.52244 .46719 m .53646 .46917 L .53503 .47335 L p
1 g
F P
s
P
p
.002 w
.53503 .47335 m .53646 .46917 L p
.54525 .4781 L 1 g
F P
s
P
p
.002 w
.54236 .47676 m .54302 .47747 L p
.53526 .47346 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54236 .47676 L p
1 g
F P
s
P
p
.54999 .48416 m .55834 .49233 L .54236 .47676 L 1 g
F
P
p
.002 w
.55748 .49143 m .55834 .49233 L p
.54999 .48416 L 1 g
F P
s
P
p
.002 w
.54924 .5138 m .52517 .49 L p
.55907 .49464 L 1 g
F P
s
P
p
.002 w
.56108 .49872 m .54924 .5138 L p
.55907 .49464 L 1 g
F P
s
P
p
.002 w
.54924 .5138 m .56108 .49872 L p
.56694 .51134 L 1 g
F P
s
P
p
.002 w
.56596 .50923 m .56713 .51061 L p
.56247 .50171 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56596 .50923 L p
1 g
F P
s
P
p
.56667 .51812 m .56854 .53025 L .56596 .50923 L 1 g
F
P
p
.002 w
.56752 .52877 m .56854 .53025 L p
.56667 .51812 L 1 g
F P
s
P
p
.002 w
.56759 .52888 m .56752 .52877 L p
.56707 .53058 L 1 g
F P
s
P
p
.002 w
.52945 .52667 m .54924 .5138 L .57131 .53456 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56759 .52888 L p
1 g
F P
s
P
p
.56428 .53969 m .56257 .5491 L .56759 .52888 L 1 g
F
P
p
.002 w
.54263 .55315 m .52945 .52667 L p
.56615 .53359 L 1 g
F P
s
P
p
.002 w
.5645 .53897 m .54263 .55315 L p
.56615 .53359 L 1 g
F P
s
P
p
.002 w
.54263 .55315 m .5645 .53897 L p
.55931 .55262 L 1 g
F P
s
P
p
.002 w
.56145 .54698 m .56257 .5491 L p
.56433 .53942 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56145 .54698 L p
1 g
F P
s
P
p
.55629 .55375 m .54998 .56518 L .56145 .54698 L 1 g
F
P
p
.002 w
.54919 .56304 m .54998 .56518 L p
.55629 .55375 L 1 g
F P
s
P
p
.002 w
.54925 .5632 m .54919 .56304 L p
.54821 .56383 L 1 g
F P
s
P
p
.002 w
.50946 .56163 m .54263 .55315 L .55416 .5752 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54925 .5632 L p
1 g
F P
s
P
p
.54168 .56783 m .5322 .57686 L .54925 .5632 L 1 g
F
P
p
.002 w
.53158 .57401 m .5322 .57686 L p
.54168 .56783 L 1 g
F P
s
P
p
.52312 .57684 m .51146 .58073 L .51787 .57953 L 1 g
F
P
p
.002 w
.47529 .55915 m .50946 .56163 L .51148 .58084 L p
1 g
F P
s
P
p
.50472 .58063 m .47529 .55915 L .51148 .58084 L 1 g
F
P
p
.002 w
.51095 .58083 m .51111 .583 L p
.51787 .57953 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58083 L p
1 g
F P
s
P
p
.50129 .58052 m .48889 .583 L .51095 .58083 L 1 g
F
P
p
.002 w
.42849 .56609 m .39586 .53747 L .41809 .5234 L p
1 g
F P
s
P
p
.002 w
.39274 .37522 m .37241 .41412 L .3495 .40257 L p
1 g
F P
s
P
p
.002 w
.3495 .40257 m .37339 .3566 L .39274 .37522 L p
1 g
F P
s
P
p
.002 w
.61757 .51764 m .59064 .55163 L .57131 .53456 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.63221 .43325 m .61801 .39188 L .63926 .37629 L p
1 g
F P
s
P
p
.002 w
.60719 .3353 m .63926 .37629 L .61801 .39188 L p
1 g
F P
s
P
p
.002 w
.40117 .49382 m .41809 .5234 L .39586 .53747 L p
1 g
F P
s
P
p
.002 w
.39586 .53747 m .37425 .49988 L .40117 .49382 L p
1 g
F P
s
P
p
.002 w
.42496 .34492 m .39274 .37522 L .37339 .3566 L p
1 g
F P
s
P
p
.002 w
.37339 .3566 m .41137 .32075 L .42496 .34492 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.57131 .53456 m .59244 .50779 L .61757 .51764 L p
1 g
F P
s
P
p
.002 w
.632 .47674 m .61757 .51764 L .59244 .50779 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39484 .46032 m .40117 .49382 L .37425 .49988 L p
1 g
F P
s
P
p
.002 w
.37425 .49988 m .36608 .45725 L .39484 .46032 L p
1 g
F P
s
P
p
.002 w
.61801 .39188 m .59077 .35722 L .60719 .3353 L p
1 g
F P
s
P
p
.002 w
.56311 .30688 m .60719 .3353 L .59077 .35722 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.46558 .32668 m .42496 .34492 L .41137 .32075 L p
1 g
F P
s
P
p
.002 w
.41137 .32075 m .45933 .29914 L .46558 .32668 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59244 .50779 m .60369 .47563 L .632 .47674 L p
1 g
F P
s
P
p
.002 w
.63221 .43325 m .632 .47674 L .60369 .47563 L p
1 g
F P
s
P
p
.002 w
.59077 .35722 m .55342 .33321 L .56311 .30688 L p
1 g
F P
s
P
p
.002 w
.51189 .29433 m .56311 .30688 L .55342 .33321 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51006 .32262 m .46558 .32668 L .45933 .29914 L p
1 g
F P
s
P
p
.002 w
.45933 .29914 m .51189 .29433 L .51006 .32262 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.55342 .33321 m .51006 .32262 L .51189 .29433 L p
1 g
F P
s
P
p
.002 w
.39991 .4265 m .39484 .46032 L .36608 .45725 L p
1 g
F P
s
P
p
.002 w
.36608 .45725 m .37241 .41412 L .39991 .4265 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.60369 .47563 m .60375 .44149 L .63221 .43325 L p
1 g
F P
s
P
p
.002 w
.61801 .39188 m .63221 .43325 L .60375 .44149 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.48292 .53083 m .50653 .53255 L .50946 .56163 L p
1 g
F P
s
P
p
.002 w
.50946 .56163 m .47529 .55915 L .48292 .53083 L p
1 g
F P
s
P
p
.002 w
.54263 .55315 m .50946 .56163 L .50653 .53255 L p
1 g
F P
s
P
p
.002 w
.46111 .52169 m .48292 .53083 L .47529 .55915 L p
1 g
F P
s
P
p
.002 w
.47529 .55915 m .44371 .54596 L .46111 .52169 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.50653 .53255 m .52945 .52667 L .54263 .55315 L p
1 g
F P
s
P
p
.002 w
.41593 .39605 m .39991 .4265 L .37241 .41412 L p
1 g
F P
s
P
p
.002 w
.37241 .41412 m .39274 .37522 L .41593 .39605 L p
1 g
F P
s
P
p
.002 w
.44345 .50608 m .46111 .52169 L .44371 .54596 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.60375 .44149 m .59252 .40908 L .61801 .39188 L p
1 g
F P
s
P
p
.002 w
.59077 .35722 m .61801 .39188 L .59252 .40908 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41809 .5234 m .40117 .49382 L .43183 .48564 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.44122 .37237 m .41593 .39605 L .39274 .37522 L p
1 g
F P
s
P
p
.002 w
.39274 .37522 m .42496 .34492 L .44122 .37237 L p
1 g
F P
s
P
p
.002 w
.60369 .47563 m .59244 .50779 L .56378 .49529 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.42755 .46254 m .43183 .48564 L .40117 .49382 L p
1 g
F P
s
P
p
.002 w
.40117 .49382 m .39484 .46032 L .42755 .46254 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59252 .40908 m .57111 .38198 L .59077 .35722 L p
1 g
F P
s
P
p
.002 w
.55342 .33321 m .59077 .35722 L .57111 .38198 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.47304 .35813 m .44122 .37237 L .42496 .34492 L p
1 g
F P
s
P
p
.002 w
.42496 .34492 m .46558 .32668 L .47304 .35813 L p
1 g
F P
s
P
p
.002 w
.56378 .49529 m .57147 .47309 L .60369 .47563 L p
1 g
F P
s
P
p
.002 w
.60375 .44149 m .60369 .47563 L .57147 .47309 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.57111 .38198 m .54183 .36322 L .55342 .33321 L p
1 g
F P
s
P
p
.002 w
.51006 .32262 m .55342 .33321 L .54183 .36322 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.50787 .35496 m .47304 .35813 L .46558 .32668 L p
1 g
F P
s
P
p
.002 w
.46558 .32668 m .51006 .32262 L .50787 .35496 L p
1 g
F P
s
P
p
.002 w
.43111 .43927 m .42755 .46254 L .39484 .46032 L p
1 g
F P
s
P
p
.002 w
.39484 .46032 m .39991 .4265 L .43111 .43927 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.54183 .36322 m .50787 .35496 L .51006 .32262 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57147 .47309 m .57144 .44958 L .60375 .44149 L p
1 g
F P
s
P
p
.002 w
.59252 .40908 m .60375 .44149 L .57144 .44958 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49125 .49873 m .50334 .49962 L .50653 .53255 L p
1 g
F P
s
P
p
.002 w
.50653 .53255 m .48292 .53083 L .49125 .49873 L p
1 g
F P
s
P
p
.002 w
.52945 .52667 m .50653 .53255 L .50334 .49962 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.4801 .49404 m .49125 .49873 L .48292 .53083 L p
1 g
F P
s
P
p
.002 w
.48292 .53083 m .46111 .52169 L .4801 .49404 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50334 .49962 m .51506 .4966 L .52945 .52667 L p
1 g
F P
s
P
p
.002 w
.54924 .5138 m .52945 .52667 L .51506 .4966 L p
1 g
F P
s
P
p
.002 w
.44219 .41836 m .43111 .43927 L .39991 .4265 L p
1 g
F P
s
P
p
.002 w
.39991 .4265 m .41593 .39605 L .44219 .41836 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.47109 .48604 m .4801 .49404 L .46111 .52169 L p
1 g
F P
s
P
p
.002 w
.46111 .52169 m .44345 .50608 L .47109 .48604 L p
1 g
F P
s
P
p
.002 w
.51506 .4966 m .52517 .49 L .54924 .5138 L p
1 g
F P
s
P
p
.002 w
.57144 .44958 m .56364 .4273 L .59252 .40908 L p
1 g
F P
s
P
p
.002 w
.57111 .38198 m .59252 .40908 L .56364 .4273 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.46519 .47558 m .47109 .48604 L .44345 .50608 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45961 .40213 m .44219 .41836 L .41593 .39605 L p
1 g
F P
s
P
p
.002 w
.41593 .39605 m .44122 .37237 L .45961 .40213 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.43183 .48564 m .42755 .46254 L .46304 .46379 L p
1 g
F P
s
P
p
.002 w
.56364 .4273 m .54887 .40871 L .57111 .38198 L p
1 g
F P
s
P
p
.002 w
.54183 .36322 m .57111 .38198 L .54887 .40871 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57144 .44958 m .57147 .47309 L .53646 .46917 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.48148 .39238 m .45961 .40213 L .44122 .37237 L p
1 g
F P
s
P
p
.002 w
.44122 .37237 m .47304 .35813 L .48148 .39238 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54887 .40871 m .52872 .39586 L .54183 .36322 L p
1 g
F P
s
P
p
.002 w
.50787 .35496 m .54183 .36322 L .52872 .39586 L p
1 g
F P
s
P
p
.002 w
.4649 .45194 m .46304 .46379 L .42755 .46254 L p
1 g
F P
s
P
p
.002 w
.42755 .46254 m .43111 .43927 L .4649 .45194 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.5054 .39021 m .48148 .39238 L .47304 .35813 L p
1 g
F P
s
P
p
.002 w
.47304 .35813 m .50787 .35496 L .5054 .39021 L p
1 g
F P
s
P
p
.002 w
.52872 .39586 m .5054 .39021 L .50787 .35496 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.53646 .46917 m .5364 .45719 L .57144 .44958 L p
1 g
F P
s
P
p
.002 w
.56364 .4273 m .57144 .44958 L .5364 .45719 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.47058 .44131 m .4649 .45194 L .43111 .43927 L p
1 g
F P
s
P
p
.002 w
.43111 .43927 m .44219 .41836 L .47058 .44131 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.5364 .45719 m .53239 .44586 L .56364 .4273 L p
1 g
F P
s
P
p
.002 w
.54887 .40871 m .56364 .4273 L .53239 .44586 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.47946 .43308 m .47058 .44131 L .44219 .41836 L p
1 g
F P
s
P
p
.002 w
.44219 .41836 m .45961 .40213 L .47946 .43308 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53239 .44586 m .52485 .43642 L .54887 .40871 L p
1 g
F P
s
P
p
.002 w
.52872 .39586 m .54887 .40871 L .52485 .43642 L p
1 g
F P
s
P
p
.002 w
.46304 .46379 m .4649 .45194 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.49058 .42814 m .47946 .43308 L .45961 .40213 L p
1 g
F P
s
P
p
.002 w
.45961 .40213 m .48148 .39238 L .49058 .42814 L p
1 g
F P
s
P
p
.002 w
.53239 .44586 m .5364 .45719 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.52485 .43642 m .51459 .4299 L .52872 .39586 L p
1 g
F P
s
P
p
.002 w
.5054 .39021 m .52872 .39586 L .51459 .4299 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50274 .42704 m .49058 .42814 L .48148 .39238 L p
1 g
F P
s
P
p
.002 w
.48148 .39238 m .5054 .39021 L .50274 .42704 L p
1 g
F P
s
P
p
.002 w
.4649 .45194 m .47058 .44131 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.51459 .4299 m .50274 .42704 L .5054 .39021 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52485 .43642 m .53239 .44586 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.51459 .4299 m .52485 .43642 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.50274 .42704 m .51459 .4299 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.49058 .42814 m .50274 .42704 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.47946 .43308 m .49058 .42814 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.47058 .44131 m .47946 .43308 L .49999 .46401 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.49998 .48482 m
.49999 .46401 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .71716 .60783 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .49998 .48482 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.303876)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.303876)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49866 .47885 m .52281 .46641 L .50597 .44364 L p
1 g
F P
s
P
p
.002 w
.50597 .44364 m .48954 .45208 L .49866 .47885 L p
1 g
F P
s
P
p
.002 w
.51893 .43045 m .50597 .44364 L .52281 .46641 L p
1 g
F P
s
P
p
.002 w
.48954 .45208 m .50597 .44364 L .48904 .42063 L p
1 g
F P
s
P
p
.002 w
.50597 .44364 m .51893 .43045 L .4956 .41394 L p
1 g
F P
s
P
p
.002 w
.4956 .41394 m .48904 .42063 L .50597 .44364 L p
1 g
F P
s
P
p
.002 w
.48904 .42063 m .4807 .42489 L .48954 .45208 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .4807 .42489 L .48904 .42063 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .48904 .42063 L .4956 .41394 L closepath p
1 g
F P
s
P
p
.002 w
.49969 .40554 m .4956 .41394 L .51893 .43045 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .4956 .41394 L .49969 .40554 L closepath p
1 g
F P
s
P
p
.002 w
.52703 .41389 m .51893 .43045 L .54187 .44702 L p
1 g
F P
s
P
p
.002 w
.52281 .46641 m .54187 .44702 L .51893 .43045 L p
1 g
F P
s
P
p
.002 w
.51893 .43045 m .52703 .41389 L .49969 .40554 L p
1 g
F P
s
P
p
.002 w
.47135 .45487 m .48954 .45208 L .4807 .42489 L p
1 g
F P
s
P
p
.002 w
.4807 .42489 m .47149 .42628 L .47135 .45487 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .47149 .42628 L .4807 .42489 L closepath p
1 g
F P
s
P
p
.002 w
.47191 .48301 m .49866 .47885 L .48954 .45208 L p
1 g
F P
s
P
p
.002 w
.48954 .45208 m .47135 .45487 L .47191 .48301 L p
1 g
F P
s
P
p
.002 w
.50087 .39633 m .49969 .40554 L .52703 .41389 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .49969 .40554 L .50087 .39633 L closepath p
1 g
F P
s
P
p
.002 w
.45335 .45168 m .47135 .45487 L .47149 .42628 L p
1 g
F P
s
P
p
.002 w
.47149 .42628 m .46238 .42463 L .45335 .45168 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .46238 .42463 L .47149 .42628 L closepath p
1 g
F P
s
P
p
.002 w
.54187 .44702 m .55385 .42269 L .52703 .41389 L p
1 g
F P
s
P
p
.002 w
.52942 .39572 m .52703 .41389 L .55385 .42269 L p
1 g
F P
s
P
p
.002 w
.52703 .41389 m .52942 .39572 L .50087 .39633 L p
1 g
F P
s
P
p
.002 w
.499 .3873 m .50087 .39633 L .52942 .39572 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .50087 .39633 L .499 .3873 L closepath p
1 g
F P
s
P
p
.002 w
.44538 .47841 m .47191 .48301 L .47135 .45487 L p
1 g
F P
s
P
p
.002 w
.47135 .45487 m .45335 .45168 L .44538 .47841 L p
1 g
F P
s
P
p
.002 w
.43744 .44281 m .45335 .45168 L .46238 .42463 L p
1 g
F P
s
P
p
.002 w
.46238 .42463 m .45436 .42012 L .43744 .44281 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .45436 .42012 L .46238 .42463 L closepath p
1 g
F P
s
P
p
.002 w
.5079 .50471 m .53926 .48852 L .52281 .46641 L p
1 g
F P
s
P
p
.002 w
.52281 .46641 m .49866 .47885 L .5079 .50471 L p
1 g
F P
s
P
p
.002 w
.54187 .44702 m .52281 .46641 L .53926 .48852 L p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .499 .3873 L .49426 .37942 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .49426 .37942 L .48717 .37356 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .48717 .37356 L .47847 .37035 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .47847 .37035 L .46912 .37016 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .46912 .37016 L .46014 .37302 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .46014 .37302 L .45252 .37862 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .45252 .37862 L .44709 .38635 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .44709 .38635 L .44444 .39535 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .44444 .39535 L .44487 .40464 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .44487 .40464 L .4483 .41321 L closepath p
1 g
F P
s
P
p
.002 w
.47231 .39778 m .4483 .41321 L .45436 .42012 L closepath p
1 g
F P
s
P
p
.002 w
.52942 .39572 m .52579 .37784 L .499 .3873 L p
1 g
F P
s
P
p
.002 w
.49426 .37942 m .499 .3873 L .52579 .37784 L p
1 g
F P
s
P
p
.002 w
.55385 .42269 m .54187 .44702 L .56402 .46335 L p
1 g
F P
s
P
p
.002 w
.53926 .48852 m .56402 .46335 L .54187 .44702 L p
1 g
F P
s
P
p
.002 w
.55385 .42269 m .55744 .39594 L .52942 .39572 L p
1 g
F P
s
P
p
.002 w
.52579 .37784 m .52942 .39572 L .55744 .39594 L p
1 g
F P
s
P
p
.002 w
.42537 .42918 m .43744 .44281 L .45436 .42012 L p
1 g
F P
s
P
p
.002 w
.45436 .42012 m .4483 .41321 L .42537 .42918 L p
1 g
F P
s
P
p
.002 w
.47317 .5102 m .5079 .50471 L .49866 .47885 L p
1 g
F P
s
P
p
.002 w
.49866 .47885 m .47191 .48301 L .47317 .5102 L p
1 g
F P
s
P
p
.002 w
.42187 .46544 m .44538 .47841 L .45335 .45168 L p
1 g
F P
s
P
p
.002 w
.45335 .45168 m .43744 .44281 L .42187 .46544 L p
1 g
F P
s
P
p
.002 w
.52579 .37784 m .51649 .3622 L .49426 .37942 L p
1 g
F P
s
P
p
.002 w
.48717 .37356 m .49426 .37942 L .51649 .3622 L p
1 g
F P
s
P
p
.002 w
.56402 .46335 m .57964 .43177 L .55385 .42269 L p
1 g
F P
s
P
p
.002 w
.55744 .39594 m .55385 .42269 L .57964 .43177 L p
1 g
F P
s
P
p
.002 w
.41848 .41221 m .42537 .42918 L .4483 .41321 L p
1 g
F P
s
P
p
.002 w
.4483 .41321 m .44487 .40464 L .41848 .41221 L p
1 g
F P
s
P
p
.002 w
.51649 .3622 m .50247 .3505 L .48717 .37356 L p
1 g
F P
s
P
p
.002 w
.47847 .37035 m .48717 .37356 L .50247 .3505 L p
1 g
F P
s
P
p
.002 w
.55744 .39594 m .5522 .36958 L .52579 .37784 L p
1 g
F P
s
P
p
.002 w
.51649 .3622 m .52579 .37784 L .5522 .36958 L p
1 g
F P
s
P
p
.002 w
.43864 .50434 m .47317 .5102 L .47191 .48301 L p
1 g
F P
s
P
p
.002 w
.47191 .48301 m .44538 .47841 L .43864 .50434 L p
1 g
F P
s
P
p
.002 w
.41757 .39375 m .41848 .41221 L .44487 .40464 L p
1 g
F P
s
P
p
.002 w
.44487 .40464 m .44444 .39535 L .41757 .39375 L p
1 g
F P
s
P
p
.002 w
.40395 .4454 m .42187 .46544 L .43744 .44281 L p
1 g
F P
s
P
p
.002 w
.43744 .44281 m .42537 .42918 L .40395 .4454 L p
1 g
F P
s
P
p
.002 w
.50247 .3505 m .48523 .34406 L .47847 .37035 L p
1 g
F P
s
P
p
.002 w
.46912 .37016 m .47847 .37035 L .48523 .34406 L p
1 g
F P
s
P
p
.002 w
.42279 .37583 m .41757 .39375 L .44444 .39535 L p
1 g
F P
s
P
p
.002 w
.44444 .39535 m .44709 .38635 L .42279 .37583 L p
1 g
F P
s
P
p
.002 w
.57964 .43177 m .58442 .39702 L .55744 .39594 L p
1 g
F P
s
P
p
.002 w
.5522 .36958 m .55744 .39594 L .58442 .39702 L p
1 g
F P
s
P
p
.002 w
.48523 .34406 m .46665 .34363 L .46912 .37016 L p
1 g
F P
s
P
p
.002 w
.46014 .37302 m .46912 .37016 L .46665 .34363 L p
1 g
F P
s
P
p
.002 w
.43358 .36044 m .42279 .37583 L .44709 .38635 L p
1 g
F P
s
P
p
.002 w
.44709 .38635 m .45252 .37862 L .43358 .36044 L p
1 g
F P
s
P
p
.002 w
.46665 .34363 m .44877 .34929 L .46014 .37302 L p
1 g
F P
s
P
p
.002 w
.45252 .37862 m .46014 .37302 L .44877 .34929 L p
1 g
F P
s
P
p
.002 w
.5171 .52916 m .555 .50955 L .53926 .48852 L p
1 g
F P
s
P
p
.002 w
.53926 .48852 m .5079 .50471 L .5171 .52916 L p
1 g
F P
s
P
p
.002 w
.56402 .46335 m .53926 .48852 L .555 .50955 L p
1 g
F P
s
P
p
.002 w
.5522 .36958 m .53858 .34644 L .51649 .3622 L p
1 g
F P
s
P
p
.002 w
.50247 .3505 m .51649 .3622 L .53858 .34644 L p
1 g
F P
s
P
p
.002 w
.44877 .34929 m .43358 .36044 L .45252 .37862 L p
1 g
F P
s
P
p
.002 w
.57964 .43177 m .56402 .46335 L .58495 .47913 L p
1 g
F P
s
P
p
.002 w
.555 .50955 m .58495 .47913 L .56402 .46335 L p
1 g
F P
s
P
p
.002 w
.40797 .48759 m .43864 .50434 L .44538 .47841 L p
1 g
F P
s
P
p
.002 w
.44538 .47841 m .42187 .46544 L .40797 .48759 L p
1 g
F P
s
P
p
.002 w
.4751 .53591 m .5171 .52916 L .5079 .50471 L p
1 g
F P
s
P
p
.002 w
.5079 .50471 m .47317 .5102 L .4751 .53591 L p
1 g
F P
s
P
p
.002 w
.39366 .42036 m .40395 .4454 L .42537 .42918 L p
1 g
F P
s
P
p
.002 w
.42537 .42918 m .41848 .41221 L .39366 .42036 L p
1 g
F P
s
P
p
.002 w
.58495 .47913 m .6039 .44097 L .57964 .43177 L p
1 g
F P
s
P
p
.002 w
.58442 .39702 m .57964 .43177 L .6039 .44097 L p
1 g
F P
s
P
p
.002 w
.53858 .34644 m .51795 .32906 L .50247 .3505 L p
1 g
F P
s
P
p
.002 w
.48523 .34406 m .50247 .3505 L .51795 .32906 L p
1 g
F P
s
P
p
.002 w
.58442 .39702 m .57773 .3627 L .5522 .36958 L p
1 g
F P
s
P
p
.002 w
.53858 .34644 m .5522 .36958 L .57773 .3627 L p
1 g
F P
s
P
p
.002 w
.39222 .39304 m .39366 .42036 L .41848 .41221 L p
1 g
F P
s
P
p
.002 w
.41848 .41221 m .41757 .39375 L .39222 .39304 L p
1 g
F P
s
P
p
.002 w
.43329 .52895 m .4751 .53591 L .47317 .5102 L p
1 g
F P
s
P
p
.002 w
.47317 .5102 m .43864 .50434 L .43329 .52895 L p
1 g
F P
s
P
p
.002 w
.38451 .46156 m .40797 .48759 L .42187 .46544 L p
1 g
F P
s
P
p
.002 w
.42187 .46544 m .40395 .4454 L .38451 .46156 L p
1 g
F P
s
P
p
.002 w
.51795 .32906 m .49248 .31943 L .48523 .34406 L p
1 g
F P
s
P
p
.002 w
.46665 .34363 m .48523 .34406 L .49248 .31943 L p
1 g
F P
s
P
p
.002 w
.3999 .36646 m .39222 .39304 L .41757 .39375 L p
1 g
F P
s
P
p
.002 w
.41757 .39375 m .42279 .37583 L .3999 .36646 L p
1 g
F P
s
P
p
.002 w
.6039 .44097 m .60981 .39894 L .58442 .39702 L p
1 g
F P
s
P
p
.002 w
.57773 .3627 m .58442 .39702 L .60981 .39894 L p
1 g
F P
s
P
p
.002 w
.57773 .3627 m .56013 .33247 L .53858 .34644 L p
1 g
F P
s
P
p
.002 w
.51795 .32906 m .53858 .34644 L .56013 .33247 L p
1 g
F P
s
P
p
.002 w
.49248 .31943 m .46495 .31872 L .46665 .34363 L p
1 g
F P
s
P
p
.002 w
.44877 .34929 m .46665 .34363 L .46495 .31872 L p
1 g
F P
s
P
p
.002 w
.41589 .3436 m .3999 .36646 L .42279 .37583 L p
1 g
F P
s
P
p
.002 w
.42279 .37583 m .43358 .36044 L .41589 .3436 L p
1 g
F P
s
P
p
.002 w
.39606 .5088 m .43329 .52895 L .43864 .50434 L p
1 g
F P
s
P
p
.002 w
.43864 .50434 m .40797 .48759 L .39606 .5088 L p
1 g
F P
s
P
p
.002 w
.46495 .31872 m .43842 .32707 L .44877 .34929 L p
1 g
F P
s
P
p
.002 w
.43358 .36044 m .44877 .34929 L .43842 .32707 L p
1 g
F P
s
P
p
.002 w
.52608 .55169 m .56971 .52906 L .555 .50955 L p
1 g
F P
s
P
p
.002 w
.555 .50955 m .5171 .52916 L .52608 .55169 L p
1 g
F P
s
P
p
.002 w
.58495 .47913 m .555 .50955 L .56971 .52906 L p
1 g
F P
s
P
p
.002 w
.43842 .32707 m .41589 .3436 L .43358 .36044 L p
1 g
F P
s
P
p
.002 w
.37095 .42894 m .38451 .46156 L .40395 .4454 L p
1 g
F P
s
P
p
.002 w
.40395 .4454 m .39366 .42036 L .37095 .42894 L p
1 g
F P
s
P
p
.002 w
.6039 .44097 m .58495 .47913 L .60422 .49404 L p
1 g
F P
s
P
p
.002 w
.56971 .52906 m .60422 .49404 L .58495 .47913 L p
1 g
F P
s
P
p
.002 w
.47771 .55957 m .52608 .55169 L .5171 .52916 L p
1 g
F P
s
P
p
.002 w
.5171 .52916 m .4751 .53591 L .47771 .55957 L p
1 g
F P
s
P
p
.002 w
.56013 .33247 m .53331 .3097 L .51795 .32906 L p
1 g
F P
s
P
p
.002 w
.49248 .31943 m .51795 .32906 L .53331 .3097 L p
1 g
F P
s
P
p
.002 w
.60981 .39894 m .60187 .35736 L .57773 .3627 L p
1 g
F P
s
P
p
.002 w
.56013 .33247 m .57773 .3627 L .60187 .35736 L p
1 g
F P
s
P
p
.002 w
.60422 .49404 m .62612 .45013 L .6039 .44097 L p
1 g
F P
s
P
p
.002 w
.60981 .39894 m .6039 .44097 L .62612 .45013 L p
1 g
F P
s
P
p
.002 w
.36896 .39325 m .37095 .42894 L .39366 .42036 L p
1 g
F P
s
P
p
.002 w
.39366 .42036 m .39222 .39304 L .36896 .39325 L p
1 g
F P
s
P
p
.002 w
.36749 .47735 m .39606 .5088 L .40797 .48759 L p
1 g
F P
s
P
p
.002 w
.40797 .48759 m .38451 .46156 L .36749 .47735 L p
1 g
F P
s
P
p
.002 w
.42949 .5517 m .47771 .55957 L .4751 .53591 L p
1 g
F P
s
P
p
.002 w
.4751 .53591 m .43329 .52895 L .42949 .5517 L p
1 g
F P
s
P
p
.002 w
.53331 .3097 m .50009 .29701 L .49248 .31943 L p
1 g
F P
s
P
p
.002 w
.46495 .31872 m .49248 .31943 L .50009 .29701 L p
1 g
F P
s
P
p
.002 w
.37893 .35845 m .36896 .39325 L .39222 .39304 L p
1 g
F P
s
P
p
.002 w
.39222 .39304 m .3999 .36646 L .37893 .35845 L p
1 g
F P
s
P
p
.002 w
.62612 .45013 m .63306 .40171 L .60981 .39894 L p
1 g
F P
s
P
p
.002 w
.60187 .35736 m .60981 .39894 L .63306 .40171 L p
1 g
F P
s
P
p
.002 w
.60187 .35736 m .58067 .32064 L .56013 .33247 L p
1 g
F P
s
P
p
.002 w
.53331 .3097 m .56013 .33247 L .58067 .32064 L p
1 g
F P
s
P
p
.002 w
.50009 .29701 m .46409 .29598 L .46495 .31872 L p
1 g
F P
s
P
p
.002 w
.43842 .32707 m .46495 .31872 L .46409 .29598 L p
1 g
F P
s
P
p
.002 w
.39984 .32851 m .37893 .35845 L .3999 .36646 L p
1 g
F P
s
P
p
.002 w
.3999 .36646 m .41589 .3436 L .39984 .32851 L p
1 g
F P
s
P
p
.002 w
.38646 .52861 m .42949 .5517 L .43329 .52895 L p
1 g
F P
s
P
p
.002 w
.43329 .52895 m .39606 .5088 L .38646 .52861 L p
1 g
F P
s
P
p
.002 w
.35088 .4378 m .36749 .47735 L .38451 .46156 L p
1 g
F P
s
P
p
.002 w
.38451 .46156 m .37095 .42894 L .35088 .4378 L p
1 g
F P
s
P
p
.002 w
.46409 .29598 m .42935 .30687 L .43842 .32707 L p
1 g
F P
s
P
p
.002 w
.41589 .3436 m .43842 .32707 L .42935 .30687 L p
1 g
F P
s
P
p
.002 w
.53465 .57179 m .58305 .54662 L .56971 .52906 L p
1 g
F P
s
P
p
.002 w
.56971 .52906 m .52608 .55169 L .53465 .57179 L p
1 g
F P
s
P
p
.002 w
.60422 .49404 m .56971 .52906 L .58305 .54662 L p
1 g
F P
s
P
p
.002 w
.42935 .30687 m .39984 .32851 L .41589 .3436 L p
1 g
F P
s
P
p
.002 w
.62612 .45013 m .60422 .49404 L .62138 .50776 L p
1 g
F P
s
P
p
.002 w
.58305 .54662 m .62138 .50776 L .60422 .49404 L p
1 g
F P
s
P
p
.002 w
.48096 .58063 m .53465 .57179 L .52608 .55169 L p
1 g
F P
s
P
p
.002 w
.52608 .55169 m .47771 .55957 L .48096 .58063 L p
1 g
F P
s
P
p
.002 w
.58067 .32064 m .54824 .29288 L .53331 .3097 L p
1 g
F P
s
P
p
.002 w
.50009 .29701 m .53331 .3097 L .54824 .29288 L p
1 g
F P
s
P
p
.002 w
.63306 .40171 m .62407 .35372 L .60187 .35736 L p
1 g
F P
s
P
p
.002 w
.58067 .32064 m .60187 .35736 L .62407 .35372 L p
1 g
F P
s
P
p
.002 w
.62138 .50776 m .64577 .45904 L .62612 .45013 L p
1 g
F P
s
P
p
.002 w
.63306 .40171 m .62612 .45013 L .64577 .45904 L p
1 g
F P
s
P
p
.002 w
.34835 .39441 m .35088 .4378 L .37095 .42894 L p
1 g
F P
s
P
p
.002 w
.37095 .42894 m .36896 .39325 L .34835 .39441 L p
1 g
F P
s
P
p
.002 w
.35335 .49241 m .38646 .52861 L .39606 .5088 L p
1 g
F P
s
P
p
.002 w
.39606 .5088 m .36749 .47735 L .35335 .49241 L p
1 g
F P
s
P
p
.002 w
.42738 .57204 m .48096 .58063 L .47771 .55957 L p
1 g
F P
s
P
p
.002 w
.47771 .55957 m .42949 .5517 L .42738 .57204 L p
1 g
F P
s
P
p
.002 w
.54824 .29288 m .50792 .27733 L .50009 .29701 L p
1 g
F P
s
P
p
.002 w
.46409 .29598 m .50009 .29701 L .50792 .27733 L p
1 g
F P
s
P
p
.002 w
.64577 .45904 m .65361 .40529 L .63306 .40171 L p
1 g
F P
s
P
p
.002 w
.62407 .35372 m .63306 .40171 L .65361 .40529 L p
1 g
F P
s
P
p
.002 w
.3604 .35203 m .34835 .39441 L .36896 .39325 L p
1 g
F P
s
P
p
.002 w
.36896 .39325 m .37893 .35845 L .3604 .35203 L p
1 g
F P
s
P
p
.002 w
.62407 .35372 m .59975 .31126 L .58067 .32064 L p
1 g
F P
s
P
p
.002 w
.54824 .29288 m .58067 .32064 L .59975 .31126 L p
1 g
F P
s
P
p
.002 w
.50792 .27733 m .46412 .27598 L .46409 .29598 L p
1 g
F P
s
P
p
.002 w
.42935 .30687 m .46409 .29598 L .46412 .27598 L p
1 g
F P
s
P
p
.002 w
.37949 .54652 m .42738 .57204 L .42949 .5517 L p
1 g
F P
s
P
p
.002 w
.42949 .5517 m .38646 .52861 L .37949 .54652 L p
1 g
F P
s
P
p
.002 w
.33402 .44676 m .35335 .49241 L .36749 .47735 L p
1 g
F P
s
P
p
.002 w
.36749 .47735 m .35088 .4378 L .33402 .44676 L p
1 g
F P
s
P
p
.002 w
.38584 .31554 m .3604 .35203 L .37893 .35845 L p
1 g
F P
s
P
p
.002 w
.37893 .35845 m .39984 .32851 L .38584 .31554 L p
1 g
F P
s
P
p
.002 w
.46412 .27598 m .4218 .28919 L .42935 .30687 L p
1 g
F P
s
P
p
.002 w
.39984 .32851 m .42935 .30687 L .4218 .28919 L p
1 g
F P
s
P
p
.002 w
.5426 .5889 m .5947 .56177 L .58305 .54662 L p
1 g
F P
s
P
p
.002 w
.58305 .54662 m .53465 .57179 L .5426 .5889 L p
1 g
F P
s
P
p
.002 w
.62138 .50776 m .58305 .54662 L .5947 .56177 L p
1 g
F P
s
P
p
.002 w
.4218 .28919 m .38584 .31554 L .39984 .32851 L p
1 g
F P
s
P
p
.002 w
.64577 .45904 m .62138 .50776 L .63598 .51993 L p
1 g
F P
s
P
p
.002 w
.5947 .56177 m .63598 .51993 L .62138 .50776 L p
1 g
F P
s
P
p
.002 w
.48481 .59852 m .5426 .5889 L .53465 .57179 L p
1 g
F P
s
P
p
.002 w
.53465 .57179 m .48096 .58063 L .48481 .59852 L p
1 g
F P
s
P
p
.002 w
.59975 .31126 m .56239 .27907 L .54824 .29288 L p
1 g
F P
s
P
p
.002 w
.50792 .27733 m .54824 .29288 L .56239 .27907 L p
1 g
F P
s
P
p
.002 w
.65361 .40529 m .64377 .35195 L .62407 .35372 L p
1 g
F P
s
P
p
.002 w
.59975 .31126 m .62407 .35372 L .64377 .35195 L p
1 g
F P
s
P
p
.002 w
.63598 .51993 m .66231 .46751 L .64577 .45904 L p
1 g
F P
s
P
p
.002 w
.65361 .40529 m .64577 .45904 L .66231 .46751 L p
1 g
F P
s
P
p
.002 w
.33096 .39655 m .33402 .44676 L .35088 .4378 L p
1 g
F P
s
P
p
.002 w
.35088 .4378 m .34835 .39441 L .33096 .39655 L p
1 g
F P
s
P
p
.002 w
.34255 .50638 m .37949 .54652 L .38646 .52861 L p
1 g
F P
s
P
p
.002 w
.38646 .52861 m .35335 .49241 L .34255 .50638 L p
1 g
F P
s
P
p
.002 w
.42709 .58939 m .48481 .59852 L .48096 .58063 L p
1 g
F P
s
P
p
.002 w
.48096 .58063 m .42738 .57204 L .42709 .58939 L p
1 g
F P
s
P
p
.002 w
.56239 .27907 m .51581 .26096 L .50792 .27733 L p
1 g
F P
s
P
p
.002 w
.46412 .27598 m .50792 .27733 L .51581 .26096 L p
1 g
F P
s
P
p
.002 w
.64377 .35195 m .61689 .30467 L .59975 .31126 L p
1 g
F P
s
P
p
.002 w
.56239 .27907 m .59975 .31126 L .61689 .30467 L p
1 g
F P
s
P
p
.002 w
.66231 .46751 m .67086 .40965 L .65361 .40529 L p
1 g
F P
s
P
p
.002 w
.64377 .35195 m .65361 .40529 L .67086 .40965 L p
1 g
F P
s
P
p
.002 w
.34485 .34744 m .33096 .39655 L .34835 .39441 L p
1 g
F P
s
P
p
.002 w
.34835 .39441 m .3604 .35203 L .34485 .34744 L p
1 g
F P
s
P
p
.002 w
.51581 .26096 m .46509 .25931 L .46412 .27598 L p
1 g
F P
s
P
p
.002 w
.4218 .28919 m .46412 .27598 L .46509 .25931 L p
1 g
F P
s
P
p
.002 w
.37543 .56203 m .42709 .58939 L .42738 .57204 L p
1 g
F P
s
P
p
.002 w
.42738 .57204 m .37949 .54652 L .37543 .56203 L p
1 g
F P
s
P
p
.002 w
.3209 .45562 m .34255 .50638 L .35335 .49241 L p
1 g
F P
s
P
p
.002 w
.35335 .49241 m .33402 .44676 L .3209 .45562 L p
1 g
F P
s
P
p
.002 w
.37432 .30511 m .34485 .34744 L .3604 .35203 L p
1 g
F P
s
P
p
.002 w
.3604 .35203 m .38584 .31554 L .37432 .30511 L p
1 g
F P
s
P
p
.002 w
.46509 .25931 m .41602 .27456 L .4218 .28919 L p
1 g
F P
s
P
p
.002 w
.38584 .31554 m .4218 .28919 L .41602 .27456 L p
1 g
F P
s
P
p
.002 w
.54973 .60248 m .6043 .57403 L .5947 .56177 L p
1 g
F P
s
P
p
.002 w
.5947 .56177 m .5426 .5889 L .54973 .60248 L p
1 g
F P
s
P
p
.002 w
.63598 .51993 m .5947 .56177 L .6043 .57403 L p
1 g
F P
s
P
p
.002 w
.41602 .27456 m .37432 .30511 L .38584 .31554 L p
1 g
F P
s
P
p
.002 w
.66231 .46751 m .63598 .51993 L .64755 .53021 L p
1 g
F P
s
P
p
.002 w
.6043 .57403 m .64755 .53021 L .63598 .51993 L p
1 g
F P
s
P
p
.002 w
.61689 .30467 m .57541 .26874 L .56239 .27907 L p
1 g
F P
s
P
p
.002 w
.51581 .26096 m .56239 .27907 L .57541 .26874 L p
1 g
F P
s
P
p
.002 w
.67086 .40965 m .66041 .35218 L .64377 .35195 L p
1 g
F P
s
P
p
.002 w
.61689 .30467 m .64377 .35195 L .66041 .35218 L p
1 g
F P
s
P
p
.002 w
.4892 .61264 m .54973 .60248 L .5426 .5889 L p
1 g
F P
s
P
p
.002 w
.5426 .5889 m .48481 .59852 L .4892 .61264 L p
1 g
F P
s
P
p
.002 w
.64755 .53021 m .67519 .47532 L .66231 .46751 L p
1 g
F P
s
P
p
.002 w
.67086 .40965 m .66231 .46751 L .67519 .47532 L p
1 g
F P
s
P
p
.002 w
.31739 .39968 m .3209 .45562 L .33402 .44676 L p
1 g
F P
s
P
p
.002 w
.33402 .44676 m .33096 .39655 L .31739 .39968 L p
1 g
F P
s
P
p
.002 w
.33552 .51886 m .37543 .56203 L .37949 .54652 L p
1 g
F P
s
P
p
.002 w
.37949 .54652 m .34255 .50638 L .33552 .51886 L p
1 g
F P
s
P
p
.002 w
.42872 .60319 m .4892 .61264 L .48481 .59852 L p
1 g
F P
s
P
p
.002 w
.48481 .59852 m .42709 .58939 L .42872 .60319 L p
1 g
F P
s
P
p
.002 w
.57541 .26874 m .52357 .24846 L .51581 .26096 L p
1 g
F P
s
P
p
.002 w
.46509 .25931 m .51581 .26096 L .52357 .24846 L p
1 g
F P
s
P
p
.002 w
.66041 .35218 m .63157 .30116 L .61689 .30467 L p
1 g
F P
s
P
p
.002 w
.57541 .26874 m .61689 .30467 L .63157 .30116 L p
1 g
F P
s
P
p
.002 w
.67519 .47532 m .68425 .41473 L .67086 .40965 L p
1 g
F P
s
P
p
.002 w
.66041 .35218 m .67086 .40965 L .68425 .41473 L p
1 g
F P
s
P
p
.002 w
.33283 .34487 m .31739 .39968 L .33096 .39655 L p
1 g
F P
s
P
p
.002 w
.33096 .39655 m .34485 .34744 L .33283 .34487 L p
1 g
F P
s
P
p
.002 w
.52357 .24846 m .46702 .24653 L .46509 .25931 L p
1 g
F P
s
P
p
.002 w
.41602 .27456 m .46509 .25931 L .46702 .24653 L p
1 g
F P
s
P
p
.002 w
.31207 .46416 m .33552 .51886 L .34255 .50638 L p
1 g
F P
s
P
p
.002 w
.34255 .50638 m .3209 .45562 L .31207 .46416 L p
1 g
F P
s
P
p
.002 w
.37456 .57463 m .42872 .60319 L .42709 .58939 L p
1 g
F P
s
P
p
.002 w
.42709 .58939 m .37543 .56203 L .37456 .57463 L p
1 g
F P
s
P
p
.002 w
.36569 .29762 m .33283 .34487 L .34485 .34744 L p
1 g
F P
s
P
p
.002 w
.34485 .34744 m .37432 .30511 L .36569 .29762 L p
1 g
F P
s
P
p
.002 w
.46702 .24653 m .41225 .26351 L .41602 .27456 L p
1 g
F P
s
P
p
.002 w
.37432 .30511 m .41602 .27456 L .41225 .26351 L p
1 g
F P
s
P
p
.002 w
.55582 .61202 m .61149 .58295 L .6043 .57403 L p
1 g
F P
s
P
p
.002 w
.6043 .57403 m .54973 .60248 L .55582 .61202 L p
1 g
F P
s
P
p
.002 w
.64755 .53021 m .6043 .57403 L .61149 .58295 L p
1 g
F P
s
P
p
.002 w
.41225 .26351 m .36569 .29762 L .37432 .30511 L p
1 g
F P
s
P
p
.002 w
.67519 .47532 m .64755 .53021 L .65565 .53824 L p
1 g
F P
s
P
p
.002 w
.61149 .58295 m .65565 .53824 L .64755 .53021 L p
1 g
F P
s
P
p
.002 w
.63157 .30116 m .58693 .26232 L .57541 .26874 L p
1 g
F P
s
P
p
.002 w
.52357 .24846 m .57541 .26874 L .58693 .26232 L p
1 g
F P
s
P
p
.002 w
.68425 .41473 m .67341 .3545 L .66041 .35218 L p
1 g
F P
s
P
p
.002 w
.63157 .30116 m .66041 .35218 L .67341 .3545 L p
1 g
F P
s
P
p
.002 w
.49406 .62244 m .55582 .61202 L .54973 .60248 L p
1 g
F P
s
P
p
.002 w
.54973 .60248 m .4892 .61264 L .49406 .62244 L p
1 g
F P
s
P
p
.002 w
.65565 .53824 m .68389 .48225 L .67519 .47532 L p
1 g
F P
s
P
p
.002 w
.68425 .41473 m .67519 .47532 L .68389 .48225 L p
1 g
F P
s
P
p
.002 w
.30821 .40377 m .31207 .46416 L .3209 .45562 L p
1 g
F P
s
P
p
.002 w
.3209 .45562 m .31739 .39968 L .30821 .40377 L p
1 g
F P
s
P
p
.002 w
.33266 .52946 m .37456 .57463 L .37543 .56203 L p
1 g
F P
s
P
p
.002 w
.37543 .56203 m .33552 .51886 L .33266 .52946 L p
1 g
F P
s
P
p
.002 w
.43236 .61287 m .49406 .62244 L .4892 .61264 L p
1 g
F P
s
P
p
.002 w
.4892 .61264 m .42872 .60319 L .43236 .61287 L p
1 g
F P
s
P
p
.002 w
.58693 .26232 m .53101 .24036 L .52357 .24846 L p
1 g
F P
s
P
p
.002 w
.46702 .24653 m .52357 .24846 L .53101 .24036 L p
1 g
F P
s
P
p
.002 w
.67341 .3545 m .64329 .301 L .63157 .30116 L p
1 g
F P
s
P
p
.002 w
.58693 .26232 m .63157 .30116 L .64329 .301 L p
1 g
F P
s
P
p
.002 w
.68389 .48225 m .6932 .42044 L .68425 .41473 L p
1 g
F P
s
P
p
.002 w
.67341 .3545 m .68425 .41473 L .6932 .42044 L p
1 g
F P
s
P
p
.002 w
.32484 .34453 m .30821 .40377 L .31739 .39968 L p
1 g
F P
s
P
p
.002 w
.31739 .39968 m .33283 .34487 L .32484 .34453 L p
1 g
F P
s
P
p
.002 w
.30801 .47213 m .33266 .52946 L .33552 .51886 L p
1 g
F P
s
P
p
.002 w
.33552 .51886 m .31207 .46416 L .30801 .47213 L p
1 g
F P
s
P
p
.002 w
.37708 .5838 m .43236 .61287 L .42872 .60319 L p
1 g
F P
s
P
p
.002 w
.42872 .60319 m .37456 .57463 L .37708 .5838 L p
1 g
F P
s
P
p
.002 w
.53101 .24036 m .46993 .23821 L .46702 .24653 L p
1 g
F P
s
P
p
.002 w
.41225 .26351 m .46702 .24653 L .46993 .23821 L p
1 g
F P
s
P
p
.002 w
.36036 .29342 m .32484 .34453 L .33283 .34487 L p
1 g
F P
s
P
p
.002 w
.33283 .34487 m .36569 .29762 L .36036 .29342 L p
1 g
F P
s
P
p
.002 w
.46993 .23821 m .41071 .25654 L .41225 .26351 L p
1 g
F P
s
P
p
.002 w
.36569 .29762 m .41225 .26351 L .41071 .25654 L p
1 g
F P
s
P
p
.002 w
.56064 .61699 m .61595 .5881 L .61149 .58295 L p
1 g
F P
s
P
p
.002 w
.61149 .58295 m .55582 .61202 L .56064 .61699 L p
1 g
F P
s
P
p
.002 w
.65565 .53824 m .61149 .58295 L .61595 .5881 L p
1 g
F P
s
P
p
.002 w
.41071 .25654 m .36036 .29342 L .36569 .29762 L p
1 g
F P
s
P
p
.002 w
.61595 .5881 m .65984 .54367 L .65565 .53824 L p
1 g
F P
s
P
p
.002 w
.68389 .48225 m .65565 .53824 L .65984 .54367 L p
1 g
F P
s
P
p
.002 w
.64329 .301 m .59655 .26023 L .58693 .26232 L p
1 g
F P
s
P
p
.002 w
.53101 .24036 m .58693 .26232 L .59655 .26023 L p
1 g
F P
s
P
p
.002 w
.6932 .42044 m .68222 .359 L .67341 .3545 L p
1 g
F P
s
P
p
.002 w
.64329 .301 m .67341 .3545 L .68222 .359 L p
1 g
F P
s
P
p
.002 w
.4993 .62738 m .56064 .61699 L .55582 .61202 L p
1 g
F P
s
P
p
.002 w
.55582 .61202 m .49406 .62244 L .4993 .62738 L p
1 g
F P
s
P
p
.002 w
.30392 .40877 m .30801 .47213 L .31207 .46416 L p
1 g
F P
s
P
p
.002 w
.31207 .46416 m .30821 .40377 L .30392 .40877 L p
1 g
F P
s
P
p
.002 w
.65984 .54367 m .68792 .48805 L .68389 .48225 L p
1 g
F P
s
P
p
.002 w
.6932 .42044 m .68389 .48225 L .68792 .48805 L p
1 g
F P
s
P
p
.002 w
.33432 .53777 m .37708 .5838 L .37456 .57463 L p
1 g
F P
s
P
p
.002 w
.37456 .57463 m .33266 .52946 L .33432 .53777 L p
1 g
F P
s
P
p
.002 w
.43803 .61791 m .4993 .62738 L .49406 .62244 L p
1 g
F P
s
P
p
.002 w
.49406 .62244 m .43236 .61287 L .43803 .61791 L p
1 g
F P
s
P
p
.002 w
.59655 .26023 m .53792 .23714 L .53101 .24036 L p
1 g
F P
s
P
p
.002 w
.46993 .23821 m .53101 .24036 L .53792 .23714 L p
1 g
F P
s
P
p
.002 w
.68222 .359 m .65155 .30441 L .64329 .301 L p
1 g
F P
s
P
p
.002 w
.59655 .26023 m .64329 .301 L .65155 .30441 L p
1 g
F P
s
P
p
.002 w
.68792 .48805 m .6972 .42667 L .6932 .42044 L p
1 g
F P
s
P
p
.002 w
.68222 .359 m .6932 .42044 L .6972 .42667 L p
1 g
F P
s
P
p
.002 w
.32137 .34656 m .30392 .40877 L .30821 .40377 L p
1 g
F P
s
P
p
.002 w
.30821 .40377 m .32484 .34453 L .32137 .34656 L p
1 g
F P
s
P
p
.002 w
.30916 .47928 m .33432 .53777 L .33266 .52946 L p
1 g
F P
s
P
p
.002 w
.33266 .52946 m .30801 .47213 L .30916 .47928 L p
1 g
F P
s
P
p
.002 w
.38316 .58908 m .43803 .61791 L .43236 .61287 L p
1 g
F P
s
P
p
.002 w
.43236 .61287 m .37708 .5838 L .38316 .58908 L p
1 g
F P
s
P
p
.002 w
.53792 .23714 m .47381 .23487 L .46993 .23821 L p
1 g
F P
s
P
p
.002 w
.41071 .25654 m .46993 .23821 L .47381 .23487 L p
1 g
F P
s
P
p
.002 w
.35868 .29287 m .32137 .34656 L .32484 .34453 L p
1 g
F P
s
P
p
.002 w
.32484 .34453 m .36036 .29342 L .35868 .29287 L p
1 g
F P
s
P
p
.002 w
.47381 .23487 m .4116 .25412 L .41071 .25654 L p
1 g
F P
s
P
p
.002 w
.36036 .29342 m .41071 .25654 L .4116 .25412 L p
1 g
F P
s
P
p
.002 w
.56397 .61698 m .61738 .58908 L .61595 .5881 L p
1 g
F P
s
P
p
.002 w
.61595 .5881 m .56064 .61699 L .56397 .61698 L p
1 g
F P
s
P
p
.002 w
.65984 .54367 m .61595 .5881 L .61738 .58908 L p
1 g
F P
s
P
p
.002 w
.4116 .25412 m .35868 .29287 L .36036 .29342 L p
1 g
F P
s
P
p
.002 w
.65155 .30441 m .6039 .2628 L .59655 .26023 L p
1 g
F P
s
P
p
.002 w
.53792 .23714 m .59655 .26023 L .6039 .2628 L p
1 g
F P
s
P
p
.002 w
.6972 .42667 m .68633 .36568 L .68222 .359 L p
1 g
F P
s
P
p
.002 w
.65155 .30441 m .68222 .359 L .68633 .36568 L p
1 g
F P
s
P
p
.002 w
.61738 .58908 m .65975 .54618 L .65984 .54367 L p
1 g
F P
s
P
p
.002 w
.68792 .48805 m .65984 .54367 L .65975 .54618 L p
1 g
F P
s
P
p
.002 w
.50478 .627 m .56397 .61698 L .56064 .61699 L p
1 g
F P
s
P
p
.002 w
.56064 .61699 m .4993 .62738 L .50478 .627 L p
1 g
F P
s
P
p
.002 w
.30499 .4146 m .30916 .47928 L .30801 .47213 L p
1 g
F P
s
P
p
.002 w
.30801 .47213 m .30392 .40877 L .30499 .4146 L p
1 g
F P
s
P
p
.002 w
.34074 .5434 m .38316 .58908 L .37708 .5838 L p
1 g
F P
s
P
p
.002 w
.37708 .5838 m .33432 .53777 L .34074 .5434 L p
1 g
F P
s
P
p
.002 w
.65975 .54618 m .68687 .4925 L .68792 .48805 L p
1 g
F P
s
P
p
.002 w
.6972 .42667 m .68792 .48805 L .68687 .4925 L p
1 g
F P
s
P
p
.002 w
.44569 .61786 m .50478 .627 L .4993 .62738 L p
1 g
F P
s
P
p
.002 w
.4993 .62738 m .43803 .61791 L .44569 .61786 L p
1 g
F P
s
P
p
.002 w
.6039 .2628 m .54406 .23923 L .53792 .23714 L p
1 g
F P
s
P
p
.002 w
.47381 .23487 m .53792 .23714 L .54406 .23923 L p
1 g
F P
s
P
p
.002 w
.68633 .36568 m .6559 .31151 L .65155 .30441 L p
1 g
F P
s
P
p
.002 w
.6039 .2628 m .65155 .30441 L .6559 .31151 L p
1 g
F P
s
P
p
.002 w
.68687 .4925 m .69581 .43329 L .6972 .42667 L p
1 g
F P
s
P
p
.002 w
.68633 .36568 m .6972 .42667 L .69581 .43329 L p
1 g
F P
s
P
p
.002 w
.32282 .35107 m .30499 .4146 L .30392 .40877 L p
1 g
F P
s
P
p
.002 w
.30392 .40877 m .32137 .34656 L .32282 .35107 L p
1 g
F P
s
P
p
.002 w
.31581 .48536 m .34074 .5434 L .33432 .53777 L p
1 g
F P
s
P
p
.002 w
.33432 .53777 m .30916 .47928 L .31581 .48536 L p
1 g
F P
s
P
p
.002 w
.39284 .59005 m .44569 .61786 L .43803 .61791 L p
1 g
F P
s
P
p
.002 w
.43803 .61791 m .38316 .58908 L .39284 .59005 L p
1 g
F P
s
P
p
.002 w
.54406 .23923 m .47859 .23693 L .47381 .23487 L p
1 g
F P
s
P
p
.002 w
.4116 .25412 m .47381 .23487 L .47859 .23693 L p
1 g
F P
s
P
p
.002 w
.36096 .29621 m .32282 .35107 L .32137 .34656 L p
1 g
F P
s
P
p
.002 w
.32137 .34656 m .35868 .29287 L .36096 .29621 L p
1 g
F P
s
P
p
.002 w
.47859 .23693 m .41504 .2566 L .4116 .25412 L p
1 g
F P
s
P
p
.002 w
.35868 .29287 m .4116 .25412 L .41504 .2566 L p
1 g
F P
s
P
p
.002 w
.6559 .31151 m .6086 .27025 L .6039 .2628 L p
1 g
F P
s
P
p
.002 w
.54406 .23923 m .6039 .2628 L .6086 .27025 L p
1 g
F P
s
P
p
.002 w
.69581 .43329 m .68531 .3745 L .68633 .36568 L p
1 g
F P
s
P
p
.002 w
.6559 .31151 m .68633 .36568 L .68531 .3745 L p
1 g
F P
s
P
p
.002 w
.56563 .61164 m .61552 .58558 L .61738 .58908 L p
1 g
F P
s
P
p
.002 w
.61738 .58908 m .56397 .61698 L .56563 .61164 L p
1 g
F P
s
P
p
.004 w
.60838 .61197 m
.65072 .68287 L
s
P
p
.002 w
.65975 .54618 m .61738 .58908 L .61552 .58558 L p
1 g
F P
s
P
p
.002 w
.41504 .2566 m .36096 .29621 L .35868 .29287 L p
1 g
F P
s
P
p
.002 w
.61552 .58558 m .65511 .54551 L .65975 .54618 L p
1 g
F P
s
P
p
.002 w
.68687 .4925 m .65975 .54618 L .65511 .54551 L p
1 g
F P
s
P
p
.002 w
.51037 .62097 m .56563 .61164 L .56397 .61698 L p
1 g
F P
s
P
p
.002 w
.56397 .61698 m .50478 .627 L .51037 .62097 L p
1 g
F P
s
P
p
.002 w
.31172 .42115 m .31581 .48536 L .30916 .47928 L p
1 g
F P
s
P
p
.002 w
.30916 .47928 m .30499 .4146 L .31172 .42115 L p
1 g
F P
s
P
p
.002 w
.35203 .54601 m .39284 .59005 L .38316 .58908 L p
1 g
F P
s
P
p
.002 w
.38316 .58908 m .34074 .5434 L .35203 .54601 L p
1 g
F P
s
P
p
.002 w
.65511 .54551 m .68041 .49537 L .68687 .4925 L p
1 g
F P
s
P
p
.002 w
.69581 .43329 m .68687 .4925 L .68041 .49537 L p
1 g
F P
s
P
p
.002 w
.45526 .6124 m .51037 .62097 L .50478 .627 L p
1 g
F P
s
P
p
.002 w
.50478 .627 m .44569 .61786 L .45526 .6124 L p
1 g
F P
s
P
p
.002 w
.6086 .27025 m .54921 .24691 L .54406 .23923 L p
1 g
F P
s
P
p
.002 w
.47859 .23693 m .54406 .23923 L .54921 .24691 L p
1 g
F P
s
P
p
.002 w
.68531 .3745 m .65595 .32235 L .6559 .31151 L p
1 g
F P
s
P
p
.002 w
.6086 .27025 m .6559 .31151 L .65595 .32235 L p
1 g
F P
s
P
p
.002 w
.68041 .49537 m .68873 .44011 L .69581 .43329 L p
1 g
F P
s
P
p
.002 w
.68531 .3745 m .69581 .43329 L .68873 .44011 L p
1 g
F P
s
P
p
.002 w
.32948 .35808 m .31172 .42115 L .30499 .4146 L p
1 g
F P
s
P
p
.002 w
.30499 .4146 m .32282 .35107 L .32948 .35808 L p
1 g
F P
s
P
p
.002 w
.32811 .49008 m .35203 .54601 L .34074 .5434 L p
1 g
F P
s
P
p
.002 w
.34074 .5434 m .31581 .48536 L .32811 .49008 L p
1 g
F P
s
P
p
.002 w
.40605 .58641 m .45526 .6124 L .44569 .61786 L p
1 g
F P
s
P
p
.002 w
.44569 .61786 m .39284 .59005 L .40605 .58641 L p
1 g
F P
s
P
p
.002 w
.54921 .24691 m .4842 .24467 L .47859 .23693 L p
1 g
F P
s
P
p
.002 w
.41504 .2566 m .47859 .23693 L .4842 .24467 L p
1 g
F P
s
P
p
.002 w
.36739 .3036 m .32948 .35808 L .32282 .35107 L p
1 g
F P
s
P
p
.002 w
.32282 .35107 m .36096 .29621 L .36739 .3036 L p
1 g
F P
s
P
p
.002 w
.65595 .32235 m .61035 .28267 L .6086 .27025 L p
1 g
F P
s
P
p
.002 w
.54921 .24691 m .6086 .27025 L .61035 .28267 L p
1 g
F P
s
P
p
.002 w
.68873 .44011 m .67887 .38532 L .68531 .3745 L p
1 g
F P
s
P
p
.002 w
.65595 .32235 m .68531 .3745 L .67887 .38532 L p
1 g
F P
s
P
p
.002 w
.4842 .24467 m .42109 .26425 L .41504 .2566 L p
1 g
F P
s
P
p
.002 w
.36096 .29621 m .41504 .2566 L .42109 .26425 L p
1 g
F P
s
P
p
.002 w
.56545 .60079 m .61022 .57743 L .61552 .58558 L p
1 g
F P
s
P
p
.002 w
.61552 .58558 m .56563 .61164 L .56545 .60079 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.59308 .58637 L
s
P
p
.004 w
.59677 .59253 m
.5975 .59377 L
s
P
p
.004 w
.5975 .59377 m
.60118 .59992 L
s
P
p
.004 w
.60118 .59992 m
.60838 .61197 L
s
P
p
.002 w
.65511 .54551 m .61552 .58558 L .61022 .57743 L p
1 g
F P
s
P
p
.002 w
.42109 .26425 m .36739 .3036 L .36096 .29621 L p
1 g
F P
s
P
p
.002 w
.68041 .49537 m .65511 .54551 L .64574 .54145 L p
1 g
F P
s
P
p
.002 w
.61022 .57743 m .64574 .54145 L .65511 .54551 L p
1 g
F P
s
P
p
.002 w
.51589 .60911 m .56545 .60079 L .56563 .61164 L p
1 g
F P
s
P
p
.002 w
.56563 .61164 m .51037 .62097 L .51589 .60911 L p
1 g
F P
s
P
p
.002 w
.32428 .42825 m .32811 .49008 L .31581 .48536 L p
1 g
F P
s
P
p
.002 w
.31581 .48536 m .31172 .42115 L .32428 .42825 L p
1 g
F P
s
P
p
.002 w
.36814 .54532 m .40605 .58641 L .39284 .59005 L p
1 g
F P
s
P
p
.002 w
.39284 .59005 m .35203 .54601 L .36814 .54532 L p
1 g
F P
s
P
p
.002 w
.64574 .54145 m .66841 .49646 L .68041 .49537 L p
1 g
F P
s
P
p
.002 w
.68873 .44011 m .68041 .49537 L .66841 .49646 L p
1 g
F P
s
P
p
.002 w
.46654 .60134 m .51589 .60911 L .51037 .62097 L p
1 g
F P
s
P
p
.002 w
.51037 .62097 m .45526 .6124 L .46654 .60134 L p
1 g
F P
s
P
p
.002 w
.61035 .28267 m .55312 .26029 L .54921 .24691 L p
1 g
F P
s
P
p
.002 w
.4842 .24467 m .54921 .24691 L .55312 .26029 L p
1 g
F P
s
P
p
.002 w
.67887 .38532 m .65143 .3368 L .65595 .32235 L p
1 g
F P
s
P
p
.002 w
.61035 .28267 m .65595 .32235 L .65143 .3368 L p
1 g
F P
s
P
p
.002 w
.66841 .49646 m .67579 .44693 L .68873 .44011 L p
1 g
F P
s
P
p
.002 w
.67887 .38532 m .68873 .44011 L .67579 .44693 L p
1 g
F P
s
P
p
.002 w
.34146 .36753 m .32428 .42825 L .31172 .42115 L p
1 g
F P
s
P
p
.002 w
.31172 .42115 m .32948 .35808 L .34146 .36753 L p
1 g
F P
s
P
p
.002 w
.34601 .49323 m .36814 .54532 L .35203 .54601 L p
1 g
F P
s
P
p
.002 w
.35203 .54601 m .32811 .49008 L .34601 .49323 L p
1 g
F P
s
P
p
.002 w
.42258 .57799 m .46654 .60134 L .45526 .6124 L p
1 g
F P
s
P
p
.002 w
.45526 .6124 m .40605 .58641 L .42258 .57799 L p
1 g
F P
s
P
p
.002 w
.55312 .26029 m .49052 .25823 L .4842 .24467 L p
1 g
F P
s
P
p
.002 w
.42109 .26425 m .4842 .24467 L .49052 .25823 L p
1 g
F P
s
P
p
.002 w
.37801 .31507 m .34146 .36753 L .32948 .35808 L p
1 g
F P
s
P
p
.002 w
.32948 .35808 m .36739 .3036 L .37801 .31507 L p
1 g
F P
s
P
p
.002 w
.67579 .44693 m .66687 .39791 L .67887 .38532 L p
1 g
F P
s
P
p
.002 w
.65143 .3368 m .67887 .38532 L .66687 .39791 L p
1 g
F P
s
P
p
.002 w
.65143 .3368 m .6089 .29998 L .61035 .28267 L p
1 g
F P
s
P
p
.002 w
.55312 .26029 m .61035 .28267 L .6089 .29998 L p
1 g
F P
s
P
p
.002 w
.49052 .25823 m .42975 .27715 L .42109 .26425 L p
1 g
F P
s
P
p
.002 w
.36739 .3036 m .42109 .26425 L .42975 .27715 L p
1 g
F P
s
P
p
.002 w
.56331 .58443 m .60144 .56457 L .61022 .57743 L p
1 g
F P
s
P
p
.002 w
.61022 .57743 m .56545 .60079 L .56331 .58443 L p
1 g
F P
s
P
p
.002 w
.64574 .54145 m .61022 .57743 L .60144 .56457 L p
1 g
F P
s
P
p
.002 w
.42975 .27715 m .37801 .31507 L .36739 .3036 L p
1 g
F P
s
P
p
.002 w
.60144 .56457 m .63167 .53394 L .64574 .54145 L p
1 g
F P
s
P
p
.002 w
.66841 .49646 m .64574 .54145 L .63167 .53394 L p
1 g
F P
s
P
p
.002 w
.52115 .59145 m .56331 .58443 L .56545 .60079 L p
1 g
F P
s
P
p
.002 w
.56545 .60079 m .51589 .60911 L .52115 .59145 L p
1 g
F P
s
P
p
.002 w
.38881 .54117 m .42258 .57799 L .40605 .58641 L p
1 g
F P
s
P
p
.002 w
.40605 .58641 m .36814 .54532 L .38881 .54117 L p
1 g
F P
s
P
p
.002 w
.34258 .43569 m .34601 .49323 L .32811 .49008 L p
1 g
F P
s
P
p
.002 w
.32811 .49008 m .32428 .42825 L .34258 .43569 L p
1 g
F P
s
P
p
.002 w
.63167 .53394 m .65091 .49564 L .66841 .49646 L p
1 g
F P
s
P
p
.002 w
.67579 .44693 m .66841 .49646 L .65091 .49564 L p
1 g
F P
s
P
p
.002 w
.47925 .58475 m .52115 .59145 L .51589 .60911 L p
1 g
F P
s
P
p
.002 w
.51589 .60911 m .46654 .60134 L .47925 .58475 L p
1 g
F P
s
P
p
.002 w
.6089 .29998 m .55561 .27929 L .55312 .26029 L p
1 g
F P
s
P
p
.002 w
.49052 .25823 m .55312 .26029 L .55561 .27929 L p
1 g
F P
s
P
p
.002 w
.66687 .39791 m .64221 .3546 L .65143 .3368 L p
1 g
F P
s
P
p
.002 w
.6089 .29998 m .65143 .3368 L .64221 .3546 L p
1 g
F P
s
P
p
.002 w
.65091 .49564 m .6571 .45353 L .67579 .44693 L p
1 g
F P
s
P
p
.002 w
.66687 .39791 m .67579 .44693 L .6571 .45353 L p
1 g
F P
s
P
p
.002 w
.35868 .37923 m .34258 .43569 L .32428 .42825 L p
1 g
F P
s
P
p
.002 w
.32428 .42825 m .34146 .36753 L .35868 .37923 L p
1 g
F P
s
P
p
.002 w
.36921 .49459 m .38881 .54117 L .36814 .54532 L p
1 g
F P
s
P
p
.002 w
.36814 .54532 m .34601 .49323 L .36921 .49459 L p
1 g
F P
s
P
p
.002 w
.44203 .56481 m .47925 .58475 L .46654 .60134 L p
1 g
F P
s
P
p
.002 w
.46654 .60134 m .42258 .57799 L .44203 .56481 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.55561 .27929 m .49736 .27749 L .49052 .25823 L p
1 g
F P
s
P
p
.002 w
.42975 .27715 m .49052 .25823 L .49736 .27749 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.39272 .33046 m .35868 .37923 L .34146 .36753 L p
1 g
F P
s
P
p
.002 w
.34146 .36753 m .37801 .31507 L .39272 .33046 L p
1 g
F P
s
P
p
.002 w
.6571 .45353 m .6494 .41195 L .66687 .39791 L p
1 g
F P
s
P
p
.002 w
.64221 .3546 m .66687 .39791 L .6494 .41195 L p
1 g
F P
s
P
p
.002 w
.64221 .3546 m .60412 .32184 L .6089 .29998 L p
1 g
F P
s
P
p
.002 w
.55561 .27929 m .6089 .29998 L .60412 .32184 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.49736 .27749 m .44084 .29517 L .42975 .27715 L p
1 g
F P
s
P
p
.002 w
.37801 .31507 m .42975 .27715 L .44084 .29517 L p
1 g
F P
s
P
p
.002 w
.55918 .56282 m .58926 .54718 L .60144 .56457 L p
1 g
F P
s
P
p
.002 w
.60144 .56457 m .56331 .58443 L .55918 .56282 L p
1 g
F P
s
P
p
.002 w
.63167 .53394 m .60144 .56457 L .58926 .54718 L p
1 g
F P
s
P
p
.002 w
.44084 .29517 m .39272 .33046 L .37801 .31507 L p
1 g
F P
s
P
p
.002 w
.58926 .54718 m .61309 .52302 L .63167 .53394 L p
1 g
F P
s
P
p
.002 w
.65091 .49564 m .63167 .53394 L .61309 .52302 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.41355 .53351 m .44203 .56481 L .42258 .57799 L p
1 g
F P
s
P
p
.002 w
.42258 .57799 m .38881 .54117 L .41355 .53351 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53165 .57433 L p
1 g
F P
s
P
p
.002 w
.55918 .56282 m .56331 .58443 L p
.53506 .57221 L 1 g
F P
s
P
p
.002 w
.54693 .56483 m .54804 .56465 L p
.53506 .57221 L 1 g
F P
s
P
p
.002 w
.54804 .56465 m .55918 .56282 L p
.54409 .56869 L 1 g
F P
s
P
p
.53506 .57221 m .54804 .56465 L .54409 .56869 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54924 .56316 L p
1 g
F P
s
P
p
.56075 .54566 m .54924 .56316 L .55024 .56191 L 1 g
F
P
p
.002 w
.55703 .55345 m .55918 .56282 L p
.55323 .55818 L 1 g
F P
s
P
p
.56075 .54566 m .55024 .56191 L .55392 .55732 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.52596 .56828 m .53012 .54016 L p
.55323 .55818 L 1 g
F P
s
P
p
.002 w
.55918 .56282 m .54804 .56465 L p
.54924 .56316 L 1 g
F P
s
P
p
.002 w
.54924 .56316 m .54854 .56129 L p
.53815 .57119 L 1 g
F P
s
P
p
.54854 .56129 m .53165 .57433 L .54087 .5686 L 1 g
F
P
p
.002 w
.54804 .56465 m .52596 .56828 L p
.55323 .55818 L 1 g
F P
s
P
p
.002 w
.56331 .58443 m .52115 .59145 L .52367 .57929 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58008 L p
1 g
F P
s
P
p
.53128 .57265 m .5109 .58008 L .51896 .57825 L 1 g
F
P
p
.52115 .59145 m .51012 .58026 L .5109 .58008 L 1 g
F
P
p
.002 w
.52413 .57707 m .52355 .57989 L p
.5109 .58008 L 1 g
F P
s
P
p
.002 w
.52355 .57989 m .52115 .59145 L p
.5109 .58008 L 1 g
F P
s
P
p
.002 w
.5109 .58008 m .51079 .57862 L p
.50288 .5802 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58041 L p
1 g
F P
s
P
p
.002 w
.52115 .59145 m .47925 .58475 L .48192 .58051 L p
1 g
F P
s
P
p
.52115 .59145 m .48192 .58051 L .48676 .58044 L 1 g
F
P
p
.51079 .57862 m .48908 .58041 L .50288 .5802 L 1 g
F
P
p
.002 w
.48908 .58041 m .48921 .57862 L p
.47872 .57776 L 1 g
F P
s
P
p
.002 w
.48277 .57917 m .47925 .58475 L p
.476 .57681 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47925 .58475 m .44304 .56535 L p
.46839 .57417 L 1 g
F P
s
P
p
.47722 .57978 m .46839 .57417 L .476 .57681 L 1 g
F
P
p
.47925 .58475 m .46839 .57417 L .47722 .57978 L 1 g
F
P
p
.002 w
.46839 .57417 m .46872 .57265 L p
.46141 .56973 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46839 .57417 L p
1 g
F P
s
P
p
.002 w
.46839 .57417 m .4678 .57686 L p
.47872 .57776 L 1 g
F P
s
P
p
.48921 .57862 m .46839 .57417 L .47872 .57776 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45082 .563 L p
1 g
F P
s
P
p
.002 w
.44203 .56481 m .44715 .56066 L p
.45082 .563 L 1 g
F P
s
P
p
.46824 .57407 m .45744 .57026 L .45082 .563 L 1 g
F
P
p
.45744 .57026 m .44203 .56481 L .45082 .563 L 1 g
F
P
p
.002 w
.45082 .563 m .45146 .56129 L p
.44501 .55569 L 1 g
F P
s
P
p
.002 w
.44804 .55994 m .44203 .56481 L p
.4419 .55131 L 1 g
F P
s
P
p
.002 w
.44203 .56481 m .41355 .53351 L .42582 .52869 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.44203 .56481 m .42582 .52869 L .43866 .54676 L 1 g
F
P
p
.44195 .55656 m .43866 .54676 L .4419 .55131 L 1 g
F
P
p
.44203 .56481 m .43866 .54676 L .44195 .55656 L 1 g
F
P
p
.002 w
.43866 .54676 m .43925 .54566 L p
.43642 .54006 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43866 .54676 L p
1 g
F P
s
P
p
.002 w
.43866 .54676 m .43743 .5491 L p
.44501 .55569 L 1 g
F P
s
P
p
.45146 .56129 m .43866 .54676 L .44501 .55569 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43258 .52862 L p
1 g
F P
s
P
p
.002 w
.42582 .52869 m .43182 .52633 L p
.43258 .52862 L 1 g
F P
s
P
p
.43866 .54676 m .43237 .53791 L .43258 .52862 L 1 g
F
P
p
.43237 .53791 m .42582 .52869 L .43258 .52862 L 1 g
F
P
p
.002 w
.43258 .52862 m .43346 .52734 L p
.43318 .51926 L 1 g
F P
s
P
p
.41355 .53351 m .43434 .50466 L .43397 .50931 L 1 g
F
P
p
.002 w
.43264 .52601 m .42486 .52906 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.42486 .52906 m .41355 .53351 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.43397 .50931 m .43485 .50826 L p
.43816 .50052 L 1 g
F P
s
P
p
.002 w
.42893 .49148 m .44344 .4896 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.43517 .5067 m .43277 .50084 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.43277 .50084 m .42893 .49148 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43318 .51926 m .43264 .52601 L .43258 .52862 L 1 g
F
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43925 .54566 m .43258 .52862 L .43642 .54006 L 1 g
F
P
p
.43866 .54676 m .43258 .52862 L .44164 .52247 L 1 g
F
P
p
.002 w
.43182 .52633 m .43264 .52601 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .433 .51046 L p
1 g
F P
s
P
p
.43346 .52734 m .433 .51046 L .43295 .51272 L 1 g
F
P
p
.002 w
.43264 .52601 m .44164 .52247 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.433 .51046 m .43287 .51061 L p
.43295 .51272 L 1 g
F P
s
P
p
.002 w
.44164 .52247 m .43264 .52601 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.43434 .50466 m .43517 .5067 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44192 .49206 L p
1 g
F P
s
P
p
.43485 .50826 m .44192 .49206 L .43998 .49626 L 1 g
F
P
p
.43816 .50052 m .43517 .5067 L .43397 .50931 L 1 g
F
P
p
.002 w
.43517 .5067 m .44164 .52247 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.44192 .49206 m .44166 .49233 L p
.43998 .49626 L 1 g
F P
s
P
p
.002 w
.4426 .49134 m .44339 .4905 L p
.44994 .48422 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46352 .487 m .44455 .48946 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.45766 .47673 m .45826 .47608 L p
.46845 .47161 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.46297 .47428 m .47755 .46719 L .49914 .46884 L 1 g
F
P
p
.002 w
.47755 .46719 m .47786 .46667 L p
.48968 .46547 L 1 g
F P
s
P
p
.002 w
.49914 .46884 m .48252 .46649 L p
.5 .46399 L 1 g
F P
s
P
p
.002 w
.5 .46399 m .5 .4634 L p
.50987 .46541 L 1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56605 .50933 L p
1 g
F P
s
P
p
.59043 .5089 m .57329 .52475 L .56605 .50933 L 1 g
F
P
p
.56547 .50288 m .56605 .50933 L .5627 .50221 L 1 g
F
P
p
.59043 .5089 m .56605 .50933 L .56547 .50288 L 1 g
F
P
p
.002 w
.56605 .50933 m .56515 .50826 L p
.56695 .51991 L 1 g
F P
s
P
p
.002 w
.5666 .51544 m .57394 .52564 L p
.56703 .52094 L 1 g
F P
s
P
p
.56695 .51991 m .56709 .52081 L .5666 .51544 L 1 g
F
P
p
.56695 .51991 m .5666 .51544 L .56605 .50933 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56764 .52895 L p
1 g
F P
s
P
p
.56783 .54082 m .56764 .52895 L .57394 .52564 L 1 g
F
P
p
.002 w
.56764 .5289 m .56766 .52889 L p
.56764 .52895 L 1 g
F P
s
P
p
.002 w
.56766 .52889 m .57394 .52564 L p
.56764 .52895 L 1 g
F P
s
P
p
.002 w
.56764 .52895 m .56654 .52734 L p
.56461 .53792 L 1 g
F P
s
P
p
.56515 .50826 m .56764 .52895 L .56764 .5289 L 1 g
F
P
p
.002 w
.57394 .52564 m .56764 .5289 L p
.56703 .52094 L 1 g
F P
s
P
p
.5674 .52576 m .56764 .5289 L .56762 .52748 L 1 g
F
P
p
.56515 .50826 m .56764 .5289 L .5674 .52576 L 1 g
F
P
p
.56515 .50826 m .56785 .52924 L .56709 .52081 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55311 .53644 m .54522 .5061 L p
.56703 .52094 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56151 .54708 L p
1 g
F P
s
P
p
.56654 .52734 m .56151 .54708 L .56461 .53792 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55311 .53644 m .56764 .5289 L p
.56764 .52895 L 1 g
F P
s
P
p
.56783 .54082 m .56401 .53968 L .56764 .52895 L 1 g
F
P
p
.56401 .53968 m .55311 .53644 L .56764 .52895 L 1 g
F
P
p
.55462 .55926 m .54924 .56316 L .55323 .55818 L 1 g
F
P
p
.56075 .54566 m .55201 .56058 L .55436 .55725 L 1 g
F
P
p
.55918 .56282 m .54924 .56316 L .55462 .55926 L 1 g
F
P
p
.002 w
.58926 .54718 m .55918 .56282 L .55703 .55345 L p
1 g
F P
s
P
p
.58926 .54718 m .55703 .55345 L .56624 .54035 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55703 .55345 m .55311 .53644 L p
.56624 .54035 L 1 g
F P
s
P
p
.002 w
.56151 .54708 m .56257 .5491 L p
.56461 .53792 L 1 g
F P
s
P
p
.002 w
.56764 .5289 m .55311 .53644 L p
.56703 .52094 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56764 .52895 L p
1 g
F P
s
P
p
.56461 .53792 m .56257 .5491 L .56764 .52895 L 1 g
F
P
p
.002 w
.56764 .52895 m .56785 .52924 L p
.56762 .52748 L 1 g
F P
s
P
p
.002 w
.57394 .52564 m .58926 .54718 L p
.56783 .54082 L 1 g
F P
s
P
p
.55661 .4905 m .56605 .50933 L .56246 .50169 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.5627 .50221 m .56605 .50933 L .55591 .50057 L 1 g
F
P
p
.002 w
.57329 .52475 m .5666 .51544 L p
.56605 .50933 L 1 g
F P
s
P
p
.002 w
.5666 .51544 m .55591 .50057 L p
.56605 .50933 L 1 g
F P
s
P
p
.002 w
.56785 .52924 m .56854 .53025 L p
.56709 .52081 L 1 g
F P
s
P
p
.002 w
.54522 .5061 m .55591 .50057 L .5666 .51544 L p
1 g
F P
s
P
p
.56703 .52094 m .54522 .5061 L .5666 .51544 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56605 .50933 L p
1 g
F P
s
P
p
.56709 .52081 m .56854 .53025 L .56605 .50933 L 1 g
F
P
p
.002 w
.56436 .49198 m .59043 .5089 L p
.5627 .50221 L 1 g
F P
s
P
p
.55661 .4905 m .56246 .50169 L .55999 .49643 L 1 g
F
P
p
.002 w
.56436 .49198 m .56128 .49511 L p
.55465 .48571 L 1 g
F P
s
P
p
.002 w
.56128 .49511 m .55999 .49643 L p
.55751 .49146 L 1 g
F P
s
P
p
.56128 .49511 m .55751 .49146 L .55465 .48571 L 1 g
F
P
p
.002 w
.55751 .49146 m .55661 .4905 L p
.55999 .49643 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55751 .49146 L p
1 g
F P
s
P
p
.002 w
.55779 .49175 m .55751 .49146 L p
.55999 .49643 L 1 g
F P
s
P
p
.54174 .47608 m .55751 .49146 L .55033 .48449 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55591 .50057 m .53677 .47417 L p
.54551 .47982 L 1 g
F P
s
P
p
.54174 .47608 m .55033 .48449 L .54391 .47827 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.53578 .47281 m .53915 .47365 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.54391 .47827 m .54018 .47576 L p
.54239 .47679 L 1 g
F P
s
P
p
.52214 .46667 m .54239 .47679 L .54235 .47677 L 1 g
F
P
p
.52214 .46667 m .54239 .47679 L .54208 .47665 L 1 g
F
P
p
.52214 .46667 m .54241 .47681 L .5385 .47499 L 1 g
F
P
p
.002 w
.54018 .47576 m .53578 .47281 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54239 .47679 L p
.54235 .47677 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54239 .47679 L p
.54391 .47827 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.54391 .47827 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.56968 .48125 m .56436 .49198 L .54391 .47827 L p
1 g
F P
s
P
p
.002 w
.53915 .47365 m .56968 .48125 L p
.54391 .47827 L 1 g
F P
s
P
p
.55465 .48571 m .55492 .48895 L .54551 .47982 L 1 g
F
P
p
.55492 .48895 m .55591 .50057 L .54551 .47982 L 1 g
F
P
p
.002 w
.55999 .49643 m .55591 .50057 L p
.55465 .48571 L 1 g
F P
s
P
p
.002 w
.55999 .49643 m .56436 .49198 L p
.5627 .50221 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55779 .49175 L p
1 g
F P
s
P
p
.56246 .50169 m .56713 .51061 L .55779 .49175 L 1 g
F
P
p
.002 w
.54018 .47576 m .56436 .49198 L p
.53677 .47417 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54239 .47679 L p
1 g
F P
s
P
p
.55033 .48449 m .55834 .49233 L .54239 .47679 L 1 g
F
P
p
.002 w
.55751 .49146 m .55834 .49233 L p
.55033 .48449 L 1 g
F P
s
P
p
.002 w
.55591 .50057 m .55999 .49643 L p
.5627 .50221 L 1 g
F P
s
P
p
.002 w
.56605 .50933 m .56713 .51061 L p
.56246 .50169 L 1 g
F P
s
P
p
.002 w
.59043 .5089 m .57394 .52564 L .57329 .52475 L p
1 g
F P
s
P
p
.002 w
.55591 .50057 m .54522 .5061 L .53607 .47385 L p
1 g
F P
s
P
p
.002 w
.53677 .47417 m .55591 .50057 L p
.53607 .47385 L 1 g
F P
s
P
p
.002 w
.54522 .5061 m .53344 .50797 L .53572 .47368 L p
1 g
F P
s
P
p
.002 w
.53607 .47385 m .54522 .5061 L p
.53572 .47368 L 1 g
F P
s
P
p
.002 w
.53344 .50797 m .52182 .50598 L .53546 .47356 L p
1 g
F P
s
P
p
.52214 .46667 m .53871 .47509 L .53572 .47368 L 1 g
F
P
p
.52214 .46667 m .53572 .47368 L .53546 .47356 L 1 g
F
P
p
.002 w
.53546 .47356 m .52182 .50598 L p
.53522 .47344 L 1 g
F P
s
P
p
.53537 .47352 m .53546 .47356 L .53538 .47352 L 1 g
F
P
p
.52214 .46667 m .53546 .47356 L .53537 .47352 L 1 g
F
P
p
.002 w
.52182 .50598 m .51161 .50032 L .53522 .47344 L p
1 g
F P
s
P
p
.002 w
.53572 .47368 m .53344 .50797 L p
.53546 .47356 L 1 g
F P
s
P
p
.50057 .46409 m .52246 .4672 L .532 .47187 L 1 g
F
P
p
.002 w
.49914 .46884 m .50057 .46409 L p
.532 .47187 L 1 g
F P
s
P
p
.002 w
.53338 .47255 m .49914 .46884 L p
.532 .47187 L 1 g
F P
s
P
p
.002 w
.51161 .50032 m .50392 .49158 L .53493 .47331 L p
1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53539 .47353 L 1 g
F P
s
P
p
.002 w
.53493 .47331 m .53578 .47281 L .53522 .47344 L p
1 g
F P
s
P
p
.002 w
.53522 .47344 m .51161 .50032 L p
.53493 .47331 L 1 g
F P
s
P
p
.002 w
.50392 .49158 m .4996 .48069 L .53448 .47309 L p
1 g
F P
s
P
p
.002 w
.53448 .47309 m .53578 .47281 L .53493 .47331 L p
1 g
F P
s
P
p
.002 w
.53493 .47331 m .50392 .49158 L p
.53448 .47309 L 1 g
F P
s
P
p
.53493 .47331 m .53563 .47365 L .53449 .47309 L 1 g
F
P
p
.53539 .47353 m .53544 .47355 L .53493 .47331 L 1 g
F
P
p
.53544 .47355 m .53563 .47365 L .53493 .47331 L 1 g
F
P
p
.002 w
.4996 .48069 m .49914 .46884 L .53338 .47255 L p
1 g
F P
s
P
p
.002 w
.53338 .47255 m .53578 .47281 L .53448 .47309 L p
1 g
F P
s
P
p
.002 w
.53448 .47309 m .4996 .48069 L p
.53338 .47255 L 1 g
F P
s
P
p
.53539 .47353 m .53474 .47322 L .52246 .4672 L 1 g
F
P
p
.53474 .47322 m .53449 .47309 L .53338 .47255 L 1 g
F
P
p
.53474 .47322 m .53338 .47255 L .52246 .4672 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52246 .4672 L p
1 g
F P
s
P
p
.53563 .47365 m .54302 .47747 L .52246 .4672 L 1 g
F
P
p
.002 w
.53578 .47281 m .53338 .47255 L p
.532 .47187 L 1 g
F P
s
P
p
.002 w
.53522 .47344 m .53578 .47281 L .53546 .47356 L p
1 g
F P
s
P
p
.002 w
.53546 .47356 m .53578 .47281 L .53572 .47368 L p
1 g
F P
s
P
p
.53538 .47352 m .53572 .47368 L .53541 .47354 L 1 g
F
P
p
.53541 .47354 m .54268 .47711 L .53563 .47365 L 1 g
F
P
p
.53871 .47509 m .54268 .47711 L .53541 .47354 L 1 g
F
P
p
.002 w
.53572 .47368 m .53578 .47281 L .53607 .47385 L p
1 g
F P
s
P
p
.002 w
.53677 .47417 m .53578 .47281 L .54018 .47576 L p
1 g
F P
s
P
p
.002 w
.54239 .47679 m .54241 .47681 L p
.54208 .47665 L 1 g
F P
s
P
p
.002 w
.54241 .47681 m .54268 .47711 L p
.5385 .47499 L 1 g
F P
s
P
p
.002 w
.53607 .47385 m .53578 .47281 L .53677 .47417 L p
1 g
F P
s
P
p
.002 w
.52434 .46747 m .53578 .47281 L p
.532 .47187 L 1 g
F P
s
P
p
.52246 .4672 m .52434 .46747 L .532 .47187 L 1 g
F
P
p
.002 w
.54268 .47711 m .54302 .47747 L p
.53563 .47365 L 1 g
F P
s
P
p
.50987 .46541 m .51824 .46711 L .50057 .46409 L 1 g
F
P
p
.50987 .46541 m .50057 .46409 L .5 .46399 L 1 g
F
P
p
.002 w
.52282 .46778 m .51824 .46711 L p
.5 .4634 L 1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.50057 .46409 m .50261 .45732 L .52434 .46747 L p
1 g
F P
s
P
p
.002 w
.50063 .4639 m .50057 .46409 L p
.5 .46399 L 1 g
F P
s
P
p
.002 w
.50057 .46409 m .49914 .46884 L p
.5 .46399 L 1 g
F P
s
P
p
.002 w
.51824 .46711 m .5 .46442 L .5 .46399 L p
1 g
F P
s
P
p
.48968 .46547 m .49045 .46539 L .48252 .46649 L 1 g
F
P
p
.48968 .46547 m .48252 .46649 L .47755 .46719 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46406 L p
1 g
F P
s
P
p
.002 w
.5 .46406 m .5 .46442 L p
.49045 .46539 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46406 L .49045 .46539 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47726 .46766 L p
1 g
F P
s
P
p
.002 w
.47726 .46766 m .47718 .46778 L p
.47368 .46932 L 1 g
F P
s
P
p
.45826 .47608 m .47726 .46766 L .47368 .46932 L 1 g
F
P
p
.44994 .48422 m .44455 .48946 L .4426 .49134 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.43517 .5067 m .4426 .49134 L .46352 .487 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45733 .47709 L p
1 g
F P
s
P
p
.44339 .4905 m .45733 .47709 L .45189 .48236 L 1 g
F
P
p
.002 w
.44344 .4896 m .44455 .48946 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.44455 .48946 m .46352 .487 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.45733 .47709 m .45698 .47747 L p
.45189 .48236 L 1 g
F P
s
P
p
.002 w
.44455 .48946 m .42893 .49148 L p
.44099 .48445 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44099 .48445 m .46285 .4717 L .45766 .47673 L 1 g
F
P
p
.44099 .48445 m .45766 .47673 L .44455 .48946 L 1 g
F
P
p
.002 w
.4625 .46367 m .47977 .46611 L p
.47755 .46719 L 1 g
F P
s
P
p
.46845 .47161 m .46297 .47428 L .45766 .47673 L 1 g
F
P
p
.002 w
.46297 .47428 m .46275 .46925 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.46275 .46925 m .4625 .46367 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.50261 .45732 m .50063 .4639 L p
.4625 .46367 L 1 g
F P
s
P
p
.002 w
.48252 .46649 m .4625 .46367 L p
.50063 .4639 L 1 g
F P
s
P
p
.002 w
.47977 .46611 m .48252 .46649 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.48252 .46649 m .49914 .46884 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47755 .46719 L p
1 g
F P
s
P
p
.49045 .46539 m .5 .46442 L .47755 .46719 L 1 g
F
P
p
.46845 .47161 m .47368 .46932 L .46297 .47428 L 1 g
F
P
p
.002 w
.46352 .487 m .46297 .47428 L p
.49914 .46884 L 1 g
F P
s
P
p
.002 w
.46285 .4717 m .46297 .47428 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.46297 .47428 m .46352 .487 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45766 .47673 L p
1 g
F P
s
P
p
.47368 .46932 m .47718 .46778 L .45766 .47673 L 1 g
F
P
p
.44994 .48422 m .45189 .48236 L .44455 .48946 L 1 g
F
P
p
.002 w
.4625 .46367 m .46285 .4717 L p
.42893 .49148 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4426 .49134 L p
1 g
F P
s
P
p
.45189 .48236 m .45698 .47747 L .4426 .49134 L 1 g
F
P
p
.43816 .50052 m .43998 .49626 L .43517 .5067 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44164 .52247 m .43517 .5067 L p
.46352 .487 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43397 .50931 L p
1 g
F P
s
P
p
.43998 .49626 m .44166 .49233 L .43397 .50931 L 1 g
F
P
p
.43318 .51926 m .43295 .51272 L .43264 .52601 L 1 g
F
P
p
.002 w
.42893 .49148 m .43434 .50466 L p
.41355 .53351 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43258 .52862 L p
1 g
F P
s
P
p
.43295 .51272 m .43287 .51061 L .43258 .52862 L 1 g
F
P
p
.002 w
.43258 .52862 m .43146 .53025 L p
.43642 .54006 L 1 g
F P
s
P
p
.4419 .55131 m .43866 .54676 L .44164 .52247 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43866 .54676 L p
1 g
F P
s
P
p
.43642 .54006 m .43146 .53025 L .43866 .54676 L 1 g
F
P
p
.46872 .57265 m .45082 .563 L .46141 .56973 L 1 g
F
P
p
.46824 .57407 m .45082 .563 L .46385 .54712 L 1 g
F
P
p
.002 w
.44715 .56066 m .44804 .55994 L p
.45082 .563 L 1 g
F P
s
P
p
.44501 .55569 m .44804 .55994 L .45082 .563 L 1 g
F
P
p
.002 w
.44804 .55994 m .46385 .54712 L p
.45082 .563 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45061 .56357 L p
1 g
F P
s
P
p
.002 w
.45061 .56357 m .45082 .563 L p
.44848 .56057 L 1 g
F P
s
P
p
.44848 .56057 m .43743 .5491 L .45061 .56357 L 1 g
F
P
p
.44501 .55569 m .4409 .55211 L .44804 .55994 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44164 .52247 m .46385 .54712 L .44804 .55994 L p
1 g
F P
s
P
p
.4419 .55131 m .44164 .52247 L .44804 .55994 L 1 g
F
P
p
.4409 .55211 m .43743 .5491 L .45082 .563 L 1 g
F
P
p
.002 w
.45082 .563 m .45002 .56518 L p
.46141 .56973 L 1 g
F P
s
P
p
.476 .57681 m .46824 .57407 L .46385 .54712 L 1 g
F
P
p
.002 w
.44304 .56535 m .44203 .56481 L p
.476 .57681 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46839 .57417 L p
1 g
F P
s
P
p
.46141 .56973 m .45002 .56518 L .46839 .57417 L 1 g
F
P
p
.002 w
.48192 .58051 m .48277 .57917 L p
.48676 .58044 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48901 .58133 L p
1 g
F P
s
P
p
.52115 .59145 m .48277 .57917 L .51537 .58559 L 1 g
F
P
p
.002 w
.48901 .58133 m .48908 .58041 L p
.48383 .57953 L 1 g
F P
s
P
p
.48383 .57953 m .4678 .57686 L .48901 .58133 L 1 g
F
P
p
.47872 .57776 m .47341 .57732 L .48277 .57917 L 1 g
F
P
p
.47872 .57776 m .48277 .57917 L .48908 .58041 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46385 .54712 m .49302 .5629 L .48277 .57917 L p
1 g
F P
s
P
p
.476 .57681 m .46385 .54712 L .48277 .57917 L 1 g
F
P
p
.002 w
.48277 .57917 m .49302 .5629 L p
.51012 .58026 L 1 g
F P
s
P
p
.51537 .58559 m .5 .58256 L .51012 .58026 L 1 g
F
P
p
.5 .58256 m .48277 .57917 L .51012 .58026 L 1 g
F
P
p
.002 w
.52367 .57929 m .52413 .57707 L p
.53165 .57433 L 1 g
F P
s
P
p
.56331 .58443 m .52367 .57929 L .53165 .57433 L 1 g
F
P
p
.53616 .57269 m .53165 .57433 L .53506 .57221 L 1 g
F
P
p
.56331 .58443 m .53165 .57433 L .53616 .57269 L 1 g
F
P
p
.53128 .57265 m .52148 .57768 L .52413 .57707 L 1 g
F
P
p
.002 w
.53186 .57532 m .53165 .57433 L p
.52413 .57707 L 1 g
F P
s
P
p
.002 w
.53165 .57433 m .53128 .57265 L p
.52413 .57707 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53186 .57532 L p
1 g
F P
s
P
p
.52148 .57768 m .51111 .583 L .53186 .57532 L 1 g
F
P
p
.002 w
.48908 .58041 m .48889 .583 L p
.50288 .5802 L 1 g
F P
s
P
p
.47341 .57732 m .4678 .57686 L .48908 .58041 L 1 g
F
P
p
.52148 .57768 m .51103 .58185 L .51903 .57894 L 1 g
F
P
p
.53128 .57265 m .51896 .57825 L .52148 .57768 L 1 g
F
P
p
.51896 .57825 m .51103 .58185 L .52148 .57768 L 1 g
F
P
p
.51012 .58026 m .49302 .5629 L .52413 .57707 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58008 L p
1 g
F P
s
P
p
.50288 .5802 m .48889 .583 L .5109 .58008 L 1 g
F
P
p
.002 w
.49302 .5629 m .52596 .56828 L .52413 .57707 L p
1 g
F P
s
P
p
.002 w
.5109 .58008 m .51103 .58185 L p
.51896 .57825 L 1 g
F P
s
P
p
.002 w
.51103 .58185 m .51111 .583 L p
.51903 .57894 L 1 g
F P
s
P
p
.53506 .57221 m .53165 .57433 L .52596 .56828 L 1 g
F
P
p
.002 w
.52413 .57707 m .52596 .56828 L p
.53165 .57433 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54931 .56335 L p
1 g
F P
s
P
p
.002 w
.54931 .56335 m .54924 .56316 L p
.54794 .5642 L 1 g
F P
s
P
p
.54794 .5642 m .5322 .57686 L .54931 .56335 L 1 g
F
P
p
.53815 .57119 m .5322 .57686 L .54924 .56316 L 1 g
F
P
p
.55392 .55732 m .54931 .56335 L .55201 .56058 L 1 g
F
P
p
.55024 .56191 m .54931 .56335 L .55392 .55732 L 1 g
F
P
p
.55436 .55725 m .55201 .56058 L .55318 .55939 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.53012 .54016 m .55311 .53644 L .55703 .55345 L p
1 g
F P
s
P
p
.55323 .55818 m .53012 .54016 L .55703 .55345 L 1 g
F
P
p
.002 w
.54924 .56316 m .54931 .56335 L p
.55024 .56191 L 1 g
F P
s
P
p
.002 w
.54931 .56335 m .54998 .56518 L p
.55318 .55939 L 1 g
F P
s
P
p
.002 w
.53165 .57433 m .5322 .57686 L p
.54087 .5686 L 1 g
F P
s
P
p
.002 w
.52596 .56828 m .54693 .56483 L p
.53506 .57221 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.36631 .44323 m .36921 .49459 L .34601 .49323 L p
1 g
F P
s
P
p
.002 w
.34601 .49323 m .34258 .43569 L .36631 .44323 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.61309 .52302 m .62821 .49281 L .65091 .49564 L p
1 g
F P
s
P
p
.002 w
.6571 .45353 m .65091 .49564 L .62821 .49281 L p
1 g
F P
s
P
p
.002 w
.6494 .41195 m .62837 .37532 L .64221 .3546 L p
1 g
F P
s
P
p
.002 w
.60412 .32184 m .64221 .3546 L .62837 .37532 L p
1 g
F P
s
P
p
.002 w
.60412 .32184 m .55649 .30353 L .55561 .27929 L p
1 g
F P
s
P
p
.002 w
.49736 .27749 m .55561 .27929 L .55649 .30353 L p
1 g
F P
s
P
p
.002 w
.62821 .49281 m .63299 .45965 L .6571 .45353 L p
1 g
F P
s
P
p
.002 w
.6494 .41195 m .6571 .45353 L .63299 .45965 L p
1 g
F P
s
P
p
.002 w
.38079 .39289 m .36631 .44323 L .34258 .43569 L p
1 g
F P
s
P
p
.002 w
.34258 .43569 m .35868 .37923 L .38079 .39289 L p
1 g
F P
s
P
p
.002 w
.39713 .49403 m .41355 .53351 L .38881 .54117 L p
1 g
F P
s
P
p
.002 w
.38881 .54117 m .36921 .49459 L .39713 .49403 L p
1 g
F P
s
P
p
.002 w
.55649 .30353 m .50451 .30207 L .49736 .27749 L p
1 g
F P
s
P
p
.002 w
.44084 .29517 m .49736 .27749 L .50451 .30207 L p
1 g
F P
s
P
p
.002 w
.63299 .45965 m .62681 .427 L .6494 .41195 L p
1 g
F P
s
P
p
.002 w
.62837 .37532 m .6494 .41195 L .62681 .427 L p
1 g
F P
s
P
p
.002 w
.62837 .37532 m .59601 .34772 L .60412 .32184 L p
1 g
F P
s
P
p
.002 w
.55649 .30353 m .60412 .32184 L .59601 .34772 L p
1 g
F P
s
P
p
.002 w
.41121 .34942 m .38079 .39289 L .35868 .37923 L p
1 g
F P
s
P
p
.002 w
.35868 .37923 m .39272 .33046 L .41121 .34942 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.50451 .30207 m .45412 .31793 L .44084 .29517 L p
1 g
F P
s
P
p
.002 w
.39272 .33046 m .44084 .29517 L .45412 .31793 L p
1 g
F P
s
P
p
.002 w
.61309 .52302 m .58926 .54718 L .57394 .52564 L p
1 g
F P
s
P
p
.002 w
.45412 .31793 m .41121 .34942 L .39272 .33046 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.62821 .49281 m .61309 .52302 L .59043 .5089 L p
1 g
F P
s
P
p
.002 w
.57394 .52564 m .59043 .5089 L .61309 .52302 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39485 .4506 m .39713 .49403 L .36921 .49459 L p
1 g
F P
s
P
p
.002 w
.36921 .49459 m .36631 .44323 L .39485 .4506 L p
1 g
F P
s
P
p
.002 w
.59043 .5089 m .60085 .48798 L .62821 .49281 L p
1 g
F P
s
P
p
.002 w
.63299 .45965 m .62821 .49281 L .60085 .48798 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.50738 .53637 m .53012 .54016 L .52596 .56828 L p
1 g
F P
s
P
p
.002 w
.52596 .56828 m .49302 .5629 L .50738 .53637 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62681 .427 m .61018 .39834 L .62837 .37532 L p
1 g
F P
s
P
p
.002 w
.59601 .34772 m .62837 .37532 L .61018 .39834 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.59601 .34772 m .55566 .3324 L .55649 .30353 L p
1 g
F P
s
P
p
.002 w
.50451 .30207 m .55649 .30353 L .55566 .3324 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60085 .48798 m .60408 .46506 L .63299 .45965 L p
1 g
F P
s
P
p
.002 w
.62681 .427 m .63299 .45965 L .60408 .46506 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.41355 .53351 m .39713 .49403 L .42893 .49148 L p
1 g
F P
s
P
p
.002 w
.4072 .40809 m .39485 .4506 L .36631 .44323 L p
1 g
F P
s
P
p
.002 w
.36631 .44323 m .38079 .39289 L .4072 .40809 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.48732 .52539 m .50738 .53637 L .49302 .5629 L p
1 g
F P
s
P
p
.002 w
.49302 .5629 m .46385 .54712 L .48732 .52539 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.55566 .3324 m .51173 .33132 L .50451 .30207 L p
1 g
F P
s
P
p
.002 w
.45412 .31793 m .50451 .30207 L .51173 .33132 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.60408 .46506 m .59972 .44255 L .62681 .427 L p
1 g
F P
s
P
p
.002 w
.61018 .39834 m .62681 .427 L .59972 .44255 L p
1 g
F P
s
P
p
.002 w
.61018 .39834 m .58471 .37684 L .59601 .34772 L p
1 g
F P
s
P
p
.002 w
.55566 .3324 m .59601 .34772 L .58471 .37684 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.43294 .3714 m .4072 .40809 L .38079 .39289 L p
1 g
F P
s
P
p
.002 w
.38079 .39289 m .41121 .34942 L .43294 .3714 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.47213 .50834 m .48732 .52539 L .46385 .54712 L p
1 g
F P
s
P
p
.002 w
.46385 .54712 m .44164 .52247 L .47213 .50834 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.51173 .33132 m .46918 .34479 L .45412 .31793 L p
1 g
F P
s
P
p
.002 w
.41121 .34942 m .45412 .31793 L .46918 .34479 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42729 .45751 m .42893 .49148 L .39713 .49403 L p
1 g
F P
s
P
p
.002 w
.39713 .49403 m .39485 .4506 L .42729 .45751 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.46918 .34479 m .43294 .3714 L .41121 .34942 L p
1 g
F P
s
P
p
.002 w
.60085 .48798 m .59043 .5089 L .56436 .49198 L p
1 g
F P
s
P
p
.002 w
.53344 .50797 m .54522 .5061 L .55311 .53644 L p
1 g
F P
s
P
p
.002 w
.55311 .53644 m .53012 .54016 L .53344 .50797 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.56436 .49198 m .56968 .48125 L .60085 .48798 L p
1 g
F P
s
P
p
.002 w
.60408 .46506 m .60085 .48798 L .56968 .48125 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59972 .44255 m .58816 .42287 L .61018 .39834 L p
1 g
F P
s
P
p
.002 w
.58471 .37684 m .61018 .39834 L .58816 .42287 L p
1 g
F P
s
P
p
.002 w
.52182 .50598 m .53344 .50797 L .53012 .54016 L p
1 g
F P
s
P
p
.002 w
.53012 .54016 m .50738 .53637 L .52182 .50598 L p
1 g
F P
s
P
p
.002 w
.58471 .37684 m .55308 .36499 L .55566 .3324 L p
1 g
F P
s
P
p
.002 w
.51173 .33132 m .55566 .3324 L .55308 .36499 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.56968 .48125 m .57129 .46951 L .60408 .46506 L p
1 g
F P
s
P
p
.002 w
.59972 .44255 m .60408 .46506 L .57129 .46951 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.46352 .487 m .47213 .50834 L .44164 .52247 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.43705 .42431 m .42729 .45751 L .39485 .4506 L p
1 g
F P
s
P
p
.002 w
.39485 .4506 m .4072 .40809 L .43705 .42431 L p
1 g
F P
s
P
p
.002 w
.51161 .50032 m .52182 .50598 L .50738 .53637 L p
1 g
F P
s
P
p
.002 w
.50738 .53637 m .48732 .52539 L .51161 .50032 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.57129 .46951 m .56901 .45802 L .59972 .44255 L p
1 g
F P
s
P
p
.002 w
.58816 .42287 m .59972 .44255 L .56901 .45802 L p
1 g
F P
s
P
p
.002 w
.58816 .42287 m .57057 .40818 L .58471 .37684 L p
1 g
F P
s
P
p
.002 w
.55308 .36499 m .58471 .37684 L .57057 .40818 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55308 .36499 m .51873 .36427 L .51173 .33132 L p
1 g
F P
s
P
p
.002 w
.46918 .34479 m .51173 .33132 L .51873 .36427 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50392 .49158 m .51161 .50032 L .48732 .52539 L p
1 g
F P
s
P
p
.002 w
.48732 .52539 m .47213 .50834 L .50392 .49158 L p
1 g
F P
s
P
p
.002 w
.4572 .39567 m .43705 .42431 L .4072 .40809 L p
1 g
F P
s
P
p
.002 w
.4072 .40809 m .43294 .3714 L .4572 .39567 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.42893 .49148 m .42729 .45751 L .4625 .46367 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.51873 .36427 m .48551 .37488 L .46918 .34479 L p
1 g
F P
s
P
p
.002 w
.43294 .3714 m .46918 .34479 L .48551 .37488 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.48551 .37488 m .4572 .39567 L .43294 .3714 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56901 .45802 m .56305 .44801 L .58816 .42287 L p
1 g
F P
s
P
p
.002 w
.57057 .40818 m .58816 .42287 L .56305 .44801 L p
1 g
F P
s
P
p
.002 w
.57129 .46951 m .56968 .48125 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57057 .40818 m .5488 .40016 L .55308 .36499 L p
1 g
F P
s
P
p
.002 w
.51873 .36427 m .55308 .36499 L .5488 .40016 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.4996 .48069 m .50392 .49158 L .47213 .50834 L p
1 g
F P
s
P
p
.002 w
.47213 .50834 m .46352 .487 L .4996 .48069 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56901 .45802 m .57129 .46951 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.46927 .44093 m .4625 .46367 L .42729 .45751 L p
1 g
F P
s
P
p
.002 w
.42729 .45751 m .43705 .42431 L .46927 .44093 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56305 .44801 m .56901 .45802 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.56305 .44801 m .55405 .44059 L .57057 .40818 L p
1 g
F P
s
P
p
.002 w
.5488 .40016 m .57057 .40818 L .55405 .44059 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.5488 .40016 m .52524 .39976 L .51873 .36427 L p
1 g
F P
s
P
p
.002 w
.48551 .37488 m .51873 .36427 L .52524 .39976 L p
1 g
F P
s
P
p
.002 w
.49914 .46884 m .4996 .48069 L .46352 .487 L p
1 g
F P
s
P
p
.002 w
.55405 .44059 m .56305 .44801 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.48311 .42134 m .46927 .44093 L .43705 .42431 L p
1 g
F P
s
P
p
.002 w
.43705 .42431 m .4572 .39567 L .48311 .42134 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52524 .39976 m .50249 .40708 L .48551 .37488 L p
1 g
F P
s
P
p
.002 w
.4572 .39567 m .48551 .37488 L .50249 .40708 L p
1 g
F P
s
P
p
.002 w
.55405 .44059 m .54296 .43657 L .5488 .40016 L p
1 g
F P
s
P
p
.002 w
.52524 .39976 m .5488 .40016 L .54296 .43657 L p
1 g
F P
s
P
p
.002 w
.54296 .43657 m .55405 .44059 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.531 .43642 m .54296 .43657 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.51947 .44016 m .531 .43642 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.50965 .44739 m .51947 .44016 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5125 .44529 L
s
P
p
.002 w
.50261 .45732 m .50965 .44739 L .53578 .47281 L closepath p
1 g
F P
s
P
p
.002 w
.50249 .40708 m .48311 .42134 L .4572 .39567 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.4625 .46367 m .46927 .44093 L .50261 .45732 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.54296 .43657 m .531 .43642 L .52524 .39976 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.50249 .40708 m .52524 .39976 L .531 .43642 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50965 .44739 m .50261 .45732 L .46927 .44093 L p
1 g
F P
s
P
p
.002 w
.46927 .44093 m .48311 .42134 L .50965 .44739 L p
1 g
F P
s
P
p
.002 w
.531 .43642 m .51947 .44016 L .50249 .40708 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.48311 .42134 m .50249 .40708 L .51947 .44016 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.004 w
.53578 .47281 m
.53693 .47417 L
s
P
p
.002 w
.51947 .44016 m .50965 .44739 L .48311 .42134 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.53693 .47417 m
.55789 .49896 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .65072 .68287 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .55789 .49896 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.309302)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.309302)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50793 .47696 m .53533 .45503 L .51462 .43571 L p
1 g
F P
s
P
p
.002 w
.51462 .43571 m .49345 .45264 L .50793 .47696 L p
1 g
F P
s
P
p
.002 w
.52975 .41332 m .51462 .43571 L .53533 .45503 L p
1 g
F P
s
P
p
.002 w
.49345 .45264 m .51462 .43571 L .49362 .41633 L p
1 g
F P
s
P
p
.002 w
.51462 .43571 m .52975 .41332 L .50391 .40104 L p
1 g
F P
s
P
p
.002 w
.50391 .40104 m .49362 .41633 L .51462 .43571 L p
1 g
F P
s
P
p
.002 w
.49362 .41633 m .47917 .42787 L .49345 .45264 L p
1 g
F P
s
P
p
.002 w
.47917 .42787 m .49362 .41633 L .47271 .39723 L p
1 g
F P
s
P
p
.002 w
.49362 .41633 m .50391 .40104 L .47793 .38945 L p
1 g
F P
s
P
p
.002 w
.47793 .38945 m .47271 .39723 L .49362 .41633 L p
1 g
F P
s
P
p
.002 w
.47271 .39723 m .46536 .40309 L .47917 .42787 L p
1 g
F P
s
P
p
.002 w
.46838 .46236 m .49345 .45264 L .47917 .42787 L p
1 g
F P
s
P
p
.002 w
.47917 .42787 m .46206 .43445 L .46838 .46236 L p
1 g
F P
s
P
p
.002 w
.46206 .43445 m .47917 .42787 L .46536 .40309 L p
1 g
F P
s
P
p
.002 w
.47549 .48965 m .50793 .47696 L .49345 .45264 L p
1 g
F P
s
P
p
.002 w
.49345 .45264 m .46838 .46236 L .47549 .48965 L p
1 g
F P
s
P
p
.002 w
.50896 .38357 m .50391 .40104 L .52975 .41332 L p
1 g
F P
s
P
p
.002 w
.50391 .40104 m .50896 .38357 L .48046 .38057 L p
1 g
F P
s
P
p
.002 w
.48046 .38057 m .47793 .38945 L .50391 .40104 L p
1 g
F P
s
P
p
.002 w
.53533 .45503 m .55498 .42607 L .52975 .41332 L p
1 g
F P
s
P
p
.002 w
.53727 .38772 m .52975 .41332 L .55498 .42607 L p
1 g
F P
s
P
p
.002 w
.52975 .41332 m .53727 .38772 L .50896 .38357 L p
1 g
F P
s
P
p
.002 w
.44194 .46383 m .46838 .46236 L .46206 .43445 L p
1 g
F P
s
P
p
.002 w
.46206 .43445 m .44405 .43535 L .44194 .46383 L p
1 g
F P
s
P
p
.002 w
.44405 .43535 m .46206 .43445 L .45666 .40641 L p
1 g
F P
s
P
p
.002 w
.46536 .40309 m .45666 .40641 L .46206 .43445 L p
1 g
F P
s
P
p
.002 w
.52236 .50038 m .55537 .47393 L .53533 .45503 L p
1 g
F P
s
P
p
.002 w
.53533 .45503 m .50793 .47696 L .52236 .50038 L p
1 g
F P
s
P
p
.002 w
.55498 .42607 m .53533 .45503 L .55537 .47393 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .46536 .40309 L .47271 .39723 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .47271 .39723 L .47793 .38945 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .45666 .40641 L .46536 .40309 L closepath p
1 g
F P
s
P
p
.002 w
.44123 .49174 m .47549 .48965 L .46838 .46236 L p
1 g
F P
s
P
p
.002 w
.46838 .46236 m .44194 .46383 L .44123 .49174 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .47793 .38945 L .48046 .38057 L closepath p
1 g
F P
s
P
p
.002 w
.48329 .51581 m .52236 .50038 L .50793 .47696 L p
1 g
F P
s
P
p
.002 w
.50793 .47696 m .47549 .48965 L .48329 .51581 L p
1 g
F P
s
P
p
.002 w
.5082 .36574 m .50896 .38357 L .53727 .38772 L p
1 g
F P
s
P
p
.002 w
.50896 .38357 m .5082 .36574 L .48001 .37153 L p
1 g
F P
s
P
p
.002 w
.48001 .37153 m .48046 .38057 L .50896 .38357 L p
1 g
F P
s
P
p
.002 w
.45666 .40641 m .44752 .40682 L .44405 .43535 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .44752 .40682 L .45666 .40641 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .48046 .38057 L .48001 .37153 L closepath p
1 g
F P
s
P
p
.002 w
.55537 .47393 m .57913 .43907 L .55498 .42607 L p
1 g
F P
s
P
p
.002 w
.56486 .39294 m .55498 .42607 L .57913 .43907 L p
1 g
F P
s
P
p
.002 w
.55498 .42607 m .56486 .39294 L .53727 .38772 L p
1 g
F P
s
P
p
.002 w
.41687 .45678 m .44194 .46383 L .44405 .43535 L p
1 g
F P
s
P
p
.002 w
.44405 .43535 m .42704 .43044 L .41687 .45678 L p
1 g
F P
s
P
p
.002 w
.42704 .43044 m .44405 .43535 L .44752 .40682 L p
1 g
F P
s
P
p
.002 w
.53631 .3615 m .53727 .38772 L .56486 .39294 L p
1 g
F P
s
P
p
.002 w
.53727 .38772 m .53631 .3615 L .5082 .36574 L p
1 g
F P
s
P
p
.002 w
.44752 .40682 m .43892 .40427 L .42704 .43044 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .43892 .40427 L .44752 .40682 L closepath p
1 g
F P
s
P
p
.002 w
.47662 .3633 m .48001 .37153 L .5082 .36574 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .48001 .37153 L .47662 .3633 L closepath p
1 g
F P
s
P
p
.002 w
.44196 .51853 m .48329 .51581 L .47549 .48965 L p
1 g
F P
s
P
p
.002 w
.47549 .48965 m .44123 .49174 L .44196 .51853 L p
1 g
F P
s
P
p
.002 w
.50163 .34943 m .5082 .36574 L .53631 .3615 L p
1 g
F P
s
P
p
.002 w
.5082 .36574 m .50163 .34943 L .47662 .3633 L p
1 g
F P
s
P
p
.002 w
.41285 .42015 m .42704 .43044 L .43892 .40427 L p
1 g
F P
s
P
p
.002 w
.43892 .40427 m .43179 .39901 L .41285 .42015 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .43179 .39901 L .43892 .40427 L closepath p
1 g
F P
s
P
p
.002 w
.40862 .4828 m .44123 .49174 L .44194 .46383 L p
1 g
F P
s
P
p
.002 w
.44194 .46383 m .41687 .45678 L .40862 .4828 L p
1 g
F P
s
P
p
.002 w
.53647 .52246 m .57437 .49206 L .55537 .47393 L p
1 g
F P
s
P
p
.002 w
.55537 .47393 m .52236 .50038 L .53647 .52246 L p
1 g
F P
s
P
p
.002 w
.57913 .43907 m .55537 .47393 L .57437 .49206 L p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .42973 .36504 L .4258 .37362 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .4258 .37362 L .42483 .38281 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .42483 .38281 L .42691 .39159 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .42691 .39159 L .43179 .39901 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .47662 .3633 L .47064 .35678 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .47064 .35678 L .46269 .35268 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .46269 .35268 L .45364 .35148 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .45364 .35148 L .44446 .35332 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .44446 .35332 L .43619 .35801 L closepath p
1 g
F P
s
P
p
.002 w
.45227 .37876 m .43619 .35801 L .42973 .36504 L closepath p
1 g
F P
s
P
p
.002 w
.47064 .35678 m .47662 .3633 L .50163 .34943 L p
1 g
F P
s
P
p
.002 w
.39585 .44179 m .41687 .45678 L .42704 .43044 L p
1 g
F P
s
P
p
.002 w
.42704 .43044 m .41285 .42015 L .39585 .44179 L p
1 g
F P
s
P
p
.002 w
.49164 .54031 m .53647 .52246 L .52236 .50038 L p
1 g
F P
s
P
p
.002 w
.52236 .50038 m .48329 .51581 L .49164 .54031 L p
1 g
F P
s
P
p
.002 w
.57913 .43907 m .59122 .39914 L .56486 .39294 L p
1 g
F P
s
P
p
.002 w
.56383 .35892 m .56486 .39294 L .59122 .39914 L p
1 g
F P
s
P
p
.002 w
.56486 .39294 m .56383 .35892 L .53631 .3615 L p
1 g
F P
s
P
p
.002 w
.40307 .40552 m .41285 .42015 L .43179 .39901 L p
1 g
F P
s
P
p
.002 w
.43179 .39901 m .42691 .39159 L .40307 .40552 L p
1 g
F P
s
P
p
.002 w
.52682 .33742 m .53631 .3615 L .56383 .35892 L p
1 g
F P
s
P
p
.002 w
.53631 .3615 m .52682 .33742 L .50163 .34943 L p
1 g
F P
s
P
p
.002 w
.50163 .34943 m .48989 .33641 L .47064 .35678 L p
1 g
F P
s
P
p
.002 w
.46269 .35268 m .47064 .35678 L .48989 .33641 L p
1 g
F P
s
P
p
.002 w
.57437 .49206 m .60173 .45207 L .57913 .43907 L p
1 g
F P
s
P
p
.002 w
.59122 .39914 m .57913 .43907 L .60173 .45207 L p
1 g
F P
s
P
p
.002 w
.48989 .33641 m .50163 .34943 L .52682 .33742 L p
1 g
F P
s
P
p
.002 w
.39882 .38811 m .40307 .40552 L .42691 .39159 L p
1 g
F P
s
P
p
.002 w
.42691 .39159 m .42483 .38281 L .39882 .38811 L p
1 g
F P
s
P
p
.002 w
.40251 .508 m .44196 .51853 L .44123 .49174 L p
1 g
F P
s
P
p
.002 w
.44123 .49174 m .40862 .4828 L .40251 .508 L p
1 g
F P
s
P
p
.002 w
.48989 .33641 m .47417 .32817 L .46269 .35268 L p
1 g
F P
s
P
p
.002 w
.45364 .35148 m .46269 .35268 L .47417 .32817 L p
1 g
F P
s
P
p
.002 w
.44415 .54367 m .49164 .54031 L .48329 .51581 L p
1 g
F P
s
P
p
.002 w
.48329 .51581 m .44196 .51853 L .44415 .54367 L p
1 g
F P
s
P
p
.002 w
.38115 .46351 m .40862 .4828 L .41687 .45678 L p
1 g
F P
s
P
p
.002 w
.41687 .45678 m .39585 .44179 L .38115 .46351 L p
1 g
F P
s
P
p
.002 w
.38124 .4203 m .39585 .44179 L .41285 .42015 L p
1 g
F P
s
P
p
.002 w
.41285 .42015 m .40307 .40552 L .38124 .4203 L p
1 g
F P
s
P
p
.002 w
.40067 .3698 m .39882 .38811 L .42483 .38281 L p
1 g
F P
s
P
p
.002 w
.42483 .38281 m .4258 .37362 L .40067 .3698 L p
1 g
F P
s
P
p
.002 w
.47417 .32817 m .45617 .32567 L .45364 .35148 L p
1 g
F P
s
P
p
.002 w
.44446 .35332 m .45364 .35148 L .45617 .32567 L p
1 g
F P
s
P
p
.002 w
.40846 .35265 m .40067 .3698 L .4258 .37362 L p
1 g
F P
s
P
p
.002 w
.4258 .37362 m .42973 .36504 L .40846 .35265 L p
1 g
F P
s
P
p
.002 w
.52682 .33742 m .50965 .31809 L .48989 .33641 L p
1 g
F P
s
P
p
.002 w
.47417 .32817 m .48989 .33641 L .50965 .31809 L p
1 g
F P
s
P
p
.002 w
.45617 .32567 m .43788 .32927 L .44446 .35332 L p
1 g
F P
s
P
p
.002 w
.43619 .35801 m .44446 .35332 L .43788 .32927 L p
1 g
F P
s
P
p
.002 w
.59122 .39914 m .59021 .35807 L .56383 .35892 L p
1 g
F P
s
P
p
.002 w
.55173 .32754 m .56383 .35892 L .59021 .35807 L p
1 g
F P
s
P
p
.002 w
.56383 .35892 m .55173 .32754 L .52682 .33742 L p
1 g
F P
s
P
p
.002 w
.42135 .33861 m .40846 .35265 L .42973 .36504 L p
1 g
F P
s
P
p
.002 w
.42973 .36504 m .43619 .35801 L .42135 .33861 L p
1 g
F P
s
P
p
.002 w
.60173 .45207 m .6158 .40624 L .59122 .39914 L p
1 g
F P
s
P
p
.002 w
.59021 .35807 m .59122 .39914 L .6158 .40624 L p
1 g
F P
s
P
p
.002 w
.54998 .54274 m .59193 .50906 L .57437 .49206 L p
1 g
F P
s
P
p
.002 w
.57437 .49206 m .53647 .52246 L .54998 .54274 L p
1 g
F P
s
P
p
.002 w
.60173 .45207 m .57437 .49206 L .59193 .50906 L p
1 g
F P
s
P
p
.002 w
.43788 .32927 m .42135 .33861 L .43619 .35801 L p
1 g
F P
s
P
p
.002 w
.50965 .31809 m .52682 .33742 L .55173 .32754 L p
1 g
F P
s
P
p
.002 w
.50039 .56263 m .54998 .54274 L .53647 .52246 L p
1 g
F P
s
P
p
.002 w
.53647 .52246 m .49164 .54031 L .50039 .56263 L p
1 g
F P
s
P
p
.002 w
.3748 .39457 m .38124 .4203 L .40307 .40552 L p
1 g
F P
s
P
p
.002 w
.40307 .40552 m .39882 .38811 L .3748 .39457 L p
1 g
F P
s
P
p
.002 w
.59193 .50906 m .6223 .46482 L .60173 .45207 L p
1 g
F P
s
P
p
.002 w
.6158 .40624 m .60173 .45207 L .6223 .46482 L p
1 g
F P
s
P
p
.002 w
.36192 .43566 m .38115 .46351 L .39585 .44179 L p
1 g
F P
s
P
p
.002 w
.39585 .44179 m .38124 .4203 L .36192 .43566 L p
1 g
F P
s
P
p
.002 w
.36911 .4849 m .40251 .508 L .40862 .4828 L p
1 g
F P
s
P
p
.002 w
.40862 .4828 m .38115 .46351 L .36911 .4849 L p
1 g
F P
s
P
p
.002 w
.39871 .53182 m .44415 .54367 L .44196 .51853 L p
1 g
F P
s
P
p
.002 w
.44196 .51853 m .40251 .508 L .39871 .53182 L p
1 g
F P
s
P
p
.002 w
.50965 .31809 m .48651 .30574 L .47417 .32817 L p
1 g
F P
s
P
p
.002 w
.45617 .32567 m .47417 .32817 L .48651 .30574 L p
1 g
F P
s
P
p
.002 w
.37742 .3674 m .3748 .39457 L .39882 .38811 L p
1 g
F P
s
P
p
.002 w
.39882 .38811 m .40067 .3698 L .37742 .3674 L p
1 g
F P
s
P
p
.002 w
.44781 .56657 m .50039 .56263 L .49164 .54031 L p
1 g
F P
s
P
p
.002 w
.49164 .54031 m .44415 .54367 L .44781 .56657 L p
1 g
F P
s
P
p
.002 w
.55173 .32754 m .52957 .30222 L .50965 .31809 L p
1 g
F P
s
P
p
.002 w
.48651 .30574 m .50965 .31809 L .52957 .30222 L p
1 g
F P
s
P
p
.002 w
.48651 .30574 m .45987 .3019 L .45617 .32567 L p
1 g
F P
s
P
p
.002 w
.43788 .32927 m .45617 .32567 L .45987 .3019 L p
1 g
F P
s
P
p
.002 w
.59021 .35807 m .57585 .32004 L .55173 .32754 L p
1 g
F P
s
P
p
.002 w
.52957 .30222 m .55173 .32754 L .57585 .32004 L p
1 g
F P
s
P
p
.002 w
.6158 .40624 m .61489 .35901 L .59021 .35807 L p
1 g
F P
s
P
p
.002 w
.57585 .32004 m .59021 .35807 L .61489 .35901 L p
1 g
F P
s
P
p
.002 w
.38893 .3419 m .37742 .3674 L .40067 .3698 L p
1 g
F P
s
P
p
.002 w
.40067 .3698 m .40846 .35265 L .38893 .3419 L p
1 g
F P
s
P
p
.002 w
.6223 .46482 m .63806 .41413 L .6158 .40624 L p
1 g
F P
s
P
p
.002 w
.61489 .35901 m .6158 .40624 L .63806 .41413 L p
1 g
F P
s
P
p
.002 w
.45987 .3019 m .43268 .30715 L .43788 .32927 L p
1 g
F P
s
P
p
.002 w
.42135 .33861 m .43788 .32927 L .43268 .30715 L p
1 g
F P
s
P
p
.002 w
.35333 .40212 m .36192 .43566 L .38124 .4203 L p
1 g
F P
s
P
p
.002 w
.38124 .4203 m .3748 .39457 L .35333 .40212 L p
1 g
F P
s
P
p
.002 w
.40808 .321 m .38893 .3419 L .40846 .35265 L p
1 g
F P
s
P
p
.002 w
.40846 .35265 m .42135 .33861 L .40808 .321 L p
1 g
F P
s
P
p
.002 w
.5626 .56073 m .60764 .52453 L .59193 .50906 L p
1 g
F P
s
P
p
.002 w
.59193 .50906 m .54998 .54274 L .5626 .56073 L p
1 g
F P
s
P
p
.002 w
.6223 .46482 m .59193 .50906 L .60764 .52453 L p
1 g
F P
s
P
p
.002 w
.43268 .30715 m .40808 .321 L .42135 .33861 L p
1 g
F P
s
P
p
.002 w
.50938 .58222 m .5626 .56073 L .54998 .54274 L p
1 g
F P
s
P
p
.002 w
.54998 .54274 m .50039 .56263 L .50938 .58222 L p
1 g
F P
s
P
p
.002 w
.34561 .45131 m .36911 .4849 L .38115 .46351 L p
1 g
F P
s
P
p
.002 w
.38115 .46351 m .36192 .43566 L .34561 .45131 L p
1 g
F P
s
P
p
.002 w
.3601 .50547 m .39871 .53182 L .40251 .508 L p
1 g
F P
s
P
p
.002 w
.40251 .508 m .36911 .4849 L .3601 .50547 L p
1 g
F P
s
P
p
.002 w
.52957 .30222 m .4995 .28592 L .48651 .30574 L p
1 g
F P
s
P
p
.002 w
.45987 .3019 m .48651 .30574 L .4995 .28592 L p
1 g
F P
s
P
p
.002 w
.3974 .55372 m .44781 .56657 L .44415 .54367 L p
1 g
F P
s
P
p
.002 w
.44415 .54367 m .39871 .53182 L .3974 .55372 L p
1 g
F P
s
P
p
.002 w
.60764 .52453 m .64033 .47705 L .6223 .46482 L p
1 g
F P
s
P
p
.002 w
.63806 .41413 m .6223 .46482 L .64033 .47705 L p
1 g
F P
s
P
p
.002 w
.35661 .36655 m .35333 .40212 L .3748 .39457 L p
1 g
F P
s
P
p
.002 w
.3748 .39457 m .37742 .3674 L .35661 .36655 L p
1 g
F P
s
P
p
.002 w
.57585 .32004 m .54923 .28921 L .52957 .30222 L p
1 g
F P
s
P
p
.002 w
.4995 .28592 m .52957 .30222 L .54923 .28921 L p
1 g
F P
s
P
p
.002 w
.45293 .58667 m .50938 .58222 L .50039 .56263 L p
1 g
F P
s
P
p
.002 w
.50039 .56263 m .44781 .56657 L .45293 .58667 L p
1 g
F P
s
P
p
.002 w
.61489 .35901 m .59865 .31516 L .57585 .32004 L p
1 g
F P
s
P
p
.002 w
.54923 .28921 m .57585 .32004 L .59865 .31516 L p
1 g
F P
s
P
p
.002 w
.4995 .28592 m .46469 .28074 L .45987 .3019 L p
1 g
F P
s
P
p
.002 w
.43268 .30715 m .45987 .3019 L .46469 .28074 L p
1 g
F P
s
P
p
.002 w
.63806 .41413 m .63732 .36181 L .61489 .35901 L p
1 g
F P
s
P
p
.002 w
.59865 .31516 m .61489 .35901 L .63732 .36181 L p
1 g
F P
s
P
p
.002 w
.37163 .33307 m .35661 .36655 L .37742 .3674 L p
1 g
F P
s
P
p
.002 w
.37742 .3674 m .38893 .3419 L .37163 .33307 L p
1 g
F P
s
P
p
.002 w
.33497 .41063 m .34561 .45131 L .36192 .43566 L p
1 g
F P
s
P
p
.002 w
.36192 .43566 m .35333 .40212 L .33497 .41063 L p
1 g
F P
s
P
p
.002 w
.64033 .47705 m .65744 .42266 L .63806 .41413 L p
1 g
F P
s
P
p
.002 w
.63732 .36181 m .63806 .41413 L .65744 .42266 L p
1 g
F P
s
P
p
.002 w
.46469 .28074 m .42905 .28751 L .43268 .30715 L p
1 g
F P
s
P
p
.002 w
.40808 .321 m .43268 .30715 L .42905 .28751 L p
1 g
F P
s
P
p
.002 w
.33279 .4669 m .3601 .50547 L .36911 .4849 L p
1 g
F P
s
P
p
.002 w
.36911 .4849 m .34561 .45131 L .33279 .4669 L p
1 g
F P
s
P
p
.002 w
.39676 .30564 m .37163 .33307 L .38893 .3419 L p
1 g
F P
s
P
p
.002 w
.38893 .3419 m .40808 .321 L .39676 .30564 L p
1 g
F P
s
P
p
.002 w
.57401 .57595 m .6211 .53808 L .60764 .52453 L p
1 g
F P
s
P
p
.002 w
.60764 .52453 m .5626 .56073 L .57401 .57595 L p
1 g
F P
s
P
p
.002 w
.64033 .47705 m .60764 .52453 L .6211 .53808 L p
1 g
F P
s
P
p
.002 w
.42905 .28751 m .39676 .30564 L .40808 .321 L p
1 g
F P
s
P
p
.002 w
.35444 .52474 m .3974 .55372 L .39871 .53182 L p
1 g
F P
s
P
p
.002 w
.39871 .53182 m .3601 .50547 L .35444 .52474 L p
1 g
F P
s
P
p
.002 w
.51842 .59853 m .57401 .57595 L .5626 .56073 L p
1 g
F P
s
P
p
.002 w
.5626 .56073 m .50938 .58222 L .51842 .59853 L p
1 g
F P
s
P
p
.002 w
.54923 .28921 m .51287 .26924 L .4995 .28592 L p
1 g
F P
s
P
p
.002 w
.46469 .28074 m .4995 .28592 L .51287 .26924 L p
1 g
F P
s
P
p
.002 w
.39872 .57312 m .45293 .58667 L .44781 .56657 L p
1 g
F P
s
P
p
.002 w
.44781 .56657 m .3974 .55372 L .39872 .57312 L p
1 g
F P
s
P
p
.002 w
.6211 .53808 m .65534 .48849 L .64033 .47705 L p
1 g
F P
s
P
p
.002 w
.65744 .42266 m .64033 .47705 L .65534 .48849 L p
1 g
F P
s
P
p
.002 w
.33882 .36733 m .33497 .41063 L .35333 .40212 L p
1 g
F P
s
P
p
.002 w
.35333 .40212 m .35661 .36655 L .33882 .36733 L p
1 g
F P
s
P
p
.002 w
.59865 .31516 m .5682 .27946 L .54923 .28921 L p
1 g
F P
s
P
p
.002 w
.51287 .26924 m .54923 .28921 L .5682 .27946 L p
1 g
F P
s
P
p
.002 w
.63732 .36181 m .61958 .31311 L .59865 .31516 L p
1 g
F P
s
P
p
.002 w
.5682 .27946 m .59865 .31516 L .61958 .31311 L p
1 g
F P
s
P
p
.002 w
.45945 .60338 m .51842 .59853 L .50938 .58222 L p
1 g
F P
s
P
p
.002 w
.50938 .58222 m .45293 .58667 L .45945 .60338 L p
1 g
F P
s
P
p
.002 w
.65744 .42266 m .65689 .36647 L .63732 .36181 L p
1 g
F P
s
P
p
.002 w
.61958 .31311 m .63732 .36181 L .65689 .36647 L p
1 g
F P
s
P
p
.002 w
.51287 .26924 m .47058 .26276 L .46469 .28074 L p
1 g
F P
s
P
p
.002 w
.42905 .28751 m .46469 .28074 L .47058 .26276 L p
1 g
F P
s
P
p
.002 w
.3203 .41996 m .33279 .4669 L .34561 .45131 L p
1 g
F P
s
P
p
.002 w
.34561 .45131 m .33497 .41063 L .3203 .41996 L p
1 g
F P
s
P
p
.002 w
.35706 .32648 m .33882 .36733 L .35661 .36655 L p
1 g
F P
s
P
p
.002 w
.35661 .36655 m .37163 .33307 L .35706 .32648 L p
1 g
F P
s
P
p
.002 w
.65534 .48849 m .67337 .43169 L .65744 .42266 L p
1 g
F P
s
P
p
.002 w
.65689 .36647 m .65744 .42266 L .67337 .43169 L p
1 g
F P
s
P
p
.002 w
.32394 .48208 m .35444 .52474 L .3601 .50547 L p
1 g
F P
s
P
p
.002 w
.3601 .50547 m .33279 .4669 L .32394 .48208 L p
1 g
F P
s
P
p
.002 w
.47058 .26276 m .42715 .27091 L .42905 .28751 L p
1 g
F P
s
P
p
.002 w
.39676 .30564 m .42905 .28751 L .42715 .27091 L p
1 g
F P
s
P
p
.002 w
.35244 .5422 m .39872 .57312 L .3974 .55372 L p
1 g
F P
s
P
p
.002 w
.3974 .55372 m .35444 .52474 L .35244 .5422 L p
1 g
F P
s
P
p
.002 w
.38772 .29299 m .35706 .32648 L .37163 .33307 L p
1 g
F P
s
P
p
.002 w
.37163 .33307 m .39676 .30564 L .38772 .29299 L p
1 g
F P
s
P
p
.002 w
.5682 .27946 m .52636 .25621 L .51287 .26924 L p
1 g
F P
s
P
p
.002 w
.47058 .26276 m .51287 .26924 L .52636 .25621 L p
1 g
F P
s
P
p
.002 w
.58391 .58792 m .63188 .54931 L .6211 .53808 L p
1 g
F P
s
P
p
.002 w
.6211 .53808 m .57401 .57595 L .58391 .58792 L p
1 g
F P
s
P
p
.002 w
.65534 .48849 m .6211 .53808 L .63188 .54931 L p
1 g
F P
s
P
p
.002 w
.42715 .27091 m .38772 .29299 L .39676 .30564 L p
1 g
F P
s
P
p
.002 w
.40278 .58943 m .45945 .60338 L .45293 .58667 L p
1 g
F P
s
P
p
.002 w
.45293 .58667 m .39872 .57312 L .40278 .58943 L p
1 g
F P
s
P
p
.002 w
.52732 .61102 m .58391 .58792 L .57401 .57595 L p
1 g
F P
s
P
p
.002 w
.57401 .57595 m .51842 .59853 L .52732 .61102 L p
1 g
F P
s
P
p
.002 w
.61958 .31311 m .58602 .27335 L .5682 .27946 L p
1 g
F P
s
P
p
.002 w
.52636 .25621 m .5682 .27946 L .58602 .27335 L p
1 g
F P
s
P
p
.002 w
.63188 .54931 m .66682 .49882 L .65534 .48849 L p
1 g
F P
s
P
p
.002 w
.67337 .43169 m .65534 .48849 L .66682 .49882 L p
1 g
F P
s
P
p
.002 w
.32463 .36982 m .3203 .41996 L .33497 .41063 L p
1 g
F P
s
P
p
.002 w
.33497 .41063 m .33882 .36733 L .32463 .36982 L p
1 g
F P
s
P
p
.002 w
.65689 .36647 m .63809 .31408 L .61958 .31311 L p
1 g
F P
s
P
p
.002 w
.58602 .27335 m .61958 .31311 L .63809 .31408 L p
1 g
F P
s
P
p
.002 w
.46729 .6161 m .52732 .61102 L .51842 .59853 L p
1 g
F P
s
P
p
.002 w
.51842 .59853 m .45945 .60338 L .46729 .6161 L p
1 g
F P
s
P
p
.002 w
.67337 .43169 m .67301 .37298 L .65689 .36647 L p
1 g
F P
s
P
p
.002 w
.63809 .31408 m .65689 .36647 L .67301 .37298 L p
1 g
F P
s
P
p
.002 w
.52636 .25621 m .47747 .24855 L .47058 .26276 L p
1 g
F P
s
P
p
.002 w
.42715 .27091 m .47058 .26276 L .47747 .24855 L p
1 g
F P
s
P
p
.002 w
.30988 .42993 m .32394 .48208 L .33279 .4669 L p
1 g
F P
s
P
p
.002 w
.33279 .4669 m .3203 .41996 L .30988 .42993 L p
1 g
F P
s
P
p
.002 w
.34573 .3224 m .32463 .36982 L .33882 .36733 L p
1 g
F P
s
P
p
.002 w
.33882 .36733 m .35706 .32648 L .34573 .3224 L p
1 g
F P
s
P
p
.002 w
.66682 .49882 m .68531 .44102 L .67337 .43169 L p
1 g
F P
s
P
p
.002 w
.67301 .37298 m .67337 .43169 L .68531 .44102 L p
1 g
F P
s
P
p
.002 w
.31949 .49644 m .35244 .5422 L .35444 .52474 L p
1 g
F P
s
P
p
.002 w
.35444 .52474 m .32394 .48208 L .31949 .49644 L p
1 g
F P
s
P
p
.002 w
.35435 .55731 m .40278 .58943 L .39872 .57312 L p
1 g
F P
s
P
p
.002 w
.39872 .57312 m .35244 .5422 L .35435 .55731 L p
1 g
F P
s
P
p
.002 w
.47747 .24855 m .4271 .2579 L .42715 .27091 L p
1 g
F P
s
P
p
.002 w
.38772 .29299 m .42715 .27091 L .4271 .2579 L p
1 g
F P
s
P
p
.002 w
.58602 .27335 m .53964 .24734 L .52636 .25621 L p
1 g
F P
s
P
p
.002 w
.47747 .24855 m .52636 .25621 L .53964 .24734 L p
1 g
F P
s
P
p
.002 w
.38131 .2835 m .34573 .3224 L .35706 .32648 L p
1 g
F P
s
P
p
.002 w
.35706 .32648 m .38772 .29299 L .38131 .2835 L p
1 g
F P
s
P
p
.002 w
.59196 .59617 m .63957 .55783 L .63188 .54931 L p
1 g
F P
s
P
p
.002 w
.63188 .54931 m .58391 .58792 L .59196 .59617 L p
1 g
F P
s
P
p
.002 w
.66682 .49882 m .63188 .54931 L .63957 .55783 L p
1 g
F P
s
P
p
.002 w
.4271 .2579 m .38131 .2835 L .38772 .29299 L p
1 g
F P
s
P
p
.002 w
.40962 .60207 m .46729 .6161 L .45945 .60338 L p
1 g
F P
s
P
p
.002 w
.45945 .60338 m .40278 .58943 L .40962 .60207 L p
1 g
F P
s
P
p
.002 w
.53583 .61914 m .59196 .59617 L .58391 .58792 L p
1 g
F P
s
P
p
.002 w
.58391 .58792 m .52732 .61102 L .53583 .61914 L p
1 g
F P
s
P
p
.002 w
.63809 .31408 m .60219 .27121 L .58602 .27335 L p
1 g
F P
s
P
p
.002 w
.53964 .24734 m .58602 .27335 L .60219 .27121 L p
1 g
F P
s
P
p
.002 w
.3146 .37405 m .30988 .42993 L .3203 .41996 L p
1 g
F P
s
P
p
.002 w
.3203 .41996 m .32463 .36982 L .3146 .37405 L p
1 g
F P
s
P
p
.002 w
.63957 .55783 m .67429 .50773 L .66682 .49882 L p
1 g
F P
s
P
p
.002 w
.68531 .44102 m .66682 .49882 L .67429 .50773 L p
1 g
F P
s
P
p
.002 w
.67301 .37298 m .65358 .3182 L .63809 .31408 L p
1 g
F P
s
P
p
.002 w
.60219 .27121 m .63809 .31408 L .65358 .3182 L p
1 g
F P
s
P
p
.002 w
.68531 .44102 m .6851 .38129 L .67301 .37298 L p
1 g
F P
s
P
p
.002 w
.65358 .3182 m .67301 .37298 L .6851 .38129 L p
1 g
F P
s
P
p
.002 w
.47635 .62428 m .53583 .61914 L .52732 .61102 L p
1 g
F P
s
P
p
.002 w
.52732 .61102 m .46729 .6161 L .47635 .62428 L p
1 g
F P
s
P
p
.002 w
.53964 .24734 m .48524 .23868 L .47747 .24855 L p
1 g
F P
s
P
p
.002 w
.4271 .2579 m .47747 .24855 L .48524 .23868 L p
1 g
F P
s
P
p
.002 w
.30424 .44032 m .31949 .49644 L .32394 .48208 L p
1 g
F P
s
P
p
.002 w
.32394 .48208 m .30988 .42993 L .30424 .44032 L p
1 g
F P
s
P
p
.002 w
.31982 .50958 m .35435 .55731 L .35244 .5422 L p
1 g
F P
s
P
p
.002 w
.35244 .5422 m .31949 .49644 L .31982 .50958 L p
1 g
F P
s
P
p
.002 w
.33811 .32109 m .3146 .37405 L .32463 .36982 L p
1 g
F P
s
P
p
.002 w
.32463 .36982 m .34573 .3224 L .33811 .32109 L p
1 g
F P
s
P
p
.002 w
.67429 .50773 m .69271 .45044 L .68531 .44102 L p
1 g
F P
s
P
p
.002 w
.6851 .38129 m .68531 .44102 L .69271 .45044 L p
1 g
F P
s
P
p
.002 w
.36034 .56952 m .40962 .60207 L .40278 .58943 L p
1 g
F P
s
P
p
.002 w
.40278 .58943 m .35435 .55731 L .36034 .56952 L p
1 g
F P
s
P
p
.002 w
.48524 .23868 m .42904 .24904 L .4271 .2579 L p
1 g
F P
s
P
p
.002 w
.38131 .2835 m .4271 .2579 L .42904 .24904 L p
1 g
F P
s
P
p
.002 w
.60219 .27121 m .55236 .24309 L .53964 .24734 L p
1 g
F P
s
P
p
.002 w
.48524 .23868 m .53964 .24734 L .55236 .24309 L p
1 g
F P
s
P
p
.002 w
.37787 .27762 m .33811 .32109 L .34573 .3224 L p
1 g
F P
s
P
p
.002 w
.34573 .3224 m .38131 .2835 L .37787 .27762 L p
1 g
F P
s
P
p
.002 w
.41924 .61048 m .47635 .62428 L .46729 .6161 L p
1 g
F P
s
P
p
.002 w
.46729 .6161 m .40962 .60207 L .41924 .61048 L p
1 g
F P
s
P
p
.002 w
.59784 .60024 m .64378 .56323 L .63957 .55783 L p
1 g
F P
s
P
p
.002 w
.63957 .55783 m .59196 .59617 L .59784 .60024 L p
1 g
F P
s
P
p
.002 w
.67429 .50773 m .63957 .55783 L .64378 .56323 L p
1 g
F P
s
P
p
.002 w
.42904 .24904 m .37787 .27762 L .38131 .2835 L p
1 g
F P
s
P
p
.002 w
.65358 .3182 m .61621 .27333 L .60219 .27121 L p
1 g
F P
s
P
p
.002 w
.55236 .24309 m .60219 .27121 L .61621 .27333 L p
1 g
F P
s
P
p
.002 w
.54372 .62243 m .59784 .60024 L .59196 .59617 L p
1 g
F P
s
P
p
.002 w
.59196 .59617 m .53583 .61914 L .54372 .62243 L p
1 g
F P
s
P
p
.002 w
.30927 .38002 m .30424 .44032 L .30988 .42993 L p
1 g
F P
s
P
p
.002 w
.30988 .42993 m .3146 .37405 L .30927 .38002 L p
1 g
F P
s
P
p
.002 w
.6851 .38129 m .66548 .32556 L .65358 .3182 L p
1 g
F P
s
P
p
.002 w
.61621 .27333 m .65358 .3182 L .66548 .32556 L p
1 g
F P
s
P
p
.002 w
.64378 .56323 m .6773 .51491 L .67429 .50773 L p
1 g
F P
s
P
p
.002 w
.69271 .45044 m .67429 .50773 L .6773 .51491 L p
1 g
F P
s
P
p
.002 w
.69271 .45044 m .6926 .39128 L .6851 .38129 L p
1 g
F P
s
P
p
.002 w
.66548 .32556 m .6851 .38129 L .6926 .39128 L p
1 g
F P
s
P
p
.002 w
.48644 .62743 m .54372 .62243 L .53583 .61914 L p
1 g
F P
s
P
p
.002 w
.53583 .61914 m .47635 .62428 L .48644 .62743 L p
1 g
F P
s
P
p
.002 w
.30382 .45088 m .31982 .50958 L .31949 .49644 L p
1 g
F P
s
P
p
.002 w
.31949 .49644 m .30424 .44032 L .30382 .45088 L p
1 g
F P
s
P
p
.002 w
.55236 .24309 m .49374 .23368 L .48524 .23868 L p
1 g
F P
s
P
p
.002 w
.42904 .24904 m .48524 .23868 L .49374 .23368 L p
1 g
F P
s
P
p
.002 w
.32521 .52103 m .36034 .56952 L .35435 .55731 L p
1 g
F P
s
P
p
.002 w
.35435 .55731 m .31982 .50958 L .32521 .52103 L p
1 g
F P
s
P
p
.002 w
.6773 .51491 m .6951 .45971 L .69271 .45044 L p
1 g
F P
s
P
p
.002 w
.6926 .39128 m .69271 .45044 L .6951 .45971 L p
1 g
F P
s
P
p
.002 w
.33467 .32277 m .30927 .38002 L .3146 .37405 L p
1 g
F P
s
P
p
.002 w
.3146 .37405 m .33811 .32109 L .33467 .32277 L p
1 g
F P
s
P
p
.002 w
.3705 .57833 m .41924 .61048 L .40962 .60207 L p
1 g
F P
s
P
p
.002 w
.40962 .60207 m .36034 .56952 L .3705 .57833 L p
1 g
F P
s
P
p
.002 w
.61621 .27333 m .56416 .24386 L .55236 .24309 L p
1 g
F P
s
P
p
.002 w
.49374 .23368 m .55236 .24309 L .56416 .24386 L p
1 g
F P
s
P
p
.002 w
.49374 .23368 m .43303 .24483 L .42904 .24904 L p
1 g
F P
s
P
p
.002 w
.37787 .27762 m .42904 .24904 L .43303 .24483 L p
1 g
F P
s
P
p
.002 w
.43154 .61417 m .48644 .62743 L .47635 .62428 L p
1 g
F P
s
P
p
.002 w
.47635 .62428 m .41924 .61048 L .43154 .61417 L p
1 g
F P
s
P
p
.002 w
.37769 .27573 m .33467 .32277 L .33811 .32109 L p
1 g
F P
s
P
p
.002 w
.33811 .32109 m .37787 .27762 L .37769 .27573 L p
1 g
F P
s
P
p
.002 w
.66548 .32556 m .62757 .27991 L .61621 .27333 L p
1 g
F P
s
P
p
.002 w
.56416 .24386 m .61621 .27333 L .62757 .27991 L p
1 g
F P
s
P
p
.002 w
.60124 .59975 m .64417 .56517 L .64378 .56323 L p
1 g
F P
s
P
p
.002 w
.64378 .56323 m .59784 .60024 L .60124 .59975 L p
1 g
F P
s
P
p
.002 w
.6773 .51491 m .64378 .56323 L .64417 .56517 L p
1 g
F P
s
P
p
.004 w
.53527 .62867 m
.53646 .63531 L
s
P
p
.004 w
.53646 .63531 m
.55223 .72394 L
s
P
p
.002 w
.43303 .24483 m .37769 .27573 L .37787 .27762 L p
1 g
F P
s
P
p
.002 w
.55072 .62048 m .60124 .59975 L .59784 .60024 L p
1 g
F P
s
P
p
.002 w
.59784 .60024 m .54372 .62243 L .55072 .62048 L p
1 g
F P
s
P
p
.002 w
.6926 .39128 m .67325 .33613 L .66548 .32556 L p
1 g
F P
s
P
p
.002 w
.62757 .27991 m .66548 .32556 L .67325 .33613 L p
1 g
F P
s
P
p
.002 w
.3091 .38768 m .30382 .45088 L .30424 .44032 L p
1 g
F P
s
P
p
.002 w
.30424 .44032 m .30927 .38002 L .3091 .38768 L p
1 g
F P
s
P
p
.002 w
.64417 .56517 m .67548 .52004 L .6773 .51491 L p
1 g
F P
s
P
p
.002 w
.6951 .45971 m .6773 .51491 L .67548 .52004 L p
1 g
F P
s
P
p
.002 w
.6951 .45971 m .69503 .40279 L .6926 .39128 L p
1 g
F P
s
P
p
.002 w
.67325 .33613 m .6926 .39128 L .69503 .40279 L p
1 g
F P
s
P
p
.002 w
.30896 .4613 m .32521 .52103 L .31982 .50958 L p
1 g
F P
s
P
p
.002 w
.31982 .50958 m .30382 .45088 L .30896 .4613 L p
1 g
F P
s
P
p
.002 w
.49734 .62512 m .55072 .62048 L .54372 .62243 L p
1 g
F P
s
P
p
.002 w
.54372 .62243 m .48644 .62743 L .49734 .62512 L p
1 g
F P
s
P
p
.002 w
.56416 .24386 m .50277 .23399 L .49374 .23368 L p
1 g
F P
s
P
p
.002 w
.43303 .24483 m .49374 .23368 L .50277 .23399 L p
1 g
F P
s
P
p
.002 w
.33582 .53037 m .3705 .57833 L .36034 .56952 L p
1 g
F P
s
P
p
.002 w
.36034 .56952 m .32521 .52103 L .33582 .53037 L p
1 g
F P
s
P
p
.002 w
.38479 .58325 m .43154 .61417 L .41924 .61048 L p
1 g
F P
s
P
p
.002 w
.41924 .61048 m .3705 .57833 L .38479 .58325 L p
1 g
F P
s
P
p
.002 w
.67548 .52004 m .69208 .46855 L .6951 .45971 L p
1 g
F P
s
P
p
.002 w
.69503 .40279 m .6951 .45971 L .69208 .46855 L p
1 g
F P
s
P
p
.002 w
.33578 .32759 m .3091 .38768 L .30927 .38002 L p
1 g
F P
s
P
p
.002 w
.30927 .38002 m .33467 .32277 L .33578 .32759 L p
1 g
F P
s
P
p
.002 w
.62757 .27991 m .57464 .24994 L .56416 .24386 L p
1 g
F P
s
P
p
.002 w
.50277 .23399 m .56416 .24386 L .57464 .24994 L p
1 g
F P
s
P
p
.002 w
.50277 .23399 m .4391 .24571 L .43303 .24483 L p
1 g
F P
s
P
p
.002 w
.37769 .27573 m .43303 .24483 L .4391 .24571 L p
1 g
F P
s
P
p
.002 w
.4463 .61272 m .49734 .62512 L .48644 .62743 L p
1 g
F P
s
P
p
.002 w
.48644 .62743 m .43154 .61417 L .4463 .61272 L p
1 g
F P
s
P
p
.002 w
.67325 .33613 m .63577 .29102 L .62757 .27991 L p
1 g
F P
s
P
p
.002 w
.57464 .24994 m .62757 .27991 L .63577 .29102 L p
1 g
F P
s
P
p
.002 w
.38098 .27818 m .33578 .32759 L .33467 .32277 L p
1 g
F P
s
P
p
.002 w
.33467 .32277 m .37769 .27573 L .38098 .27818 L p
1 g
F P
s
P
p
.002 w
.69503 .40279 m .67642 .34983 L .67325 .33613 L p
1 g
F P
s
P
p
.002 w
.63577 .29102 m .67325 .33613 L .67642 .34983 L p
1 g
F P
s
P
p
.002 w
.60191 .59441 m .64047 .56336 L .64417 .56517 L p
1 g
F P
s
P
p
.002 w
.64417 .56517 m .60124 .59975 L .60191 .59441 L p
1 g
F P
s
P
p
.002 w
.67548 .52004 m .64417 .56517 L .64047 .56336 L p
1 g
F P
s
P
p
.002 w
.4391 .24571 m .38098 .27818 L .37769 .27573 L p
1 g
F P
s
P
p
.002 w
.31442 .3969 m .30896 .4613 L .30382 .45088 L p
1 g
F P
s
P
p
.002 w
.30382 .45088 m .3091 .38768 L .31442 .3969 L p
1 g
F P
s
P
p
.002 w
.55658 .61299 m .60191 .59441 L .60124 .59975 L p
1 g
F P
s
P
p
.002 w
.60124 .59975 m .55072 .62048 L .55658 .61299 L p
1 g
F P
s
P
p
.002 w
.64047 .56336 m .66857 .52284 L .67548 .52004 L p
1 g
F P
s
P
p
.002 w
.69208 .46855 m .67548 .52004 L .66857 .52284 L p
1 g
F P
s
P
p
.002 w
.69208 .46855 m .69198 .41556 L .69503 .40279 L p
1 g
F P
s
P
p
.002 w
.67642 .34983 m .69503 .40279 L .69198 .41556 L p
1 g
F P
s
P
p
.002 w
.31987 .47125 m .33582 .53037 L .32521 .52103 L p
1 g
F P
s
P
p
.002 w
.32521 .52103 m .30896 .4613 L .31987 .47125 L p
1 g
F P
s
P
p
.002 w
.50877 .61708 m .55658 .61299 L .55072 .62048 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53284 .61502 L
s
P
p
.002 w
.55072 .62048 m .49734 .62512 L .50877 .61708 L p
1 g
F P
s
P
p
.004 w
.53375 .62013 m
.53401 .62156 L
s
P
p
.004 w
.53401 .62156 m
.53527 .62867 L
s
P
p
.002 w
.57464 .24994 m .51212 .23995 L .50277 .23399 L p
1 g
F P
s
P
p
.002 w
.4391 .24571 m .50277 .23399 L .51212 .23995 L p
1 g
F P
s
P
p
.002 w
.35164 .53716 m .38479 .58325 L .3705 .57833 L p
1 g
F P
s
P
p
.002 w
.3705 .57833 m .33582 .53037 L .35164 .53716 L p
1 g
F P
s
P
p
.002 w
.40299 .58391 m .4463 .61272 L .43154 .61417 L p
1 g
F P
s
P
p
.002 w
.43154 .61417 m .38479 .58325 L .40299 .58391 L p
1 g
F P
s
P
p
.002 w
.66857 .52284 m .68341 .47667 L .69208 .46855 L p
1 g
F P
s
P
p
.002 w
.69198 .41556 m .69208 .46855 L .68341 .47667 L p
1 g
F P
s
P
p
.002 w
.34171 .33561 m .31442 .3969 L .3091 .38768 L p
1 g
F P
s
P
p
.002 w
.3091 .38768 m .33578 .32759 L .34171 .33561 L p
1 g
F P
s
P
p
.002 w
.63577 .29102 m .5834 .26148 L .57464 .24994 L p
1 g
F P
s
P
p
.002 w
.51212 .23995 m .57464 .24994 L .5834 .26148 L p
1 g
F P
s
P
p
.002 w
.67642 .34983 m .64038 .30661 L .63577 .29102 L p
1 g
F P
s
P
p
.002 w
.5834 .26148 m .63577 .29102 L .64038 .30661 L p
1 g
F P
s
P
p
.002 w
.46321 .60589 m .50877 .61708 L .49734 .62512 L p
1 g
F P
s
P
p
.002 w
.49734 .62512 m .4463 .61272 L .46321 .60589 L p
1 g
F P
s
P
p
.002 w
.51212 .23995 m .44719 .25198 L .4391 .24571 L p
1 g
F P
s
P
p
.002 w
.38098 .27818 m .4391 .24571 L .44719 .25198 L p
1 g
F P
s
P
p
.002 w
.69198 .41556 m .67459 .3664 L .67642 .34983 L p
1 g
F P
s
P
p
.002 w
.64038 .30661 m .67642 .34983 L .67459 .3664 L p
1 g
F P
s
P
p
.002 w
.38787 .28516 m .34171 .33561 L .33578 .32759 L p
1 g
F P
s
P
p
.002 w
.33578 .32759 m .38098 .27818 L .38787 .28516 L p
1 g
F P
s
P
p
.002 w
.32542 .4075 m .31987 .47125 L .30896 .4613 L p
1 g
F P
s
P
p
.002 w
.30896 .4613 m .31442 .3969 L .32542 .4075 L p
1 g
F P
s
P
p
.002 w
.59965 .58407 m .63252 .55761 L .64047 .56336 L p
1 g
F P
s
P
p
.002 w
.64047 .56336 m .60191 .59441 L .59965 .58407 L p
1 g
F P
s
P
p
.002 w
.66857 .52284 m .64047 .56336 L .63252 .55761 L p
1 g
F P
s
P
p
.002 w
.44719 .25198 m .38787 .28516 L .38098 .27818 L p
1 g
F P
s
P
p
.002 w
.56102 .59985 m .59965 .58407 L .60191 .59441 L p
1 g
F P
s
P
p
.002 w
.60191 .59441 m .55658 .61299 L .56102 .59985 L p
1 g
F P
s
P
p
.002 w
.68341 .47667 m .68322 .42928 L .69198 .41556 L p
1 g
F P
s
P
p
.002 w
.67459 .3664 m .69198 .41556 L .68322 .42928 L p
1 g
F P
s
P
p
.002 w
.63252 .55761 m .65644 .52306 L .66857 .52284 L p
1 g
F P
s
P
p
.002 w
.68341 .47667 m .66857 .52284 L .65644 .52306 L p
1 g
F P
s
P
p
.002 w
.33653 .48039 m .35164 .53716 L .33582 .53037 L p
1 g
F P
s
P
p
.002 w
.33582 .53037 m .31987 .47125 L .33653 .48039 L p
1 g
F P
s
P
p
.002 w
.37244 .54105 m .40299 .58391 L .38479 .58325 L p
1 g
F P
s
P
p
.002 w
.38479 .58325 m .35164 .53716 L .37244 .54105 L p
1 g
F P
s
P
p
.002 w
.52039 .60322 m .56102 .59985 L .55658 .61299 L p
1 g
F P
s
P
p
.002 w
.55658 .61299 m .50877 .61708 L .52039 .60322 L p
1 g
F P
s
P
p
.002 w
.5834 .26148 m .52149 .25173 L .51212 .23995 L p
1 g
F P
s
P
p
.002 w
.44719 .25198 m .51212 .23995 L .52149 .25173 L p
1 g
F P
s
P
p
.002 w
.42473 .58004 m .46321 .60589 L .4463 .61272 L p
1 g
F P
s
P
p
.002 w
.4463 .61272 m .40299 .58391 L .42473 .58004 L p
1 g
F P
s
P
p
.002 w
.65644 .52306 m .66899 .48376 L .68341 .47667 L p
1 g
F P
s
P
p
.002 w
.68322 .42928 m .68341 .47667 L .66899 .48376 L p
1 g
F P
s
P
p
.002 w
.35257 .34677 m .32542 .4075 L .31442 .3969 L p
1 g
F P
s
P
p
.002 w
.31442 .3969 m .34171 .33561 L .35257 .34677 L p
1 g
F P
s
P
p
.002 w
.64038 .30661 m .59004 .27844 L .5834 .26148 L p
1 g
F P
s
P
p
.002 w
.52149 .25173 m .5834 .26148 L .59004 .27844 L p
1 g
F P
s
P
p
.002 w
.67459 .3664 m .64102 .32644 L .64038 .30661 L p
1 g
F P
s
P
p
.002 w
.59004 .27844 m .64038 .30661 L .64102 .32644 L p
1 g
F P
s
P
p
.002 w
.48183 .59358 m .52039 .60322 L .50877 .61708 L p
1 g
F P
s
P
p
.002 w
.50877 .61708 m .46321 .60589 L .48183 .59358 L p
1 g
F P
s
P
p
.002 w
.52149 .25173 m .45718 .26378 L .44719 .25198 L p
1 g
F P
s
P
p
.002 w
.38787 .28516 m .44719 .25198 L .45718 .26378 L p
1 g
F P
s
P
p
.002 w
.68322 .42928 m .66755 .38549 L .67459 .3664 L p
1 g
F P
s
P
p
.002 w
.64102 .32644 m .67459 .3664 L .66755 .38549 L p
1 g
F P
s
P
p
.002 w
.34207 .41918 m .33653 .48039 L .31987 .47125 L p
1 g
F P
s
P
p
.002 w
.31987 .47125 m .32542 .4075 L .34207 .41918 L p
1 g
F P
s
P
p
.002 w
.39838 .29675 m .35257 .34677 L .34171 .33561 L p
1 g
F P
s
P
p
.002 w
.34171 .33561 m .38787 .28516 L .39838 .29675 L p
1 g
F P
s
P
p
.002 w
.59433 .56875 m .6203 .54785 L .63252 .55761 L p
1 g
F P
s
P
p
.002 w
.63252 .55761 m .59965 .58407 L .59433 .56875 L p
1 g
F P
s
P
p
.002 w
.65644 .52306 m .63252 .55761 L .6203 .54785 L p
1 g
F P
s
P
p
.002 w
.45718 .26378 m .39838 .29675 L .38787 .28516 L p
1 g
F P
s
P
p
.002 w
.66899 .48376 m .6687 .44356 L .68322 .42928 L p
1 g
F P
s
P
p
.002 w
.66755 .38549 m .68322 .42928 L .6687 .44356 L p
1 g
F P
s
P
p
.002 w
.56382 .58114 m .59433 .56875 L .59965 .58407 L p
1 g
F P
s
P
p
.002 w
.59965 .58407 m .56102 .59985 L .56382 .58114 L p
1 g
F P
s
P
p
.002 w
.3587 .48835 m .37244 .54105 L .35164 .53716 L p
1 g
F P
s
P
p
.002 w
.35164 .53716 m .33653 .48039 L .3587 .48835 L p
1 g
F P
s
P
p
.002 w
.6203 .54785 m .63917 .52054 L .65644 .52306 L p
1 g
F P
s
P
p
.002 w
.66899 .48376 m .65644 .52306 L .63917 .52054 L p
1 g
F P
s
P
p
.002 w
.39777 .54173 m .42473 .58004 L .40299 .58391 L p
1 g
F P
s
P
p
.002 w
.40299 .58391 m .37244 .54105 L .39777 .54173 L p
1 g
F P
s
P
p
.002 w
.59004 .27844 m .53059 .26929 L .52149 .25173 L p
1 g
F P
s
P
p
.002 w
.45718 .26378 m .52149 .25173 L .53059 .26929 L p
1 g
F P
s
P
p
.002 w
.53182 .58369 m .56382 .58114 L .56102 .59985 L p
1 g
F P
s
P
p
.002 w
.56102 .59985 m .52039 .60322 L .53182 .58369 L p
1 g
F P
s
P
p
.002 w
.44944 .57153 m .48183 .59358 L .46321 .60589 L p
1 g
F P
s
P
p
.002 w
.46321 .60589 m .42473 .58004 L .44944 .57153 L p
1 g
F P
s
P
p
.002 w
.63917 .52054 m .64898 .48953 L .66899 .48376 L p
1 g
F P
s
P
p
.002 w
.6687 .44356 m .66899 .48376 L .64898 .48953 L p
1 g
F P
s
P
p
.002 w
.64102 .32644 m .59424 .30055 L .59004 .27844 L p
1 g
F P
s
P
p
.002 w
.53059 .26929 m .59004 .27844 L .59424 .30055 L p
1 g
F P
s
P
p
.002 w
.36829 .36088 m .34207 .41918 L .32542 .4075 L p
1 g
F P
s
P
p
.002 w
.32542 .4075 m .35257 .34677 L .36829 .36088 L p
1 g
F P
s
P
p
.002 w
.66755 .38549 m .63747 .35007 L .64102 .32644 L p
1 g
F P
s
P
p
.002 w
.59424 .30055 m .64102 .32644 L .63747 .35007 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53182 .58369 m .52039 .60322 L p
.50556 .58171 L 1 g
F P
s
P
p
.50556 .58171 m .50488 .58072 L .50837 .5811 L 1 g
F
P
p
.50556 .58171 m .50837 .5811 L .53182 .58369 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58055 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58055 L .5156 .57953 L 1 g
F
P
p
.53128 .57265 m .5156 .57953 L .5214 .57772 L 1 g
F
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53182 .58369 m .5156 .57953 L p
.52906 .57532 L 1 g
F P
s
P
p
.002 w
.53648 .573 m .53182 .58369 L p
.52926 .57594 L 1 g
F P
s
P
p
.52926 .57594 m .52906 .57532 L .53168 .5745 L 1 g
F
P
p
.52926 .57594 m .53168 .5745 L .53648 .573 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53168 .5745 L p
1 g
F P
s
P
p
.54854 .56129 m .53168 .5745 L .53728 .57117 L 1 g
F
P
p
.54854 .56129 m .53728 .57117 L .54039 .56906 L 1 g
F
P
p
.002 w
.56382 .58114 m .53182 .58369 L .53728 .57117 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.56382 .58114 m .53728 .57117 L .54764 .56413 L 1 g
F
P
p
.002 w
.56478 .55722 m .56382 .58114 L p
.54795 .56446 L 1 g
F P
s
P
p
.54795 .56446 m .54764 .56413 L .5486 .56375 L 1 g
F
P
p
.54795 .56446 m .5486 .56375 L .56478 .55722 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5492 .56307 L p
1 g
F P
s
P
p
.56075 .54566 m .5492 .56307 L .55372 .55805 L 1 g
F
P
p
.56075 .54566 m .55372 .55805 L .55453 .55693 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56478 .55722 m .55372 .55805 L p
.56082 .5483 L 1 g
F P
s
P
p
.002 w
.5643 .54351 m .56478 .55722 L p
.56105 .54883 L 1 g
F P
s
P
p
.56105 .54883 m .56082 .5483 L .56159 .54724 L 1 g
F
P
p
.56105 .54883 m .56159 .54724 L .5643 .54351 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56159 .54724 L p
1 g
F P
s
P
p
.56654 .52734 m .56159 .54724 L .56417 .53967 L 1 g
F
P
p
.56654 .52734 m .56417 .53967 L .56444 .53884 L 1 g
F
P
p
.002 w
.58596 .54867 m .56478 .55722 L .56417 .53967 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.58596 .54867 m .56417 .53967 L .56684 .53144 L 1 g
F
P
p
.002 w
.57468 .52432 m .58596 .54867 L p
.56773 .53223 L 1 g
F P
s
P
p
.56773 .53223 m .56684 .53144 L .56769 .53067 L 1 g
F
P
p
.56773 .53223 m .56769 .53067 L .57468 .52432 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56765 .52895 L p
1 g
F P
s
P
p
.56515 .50826 m .56765 .52895 L .56761 .52715 L 1 g
F
P
p
.002 w
.56584 .50656 m .57468 .52432 L .57335 .52486 L p
1 g
F P
s
P
p
.002 w
.57335 .52486 m .56761 .52715 L p
.56608 .50936 L 1 g
F P
s
P
p
.57335 .52486 m .56608 .50936 L .56584 .50656 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56608 .50936 L p
1 g
F P
s
P
p
.55661 .4905 m .56608 .50936 L .5626 .50196 L 1 g
F
P
p
.56515 .50826 m .56761 .52715 L .56703 .52046 L 1 g
F
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56833 .52687 m .57468 .52432 L p
.56684 .53144 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55243 .52947 m .56379 .52868 L .56417 .53967 L p
1 g
F P
s
P
p
.002 w
.56417 .53967 m .5643 .54351 L p
.56328 .54229 L 1 g
F P
s
P
p
.56328 .54229 m .55243 .52947 L .56417 .53967 L 1 g
F
P
p
.002 w
.55696 .5578 m .56478 .55722 L p
.5486 .56375 L 1 g
F P
s
P
p
.54764 .56413 m .5492 .56307 L .5486 .56375 L 1 g
F
P
p
.5492 .56307 m .55696 .5578 L .5486 .56375 L 1 g
F
P
p
.55453 .55693 m .55423 .55748 L .56159 .54724 L 1 g
F
P
p
.002 w
.55372 .55805 m .55696 .5578 L p
.5492 .56307 L 1 g
F P
s
P
p
.55423 .55748 m .54998 .56518 L .55685 .55457 L 1 g
F
P
p
.55423 .55748 m .55685 .55457 L .56159 .54724 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5492 .56307 L p
1 g
F P
s
P
p
.002 w
.5492 .56307 m .54854 .56129 L p
.54039 .56906 L 1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52183 .55339 m .54264 .55888 L .53728 .57117 L p
1 g
F P
s
P
p
.002 w
.53728 .57117 m .53648 .573 L p
.53578 .57206 L 1 g
F P
s
P
p
.53578 .57206 m .52183 .55339 L .53728 .57117 L 1 g
F
P
p
.54039 .56906 m .53966 .56976 L .5492 .56307 L 1 g
F
P
p
.002 w
.51093 .58055 m .51079 .57862 L p
.49954 .58087 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58036 L p
1 g
F P
s
P
p
.51079 .57862 m .48908 .58036 L .49297 .5807 L 1 g
F
P
p
.48183 .59358 m .47964 .57952 L .48908 .58036 L 1 g
F
P
p
.002 w
.49596 .58097 m .49472 .58208 L p
.48908 .58036 L 1 g
F P
s
P
p
.002 w
.49472 .58208 m .48183 .59358 L p
.48908 .58036 L 1 g
F P
s
P
p
.002 w
.48908 .58036 m .48921 .57862 L p
.48121 .57796 L 1 g
F P
s
P
p
.51079 .57862 m .49297 .5807 L .49954 .58087 L 1 g
F
P
p
.49297 .5807 m .48902 .58117 L .49596 .58097 L 1 g
F
P
p
.49297 .5807 m .49596 .58097 L .49954 .58087 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46841 .57406 L p
1 g
F P
s
P
p
.47964 .57952 m .47931 .57738 L .48908 .58036 L 1 g
F
P
p
.48921 .57862 m .46841 .57406 L .48121 .57796 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48183 .59358 m .44944 .57153 L .4573 .56773 L p
1 g
F P
s
P
p
.002 w
.46841 .57406 m .46872 .57265 L p
.4594 .56893 L 1 g
F P
s
P
p
.48183 .59358 m .4573 .56773 L .4798 .58056 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45088 .56286 L p
1 g
F P
s
P
p
.002 w
.4573 .56773 m .44944 .57153 L p
.45148 .56331 L 1 g
F P
s
P
p
.46872 .57265 m .45088 .56286 L .45829 .56848 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.42694 .53905 m .43172 .53814 L p
.43856 .54696 L 1 g
F P
s
P
p
.45042 .56226 m .44063 .55258 L .43856 .54696 L 1 g
F
P
p
.44063 .55258 m .42694 .53905 L .43856 .54696 L 1 g
F
P
p
.002 w
.43856 .54696 m .43925 .54566 L p
.43502 .53728 L 1 g
F P
s
P
p
.002 w
.43507 .5375 m .42694 .53905 L p
.43308 .52984 L 1 g
F P
s
P
p
.43502 .53728 m .43493 .53711 L .43507 .5375 L 1 g
F
P
p
.43502 .53728 m .43507 .5375 L .43856 .54696 L 1 g
F
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45088 .56286 m .45146 .56129 L p
.44596 .55651 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.45042 .56226 m .43856 .54696 L .45901 .53296 L 1 g
F
P
p
.002 w
.43172 .53814 m .43507 .5375 L p
.43856 .54696 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43272 .52843 L p
1 g
F P
s
P
p
.42694 .53905 m .42534 .5 L .43272 .52843 L 1 g
F
P
p
.43255 .53063 m .43272 .52843 L .43308 .52984 L 1 g
F
P
p
.42694 .53905 m .43272 .52843 L .43255 .53063 L 1 g
F
P
p
.002 w
.43272 .52843 m .43346 .52734 L p
.43325 .52122 L 1 g
F P
s
P
p
.43925 .54566 m .43272 .52843 L .43423 .53427 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.43308 .52984 m .43272 .52843 L .45167 .50196 L 1 g
F
P
p
.002 w
.42534 .5 m .43477 .50071 L p
.43414 .5091 L 1 g
F P
s
P
p
.43001 .51801 m .42534 .5 L .43414 .5091 L 1 g
F
P
p
.002 w
.43414 .5091 m .43485 .50826 L p
.43833 .50013 L 1 g
F P
s
P
p
.41719 .4994 m .45264 .47113 L .44273 .4912 L 1 g
F
P
p
.002 w
.43793 .50094 m .43304 .50058 L p
.44273 .4912 L 1 g
F P
s
P
p
.002 w
.43304 .50058 m .41719 .4994 L p
.44273 .4912 L 1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43414 .5091 L p
1 g
F P
s
P
p
.43346 .52734 m .43414 .5091 L .43325 .52122 L 1 g
F
P
p
.43272 .52843 m .43414 .5091 L .45167 .50196 L 1 g
F
P
p
.002 w
.43477 .50071 m .43793 .50094 L p
.43414 .5091 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44217 .4918 L p
1 g
F P
s
P
p
.43485 .50826 m .44217 .4918 L .43862 .49946 L 1 g
F
P
p
.43833 .50013 m .43793 .50094 L .43414 .5091 L 1 g
F
P
p
.002 w
.43793 .50094 m .45167 .50196 L p
.43414 .5091 L 1 g
F P
s
P
p
.002 w
.44217 .4918 m .44166 .49233 L p
.43862 .49946 L 1 g
F P
s
P
p
.002 w
.44273 .4912 m .44339 .4905 L p
.4498 .48436 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45167 .50196 m .43793 .50094 L p
.44382 .49014 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45764 .47675 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45415 .48015 m .45764 .47675 L .49076 .47974 L 1 g
F
P
p
.002 w
.45764 .47675 m .45826 .47608 L p
.46807 .47178 L 1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47759 .46712 m .47786 .46667 L p
.48883 .46555 L 1 g
F P
s
P
p
.002 w
.49076 .47974 m .49805 .46427 L p
.53147 .47826 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46395 L .4989 .46413 L 1 g
F
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.49805 .46427 m .5 .46395 L .53147 .47826 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46718 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53147 .47826 m .51213 .46573 L p
.52244 .46718 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.56079 .49642 m .56584 .50656 L p
.56566 .50847 L 1 g
F P
s
P
p
.55661 .4905 m .5626 .50196 L .55757 .49158 L 1 g
F
P
p
.002 w
.54496 .46632 m .55016 .4633 L p
.55815 .49208 L 1 g
F P
s
P
p
.55751 .49146 m .55815 .49208 L .55856 .49356 L 1 g
F
P
p
.54496 .46632 m .55815 .49208 L .55751 .49146 L 1 g
F
P
p
.002 w
.55751 .49146 m .55661 .4905 L p
.55757 .49158 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55751 .49146 L p
1 g
F P
s
P
p
.002 w
.55752 .49146 m .55751 .49146 L p
.55757 .49158 L 1 g
F P
s
P
p
.002 w
.56079 .49642 m .55856 .49356 L p
.55815 .49208 L 1 g
F P
s
P
p
.002 w
.55016 .4633 m .55996 .49383 L p
.55815 .49208 L 1 g
F P
s
P
p
.002 w
.55996 .49383 m .56079 .49642 L p
.55815 .49208 L 1 g
F P
s
P
p
.54174 .47608 m .55751 .49146 L .55512 .48914 L 1 g
F
P
p
.5626 .50196 m .56099 .49852 L .55752 .49146 L 1 g
F
P
p
.56099 .49852 m .56041 .4973 L .55752 .49146 L 1 g
F
P
p
.56041 .4973 m .56018 .49681 L .55752 .49146 L 1 g
F
P
p
.002 w
.56013 .49672 m .56079 .49642 L .56022 .49691 L p
1 g
F P
s
P
p
.56018 .49681 m .56013 .49672 L .56008 .49662 L 1 g
F
P
p
.56018 .49681 m .56008 .49662 L .55752 .49146 L 1 g
F
P
p
.56013 .49672 m .55996 .49637 L .55752 .49146 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.52723 .51127 m .52488 .50045 L .56003 .49651 L p
1 g
F P
s
P
p
.002 w
.56003 .49651 m .56079 .49642 L .56013 .49672 L p
1 g
F P
s
P
p
.002 w
.56013 .49672 m .52723 .51127 L p
.56003 .49651 L 1 g
F P
s
P
p
.002 w
.52488 .50045 m .52634 .48903 L .55989 .49623 L p
1 g
F P
s
P
p
.002 w
.55989 .49623 m .56079 .49642 L .56003 .49651 L p
1 g
F P
s
P
p
.002 w
.56003 .49651 m .52488 .50045 L p
.55989 .49623 L 1 g
F P
s
P
p
.56013 .49672 m .56008 .49662 L .55996 .49637 L 1 g
F
P
p
.56008 .49662 m .56003 .49652 L .55963 .4957 L 1 g
F
P
p
.56008 .49662 m .55963 .4957 L .55752 .49146 L 1 g
F
P
p
.002 w
.52634 .48903 m .53147 .47826 L .55963 .4957 L p
1 g
F P
s
P
p
.002 w
.55963 .4957 m .56079 .49642 L .55989 .49623 L p
1 g
F P
s
P
p
.002 w
.55989 .49623 m .52634 .48903 L p
.55963 .4957 L 1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.5331 .5203 m .52723 .51127 L .56013 .49672 L p
1 g
F P
s
P
p
.002 w
.56022 .49691 m .5331 .5203 L p
.56013 .49672 L 1 g
F P
s
P
p
.56022 .49691 m .56014 .49673 L .56003 .49652 L 1 g
F
P
p
.002 w
.56022 .49691 m .56079 .49642 L .56034 .49715 L p
1 g
F P
s
P
p
.56041 .4973 m .56034 .49715 L .56022 .49691 L 1 g
F
P
p
.56034 .49715 m .56014 .49673 L .56022 .49691 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54182 .52658 m .5331 .5203 L .56022 .49691 L p
1 g
F P
s
P
p
.002 w
.56034 .49715 m .54182 .52658 L p
.56022 .49691 L 1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55243 .52947 m .54182 .52658 L .56034 .49715 L p
1 g
F P
s
P
p
.002 w
.56034 .49715 m .56079 .49642 L .56051 .49752 L p
1 g
F P
s
P
p
.002 w
.56051 .49752 m .55243 .52947 L p
.56034 .49715 L 1 g
F P
s
P
p
.56051 .49752 m .56019 .49683 L .56014 .49673 L 1 g
F
P
p
.002 w
.56051 .49752 m .56079 .49642 L .56099 .49852 L p
1 g
F P
s
P
p
.56099 .49852 m .56068 .49786 L .56051 .49752 L 1 g
F
P
p
.56068 .49786 m .56019 .49683 L .56051 .49752 L 1 g
F
P
p
.002 w
.56379 .52868 m .55243 .52947 L .56051 .49752 L p
1 g
F P
s
P
p
.002 w
.56099 .49852 m .56379 .52868 L p
.56051 .49752 L 1 g
F P
s
P
p
.002 w
.55512 .48914 m .55856 .49356 L p
.54239 .47679 L 1 g
F P
s
P
p
.55034 .4845 m .55512 .48914 L .55041 .48457 L 1 g
F
P
p
.54174 .47608 m .55512 .48914 L .55034 .4845 L 1 g
F
P
p
.53571 .47368 m .54239 .47679 L .55856 .49356 L 1 g
F
P
p
.002 w
.5424 .4768 m .54239 .47679 L p
.55041 .48457 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.55034 .4845 L 1 g
F P
s
P
p
.55034 .4845 m .55041 .48457 L .54239 .47679 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53972 .46936 m .54727 .47906 L p
.54239 .47679 L 1 g
F P
s
P
p
.52214 .46667 m .54239 .47679 L .53857 .47501 L 1 g
F
P
p
.52214 .46667 m .54266 .47709 L .53514 .4734 L 1 g
F
P
p
.002 w
.53571 .47368 m .53736 .47191 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.53736 .47191 m .53972 .46936 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.54727 .47906 m .55512 .48914 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.55856 .49356 m .53972 .46936 L .54496 .46632 L p
1 g
F P
s
P
p
.002 w
.56099 .49852 m .56079 .49642 L p
.56566 .50847 L 1 g
F P
s
P
p
.002 w
.55856 .49356 m .56079 .49642 L p
.55933 .49509 L 1 g
F P
s
P
p
.002 w
.56079 .49642 m .53147 .47826 L .53571 .47368 L p
1 g
F P
s
P
p
.002 w
.56765 .52895 m .56654 .52734 L p
.56444 .53884 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56515 .50826 L p
.56753 .52367 L 1 g
F P
s
P
p
.002 w
.56761 .52715 m .56379 .52868 L p
.56584 .50656 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55752 .49146 L p
1 g
F P
s
P
p
.56576 .508 m .56713 .51061 L .55752 .49146 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5424 .4768 L p
1 g
F P
s
P
p
.55041 .48457 m .55834 .49233 L .5424 .4768 L 1 g
F
P
p
.002 w
.55751 .49146 m .55834 .49233 L p
.55041 .48457 L 1 g
F P
s
P
p
.002 w
.56379 .52868 m .56099 .49852 L p
.56566 .50847 L 1 g
F P
s
P
p
.5626 .50196 m .56576 .508 L .56019 .49683 L 1 g
F
P
p
.53571 .47368 m .55856 .49356 L .55933 .49509 L 1 g
F
P
p
.002 w
.54239 .47679 m .54266 .47709 L p
.53857 .47501 L 1 g
F P
s
P
p
.002 w
.53571 .47368 m .53147 .47826 L p
.52244 .46718 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46718 L p
1 g
F P
s
P
p
.002 w
.52244 .46718 m .52214 .46667 L p
.53514 .4734 L 1 g
F P
s
P
p
.53514 .4734 m .54302 .47747 L .52244 .46718 L 1 g
F
P
p
.5 .4634 m .52244 .46718 L .52044 .46689 L 1 g
F
P
p
.5 .4634 m .52249 .46724 L .51203 .46571 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.51213 .46573 m .50082 .4584 L p
.50985 .461 L 1 g
F P
s
P
p
.50985 .461 m .53952 .46957 L .52244 .46718 L 1 g
F
P
p
.50985 .461 m .52244 .46718 L .51213 .46573 L 1 g
F
P
p
.002 w
.53952 .46957 m .53571 .47368 L p
.52244 .46718 L 1 g
F P
s
P
p
.002 w
.54266 .47709 m .54302 .47747 L p
.53514 .4734 L 1 g
F P
s
P
p
.002 w
.52244 .46718 m .52249 .46724 L p
.52044 .46689 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53972 .46936 m .53952 .46957 L p
.50082 .4584 L 1 g
F P
s
P
p
.002 w
.51213 .46573 m .53147 .47826 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .4634 L p
.51203 .46571 L 1 g
F P
s
P
p
.51203 .46571 m .52282 .46778 L .5 .46395 L 1 g
F
P
p
.002 w
.50082 .4584 m .5075 .46273 L p
.5 .46395 L 1 g
F P
s
P
p
.47786 .46667 m .4989 .46413 L .48883 .46555 L 1 g
F
P
p
.4989 .46413 m .5 .464 L .49805 .46427 L 1 g
F
P
p
.4989 .46413 m .49805 .46427 L .48883 .46555 L 1 g
F
P
p
.002 w
.49805 .46427 m .49832 .46371 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.49832 .46371 m .50082 .4584 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.5075 .46273 m .51213 .46573 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52282 .46778 L p
.51203 .46571 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .464 L p
.4989 .46413 L 1 g
F P
s
P
p
.002 w
.49805 .46427 m .49076 .47974 L p
.48067 .46669 L 1 g
F P
s
P
p
.002 w
.5 .464 m .5 .46442 L p
.48883 .46555 L 1 g
F P
s
P
p
.002 w
.49076 .47974 m .46681 .4724 L p
.48067 .46669 L 1 g
F P
s
P
p
.002 w
.50082 .4584 m .49805 .46427 L p
.48067 .46669 L 1 g
F P
s
P
p
.49056 .46077 m .50082 .4584 L .48067 .46669 L 1 g
F
P
p
.47759 .46712 m .48067 .46669 L .46681 .4724 L 1 g
F
P
p
.49056 .46077 m .48067 .46669 L .47759 .46712 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46712 L p
1 g
F P
s
P
p
.48883 .46555 m .5 .46442 L .47759 .46712 L 1 g
F
P
p
.46807 .47178 m .46854 .47157 L .46681 .4724 L 1 g
F
P
p
.46807 .47178 m .46681 .4724 L .45764 .47675 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47746 .46733 L p
1 g
F P
s
P
p
.002 w
.47746 .46733 m .47718 .46778 L p
.46854 .47157 L 1 g
F P
s
P
p
.45826 .47608 m .47746 .46733 L .46854 .47157 L 1 g
F
P
p
.002 w
.45542 .46891 m .46325 .47131 L p
.45764 .47675 L 1 g
F P
s
P
p
.44339 .4905 m .45764 .47675 L .45589 .47845 L 1 g
F
P
p
.44339 .4905 m .45753 .47688 L .4498 .48436 L 1 g
F
P
p
.002 w
.45415 .48015 m .45436 .47832 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.45436 .47832 m .45542 .46891 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.46681 .4724 m .45542 .46891 L p
.49056 .46077 L 1 g
F P
s
P
p
.002 w
.46325 .47131 m .46681 .4724 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.46681 .4724 m .49076 .47974 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45764 .47675 L p
1 g
F P
s
P
p
.46854 .47157 m .47718 .46778 L .45764 .47675 L 1 g
F
P
p
.002 w
.45764 .47675 m .45753 .47688 L p
.45589 .47845 L 1 g
F P
s
P
p
.002 w
.45167 .50196 m .45415 .48015 L p
.49076 .47974 L 1 g
F P
s
P
p
.002 w
.45542 .46891 m .45415 .48015 L p
.44382 .49014 L 1 g
F P
s
P
p
.002 w
.45415 .48015 m .45167 .50196 L p
.44382 .49014 L 1 g
F P
s
P
p
.002 w
.45753 .47688 m .45698 .47747 L p
.4498 .48436 L 1 g
F P
s
P
p
.45264 .47113 m .45542 .46891 L .43793 .50094 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44273 .4912 L p
1 g
F P
s
P
p
.4498 .48436 m .45698 .47747 L .44273 .4912 L 1 g
F
P
p
.43833 .50013 m .43862 .49946 L .43793 .50094 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43414 .5091 L p
1 g
F P
s
P
p
.43862 .49946 m .44166 .49233 L .43414 .5091 L 1 g
F
P
p
.43272 .52843 m .43001 .51801 L .43414 .5091 L 1 g
F
P
p
.002 w
.43414 .5091 m .43287 .51061 L p
.43325 .52122 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43272 .52843 L p
1 g
F P
s
P
p
.43325 .52122 m .43287 .51061 L .43272 .52843 L 1 g
F
P
p
.002 w
.43272 .52843 m .43207 .52936 L p
.43423 .53427 L 1 g
F P
s
P
p
.002 w
.42694 .53905 m .41719 .4994 L .42534 .5 L p
1 g
F P
s
P
p
.43925 .54566 m .43207 .52936 L .43493 .53711 L 1 g
F
P
p
.002 w
.43507 .5375 m .45901 .53296 L p
.43856 .54696 L 1 g
F P
s
P
p
.002 w
.43207 .52936 m .43146 .53025 L p
.43493 .53711 L 1 g
F P
s
P
p
.002 w
.45167 .50196 m .45901 .53296 L .43507 .5375 L p
1 g
F P
s
P
p
.43308 .52984 m .45167 .50196 L .43507 .5375 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43856 .54696 L p
1 g
F P
s
P
p
.43493 .53711 m .43146 .53025 L .43856 .54696 L 1 g
F
P
p
.002 w
.44944 .57153 m .43518 .55094 L p
.45148 .56331 L 1 g
F P
s
P
p
.002 w
.43518 .55094 m .42694 .53905 L p
.45148 .56331 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45088 .56286 L p
1 g
F P
s
P
p
.44596 .55651 m .43743 .5491 L .45088 .56286 L 1 g
F
P
p
.45148 .56331 m .45042 .56226 L .45901 .53296 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46802 .57587 L p
1 g
F P
s
P
p
.002 w
.46802 .57587 m .46841 .57406 L p
.4608 .57039 L 1 g
F P
s
P
p
.4608 .57039 m .45002 .56518 L .46802 .57587 L 1 g
F
P
p
.002 w
.45088 .56286 m .45002 .56518 L p
.45829 .56848 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45901 .53296 m .47637 .55849 L .4573 .56773 L p
1 g
F P
s
P
p
.45148 .56331 m .45901 .53296 L .4573 .56773 L 1 g
F
P
p
.002 w
.4573 .56773 m .47637 .55849 L p
.4798 .58056 L 1 g
F P
s
P
p
.4594 .56893 m .45002 .56518 L .46841 .57406 L 1 g
F
P
p
.002 w
.46841 .57406 m .4678 .57686 L p
.48121 .57796 L 1 g
F P
s
P
p
.48908 .58036 m .47637 .55849 L .49596 .58097 L 1 g
F
P
p
.47931 .57738 m .47637 .55849 L .48908 .58036 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58036 L p
1 g
F P
s
P
p
.48121 .57796 m .4678 .57686 L .48908 .58036 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.47637 .55849 m .50159 .57595 L .49596 .58097 L p
1 g
F P
s
P
p
.002 w
.48908 .58036 m .48902 .58117 L p
.49297 .5807 L 1 g
F P
s
P
p
.002 w
.52039 .60322 m .48183 .59358 L .49596 .58097 L p
1 g
F P
s
P
p
.52039 .60322 m .49596 .58097 L .50488 .58072 L 1 g
F
P
p
.002 w
.48902 .58117 m .48889 .583 L p
.49954 .58087 L 1 g
F P
s
P
p
.002 w
.49596 .58097 m .50159 .57595 L p
.50488 .58072 L 1 g
F P
s
P
p
.002 w
.50159 .57595 m .5156 .57953 L p
.50488 .58072 L 1 g
F P
s
P
p
.002 w
.5156 .57953 m .5187 .58033 L p
.51093 .58055 L 1 g
F P
s
P
p
.50488 .58072 m .5156 .57953 L .51093 .58055 L 1 g
F
P
p
.002 w
.5187 .58033 m .53182 .58369 L p
.50488 .58072 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53201 .57597 L p
1 g
F P
s
P
p
.002 w
.53201 .57597 m .53168 .5745 L p
.52382 .57775 L 1 g
F P
s
P
p
.52382 .57775 m .51111 .583 L .53201 .57597 L 1 g
F
P
p
.002 w
.53168 .5745 m .53128 .57265 L p
.5214 .57772 L 1 g
F P
s
P
p
.5214 .57772 m .51111 .583 L .53168 .5745 L 1 g
F
P
p
.52906 .57532 m .52183 .55339 L .53648 .573 L 1 g
F
P
p
.53966 .56976 m .5322 .57686 L .54455 .56684 L 1 g
F
P
p
.53966 .56976 m .54455 .56684 L .5492 .56307 L 1 g
F
P
p
.002 w
.54264 .55888 m .55372 .55805 L p
.54764 .56413 L 1 g
F P
s
P
p
.54764 .56413 m .55372 .55805 L .5492 .56307 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56227 .54853 L p
1 g
F P
s
P
p
.002 w
.56227 .54853 m .56159 .54724 L p
.55685 .55457 L 1 g
F P
s
P
p
.55685 .55457 m .54998 .56518 L .56227 .54853 L 1 g
F
P
p
.002 w
.56159 .54724 m .56075 .54566 L p
.55453 .55693 L 1 g
F P
s
P
p
.56082 .5483 m .55243 .52947 L .56328 .54229 L 1 g
F
P
p
.56159 .54724 m .56328 .54229 L .5643 .54351 L 1 g
F
P
p
.56082 .5483 m .56328 .54229 L .56159 .54724 L 1 g
F
P
p
.56444 .53884 m .56442 .53892 L .56765 .52895 L 1 g
F
P
p
.56442 .53892 m .56257 .5491 L .56715 .53092 L 1 g
F
P
p
.56442 .53892 m .56715 .53092 L .56765 .52895 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56777 .52912 L p
1 g
F P
s
P
p
.002 w
.56777 .52912 m .56765 .52895 L p
.56715 .53092 L 1 g
F P
s
P
p
.56715 .53092 m .56257 .5491 L .56777 .52912 L 1 g
F
P
p
.002 w
.56379 .52868 m .56761 .52715 L p
.56684 .53144 L 1 g
F P
s
P
p
.002 w
.56761 .52715 m .56833 .52687 L p
.56765 .52895 L 1 g
F P
s
P
p
.56684 .53144 m .56761 .52715 L .56765 .52895 L 1 g
F
P
p
.002 w
.56854 .53025 m .56727 .51258 L p
.56753 .52367 L 1 g
F P
s
P
p
.002 w
.56727 .51258 m .56713 .51061 L p
.56753 .52367 L 1 g
F P
s
P
p
.002 w
.56608 .50936 m .56713 .51061 L p
.5626 .50196 L 1 g
F P
s
P
p
.56703 .52046 m .56761 .52715 L .56753 .52367 L 1 g
F
P
p
.002 w
.56765 .52895 m .56854 .53025 L p
.56753 .52367 L 1 g
F P
s
P
p
.002 w
.56417 .53967 m .56379 .52868 L p
.56684 .53144 L 1 g
F P
s
P
p
.56442 .53892 m .56417 .53967 L .56257 .5491 L 1 g
F
P
p
.002 w
.56159 .54724 m .56167 .54739 L p
.56417 .53967 L 1 g
F P
s
P
p
.002 w
.56167 .54739 m .56257 .5491 L p
.56417 .53967 L 1 g
F P
s
P
p
.56444 .53884 m .56417 .53967 L .56442 .53892 L 1 g
F
P
p
.002 w
.54264 .55888 m .55243 .52947 L p
.56082 .5483 L 1 g
F P
s
P
p
.002 w
.55372 .55805 m .54264 .55888 L p
.56082 .5483 L 1 g
F P
s
P
p
.55423 .55748 m .55372 .55805 L .54998 .56518 L 1 g
F
P
p
.002 w
.5492 .56307 m .54949 .56385 L p
.55372 .55805 L 1 g
F P
s
P
p
.002 w
.54949 .56385 m .54998 .56518 L p
.55372 .55805 L 1 g
F P
s
P
p
.55453 .55693 m .55372 .55805 L .55423 .55748 L 1 g
F
P
p
.002 w
.53728 .57117 m .54264 .55888 L p
.54764 .56413 L 1 g
F P
s
P
p
.53966 .56976 m .53728 .57117 L .5322 .57686 L 1 g
F
P
p
.002 w
.53168 .5745 m .53177 .57491 L p
.53728 .57117 L 1 g
F P
s
P
p
.002 w
.53177 .57491 m .5322 .57686 L p
.53728 .57117 L 1 g
F P
s
P
p
.54039 .56906 m .53728 .57117 L .53966 .56976 L 1 g
F
P
p
.002 w
.50159 .57595 m .52183 .55339 L p
.52906 .57532 L 1 g
F P
s
P
p
.002 w
.5156 .57953 m .50159 .57595 L p
.52906 .57532 L 1 g
F P
s
P
p
.51953 .57868 m .5156 .57953 L .51111 .583 L 1 g
F
P
p
.002 w
.51093 .58055 m .51097 .58098 L p
.5156 .57953 L 1 g
F P
s
P
p
.002 w
.51097 .58098 m .51111 .583 L p
.5156 .57953 L 1 g
F P
s
P
p
.5214 .57772 m .5156 .57953 L .51953 .57868 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58055 L p
1 g
F P
s
P
p
.49954 .58087 m .48889 .583 L .51093 .58055 L 1 g
F
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.6687 .44356 m .65525 .40658 L .66755 .38549 L p
1 g
F P
s
P
p
.002 w
.63747 .35007 m .66755 .38549 L .65525 .40658 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53446 .46787 L
s
P
p
.002 w
.53059 .26929 m .46883 .28104 L .45718 .26378 L p
1 g
F P
s
P
p
.002 w
.39838 .29675 m .45718 .26378 L .46883 .28104 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.36409 .43161 m .3587 .48835 L .33653 .48039 L p
1 g
F P
s
P
p
.002 w
.33653 .48039 m .34207 .41918 L .36409 .43161 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.41236 .31281 m .36829 .36088 L .35257 .34677 L p
1 g
F P
s
P
p
.002 w
.35257 .34677 m .39838 .29675 L .41236 .31281 L p
1 g
F P
s
P
p
.002 w
.64898 .48953 m .64861 .45793 L .6687 .44356 L p
1 g
F P
s
P
p
.002 w
.65525 .40658 m .6687 .44356 L .64861 .45793 L p
1 g
F P
s
P
p
.002 w
.38585 .49478 m .39777 .54173 L .37244 .54105 L p
1 g
F P
s
P
p
.002 w
.37244 .54105 m .3587 .48835 L .38585 .49478 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.58596 .54867 m .604 .53417 L .6203 .54785 L p
1 g
F P
s
P
p
.002 w
.6203 .54785 m .59433 .56875 L .58596 .54867 L p
1 g
F P
s
P
p
.002 w
.63917 .52054 m .6203 .54785 L .604 .53417 L p
1 g
F P
s
P
p
.002 w
.46883 .28104 m .41236 .31281 L .39838 .29675 L p
1 g
F P
s
P
p
.002 w
.42694 .53905 m .44944 .57153 L .42473 .58004 L p
1 g
F P
s
P
p
.002 w
.42473 .58004 m .39777 .54173 L .42694 .53905 L p
1 g
F P
s
P
p
.002 w
.56478 .55722 m .58596 .54867 L .59433 .56875 L p
1 g
F P
s
P
p
.002 w
.59433 .56875 m .56382 .58114 L .56478 .55722 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.604 .53417 m .61706 .51521 L .63917 .52054 L p
1 g
F P
s
P
p
.002 w
.64898 .48953 m .63917 .52054 L .61706 .51521 L p
1 g
F P
s
P
p
.002 w
.59424 .30055 m .53907 .29233 L .53059 .26929 L p
1 g
F P
s
P
p
.002 w
.46883 .28104 m .53059 .26929 L .53907 .29233 L p
1 g
F P
s
P
p
.002 w
.63747 .35007 m .59571 .3273 L .59424 .30055 L p
1 g
F P
s
P
p
.002 w
.53907 .29233 m .59424 .30055 L .59571 .3273 L p
1 g
F P
s
P
p
.002 w
.61706 .51521 m .62378 .49371 L .64898 .48953 L p
1 g
F P
s
P
p
.002 w
.64861 .45793 m .64898 .48953 L .62378 .49371 L p
1 g
F P
s
P
p
.002 w
.65525 .40658 m .62965 .37685 L .63747 .35007 L p
1 g
F P
s
P
p
.002 w
.59571 .3273 m .63747 .35007 L .62965 .37685 L p
1 g
F P
s
P
p
.002 w
.38857 .37759 m .36409 .43161 L .34207 .41918 L p
1 g
F P
s
P
p
.002 w
.34207 .41918 m .36829 .36088 L .38857 .37759 L p
1 g
F P
s
P
p
.002 w
.64861 .45793 m .63787 .42901 L .65525 .40658 L p
1 g
F P
s
P
p
.002 w
.62965 .37685 m .65525 .40658 L .63787 .42901 L p
1 g
F P
s
P
p
.002 w
.53907 .29233 m .48183 .30345 L .46883 .28104 L p
1 g
F P
s
P
p
.002 w
.41236 .31281 m .46883 .28104 L .48183 .30345 L p
1 g
F P
s
P
p
.002 w
.39091 .44435 m .38585 .49478 L .3587 .48835 L p
1 g
F P
s
P
p
.002 w
.3587 .48835 m .36409 .43161 L .39091 .44435 L p
1 g
F P
s
P
p
.002 w
.62378 .49371 m .6234 .47188 L .64861 .45793 L p
1 g
F P
s
P
p
.002 w
.63787 .42901 m .64861 .45793 L .6234 .47188 L p
1 g
F P
s
P
p
.002 w
.41719 .4994 m .42694 .53905 L .39777 .54173 L p
1 g
F P
s
P
p
.002 w
.39777 .54173 m .38585 .49478 L .41719 .4994 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42948 .33302 m .38857 .37759 L .36829 .36088 L p
1 g
F P
s
P
p
.002 w
.36829 .36088 m .41236 .31281 L .42948 .33302 L p
1 g
F P
s
P
p
.002 w
.57468 .52432 m .58397 .51687 L .604 .53417 L p
1 g
F P
s
P
p
.002 w
.604 .53417 m .58596 .54867 L .57468 .52432 L p
1 g
F P
s
P
p
.002 w
.61706 .51521 m .604 .53417 L .58397 .51687 L p
1 g
F P
s
P
p
.002 w
.48183 .30345 m .42948 .33302 L .41236 .31281 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.5046 .54124 m .52183 .55339 L .50159 .57595 L p
1 g
F P
s
P
p
.002 w
.50159 .57595 m .47637 .55849 L .5046 .54124 L p
1 g
F P
s
P
p
.002 w
.58397 .51687 m .59067 .50711 L .61706 .51521 L p
1 g
F P
s
P
p
.002 w
.62378 .49371 m .61706 .51521 L .59067 .50711 L p
1 g
F P
s
P
p
.002 w
.59571 .3273 m .54661 .32029 L .53907 .29233 L p
1 g
F P
s
P
p
.002 w
.48183 .30345 m .53907 .29233 L .54661 .32029 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.62965 .37685 m .59429 .35793 L .59571 .3273 L p
1 g
F P
s
P
p
.002 w
.54661 .32029 m .59571 .3273 L .59429 .35793 L p
1 g
F P
s
P
p
.002 w
.63787 .42901 m .61765 .40594 L .62965 .37685 L p
1 g
F P
s
P
p
.002 w
.59429 .35793 m .62965 .37685 L .61765 .40594 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59067 .50711 m .59407 .49606 L .62378 .49371 L p
1 g
F P
s
P
p
.002 w
.6234 .47188 m .62378 .49371 L .59407 .49606 L p
1 g
F P
s
P
p
.002 w
.6234 .47188 m .61584 .45204 L .63787 .42901 L p
1 g
F P
s
P
p
.002 w
.61765 .40594 m .63787 .42901 L .61584 .45204 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41284 .39639 m .39091 .44435 L .36409 .43161 L p
1 g
F P
s
P
p
.002 w
.36409 .43161 m .38857 .37759 L .41284 .39639 L p
1 g
F P
s
P
p
.002 w
.54182 .52658 m .55243 .52947 L .54264 .55888 L p
1 g
F P
s
P
p
.002 w
.54264 .55888 m .52183 .55339 L .54182 .52658 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42172 .45695 m .41719 .4994 L .38585 .49478 L p
1 g
F P
s
P
p
.002 w
.38585 .49478 m .39091 .44435 L .42172 .45695 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59407 .49606 m .59379 .48489 L .6234 .47188 L p
1 g
F P
s
P
p
.002 w
.61584 .45204 m .6234 .47188 L .59379 .48489 L p
1 g
F P
s
P
p
.002 w
.49287 .5236 m .5046 .54124 L .47637 .55849 L p
1 g
F P
s
P
p
.002 w
.47637 .55849 m .45901 .53296 L .49287 .5236 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.54661 .32029 m .49575 .3304 L .48183 .30345 L p
1 g
F P
s
P
p
.002 w
.42948 .33302 m .48183 .30345 L .49575 .3304 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5331 .5203 m .54182 .52658 L .52183 .55339 L p
1 g
F P
s
P
p
.002 w
.52183 .55339 m .5046 .54124 L .5331 .5203 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44925 .35678 m .41284 .39639 L .38857 .37759 L p
1 g
F P
s
P
p
.002 w
.38857 .37759 m .42948 .33302 L .44925 .35678 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58397 .51687 m .57468 .52432 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.59067 .50711 m .58397 .51687 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.49575 .3304 m .44925 .35678 L .42948 .33302 L p
1 g
F P
s
P
p
.002 w
.61584 .45204 m .6018 .43633 L .61765 .40594 L p
1 g
F P
s
P
p
.002 w
.58992 .39141 m .61765 .40594 L .6018 .43633 L p
1 g
F P
s
P
p
.002 w
.61765 .40594 m .58992 .39141 L .59429 .35793 L p
1 g
F P
s
P
p
.002 w
.59429 .35793 m .55288 .35231 L .54661 .32029 L p
1 g
F P
s
P
p
.002 w
.49575 .3304 m .54661 .32029 L .55288 .35231 L p
1 g
F P
s
P
p
.002 w
.55288 .35231 m .59429 .35793 L .58992 .39141 L p
1 g
F P
s
P
p
.002 w
.59407 .49606 m .59067 .50711 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.59379 .48489 m .58985 .4748 L .61584 .45204 L p
1 g
F P
s
P
p
.002 w
.6018 .43633 m .61584 .45204 L .58985 .4748 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59379 .48489 m .59407 .49606 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.52723 .51127 m .5331 .5203 L .5046 .54124 L p
1 g
F P
s
P
p
.002 w
.5046 .54124 m .49287 .5236 L .52723 .51127 L p
1 g
F P
s
P
p
.002 w
.48803 .50233 m .49287 .5236 L .45901 .53296 L p
1 g
F P
s
P
p
.002 w
.45901 .53296 m .45167 .50196 L .48803 .50233 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.44033 .41664 m .42172 .45695 L .39091 .44435 L p
1 g
F P
s
P
p
.002 w
.39091 .44435 m .41284 .39639 L .44033 .41664 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.58985 .4748 m .59379 .48489 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.41719 .4994 m .42172 .45695 L .45542 .46891 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58985 .4748 m .58262 .46688 L .6018 .43633 L p
1 g
F P
s
P
p
.002 w
.5827 .42655 m .6018 .43633 L .58262 .46688 L p
1 g
F P
s
P
p
.002 w
.6018 .43633 m .5827 .42655 L .58992 .39141 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.55288 .35231 m .51009 .36103 L .49575 .3304 L p
1 g
F P
s
P
p
.002 w
.44925 .35678 m .49575 .3304 L .51009 .36103 L p
1 g
F P
s
P
p
.002 w
.58262 .46688 m .58985 .4748 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5576 .38728 m .58992 .39141 L .5827 .42655 L p
1 g
F P
s
P
p
.002 w
.58992 .39141 m .5576 .38728 L .55288 .35231 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.51009 .36103 m .55288 .35231 L .5576 .38728 L p
1 g
F P
s
P
p
.002 w
.471 .38333 m .44033 .41664 L .41284 .39639 L p
1 g
F P
s
P
p
.002 w
.41284 .39639 m .44925 .35678 L .471 .38333 L p
1 g
F P
s
P
p
.002 w
.52488 .50045 m .52723 .51127 L .49287 .5236 L p
1 g
F P
s
P
p
.002 w
.49287 .5236 m .48803 .50233 L .52488 .50045 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57286 .46201 m .58262 .46688 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.58262 .46688 m .57286 .46201 L .5827 .42655 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56163 .46076 m .57286 .46201 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.55016 .4633 m .56163 .46076 L .56079 .49642 L closepath p
1 g
F P
s
P
p
.002 w
.51009 .36103 m .471 .38333 L .44925 .35678 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.49076 .47974 m .48803 .50233 L .45167 .50196 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56056 .42391 m .5827 .42655 L .57286 .46201 L p
1 g
F P
s
P
p
.002 w
.5827 .42655 m .56056 .42391 L .5576 .38728 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.47004 .43758 m .45542 .46891 L .42172 .45695 L p
1 g
F P
s
P
p
.002 w
.42172 .45695 m .44033 .41664 L .47004 .43758 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57286 .46201 m .56163 .46076 L .56056 .42391 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52634 .48903 m .52488 .50045 L .48803 .50233 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.48803 .50233 m .49076 .47974 L .52634 .48903 L p
1 g
F P
s
P
p
.002 w
.52431 .39425 m .5576 .38728 L .56056 .42391 L p
1 g
F P
s
P
p
.002 w
.5576 .38728 m .52431 .39425 L .51009 .36103 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.471 .38333 m .51009 .36103 L .52431 .39425 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.56163 .46076 m .55016 .4633 L .53784 .4288 L p
1 g
F P
s
P
p
.002 w
.53784 .4288 m .56056 .42391 L .56163 .46076 L p
1 g
F P
s
P
p
.002 w
.53147 .47826 m .52634 .48903 L .49076 .47974 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.49393 .41168 m .47004 .43758 L .44033 .41664 L p
1 g
F P
s
P
p
.002 w
.44033 .41664 m .471 .38333 L .49393 .41168 L p
1 g
F P
s
P
p
.002 w
.56056 .42391 m .53784 .4288 L .52431 .39425 L p
1 g
F P
s
P
p
.002 w
.55016 .4633 m .53972 .46936 L .51714 .44074 L p
1 g
F P
s
P
p
.002 w
.51714 .44074 m .53784 .4288 L .55016 .4633 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.45542 .46891 m .47004 .43758 L .50082 .4584 L p
1 g
F P
s
P
p
.002 w
.50082 .4584 m .51714 .44074 L .53972 .46936 L p
1 g
F P
s
P
p
.002 w
.52431 .39425 m .49393 .41168 L .471 .38333 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49393 .41168 m .52431 .39425 L .53784 .4288 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53784 .4288 m .51714 .44074 L .49393 .41168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51714 .44074 m .50082 .4584 L .47004 .43758 L p
1 g
F P
s
P
p
.002 w
.47004 .43758 m .49393 .41168 L .51714 .44074 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.58009 .51734 m
.59788 .53664 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .55223 .72394 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .59788 .53664 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.314729)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.314729)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48546 .45675 m .51556 .43894 L .49775 .4166 L p
1 g
F P
s
P
p
.002 w
.49775 .4166 m .47442 .43037 L .48546 .45675 L p
1 g
F P
s
P
p
.002 w
.51625 .39698 m .49775 .4166 L .51556 .43894 L p
1 g
F P
s
P
p
.002 w
.47442 .43037 m .49775 .4166 L .47995 .39453 L p
1 g
F P
s
P
p
.002 w
.49775 .4166 m .51625 .39698 L .49257 .38108 L p
1 g
F P
s
P
p
.002 w
.49257 .38108 m .47995 .39453 L .49775 .4166 L p
1 g
F P
s
P
p
.002 w
.49689 .48261 m .53305 .46117 L .51556 .43894 L p
1 g
F P
s
P
p
.002 w
.51556 .43894 m .48546 .45675 L .49689 .48261 L p
1 g
F P
s
P
p
.002 w
.53951 .41367 m .51556 .43894 L .53305 .46117 L p
1 g
F P
s
P
p
.002 w
.51556 .43894 m .53951 .41367 L .51625 .39698 L p
1 g
F P
s
P
p
.002 w
.4521 .46536 m .48546 .45675 L .47442 .43037 L p
1 g
F P
s
P
p
.002 w
.47442 .43037 m .44857 .43692 L .4521 .46536 L p
1 g
F P
s
P
p
.002 w
.44857 .43692 m .47442 .43037 L .46398 .40393 L p
1 g
F P
s
P
p
.002 w
.47995 .39453 m .46398 .40393 L .47442 .43037 L p
1 g
F P
s
P
p
.002 w
.45681 .49312 m .49689 .48261 L .48546 .45675 L p
1 g
F P
s
P
p
.002 w
.48546 .45675 m .4521 .46536 L .45681 .49312 L p
1 g
F P
s
P
p
.002 w
.52805 .37344 m .51625 .39698 L .53951 .41367 L p
1 g
F P
s
P
p
.002 w
.51625 .39698 m .52805 .37344 L .50053 .36495 L p
1 g
F P
s
P
p
.002 w
.50053 .36495 m .49257 .38108 L .51625 .39698 L p
1 g
F P
s
P
p
.002 w
.46398 .40393 m .47995 .39453 L .46247 .37313 L p
1 g
F P
s
P
p
.002 w
.47995 .39453 m .49257 .38108 L .46889 .36626 L p
1 g
F P
s
P
p
.002 w
.46889 .36626 m .46247 .37313 L .47995 .39453 L p
1 g
F P
s
P
p
.002 w
.53305 .46117 m .56192 .43086 L .53951 .41367 L p
1 g
F P
s
P
p
.002 w
.55493 .38333 m .53951 .41367 L .56192 .43086 L p
1 g
F P
s
P
p
.002 w
.53951 .41367 m .55493 .38333 L .52805 .37344 L p
1 g
F P
s
P
p
.002 w
.46398 .40393 m .44629 .40834 L .44857 .43692 L p
1 g
F P
s
P
p
.002 w
.44629 .40834 m .46398 .40393 L .45433 .37792 L p
1 g
F P
s
P
p
.002 w
.46247 .37313 m .45433 .37792 L .46398 .40393 L p
1 g
F P
s
P
p
.002 w
.50852 .50746 m .54991 .48286 L .53305 .46117 L p
1 g
F P
s
P
p
.002 w
.53305 .46117 m .49689 .48261 L .50852 .50746 L p
1 g
F P
s
P
p
.002 w
.56192 .43086 m .53305 .46117 L .54991 .48286 L p
1 g
F P
s
P
p
.002 w
.49257 .38108 m .50053 .36495 L .4729 .35803 L p
1 g
F P
s
P
p
.002 w
.4729 .35803 m .46889 .36626 L .49257 .38108 L p
1 g
F P
s
P
p
.002 w
.4187 .46377 m .4521 .46536 L .44857 .43692 L p
1 g
F P
s
P
p
.002 w
.44857 .43692 m .42276 .4355 L .4187 .46377 L p
1 g
F P
s
P
p
.002 w
.42276 .4355 m .44857 .43692 L .44629 .40834 L p
1 g
F P
s
P
p
.002 w
.46265 .51969 m .50852 .50746 L .49689 .48261 L p
1 g
F P
s
P
p
.002 w
.49689 .48261 m .45681 .49312 L .46265 .51969 L p
1 g
F P
s
P
p
.002 w
.44629 .40834 m .42869 .40724 L .42276 .4355 L p
1 g
F P
s
P
p
.002 w
.45433 .37792 m .44531 .38013 L .44629 .40834 L p
1 g
F P
s
P
p
.002 w
.42869 .40724 m .44629 .40834 L .44531 .38013 L p
1 g
F P
s
P
p
.002 w
.4166 .4915 m .45681 .49312 L .4521 .46536 L p
1 g
F P
s
P
p
.002 w
.4521 .46536 m .4187 .46377 L .4166 .4915 L p
1 g
F P
s
P
p
.002 w
.54991 .48286 m .58306 .44822 L .56192 .43086 L p
1 g
F P
s
P
p
.002 w
.58068 .39446 m .56192 .43086 L .58306 .44822 L p
1 g
F P
s
P
p
.002 w
.56192 .43086 m .58068 .39446 L .55493 .38333 L p
1 g
F P
s
P
p
.002 w
.53184 .3483 m .52805 .37344 L .55493 .38333 L p
1 g
F P
s
P
p
.002 w
.52805 .37344 m .53184 .3483 L .50297 .34779 L p
1 g
F P
s
P
p
.002 w
.50297 .34779 m .50053 .36495 L .52805 .37344 L p
1 g
F P
s
P
p
.002 w
.50053 .36495 m .50297 .34779 L .47406 .3493 L p
1 g
F P
s
P
p
.002 w
.47406 .3493 m .4729 .35803 L .50053 .36495 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .45433 .37792 L .46247 .37313 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .46247 .37313 L .46889 .36626 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .44531 .38013 L .45433 .37792 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .46889 .36626 L .4729 .35803 L closepath p
1 g
F P
s
P
p
.002 w
.52013 .53082 m .56582 .50362 L .54991 .48286 L p
1 g
F P
s
P
p
.002 w
.54991 .48286 m .50852 .50746 L .52013 .53082 L p
1 g
F P
s
P
p
.002 w
.58306 .44822 m .54991 .48286 L .56582 .50362 L p
1 g
F P
s
P
p
.002 w
.56011 .35083 m .55493 .38333 L .58068 .39446 L p
1 g
F P
s
P
p
.002 w
.55493 .38333 m .56011 .35083 L .53184 .3483 L p
1 g
F P
s
P
p
.002 w
.44531 .38013 m .43636 .3795 L .42869 .40724 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .43636 .3795 L .44531 .38013 L closepath p
1 g
F P
s
P
p
.002 w
.39965 .4261 m .42276 .4355 L .42869 .40724 L p
1 g
F P
s
P
p
.002 w
.42869 .40724 m .41301 .40068 L .39965 .4261 L p
1 g
F P
s
P
p
.002 w
.41301 .40068 m .42869 .40724 L .43636 .3795 L p
1 g
F P
s
P
p
.002 w
.41655 .51816 m .46265 .51969 L .45681 .49312 L p
1 g
F P
s
P
p
.002 w
.45681 .49312 m .4166 .4915 L .41655 .51816 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .4729 .35803 L .47406 .3493 L closepath p
1 g
F P
s
P
p
.002 w
.38864 .45189 m .4187 .46377 L .42276 .4355 L p
1 g
F P
s
P
p
.002 w
.42276 .4355 m .39965 .4261 L .38864 .45189 L p
1 g
F P
s
P
p
.002 w
.46952 .54453 m .52013 .53082 L .50852 .50746 L p
1 g
F P
s
P
p
.002 w
.50852 .50746 m .46265 .51969 L .46952 .54453 L p
1 g
F P
s
P
p
.002 w
.43636 .3795 m .42845 .3761 L .41301 .40068 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .42845 .3761 L .43636 .3795 L closepath p
1 g
F P
s
P
p
.002 w
.49953 .33138 m .50297 .34779 L .53184 .3483 L p
1 g
F P
s
P
p
.002 w
.50297 .34779 m .49953 .33138 L .47223 .34101 L p
1 g
F P
s
P
p
.002 w
.47223 .34101 m .47406 .3493 L .50297 .34779 L p
1 g
F P
s
P
p
.002 w
.56582 .50362 m .60252 .46544 L .58306 .44822 L p
1 g
F P
s
P
p
.002 w
.60478 .40663 m .58306 .44822 L .60252 .46544 L p
1 g
F P
s
P
p
.002 w
.58306 .44822 m .60478 .40663 L .58068 .39446 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .47406 .3493 L .47223 .34101 L closepath p
1 g
F P
s
P
p
.002 w
.38024 .47753 m .4166 .4915 L .4187 .46377 L p
1 g
F P
s
P
p
.002 w
.4187 .46377 m .38864 .45189 L .38024 .47753 L p
1 g
F P
s
P
p
.002 w
.52705 .32412 m .53184 .3483 L .56011 .35083 L p
1 g
F P
s
P
p
.002 w
.53184 .3483 m .52705 .32412 L .49953 .33138 L p
1 g
F P
s
P
p
.002 w
.58725 .35537 m .58068 .39446 L .60478 .40663 L p
1 g
F P
s
P
p
.002 w
.58068 .39446 m .58725 .35537 L .56011 .35083 L p
1 g
F P
s
P
p
.002 w
.40096 .38926 m .41301 .40068 L .42845 .3761 L p
1 g
F P
s
P
p
.002 w
.42845 .3761 m .42241 .37025 L .40096 .38926 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .42241 .37025 L .42845 .3761 L closepath p
1 g
F P
s
P
p
.002 w
.38173 .40951 m .39965 .4261 L .41301 .40068 L p
1 g
F P
s
P
p
.002 w
.41301 .40068 m .40096 .38926 L .38173 .40951 L p
1 g
F P
s
P
p
.002 w
.46757 .33404 m .47223 .34101 L .49953 .33138 L p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .47223 .34101 L .46757 .33404 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .41843 .35388 L .41894 .36257 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .41894 .36257 L .42241 .37025 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .46757 .33404 L .46057 .32918 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .46057 .32918 L .45197 .32697 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .45197 .32697 L .44271 .32769 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .44271 .32769 L .43382 .33126 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .43382 .33126 L .4263 .3373 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .4263 .3373 L .42097 .34514 L closepath p
1 g
F P
s
P
p
.002 w
.44566 .35282 m .42097 .34514 L .41843 .35388 L closepath p
1 g
F P
s
P
p
.002 w
.41859 .54316 m .46952 .54453 L .46265 .51969 L p
1 g
F P
s
P
p
.002 w
.46265 .51969 m .41655 .51816 L .41859 .54316 L p
1 g
F P
s
P
p
.002 w
.39391 .37413 m .40096 .38926 L .42241 .37025 L p
1 g
F P
s
P
p
.002 w
.42241 .37025 m .41894 .36257 L .39391 .37413 L p
1 g
F P
s
P
p
.002 w
.53149 .5522 m .58044 .52301 L .56582 .50362 L p
1 g
F P
s
P
p
.002 w
.56582 .50362 m .52013 .53082 L .53149 .5522 L p
1 g
F P
s
P
p
.002 w
.60252 .46544 m .56582 .50362 L .58044 .52301 L p
1 g
F P
s
P
p
.002 w
.49048 .31749 m .49953 .33138 L .52705 .32412 L p
1 g
F P
s
P
p
.002 w
.49953 .33138 m .49048 .31749 L .46757 .33404 L p
1 g
F P
s
P
p
.002 w
.55424 .31943 m .56011 .35083 L .58725 .35537 L p
1 g
F P
s
P
p
.002 w
.56011 .35083 m .55424 .31943 L .52705 .32412 L p
1 g
F P
s
P
p
.002 w
.36516 .43061 m .38864 .45189 L .39965 .4261 L p
1 g
F P
s
P
p
.002 w
.39965 .4261 m .38173 .40951 L .36516 .43061 L p
1 g
F P
s
P
p
.002 w
.46057 .32918 m .46757 .33404 L .49048 .31749 L p
1 g
F P
s
P
p
.002 w
.47732 .56709 m .53149 .5522 L .52013 .53082 L p
1 g
F P
s
P
p
.002 w
.52013 .53082 m .46952 .54453 L .47732 .56709 L p
1 g
F P
s
P
p
.002 w
.37471 .5025 m .41655 .51816 L .4166 .4915 L p
1 g
F P
s
P
p
.002 w
.4166 .4915 m .38024 .47753 L .37471 .5025 L p
1 g
F P
s
P
p
.002 w
.39275 .35688 m .39391 .37413 L .41894 .36257 L p
1 g
F P
s
P
p
.002 w
.41894 .36257 m .41843 .35388 L .39275 .35688 L p
1 g
F P
s
P
p
.002 w
.3711 .38731 m .38173 .40951 L .40096 .38926 L p
1 g
F P
s
P
p
.002 w
.40096 .38926 m .39391 .37413 L .3711 .38731 L p
1 g
F P
s
P
p
.002 w
.60252 .46544 m .62674 .41963 L .60478 .40663 L p
1 g
F P
s
P
p
.002 w
.61268 .36187 m .60478 .40663 L .62674 .41963 L p
1 g
F P
s
P
p
.002 w
.60478 .40663 m .61268 .36187 L .58725 .35537 L p
1 g
F P
s
P
p
.002 w
.58044 .52301 m .61985 .48219 L .60252 .46544 L p
1 g
F P
s
P
p
.002 w
.62674 .41963 m .60252 .46544 L .61985 .48219 L p
1 g
F P
s
P
p
.002 w
.49048 .31749 m .47669 .3077 L .46057 .32918 L p
1 g
F P
s
P
p
.002 w
.45197 .32697 m .46057 .32918 L .47669 .3077 L p
1 g
F P
s
P
p
.002 w
.51395 .30353 m .52705 .32412 L .55424 .31943 L p
1 g
F P
s
P
p
.002 w
.52705 .32412 m .51395 .30353 L .49048 .31749 L p
1 g
F P
s
P
p
.002 w
.3977 .33942 m .39275 .35688 L .41843 .35388 L p
1 g
F P
s
P
p
.002 w
.41843 .35388 m .42097 .34514 L .3977 .33942 L p
1 g
F P
s
P
p
.002 w
.35166 .45215 m .38024 .47753 L .38864 .45189 L p
1 g
F P
s
P
p
.002 w
.38864 .45189 m .36516 .43061 L .35166 .45215 L p
1 g
F P
s
P
p
.002 w
.47669 .3077 m .49048 .31749 L .51395 .30353 L p
1 g
F P
s
P
p
.002 w
.47669 .3077 m .45962 .30318 L .45197 .32697 L p
1 g
F P
s
P
p
.002 w
.44271 .32769 m .45197 .32697 L .45962 .30318 L p
1 g
F P
s
P
p
.002 w
.58054 .31745 m .58725 .35537 L .61268 .36187 L p
1 g
F P
s
P
p
.002 w
.58725 .35537 m .58054 .31745 L .55424 .31943 L p
1 g
F P
s
P
p
.002 w
.40829 .32373 m .3977 .33942 L .42097 .34514 L p
1 g
F P
s
P
p
.002 w
.42097 .34514 m .4263 .3373 L .40829 .32373 L p
1 g
F P
s
P
p
.002 w
.45962 .30318 m .44113 .30452 L .44271 .32769 L p
1 g
F P
s
P
p
.002 w
.43382 .33126 m .44271 .32769 L .44113 .30452 L p
1 g
F P
s
P
p
.002 w
.42276 .56595 m .47732 .56709 L .46952 .54453 L p
1 g
F P
s
P
p
.002 w
.46952 .54453 m .41859 .54316 L .42276 .56595 L p
1 g
F P
s
P
p
.002 w
.42334 .31163 m .40829 .32373 L .4263 .3373 L p
1 g
F P
s
P
p
.002 w
.4263 .3373 m .43382 .33126 L .42334 .31163 L p
1 g
F P
s
P
p
.002 w
.44113 .30452 m .42334 .31163 L .43382 .33126 L p
1 g
F P
s
P
p
.002 w
.35106 .40188 m .36516 .43061 L .38173 .40951 L p
1 g
F P
s
P
p
.002 w
.38173 .40951 m .3711 .38731 L .35106 .40188 L p
1 g
F P
s
P
p
.002 w
.36917 .36181 m .3711 .38731 L .39391 .37413 L p
1 g
F P
s
P
p
.002 w
.39391 .37413 m .39275 .35688 L .36917 .36181 L p
1 g
F P
s
P
p
.002 w
.37224 .52625 m .41859 .54316 L .41655 .51816 L p
1 g
F P
s
P
p
.002 w
.41655 .51816 m .37471 .5025 L .37224 .52625 L p
1 g
F P
s
P
p
.002 w
.54238 .5711 m .59343 .5406 L .58044 .52301 L p
1 g
F P
s
P
p
.002 w
.58044 .52301 m .53149 .5522 L .54238 .5711 L p
1 g
F P
s
P
p
.002 w
.61985 .48219 m .58044 .52301 L .59343 .5406 L p
1 g
F P
s
P
p
.002 w
.53751 .29251 m .55424 .31943 L .58054 .31745 L p
1 g
F P
s
P
p
.002 w
.55424 .31943 m .53751 .29251 L .51395 .30353 L p
1 g
F P
s
P
p
.002 w
.51395 .30353 m .49374 .28888 L .47669 .3077 L p
1 g
F P
s
P
p
.002 w
.45962 .30318 m .47669 .3077 L .49374 .28888 L p
1 g
F P
s
P
p
.002 w
.48593 .5868 m .54238 .5711 L .53149 .5522 L p
1 g
F P
s
P
p
.002 w
.53149 .5522 m .47732 .56709 L .48593 .5868 L p
1 g
F P
s
P
p
.002 w
.61985 .48219 m .64603 .43323 L .62674 .41963 L p
1 g
F P
s
P
p
.002 w
.63583 .37027 m .62674 .41963 L .64603 .43323 L p
1 g
F P
s
P
p
.002 w
.62674 .41963 m .63583 .37027 L .61268 .36187 L p
1 g
F P
s
P
p
.002 w
.49374 .28888 m .51395 .30353 L .53751 .29251 L p
1 g
F P
s
P
p
.002 w
.34164 .47368 m .37471 .5025 L .38024 .47753 L p
1 g
F P
s
P
p
.002 w
.38024 .47753 m .35166 .45215 L .34164 .47368 L p
1 g
F P
s
P
p
.002 w
.37637 .33586 m .36917 .36181 L .39275 .35688 L p
1 g
F P
s
P
p
.002 w
.39275 .35688 m .3977 .33942 L .37637 .33586 L p
1 g
F P
s
P
p
.002 w
.59343 .5406 m .63462 .49808 L .61985 .48219 L p
1 g
F P
s
P
p
.002 w
.64603 .43323 m .61985 .48219 L .63462 .49808 L p
1 g
F P
s
P
p
.002 w
.60539 .3183 m .61268 .36187 L .63583 .37027 L p
1 g
F P
s
P
p
.002 w
.61268 .36187 m .60539 .3183 L .58054 .31745 L p
1 g
F P
s
P
p
.002 w
.49374 .28888 m .46849 .282 L .45962 .30318 L p
1 g
F P
s
P
p
.002 w
.44113 .30452 m .45962 .30318 L .46849 .282 L p
1 g
F P
s
P
p
.002 w
.33431 .41759 m .35166 .45215 L .36516 .43061 L p
1 g
F P
s
P
p
.002 w
.36516 .43061 m .35106 .40188 L .33431 .41759 L p
1 g
F P
s
P
p
.002 w
.34829 .36865 m .35106 .40188 L .3711 .38731 L p
1 g
F P
s
P
p
.002 w
.3711 .38731 m .36917 .36181 L .34829 .36865 L p
1 g
F P
s
P
p
.002 w
.39207 .31246 m .37637 .33586 L .3977 .33942 L p
1 g
F P
s
P
p
.002 w
.3977 .33942 m .40829 .32373 L .39207 .31246 L p
1 g
F P
s
P
p
.002 w
.42907 .58591 m .48593 .5868 L .47732 .56709 L p
1 g
F P
s
P
p
.002 w
.47732 .56709 m .42276 .56595 L .42907 .58591 L p
1 g
F P
s
P
p
.002 w
.56068 .28475 m .58054 .31745 L .60539 .3183 L p
1 g
F P
s
P
p
.002 w
.58054 .31745 m .56068 .28475 L .53751 .29251 L p
1 g
F P
s
P
p
.002 w
.37303 .5482 m .42276 .56595 L .41859 .54316 L p
1 g
F P
s
P
p
.002 w
.41859 .54316 m .37224 .52625 L .37303 .5482 L p
1 g
F P
s
P
p
.002 w
.46849 .282 m .44102 .28387 L .44113 .30452 L p
1 g
F P
s
P
p
.002 w
.42334 .31163 m .44113 .30452 L .44102 .28387 L p
1 g
F P
s
P
p
.002 w
.41449 .29442 m .39207 .31246 L .40829 .32373 L p
1 g
F P
s
P
p
.002 w
.40829 .32373 m .42334 .31163 L .41449 .29442 L p
1 g
F P
s
P
p
.002 w
.44102 .28387 m .41449 .29442 L .42334 .31163 L p
1 g
F P
s
P
p
.002 w
.53751 .29251 m .51137 .2732 L .49374 .28888 L p
1 g
F P
s
P
p
.002 w
.46849 .282 m .49374 .28888 L .51137 .2732 L p
1 g
F P
s
P
p
.002 w
.51137 .2732 m .53751 .29251 L .56068 .28475 L p
1 g
F P
s
P
p
.002 w
.55252 .58699 m .60443 .55593 L .59343 .5406 L p
1 g
F P
s
P
p
.002 w
.59343 .5406 m .54238 .5711 L .55252 .58699 L p
1 g
F P
s
P
p
.002 w
.63462 .49808 m .59343 .5406 L .60443 .55593 L p
1 g
F P
s
P
p
.002 w
.33546 .49472 m .37224 .52625 L .37471 .5025 L p
1 g
F P
s
P
p
.002 w
.37471 .5025 m .34164 .47368 L .33546 .49472 L p
1 g
F P
s
P
p
.002 w
.63462 .49808 m .66214 .44715 L .64603 .43323 L p
1 g
F P
s
P
p
.002 w
.65612 .38044 m .64603 .43323 L .66214 .44715 L p
1 g
F P
s
P
p
.002 w
.64603 .43323 m .65612 .38044 L .63583 .37027 L p
1 g
F P
s
P
p
.002 w
.49518 .60311 m .55252 .58699 L .54238 .5711 L p
1 g
F P
s
P
p
.002 w
.54238 .5711 m .48593 .5868 L .49518 .60311 L p
1 g
F P
s
P
p
.002 w
.35756 .33464 m .34829 .36865 L .36917 .36181 L p
1 g
F P
s
P
p
.002 w
.36917 .36181 m .37637 .33586 L .35756 .33464 L p
1 g
F P
s
P
p
.002 w
.62818 .32208 m .63583 .37027 L .65612 .38044 L p
1 g
F P
s
P
p
.002 w
.63583 .37027 m .62818 .32208 L .60539 .3183 L p
1 g
F P
s
P
p
.002 w
.32139 .43411 m .34164 .47368 L .35166 .45215 L p
1 g
F P
s
P
p
.002 w
.35166 .45215 m .33431 .41759 L .32139 .43411 L p
1 g
F P
s
P
p
.002 w
.60443 .55593 m .6464 .51276 L .63462 .49808 L p
1 g
F P
s
P
p
.002 w
.66214 .44715 m .63462 .49808 L .6464 .51276 L p
1 g
F P
s
P
p
.002 w
.33069 .37733 m .33431 .41759 L .35106 .40188 L p
1 g
F P
s
P
p
.002 w
.35106 .40188 m .34829 .36865 L .33069 .37733 L p
1 g
F P
s
P
p
.002 w
.51137 .2732 m .47846 .26401 L .46849 .282 L p
1 g
F P
s
P
p
.002 w
.44102 .28387 m .46849 .282 L .47846 .26401 L p
1 g
F P
s
P
p
.002 w
.58291 .28056 m .60539 .3183 L .62818 .32208 L p
1 g
F P
s
P
p
.002 w
.60539 .3183 m .58291 .28056 L .56068 .28475 L p
1 g
F P
s
P
p
.002 w
.37808 .30388 m .35756 .33464 L .37637 .33586 L p
1 g
F P
s
P
p
.002 w
.37637 .33586 m .39207 .31246 L .37808 .30388 L p
1 g
F P
s
P
p
.002 w
.3772 .56776 m .42907 .58591 L .42276 .56595 L p
1 g
F P
s
P
p
.002 w
.42276 .56595 m .37303 .5482 L .3772 .56776 L p
1 g
F P
s
P
p
.002 w
.43745 .60245 m .49518 .60311 L .48593 .5868 L p
1 g
F P
s
P
p
.002 w
.48593 .5868 m .42907 .58591 L .43745 .60245 L p
1 g
F P
s
P
p
.002 w
.56068 .28475 m .52923 .26115 L .51137 .2732 L p
1 g
F P
s
P
p
.002 w
.47846 .26401 m .51137 .2732 L .52923 .26115 L p
1 g
F P
s
P
p
.002 w
.52923 .26115 m .56068 .28475 L .58291 .28056 L p
1 g
F P
s
P
p
.002 w
.47846 .26401 m .44243 .26633 L .44102 .28387 L p
1 g
F P
s
P
p
.002 w
.41449 .29442 m .44102 .28387 L .44243 .26633 L p
1 g
F P
s
P
p
.002 w
.33345 .51474 m .37303 .5482 L .37224 .52625 L p
1 g
F P
s
P
p
.002 w
.37224 .52625 m .33546 .49472 L .33345 .51474 L p
1 g
F P
s
P
p
.002 w
.40756 .28014 m .37808 .30388 L .39207 .31246 L p
1 g
F P
s
P
p
.002 w
.39207 .31246 m .41449 .29442 L .40756 .28014 L p
1 g
F P
s
P
p
.002 w
.44243 .26633 m .40756 .28014 L .41449 .29442 L p
1 g
F P
s
P
p
.002 w
.6464 .51276 m .67454 .46111 L .66214 .44715 L p
1 g
F P
s
P
p
.002 w
.67295 .39223 m .66214 .44715 L .67454 .46111 L p
1 g
F P
s
P
p
.002 w
.66214 .44715 m .67295 .39223 L .65612 .38044 L p
1 g
F P
s
P
p
.002 w
.56166 .59935 m .61311 .56854 L .60443 .55593 L p
1 g
F P
s
P
p
.002 w
.60443 .55593 m .55252 .58699 L .56166 .59935 L p
1 g
F P
s
P
p
.002 w
.6464 .51276 m .60443 .55593 L .61311 .56854 L p
1 g
F P
s
P
p
.002 w
.34181 .33591 m .33069 .37733 L .34829 .36865 L p
1 g
F P
s
P
p
.002 w
.34829 .36865 m .35756 .33464 L .34181 .33591 L p
1 g
F P
s
P
p
.002 w
.6483 .32882 m .65612 .38044 L .67295 .39223 L p
1 g
F P
s
P
p
.002 w
.65612 .38044 m .6483 .32882 L .62818 .32208 L p
1 g
F P
s
P
p
.002 w
.31279 .45111 m .33546 .49472 L .34164 .47368 L p
1 g
F P
s
P
p
.002 w
.34164 .47368 m .32139 .43411 L .31279 .45111 L p
1 g
F P
s
P
p
.002 w
.5049 .61545 m .56166 .59935 L .55252 .58699 L p
1 g
F P
s
P
p
.002 w
.55252 .58699 m .49518 .60311 L .5049 .61545 L p
1 g
F P
s
P
p
.002 w
.31698 .38774 m .32139 .43411 L .33431 .41759 L p
1 g
F P
s
P
p
.002 w
.33431 .41759 m .33069 .37733 L .31698 .38774 L p
1 g
F P
s
P
p
.002 w
.52923 .26115 m .48933 .24978 L .47846 .26401 L p
1 g
F P
s
P
p
.002 w
.44243 .26633 m .47846 .26401 L .48933 .24978 L p
1 g
F P
s
P
p
.002 w
.60366 .28019 m .62818 .32208 L .6483 .32882 L p
1 g
F P
s
P
p
.002 w
.62818 .32208 m .60366 .28019 L .58291 .28056 L p
1 g
F P
s
P
p
.002 w
.61311 .56854 m .65476 .52581 L .6464 .51276 L p
1 g
F P
s
P
p
.002 w
.67454 .46111 m .6464 .51276 L .65476 .52581 L p
1 g
F P
s
P
p
.002 w
.38482 .58431 m .43745 .60245 L .42907 .58591 L p
1 g
F P
s
P
p
.002 w
.42907 .58591 m .3772 .56776 L .38482 .58431 L p
1 g
F P
s
P
p
.002 w
.54691 .25316 m .58291 .28056 L .60366 .28019 L p
1 g
F P
s
P
p
.002 w
.58291 .28056 m .54691 .25316 L .52923 .26115 L p
1 g
F P
s
P
p
.002 w
.3668 .29833 m .34181 .33591 L .35756 .33464 L p
1 g
F P
s
P
p
.002 w
.35756 .33464 m .37808 .30388 L .3668 .29833 L p
1 g
F P
s
P
p
.002 w
.48933 .24978 m .52923 .26115 L .54691 .25316 L p
1 g
F P
s
P
p
.002 w
.44784 .61498 m .5049 .61545 L .49518 .60311 L p
1 g
F P
s
P
p
.002 w
.49518 .60311 m .43745 .60245 L .44784 .61498 L p
1 g
F P
s
P
p
.002 w
.33587 .53318 m .3772 .56776 L .37303 .5482 L p
1 g
F P
s
P
p
.002 w
.37303 .5482 m .33345 .51474 L .33587 .53318 L p
1 g
F P
s
P
p
.002 w
.48933 .24978 m .44542 .25249 L .44243 .26633 L p
1 g
F P
s
P
p
.002 w
.40756 .28014 m .44243 .26633 L .44542 .25249 L p
1 g
F P
s
P
p
.002 w
.40281 .26931 m .3668 .29833 L .37808 .30388 L p
1 g
F P
s
P
p
.002 w
.37808 .30388 m .40756 .28014 L .40281 .26931 L p
1 g
F P
s
P
p
.002 w
.44542 .25249 m .40281 .26931 L .40756 .28014 L p
1 g
F P
s
P
p
.002 w
.30897 .46816 m .33345 .51474 L .33546 .49472 L p
1 g
F P
s
P
p
.002 w
.33546 .49472 m .31279 .45111 L .30897 .46816 L p
1 g
F P
s
P
p
.002 w
.67454 .46111 m .68577 .40545 L .67295 .39223 L p
1 g
F P
s
P
p
.002 w
.66515 .3385 m .67295 .39223 L .68577 .40545 L p
1 g
F P
s
P
p
.002 w
.67295 .39223 m .66515 .3385 L .6483 .32882 L p
1 g
F P
s
P
p
.002 w
.65476 .52581 m .68275 .47476 L .67454 .46111 L p
1 g
F P
s
P
p
.002 w
.68577 .40545 m .67454 .46111 L .68275 .47476 L p
1 g
F P
s
P
p
.002 w
.32971 .33979 m .31698 .38774 L .33069 .37733 L p
1 g
F P
s
P
p
.002 w
.33069 .37733 m .34181 .33591 L .32971 .33979 L p
1 g
F P
s
P
p
.002 w
.56952 .60769 m .61911 .57797 L .61311 .56854 L p
1 g
F P
s
P
p
.002 w
.61311 .56854 m .56166 .59935 L .56952 .60769 L p
1 g
F P
s
P
p
.002 w
.65476 .52581 m .61311 .56854 L .61911 .57797 L p
1 g
F P
s
P
p
.002 w
.30772 .39971 m .31279 .45111 L .32139 .43411 L p
1 g
F P
s
P
p
.002 w
.32139 .43411 m .31698 .38774 L .30772 .39971 L p
1 g
F P
s
P
p
.002 w
.51488 .62328 m .56952 .60769 L .56166 .59935 L p
1 g
F P
s
P
p
.002 w
.56166 .59935 m .5049 .61545 L .51488 .62328 L p
1 g
F P
s
P
p
.002 w
.62234 .28385 m .6483 .32882 L .66515 .3385 L p
1 g
F P
s
P
p
.002 w
.6483 .32882 m .62234 .28385 L .60366 .28019 L p
1 g
F P
s
P
p
.002 w
.54691 .25316 m .5009 .23986 L .48933 .24978 L p
1 g
F P
s
P
p
.002 w
.44542 .25249 m .48933 .24978 L .5009 .23986 L p
1 g
F P
s
P
p
.002 w
.61911 .57797 m .65929 .53681 L .65476 .52581 L p
1 g
F P
s
P
p
.002 w
.68275 .47476 m .65476 .52581 L .65929 .53681 L p
1 g
F P
s
P
p
.002 w
.56397 .24966 m .60366 .28019 L .62234 .28385 L p
1 g
F P
s
P
p
.002 w
.60366 .28019 m .56397 .24966 L .54691 .25316 L p
1 g
F P
s
P
p
.002 w
.39588 .59725 m .44784 .61498 L .43745 .60245 L p
1 g
F P
s
P
p
.002 w
.43745 .60245 m .38482 .58431 L .39588 .59725 L p
1 g
F P
s
P
p
.002 w
.5009 .23986 m .54691 .25316 L .56397 .24966 L p
1 g
F P
s
P
p
.002 w
.3429 .54947 m .38482 .58431 L .3772 .56776 L p
1 g
F P
s
P
p
.002 w
.3772 .56776 m .33587 .53318 L .3429 .54947 L p
1 g
F P
s
P
p
.002 w
.35866 .29614 m .32971 .33979 L .34181 .33591 L p
1 g
F P
s
P
p
.002 w
.34181 .33591 m .3668 .29833 L .35866 .29614 L p
1 g
F P
s
P
p
.002 w
.46005 .62294 m .51488 .62328 L .5049 .61545 L p
1 g
F P
s
P
p
.002 w
.5049 .61545 m .44784 .61498 L .46005 .62294 L p
1 g
F P
s
P
p
.002 w
.5009 .23986 m .45002 .2429 L .44542 .25249 L p
1 g
F P
s
P
p
.002 w
.40281 .26931 m .44542 .25249 L .45002 .2429 L p
1 g
F P
s
P
p
.002 w
.31028 .48482 m .33587 .53318 L .33345 .51474 L p
1 g
F P
s
P
p
.002 w
.33345 .51474 m .30897 .46816 L .31028 .48482 L p
1 g
F P
s
P
p
.002 w
.68275 .47476 m .69403 .41985 L .68577 .40545 L p
1 g
F P
s
P
p
.002 w
.6781 .35103 m .68577 .40545 L .69403 .41985 L p
1 g
F P
s
P
p
.002 w
.68577 .40545 m .6781 .35103 L .66515 .3385 L p
1 g
F P
s
P
p
.002 w
.40051 .2624 m .35866 .29614 L .3668 .29833 L p
1 g
F P
s
P
p
.002 w
.3668 .29833 m .40281 .26931 L .40051 .2624 L p
1 g
F P
s
P
p
.002 w
.3218 .34633 m .30772 .39971 L .31698 .38774 L p
1 g
F P
s
P
p
.002 w
.31698 .38774 m .32971 .33979 L .3218 .34633 L p
1 g
F P
s
P
p
.002 w
.65929 .53681 m .68632 .48776 L .68275 .47476 L p
1 g
F P
s
P
p
.002 w
.69403 .41985 m .68275 .47476 L .68632 .48776 L p
1 g
F P
s
P
p
.002 w
.45002 .2429 m .40051 .2624 L .40281 .26931 L p
1 g
F P
s
P
p
.002 w
.30341 .41301 m .30897 .46816 L .31279 .45111 L p
1 g
F P
s
P
p
.002 w
.31279 .45111 m .30772 .39971 L .30341 .41301 L p
1 g
F P
s
P
p
.002 w
.63835 .29164 m .66515 .3385 L .6781 .35103 L p
1 g
F P
s
P
p
.002 w
.66515 .3385 m .63835 .29164 L .62234 .28385 L p
1 g
F P
s
P
p
.002 w
.57581 .61154 m .62211 .58377 L .61911 .57797 L p
1 g
F P
s
P
p
.002 w
.61911 .57797 m .56952 .60769 L .57581 .61154 L p
1 g
F P
s
P
p
.002 w
.65929 .53681 m .61911 .57797 L .62211 .58377 L p
1 g
F P
s
P
p
.002 w
.52486 .62611 m .57581 .61154 L .56952 .60769 L p
1 g
F P
s
P
p
.002 w
.56952 .60769 m .51488 .62328 L .52486 .62611 L p
1 g
F P
s
P
p
.002 w
.56397 .24966 m .5129 .23476 L .5009 .23986 L p
1 g
F P
s
P
p
.002 w
.45002 .2429 m .5009 .23986 L .5129 .23476 L p
1 g
F P
s
P
p
.002 w
.57992 .25099 m .62234 .28385 L .63835 .29164 L p
1 g
F P
s
P
p
.002 w
.62234 .28385 m .57992 .25099 L .56397 .24966 L p
1 g
F P
s
P
p
.002 w
.62211 .58377 m .65964 .54537 L .65929 .53681 L p
1 g
F P
s
P
p
.002 w
.68632 .48776 m .65929 .53681 L .65964 .54537 L p
1 g
F P
s
P
p
.002 w
.41028 .60603 m .46005 .62294 L .44784 .61498 L p
1 g
F P
s
P
p
.002 w
.44784 .61498 m .39588 .59725 L .41028 .60603 L p
1 g
F P
s
P
p
.002 w
.5129 .23476 m .56397 .24966 L .57992 .25099 L p
1 g
F P
s
P
p
.002 w
.35461 .56303 m .39588 .59725 L .38482 .58431 L p
1 g
F P
s
P
p
.002 w
.38482 .58431 m .3429 .54947 L .35461 .56303 L p
1 g
F P
s
P
p
.002 w
.35409 .29759 m .3218 .34633 L .32971 .33979 L p
1 g
F P
s
P
p
.002 w
.32971 .33979 m .35866 .29614 L .35409 .29759 L p
1 g
F P
s
P
p
.002 w
.47388 .62584 m .52486 .62611 L .51488 .62328 L p
1 g
F P
s
P
p
.002 w
.51488 .62328 m .46005 .62294 L .47388 .62584 L p
1 g
F P
s
P
p
.002 w
.317 .50058 m .3429 .54947 L .33587 .53318 L p
1 g
F P
s
P
p
.002 w
.33587 .53318 m .31028 .48482 L .317 .50058 L p
1 g
F P
s
P
p
.002 w
.5129 .23476 m .4562 .23809 L .45002 .2429 L p
1 g
F P
s
P
p
.002 w
.40051 .2624 m .45002 .2429 L .4562 .23809 L p
1 g
F P
s
P
p
.002 w
.68632 .48776 m .69724 .43509 L .69403 .41985 L p
1 g
F P
s
P
p
.002 w
.6866 .36623 m .69403 .41985 L .69724 .43509 L p
1 g
F P
s
P
p
.002 w
.69403 .41985 m .6866 .36623 L .6781 .35103 L p
1 g
F P
s
P
p
.002 w
.30449 .42734 m .31028 .48482 L .30897 .46816 L p
1 g
F P
s
P
p
.002 w
.30897 .46816 m .30341 .41301 L .30449 .42734 L p
1 g
F P
s
P
p
.002 w
.31857 .35551 m .30341 .41301 L .30772 .39971 L p
1 g
F P
s
P
p
.002 w
.30772 .39971 m .3218 .34633 L .31857 .35551 L p
1 g
F P
s
P
p
.002 w
.65964 .54537 m .68487 .49969 L .68632 .48776 L p
1 g
F P
s
P
p
.002 w
.69724 .43509 m .68632 .48776 L .68487 .49969 L p
1 g
F P
s
P
p
.002 w
.40087 .25987 m .35409 .29759 L .35866 .29614 L p
1 g
F P
s
P
p
.002 w
.35866 .29614 m .40051 .2624 L .40087 .25987 L p
1 g
F P
s
P
p
.002 w
.6781 .35103 m .65111 .30359 L .63835 .29164 L p
1 g
F P
s
P
p
.002 w
.65111 .30359 m .6781 .35103 L .6866 .36623 L p
1 g
F P
s
P
p
.002 w
.4562 .23809 m .40087 .25987 L .40051 .2624 L p
1 g
F P
s
P
p
.004 w
.46024 .62827 m
.46052 .62688 L
s
P
p
.004 w
.45891 .63488 m
.46024 .62827 L
s
P
p
.004 w
.45745 .64213 m
.45891 .63488 L
s
P
p
.004 w
.44118 .72308 m
.45745 .64213 L
s
P
p
.002 w
.58025 .61049 m .62184 .58555 L .62211 .58377 L p
1 g
F P
s
P
p
.002 w
.62211 .58377 m .57581 .61154 L .58025 .61049 L p
1 g
F P
s
P
p
.002 w
.65964 .54537 m .62211 .58377 L .62184 .58555 L p
1 g
F P
s
P
p
.002 w
.63835 .29164 m .59426 .25738 L .57992 .25099 L p
1 g
F P
s
P
p
.002 w
.59426 .25738 m .63835 .29164 L .65111 .30359 L p
1 g
F P
s
P
p
.002 w
.57992 .25099 m .52504 .23491 L .5129 .23476 L p
1 g
F P
s
P
p
.002 w
.4562 .23809 m .5129 .23476 L .52504 .23491 L p
1 g
F P
s
P
p
.002 w
.53457 .62356 m .58025 .61049 L .57581 .61154 L p
1 g
F P
s
P
p
.002 w
.57581 .61154 m .52486 .62611 L .53457 .62356 L p
1 g
F P
s
P
p
.002 w
.52504 .23491 m .57992 .25099 L .59426 .25738 L p
1 g
F P
s
P
p
.002 w
.42777 .61014 m .47388 .62584 L .46005 .62294 L p
1 g
F P
s
P
p
.002 w
.46005 .62294 m .41028 .60603 L .42777 .61014 L p
1 g
F P
s
P
p
.002 w
.3709 .57331 m .41028 .60603 L .39588 .59725 L p
1 g
F P
s
P
p
.002 w
.39588 .59725 m .35461 .56303 L .3709 .57331 L p
1 g
F P
s
P
p
.002 w
.62184 .58555 m .65554 .55108 L .65964 .54537 L p
1 g
F P
s
P
p
.002 w
.68487 .49969 m .65964 .54537 L .65554 .55108 L p
1 g
F P
s
P
p
.002 w
.32922 .51492 m .35461 .56303 L .3429 .54947 L p
1 g
F P
s
P
p
.002 w
.3429 .54947 m .317 .50058 L .32922 .51492 L p
1 g
F P
s
P
p
.002 w
.35346 .30288 m .31857 .35551 L .3218 .34633 L p
1 g
F P
s
P
p
.002 w
.3218 .34633 m .35409 .29759 L .35346 .30288 L p
1 g
F P
s
P
p
.002 w
.489 .62329 m .53457 .62356 L .52486 .62611 L p
1 g
F P
s
P
p
.002 w
.52486 .62611 m .47388 .62584 L .489 .62329 L p
1 g
F P
s
P
p
.002 w
.68487 .49969 m .69502 .4508 L .69724 .43509 L p
1 g
F P
s
P
p
.002 w
.69724 .43509 m .69016 .38381 L .6866 .36623 L p
1 g
F P
s
P
p
.002 w
.69016 .38381 m .69724 .43509 L .69502 .4508 L p
1 g
F P
s
P
p
.002 w
.31123 .44233 m .317 .50058 L .31028 .48482 L p
1 g
F P
s
P
p
.002 w
.31028 .48482 m .30449 .42734 L .31123 .44233 L p
1 g
F P
s
P
p
.002 w
.52504 .23491 m .46388 .23851 L .4562 .23809 L p
1 g
F P
s
P
p
.002 w
.40087 .25987 m .4562 .23809 L .46388 .23851 L p
1 g
F P
s
P
p
.002 w
.66007 .31959 m .6866 .36623 L .69016 .38381 L p
1 g
F P
s
P
p
.002 w
.6866 .36623 m .66007 .31959 L .65111 .30359 L p
1 g
F P
s
P
p
.002 w
.32041 .36724 m .30449 .42734 L .30341 .41301 L p
1 g
F P
s
P
p
.002 w
.30341 .41301 m .31857 .35551 L .32041 .36724 L p
1 g
F P
s
P
p
.002 w
.65554 .55108 m .67812 .51017 L .68487 .49969 L p
1 g
F P
s
P
p
.002 w
.69502 .4508 m .68487 .49969 L .67812 .51017 L p
1 g
F P
s
P
p
.002 w
.40408 .26208 m .35346 .30288 L .35409 .29759 L p
1 g
F P
s
P
p
.002 w
.35409 .29759 m .40087 .25987 L .40408 .26208 L p
1 g
F P
s
P
p
.002 w
.46388 .23851 m .40408 .26208 L .40087 .25987 L p
1 g
F P
s
P
p
.002 w
.60647 .26895 m .65111 .30359 L .66007 .31959 L p
1 g
F P
s
P
p
.002 w
.65111 .30359 m .60647 .26895 L .59426 .25738 L p
1 g
F P
s
P
p
.002 w
.59426 .25738 m .53697 .24064 L .52504 .23491 L p
1 g
F P
s
P
p
.002 w
.46388 .23851 m .52504 .23491 L .53697 .24064 L p
1 g
F P
s
P
p
.002 w
.5826 .60425 m .61808 .58298 L .62184 .58555 L p
1 g
F P
s
P
p
.002 w
.62184 .58555 m .58025 .61049 L .5826 .60425 L p
1 g
F P
s
P
p
.002 w
.65554 .55108 m .62184 .58555 L .61808 .58298 L p
1 g
F P
s
P
p
.002 w
.53697 .24064 m .59426 .25738 L .60647 .26895 L p
1 g
F P
s
P
p
.002 w
.39152 .57981 m .42777 .61014 L .41028 .60603 L p
1 g
F P
s
P
p
.002 w
.41028 .60603 m .3709 .57331 L .39152 .57981 L p
1 g
F P
s
P
p
.002 w
.448 .6092 m .489 .62329 L .47388 .62584 L p
1 g
F P
s
P
p
.002 w
.47388 .62584 m .42777 .61014 L .448 .6092 L p
1 g
F P
s
P
p
.004 w
.46052 .62688 m
.46166 .62119 L
s
P
p
.004 w
.46303 .61437 m
.5 .43051 L
s
P
p
.004 w
.46166 .62119 m
.46195 .61976 L
s
P
p
.002 w
.54369 .61535 m .5826 .60425 L .58025 .61049 L p
1 g
F P
s
P
p
.002 w
.58025 .61049 m .53457 .62356 L .54369 .61535 L p
1 g
F P
s
P
p
.002 w
.61808 .58298 m .6468 .55358 L .65554 .55108 L p
1 g
F P
s
P
p
.002 w
.67812 .51017 m .65554 .55108 L .6468 .55358 L p
1 g
F P
s
P
p
.002 w
.34687 .52731 m .3709 .57331 L .35461 .56303 L p
1 g
F P
s
P
p
.002 w
.35461 .56303 m .32922 .51492 L .34687 .52731 L p
1 g
F P
s
P
p
.002 w
.35706 .31209 m .32041 .36724 L .31857 .35551 L p
1 g
F P
s
P
p
.002 w
.31857 .35551 m .35346 .30288 L .35706 .31209 L p
1 g
F P
s
P
p
.002 w
.50503 .61503 m .54369 .61535 L .53457 .62356 L p
1 g
F P
s
P
p
.002 w
.53457 .62356 m .489 .62329 L .50503 .61503 L p
1 g
F P
s
P
p
.002 w
.67812 .51017 m .68711 .46654 L .69502 .4508 L p
1 g
F P
s
P
p
.002 w
.68839 .40339 m .69502 .4508 L .68711 .46654 L p
1 g
F P
s
P
p
.002 w
.69502 .4508 m .68839 .40339 L .69016 .38381 L p
1 g
F P
s
P
p
.002 w
.32377 .45754 m .32922 .51492 L .317 .50058 L p
1 g
F P
s
P
p
.002 w
.317 .50058 m .31123 .44233 L .32377 .45754 L p
1 g
F P
s
P
p
.002 w
.66473 .33938 m .69016 .38381 L .68839 .40339 L p
1 g
F P
s
P
p
.002 w
.69016 .38381 m .66473 .33938 L .66007 .31959 L p
1 g
F P
s
P
p
.002 w
.32758 .3813 m .31123 .44233 L .30449 .42734 L p
1 g
F P
s
P
p
.002 w
.30449 .42734 m .32041 .36724 L .32758 .3813 L p
1 g
F P
s
P
p
.002 w
.53697 .24064 m .47294 .2445 L .46388 .23851 L p
1 g
F P
s
P
p
.002 w
.40408 .26208 m .46388 .23851 L .47294 .2445 L p
1 g
F P
s
P
p
.002 w
.6468 .55358 m .66595 .51877 L .67812 .51017 L p
1 g
F P
s
P
p
.002 w
.68711 .46654 m .67812 .51017 L .66595 .51877 L p
1 g
F P
s
P
p
.002 w
.61605 .28565 m .66007 .31959 L .66473 .33938 L p
1 g
F P
s
P
p
.002 w
.66007 .31959 m .61605 .28565 L .60647 .26895 L p
1 g
F P
s
P
p
.002 w
.41021 .26928 m .35706 .31209 L .35346 .30288 L p
1 g
F P
s
P
p
.002 w
.35346 .30288 m .40408 .26208 L .41021 .26928 L p
1 g
F P
s
P
p
.002 w
.47294 .2445 m .41021 .26928 L .40408 .26208 L p
1 g
F P
s
P
p
.002 w
.41602 .58211 m .448 .6092 L .42777 .61014 L p
1 g
F P
s
P
p
.002 w
.42777 .61014 m .39152 .57981 L .41602 .58211 L p
1 g
F P
s
P
p
.002 w
.54831 .25211 m .60647 .26895 L .61605 .28565 L p
1 g
F P
s
P
p
.002 w
.60647 .26895 m .54831 .25211 L .53697 .24064 L p
1 g
F P
s
P
p
.002 w
.47294 .2445 m .53697 .24064 L .54831 .25211 L p
1 g
F P
s
P
p
.002 w
.47046 .60297 m .50503 .61503 L .489 .62329 L p
1 g
F P
s
P
p
.002 w
.489 .62329 m .448 .6092 L .47046 .60297 L p
1 g
F P
s
P
p
.002 w
.58264 .59268 m .61071 .57586 L .61808 .58298 L p
1 g
F P
s
P
p
.002 w
.61808 .58298 m .5826 .60425 L .58264 .59268 L p
1 g
F P
s
P
p
.002 w
.6468 .55358 m .61808 .58298 L .61071 .57586 L p
1 g
F P
s
P
p
.002 w
.36965 .53724 m .39152 .57981 L .3709 .57331 L p
1 g
F P
s
P
p
.002 w
.3709 .57331 m .34687 .52731 L .36965 .53724 L p
1 g
F P
s
P
p
.002 w
.5519 .60139 m .58264 .59268 L .5826 .60425 L p
1 g
F P
s
P
p
.002 w
.5826 .60425 m .54369 .61535 L .5519 .60139 L p
1 g
F P
s
P
p
.002 w
.61071 .57586 m .6334 .5526 L .6468 .55358 L p
1 g
F P
s
P
p
.002 w
.66595 .51877 m .6468 .55358 L .6334 .5526 L p
1 g
F P
s
P
p
.002 w
.66595 .51877 m .67344 .48181 L .68711 .46654 L p
1 g
F P
s
P
p
.002 w
.68105 .42445 m .68711 .46654 L .67344 .48181 L p
1 g
F P
s
P
p
.002 w
.68711 .46654 m .68105 .42445 L .68839 .40339 L p
1 g
F P
s
P
p
.002 w
.342 .47247 m .34687 .52731 L .32922 .51492 L p
1 g
F P
s
P
p
.002 w
.32922 .51492 m .32377 .45754 L .342 .47247 L p
1 g
F P
s
P
p
.002 w
.36503 .3252 m .32758 .3813 L .32041 .36724 L p
1 g
F P
s
P
p
.002 w
.32041 .36724 m .35706 .31209 L .36503 .3252 L p
1 g
F P
s
P
p
.002 w
.66472 .36251 m .68839 .40339 L .68105 .42445 L p
1 g
F P
s
P
p
.002 w
.68839 .40339 m .66472 .36251 L .66473 .33938 L p
1 g
F P
s
P
p
.002 w
.52149 .60102 m .5519 .60139 L .54369 .61535 L p
1 g
F P
s
P
p
.002 w
.54369 .61535 m .50503 .61503 L .52149 .60102 L p
1 g
F P
s
P
p
.002 w
.34017 .39736 m .32377 .45754 L .31123 .44233 L p
1 g
F P
s
P
p
.002 w
.31123 .44233 m .32758 .3813 L .34017 .39736 L p
1 g
F P
s
P
p
.002 w
.62256 .3072 m .66473 .33938 L .66472 .36251 L p
1 g
F P
s
P
p
.002 w
.66473 .33938 m .62256 .3072 L .61605 .28565 L p
1 g
F P
s
P
p
.002 w
.54831 .25211 m .48317 .25621 L .47294 .2445 L p
1 g
F P
s
P
p
.002 w
.41021 .26928 m .47294 .2445 L .48317 .25621 L p
1 g
F P
s
P
p
.002 w
.6334 .5526 m .64843 .52511 L .66595 .51877 L p
1 g
F P
s
P
p
.002 w
.67344 .48181 m .66595 .51877 L .64843 .52511 L p
1 g
F P
s
P
p
.002 w
.44375 .57995 m .47046 .60297 L .448 .6092 L p
1 g
F P
s
P
p
.002 w
.448 .6092 m .41602 .58211 L .44375 .57995 L p
1 g
F P
s
P
p
.002 w
.41925 .28156 m .36503 .3252 L .35706 .31209 L p
1 g
F P
s
P
p
.002 w
.35706 .31209 m .41021 .26928 L .41925 .28156 L p
1 g
F P
s
P
p
.002 w
.55865 .26929 m .61605 .28565 L .62256 .3072 L p
1 g
F P
s
P
p
.002 w
.61605 .28565 m .55865 .26929 L .54831 .25211 L p
1 g
F P
s
P
p
.002 w
.48317 .25621 m .54831 .25211 L .55865 .26929 L p
1 g
F P
s
P
p
.002 w
.4945 .59139 m .52149 .60102 L .50503 .61503 L p
1 g
F P
s
P
p
.002 w
.50503 .61503 m .47046 .60297 L .4945 .59139 L p
1 g
F P
s
P
p
.002 w
.48317 .25621 m .41925 .28156 L .41021 .26928 L p
1 g
F P
s
P
p
.002 w
.397 .54425 m .41602 .58211 L .39152 .57981 L p
1 g
F P
s
P
p
.002 w
.39152 .57981 m .36965 .53724 L .397 .54425 L p
1 g
F P
s
P
p
.002 w
.58022 .57581 m .59975 .56413 L .61071 .57586 L p
1 g
F P
s
P
p
.002 w
.61071 .57586 m .58264 .59268 L .58022 .57581 L p
1 g
F P
s
P
p
.002 w
.6334 .5526 m .61071 .57586 L .59975 .56413 L p
1 g
F P
s
P
p
.002 w
.55887 .58181 m .58022 .57581 L .58264 .59268 L p
1 g
F P
s
P
p
.002 w
.58264 .59268 m .5519 .60139 L .55887 .58181 L p
1 g
F P
s
P
p
.002 w
.36556 .48659 m .36965 .53724 L .34687 .52731 L p
1 g
F P
s
P
p
.002 w
.34687 .52731 m .342 .47247 L .36556 .48659 L p
1 g
F P
s
P
p
.002 w
.67344 .48181 m .66811 .44636 L .68105 .42445 L p
1 g
F P
s
P
p
.002 w
.65981 .38839 m .68105 .42445 L .66811 .44636 L p
1 g
F P
s
P
p
.002 w
.68105 .42445 m .65981 .38839 L .66472 .36251 L p
1 g
F P
s
P
p
.002 w
.64843 .52511 m .65416 .49607 L .67344 .48181 L p
1 g
F P
s
P
p
.002 w
.66811 .44636 m .67344 .48181 L .65416 .49607 L p
1 g
F P
s
P
p
.002 w
.59975 .56413 m .6155 .54794 L .6334 .5526 L p
1 g
F P
s
P
p
.002 w
.64843 .52511 m .6334 .5526 L .6155 .54794 L p
1 g
F P
s
P
p
.002 w
.37737 .34197 m .34017 .39736 L .32758 .3813 L p
1 g
F P
s
P
p
.002 w
.32758 .3813 m .36503 .3252 L .37737 .34197 L p
1 g
F P
s
P
p
.002 w
.53785 .58144 m .55887 .58181 L .5519 .60139 L p
1 g
F P
s
P
p
.002 w
.5519 .60139 m .52149 .60102 L .53785 .58144 L p
1 g
F P
s
P
p
.002 w
.35802 .41497 m .342 .47247 L .32377 .45754 L p
1 g
F P
s
P
p
.002 w
.32377 .45754 m .34017 .39736 L .35802 .41497 L p
1 g
F P
s
P
p
.002 w
.6256 .33314 m .66472 .36251 L .65981 .38839 L p
1 g
F P
s
P
p
.002 w
.66472 .36251 m .6256 .33314 L .62256 .3072 L p
1 g
F P
s
P
p
.002 w
.6155 .54794 m .62584 .52885 L .64843 .52511 L p
1 g
F P
s
P
p
.002 w
.65416 .49607 m .64843 .52511 L .62584 .52885 L p
1 g
F P
s
P
p
.002 w
.55865 .26929 m .49429 .27358 L .48317 .25621 L p
1 g
F P
s
P
p
.002 w
.41925 .28156 m .48317 .25621 L .49429 .27358 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.4945 .59139 m .47046 .60297 L p
.47316 .57937 L 1 g
F P
s
P
p
.47316 .57937 m .47349 .57642 L .4785 .57998 L 1 g
F
P
p
.47316 .57937 m .4785 .57998 L .4945 .59139 L 1 g
F
P
p
.002 w
.47964 .57831 m .482 .58039 L p
.47349 .57642 L 1 g
F P
s
P
p
.002 w
.482 .58039 m .4945 .59139 L p
.4785 .57998 L 1 g
F P
s
P
p
.47349 .57642 m .482 .58039 L .4785 .57998 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .5807 L p
1 g
F P
s
P
p
.002 w
.52149 .60102 m .4945 .59139 L .50999 .58095 L p
1 g
F P
s
P
p
.52149 .60102 m .50999 .58095 L .51035 .58086 L 1 g
F
P
p
.53128 .57265 m .51095 .5807 L .52019 .57834 L 1 g
F
P
p
.002 w
.51095 .5807 m .51079 .57862 L p
.50076 .58063 L 1 g
F P
s
P
p
.002 w
.51029 .58074 m .4945 .59139 L p
.49849 .5806 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4945 .59139 m .482 .58039 L p
.48907 .58048 L 1 g
F P
s
P
p
.49779 .58248 m .48907 .58048 L .49849 .5806 L 1 g
F
P
p
.4945 .59139 m .48907 .58048 L .49779 .58248 L 1 g
F
P
p
.48921 .57862 m .47752 .57766 L .47964 .57831 L 1 g
F
P
p
.002 w
.48907 .58048 m .48921 .57862 L p
.47964 .57831 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58048 L p
1 g
F P
s
P
p
.002 w
.48907 .58048 m .48889 .583 L p
.50076 .58063 L 1 g
F P
s
P
p
.51079 .57862 m .48907 .58048 L .50076 .58063 L 1 g
F
P
p
.002 w
.482 .58039 m .47964 .57831 L p
.48907 .58048 L 1 g
F P
s
P
p
.002 w
.47046 .60297 m .44375 .57995 L .46763 .57461 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46825 .5748 L p
1 g
F P
s
P
p
.48921 .57862 m .46825 .5748 L .47752 .57766 L 1 g
F
P
p
.002 w
.46763 .57461 m .46782 .57457 L p
.46825 .5748 L 1 g
F P
s
P
p
.47046 .60297 m .46763 .57461 L .47349 .57642 L 1 g
F
P
p
.002 w
.46782 .57457 m .44375 .57995 L p
.45297 .56392 L 1 g
F P
s
P
p
.002 w
.46825 .5748 m .46872 .57265 L p
.45193 .56594 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45101 .56251 L p
1 g
F P
s
P
p
.44375 .57995 m .43075 .54799 L .45101 .56251 L 1 g
F
P
p
.45265 .56448 m .45101 .56251 L .45297 .56392 L 1 g
F
P
p
.44375 .57995 m .45101 .56251 L .45265 .56448 L 1 g
F
P
p
.002 w
.45101 .56251 m .45146 .56129 L p
.44603 .55657 L 1 g
F P
s
P
p
.46872 .57265 m .45101 .56251 L .46065 .56943 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.45297 .56392 m .45101 .56251 L .46204 .54817 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43838 .54729 L p
1 g
F P
s
P
p
.45146 .56129 m .43838 .54729 L .43871 .54779 L 1 g
F
P
p
.43925 .54566 m .43599 .53921 L .4363 .54025 L 1 g
F
P
p
.002 w
.4386 .54803 m .42813 .54797 L p
.43484 .54196 L 1 g
F P
s
P
p
.43484 .54196 m .43639 .54057 L .43838 .54729 L 1 g
F
P
p
.43484 .54196 m .43838 .54729 L .4386 .54803 L 1 g
F
P
p
.002 w
.43838 .54729 m .43925 .54566 L p
.4363 .54025 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42813 .54797 m .4259 .51025 L .42752 .51065 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43277 .52835 L p
1 g
F P
s
P
p
.43925 .54566 m .43277 .52835 L .43599 .53921 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42752 .51065 m .43361 .51215 L p
.43277 .52835 L 1 g
F P
s
P
p
.42813 .54797 m .42752 .51065 L .43639 .54057 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.4259 .51025 m .4343 .50611 L .43393 .50936 L 1 g
F
P
p
.002 w
.43361 .51215 m .43268 .51192 L p
.43393 .50936 L 1 g
F P
s
P
p
.002 w
.43268 .51192 m .4259 .51025 L p
.43393 .50936 L 1 g
F P
s
P
p
.002 w
.43393 .50936 m .43485 .50826 L p
.43762 .50178 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43393 .50936 L p
1 g
F P
s
P
p
.002 w
.43393 .50936 m .43287 .51061 L p
.43309 .51667 L 1 g
F P
s
P
p
.43346 .52734 m .43393 .50936 L .43309 .51667 L 1 g
F
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44283 .4911 L p
1 g
F P
s
P
p
.43485 .50826 m .44283 .4911 L .43762 .50178 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4259 .51025 m .42711 .50631 L p
.47027 .4884 L 1 g
F P
s
P
p
.002 w
.44283 .4911 m .44339 .4905 L p
.44911 .48502 L 1 g
F P
s
P
p
.002 w
.45442 .47988 m .47027 .4884 L p
.42711 .50631 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45774 .47665 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47027 .4884 m .45442 .47988 L p
.47793 .46708 L 1 g
F P
s
P
p
.47793 .46708 m .47945 .46688 L .47027 .4884 L 1 g
F
P
p
.002 w
.47759 .46712 m .47786 .46667 L p
.49039 .4654 L 1 g
F P
s
P
p
.002 w
.49463 .46476 m .51709 .48511 L p
.48606 .46604 L 1 g
F P
s
P
p
.49039 .4654 m .49396 .46503 L .48606 .46604 L 1 g
F
P
p
.49039 .4654 m .48606 .46604 L .47759 .46712 L 1 g
F
P
p
.002 w
.47027 .4884 m .48606 .46604 L p
.51709 .48511 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46387 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51709 .48511 m .49463 .46476 L p
.526 .46891 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54236 .47675 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56608 .50937 L p
1 g
F P
s
P
p
.002 w
.56537 .50785 m .5638 .4956 L p
.56538 .50122 L 1 g
F P
s
P
p
.56538 .50122 m .57001 .51775 L .56608 .50937 L 1 g
F
P
p
.56538 .50122 m .56608 .50937 L .56537 .50785 L 1 g
F
P
p
.002 w
.56608 .50937 m .56515 .50826 L p
.56705 .52057 L 1 g
F P
s
P
p
.55661 .4905 m .56608 .50937 L .56537 .50785 L 1 g
F
P
p
.002 w
.5603 .49708 m .5638 .4956 L .56537 .50785 L p
1 g
F P
s
P
p
.56259 .50194 m .56537 .50785 L .56267 .5021 L 1 g
F
P
p
.55661 .4905 m .56537 .50785 L .56259 .50194 L 1 g
F
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.57529 .55393 m .56831 .55587 L p
.56791 .52835 L 1 g
F P
s
P
p
.002 w
.56802 .52801 m .57529 .55393 L p
.56791 .52835 L 1 g
F P
s
P
p
.002 w
.56831 .55587 m .56429 .55698 L .56769 .52921 L p
1 g
F P
s
P
p
.002 w
.56769 .52921 m .56789 .52757 L p
.56831 .55587 L 1 g
F P
s
P
p
.002 w
.56769 .52901 m .56654 .52734 L p
.56445 .53877 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56769 .52901 L p
1 g
F P
s
P
p
.56515 .50826 m .56769 .52901 L .56769 .52901 L 1 g
F
P
p
.56515 .50826 m .56769 .52901 L .56767 .52823 L 1 g
F
P
p
.002 w
.56429 .55698 m .55887 .58181 L p
.5538 .55807 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56323 L p
1 g
F P
s
P
p
.53785 .58144 m .53947 .57413 L .54926 .56323 L 1 g
F
P
p
.002 w
.54971 .56273 m .54949 .56308 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.54949 .56308 m .53785 .58144 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54854 .56129 L p
.54048 .56897 L 1 g
F P
s
P
p
.56075 .54566 m .54926 .56323 L .54929 .5632 L 1 g
F
P
p
.56075 .54566 m .54926 .56323 L .55243 .55964 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .5747 L p
1 g
F P
s
P
p
.54854 .56129 m .53173 .5747 L .54048 .56897 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.54926 .56323 m .54411 .55315 L .54971 .56273 L 1 g
F
P
p
.53947 .57413 m .54063 .56888 L .54926 .56323 L 1 g
F
P
p
.54063 .56888 m .54411 .55315 L .54926 .56323 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.50076 .58063 m .51029 .58074 L .51095 .5807 L 1 g
F
P
p
.002 w
.51029 .58074 m .51934 .57465 L p
.51965 .57848 L 1 g
F P
s
P
p
.51979 .58016 m .51095 .5807 L .51965 .57848 L 1 g
F
P
p
.51095 .5807 m .51029 .58074 L .51965 .57848 L 1 g
F
P
p
.002 w
.53173 .5747 m .53128 .57265 L p
.52019 .57834 L 1 g
F P
s
P
p
.52149 .60102 m .51029 .58074 L .51979 .58016 L 1 g
F
P
p
.52019 .57834 m .52561 .57695 L .53173 .5747 L 1 g
F
P
p
.002 w
.53785 .58144 m .52149 .60102 L p
.51965 .57848 L 1 g
F P
s
P
p
.002 w
.51934 .57465 m .52561 .57695 L p
.51965 .57848 L 1 g
F P
s
P
p
.002 w
.52561 .57695 m .53785 .58144 L p
.51965 .57848 L 1 g
F P
s
P
p
.002 w
.53785 .58144 m .52561 .57695 L p
.54001 .57165 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53187 .57535 L p
1 g
F P
s
P
p
.002 w
.53187 .57535 m .53173 .5747 L p
.52705 .57658 L 1 g
F P
s
P
p
.52705 .57658 m .51111 .583 L .53187 .57535 L 1 g
F
P
p
.52019 .57834 m .516 .58049 L .52561 .57695 L 1 g
F
P
p
.002 w
.51934 .57465 m .54411 .55315 L p
.54001 .57165 L 1 g
F P
s
P
p
.002 w
.52561 .57695 m .51934 .57465 L p
.54001 .57165 L 1 g
F P
s
P
p
.516 .58049 m .51111 .583 L .53173 .5747 L 1 g
F
P
p
.002 w
.53173 .5747 m .5322 .57686 L p
.54048 .56897 L 1 g
F P
s
P
p
.002 w
.55887 .58181 m .53785 .58144 L .54949 .56308 L p
1 g
F P
s
P
p
.002 w
.54949 .56308 m .54971 .56273 L p
.55418 .55982 L 1 g
F P
s
P
p
.55418 .55982 m .54971 .56273 L .5538 .55807 L 1 g
F
P
p
.55887 .58181 m .54949 .56308 L .55418 .55982 L 1 g
F
P
p
.002 w
.55496 .55676 m .56429 .55698 L p
.5538 .55807 L 1 g
F P
s
P
p
.55407 .55777 m .54966 .56429 L .55343 .55894 L 1 g
F
P
p
.56075 .54566 m .55243 .55964 L .55407 .55777 L 1 g
F
P
p
.55243 .55964 m .54966 .56429 L .55407 .55777 L 1 g
F
P
p
.002 w
.54971 .56273 m .55352 .55672 L p
.5538 .55807 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54926 .56323 L p
1 g
F P
s
P
p
.002 w
.54926 .56323 m .54926 .56323 L p
.54917 .5633 L 1 g
F P
s
P
p
.54917 .5633 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.54048 .56897 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.002 w
.54926 .56323 m .54926 .56323 L p
.54929 .5632 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54411 .55315 m .55352 .55672 L .54971 .56273 L p
1 g
F P
s
P
p
.002 w
.55846 .55684 m .55496 .55676 L p
.56161 .54732 L 1 g
F P
s
P
p
.55846 .55684 m .56161 .54732 L .56162 .5473 L 1 g
F
P
p
.002 w
.56774 .52887 m .56429 .55698 L .55846 .55684 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56162 .5473 L p
1 g
F P
s
P
p
.002 w
.56162 .5473 m .56075 .54566 L p
.55343 .55894 L 1 g
F P
s
P
p
.55343 .55894 m .54998 .56518 L .56162 .5473 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56257 .5491 L p
1 g
F P
s
P
p
.56162 .5473 m .56769 .52897 L .56769 .52901 L 1 g
F
P
p
.56161 .54732 m .56769 .52897 L .56162 .5473 L 1 g
F
P
p
.002 w
.55352 .55672 m .55496 .55676 L p
.5538 .55807 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54966 .56429 L p
.55243 .55964 L 1 g
F P
s
P
p
.002 w
.54966 .56429 m .54998 .56518 L p
.55343 .55894 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56161 .54732 m .55352 .55672 L .56769 .52897 L 1 g
F
P
p
.002 w
.55496 .55676 m .55352 .55672 L p
.56161 .54732 L 1 g
F P
s
P
p
.56769 .52901 m .56769 .52897 L .56774 .52887 L 1 g
F
P
p
.002 w
.56767 .52804 m .56789 .52757 L p
.56769 .52897 L 1 g
F P
s
P
p
.56767 .52823 m .56769 .52901 L .56767 .52824 L 1 g
F
P
p
.56769 .52901 m .56769 .52901 L .56767 .52823 L 1 g
F
P
p
.002 w
.56769 .52901 m .56769 .52901 L p
.56769 .52901 L 1 g
F P
s
P
p
.002 w
.56789 .52757 m .56774 .52887 L p
.56769 .52897 L 1 g
F P
s
P
p
.002 w
.57001 .51775 m .56789 .52757 L .56715 .52178 L p
1 g
F P
s
P
p
.56515 .50826 m .56715 .52178 L .56705 .52057 L 1 g
F
P
p
.002 w
.56715 .52178 m .56537 .50785 L p
.56608 .50937 L 1 g
F P
s
P
p
.56608 .50937 m .57001 .51775 L .56715 .52178 L 1 g
F
P
p
.56515 .50826 m .56767 .52824 L .56715 .52178 L 1 g
F
P
p
.56767 .52824 m .56766 .52783 L .56715 .52178 L 1 g
F
P
p
.56766 .52783 m .56765 .52768 L .56715 .52178 L 1 g
F
P
p
.56765 .52768 m .56765 .52762 L .56715 .52178 L 1 g
F
P
p
.56765 .52765 m .56765 .52755 L .56715 .52178 L 1 g
F
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.53325 .5378 m .53305 .52763 L .56765 .52757 L p
1 g
F P
s
P
p
.002 w
.56765 .52757 m .56789 .52757 L .56765 .52765 L p
1 g
F P
s
P
p
.002 w
.56765 .52765 m .53325 .5378 L p
.56765 .52757 L 1 g
F P
s
P
p
.002 w
.56765 .52765 m .56789 .52757 L .56766 .52772 L p
1 g
F P
s
P
p
.56765 .52768 m .56765 .52765 L .56765 .52762 L 1 g
F
P
p
.56765 .52765 m .56765 .52761 L .56765 .52755 L 1 g
F
P
p
.56765 .52761 m .56764 .52743 L .56715 .52178 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53305 .52763 m .53655 .51722 L .56764 .52749 L p
1 g
F P
s
P
p
.002 w
.56764 .52749 m .56789 .52757 L .56765 .52757 L p
1 g
F P
s
P
p
.002 w
.56765 .52757 m .53305 .52763 L p
.56764 .52749 L 1 g
F P
s
P
p
.002 w
.53655 .51722 m .5434 .50774 L .56763 .52736 L p
1 g
F P
s
P
p
.002 w
.56763 .52736 m .56789 .52757 L .56764 .52749 L p
1 g
F P
s
P
p
.002 w
.56764 .52749 m .53655 .51722 L p
.56763 .52736 L 1 g
F P
s
P
p
.56765 .52761 m .56765 .52758 L .56764 .52743 L 1 g
F
P
p
.56765 .52758 m .56765 .52754 L .56761 .52705 L 1 g
F
P
p
.56765 .52758 m .56761 .52705 L .56715 .52178 L 1 g
F
P
p
.002 w
.5434 .50774 m .55283 .50025 L .56761 .52705 L p
1 g
F P
s
P
p
.002 w
.56761 .52705 m .56789 .52757 L .56763 .52736 L p
1 g
F P
s
P
p
.002 w
.56763 .52736 m .5434 .50774 L p
.56761 .52705 L 1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53709 .54662 m .53325 .5378 L .56765 .52765 L p
1 g
F P
s
P
p
.002 w
.56766 .52772 m .53709 .54662 L p
.56765 .52765 L 1 g
F P
s
P
p
.56766 .52772 m .56765 .52758 L .56765 .52754 L 1 g
F
P
p
.002 w
.56766 .52772 m .56789 .52757 L .56766 .52783 L p
1 g
F P
s
P
p
.56766 .52783 m .56766 .52777 L .56766 .52772 L 1 g
F
P
p
.56766 .52777 m .56765 .52758 L .56766 .52772 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54411 .55315 m .53709 .54662 L .56766 .52772 L p
1 g
F P
s
P
p
.002 w
.56766 .52783 m .54411 .55315 L p
.56766 .52772 L 1 g
F P
s
P
p
.002 w
.55352 .55672 m .54411 .55315 L .56766 .52783 L p
1 g
F P
s
P
p
.002 w
.56766 .52783 m .56789 .52757 L .56767 .52804 L p
1 g
F P
s
P
p
.002 w
.56767 .52804 m .55352 .55672 L p
.56766 .52783 L 1 g
F P
s
P
p
.56767 .52824 m .56779 .52916 L .56765 .52758 L 1 g
F
P
p
.56705 .52057 m .56715 .52178 L .56705 .52058 L 1 g
F
P
p
.002 w
.55352 .55672 m .56767 .52804 L p
.56769 .52897 L 1 g
F P
s
P
p
.002 w
.56769 .52901 m .56769 .52901 L p
.56441 .53899 L 1 g
F P
s
P
p
.56445 .53877 m .56441 .53899 L .56769 .52901 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56769 .52901 L p
1 g
F P
s
P
p
.56441 .53899 m .56257 .5491 L .56769 .52901 L 1 g
F
P
p
.002 w
.56789 .52757 m .56802 .52801 L p
.56791 .52835 L 1 g
F P
s
P
p
.002 w
.56769 .52901 m .56779 .52916 L p
.56767 .52824 L 1 g
F P
s
P
p
.002 w
.56789 .52757 m .56761 .52705 L p
.56752 .52608 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55748 .49142 m .55661 .4905 L p
.56583 .50814 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55748 .49142 L p
1 g
F P
s
P
p
.002 w
.55283 .50025 m .53853 .47498 L p
.5511 .48523 L 1 g
F P
s
P
p
.5511 .48523 m .55642 .49039 L .55283 .50025 L 1 g
F
P
p
.002 w
.5638 .4956 m .5603 .49708 L p
.55665 .48976 L 1 g
F P
s
P
p
.54174 .47608 m .55748 .49142 L .54995 .48412 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.5603 .49708 m .55283 .50025 L p
.55665 .48976 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55748 .49142 L p
1 g
F P
s
P
p
.56583 .50814 m .56713 .51061 L .55748 .49142 L 1 g
F
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.54376 .4774 m .5638 .4956 L .5511 .48523 L 1 g
F
P
p
.54236 .47675 m .5511 .48523 L .53853 .47498 L 1 g
F
P
p
.002 w
.54236 .47675 m .54174 .47608 L p
.54995 .48412 L 1 g
F P
s
P
p
.54376 .4774 m .5511 .48523 L .54236 .47675 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54236 .47675 L p
1 g
F P
s
P
p
.54995 .48412 m .55834 .49233 L .54236 .47675 L 1 g
F
P
p
.002 w
.55748 .49142 m .55834 .49233 L p
.54995 .48412 L 1 g
F P
s
P
p
.5511 .48523 m .55665 .48976 L .55642 .49039 L 1 g
F
P
p
.002 w
.56537 .50785 m .56789 .52757 L p
.5603 .49708 L 1 g
F P
s
P
p
.002 w
.58537 .54792 m .57529 .55393 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.59347 .53956 m .58537 .54792 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.59874 .52972 m .59347 .53956 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.6006 .51944 m .59874 .52972 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.59883 .5098 m .6006 .51944 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.59358 .50185 m .59883 .5098 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.58536 .49648 m .59358 .50185 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.57506 .4943 m .58536 .49648 L .56789 .52757 L closepath p
1 g
F P
s
P
p
.002 w
.56779 .52916 m .56854 .53025 L p
.56705 .52058 L 1 g
F P
s
P
p
.002 w
.55283 .50025 m .5603 .49708 L p
.56752 .52608 L 1 g
F P
s
P
p
.002 w
.56761 .52705 m .55283 .50025 L p
.56752 .52608 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56608 .50937 L p
1 g
F P
s
P
p
.56705 .52057 m .56854 .53025 L .56608 .50937 L 1 g
F
P
p
.002 w
.56608 .50937 m .56713 .51061 L p
.56267 .5021 L 1 g
F P
s
P
p
.002 w
.5638 .4956 m .57506 .4943 L .57001 .51775 L p
1 g
F P
s
P
p
.002 w
.51709 .48511 m .53307 .47241 L p
.55283 .50025 L 1 g
F P
s
P
p
.52214 .46667 m .54236 .47675 L .53727 .47439 L 1 g
F
P
p
.002 w
.53853 .47498 m .55283 .50025 L p
.53307 .47241 L 1 g
F P
s
P
p
.52214 .46667 m .54276 .4772 L .5364 .47405 L 1 g
F
P
p
.002 w
.53307 .47241 m .51709 .48511 L p
.526 .46891 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46387 m .52327 .46756 L .49463 .46476 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46714 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46714 L .5101 .46534 L 1 g
F
P
p
.51875 .46661 m .52327 .46756 L .5 .46387 L 1 g
F
P
p
.52327 .46756 m .526 .46891 L .49463 .46476 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .4634 L p
.5101 .46534 L 1 g
F P
s
P
p
.5101 .46534 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.48995 .46053 m .50322 .46333 L .5 .46387 L 1 g
F
P
p
.47786 .46667 m .5 .46387 L .49324 .465 L 1 g
F
P
p
.002 w
.49463 .46476 m .49241 .46276 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.49241 .46276 m .48995 .46053 L p
.5 .46387 L 1 g
F P
s
P
p
.50322 .46333 m .51875 .46661 L .5 .46387 L 1 g
F
P
p
.002 w
.52242 .46714 m .52214 .46667 L p
.5364 .47405 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.48995 .46053 m .5175 .43858 L .53583 .47021 L p
1 g
F P
s
P
p
.002 w
.52242 .46714 m .52282 .46778 L p
.5101 .46534 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52242 .46714 L p
1 g
F P
s
P
p
.5364 .47405 m .54302 .47747 L .52242 .46714 L 1 g
F
P
p
.52327 .46756 m .53583 .47021 L .526 .46891 L 1 g
F
P
p
.002 w
.53307 .47241 m .53583 .47021 L .53853 .47498 L p
1 g
F P
s
P
p
.53727 .47439 m .53853 .47498 L .54276 .4772 L 1 g
F
P
p
.002 w
.54236 .47675 m .5424 .4768 L p
.53853 .47498 L 1 g
F P
s
P
p
.002 w
.5424 .4768 m .54276 .4772 L p
.53853 .47498 L 1 g
F P
s
P
p
.002 w
.53853 .47498 m .53583 .47021 L p
.54376 .4774 L 1 g
F P
s
P
p
.002 w
.53583 .47021 m .53307 .47241 L p
.526 .46891 L 1 g
F P
s
P
p
.002 w
.54276 .4772 m .54302 .47747 L p
.5364 .47405 L 1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .46426 L p
.49324 .465 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46426 L .49396 .46503 L 1 g
F
P
p
.002 w
.48925 .46152 m .48606 .46604 L p
.4798 .46606 L 1 g
F P
s
P
p
.002 w
.48606 .46604 m .47027 .4884 L p
.47945 .46688 L 1 g
F P
s
P
p
.4798 .46606 m .48606 .46604 L .47945 .46688 L 1 g
F
P
p
.002 w
.5 .46426 m .5 .46442 L p
.49396 .46503 L 1 g
F P
s
P
p
.002 w
.48606 .46604 m .48995 .46053 L .49463 .46476 L p
1 g
F P
s
P
p
.002 w
.45774 .47665 m .45826 .47608 L p
.46594 .47271 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.47021 .4645 m .48995 .46053 L .4798 .46606 L 1 g
F
P
p
.45774 .47665 m .4798 .46606 L .45442 .47988 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46712 L p
1 g
F P
s
P
p
.45826 .47608 m .47759 .46712 L .46594 .47271 L 1 g
F
P
p
.47021 .4645 m .4798 .46606 L .45774 .47665 L 1 g
F
P
p
.002 w
.47759 .46712 m .47718 .46778 L p
.46594 .47271 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46712 L p
1 g
F P
s
P
p
.49396 .46503 m .5 .46442 L .47759 .46712 L 1 g
F
P
p
.47793 .46708 m .4798 .46606 L .47945 .46688 L 1 g
F
P
p
.002 w
.48995 .46053 m .48925 .46152 L p
.4798 .46606 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45774 .47665 L p
1 g
F P
s
P
p
.46594 .47271 m .47718 .46778 L .45774 .47665 L 1 g
F
P
p
.002 w
.45774 .47665 m .45698 .47747 L p
.45137 .48285 L 1 g
F P
s
P
p
.44339 .4905 m .45774 .47665 L .45137 .48285 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45442 .47988 m .43788 .471 L p
.47021 .4645 L 1 g
F P
s
P
p
.002 w
.42711 .50631 m .43788 .471 L .45442 .47988 L p
1 g
F P
s
P
p
.002 w
.44283 .4911 m .44166 .49233 L p
.43762 .50178 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44283 .4911 L p
1 g
F P
s
P
p
.44911 .48502 m .45698 .47747 L .44283 .4911 L 1 g
F
P
p
.43393 .50936 m .47027 .4884 L .43361 .51215 L 1 g
F
P
p
.4343 .50611 m .43589 .50533 L .43393 .50936 L 1 g
F
P
p
.43589 .50533 m .47027 .4884 L .43393 .50936 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43393 .50936 L p
1 g
F P
s
P
p
.43762 .50178 m .44166 .49233 L .43393 .50936 L 1 g
F
P
p
.002 w
.47027 .4884 m .46068 .51881 L .43361 .51215 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43154 .53014 L p
1 g
F P
s
P
p
.002 w
.43154 .53014 m .43277 .52835 L p
.43282 .51895 L 1 g
F P
s
P
p
.43282 .51895 m .43287 .51061 L .43154 .53014 L 1 g
F
P
p
.002 w
.43277 .52835 m .43346 .52734 L p
.4332 .51995 L 1 g
F P
s
P
p
.4332 .51995 m .43287 .51061 L .43277 .52835 L 1 g
F
P
p
.43639 .54057 m .43277 .52835 L .46068 .51881 L 1 g
F
P
p
.002 w
.43361 .51215 m .46068 .51881 L p
.43277 .52835 L 1 g
F P
s
P
p
.002 w
.43277 .52835 m .43146 .53025 L p
.43599 .53921 L 1 g
F P
s
P
p
.002 w
.43833 .54739 m .43838 .54729 L p
.43232 .53296 L 1 g
F P
s
P
p
.4363 .54025 m .43232 .53296 L .43838 .54729 L 1 g
F
P
p
.45146 .56129 m .43833 .54739 L .44603 .55657 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.43639 .54057 m .46068 .51881 L .43875 .54784 L 1 g
F
P
p
.43838 .54729 m .43875 .54784 L .4386 .54803 L 1 g
F
P
p
.43639 .54057 m .43875 .54784 L .43838 .54729 L 1 g
F
P
p
.45101 .56251 m .44193 .556 L .43888 .54804 L 1 g
F
P
p
.002 w
.43075 .54799 m .4386 .54803 L p
.44193 .556 L 1 g
F P
s
P
p
.002 w
.4386 .54803 m .43888 .54804 L p
.44193 .556 L 1 g
F P
s
P
p
.002 w
.43833 .54739 m .43743 .5491 L p
.44252 .55352 L 1 g
F P
s
P
p
.44603 .55657 m .43888 .54804 L .44252 .55352 L 1 g
F
P
p
.002 w
.43888 .54804 m .4386 .54803 L p
.43875 .54784 L 1 g
F P
s
P
p
.43888 .54804 m .43833 .54739 L .44252 .55352 L 1 g
F
P
p
.002 w
.43838 .54729 m .43833 .54739 L p
.43871 .54779 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.46068 .51881 m .46204 .54817 L .43888 .54804 L p
1 g
F P
s
P
p
.43875 .54784 m .46068 .51881 L .43888 .54804 L 1 g
F
P
p
.002 w
.43146 .53025 m .43232 .53296 L p
.4363 .54025 L 1 g
F P
s
P
p
.43599 .53921 m .43146 .53025 L .4363 .54025 L 1 g
F
P
p
.002 w
.43232 .53296 m .43743 .5491 L .43833 .54739 L p
1 g
F P
s
P
p
.002 w
.43888 .54804 m .46204 .54817 L p
.45101 .56251 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45101 .56251 L p
1 g
F P
s
P
p
.44603 .55657 m .43743 .5491 L .45101 .56251 L 1 g
F
P
p
.002 w
.45101 .56251 m .45002 .56518 L p
.46065 .56943 L 1 g
F P
s
P
p
.002 w
.44375 .57995 m .42813 .54797 L .43075 .54799 L p
1 g
F P
s
P
p
.002 w
.46204 .54817 m .47386 .57322 L .46782 .57457 L p
1 g
F P
s
P
p
.45297 .56392 m .46204 .54817 L .46782 .57457 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46824 .57487 L p
1 g
F P
s
P
p
.002 w
.46824 .57487 m .46825 .5748 L p
.46786 .57459 L 1 g
F P
s
P
p
.46786 .57459 m .45002 .56518 L .46824 .57487 L 1 g
F
P
p
.45193 .56594 m .45002 .56518 L .46825 .5748 L 1 g
F
P
p
.47349 .57642 m .46825 .5748 L .47386 .57322 L 1 g
F
P
p
.002 w
.46782 .57457 m .47386 .57322 L p
.46825 .5748 L 1 g
F P
s
P
p
.002 w
.46825 .5748 m .4678 .57686 L p
.47752 .57766 L 1 g
F P
s
P
p
.47964 .57831 m .4678 .57686 L .48902 .5812 L 1 g
F
P
p
.47752 .57766 m .47639 .57757 L .47964 .57831 L 1 g
F
P
p
.47639 .57757 m .4678 .57686 L .47964 .57831 L 1 g
F
P
p
.48907 .58048 m .47386 .57322 L .49849 .5806 L 1 g
F
P
p
.002 w
.47964 .57831 m .47386 .57322 L p
.48907 .58048 L 1 g
F P
s
P
p
.002 w
.48902 .5812 m .48907 .58048 L p
.47964 .57831 L 1 g
F P
s
P
p
.002 w
.47386 .57322 m .50535 .56201 L p
.49849 .5806 L 1 g
F P
s
P
p
.002 w
.50999 .58095 m .51029 .58074 L p
.51035 .58086 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58075 L p
1 g
F P
s
P
p
.002 w
.51095 .58075 m .51095 .5807 L p
.51053 .58075 L 1 g
F P
s
P
p
.51053 .58075 m .48889 .583 L .51095 .58075 L 1 g
F
P
p
.50076 .58063 m .49562 .58165 L .51029 .58074 L 1 g
F
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.50535 .56201 m .51934 .57465 L .51029 .58074 L p
1 g
F P
s
P
p
.49849 .5806 m .50535 .56201 L .51029 .58074 L 1 g
F
P
p
.002 w
.51095 .5807 m .51111 .583 L p
.52019 .57834 L 1 g
F P
s
P
p
.49562 .58165 m .48889 .583 L .51095 .5807 L 1 g
F
P
p
.002 w
.48889 .583 m .48857 .5874 L p
.50866 .58348 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .50452 .583 L p
.50866 .58348 L 1 g
F P
s
P
p
.002 w
.50452 .583 m .48889 .583 L p
.50866 .58348 L 1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51117 .58377 L p
1 g
F P
s
P
p
.002 w
.51117 .58377 m .51111 .583 L p
.50866 .58348 L 1 g
F P
s
P
p
.50866 .58348 m .48857 .5874 L .51117 .58377 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .5812 L p
1 g
F P
s
P
p
.002 w
.47386 .57322 m .47964 .57831 L p
.47349 .57642 L 1 g
F P
s
P
p
.002 w
.56758 .29191 m .62256 .3072 L .6256 .33314 L p
1 g
F P
s
P
p
.002 w
.62256 .3072 m .56758 .29191 L .55865 .26929 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.42813 .54797 m .44375 .57995 L .41602 .58211 L p
1 g
F P
s
P
p
.002 w
.41602 .58211 m .397 .54425 L .42813 .54797 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50989 .44465 L
s
P
p
.004 w
.54707 .49781 m
.55023 .50232 L
s
P
p
.002 w
.49429 .27358 m .55865 .26929 L .56758 .29191 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.43107 .29879 m .37737 .34197 L .36503 .3252 L p
1 g
F P
s
P
p
.002 w
.36503 .3252 m .41925 .28156 L .43107 .29879 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49429 .27358 m .43107 .29879 L .41925 .28156 L p
1 g
F P
s
P
p
.002 w
.65416 .49607 m .64975 .46841 L .66811 .44636 L p
1 g
F P
s
P
p
.002 w
.64996 .41624 m .66811 .44636 L .64975 .46841 L p
1 g
F P
s
P
p
.002 w
.66811 .44636 m .64996 .41624 L .65981 .38839 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.39382 .49936 m .397 .54425 L .36965 .53724 L p
1 g
F P
s
P
p
.002 w
.36965 .53724 m .36556 .48659 L .39382 .49936 L p
1 g
F P
s
P
p
.002 w
.62584 .52885 m .62966 .50879 L .65416 .49607 L p
1 g
F P
s
P
p
.002 w
.64975 .46841 m .65416 .49607 L .62966 .50879 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.57529 .55393 m .58537 .54792 L .59975 .56413 L p
1 g
F P
s
P
p
.002 w
.59975 .56413 m .58022 .57581 L .57529 .55393 L p
1 g
F P
s
P
p
.004 w
.59622 .56807 m
.60861 .58578 L
s
P
p
.002 w
.6155 .54794 m .59975 .56413 L .58537 .54792 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.56429 .55698 m .57529 .55393 L .58022 .57581 L p
1 g
F P
s
P
p
.002 w
.58022 .57581 m .55887 .58181 L .56429 .55698 L p
1 g
F P
s
P
p
.002 w
.62492 .36272 m .65981 .38839 L .64996 .41624 L p
1 g
F P
s
P
p
.002 w
.65981 .38839 m .62492 .36272 L .6256 .33314 L p
1 g
F P
s
P
p
.002 w
.58537 .54792 m .59347 .53956 L .6155 .54794 L p
1 g
F P
s
P
p
.002 w
.62584 .52885 m .6155 .54794 L .59347 .53956 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.38074 .43356 m .36556 .48659 L .342 .47247 L p
1 g
F P
s
P
p
.002 w
.342 .47247 m .35802 .41497 L .38074 .43356 L p
1 g
F P
s
P
p
.002 w
.39387 .36201 m .35802 .41497 L .34017 .39736 L p
1 g
F P
s
P
p
.002 w
.34017 .39736 m .37737 .34197 L .39387 .36201 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.59347 .53956 m .59874 .52972 L .62584 .52885 L p
1 g
F P
s
P
p
.002 w
.62966 .50879 m .62584 .52885 L .59874 .52972 L p
1 g
F P
s
P
p
.002 w
.57471 .31941 m .6256 .33314 L .62492 .36272 L p
1 g
F P
s
P
p
.002 w
.6256 .33314 m .57471 .31941 L .56758 .29191 L p
1 g
F P
s
P
p
.002 w
.56758 .29191 m .50596 .29632 L .49429 .27358 L p
1 g
F P
s
P
p
.002 w
.43107 .29879 m .49429 .27358 L .50596 .29632 L p
1 g
F P
s
P
p
.002 w
.62966 .50879 m .62643 .48982 L .64975 .46841 L p
1 g
F P
s
P
p
.002 w
.63533 .44512 m .64975 .46841 L .62643 .48982 L p
1 g
F P
s
P
p
.002 w
.64975 .46841 m .63533 .44512 L .64996 .41624 L p
1 g
F P
s
P
p
.002 w
.50596 .29632 m .56758 .29191 L .57471 .31941 L p
1 g
F P
s
P
p
.002 w
.4259 .51025 m .42813 .54797 L .397 .54425 L p
1 g
F P
s
P
p
.002 w
.397 .54425 m .39382 .49936 L .4259 .51025 L p
1 g
F P
s
P
p
.002 w
.59874 .52972 m .6006 .51944 L .62966 .50879 L p
1 g
F P
s
P
p
.002 w
.62643 .48982 m .62966 .50879 L .6006 .51944 L p
1 g
F P
s
P
p
.002 w
.4454 .32064 m .39387 .36201 L .37737 .34197 L p
1 g
F P
s
P
p
.002 w
.37737 .34197 m .43107 .29879 L .4454 .32064 L p
1 g
F P
s
P
p
.002 w
.6204 .39503 m .64996 .41624 L .63533 .44512 L p
1 g
F P
s
P
p
.002 w
.64996 .41624 m .6204 .39503 L .62492 .36272 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.50596 .29632 m .4454 .32064 L .43107 .29879 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.40766 .45247 m .39382 .49936 L .36556 .48659 L p
1 g
F P
s
P
p
.002 w
.36556 .48659 m .38074 .43356 L .40766 .45247 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.53709 .54662 m .54411 .55315 L .51934 .57465 L p
1 g
F P
s
P
p
.002 w
.51934 .57465 m .50535 .56201 L .53709 .54662 L p
1 g
F P
s
P
p
.002 w
.49751 .54475 m .50535 .56201 L .47386 .57322 L p
1 g
F P
s
P
p
.002 w
.47386 .57322 m .46204 .54817 L .49751 .54475 L p
1 g
F P
s
P
p
.002 w
.41411 .38472 m .38074 .43356 L .35802 .41497 L p
1 g
F P
s
P
p
.002 w
.35802 .41497 m .39387 .36201 L .41411 .38472 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.57972 .35099 m .62492 .36272 L .6204 .39503 L p
1 g
F P
s
P
p
.002 w
.62492 .36272 m .57972 .35099 L .57471 .31941 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.6006 .51944 m .59883 .5098 L .62643 .48982 L p
1 g
F P
s
P
p
.002 w
.61633 .47402 m .62643 .48982 L .59883 .5098 L p
1 g
F P
s
P
p
.002 w
.62643 .48982 m .61633 .47402 L .63533 .44512 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.61211 .42893 m .63533 .44512 L .61633 .47402 L p
1 g
F P
s
P
p
.002 w
.63533 .44512 m .61211 .42893 L .6204 .39503 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.57471 .31941 m .51777 .32384 L .50596 .29632 L p
1 g
F P
s
P
p
.002 w
.4454 .32064 m .50596 .29632 L .51777 .32384 L p
1 g
F P
s
P
p
.002 w
.51777 .32384 m .57471 .31941 L .57972 .35099 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.53325 .5378 m .53709 .54662 L .50535 .56201 L p
1 g
F P
s
P
p
.002 w
.50535 .56201 m .49751 .54475 L .53325 .5378 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59883 .5098 m .59358 .50185 L .61633 .47402 L p
1 g
F P
s
P
p
.002 w
.43788 .471 m .4259 .51025 L .39382 .49936 L p
1 g
F P
s
P
p
.002 w
.39382 .49936 m .40766 .45247 L .43788 .471 L p
1 g
F P
s
P
p
.002 w
.46182 .34648 m .41411 .38472 L .39387 .36201 L p
1 g
F P
s
P
p
.002 w
.39387 .36201 m .4454 .32064 L .46182 .34648 L p
1 g
F P
s
P
p
.002 w
.58235 .38559 m .6204 .39503 L .61211 .42893 L p
1 g
F P
s
P
p
.002 w
.6204 .39503 m .58235 .38559 L .57972 .35099 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.60029 .46318 m .61633 .47402 L .59358 .50185 L p
1 g
F P
s
P
p
.002 w
.61633 .47402 m .60029 .46318 L .61211 .42893 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.49685 .52468 m .49751 .54475 L .46204 .54817 L p
1 g
F P
s
P
p
.002 w
.46204 .54817 m .46068 .51881 L .49685 .52468 L p
1 g
F P
s
P
p
.002 w
.51777 .32384 m .46182 .34648 L .4454 .32064 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.43745 .40933 m .40766 .45247 L .38074 .43356 L p
1 g
F P
s
P
p
.002 w
.38074 .43356 m .41411 .38472 L .43745 .40933 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.59358 .50185 m .58536 .49648 L .60029 .46318 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53305 .52763 m .53325 .5378 L .49751 .54475 L p
1 g
F P
s
P
p
.002 w
.49751 .54475 m .49685 .52468 L .53305 .52763 L p
1 g
F P
s
P
p
.002 w
.52928 .35526 m .57972 .35099 L .58235 .38559 L p
1 g
F P
s
P
p
.002 w
.57972 .35099 m .52928 .35526 L .51777 .32384 L p
1 g
F P
s
P
p
.002 w
.58245 .42193 m .61211 .42893 L .60029 .46318 L p
1 g
F P
s
P
p
.002 w
.61211 .42893 m .58245 .42193 L .58235 .38559 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.46182 .34648 m .51777 .32384 L .52928 .35526 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.58536 .49648 m .57506 .4943 L .57999 .45864 L p
1 g
F P
s
P
p
.002 w
.57999 .45864 m .60029 .46318 L .58536 .49648 L p
1 g
F P
s
P
p
.002 w
.60029 .46318 m .57999 .45864 L .58245 .42193 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.53655 .51722 m .53305 .52763 L .49685 .52468 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57506 .4943 m .5638 .4956 L .55765 .46104 L p
1 g
F P
s
P
p
.002 w
.55765 .46104 m .57999 .45864 L .57506 .4943 L p
1 g
F P
s
P
p
.002 w
.47976 .37548 m .43745 .40933 L .41411 .38472 L p
1 g
F P
s
P
p
.002 w
.41411 .38472 m .46182 .34648 L .47976 .37548 L p
1 g
F P
s
P
p
.002 w
.50359 .50401 m .49685 .52468 L .46068 .51881 L p
1 g
F P
s
P
p
.002 w
.46068 .51881 m .47027 .4884 L .50359 .50401 L p
1 g
F P
s
P
p
.002 w
.46305 .43493 m .43788 .471 L .40766 .45247 L p
1 g
F P
s
P
p
.002 w
.40766 .45247 m .43745 .40933 L .46305 .43493 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49685 .52468 m .50359 .50401 L .53655 .51722 L p
1 g
F P
s
P
p
.002 w
.5434 .50774 m .53655 .51722 L .50359 .50401 L p
1 g
F P
s
P
p
.002 w
.54005 .38948 m .58235 .38559 L .58245 .42193 L p
1 g
F P
s
P
p
.002 w
.58235 .38559 m .54005 .38948 L .52928 .35526 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.52928 .35526 m .47976 .37548 L .46182 .34648 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.53583 .47021 m .55765 .46104 L .5638 .4956 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55283 .50025 m .5434 .50774 L .51709 .48511 L p
1 g
F P
s
P
p
.002 w
.50359 .50401 m .51709 .48511 L .5434 .50774 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57999 .45864 m .55765 .46104 L .54963 .42521 L p
1 g
F P
s
P
p
.002 w
.54963 .42521 m .58245 .42193 L .57999 .45864 L p
1 g
F P
s
P
p
.002 w
.58245 .42193 m .54963 .42521 L .54005 .38948 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47976 .37548 m .52928 .35526 L .54005 .38948 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.43788 .471 m .46305 .43493 L .48995 .46053 L p
1 g
F P
s
P
p
.002 w
.51709 .48511 m .50359 .50401 L .47027 .4884 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49856 .40658 m .46305 .43493 L .43745 .40933 L p
1 g
F P
s
P
p
.002 w
.43745 .40933 m .47976 .37548 L .49856 .40658 L p
1 g
F P
s
P
p
.002 w
.55765 .46104 m .53583 .47021 L .5175 .43858 L p
1 g
F P
s
P
p
.002 w
.5175 .43858 m .54963 .42521 L .55765 .46104 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54005 .38948 m .49856 .40658 L .47976 .37548 L p
1 g
F P
s
P
p
.002 w
.49856 .40658 m .54005 .38948 L .54963 .42521 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54963 .42521 m .5175 .43858 L .49856 .40658 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.5175 .43858 m .48995 .46053 L .46305 .43493 L p
1 g
F P
s
P
p
.002 w
.46305 .43493 m .49856 .40658 L .5175 .43858 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.5913 .56103 m
.59622 .56807 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .44118 .72308 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60861 .58578 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.320155)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.320155)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48213 .46177 m .52131 .4468 L .5079 .4216 L p
1 g
F P
s
P
p
.002 w
.5079 .4216 m .47522 .43406 L .48213 .46177 L p
1 g
F P
s
P
p
.002 w
.53606 .40139 m .5079 .4216 L .52131 .4468 L p
1 g
F P
s
P
p
.002 w
.47522 .43406 m .5079 .4216 L .49428 .39659 L p
1 g
F P
s
P
p
.002 w
.5079 .4216 m .53606 .40139 L .51609 .38084 L p
1 g
F P
s
P
p
.002 w
.51609 .38084 m .49428 .39659 L .5079 .4216 L p
1 g
F P
s
P
p
.002 w
.44122 .46619 m .48213 .46177 L .47522 .43406 L p
1 g
F P
s
P
p
.002 w
.47522 .43406 m .44111 .43758 L .44122 .46619 L p
1 g
F P
s
P
p
.002 w
.44111 .43758 m .47522 .43406 L .46891 .40625 L p
1 g
F P
s
P
p
.002 w
.49428 .39659 m .46891 .40625 L .47522 .43406 L p
1 g
F P
s
P
p
.002 w
.48952 .48889 m .53427 .47174 L .52131 .4468 L p
1 g
F P
s
P
p
.002 w
.52131 .4468 m .48213 .46177 L .48952 .48889 L p
1 g
F P
s
P
p
.002 w
.55517 .42267 m .52131 .4468 L .53427 .47174 L p
1 g
F P
s
P
p
.002 w
.52131 .4468 m .55517 .42267 L .53606 .40139 L p
1 g
F P
s
P
p
.002 w
.46891 .40625 m .49428 .39659 L .48071 .37223 L p
1 g
F P
s
P
p
.002 w
.49428 .39659 m .51609 .38084 L .49562 .36138 L p
1 g
F P
s
P
p
.002 w
.49562 .36138 m .48071 .37223 L .49428 .39659 L p
1 g
F P
s
P
p
.002 w
.44277 .49416 m .48952 .48889 L .48213 .46177 L p
1 g
F P
s
P
p
.002 w
.48213 .46177 m .44122 .46619 L .44277 .49416 L p
1 g
F P
s
P
p
.002 w
.46891 .40625 m .44243 .40885 L .44111 .43758 L p
1 g
F P
s
P
p
.002 w
.44243 .40885 m .46891 .40625 L .4633 .37883 L p
1 g
F P
s
P
p
.002 w
.48071 .37223 m .4633 .37883 L .46891 .40625 L p
1 g
F P
s
P
p
.002 w
.55697 .37528 m .53606 .40139 L .55517 .42267 L p
1 g
F P
s
P
p
.002 w
.53606 .40139 m .55697 .37528 L .53215 .36048 L p
1 g
F P
s
P
p
.002 w
.53215 .36048 m .51609 .38084 L .53606 .40139 L p
1 g
F P
s
P
p
.002 w
.51609 .38084 m .53215 .36048 L .50651 .34738 L p
1 g
F P
s
P
p
.002 w
.50651 .34738 m .49562 .36138 L .51609 .38084 L p
1 g
F P
s
P
p
.002 w
.49725 .5149 m .54656 .49597 L .53427 .47174 L p
1 g
F P
s
P
p
.002 w
.53427 .47174 m .48952 .48889 L .49725 .5149 L p
1 g
F P
s
P
p
.002 w
.57307 .44428 m .53427 .47174 L .54656 .49597 L p
1 g
F P
s
P
p
.002 w
.53427 .47174 m .57307 .44428 L .55517 .42267 L p
1 g
F P
s
P
p
.002 w
.58051 .39149 m .55517 .42267 L .57307 .44428 L p
1 g
F P
s
P
p
.002 w
.55517 .42267 m .58051 .39149 L .55697 .37528 L p
1 g
F P
s
P
p
.002 w
.40237 .45943 m .44122 .46619 L .44111 .43758 L p
1 g
F P
s
P
p
.002 w
.44111 .43758 m .40882 .43167 L .40237 .45943 L p
1 g
F P
s
P
p
.002 w
.40882 .43167 m .44111 .43758 L .44243 .40885 L p
1 g
F P
s
P
p
.002 w
.44575 .52094 m .49725 .5149 L .48952 .48889 L p
1 g
F P
s
P
p
.002 w
.48952 .48889 m .44277 .49416 L .44575 .52094 L p
1 g
F P
s
P
p
.002 w
.4633 .37883 m .48071 .37223 L .46742 .34896 L p
1 g
F P
s
P
p
.002 w
.48071 .37223 m .49562 .36138 L .47502 .3434 L p
1 g
F P
s
P
p
.002 w
.47502 .3434 m .46742 .34896 L .48071 .37223 L p
1 g
F P
s
P
p
.002 w
.44243 .40885 m .41746 .40406 L .40882 .43167 L p
1 g
F P
s
P
p
.002 w
.41746 .40406 m .44243 .40885 L .44516 .38053 L p
1 g
F P
s
P
p
.002 w
.4633 .37883 m .44516 .38053 L .44243 .40885 L p
1 g
F P
s
P
p
.002 w
.44516 .38053 m .4633 .37883 L .45853 .35233 L p
1 g
F P
s
P
p
.002 w
.46742 .34896 m .45853 .35233 L .4633 .37883 L p
1 g
F P
s
P
p
.002 w
.39826 .48679 m .44277 .49416 L .44122 .46619 L p
1 g
F P
s
P
p
.002 w
.44122 .46619 m .40237 .45943 L .39826 .48679 L p
1 g
F P
s
P
p
.002 w
.49562 .36138 m .50651 .34738 L .48052 .33622 L p
1 g
F P
s
P
p
.002 w
.48052 .33622 m .47502 .3434 L .49562 .36138 L p
1 g
F P
s
P
p
.002 w
.44516 .38053 m .42812 .37711 L .41746 .40406 L p
1 g
F P
s
P
p
.002 w
.42812 .37711 m .44516 .38053 L .44926 .35316 L p
1 g
F P
s
P
p
.002 w
.45853 .35233 m .44926 .35316 L .44516 .38053 L p
1 g
F P
s
P
p
.002 w
.54656 .49597 m .5894 .46584 L .57307 .44428 L p
1 g
F P
s
P
p
.002 w
.6023 .40883 m .57307 .44428 L .5894 .46584 L p
1 g
F P
s
P
p
.002 w
.57307 .44428 m .6023 .40883 L .58051 .39149 L p
1 g
F P
s
P
p
.002 w
.54075 .33748 m .53215 .36048 L .55697 .37528 L p
1 g
F P
s
P
p
.002 w
.53215 .36048 m .54075 .33748 L .5122 .33161 L p
1 g
F P
s
P
p
.002 w
.5122 .33161 m .50651 .34738 L .53215 .36048 L p
1 g
F P
s
P
p
.002 w
.56842 .34566 m .55697 .37528 L .58051 .39149 L p
1 g
F P
s
P
p
.002 w
.55697 .37528 m .56842 .34566 L .54075 .33748 L p
1 g
F P
s
P
p
.002 w
.50519 .5393 m .55791 .51901 L .54656 .49597 L p
1 g
F P
s
P
p
.002 w
.54656 .49597 m .49725 .5149 L .50519 .5393 L p
1 g
F P
s
P
p
.002 w
.5894 .46584 m .54656 .49597 L .55791 .51901 L p
1 g
F P
s
P
p
.002 w
.50651 .34738 m .5122 .33161 L .48333 .32818 L p
1 g
F P
s
P
p
.002 w
.48333 .32818 m .48052 .33622 L .50651 .34738 L p
1 g
F P
s
P
p
.002 w
.45015 .54599 m .50519 .5393 L .49725 .5149 L p
1 g
F P
s
P
p
.002 w
.49725 .5149 m .44575 .52094 L .45015 .54599 L p
1 g
F P
s
P
p
.002 w
.39664 .51322 m .44575 .52094 L .44277 .49416 L p
1 g
F P
s
P
p
.002 w
.44277 .49416 m .39826 .48679 L .39664 .51322 L p
1 g
F P
s
P
p
.002 w
.3816 .41664 m .40882 .43167 L .41746 .40406 L p
1 g
F P
s
P
p
.002 w
.41746 .40406 m .39656 .39218 L .3816 .41664 L p
1 g
F P
s
P
p
.002 w
.39656 .39218 m .41746 .40406 L .42812 .37711 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .45853 .35233 L .46742 .34896 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .46742 .34896 L .47502 .3434 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .44926 .35316 L .45853 .35233 L closepath p
1 g
F P
s
P
p
.002 w
.59465 .35604 m .58051 .39149 L .6023 .40883 L p
1 g
F P
s
P
p
.002 w
.58051 .39149 m .59465 .35604 L .56842 .34566 L p
1 g
F P
s
P
p
.002 w
.42812 .37711 m .41397 .36883 L .39656 .39218 L p
1 g
F P
s
P
p
.002 w
.44926 .35316 m .4406 .35134 L .42812 .37711 L p
1 g
F P
s
P
p
.002 w
.41397 .36883 m .42812 .37711 L .4406 .35134 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .47502 .3434 L .48052 .33622 L closepath p
1 g
F P
s
P
p
.002 w
.36942 .44174 m .40237 .45943 L .40882 .43167 L p
1 g
F P
s
P
p
.002 w
.40882 .43167 m .3816 .41664 L .36942 .44174 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .4406 .35134 L .44926 .35316 L closepath p
1 g
F P
s
P
p
.002 w
.55791 .51901 m .60382 .48692 L .5894 .46584 L p
1 g
F P
s
P
p
.002 w
.62188 .42698 m .5894 .46584 L .60382 .48692 L p
1 g
F P
s
P
p
.002 w
.5894 .46584 m .62188 .42698 L .6023 .40883 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .48052 .33622 L .48333 .32818 L closepath p
1 g
F P
s
P
p
.002 w
.4406 .35134 m .43347 .34705 L .41397 .36883 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .43347 .34705 L .4406 .35134 L closepath p
1 g
F P
s
P
p
.002 w
.51201 .3157 m .5122 .33161 L .54075 .33748 L p
1 g
F P
s
P
p
.002 w
.5122 .33161 m .51201 .3157 L .48312 .32012 L p
1 g
F P
s
P
p
.002 w
.48312 .32012 m .48333 .32818 L .5122 .33161 L p
1 g
F P
s
P
p
.002 w
.54079 .31412 m .54075 .33748 L .56842 .34566 L p
1 g
F P
s
P
p
.002 w
.54075 .33748 m .54079 .31412 L .51201 .3157 L p
1 g
F P
s
P
p
.002 w
.36034 .46698 m .39826 .48679 L .40237 .45943 L p
1 g
F P
s
P
p
.002 w
.40237 .45943 m .36942 .44174 L .36034 .46698 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .48333 .32818 L .48312 .32012 L closepath p
1 g
F P
s
P
p
.002 w
.61889 .36844 m .6023 .40883 L .62188 .42698 L p
1 g
F P
s
P
p
.002 w
.6023 .40883 m .61889 .36844 L .59465 .35604 L p
1 g
F P
s
P
p
.002 w
.3976 .53812 m .45015 .54599 L .44575 .52094 L p
1 g
F P
s
P
p
.002 w
.44575 .52094 m .39664 .51322 L .3976 .53812 L p
1 g
F P
s
P
p
.002 w
.51318 .56155 m .56808 .54038 L .55791 .51901 L p
1 g
F P
s
P
p
.002 w
.55791 .51901 m .50519 .5393 L .51318 .56155 L p
1 g
F P
s
P
p
.002 w
.60382 .48692 m .55791 .51901 L .56808 .54038 L p
1 g
F P
s
P
p
.002 w
.38203 .37424 m .39656 .39218 L .41397 .36883 L p
1 g
F P
s
P
p
.002 w
.41397 .36883 m .40425 .35648 L .38203 .37424 L p
1 g
F P
s
P
p
.002 w
.40425 .35648 m .41397 .36883 L .43347 .34705 L p
1 g
F P
s
P
p
.002 w
.43347 .34705 m .42864 .34072 L .40425 .35648 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .42864 .34072 L .43347 .34705 L closepath p
1 g
F P
s
P
p
.002 w
.45591 .56874 m .51318 .56155 L .50519 .5393 L p
1 g
F P
s
P
p
.002 w
.50519 .5393 m .45015 .54599 L .45591 .56874 L p
1 g
F P
s
P
p
.002 w
.56888 .31543 m .56842 .34566 L .59465 .35604 L p
1 g
F P
s
P
p
.002 w
.56842 .34566 m .56888 .31543 L .54079 .31412 L p
1 g
F P
s
P
p
.002 w
.36246 .39367 m .3816 .41664 L .39656 .39218 L p
1 g
F P
s
P
p
.002 w
.39656 .39218 m .38203 .37424 L .36246 .39367 L p
1 g
F P
s
P
p
.002 w
.47988 .31291 m .48312 .32012 L .51201 .3157 L p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .48312 .32012 L .47988 .31291 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .47988 .31291 L .47393 .30734 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .47393 .30734 L .46589 .30405 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .46589 .30405 L .45665 .30344 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .45665 .30344 L .44722 .30557 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .44722 .30557 L .43866 .31022 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .43866 .31022 L .43194 .31687 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .43194 .31687 L .4278 .32477 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .4278 .32477 L .42667 .33302 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .32726 m .42667 .33302 L .42864 .34072 L closepath p
1 g
F P
s
P
p
.002 w
.40013 .3413 m .40425 .35648 L .42864 .34072 L p
1 g
F P
s
P
p
.002 w
.42864 .34072 m .42667 .33302 L .40013 .3413 L p
1 g
F P
s
P
p
.002 w
.50582 .30135 m .51201 .3157 L .54079 .31412 L p
1 g
F P
s
P
p
.002 w
.51201 .3157 m .50582 .30135 L .47988 .31291 L p
1 g
F P
s
P
p
.002 w
.35463 .49183 m .39664 .51322 L .39826 .48679 L p
1 g
F P
s
P
p
.002 w
.39826 .48679 m .36034 .46698 L .35463 .49183 L p
1 g
F P
s
P
p
.002 w
.56808 .54038 m .61598 .50709 L .60382 .48692 L p
1 g
F P
s
P
p
.002 w
.6388 .4456 m .60382 .48692 L .61598 .50709 L p
1 g
F P
s
P
p
.002 w
.60382 .48692 m .6388 .4456 L .62188 .42698 L p
1 g
F P
s
P
p
.002 w
.34603 .41441 m .36942 .44174 L .3816 .41664 L p
1 g
F P
s
P
p
.002 w
.3816 .41664 m .36246 .39367 L .34603 .41441 L p
1 g
F P
s
P
p
.002 w
.47393 .30734 m .47988 .31291 L .50582 .30135 L p
1 g
F P
s
P
p
.002 w
.59568 .31968 m .59465 .35604 L .61889 .36844 L p
1 g
F P
s
P
p
.002 w
.59465 .35604 m .59568 .31968 L .56888 .31543 L p
1 g
F P
s
P
p
.002 w
.37566 .35198 m .38203 .37424 L .40425 .35648 L p
1 g
F P
s
P
p
.002 w
.40425 .35648 m .40013 .3413 L .37566 .35198 L p
1 g
F P
s
P
p
.002 w
.6406 .38265 m .62188 .42698 L .6388 .4456 L p
1 g
F P
s
P
p
.002 w
.62188 .42698 m .6406 .38265 L .61889 .36844 L p
1 g
F P
s
P
p
.002 w
.40219 .32489 m .40013 .3413 L .42667 .33302 L p
1 g
F P
s
P
p
.002 w
.42667 .33302 m .4278 .32477 L .40219 .32489 L p
1 g
F P
s
P
p
.002 w
.53199 .29289 m .54079 .31412 L .56888 .31543 L p
1 g
F P
s
P
p
.002 w
.54079 .31412 m .53199 .29289 L .50582 .30135 L p
1 g
F P
s
P
p
.002 w
.40121 .56092 m .45591 .56874 L .45015 .54599 L p
1 g
F P
s
P
p
.002 w
.45015 .54599 m .3976 .53812 L .40121 .56092 L p
1 g
F P
s
P
p
.002 w
.50582 .30135 m .49417 .29018 L .47393 .30734 L p
1 g
F P
s
P
p
.002 w
.46589 .30405 m .47393 .30734 L .49417 .29018 L p
1 g
F P
s
P
p
.002 w
.41034 .3091 m .40219 .32489 L .4278 .32477 L p
1 g
F P
s
P
p
.002 w
.4278 .32477 m .43194 .31687 L .41034 .3091 L p
1 g
F P
s
P
p
.002 w
.52107 .58111 m .57682 .55958 L .56808 .54038 L p
1 g
F P
s
P
p
.002 w
.56808 .54038 m .51318 .56155 L .52107 .58111 L p
1 g
F P
s
P
p
.002 w
.61598 .50709 m .56808 .54038 L .57682 .55958 L p
1 g
F P
s
P
p
.002 w
.49417 .29018 m .50582 .30135 L .53199 .29289 L p
1 g
F P
s
P
p
.002 w
.35384 .3649 m .36246 .39367 L .38203 .37424 L p
1 g
F P
s
P
p
.002 w
.38203 .37424 m .37566 .35198 L .35384 .3649 L p
1 g
F P
s
P
p
.002 w
.49417 .29018 m .47824 .2835 L .46589 .30405 L p
1 g
F P
s
P
p
.002 w
.45665 .30344 m .46589 .30405 L .47824 .2835 L p
1 g
F P
s
P
p
.002 w
.3332 .43604 m .36034 .46698 L .36942 .44174 L p
1 g
F P
s
P
p
.002 w
.36942 .44174 m .34603 .41441 L .3332 .43604 L p
1 g
F P
s
P
p
.002 w
.46298 .58861 m .52107 .58111 L .51318 .56155 L p
1 g
F P
s
P
p
.002 w
.51318 .56155 m .45591 .56874 L .46298 .58861 L p
1 g
F P
s
P
p
.002 w
.35255 .51572 m .3976 .53812 L .39664 .51322 L p
1 g
F P
s
P
p
.002 w
.39664 .51322 m .35463 .49183 L .35255 .51572 L p
1 g
F P
s
P
p
.002 w
.42373 .29575 m .41034 .3091 L .43194 .31687 L p
1 g
F P
s
P
p
.002 w
.43194 .31687 m .43866 .31022 L .42373 .29575 L p
1 g
F P
s
P
p
.002 w
.37846 .32773 m .37566 .35198 L .40013 .3413 L p
1 g
F P
s
P
p
.002 w
.40013 .3413 m .40219 .32489 L .37846 .32773 L p
1 g
F P
s
P
p
.002 w
.55784 .28777 m .56888 .31543 L .59568 .31968 L p
1 g
F P
s
P
p
.002 w
.56888 .31543 m .55784 .28777 L .53199 .29289 L p
1 g
F P
s
P
p
.002 w
.62057 .32686 m .61889 .36844 L .6406 .38265 L p
1 g
F P
s
P
p
.002 w
.61889 .36844 m .62057 .32686 L .59568 .31968 L p
1 g
F P
s
P
p
.002 w
.47824 .2835 m .45977 .28217 L .45665 .30344 L p
1 g
F P
s
P
p
.002 w
.44722 .30557 m .45665 .30344 L .45977 .28217 L p
1 g
F P
s
P
p
.002 w
.44087 .2864 m .42373 .29575 L .43866 .31022 L p
1 g
F P
s
P
p
.002 w
.43866 .31022 m .44722 .30557 L .44087 .2864 L p
1 g
F P
s
P
p
.002 w
.45977 .28217 m .44087 .2864 L .44722 .30557 L p
1 g
F P
s
P
p
.002 w
.57682 .55958 m .62553 .5259 L .61598 .50709 L p
1 g
F P
s
P
p
.002 w
.65262 .46431 m .61598 .50709 L .62553 .5259 L p
1 g
F P
s
P
p
.002 w
.61598 .50709 m .65262 .46431 L .6388 .4456 L p
1 g
F P
s
P
p
.002 w
.65921 .39844 m .6388 .4456 L .65262 .46431 L p
1 g
F P
s
P
p
.002 w
.6388 .4456 m .65921 .39844 L .6406 .38265 L p
1 g
F P
s
P
p
.002 w
.53199 .29289 m .515 .27621 L .49417 .29018 L p
1 g
F P
s
P
p
.002 w
.47824 .2835 m .49417 .29018 L .515 .27621 L p
1 g
F P
s
P
p
.002 w
.515 .27621 m .53199 .29289 L .55784 .28777 L p
1 g
F P
s
P
p
.002 w
.33525 .37987 m .34603 .41441 L .36246 .39367 L p
1 g
F P
s
P
p
.002 w
.36246 .39367 m .35384 .3649 L .33525 .37987 L p
1 g
F P
s
P
p
.002 w
.39038 .30423 m .37846 .32773 L .40219 .32489 L p
1 g
F P
s
P
p
.002 w
.40219 .32489 m .41034 .3091 L .39038 .30423 L p
1 g
F P
s
P
p
.002 w
.32439 .4581 m .35463 .49183 L .36034 .46698 L p
1 g
F P
s
P
p
.002 w
.36034 .46698 m .3332 .43604 L .32439 .4581 L p
1 g
F P
s
P
p
.002 w
.40752 .58102 m .46298 .58861 L .45591 .56874 L p
1 g
F P
s
P
p
.002 w
.45591 .56874 m .40121 .56092 L .40752 .58102 L p
1 g
F P
s
P
p
.002 w
.5828 .28621 m .59568 .31968 L .62057 .32686 L p
1 g
F P
s
P
p
.002 w
.59568 .31968 m .5828 .28621 L .55784 .28777 L p
1 g
F P
s
P
p
.002 w
.35719 .33332 m .35384 .3649 L .37566 .35198 L p
1 g
F P
s
P
p
.002 w
.37566 .35198 m .37846 .32773 L .35719 .33332 L p
1 g
F P
s
P
p
.002 w
.64296 .33689 m .6406 .38265 L .65921 .39844 L p
1 g
F P
s
P
p
.002 w
.6406 .38265 m .64296 .33689 L .62057 .32686 L p
1 g
F P
s
P
p
.002 w
.35428 .53807 m .40121 .56092 L .3976 .53812 L p
1 g
F P
s
P
p
.002 w
.3976 .53812 m .35255 .51572 L .35428 .53807 L p
1 g
F P
s
P
p
.002 w
.515 .27621 m .49149 .26614 L .47824 .2835 L p
1 g
F P
s
P
p
.002 w
.45977 .28217 m .47824 .2835 L .49149 .26614 L p
1 g
F P
s
P
p
.002 w
.52869 .59744 m .58386 .5761 L .57682 .55958 L p
1 g
F P
s
P
p
.002 w
.57682 .55958 m .52107 .58111 L .52869 .59744 L p
1 g
F P
s
P
p
.002 w
.62553 .5259 m .57682 .55958 L .58386 .5761 L p
1 g
F P
s
P
p
.002 w
.41026 .28428 m .39038 .30423 L .41034 .3091 L p
1 g
F P
s
P
p
.002 w
.41034 .3091 m .42373 .29575 L .41026 .28428 L p
1 g
F P
s
P
p
.002 w
.47125 .60502 m .52869 .59744 L .52107 .58111 L p
1 g
F P
s
P
p
.002 w
.52107 .58111 m .46298 .58861 L .47125 .60502 L p
1 g
F P
s
P
p
.002 w
.49149 .26614 m .46404 .26404 L .45977 .28217 L p
1 g
F P
s
P
p
.002 w
.44087 .2864 m .45977 .28217 L .46404 .26404 L p
1 g
F P
s
P
p
.002 w
.536 .26586 m .55784 .28777 L .5828 .28621 L p
1 g
F P
s
P
p
.002 w
.55784 .28777 m .536 .26586 L .515 .27621 L p
1 g
F P
s
P
p
.002 w
.32046 .39661 m .3332 .43604 L .34603 .41441 L p
1 g
F P
s
P
p
.002 w
.34603 .41441 m .33525 .37987 L .32046 .39661 L p
1 g
F P
s
P
p
.002 w
.43583 .27031 m .41026 .28428 L .42373 .29575 L p
1 g
F P
s
P
p
.002 w
.42373 .29575 m .44087 .2864 L .43583 .27031 L p
1 g
F P
s
P
p
.002 w
.49149 .26614 m .515 .27621 L .536 .26586 L p
1 g
F P
s
P
p
.002 w
.46404 .26404 m .43583 .27031 L .44087 .2864 L p
1 g
F P
s
P
p
.002 w
.62553 .5259 m .66289 .48271 L .65262 .46431 L p
1 g
F P
s
P
p
.002 w
.6742 .41551 m .65262 .46431 L .66289 .48271 L p
1 g
F P
s
P
p
.002 w
.65262 .46431 m .6742 .41551 L .65921 .39844 L p
1 g
F P
s
P
p
.002 w
.58386 .5761 m .63214 .54286 L .62553 .5259 L p
1 g
F P
s
P
p
.002 w
.66289 .48271 m .62553 .5259 L .63214 .54286 L p
1 g
F P
s
P
p
.002 w
.31999 .48008 m .35255 .51572 L .35463 .49183 L p
1 g
F P
s
P
p
.002 w
.35463 .49183 m .32439 .4581 L .31999 .48008 L p
1 g
F P
s
P
p
.002 w
.60627 .28839 m .62057 .32686 L .64296 .33689 L p
1 g
F P
s
P
p
.002 w
.62057 .32686 m .60627 .28839 L .5828 .28621 L p
1 g
F P
s
P
p
.002 w
.37262 .30251 m .35719 .33332 L .37846 .32773 L p
1 g
F P
s
P
p
.002 w
.37846 .32773 m .39038 .30423 L .37262 .30251 L p
1 g
F P
s
P
p
.002 w
.33901 .34165 m .33525 .37987 L .35384 .3649 L p
1 g
F P
s
P
p
.002 w
.35384 .3649 m .35719 .33332 L .33901 .34165 L p
1 g
F P
s
P
p
.002 w
.4165 .59779 m .47125 .60502 L .46298 .58861 L p
1 g
F P
s
P
p
.002 w
.46298 .58861 m .40752 .58102 L .4165 .59779 L p
1 g
F P
s
P
p
.002 w
.6622 .34967 m .65921 .39844 L .6742 .41551 L p
1 g
F P
s
P
p
.002 w
.65921 .39844 m .6622 .34967 L .64296 .33689 L p
1 g
F P
s
P
p
.002 w
.35996 .55825 m .40752 .58102 L .40121 .56092 L p
1 g
F P
s
P
p
.002 w
.40121 .56092 m .35428 .53807 L .35996 .55825 L p
1 g
F P
s
P
p
.002 w
.536 .26586 m .5054 .25251 L .49149 .26614 L p
1 g
F P
s
P
p
.002 w
.46404 .26404 m .49149 .26614 L .5054 .25251 L p
1 g
F P
s
P
p
.002 w
.55668 .25953 m .5828 .28621 L .60627 .28839 L p
1 g
F P
s
P
p
.002 w
.5828 .28621 m .55668 .25953 L .536 .26586 L p
1 g
F P
s
P
p
.002 w
.31001 .4148 m .32439 .4581 L .3332 .43604 L p
1 g
F P
s
P
p
.002 w
.3332 .43604 m .32046 .39661 L .31001 .4148 L p
1 g
F P
s
P
p
.002 w
.39866 .27624 m .37262 .30251 L .39038 .30423 L p
1 g
F P
s
P
p
.002 w
.39038 .30423 m .41026 .28428 L .39866 .27624 L p
1 g
F P
s
P
p
.002 w
.53583 .60997 m .58897 .5894 L .58386 .5761 L p
1 g
F P
s
P
p
.002 w
.58386 .5761 m .52869 .59744 L .53583 .60997 L p
1 g
F P
s
P
p
.002 w
.63214 .54286 m .58386 .5761 L .58897 .5894 L p
1 g
F P
s
P
p
.002 w
.5054 .25251 m .536 .26586 L .55668 .25953 L p
1 g
F P
s
P
p
.002 w
.48059 .61739 m .53583 .60997 L .52869 .59744 L p
1 g
F P
s
P
p
.002 w
.52869 .59744 m .47125 .60502 L .48059 .61739 L p
1 g
F P
s
P
p
.002 w
.32031 .50142 m .35428 .53807 L .35255 .51572 L p
1 g
F P
s
P
p
.002 w
.35255 .51572 m .31999 .48008 L .32031 .50142 L p
1 g
F P
s
P
p
.002 w
.5054 .25251 m .46941 .24963 L .46404 .26404 L p
1 g
F P
s
P
p
.002 w
.43583 .27031 m .46404 .26404 L .46941 .24963 L p
1 g
F P
s
P
p
.002 w
.62761 .2944 m .64296 .33689 L .6622 .34967 L p
1 g
F P
s
P
p
.002 w
.64296 .33689 m .62761 .2944 L .60627 .28839 L p
1 g
F P
s
P
p
.002 w
.63214 .54286 m .66922 .50036 L .66289 .48271 L p
1 g
F P
s
P
p
.002 w
.68505 .4335 m .66289 .48271 L .66922 .50036 L p
1 g
F P
s
P
p
.002 w
.66289 .48271 m .68505 .4335 L .6742 .41551 L p
1 g
F P
s
P
p
.002 w
.4323 .25784 m .39866 .27624 L .41026 .28428 L p
1 g
F P
s
P
p
.002 w
.41026 .28428 m .43583 .27031 L .4323 .25784 L p
1 g
F P
s
P
p
.002 w
.32452 .35268 m .32046 .39661 L .33525 .37987 L p
1 g
F P
s
P
p
.002 w
.33525 .37987 m .33901 .34165 L .32452 .35268 L p
1 g
F P
s
P
p
.002 w
.46941 .24963 m .4323 .25784 L .43583 .27031 L p
1 g
F P
s
P
p
.002 w
.3576 .30415 m .33901 .34165 L .35719 .33332 L p
1 g
F P
s
P
p
.002 w
.35719 .33332 m .37262 .30251 L .3576 .30415 L p
1 g
F P
s
P
p
.002 w
.58897 .5894 m .63549 .55748 L .63214 .54286 L p
1 g
F P
s
P
p
.002 w
.66922 .50036 m .63214 .54286 L .63549 .55748 L p
1 g
F P
s
P
p
.002 w
.67771 .36501 m .6742 .41551 L .68505 .4335 L p
1 g
F P
s
P
p
.002 w
.6742 .41551 m .67771 .36501 L .6622 .34967 L p
1 g
F P
s
P
p
.002 w
.36965 .57565 m .4165 .59779 L .40752 .58102 L p
1 g
F P
s
P
p
.002 w
.40752 .58102 m .35996 .55825 L .36965 .57565 L p
1 g
F P
s
P
p
.002 w
.42807 .61064 m .48059 .61739 L .47125 .60502 L p
1 g
F P
s
P
p
.002 w
.47125 .60502 m .4165 .59779 L .42807 .61064 L p
1 g
F P
s
P
p
.002 w
.57653 .25756 m .60627 .28839 L .62761 .2944 L p
1 g
F P
s
P
p
.002 w
.60627 .28839 m .57653 .25756 L .55668 .25953 L p
1 g
F P
s
P
p
.002 w
.30439 .43403 m .31999 .48008 L .32439 .4581 L p
1 g
F P
s
P
p
.002 w
.32439 .4581 m .31001 .4148 L .30439 .43403 L p
1 g
F P
s
P
p
.002 w
.55668 .25953 m .51967 .24314 L .5054 .25251 L p
1 g
F P
s
P
p
.002 w
.46941 .24963 m .5054 .25251 L .51967 .24314 L p
1 g
F P
s
P
p
.002 w
.51967 .24314 m .55668 .25953 L .57653 .25756 L p
1 g
F P
s
P
p
.002 w
.38932 .27203 m .3576 .30415 L .37262 .30251 L p
1 g
F P
s
P
p
.002 w
.37262 .30251 m .39866 .27624 L .38932 .27203 L p
1 g
F P
s
P
p
.002 w
.32557 .52153 m .35996 .55825 L .35428 .53807 L p
1 g
F P
s
P
p
.002 w
.35428 .53807 m .32031 .50142 L .32557 .52153 L p
1 g
F P
s
P
p
.002 w
.6462 .30429 m .6622 .34967 L .67771 .36501 L p
1 g
F P
s
P
p
.002 w
.6622 .34967 m .6462 .30429 L .62761 .2944 L p
1 g
F P
s
P
p
.002 w
.5423 .61819 m .59189 .59897 L .58897 .5894 L p
1 g
F P
s
P
p
.002 w
.58897 .5894 m .53583 .60997 L .5423 .61819 L p
1 g
F P
s
P
p
.002 w
.63549 .55748 m .58897 .5894 L .59189 .59897 L p
1 g
F P
s
P
p
.002 w
.3143 .36624 m .31001 .4148 L .32046 .39661 L p
1 g
F P
s
P
p
.002 w
.32046 .39661 m .32452 .35268 L .3143 .36624 L p
1 g
F P
s
P
p
.002 w
.49084 .62518 m .5423 .61819 L .53583 .60997 L p
1 g
F P
s
P
p
.002 w
.53583 .60997 m .48059 .61739 L .49084 .62518 L p
1 g
F P
s
P
p
.002 w
.63549 .55748 m .67122 .51678 L .66922 .50036 L p
1 g
F P
s
P
p
.002 w
.69128 .45203 m .66922 .50036 L .67122 .51678 L p
1 g
F P
s
P
p
.002 w
.66922 .50036 m .69128 .45203 L .68505 .4335 L p
1 g
F P
s
P
p
.002 w
.51967 .24314 m .47583 .23952 L .46941 .24963 L p
1 g
F P
s
P
p
.002 w
.4323 .25784 m .46941 .24963 L .47583 .23952 L p
1 g
F P
s
P
p
.002 w
.34587 .30931 m .32452 .35268 L .33901 .34165 L p
1 g
F P
s
P
p
.002 w
.33901 .34165 m .3576 .30415 L .34587 .30931 L p
1 g
F P
s
P
p
.002 w
.43045 .24952 m .38932 .27203 L .39866 .27624 L p
1 g
F P
s
P
p
.002 w
.39866 .27624 m .4323 .25784 L .43045 .24952 L p
1 g
F P
s
P
p
.002 w
.6889 .38263 m .68505 .4335 L .69128 .45203 L p
1 g
F P
s
P
p
.002 w
.68505 .4335 m .6889 .38263 L .67771 .36501 L p
1 g
F P
s
P
p
.002 w
.47583 .23952 m .43045 .24952 L .4323 .25784 L p
1 g
F P
s
P
p
.002 w
.59189 .59897 m .63531 .56925 L .63549 .55748 L p
1 g
F P
s
P
p
.002 w
.67122 .51678 m .63549 .55748 L .63531 .56925 L p
1 g
F P
s
P
p
.002 w
.59501 .26022 m .62761 .2944 L .6462 .30429 L p
1 g
F P
s
P
p
.002 w
.62761 .2944 m .59501 .26022 L .57653 .25756 L p
1 g
F P
s
P
p
.002 w
.304 .45384 m .32031 .50142 L .31999 .48008 L p
1 g
F P
s
P
p
.002 w
.31999 .48008 m .30439 .43403 L .304 .45384 L p
1 g
F P
s
P
p
.002 w
.38329 .58964 m .42807 .61064 L .4165 .59779 L p
1 g
F P
s
P
p
.002 w
.4165 .59779 m .36965 .57565 L .38329 .58964 L p
1 g
F P
s
P
p
.002 w
.44207 .61901 m .49084 .62518 L .48059 .61739 L p
1 g
F P
s
P
p
.002 w
.48059 .61739 m .42807 .61064 L .44207 .61901 L p
1 g
F P
s
P
p
.002 w
.57653 .25756 m .53395 .23851 L .51967 .24314 L p
1 g
F P
s
P
p
.002 w
.47583 .23952 m .51967 .24314 L .53395 .23851 L p
1 g
F P
s
P
p
.002 w
.53395 .23851 m .57653 .25756 L .59501 .26022 L p
1 g
F P
s
P
p
.002 w
.6614 .31798 m .67771 .36501 L .6889 .38263 L p
1 g
F P
s
P
p
.002 w
.67771 .36501 m .6614 .31798 L .6462 .30429 L p
1 g
F P
s
P
p
.002 w
.33589 .53979 m .36965 .57565 L .35996 .55825 L p
1 g
F P
s
P
p
.002 w
.35996 .55825 m .32557 .52153 L .33589 .53979 L p
1 g
F P
s
P
p
.002 w
.38263 .27203 m .34587 .30931 L .3576 .30415 L p
1 g
F P
s
P
p
.002 w
.3576 .30415 m .38932 .27203 L .38263 .27203 L p
1 g
F P
s
P
p
.002 w
.30887 .38212 m .30439 .43403 L .31001 .4148 L p
1 g
F P
s
P
p
.002 w
.31001 .4148 m .3143 .36624 L .30887 .38212 L p
1 g
F P
s
P
p
.002 w
.63531 .56925 m .66861 .53147 L .67122 .51678 L p
1 g
F P
s
P
p
.002 w
.69248 .47063 m .67122 .51678 L .66861 .53147 L p
1 g
F P
s
P
p
.002 w
.67122 .51678 m .69248 .47063 L .69128 .45203 L p
1 g
F P
s
P
p
.002 w
.54789 .62159 m .59241 .60433 L .59189 .59897 L p
1 g
F P
s
P
p
.002 w
.59189 .59897 m .5423 .61819 L .54789 .62159 L p
1 g
F P
s
P
p
.002 w
.63531 .56925 m .59189 .59897 L .59241 .60433 L p
1 g
F P
s
P
p
.002 w
.33796 .31806 m .3143 .36624 L .32452 .35268 L p
1 g
F P
s
P
p
.002 w
.32452 .35268 m .34587 .30931 L .33796 .31806 L p
1 g
F P
s
P
p
.002 w
.50177 .62789 m .54789 .62159 L .5423 .61819 L p
1 g
F P
s
P
p
.002 w
.5423 .61819 m .49084 .62518 L .50177 .62789 L p
1 g
F P
s
P
p
.002 w
.69524 .40218 m .69128 .45203 L .69248 .47063 L p
1 g
F P
s
P
p
.002 w
.69128 .45203 m .69524 .40218 L .6889 .38263 L p
1 g
F P
s
P
p
.002 w
.53395 .23851 m .48318 .23425 L .47583 .23952 L p
1 g
F P
s
P
p
.002 w
.43045 .24952 m .47583 .23952 L .48318 .23425 L p
1 g
F P
s
P
p
.002 w
.61152 .26769 m .6462 .30429 L .6614 .31798 L p
1 g
F P
s
P
p
.002 w
.6462 .30429 m .61152 .26769 L .59501 .26022 L p
1 g
F P
s
P
p
.002 w
.30912 .47369 m .32557 .52153 L .32031 .50142 L p
1 g
F P
s
P
p
.002 w
.32031 .50142 m .304 .45384 L .30912 .47369 L p
1 g
F P
s
P
p
.002 w
.43045 .24584 m .38263 .27203 L .38932 .27203 L p
1 g
F P
s
P
p
.002 w
.38932 .27203 m .43045 .24952 L .43045 .24584 L p
1 g
F P
s
P
p
.002 w
.59241 .60433 m .63138 .57769 L .63531 .56925 L p
1 g
F P
s
P
p
.002 w
.66861 .53147 m .63531 .56925 L .63138 .57769 L p
1 g
F P
s
P
p
.002 w
.48318 .23425 m .43045 .24584 L .43045 .24952 L p
1 g
F P
s
P
p
.002 w
.40069 .59965 m .44207 .61901 L .42807 .61064 L p
1 g
F P
s
P
p
.002 w
.42807 .61064 m .38329 .58964 L .40069 .59965 L p
1 g
F P
s
P
p
.002 w
.6889 .38263 m .67262 .33529 L .6614 .31798 L p
1 g
F P
s
P
p
.002 w
.67262 .33529 m .6889 .38263 L .69524 .40218 L p
1 g
F P
s
P
p
.002 w
.45823 .6224 m .50177 .62789 L .49084 .62518 L p
1 g
F P
s
P
p
.002 w
.49084 .62518 m .44207 .61901 L .45823 .6224 L p
1 g
F P
s
P
p
.002 w
.59501 .26022 m .54786 .23902 L .53395 .23851 L p
1 g
F P
s
P
p
.002 w
.48318 .23425 m .53395 .23851 L .54786 .23902 L p
1 g
F P
s
P
p
.002 w
.54786 .23902 m .59501 .26022 L .61152 .26769 L p
1 g
F P
s
P
p
.002 w
.35121 .55557 m .38329 .58964 L .36965 .57565 L p
1 g
F P
s
P
p
.002 w
.36965 .57565 m .33589 .53979 L .35121 .55557 L p
1 g
F P
s
P
p
.002 w
.30868 .39998 m .304 .45384 L .30439 .43403 L p
1 g
F P
s
P
p
.002 w
.30439 .43403 m .30887 .38212 L .30868 .39998 L p
1 g
F P
s
P
p
.004 w
.37088 .62914 m
.38773 .60321 L
s
P
p
.004 w
.33864 .67874 m
.37088 .62914 L
s
P
p
.002 w
.37896 .27649 m .33796 .31806 L .34587 .30931 L p
1 g
F P
s
P
p
.002 w
.34587 .30931 m .38263 .27203 L .37896 .27649 L p
1 g
F P
s
P
p
.002 w
.33433 .33039 m .30887 .38212 L .3143 .36624 L p
1 g
F P
s
P
p
.002 w
.3143 .36624 m .33796 .31806 L .33433 .33039 L p
1 g
F P
s
P
p
.002 w
.63138 .57769 m .66118 .54392 L .66861 .53147 L p
1 g
F P
s
P
p
.002 w
.66861 .53147 m .68835 .48879 L .69248 .47063 L p
1 g
F P
s
P
p
.002 w
.68835 .48879 m .66861 .53147 L .66118 .54392 L p
1 g
F P
s
P
p
.002 w
.69248 .47063 m .69632 .42319 L .69524 .40218 L p
1 g
F P
s
P
p
.002 w
.69632 .42319 m .69248 .47063 L .68835 .48879 L p
1 g
F P
s
P
p
.002 w
.31991 .49298 m .33589 .53979 L .32557 .52153 L p
1 g
F P
s
P
p
.002 w
.32557 .52153 m .30912 .47369 L .31991 .49298 L p
1 g
F P
s
P
p
.002 w
.6614 .31798 m .62551 .28003 L .61152 .26769 L p
1 g
F P
s
P
p
.002 w
.62551 .28003 m .6614 .31798 L .67262 .33529 L p
1 g
F P
s
P
p
.002 w
.55237 .61977 m .59036 .60504 L .59241 .60433 L p
1 g
F P
s
P
p
.002 w
.59241 .60433 m .54789 .62159 L .55237 .61977 L p
1 g
F P
s
P
p
.002 w
.63138 .57769 m .59241 .60433 L .59036 .60504 L p
1 g
F P
s
P
p
.002 w
.54786 .23902 m .49132 .23426 L .48318 .23425 L p
1 g
F P
s
P
p
.002 w
.43045 .24584 m .48318 .23425 L .49132 .23426 L p
1 g
F P
s
P
p
.002 w
.5131 .62512 m .55237 .61977 L .54789 .62159 L p
1 g
F P
s
P
p
.002 w
.54789 .62159 m .50177 .62789 L .5131 .62512 L p
1 g
F P
s
P
p
.002 w
.42155 .60516 m .45823 .6224 L .44207 .61901 L p
1 g
F P
s
P
p
.002 w
.44207 .61901 m .40069 .59965 L .42155 .60516 L p
1 g
F P
s
P
p
.002 w
.43242 .24723 m .37896 .27649 L .38263 .27203 L p
1 g
F P
s
P
p
.002 w
.38263 .27203 m .43045 .24584 L .43242 .24723 L p
1 g
F P
s
P
p
.002 w
.59036 .60504 m .62357 .58233 L .63138 .57769 L p
1 g
F P
s
P
p
.002 w
.66118 .54392 m .63138 .57769 L .62357 .58233 L p
1 g
F P
s
P
p
.002 w
.67932 .35589 m .69524 .40218 L .69632 .42319 L p
1 g
F P
s
P
p
.002 w
.69524 .40218 m .67932 .35589 L .67262 .33529 L p
1 g
F P
s
P
p
.002 w
.49132 .23426 m .43242 .24723 L .43045 .24584 L p
1 g
F P
s
P
p
.002 w
.37133 .56825 m .40069 .59965 L .38329 .58964 L p
1 g
F P
s
P
p
.002 w
.38329 .58964 m .35121 .55557 L .37133 .56825 L p
1 g
F P
s
P
p
.002 w
.56098 .24496 m .61152 .26769 L .62551 .28003 L p
1 g
F P
s
P
p
.002 w
.61152 .26769 m .56098 .24496 L .54786 .23902 L p
1 g
F P
s
P
p
.002 w
.49132 .23426 m .54786 .23902 L .56098 .24496 L p
1 g
F P
s
P
p
.002 w
.47621 .62042 m .5131 .62512 L .50177 .62789 L p
1 g
F P
s
P
p
.002 w
.50177 .62789 m .45823 .6224 L .47621 .62042 L p
1 g
F P
s
P
p
.002 w
.31403 .41939 m .30912 .47369 L .304 .45384 L p
1 g
F P
s
P
p
.002 w
.304 .45384 m .30868 .39998 L .31403 .41939 L p
1 g
F P
s
P
p
.002 w
.37861 .28558 m .33433 .33039 L .33796 .31806 L p
1 g
F P
s
P
p
.002 w
.33796 .31806 m .37896 .27649 L .37861 .28558 L p
1 g
F P
s
P
p
.002 w
.33629 .51108 m .35121 .55557 L .33589 .53979 L p
1 g
F P
s
P
p
.002 w
.33589 .53979 m .31991 .49298 L .33629 .51108 L p
1 g
F P
s
P
p
.002 w
.66118 .54392 m .67871 .50595 L .68835 .48879 L p
1 g
F P
s
P
p
.002 w
.69182 .44513 m .68835 .48879 L .67871 .50595 L p
1 g
F P
s
P
p
.002 w
.68835 .48879 m .69182 .44513 L .69632 .42319 L p
1 g
F P
s
P
p
.002 w
.33536 .34611 m .30868 .39998 L .30887 .38212 L p
1 g
F P
s
P
p
.002 w
.30887 .38212 m .33433 .33039 L .33536 .34611 L p
1 g
F P
s
P
p
.002 w
.6364 .29713 m .67262 .33529 L .67932 .35589 L p
1 g
F P
s
P
p
.002 w
.67262 .33529 m .6364 .29713 L .62551 .28003 L p
1 g
F P
s
P
p
.002 w
.62357 .58233 m .64886 .55363 L .66118 .54392 L p
1 g
F P
s
P
p
.002 w
.67871 .50595 m .66118 .54392 L .64886 .55363 L p
1 g
F P
s
P
p
.002 w
.55554 .61243 m .58562 .60077 L .59036 .60504 L p
1 g
F P
s
P
p
.002 w
.59036 .60504 m .55237 .61977 L .55554 .61243 L p
1 g
F P
s
P
p
.002 w
.62357 .58233 m .59036 .60504 L .58562 .60077 L p
1 g
F P
s
P
p
.002 w
.68107 .37933 m .69632 .42319 L .69182 .44513 L p
1 g
F P
s
P
p
.002 w
.69632 .42319 m .68107 .37933 L .67932 .35589 L p
1 g
F P
s
P
p
.002 w
.56098 .24496 m .50006 .23991 L .49132 .23426 L p
1 g
F P
s
P
p
.002 w
.43242 .24723 m .49132 .23426 L .50006 .23991 L p
1 g
F P
s
P
p
.002 w
.44539 .60577 m .47621 .62042 L .45823 .6224 L p
1 g
F P
s
P
p
.002 w
.45823 .6224 m .42155 .60516 L .44539 .60577 L p
1 g
F P
s
P
p
.002 w
.52452 .61662 m .55554 .61243 L .55237 .61977 L p
1 g
F P
s
P
p
.002 w
.55237 .61977 m .5131 .62512 L .52452 .61662 L p
1 g
F P
s
P
p
.002 w
.39582 .57728 m .42155 .60516 L .40069 .59965 L p
1 g
F P
s
P
p
.004 w
.40097 .58286 m
.5 .43051 L
s
P
p
.002 w
.40069 .59965 m .37133 .56825 L .39582 .57728 L p
1 g
F P
s
P
p
.004 w
.39532 .59154 m
.39611 .59033 L
s
P
p
.004 w
.39217 .59639 m
.39532 .59154 L
s
P
p
.004 w
.38773 .60321 m
.39217 .59639 L
s
P
p
.002 w
.57286 .25649 m .62551 .28003 L .6364 .29713 L p
1 g
F P
s
P
p
.002 w
.62551 .28003 m .57286 .25649 L .56098 .24496 L p
1 g
F P
s
P
p
.002 w
.43642 .25396 m .37861 .28558 L .37896 .27649 L p
1 g
F P
s
P
p
.002 w
.37896 .27649 m .43242 .24723 L .43642 .25396 L p
1 g
F P
s
P
p
.002 w
.58562 .60077 m .61187 .58279 L .62357 .58233 L p
1 g
F P
s
P
p
.002 w
.64886 .55363 m .62357 .58233 L .61187 .58279 L p
1 g
F P
s
P
p
.002 w
.32503 .43979 m .31991 .49298 L .30912 .47369 L p
1 g
F P
s
P
p
.002 w
.30912 .47369 m .31403 .41939 L .32503 .43979 L p
1 g
F P
s
P
p
.002 w
.50006 .23991 m .43642 .25396 L .43242 .24723 L p
1 g
F P
s
P
p
.002 w
.50006 .23991 m .56098 .24496 L .57286 .25649 L p
1 g
F P
s
P
p
.002 w
.49554 .61283 m .52452 .61662 L .5131 .62512 L p
1 g
F P
s
P
p
.002 w
.5131 .62512 m .47621 .62042 L .49554 .61283 L p
1 g
F P
s
P
p
.002 w
.358 .52733 m .37133 .56825 L .35121 .55557 L p
1 g
F P
s
P
p
.002 w
.35121 .55557 m .33629 .51108 L .358 .52733 L p
1 g
F P
s
P
p
.002 w
.64368 .31872 m .67932 .35589 L .68107 .37933 L p
1 g
F P
s
P
p
.002 w
.67932 .35589 m .64368 .31872 L .6364 .29713 L p
1 g
F P
s
P
p
.002 w
.64886 .55363 m .66357 .52154 L .67871 .50595 L p
1 g
F P
s
P
p
.002 w
.68161 .46734 m .67871 .50595 L .66357 .52154 L p
1 g
F P
s
P
p
.002 w
.67871 .50595 m .68161 .46734 L .69182 .44513 L p
1 g
F P
s
P
p
.002 w
.3413 .36493 m .31403 .41939 L .30868 .39998 L p
1 g
F P
s
P
p
.002 w
.30868 .39998 m .33536 .34611 L .3413 .36493 L p
1 g
F P
s
P
p
.002 w
.38182 .29932 m .33536 .34611 L .33433 .33039 L p
1 g
F P
s
P
p
.002 w
.33433 .33039 m .37861 .28558 L .38182 .29932 L p
1 g
F P
s
P
p
.002 w
.61187 .58279 m .63175 .56015 L .64886 .55363 L p
1 g
F P
s
P
p
.002 w
.66357 .52154 m .64886 .55363 L .63175 .56015 L p
1 g
F P
s
P
p
.002 w
.67757 .40499 m .69182 .44513 L .68161 .46734 L p
1 g
F P
s
P
p
.002 w
.69182 .44513 m .67757 .40499 L .68107 .37933 L p
1 g
F P
s
P
p
.002 w
.42407 .58222 m .44539 .60577 L .42155 .60516 L p
1 g
F P
s
P
p
.002 w
.42155 .60516 m .39582 .57728 L .42407 .58222 L p
1 g
F P
s
P
p
.002 w
.47155 .60123 m .49554 .61283 L .47621 .62042 L p
1 g
F P
s
P
p
.002 w
.47621 .62042 m .44539 .60577 L .47155 .60123 L p
1 g
F P
s
P
p
.002 w
.58305 .27356 m .6364 .29713 L .64368 .31872 L p
1 g
F P
s
P
p
.002 w
.6364 .29713 m .58305 .27356 L .57286 .25649 L p
1 g
F P
s
P
p
.002 w
.3416 .46054 m .33629 .51108 L .31991 .49298 L p
1 g
F P
s
P
p
.002 w
.31991 .49298 m .32503 .43979 L .3416 .46054 L p
1 g
F P
s
P
p
.002 w
.57286 .25649 m .50916 .25137 L .50006 .23991 L p
1 g
F P
s
P
p
.002 w
.43642 .25396 m .50006 .23991 L .50916 .25137 L p
1 g
F P
s
P
p
.002 w
.55723 .59944 m .57817 .59133 L .58562 .60077 L p
1 g
F P
s
P
p
.002 w
.58562 .60077 m .55554 .61243 L .55723 .59944 L p
1 g
F P
s
P
p
.002 w
.61187 .58279 m .58562 .60077 L .57817 .59133 L p
1 g
F P
s
P
p
.002 w
.53567 .60231 m .55723 .59944 L .55554 .61243 L p
1 g
F P
s
P
p
.002 w
.55554 .61243 m .52452 .61662 L .53567 .60231 L p
1 g
F P
s
P
p
.002 w
.44247 .26619 m .38182 .29932 L .37861 .28558 L p
1 g
F P
s
P
p
.002 w
.37861 .28558 m .43642 .25396 L .44247 .26619 L p
1 g
F P
s
P
p
.002 w
.57817 .59133 m .59641 .5788 L .61187 .58279 L p
1 g
F P
s
P
p
.002 w
.63175 .56015 m .61187 .58279 L .59641 .5788 L p
1 g
F P
s
P
p
.002 w
.50916 .25137 m .57286 .25649 L .58305 .27356 L p
1 g
F P
s
P
p
.002 w
.3845 .5411 m .39582 .57728 L .37133 .56825 L p
1 g
F P
s
P
p
.002 w
.37133 .56825 m .358 .52733 L .3845 .5411 L p
1 g
F P
s
P
p
.002 w
.64695 .34429 m .68107 .37933 L .67757 .40499 L p
1 g
F P
s
P
p
.002 w
.68107 .37933 m .64695 .34429 L .64368 .31872 L p
1 g
F P
s
P
p
.002 w
.51565 .59959 m .53567 .60231 L .52452 .61662 L p
1 g
F P
s
P
p
.002 w
.52452 .61662 m .49554 .61283 L .51565 .59959 L p
1 g
F P
s
P
p
.002 w
.50916 .25137 m .44247 .26619 L .43642 .25396 L p
1 g
F P
s
P
p
.002 w
.63175 .56015 m .64312 .53496 L .66357 .52154 L p
1 g
F P
s
P
p
.002 w
.66576 .48913 m .66357 .52154 L .64312 .53496 L p
1 g
F P
s
P
p
.002 w
.66357 .52154 m .66576 .48913 L .68161 .46734 L p
1 g
F P
s
P
p
.002 w
.35222 .38638 m .32503 .43979 L .31403 .41939 L p
1 g
F P
s
P
p
.002 w
.31403 .41939 m .3413 .36493 L .35222 .38638 L p
1 g
F P
s
P
p
.002 w
.6687 .43211 m .68161 .46734 L .66576 .48913 L p
1 g
F P
s
P
p
.002 w
.68161 .46734 m .6687 .43211 L .67757 .40499 L p
1 g
F P
s
P
p
.002 w
.38869 .31751 m .3413 .36493 L .33536 .34611 L p
1 g
F P
s
P
p
.002 w
.33536 .34611 m .38182 .29932 L .38869 .31751 L p
1 g
F P
s
P
p
.002 w
.59641 .5788 m .61012 .56306 L .63175 .56015 L p
1 g
F P
s
P
p
.002 w
.64312 .53496 m .63175 .56015 L .61012 .56306 L p
1 g
F P
s
P
p
.002 w
.45523 .58272 m .47155 .60123 L .44539 .60577 L p
1 g
F P
s
P
p
.002 w
.44539 .60577 m .42407 .58222 L .45523 .58272 L p
1 g
F P
s
P
p
.002 w
.3634 .48095 m .358 .52733 L .33629 .51108 L p
1 g
F P
s
P
p
.002 w
.33629 .51108 m .3416 .46054 L .3634 .48095 L p
1 g
F P
s
P
p
.002 w
.49926 .59147 m .51565 .59959 L .49554 .61283 L p
1 g
F P
s
P
p
.002 w
.49554 .61283 m .47155 .60123 L .49926 .59147 L p
1 g
F P
s
P
p
.002 w
.59111 .29591 m .64368 .31872 L .64695 .34429 L p
1 g
F P
s
P
p
.002 w
.64368 .31872 m .59111 .29591 L .58305 .27356 L p
1 g
F P
s
P
p
.002 w
.41505 .55183 m .42407 .58222 L .39582 .57728 L p
1 g
F P
s
P
p
.002 w
.39582 .57728 m .3845 .5411 L .41505 .55183 L p
1 g
F P
s
P
p
.002 w
.64589 .37316 m .67757 .40499 L .6687 .43211 L p
1 g
F P
s
P
p
.002 w
.67757 .40499 m .64589 .37316 L .64695 .34429 L p
1 g
F P
s
P
p
.002 w
.58305 .27356 m .51834 .26862 L .50916 .25137 L p
1 g
F P
s
P
p
.002 w
.44247 .26619 m .50916 .25137 L .51834 .26862 L p
1 g
F P
s
P
p
.002 w
.55727 .58089 m .56808 .57671 L .57817 .59133 L p
1 g
F P
s
P
p
.002 w
.57817 .59133 m .55723 .59944 L .55727 .58089 L p
1 g
F P
s
P
p
.002 w
.59641 .5788 m .57817 .59133 L .56808 .57671 L p
1 g
F P
s
P
p
.002 w
.54615 .58234 m .55727 .58089 L .55723 .59944 L p
1 g
F P
s
P
p
.002 w
.55723 .59944 m .53567 .60231 L .54615 .58234 L p
1 g
F P
s
P
p
.002 w
.51834 .26862 m .58305 .27356 L .59111 .29591 L p
1 g
F P
s
P
p
.002 w
.61012 .56306 m .61782 .54567 L .64312 .53496 L p
1 g
F P
s
P
p
.002 w
.64457 .50973 m .64312 .53496 L .61782 .54567 L p
1 g
F P
s
P
p
.002 w
.64312 .53496 m .64457 .50973 L .66576 .48913 L p
1 g
F P
s
P
p
.002 w
.56808 .57671 m .57748 .57023 L .59641 .5788 L p
1 g
F P
s
P
p
.002 w
.61012 .56306 m .59641 .5788 L .57748 .57023 L p
1 g
F P
s
P
p
.002 w
.45048 .28383 m .38869 .31751 L .38182 .29932 L p
1 g
F P
s
P
p
.002 w
.38182 .29932 m .44247 .26619 L .45048 .28383 L p
1 g
F P
s
P
p
.002 w
.65458 .45981 m .66576 .48913 L .64457 .50973 L p
1 g
F P
s
P
p
.002 w
.66576 .48913 m .65458 .45981 L .6687 .43211 L p
1 g
F P
s
P
p
.002 w
.5359 .58087 m .54615 .58234 L .53567 .60231 L p
1 g
F P
s
P
p
.002 w
.53567 .60231 m .51565 .59959 L .5359 .58087 L p
1 g
F P
s
P
p
.002 w
.36795 .40981 m .3416 .46054 L .32503 .43979 L p
1 g
F P
s
P
p
.002 w
.32503 .43979 m .35222 .38638 L .36795 .40981 L p
1 g
F P
s
P
p
.002 w
.51834 .26862 m .45048 .28383 L .44247 .26619 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.49926 .59147 m .47155 .60123 L p
.48669 .58083 L 1 g
F P
s
P
p
.48669 .58083 m .48697 .58046 L .48746 .58089 L 1 g
F
P
p
.48669 .58083 m .48746 .58089 L .49926 .59147 L 1 g
F
P
p
.002 w
.49075 .5815 m .49926 .59147 L p
.48746 .58089 L 1 g
F P
s
P
p
.48697 .58046 m .48903 .58103 L .48746 .58089 L 1 g
F
P
p
.48903 .58103 m .49075 .5815 L .48746 .58089 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58103 L p
1 g
F P
s
P
p
.51079 .57862 m .48903 .58103 L .49045 .58115 L 1 g
F
P
p
.002 w
.49926 .59147 m .49045 .58115 L p
.51092 .58056 L 1 g
F P
s
P
p
.49945 .58089 m .49045 .58115 L .49584 .58161 L 1 g
F
P
p
.51079 .57862 m .49045 .58115 L .49945 .58089 L 1 g
F
P
p
.002 w
.52064 .58028 m .49926 .59147 L p
.51091 .58056 L 1 g
F P
s
P
p
.51091 .58056 m .51092 .58056 L .51093 .58056 L 1 g
F
P
p
.51091 .58056 m .51093 .58056 L .52064 .58028 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58056 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58056 L .52022 .57832 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.53128 .57265 m .52022 .57832 L .52754 .57656 L 1 g
F
P
p
.53128 .57265 m .52754 .57656 L .52757 .57656 L 1 g
F
P
p
.002 w
.53178 .57493 m .53128 .57265 L p
.52756 .57656 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53178 .57493 L p
1 g
F P
s
P
p
.002 w
.5521 .56131 m .54507 .5698 L p
.54253 .57078 L 1 g
F P
s
P
p
.54253 .57078 m .53178 .57493 L .54926 .56321 L 1 g
F
P
p
.54253 .57078 m .54926 .56321 L .5521 .56131 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56321 L p
1 g
F P
s
P
p
.56075 .54566 m .54926 .56321 L .55321 .55876 L 1 g
F
P
p
.002 w
.55419 .55766 m .55557 .55712 L .55321 .55876 L p
1 g
F P
s
P
p
.55404 .55782 m .55321 .55876 L .55403 .55785 L 1 g
F
P
p
.56075 .54566 m .55321 .55876 L .55404 .55782 L 1 g
F
P
p
.54854 .56129 m .53178 .57493 L .54003 .5694 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54507 .5698 m .5359 .58087 L p
.52789 .57643 L 1 g
F P
s
P
p
.002 w
.54615 .58234 m .5359 .58087 L .5521 .56131 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54926 .56324 L p
1 g
F P
s
P
p
.002 w
.54926 .56324 m .54854 .56129 L p
.53958 .56983 L 1 g
F P
s
P
p
.53958 .56983 m .5322 .57686 L .54926 .56324 L 1 g
F
P
p
.002 w
.5521 .56131 m .55557 .55712 L .55465 .55957 L p
1 g
F P
s
P
p
.002 w
.55465 .55957 m .54615 .58234 L p
.5521 .56131 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55557 .55712 m .5521 .56131 L p
.54952 .56292 L 1 g
F P
s
P
p
.002 w
.52789 .57643 m .55321 .55876 L p
.54952 .56292 L 1 g
F P
s
P
p
.002 w
.55321 .55876 m .55557 .55712 L p
.54952 .56292 L 1 g
F P
s
P
p
.002 w
.56808 .57671 m .55727 .58089 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.57748 .57023 m .56808 .57671 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.55727 .58089 m .54615 .58234 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.58448 .5621 m .57748 .57023 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.58833 .55318 m .58448 .5621 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.58857 .5444 m .58833 .55318 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.58514 .53671 m .58857 .5444 L .55557 .55712 L closepath p
1 g
F P
s
P
p
.002 w
.57836 .53096 m .58514 .53671 L .55917 .55464 L p
1 g
F P
s
P
p
.002 w
.55917 .55464 m .55557 .55712 L .56008 .55194 L p
1 g
F P
s
P
p
.002 w
.56008 .55194 m .57836 .53096 L p
.55917 .55464 L 1 g
F P
s
P
p
.56075 .54566 m .55404 .55783 L .55453 .55726 L 1 g
F
P
p
.002 w
.55473 .55701 m .55557 .55712 L .55453 .55726 L p
1 g
F P
s
P
p
.55465 .55712 m .55453 .55726 L .55464 .55713 L 1 g
F
P
p
.56075 .54566 m .55453 .55726 L .55465 .55712 L 1 g
F
P
p
.56075 .54566 m .55464 .55713 L .55475 .55699 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.52021 .56175 m .52202 .55267 L .55473 .55701 L p
1 g
F P
s
P
p
.002 w
.55453 .55726 m .52021 .56175 L p
.55473 .55701 L 1 g
F P
s
P
p
.56075 .54566 m .55474 .55702 L .55484 .55688 L 1 g
F
P
p
.56075 .54566 m .55482 .55692 L .55493 .55677 L 1 g
F
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.52202 .55267 m .52743 .5438 L .5549 .55681 L p
1 g
F P
s
P
p
.002 w
.5549 .55681 m .55557 .55712 L .55473 .55701 L p
1 g
F P
s
P
p
.002 w
.55473 .55701 m .52202 .55267 L p
.5549 .55681 L 1 g
F P
s
P
p
.55475 .55699 m .55464 .55713 L .55474 .55702 L 1 g
F
P
p
.55484 .55688 m .55474 .55702 L .55482 .55692 L 1 g
F
P
p
.56075 .54566 m .5549 .55682 L .555 .55669 L 1 g
F
P
p
.002 w
.55507 .55659 m .55557 .55712 L .5549 .55681 L p
1 g
F P
s
P
p
.002 w
.55528 .5563 m .55557 .55712 L .55507 .55659 L p
1 g
F P
s
P
p
.002 w
.55567 .55576 m .55557 .55712 L .55528 .5563 L p
1 g
F P
s
P
p
.002 w
.56162 .54731 m .56075 .54566 L p
.55496 .55676 L 1 g
F P
s
P
p
.55496 .55676 m .55492 .55685 L .55712 .55371 L 1 g
F
P
p
.55496 .55676 m .55712 .55371 L .56162 .54731 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .54731 L p
1 g
F P
s
P
p
.56654 .52734 m .56162 .54731 L .56174 .54696 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56769 .52902 L p
1 g
F P
s
P
p
.56515 .50826 m .56769 .52902 L .56769 .52895 L 1 g
F
P
p
.56515 .50826 m .56769 .52895 L .56766 .5278 L 1 g
F
P
p
.002 w
.56892 .52782 m .56766 .5278 L p
.56716 .52225 L 1 g
F P
s
P
p
.56515 .50826 m .56766 .5278 L .56697 .52007 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.58037 .49502 m .56892 .52782 L p
.56716 .52225 L 1 g
F P
s
P
p
.002 w
.56602 .50929 m .56515 .50826 L p
.56697 .52007 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56602 .50929 L p
1 g
F P
s
P
p
.002 w
.55908 .49455 m .56472 .49468 L p
.56602 .50929 L 1 g
F P
s
P
p
.002 w
.56472 .49468 m .58037 .49502 L p
.56968 .51707 L 1 g
F P
s
P
p
.56602 .50929 m .56968 .51707 L .56716 .52225 L 1 g
F
P
p
.56472 .49468 m .56968 .51707 L .56602 .50929 L 1 g
F
P
p
.002 w
.58037 .49502 m .55908 .49455 L p
.55715 .45891 L 1 g
F P
s
P
p
.55661 .4905 m .56227 .50132 L .55908 .49455 L 1 g
F
P
p
.55661 .4905 m .55908 .49455 L .55836 .49311 L 1 g
F
P
p
.002 w
.54287 .4624 m .55715 .45891 L .55833 .49226 L p
1 g
F P
s
P
p
.002 w
.55833 .49226 m .55836 .49311 L p
.55756 .49151 L 1 g
F P
s
P
p
.54287 .4624 m .55833 .49226 L .55756 .49151 L 1 g
F
P
p
.002 w
.55756 .49151 m .55661 .4905 L p
.55836 .49311 L 1 g
F P
s
P
p
.55661 .4905 m .56602 .50929 L .56227 .50132 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55756 .49151 L p
1 g
F P
s
P
p
.002 w
.55759 .49154 m .55756 .49151 L p
.55836 .49311 L 1 g
F P
s
P
p
.54174 .47608 m .55756 .49151 L .54943 .48361 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47662 L p
1 g
F P
s
P
p
.52553 .46876 m .54065 .47587 L .55841 .49454 L 1 g
F
P
p
.52214 .46667 m .54223 .47662 L .53254 .47206 L 1 g
F
P
p
.54065 .47587 m .55641 .49039 L .55841 .49454 L 1 g
F
P
p
.53067 .46538 m .54223 .47662 L .54065 .47587 L 1 g
F
P
p
.54223 .47662 m .55641 .49039 L .54065 .47587 L 1 g
F
P
p
.52214 .46667 m .53254 .47206 L .52376 .46792 L 1 g
F
P
p
.002 w
.52376 .46792 m .5356 .5002 L p
.52285 .46748 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49253 .48367 m .48002 .46685 L p
.51765 .46654 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52253 .46732 L p
1 g
F P
s
P
p
.5 .4634 m .52253 .46732 L .51016 .46535 L 1 g
F
P
p
.51765 .46654 m .52094 .46652 L .52022 .46695 L 1 g
F
P
p
.51765 .46654 m .52022 .46695 L .49253 .48367 L 1 g
F
P
p
.50595 .46281 m .52094 .46652 L .51765 .46654 L 1 g
F
P
p
.5 .46374 m .51765 .46654 L .48002 .46685 L 1 g
F
P
p
.002 w
.5 .46374 m .5 .4634 L p
.51016 .46535 L 1 g
F P
s
P
p
.50595 .46281 m .51765 .46654 L .5 .46374 L 1 g
F
P
p
.002 w
.52285 .46748 m .49253 .48367 L p
.52094 .46652 L 1 g
F P
s
P
p
.002 w
.49253 .48367 m .52285 .46748 L p
.5356 .5002 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46374 L p
1 g
F P
s
P
p
.51016 .46535 m .52282 .46778 L .5 .46374 L 1 g
F
P
p
.002 w
.52253 .46732 m .52282 .46778 L p
.51016 .46535 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45048 .4837 m .45783 .47655 L .49253 .48367 L 1 g
F
P
p
.002 w
.45783 .47655 m .45826 .47608 L p
.46543 .47294 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46716 L p
1 g
F P
s
P
p
.45826 .47608 m .47756 .46716 L .46543 .47294 L 1 g
F
P
p
.002 w
.48002 .46685 m .49253 .48367 L p
.45339 .47024 L 1 g
F P
s
P
p
.002 w
.47756 .46716 m .47718 .46778 L p
.46543 .47294 L 1 g
F P
s
P
p
.002 w
.49253 .48367 m .46809 .50644 L .44541 .48863 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45783 .47655 L p
1 g
F P
s
P
p
.44339 .4905 m .45783 .47655 L .45035 .48382 L 1 g
F
P
p
.45048 .4837 m .49253 .48367 L .44541 .48863 L 1 g
F
P
p
.44339 .4905 m .4571 .47734 L .45468 .47968 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44261 .49133 L p
1 g
F P
s
P
p
.43485 .50826 m .44261 .49133 L .43748 .50211 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43417 .50907 m .43485 .50826 L p
.43748 .50211 L 1 g
F P
s
P
p
.002 w
.44541 .48863 m .46809 .50644 L p
.43496 .50741 L 1 g
F P
s
P
p
.42566 .50769 m .44261 .49133 L .43496 .50741 L 1 g
F
P
p
.44261 .49133 m .44541 .48863 L .43496 .50741 L 1 g
F
P
p
.002 w
.42004 .51769 m .42566 .50769 L p
.43496 .50741 L 1 g
F P
s
P
p
.42004 .51769 m .43428 .50788 L .43132 .51505 L 1 g
F
P
p
.43428 .50788 m .43496 .50741 L .43417 .50907 L 1 g
F
P
p
.43428 .50788 m .43417 .50907 L .43132 .51505 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43417 .50907 L p
1 g
F P
s
P
p
.43346 .52734 m .43417 .50907 L .43319 .51953 L 1 g
F
P
p
.43366 .5145 m .43496 .50741 L .46809 .50644 L 1 g
F
P
p
.43132 .51505 m .43417 .50907 L .43366 .5145 L 1 g
F
P
p
.43417 .50907 m .43496 .50741 L .43366 .5145 L 1 g
F
P
p
.43346 .52734 m .43319 .51953 L .43282 .52348 L 1 g
F
P
p
.41505 .55183 m .43166 .52532 L .43227 .5431 L 1 g
F
P
p
.43166 .52532 m .43282 .52348 L .43268 .52848 L 1 g
F
P
p
.43166 .52532 m .43268 .52848 L .43227 .5431 L 1 g
F
P
p
.002 w
.4386 .54688 m .43925 .54566 L p
.43638 .53999 L 1 g
F P
s
P
p
.002 w
.43268 .52848 m .43346 .52734 L p
.43282 .52348 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43268 .52848 L p
1 g
F P
s
P
p
.43925 .54566 m .43268 .52848 L .43638 .53999 L 1 g
F
P
p
.002 w
.43282 .52348 m .45297 .53261 L p
.43667 .54087 L 1 g
F P
s
P
p
.43227 .5431 m .43268 .52848 L .43667 .54087 L 1 g
F
P
p
.43268 .52848 m .43282 .52348 L .43667 .54087 L 1 g
F
P
p
.002 w
.43268 .52848 m .43146 .53025 L p
.43638 .53999 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.45146 .56129 m .44404 .55484 L .4466 .5586 L 1 g
F
P
p
.002 w
.45523 .58272 m .42407 .58222 L p
.44772 .55991 L 1 g
F P
s
P
p
.002 w
.44947 .56199 m .44966 .56265 L p
.44772 .55991 L 1 g
F P
s
P
p
.002 w
.44966 .56265 m .45523 .58272 L p
.44828 .56163 L 1 g
F P
s
P
p
.44772 .55991 m .44966 .56265 L .44828 .56163 L 1 g
F
P
p
.002 w
.48287 .57932 m .47745 .57999 L p
.4783 .57775 L 1 g
F P
s
P
p
.002 w
.47745 .57999 m .45523 .58272 L p
.46757 .57404 L 1 g
F P
s
P
p
.46757 .57404 m .46774 .57393 L .46836 .57432 L 1 g
F
P
p
.46757 .57404 m .46836 .57432 L .47745 .57999 L 1 g
F
P
p
.002 w
.46836 .57432 m .46872 .57265 L p
.46028 .56928 L 1 g
F P
s
P
p
.002 w
.48903 .58103 m .48921 .57862 L p
.47822 .57772 L 1 g
F P
s
P
p
.47822 .57772 m .48287 .57932 L .48903 .58103 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.46836 .57432 m .4783 .57775 L .47745 .57999 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46836 .57432 L p
1 g
F P
s
P
p
.002 w
.46836 .57432 m .4678 .57686 L p
.47822 .57772 L 1 g
F P
s
P
p
.48921 .57862 m .46836 .57432 L .47822 .57772 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45071 .56331 L p
1 g
F P
s
P
p
.46872 .57265 m .45071 .56331 L .46028 .56928 L 1 g
F
P
p
.002 w
.45126 .56842 m .44947 .56199 L p
.45753 .57058 L 1 g
F P
s
P
p
.002 w
.45067 .56341 m .45146 .56129 L p
.4466 .5586 L 1 g
F P
s
P
p
.002 w
.4466 .5586 m .41505 .55183 L p
.43505 .54169 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.45753 .57058 m .44865 .55903 L .46757 .57404 L 1 g
F
P
p
.002 w
.44947 .56199 m .44865 .55903 L p
.45753 .57058 L 1 g
F P
s
P
p
.002 w
.4504 .56415 m .45067 .56341 L p
.44947 .56199 L 1 g
F P
s
P
p
.002 w
.42407 .58222 m .41505 .55183 L .4466 .5586 L p
1 g
F P
s
P
p
.002 w
.4466 .5586 m .44865 .55903 L p
.44772 .55991 L 1 g
F P
s
P
p
.42407 .58222 m .4466 .5586 L .44772 .55991 L 1 g
F
P
p
.4466 .5586 m .43743 .5491 L .4504 .56415 L 1 g
F
P
p
.44404 .55484 m .44177 .55287 L .4466 .5586 L 1 g
F
P
p
.44177 .55287 m .43743 .5491 L .4466 .5586 L 1 g
F
P
p
.44947 .56199 m .4466 .5586 L .44746 .55985 L 1 g
F
P
p
.44947 .56199 m .44746 .55985 L .4504 .56415 L 1 g
F
P
p
.002 w
.45071 .56331 m .45002 .56518 L p
.46028 .56928 L 1 g
F P
s
P
p
.002 w
.44865 .55903 m .48413 .5624 L p
.46774 .57393 L 1 g
F P
s
P
p
.46757 .57404 m .46628 .57302 L .46774 .57393 L 1 g
F
P
p
.46628 .57302 m .44865 .55903 L .46774 .57393 L 1 g
F
P
p
.002 w
.45523 .58272 m .45126 .56842 L p
.46757 .57404 L 1 g
F P
s
P
p
.46774 .57393 m .48413 .5624 L .4783 .57775 L 1 g
F
P
p
.46774 .57393 m .4783 .57775 L .46836 .57432 L 1 g
F
P
p
.47822 .57772 m .4766 .57758 L .48287 .57932 L 1 g
F
P
p
.002 w
.47155 .60123 m .45523 .58272 L .48831 .57865 L p
1 g
F P
s
P
p
.4766 .57758 m .4678 .57686 L .48622 .58047 L 1 g
F
P
p
.48287 .57932 m .48622 .58047 L .48903 .58103 L 1 g
F
P
p
.4766 .57758 m .48622 .58047 L .48287 .57932 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .489 .58144 L p
1 g
F P
s
P
p
.002 w
.489 .58144 m .48903 .58103 L p
.48622 .58047 L 1 g
F P
s
P
p
.48622 .58047 m .4678 .57686 L .489 .58144 L 1 g
F
P
p
.002 w
.48413 .5624 m .48831 .57865 L .48287 .57932 L p
1 g
F P
s
P
p
.4783 .57775 m .48413 .5624 L .48287 .57932 L 1 g
F
P
p
.002 w
.46792 .5763 m .46836 .57432 L p
.4565 .56777 L 1 g
F P
s
P
p
.46028 .56928 m .4565 .56777 L .46836 .57432 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46792 .5763 L p
1 g
F P
s
P
p
.4565 .56777 m .45002 .56518 L .46792 .5763 L 1 g
F
P
p
.002 w
.44865 .55903 m .44947 .56199 L p
.44772 .55991 L 1 g
F P
s
P
p
.002 w
.45297 .53261 m .44865 .55903 L .4466 .5586 L p
1 g
F P
s
P
p
.43505 .54169 m .45297 .53261 L .4466 .5586 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4504 .56415 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4386 .54688 L p
1 g
F P
s
P
p
.43638 .53999 m .43146 .53025 L .4386 .54688 L 1 g
F
P
p
.002 w
.4323 .52903 m .43268 .52848 L p
.43282 .52348 L 1 g
F P
s
P
p
.002 w
.41505 .55183 m .42004 .51769 L .43282 .52348 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.46809 .50644 m .45297 .53261 L .42004 .51769 L p
1 g
F P
s
P
p
.002 w
.43417 .50907 m .43287 .51061 L p
.43319 .51953 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4323 .52903 L p
1 g
F P
s
P
p
.43319 .51953 m .43287 .51061 L .4323 .52903 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43417 .50907 L p
1 g
F P
s
P
p
.43748 .50211 m .44166 .49233 L .43417 .50907 L 1 g
F
P
p
.002 w
.44261 .49133 m .44166 .49233 L p
.43748 .50211 L 1 g
F P
s
P
p
.002 w
.44237 .49158 m .44339 .4905 L p
.44977 .48438 L 1 g
F P
s
P
p
.002 w
.44541 .48863 m .43913 .4837 L p
.45048 .4837 L 1 g
F P
s
P
p
.002 w
.45783 .47655 m .4571 .47734 L p
.45035 .48382 L 1 g
F P
s
P
p
.002 w
.4571 .47734 m .45698 .47747 L p
.45468 .47968 L 1 g
F P
s
P
p
.002 w
.42566 .50769 m .43913 .4837 L .44541 .48863 L p
1 g
F P
s
P
p
.43913 .4837 m .46147 .47301 L .45783 .47655 L 1 g
F
P
p
.4428 .4837 m .45783 .47655 L .45048 .4837 L 1 g
F
P
p
.43913 .4837 m .45783 .47655 L .4428 .4837 L 1 g
F
P
p
.45783 .47655 m .46147 .47301 L .46368 .47377 L 1 g
F
P
p
.45783 .47655 m .46368 .47377 L .49253 .48367 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45783 .47655 L p
1 g
F P
s
P
p
.46543 .47294 m .47718 .46778 L .45783 .47655 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44237 .49158 L p
1 g
F P
s
P
p
.44977 .48438 m .45698 .47747 L .44237 .49158 L 1 g
F
P
p
.002 w
.43913 .4837 m .45339 .47024 L p
.46147 .47301 L 1 g
F P
s
P
p
.47786 .46667 m .48742 .4657 L .48002 .46685 L 1 g
F
P
p
.002 w
.47756 .46716 m .47786 .46667 L p
.48002 .46685 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.45339 .47024 m .47051 .45407 L .48002 .46685 L p
1 g
F P
s
P
p
.002 w
.47752 .46724 m .47756 .46716 L p
.48002 .46685 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46724 L p
1 g
F P
s
P
p
.48742 .4657 m .5 .46442 L .47752 .46724 L 1 g
F
P
p
.002 w
.48002 .46685 m .47051 .45407 L p
.50595 .46281 L 1 g
F P
s
P
p
.52214 .46667 m .52376 .46792 L .52285 .46748 L 1 g
F
P
p
.002 w
.52254 .46733 m .52253 .46732 L p
.52285 .46748 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52214 .46667 L p
.52285 .46748 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5105 .43262 m .52348 .46714 L p
.52094 .46652 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.47051 .45407 m .48302 .44736 L p
.52094 .46652 L 1 g
F P
s
P
p
.002 w
.48302 .44736 m .5105 .43262 L p
.52094 .46652 L 1 g
F P
s
P
p
.002 w
.52348 .46714 m .52285 .46748 L p
.52094 .46652 L 1 g
F P
s
P
p
.002 w
.52255 .46735 m .52254 .46733 L p
.52285 .46748 L 1 g
F P
s
P
p
.52285 .46748 m .52376 .46792 L .52322 .46766 L 1 g
F
P
p
.52285 .46748 m .52322 .46766 L .52255 .46735 L 1 g
F
P
p
.002 w
.52285 .46748 m .52348 .46714 L .52376 .46792 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55841 .49454 m .5356 .5002 L .52348 .46714 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52255 .46735 L p
1 g
F P
s
P
p
.53254 .47206 m .54302 .47747 L .52255 .46735 L 1 g
F
P
p
.002 w
.54223 .47662 m .54302 .47747 L p
.53254 .47206 L 1 g
F P
s
P
p
.002 w
.52348 .46714 m .53067 .46538 L p
.54065 .47587 L 1 g
F P
s
P
p
.52348 .46714 m .54065 .47587 L .52553 .46876 L 1 g
F
P
p
.002 w
.54223 .47662 m .54174 .47608 L p
.54943 .48361 L 1 g
F P
s
P
p
.002 w
.53067 .46538 m .54287 .4624 L p
.55641 .49039 L 1 g
F P
s
P
p
.002 w
.55836 .49311 m .55841 .49454 L p
.54287 .4624 L 1 g
F P
s
P
p
.002 w
.55836 .49311 m .55715 .45891 L p
.55908 .49455 L 1 g
F P
s
P
p
.002 w
.55774 .4917 m .55759 .49154 L p
.55908 .49455 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55774 .4917 L p
1 g
F P
s
P
p
.56227 .50132 m .56713 .51061 L .55774 .4917 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54223 .47662 L p
1 g
F P
s
P
p
.54943 .48361 m .55834 .49233 L .54223 .47662 L 1 g
F
P
p
.002 w
.55756 .49151 m .55834 .49233 L p
.54943 .48361 L 1 g
F P
s
P
p
.002 w
.55908 .49455 m .55841 .49454 L .55836 .49311 L p
1 g
F P
s
P
p
.002 w
.56602 .50929 m .56713 .51061 L p
.56227 .50132 L 1 g
F P
s
P
p
.002 w
.55841 .49454 m .55908 .49455 L p
.56716 .52225 L 1 g
F P
s
P
p
.55908 .49455 m .56602 .50929 L .56716 .52225 L 1 g
F
P
p
.002 w
.56809 .52781 m .56892 .52782 L .56773 .53043 L p
1 g
F P
s
P
p
.002 w
.56773 .53043 m .56892 .52782 L p
.56774 .53103 L 1 g
F P
s
P
p
.002 w
.56892 .52782 m .5741 .52954 L p
.56195 .54683 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56602 .50929 L p
1 g
F P
s
P
p
.56697 .52007 m .56854 .53025 L .56602 .50929 L 1 g
F
P
p
.56697 .52007 m .56766 .5278 L .56754 .52379 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55786 .52767 m .55841 .49454 L p
.56716 .52225 L 1 g
F P
s
P
p
.56195 .54683 m .56162 .54731 L .56588 .53449 L 1 g
F
P
p
.56654 .52734 m .56167 .54723 L .56443 .53887 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56773 .53043 m .56588 .53449 L p
.56769 .52902 L 1 g
F P
s
P
p
.56809 .52781 m .56773 .53043 L .56769 .52902 L 1 g
F
P
p
.002 w
.56588 .53449 m .56773 .53043 L p
.56195 .54683 L 1 g
F P
s
P
p
.56774 .53103 m .56195 .54683 L .56773 .53043 L 1 g
F
P
p
.002 w
.57836 .53096 m .56008 .55194 L p
.56195 .54683 L 1 g
F P
s
P
p
.002 w
.5741 .52954 m .57836 .53096 L p
.56195 .54683 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56766 .5278 m .55786 .52767 L p
.56716 .52225 L 1 g
F P
s
P
p
.002 w
.56588 .53449 m .55712 .55371 L p
.56809 .52781 L 1 g
F P
s
P
p
.56754 .52379 m .5677 .52903 L .56758 .52403 L 1 g
F
P
p
.56769 .52895 m .5677 .52903 L .56754 .52379 L 1 g
F
P
p
.002 w
.55786 .52767 m .56766 .5278 L p
.55712 .55371 L 1 g
F P
s
P
p
.002 w
.56766 .5278 m .56809 .52781 L p
.56768 .52877 L 1 g
F P
s
P
p
.56766 .5278 m .56768 .52877 L .55712 .55371 L 1 g
F
P
p
.002 w
.56769 .52902 m .5677 .52903 L p
.56769 .52895 L 1 g
F P
s
P
p
.002 w
.5677 .52903 m .56854 .53025 L p
.56758 .52403 L 1 g
F P
s
P
p
.56195 .54683 m .56008 .55194 L .56162 .54731 L 1 g
F
P
p
.002 w
.55712 .55371 m .55557 .55712 L .55567 .55576 L p
1 g
F P
s
P
p
.002 w
.55453 .55726 m .55557 .55712 L .55419 .55766 L p
1 g
F P
s
P
p
.002 w
.56008 .55194 m .55557 .55712 L .56588 .53449 L p
1 g
F P
s
P
p
.55492 .55685 m .54998 .56518 L .56229 .54856 L 1 g
F
P
p
.55403 .55785 m .55335 .55908 L .55492 .55685 L 1 g
F
P
p
.55335 .55908 m .54998 .56518 L .55492 .55685 L 1 g
F
P
p
.56443 .53887 m .56164 .54735 L .56433 .53944 L 1 g
F
P
p
.56167 .54723 m .56164 .54735 L .56443 .53887 L 1 g
F
P
p
.002 w
.55567 .55576 m .55786 .52767 L p
.55712 .55371 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.52743 .5438 m .53588 .53613 L .55507 .55659 L p
1 g
F P
s
P
p
.002 w
.5549 .55681 m .52743 .5438 L p
.55507 .55659 L 1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.53588 .53613 m .54642 .53054 L .55528 .5563 L p
1 g
F P
s
P
p
.002 w
.55507 .55659 m .53588 .53613 L p
.55528 .5563 L 1 g
F P
s
P
p
.55493 .55677 m .55482 .55692 L .5549 .55682 L 1 g
F
P
p
.555 .55669 m .5549 .55682 L .55497 .55674 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54642 .53054 m .55786 .52767 L .55567 .55576 L p
1 g
F P
s
P
p
.002 w
.55528 .5563 m .54642 .53054 L p
.55567 .55576 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.52216 .57003 m .52021 .56175 L .55453 .55726 L p
1 g
F P
s
P
p
.002 w
.55419 .55766 m .52216 .57003 L p
.55453 .55726 L 1 g
F P
s
P
p
.55497 .55674 m .55403 .55785 L .55492 .55685 L 1 g
F
P
p
.55404 .55783 m .55403 .55785 L .55497 .55674 L 1 g
F
P
p
.002 w
.56229 .54856 m .56162 .54731 L p
.55492 .55685 L 1 g
F P
s
P
p
.002 w
.56162 .54731 m .56164 .54735 L p
.56174 .54696 L 1 g
F P
s
P
p
.002 w
.56164 .54735 m .56257 .5491 L p
.56433 .53944 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56229 .54856 L p
1 g
F P
s
P
p
.002 w
.52216 .57003 m .55419 .55766 L p
.52789 .57643 L 1 g
F P
s
P
p
.002 w
.55321 .55876 m .52789 .57643 L p
.55419 .55766 L 1 g
F P
s
P
p
.53178 .57493 m .52789 .57643 L .5521 .56131 L 1 g
F
P
p
.002 w
.54926 .56321 m .54998 .56518 L p
.55403 .55785 L 1 g
F P
s
P
p
.002 w
.53178 .57493 m .5322 .57686 L p
.54003 .5694 L 1 g
F P
s
P
p
.002 w
.52789 .57643 m .5276 .57663 L .52754 .57656 L p
1 g
F P
s
P
p
.002 w
.52754 .57656 m .52216 .57003 L p
.52789 .57643 L 1 g
F P
s
P
p
.52757 .57656 m .52754 .57656 L .52756 .57656 L 1 g
F
P
p
.002 w
.5359 .58087 m .5276 .57663 L .52789 .57643 L p
1 g
F P
s
P
p
.002 w
.53191 .57552 m .53178 .57493 L p
.52756 .57656 L 1 g
F P
s
P
p
.51092 .58056 m .52216 .57003 L .52096 .57815 L 1 g
F
P
p
.51093 .58056 m .52096 .57815 L .52064 .58028 L 1 g
F
P
p
.51092 .58056 m .52096 .57815 L .51093 .58056 L 1 g
F
P
p
.002 w
.52216 .57003 m .5276 .57663 L .52064 .58028 L p
1 g
F P
s
P
p
.002 w
.5276 .57663 m .5359 .58087 L .51565 .59959 L p
1 g
F P
s
P
p
.002 w
.51565 .59959 m .49926 .59147 L .5276 .57663 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53191 .57552 L p
1 g
F P
s
P
p
.52022 .57832 m .51111 .583 L .53191 .57552 L 1 g
F
P
p
.002 w
.51093 .58056 m .51111 .583 L p
.52022 .57832 L 1 g
F P
s
P
p
.002 w
.51111 .58291 m .51093 .58056 L p
.49584 .58161 L 1 g
F P
s
P
p
.002 w
.51093 .58056 m .51079 .57862 L p
.49945 .58089 L 1 g
F P
s
P
p
.49945 .58089 m .49584 .58161 L .51093 .58056 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48831 .57865 m .52216 .57003 L p
.51092 .58056 L 1 g
F P
s
P
p
.002 w
.49045 .58115 m .48831 .57865 L p
.51092 .58056 L 1 g
F P
s
P
p
.002 w
.48831 .57865 m .49075 .5815 L p
.48697 .58046 L 1 g
F P
s
P
p
.002 w
.48903 .58103 m .48889 .583 L p
.49584 .58161 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51111 .58291 L p
1 g
F P
s
P
p
.49584 .58161 m .48889 .583 L .51111 .58291 L 1 g
F
P
p
.002 w
.57748 .57023 m .58448 .5621 L .61012 .56306 L p
1 g
F P
s
P
p
.002 w
.61782 .54567 m .61012 .56306 L .58448 .5621 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50275 .43678 L
s
P
p
.004 w
.52957 .49788 m
.54316 .52886 L
s
P
p
.002 w
.38983 .50024 m .3845 .5411 L .358 .52733 L p
1 g
F P
s
P
p
.002 w
.358 .52733 m .3634 .48095 L .38983 .50024 L p
1 g
F P
s
P
p
.002 w
.39918 .33978 m .35222 .38638 L .3413 .36493 L p
1 g
F P
s
P
p
.002 w
.3413 .36493 m .38869 .31751 L .39918 .33978 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.59666 .323 m .64695 .34429 L .64589 .37316 L p
1 g
F P
s
P
p
.002 w
.64695 .34429 m .59666 .323 L .59111 .29591 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.6404 .40443 m .6687 .43211 L .65458 .45981 L p
1 g
F P
s
P
p
.002 w
.6687 .43211 m .6404 .40443 L .64589 .37316 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.61782 .54567 m .61858 .5284 L .64457 .50973 L p
1 g
F P
s
P
p
.002 w
.63553 .48713 m .64457 .50973 L .61858 .5284 L p
1 g
F P
s
P
p
.002 w
.64457 .50973 m .63553 .48713 L .65458 .45981 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.58448 .5621 m .58833 .55318 L .61782 .54567 L p
1 g
F P
s
P
p
.002 w
.61858 .5284 m .61782 .54567 L .58833 .55318 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.59111 .29591 m .52728 .29137 L .51834 .26862 L p
1 g
F P
s
P
p
.002 w
.45048 .28383 m .51834 .26862 L .52728 .29137 L p
1 g
F P
s
P
p
.002 w
.52728 .29137 m .59111 .29591 L .59666 .323 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.38814 .43444 m .3634 .48095 L .3416 .46054 L p
1 g
F P
s
P
p
.002 w
.3416 .46054 m .36795 .40981 L .38814 .43444 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.42004 .51769 m .41505 .55183 L .3845 .5411 L p
1 g
F P
s
P
p
.002 w
.3845 .5411 m .38983 .50024 L .42004 .51769 L p
1 g
F P
s
P
p
.002 w
.46028 .30656 m .39918 .33978 L .38869 .31751 L p
1 g
F P
s
P
p
.002 w
.38869 .31751 m .45048 .28383 L .46028 .30656 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.63053 .43703 m .65458 .45981 L .63553 .48713 L p
1 g
F P
s
P
p
.002 w
.65458 .45981 m .63053 .43703 L .6404 .40443 L p
1 g
F P
s
P
p
.002 w
.5994 .35406 m .64589 .37316 L .6404 .40443 L p
1 g
F P
s
P
p
.002 w
.64589 .37316 m .5994 .35406 L .59666 .323 L p
1 g
F P
s
P
p
.002 w
.52728 .29137 m .46028 .30656 L .45048 .28383 L p
1 g
F P
s
P
p
.002 w
.41309 .36549 m .36795 .40981 L .35222 .38638 L p
1 g
F P
s
P
p
.002 w
.35222 .38638 m .39918 .33978 L .41309 .36549 L p
1 g
F P
s
P
p
.002 w
.58833 .55318 m .58857 .5444 L .61858 .5284 L p
1 g
F P
s
P
p
.002 w
.61212 .51309 m .61858 .5284 L .58857 .5444 L p
1 g
F P
s
P
p
.002 w
.61858 .5284 m .61212 .51309 L .63553 .48713 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.52021 .56175 m .52216 .57003 L .48831 .57865 L p
1 g
F P
s
P
p
.002 w
.48831 .57865 m .48413 .5624 L .52021 .56175 L p
1 g
F P
s
P
p
.002 w
.61656 .46979 m .63553 .48713 L .61212 .51309 L p
1 g
F P
s
P
p
.002 w
.63553 .48713 m .61656 .46979 L .63053 .43703 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41214 .45939 m .38983 .50024 L .3634 .48095 L p
1 g
F P
s
P
p
.002 w
.3634 .48095 m .38814 .43444 L .41214 .45939 L p
1 g
F P
s
P
p
.002 w
.53565 .31907 m .59666 .323 L .5994 .35406 L p
1 g
F P
s
P
p
.002 w
.59666 .323 m .53565 .31907 L .52728 .29137 L p
1 g
F P
s
P
p
.002 w
.58857 .5444 m .58514 .53671 L .61212 .51309 L p
1 g
F P
s
P
p
.002 w
.59912 .38806 m .6404 .40443 L .63053 .43703 L p
1 g
F P
s
P
p
.002 w
.6404 .40443 m .59912 .38806 L .5994 .35406 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46028 .30656 m .52728 .29137 L .53565 .31907 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59895 .50149 m .61212 .51309 L .58514 .53671 L p
1 g
F P
s
P
p
.002 w
.61212 .51309 m .59895 .50149 L .61656 .46979 L p
1 g
F P
s
P
p
.002 w
.48739 .54442 m .48413 .5624 L .44865 .55903 L p
1 g
F P
s
P
p
.002 w
.44865 .55903 m .45297 .53261 L .48739 .54442 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.58514 .53671 m .57836 .53096 L .59895 .50149 L p
1 g
F P
s
P
p
.002 w
.47159 .33378 m .41309 .36549 L .39918 .33978 L p
1 g
F P
s
P
p
.002 w
.39918 .33978 m .46028 .30656 L .47159 .33378 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.43002 .39381 m .38814 .43444 L .36795 .40981 L p
1 g
F P
s
P
p
.002 w
.36795 .40981 m .41309 .36549 L .43002 .39381 L p
1 g
F P
s
P
p
.002 w
.52202 .55267 m .52021 .56175 L .48413 .5624 L p
1 g
F P
s
P
p
.002 w
.48413 .5624 m .48739 .54442 L .52202 .55267 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59578 .42379 m .63053 .43703 L .61656 .46979 L p
1 g
F P
s
P
p
.002 w
.63053 .43703 m .59578 .42379 L .59912 .38806 L p
1 g
F P
s
P
p
.002 w
.43913 .4837 m .42004 .51769 L .38983 .50024 L p
1 g
F P
s
P
p
.002 w
.38983 .50024 m .41214 .45939 L .43913 .4837 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.53565 .31907 m .47159 .33378 L .46028 .30656 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.57836 .53096 m .56892 .52782 L .58037 .49502 L p
1 g
F P
s
P
p
.002 w
.58037 .49502 m .59895 .50149 L .57836 .53096 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.54311 .35086 m .5994 .35406 L .59912 .38806 L p
1 g
F P
s
P
p
.002 w
.5994 .35406 m .54311 .35086 L .53565 .31907 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.52743 .5438 m .52202 .55267 L .48739 .54442 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58945 .4599 m .61656 .46979 L .59895 .50149 L p
1 g
F P
s
P
p
.002 w
.61656 .46979 m .58945 .4599 L .59578 .42379 L p
1 g
F P
s
P
p
.002 w
.59895 .50149 m .58037 .49502 L .58945 .4599 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47159 .33378 m .53565 .31907 L .54311 .35086 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53588 .53613 m .52743 .5438 L .49791 .52672 L p
1 g
F P
s
P
p
.002 w
.48739 .54442 m .49791 .52672 L .52743 .5438 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49791 .52672 m .48739 .54442 L .45297 .53261 L p
1 g
F P
s
P
p
.002 w
.55786 .52767 m .54642 .53054 L .5356 .5002 L p
1 g
F P
s
P
p
.002 w
.5356 .5002 m .55841 .49454 L .55786 .52767 L p
1 g
F P
s
P
p
.002 w
.45297 .53261 m .46809 .50644 L .49791 .52672 L p
1 g
F P
s
P
p
.002 w
.4494 .42372 m .41214 .45939 L .38814 .43444 L p
1 g
F P
s
P
p
.002 w
.38814 .43444 m .43002 .39381 L .4494 .42372 L p
1 g
F P
s
P
p
.002 w
.54642 .53054 m .53588 .53613 L .51461 .51137 L p
1 g
F P
s
P
p
.002 w
.49791 .52672 m .51461 .51137 L .53588 .53613 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.51461 .51137 m .5356 .5002 L .54642 .53054 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.48404 .36463 m .43002 .39381 L .41309 .36549 L p
1 g
F P
s
P
p
.002 w
.41309 .36549 m .47159 .33378 L .48404 .36463 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54935 .38565 m .59912 .38806 L .59578 .42379 L p
1 g
F P
s
P
p
.002 w
.59912 .38806 m .54935 .38565 L .54311 .35086 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55715 .45891 m .58945 .4599 L .58037 .49502 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.54311 .35086 m .48404 .36463 L .47159 .33378 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51461 .51137 m .49791 .52672 L .46809 .50644 L p
1 g
F P
s
P
p
.002 w
.55409 .42214 m .59578 .42379 L .58945 .4599 L p
1 g
F P
s
P
p
.002 w
.59578 .42379 m .55409 .42214 L .54935 .38565 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.58945 .4599 m .55715 .45891 L .55409 .42214 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.47051 .45407 m .43913 .4837 L .41214 .45939 L p
1 g
F P
s
P
p
.002 w
.41214 .45939 m .4494 .42372 L .47051 .45407 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.48404 .36463 m .54311 .35086 L .54935 .38565 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46809 .50644 m .49253 .48367 L .51461 .51137 L p
1 g
F P
s
P
p
.002 w
.5356 .5002 m .51461 .51137 L .49253 .48367 L p
1 g
F P
s
P
p
.002 w
.49718 .398 m .4494 .42372 L .43002 .39381 L p
1 g
F P
s
P
p
.002 w
.43002 .39381 m .48404 .36463 L .49718 .398 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54935 .38565 m .49718 .398 L .48404 .36463 L p
1 g
F P
s
P
p
.002 w
.49718 .398 m .54935 .38565 L .55409 .42214 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.55715 .45891 m .52348 .46714 L .5105 .43262 L p
1 g
F P
s
P
p
.002 w
.5105 .43262 m .55409 .42214 L .55715 .45891 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55409 .42214 m .5105 .43262 L .49718 .398 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5105 .43262 m .47051 .45407 L .4494 .42372 L p
1 g
F P
s
P
p
.002 w
.4494 .42372 m .49718 .398 L .5105 .43262 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.57426 .59972 m
.57841 .60918 L
s
P
p
.004 w
.57841 .60918 m
.58835 .63181 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .33864 .67874 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58835 .63181 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.325581)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.325581)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47994 .47305 m .5271 .46499 L .51937 .4377 L p
1 g
F P
s
P
p
.002 w
.51937 .4377 m .47805 .44475 L .47994 .47305 L p
1 g
F P
s
P
p
.002 w
.55729 .42123 m .51937 .4377 L .5271 .46499 L p
1 g
F P
s
P
p
.002 w
.47805 .44475 m .51937 .4377 L .5112 .41031 L p
1 g
F P
s
P
p
.002 w
.51937 .4377 m .55729 .42123 L .5428 .39644 L p
1 g
F P
s
P
p
.002 w
.5428 .39644 m .5112 .41031 L .51937 .4377 L p
1 g
F P
s
P
p
.002 w
.5112 .41031 m .4767 .41618 L .47805 .44475 L p
1 g
F P
s
P
p
.002 w
.4767 .41618 m .5112 .41031 L .50273 .3833 L p
1 g
F P
s
P
p
.002 w
.5112 .41031 m .5428 .39644 L .52724 .37243 L p
1 g
F P
s
P
p
.002 w
.52724 .37243 m .50273 .3833 L .5112 .41031 L p
1 g
F P
s
P
p
.002 w
.43309 .46982 m .47994 .47305 L .47805 .44475 L p
1 g
F P
s
P
p
.002 w
.47805 .44475 m .43703 .44172 L .43309 .46982 L p
1 g
F P
s
P
p
.002 w
.43703 .44172 m .47805 .44475 L .4767 .41618 L p
1 g
F P
s
P
p
.002 w
.4767 .41618 m .44248 .41349 L .43703 .44172 L p
1 g
F P
s
P
p
.002 w
.44248 .41349 m .4767 .41618 L .4759 .38786 L p
1 g
F P
s
P
p
.002 w
.50273 .3833 m .4759 .38786 L .4767 .41618 L p
1 g
F P
s
P
p
.002 w
.48233 .50058 m .53423 .4917 L .5271 .46499 L p
1 g
F P
s
P
p
.002 w
.5271 .46499 m .47994 .47305 L .48233 .50058 L p
1 g
F P
s
P
p
.002 w
.57046 .44637 m .5271 .46499 L .53423 .4917 L p
1 g
F P
s
P
p
.002 w
.5271 .46499 m .57046 .44637 L .55729 .42123 L p
1 g
F P
s
P
p
.002 w
.43076 .49725 m .48233 .50058 L .47994 .47305 L p
1 g
F P
s
P
p
.002 w
.47994 .47305 m .43309 .46982 L .43076 .49725 L p
1 g
F P
s
P
p
.002 w
.4759 .38786 m .50273 .3833 L .49411 .35719 L p
1 g
F P
s
P
p
.002 w
.50273 .3833 m .52724 .37243 L .5109 .34966 L p
1 g
F P
s
P
p
.002 w
.5109 .34966 m .49411 .35719 L .50273 .3833 L p
1 g
F P
s
P
p
.002 w
.4759 .38786 m .44933 .38565 L .44248 .41349 L p
1 g
F P
s
P
p
.002 w
.44933 .38565 m .4759 .38786 L .47569 .36031 L p
1 g
F P
s
P
p
.002 w
.49411 .35719 m .47569 .36031 L .4759 .38786 L p
1 g
F P
s
P
p
.002 w
.56845 .37576 m .5428 .39644 L .55729 .42123 L p
1 g
F P
s
P
p
.002 w
.5428 .39644 m .56845 .37576 L .547 .35622 L p
1 g
F P
s
P
p
.002 w
.547 .35622 m .52724 .37243 L .5428 .39644 L p
1 g
F P
s
P
p
.002 w
.58827 .39669 m .55729 .42123 L .57046 .44637 L p
1 g
F P
s
P
p
.002 w
.55729 .42123 m .58827 .39669 L .56845 .37576 L p
1 g
F P
s
P
p
.002 w
.40011 .4287 m .43703 .44172 L .44248 .41349 L p
1 g
F P
s
P
p
.002 w
.44248 .41349 m .41181 .40236 L .40011 .4287 L p
1 g
F P
s
P
p
.002 w
.41181 .40236 m .44248 .41349 L .44933 .38565 L p
1 g
F P
s
P
p
.002 w
.39078 .45532 m .43309 .46982 L .43703 .44172 L p
1 g
F P
s
P
p
.002 w
.43703 .44172 m .40011 .4287 L .39078 .45532 L p
1 g
F P
s
P
p
.002 w
.52724 .37243 m .547 .35622 L .52433 .33846 L p
1 g
F P
s
P
p
.002 w
.52433 .33846 m .5109 .34966 L .52724 .37243 L p
1 g
F P
s
P
p
.002 w
.44933 .38565 m .42563 .3768 L .41181 .40236 L p
1 g
F P
s
P
p
.002 w
.42563 .3768 m .44933 .38565 L .45747 .35871 L p
1 g
F P
s
P
p
.002 w
.47569 .36031 m .45747 .35871 L .44933 .38565 L p
1 g
F P
s
P
p
.002 w
.48519 .52681 m .54063 .5173 L .53423 .4917 L p
1 g
F P
s
P
p
.002 w
.53423 .4917 m .48233 .50058 L .48519 .52681 L p
1 g
F P
s
P
p
.002 w
.58204 .47138 m .53423 .4917 L .54063 .5173 L p
1 g
F P
s
P
p
.002 w
.53423 .4917 m .58204 .47138 L .57046 .44637 L p
1 g
F P
s
P
p
.002 w
.60608 .41863 m .57046 .44637 L .58204 .47138 L p
1 g
F P
s
P
p
.002 w
.57046 .44637 m .60608 .41863 L .58827 .39669 L p
1 g
F P
s
P
p
.002 w
.4301 .52349 m .48519 .52681 L .48233 .50058 L p
1 g
F P
s
P
p
.002 w
.48233 .50058 m .43076 .49725 L .4301 .52349 L p
1 g
F P
s
P
p
.002 w
.47569 .36031 m .49411 .35719 L .4855 .33245 L p
1 g
F P
s
P
p
.002 w
.49411 .35719 m .5109 .34966 L .49407 .32857 L p
1 g
F P
s
P
p
.002 w
.49407 .32857 m .4855 .33245 L .49411 .35719 L p
1 g
F P
s
P
p
.002 w
.45747 .35871 m .47569 .36031 L .47607 .33405 L p
1 g
F P
s
P
p
.002 w
.4855 .33245 m .47607 .33405 L .47569 .36031 L p
1 g
F P
s
P
p
.002 w
.38404 .4817 m .43076 .49725 L .43309 .46982 L p
1 g
F P
s
P
p
.002 w
.43309 .46982 m .39078 .45532 L .38404 .4817 L p
1 g
F P
s
P
p
.002 w
.5109 .34966 m .52433 .33846 L .50087 .32281 L p
1 g
F P
s
P
p
.002 w
.50087 .32281 m .49407 .32857 L .5109 .34966 L p
1 g
F P
s
P
p
.002 w
.45747 .35871 m .44131 .35251 L .42563 .3768 L p
1 g
F P
s
P
p
.002 w
.44131 .35251 m .45747 .35871 L .46677 .33319 L p
1 g
F P
s
P
p
.002 w
.47607 .33405 m .46677 .33319 L .45747 .35871 L p
1 g
F P
s
P
p
.002 w
.58549 .3501 m .56845 .37576 L .58827 .39669 L p
1 g
F P
s
P
p
.002 w
.56845 .37576 m .58549 .3501 L .55994 .33619 L p
1 g
F P
s
P
p
.002 w
.55994 .33619 m .547 .35622 L .56845 .37576 L p
1 g
F P
s
P
p
.002 w
.547 .35622 m .55994 .33619 L .53299 .32467 L p
1 g
F P
s
P
p
.002 w
.53299 .32467 m .52433 .33846 L .547 .35622 L p
1 g
F P
s
P
p
.002 w
.54063 .5173 m .59177 .49579 L .58204 .47138 L p
1 g
F P
s
P
p
.002 w
.62148 .44116 m .58204 .47138 L .59177 .49579 L p
1 g
F P
s
P
p
.002 w
.58204 .47138 m .62148 .44116 L .60608 .41863 L p
1 g
F P
s
P
p
.002 w
.38778 .38362 m .41181 .40236 L .42563 .3768 L p
1 g
F P
s
P
p
.002 w
.42563 .3768 m .40723 .36205 L .38778 .38362 L p
1 g
F P
s
P
p
.002 w
.40723 .36205 m .42563 .3768 L .44131 .35251 L p
1 g
F P
s
P
p
.002 w
.37096 .40657 m .40011 .4287 L .41181 .40236 L p
1 g
F P
s
P
p
.002 w
.41181 .40236 m .38778 .38362 L .37096 .40657 L p
1 g
F P
s
P
p
.002 w
.60912 .36613 m .58827 .39669 L .60608 .41863 L p
1 g
F P
s
P
p
.002 w
.58827 .39669 m .60912 .36613 L .58549 .3501 L p
1 g
F P
s
P
p
.002 w
.52433 .33846 m .53299 .32467 L .50518 .31575 L p
1 g
F P
s
P
p
.002 w
.50518 .31575 m .50087 .32281 L .52433 .33846 L p
1 g
F P
s
P
p
.002 w
.48849 .5512 m .54616 .54129 L .54063 .5173 L p
1 g
F P
s
P
p
.002 w
.54063 .5173 m .48519 .52681 L .48849 .5512 L p
1 g
F P
s
P
p
.002 w
.59177 .49579 m .54063 .5173 L .54616 .54129 L p
1 g
F P
s
P
p
.002 w
.3801 .5073 m .4301 .52349 L .43076 .49725 L p
1 g
F P
s
P
p
.002 w
.43076 .49725 m .38404 .4817 L .3801 .5073 L p
1 g
F P
s
P
p
.002 w
.43118 .54798 m .48849 .5512 L .48519 .52681 L p
1 g
F P
s
P
p
.002 w
.48519 .52681 m .4301 .52349 L .43118 .54798 L p
1 g
F P
s
P
p
.002 w
.44131 .35251 m .42889 .34227 L .40723 .36205 L p
1 g
F P
s
P
p
.002 w
.42889 .34227 m .44131 .35251 L .45856 .32996 L p
1 g
F P
s
P
p
.002 w
.46677 .33319 m .45856 .32996 L .44131 .35251 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .47607 .33405 L .4855 .33245 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .4855 .33245 L .49407 .32857 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .46677 .33319 L .47607 .33405 L closepath p
1 g
F P
s
P
p
.002 w
.35715 .43045 m .39078 .45532 L .40011 .4287 L p
1 g
F P
s
P
p
.002 w
.40011 .4287 m .37096 .40657 L .35715 .43045 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .49407 .32857 L .50087 .32281 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .45856 .32996 L .46677 .33319 L closepath p
1 g
F P
s
P
p
.002 w
.63033 .38399 m .60608 .41863 L .62148 .44116 L p
1 g
F P
s
P
p
.002 w
.60608 .41863 m .63033 .38399 L .60912 .36613 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .50087 .32281 L .50518 .31575 L closepath p
1 g
F P
s
P
p
.002 w
.45856 .32996 m .45232 .32468 L .42889 .34227 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .45232 .32468 L .45856 .32996 L closepath p
1 g
F P
s
P
p
.002 w
.53587 .30968 m .53299 .32467 L .55994 .33619 L p
1 g
F P
s
P
p
.002 w
.53299 .32467 m .53587 .30968 L .50652 .30813 L p
1 g
F P
s
P
p
.002 w
.50652 .30813 m .50518 .31575 L .53299 .32467 L p
1 g
F P
s
P
p
.002 w
.56451 .31427 m .55994 .33619 L .58549 .3501 L p
1 g
F P
s
P
p
.002 w
.55994 .33619 m .56451 .31427 L .53587 .30968 L p
1 g
F P
s
P
p
.002 w
.34673 .45478 m .38404 .4817 L .39078 .45532 L p
1 g
F P
s
P
p
.002 w
.39078 .45532 m .35715 .43045 L .34673 .45478 L p
1 g
F P
s
P
p
.002 w
.54616 .54129 m .59942 .5191 L .59177 .49579 L p
1 g
F P
s
P
p
.002 w
.63413 .46385 m .59177 .49579 L .59942 .5191 L p
1 g
F P
s
P
p
.002 w
.59177 .49579 m .63413 .46385 L .62148 .44116 L p
1 g
F P
s
P
p
.002 w
.39622 .34273 m .40723 .36205 L .42889 .34227 L p
1 g
F P
s
P
p
.002 w
.42889 .34227 m .4216 .32899 L .39622 .34273 L p
1 g
F P
s
P
p
.002 w
.4216 .32899 m .42889 .34227 L .45232 .32468 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .50518 .31575 L .50652 .30813 L closepath p
1 g
F P
s
P
p
.002 w
.37315 .35886 m .38778 .38362 L .40723 .36205 L p
1 g
F P
s
P
p
.002 w
.40723 .36205 m .39622 .34273 L .37315 .35886 L p
1 g
F P
s
P
p
.002 w
.45232 .32468 m .44873 .31789 L .4216 .32899 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .44873 .31789 L .45232 .32468 L closepath p
1 g
F P
s
P
p
.002 w
.37913 .53154 m .43118 .54798 L .4301 .52349 L p
1 g
F P
s
P
p
.002 w
.4301 .52349 m .3801 .5073 L .37913 .53154 L p
1 g
F P
s
P
p
.002 w
.59185 .32185 m .58549 .3501 L .60912 .36613 L p
1 g
F P
s
P
p
.002 w
.58549 .3501 m .59185 .32185 L .56451 .31427 L p
1 g
F P
s
P
p
.002 w
.49216 .57319 m .55067 .56312 L .54616 .54129 L p
1 g
F P
s
P
p
.002 w
.54616 .54129 m .48849 .5512 L .49216 .57319 L p
1 g
F P
s
P
p
.002 w
.59942 .5191 m .54616 .54129 L .55067 .56312 L p
1 g
F P
s
P
p
.002 w
.43404 .57014 m .49216 .57319 L .48849 .5512 L p
1 g
F P
s
P
p
.002 w
.48849 .5512 m .43118 .54798 L .43404 .57014 L p
1 g
F P
s
P
p
.002 w
.35293 .37709 m .37096 .40657 L .38778 .38362 L p
1 g
F P
s
P
p
.002 w
.38778 .38362 m .37315 .35886 L .35293 .37709 L p
1 g
F P
s
P
p
.002 w
.6486 .40336 m .62148 .44116 L .63413 .46385 L p
1 g
F P
s
P
p
.002 w
.62148 .44116 m .6486 .40336 L .63033 .38399 L p
1 g
F P
s
P
p
.002 w
.50469 .30077 m .50652 .30813 L .53587 .30968 L p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .50652 .30813 L .50469 .30077 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .50469 .30077 L .49987 .29448 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .49987 .29448 L .49254 .28996 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .49254 .28996 L .4835 .28774 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .4835 .28774 L .47376 .28809 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .47376 .28809 L .46441 .29096 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .46441 .29096 L .4565 .29604 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .4565 .29604 L .45091 .30274 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .45091 .30274 L .44823 .3103 L closepath p
1 g
F P
s
P
p
.002 w
.47706 .30962 m .44823 .3103 L .44873 .31789 L closepath p
1 g
F P
s
P
p
.002 w
.42036 .31401 m .4216 .32899 L .44873 .31789 L p
1 g
F P
s
P
p
.002 w
.44873 .31789 m .44823 .3103 L .42036 .31401 L p
1 g
F P
s
P
p
.002 w
.53251 .29508 m .53587 .30968 L .56451 .31427 L p
1 g
F P
s
P
p
.002 w
.53587 .30968 m .53251 .29508 L .50469 .30077 L p
1 g
F P
s
P
p
.002 w
.61727 .33231 m .60912 .36613 L .63033 .38399 L p
1 g
F P
s
P
p
.002 w
.60912 .36613 m .61727 .33231 L .59185 .32185 L p
1 g
F P
s
P
p
.002 w
.34002 .47905 m .3801 .5073 L .38404 .4817 L p
1 g
F P
s
P
p
.002 w
.38404 .4817 m .34673 .45478 L .34002 .47905 L p
1 g
F P
s
P
p
.002 w
.39406 .32075 m .39622 .34273 L .4216 .32899 L p
1 g
F P
s
P
p
.002 w
.4216 .32899 m .42036 .31401 L .39406 .32075 L p
1 g
F P
s
P
p
.002 w
.49987 .29448 m .50469 .30077 L .53251 .29508 L p
1 g
F P
s
P
p
.002 w
.42547 .29896 m .42036 .31401 L .44823 .3103 L p
1 g
F P
s
P
p
.002 w
.44823 .3103 m .45091 .30274 L .42547 .29896 L p
1 g
F P
s
P
p
.002 w
.33609 .39708 m .35715 .43045 L .37096 .40657 L p
1 g
F P
s
P
p
.002 w
.37096 .40657 m .35293 .37709 L .33609 .39708 L p
1 g
F P
s
P
p
.002 w
.55992 .29275 m .56451 .31427 L .59185 .32185 L p
1 g
F P
s
P
p
.002 w
.56451 .31427 m .55992 .29275 L .53251 .29508 L p
1 g
F P
s
P
p
.002 w
.55067 .56312 m .60475 .54079 L .59942 .5191 L p
1 g
F P
s
P
p
.002 w
.64365 .48622 m .59942 .5191 L .60475 .54079 L p
1 g
F P
s
P
p
.002 w
.59942 .5191 m .64365 .48622 L .63413 .46385 L p
1 g
F P
s
P
p
.002 w
.36993 .33045 m .37315 .35886 L .39622 .34273 L p
1 g
F P
s
P
p
.002 w
.39622 .34273 m .39406 .32075 L .36993 .33045 L p
1 g
F P
s
P
p
.002 w
.53251 .29508 m .52312 .28249 L .49987 .29448 L p
1 g
F P
s
P
p
.002 w
.49254 .28996 m .49987 .29448 L .52312 .28249 L p
1 g
F P
s
P
p
.002 w
.38126 .55385 m .43404 .57014 L .43118 .54798 L p
1 g
F P
s
P
p
.002 w
.43118 .54798 m .37913 .53154 L .38126 .55385 L p
1 g
F P
s
P
p
.002 w
.4365 .28553 m .42547 .29896 L .45091 .30274 L p
1 g
F P
s
P
p
.002 w
.45091 .30274 m .4565 .29604 L .4365 .28553 L p
1 g
F P
s
P
p
.002 w
.66347 .42386 m .63413 .46385 L .64365 .48622 L p
1 g
F P
s
P
p
.002 w
.63413 .46385 m .66347 .42386 L .6486 .40336 L p
1 g
F P
s
P
p
.002 w
.64018 .3455 m .63033 .38399 L .6486 .40336 L p
1 g
F P
s
P
p
.002 w
.63033 .38399 m .64018 .3455 L .61727 .33231 L p
1 g
F P
s
P
p
.002 w
.52312 .28249 m .53251 .29508 L .55992 .29275 L p
1 g
F P
s
P
p
.002 w
.52312 .28249 m .50862 .27338 L .49254 .28996 L p
1 g
F P
s
P
p
.002 w
.4835 .28774 m .49254 .28996 L .50862 .27338 L p
1 g
F P
s
P
p
.002 w
.40133 .29847 m .39406 .32075 L .42036 .31401 L p
1 g
F P
s
P
p
.002 w
.42036 .31401 m .42547 .29896 L .40133 .29847 L p
1 g
F P
s
P
p
.002 w
.45228 .2753 m .4365 .28553 L .4565 .29604 L p
1 g
F P
s
P
p
.002 w
.4565 .29604 m .46441 .29096 L .45228 .2753 L p
1 g
F P
s
P
p
.002 w
.49615 .59222 m .55402 .58225 L .55067 .56312 L p
1 g
F P
s
P
p
.002 w
.55067 .56312 m .49216 .57319 L .49615 .59222 L p
1 g
F P
s
P
p
.002 w
.60475 .54079 m .55067 .56312 L .55402 .58225 L p
1 g
F P
s
P
p
.002 w
.58633 .29391 m .59185 .32185 L .61727 .33231 L p
1 g
F P
s
P
p
.002 w
.59185 .32185 m .58633 .29391 L .55992 .29275 L p
1 g
F P
s
P
p
.002 w
.33733 .50268 m .37913 .53154 L .3801 .5073 L p
1 g
F P
s
P
p
.002 w
.3801 .5073 m .34002 .47905 L .33733 .50268 L p
1 g
F P
s
P
p
.002 w
.32312 .41843 m .34673 .45478 L .35715 .43045 L p
1 g
F P
s
P
p
.002 w
.35715 .43045 m .33609 .39708 L .32312 .41843 L p
1 g
F P
s
P
p
.002 w
.43871 .58939 m .49615 .59222 L .49216 .57319 L p
1 g
F P
s
P
p
.002 w
.49216 .57319 m .43404 .57014 L .43871 .58939 L p
1 g
F P
s
P
p
.002 w
.50862 .27338 m .49057 .26885 L .4835 .28774 L p
1 g
F P
s
P
p
.002 w
.47376 .28809 m .4835 .28774 L .49057 .26885 L p
1 g
F P
s
P
p
.002 w
.47103 .26951 m .45228 .2753 L .46441 .29096 L p
1 g
F P
s
P
p
.002 w
.46441 .29096 m .47376 .28809 L .47103 .26951 L p
1 g
F P
s
P
p
.002 w
.49057 .26885 m .47103 .26951 L .47376 .28809 L p
1 g
F P
s
P
p
.002 w
.3486 .343 m .35293 .37709 L .37315 .35886 L p
1 g
F P
s
P
p
.002 w
.37315 .35886 m .36993 .33045 L .3486 .343 L p
1 g
F P
s
P
p
.002 w
.55992 .29275 m .54632 .27403 L .52312 .28249 L p
1 g
F P
s
P
p
.002 w
.50862 .27338 m .52312 .28249 L .54632 .27403 L p
1 g
F P
s
P
p
.002 w
.54632 .27403 m .55992 .29275 L .58633 .29391 L p
1 g
F P
s
P
p
.002 w
.65998 .36122 m .6486 .40336 L .66347 .42386 L p
1 g
F P
s
P
p
.002 w
.6486 .40336 m .65998 .36122 L .64018 .3455 L p
1 g
F P
s
P
p
.002 w
.41752 .27845 m .40133 .29847 L .42547 .29896 L p
1 g
F P
s
P
p
.002 w
.42547 .29896 m .4365 .28553 L .41752 .27845 L p
1 g
F P
s
P
p
.002 w
.55402 .58225 m .60754 .56032 L .60475 .54079 L p
1 g
F P
s
P
p
.002 w
.64973 .50778 m .60475 .54079 L .60754 .56032 L p
1 g
F P
s
P
p
.002 w
.60475 .54079 m .64973 .50778 L .64365 .48622 L p
1 g
F P
s
P
p
.002 w
.37907 .30142 m .36993 .33045 L .39406 .32075 L p
1 g
F P
s
P
p
.002 w
.39406 .32075 m .40133 .29847 L .37907 .30142 L p
1 g
F P
s
P
p
.002 w
.61111 .29864 m .61727 .33231 L .64018 .3455 L p
1 g
F P
s
P
p
.002 w
.61727 .33231 m .61111 .29864 L .58633 .29391 L p
1 g
F P
s
P
p
.002 w
.67446 .44507 m .64365 .48622 L .64973 .50778 L p
1 g
F P
s
P
p
.002 w
.64365 .48622 m .67446 .44507 L .66347 .42386 L p
1 g
F P
s
P
p
.002 w
.3866 .57362 m .43871 .58939 L .43404 .57014 L p
1 g
F P
s
P
p
.002 w
.43404 .57014 m .38126 .55385 L .3866 .57362 L p
1 g
F P
s
P
p
.002 w
.31449 .44069 m .34002 .47905 L .34673 .45478 L p
1 g
F P
s
P
p
.002 w
.34673 .45478 m .32312 .41843 L .31449 .44069 L p
1 g
F P
s
P
p
.002 w
.33069 .35821 m .33609 .39708 L .35293 .37709 L p
1 g
F P
s
P
p
.002 w
.35293 .37709 m .3486 .343 L .33069 .35821 L p
1 g
F P
s
P
p
.002 w
.54632 .27403 m .52496 .26037 L .50862 .27338 L p
1 g
F P
s
P
p
.002 w
.49057 .26885 m .50862 .27338 L .52496 .26037 L p
1 g
F P
s
P
p
.002 w
.33888 .5251 m .38126 .55385 L .37913 .53154 L p
1 g
F P
s
P
p
.002 w
.37913 .53154 m .33733 .50268 L .33888 .5251 L p
1 g
F P
s
P
p
.002 w
.44096 .26314 m .41752 .27845 L .4365 .28553 L p
1 g
F P
s
P
p
.002 w
.4365 .28553 m .45228 .2753 L .44096 .26314 L p
1 g
F P
s
P
p
.002 w
.50039 .60771 m .55608 .5981 L .55402 .58225 L p
1 g
F P
s
P
p
.002 w
.55402 .58225 m .49615 .59222 L .50039 .60771 L p
1 g
F P
s
P
p
.002 w
.60754 .56032 m .55402 .58225 L .55608 .5981 L p
1 g
F P
s
P
p
.002 w
.56896 .26942 m .58633 .29391 L .61111 .29864 L p
1 g
F P
s
P
p
.002 w
.58633 .29391 m .56896 .26942 L .54632 .27403 L p
1 g
F P
s
P
p
.002 w
.44515 .60512 m .50039 .60771 L .49615 .59222 L p
1 g
F P
s
P
p
.002 w
.49615 .59222 m .43871 .58939 L .44515 .60512 L p
1 g
F P
s
P
p
.002 w
.52496 .26037 m .49813 .25353 L .49057 .26885 L p
1 g
F P
s
P
p
.002 w
.47103 .26951 m .49057 .26885 L .49813 .25353 L p
1 g
F P
s
P
p
.002 w
.46895 .25447 m .44096 .26314 L .45228 .2753 L p
1 g
F P
s
P
p
.002 w
.45228 .2753 m .47103 .26951 L .46895 .25447 L p
1 g
F P
s
P
p
.002 w
.52496 .26037 m .54632 .27403 L .56896 .26942 L p
1 g
F P
s
P
p
.002 w
.49813 .25353 m .46895 .25447 L .47103 .26951 L p
1 g
F P
s
P
p
.002 w
.67607 .37918 m .66347 .42386 L .67446 .44507 L p
1 g
F P
s
P
p
.002 w
.66347 .42386 m .67607 .37918 L .65998 .36122 L p
1 g
F P
s
P
p
.002 w
.63363 .30698 m .64018 .3455 L .65998 .36122 L p
1 g
F P
s
P
p
.002 w
.64018 .3455 m .63363 .30698 L .61111 .29864 L p
1 g
F P
s
P
p
.002 w
.35931 .30789 m .3486 .343 L .36993 .33045 L p
1 g
F P
s
P
p
.002 w
.36993 .33045 m .37907 .30142 L .35931 .30789 L p
1 g
F P
s
P
p
.002 w
.40006 .27516 m .37907 .30142 L .40133 .29847 L p
1 g
F P
s
P
p
.002 w
.40133 .29847 m .41752 .27845 L .40006 .27516 L p
1 g
F P
s
P
p
.002 w
.3106 .46333 m .33733 .50268 L .34002 .47905 L p
1 g
F P
s
P
p
.002 w
.34002 .47905 m .31449 .44069 L .3106 .46333 L p
1 g
F P
s
P
p
.002 w
.31677 .37582 m .32312 .41843 L .33609 .39708 L p
1 g
F P
s
P
p
.002 w
.33609 .39708 m .33069 .35821 L .31677 .37582 L p
1 g
F P
s
P
p
.002 w
.60754 .56032 m .65207 .528 L .64973 .50778 L p
1 g
F P
s
P
p
.002 w
.68115 .46651 m .64973 .50778 L .65207 .528 L p
1 g
F P
s
P
p
.002 w
.64973 .50778 m .68115 .46651 L .67446 .44507 L p
1 g
F P
s
P
p
.002 w
.55608 .5981 m .6076 .57712 L .60754 .56032 L p
1 g
F P
s
P
p
.002 w
.65207 .528 m .60754 .56032 L .6076 .57712 L p
1 g
F P
s
P
p
.002 w
.39516 .59024 m .44515 .60512 L .43871 .58939 L p
1 g
F P
s
P
p
.002 w
.43871 .58939 m .3866 .57362 L .39516 .59024 L p
1 g
F P
s
P
p
.002 w
.34482 .54568 m .3866 .57362 L .38126 .55385 L p
1 g
F P
s
P
p
.002 w
.38126 .55385 m .33888 .5251 L .34482 .54568 L p
1 g
F P
s
P
p
.002 w
.56896 .26942 m .5412 .25141 L .52496 .26037 L p
1 g
F P
s
P
p
.002 w
.49813 .25353 m .52496 .26037 L .5412 .25141 L p
1 g
F P
s
P
p
.002 w
.59046 .26893 m .61111 .29864 L .63363 .30698 L p
1 g
F P
s
P
p
.002 w
.61111 .29864 m .59046 .26893 L .56896 .26942 L p
1 g
F P
s
P
p
.002 w
.43078 .25497 m .40006 .27516 L .41752 .27845 L p
1 g
F P
s
P
p
.002 w
.41752 .27845 m .44096 .26314 L .43078 .25497 L p
1 g
F P
s
P
p
.002 w
.65323 .31886 m .65998 .36122 L .67607 .37918 L p
1 g
F P
s
P
p
.002 w
.65998 .36122 m .65323 .31886 L .63363 .30698 L p
1 g
F P
s
P
p
.002 w
.34269 .31791 m .33069 .35821 L .3486 .343 L p
1 g
F P
s
P
p
.002 w
.3486 .343 m .35931 .30789 L .34269 .31791 L p
1 g
F P
s
P
p
.002 w
.68792 .39904 m .67446 .44507 L .68115 .46651 L p
1 g
F P
s
P
p
.002 w
.67446 .44507 m .68792 .39904 L .67607 .37918 L p
1 g
F P
s
P
p
.002 w
.5412 .25141 m .56896 .26942 L .59046 .26893 L p
1 g
F P
s
P
p
.002 w
.50478 .61908 m .55673 .61011 L .55608 .5981 L p
1 g
F P
s
P
p
.002 w
.55608 .5981 m .50039 .60771 L .50478 .61908 L p
1 g
F P
s
P
p
.002 w
.6076 .57712 m .55608 .5981 L .55673 .61011 L p
1 g
F P
s
P
p
.002 w
.38463 .27593 m .35931 .30789 L .37907 .30142 L p
1 g
F P
s
P
p
.002 w
.37907 .30142 m .40006 .27516 L .38463 .27593 L p
1 g
F P
s
P
p
.002 w
.5412 .25141 m .50603 .24233 L .49813 .25353 L p
1 g
F P
s
P
p
.002 w
.46895 .25447 m .49813 .25353 L .50603 .24233 L p
1 g
F P
s
P
p
.002 w
.45333 .61677 m .50478 .61908 L .50039 .60771 L p
1 g
F P
s
P
p
.002 w
.50039 .60771 m .44515 .60512 L .45333 .61677 L p
1 g
F P
s
P
p
.002 w
.30742 .39549 m .31449 .44069 L .32312 .41843 L p
1 g
F P
s
P
p
.002 w
.32312 .41843 m .31677 .37582 L .30742 .39549 L p
1 g
F P
s
P
p
.002 w
.46763 .24353 m .43078 .25497 L .44096 .26314 L p
1 g
F P
s
P
p
.002 w
.44096 .26314 m .46895 .25447 L .46763 .24353 L p
1 g
F P
s
P
p
.002 w
.31177 .48577 m .33888 .5251 L .33733 .50268 L p
1 g
F P
s
P
p
.002 w
.33733 .50268 m .3106 .46333 L .31177 .48577 L p
1 g
F P
s
P
p
.002 w
.50603 .24233 m .46763 .24353 L .46895 .25447 L p
1 g
F P
s
P
p
.002 w
.6076 .57712 m .65042 .54631 L .65207 .528 L p
1 g
F P
s
P
p
.002 w
.68318 .48767 m .65207 .528 L .65042 .54631 L p
1 g
F P
s
P
p
.002 w
.65207 .528 m .68318 .48767 L .68115 .46651 L p
1 g
F P
s
P
p
.002 w
.55673 .61011 m .60477 .59064 L .6076 .57712 L p
1 g
F P
s
P
p
.002 w
.65042 .54631 m .6076 .57712 L .60477 .59064 L p
1 g
F P
s
P
p
.002 w
.61024 .27278 m .63363 .30698 L .65323 .31886 L p
1 g
F P
s
P
p
.002 w
.63363 .30698 m .61024 .27278 L .59046 .26893 L p
1 g
F P
s
P
p
.002 w
.35524 .56378 m .39516 .59024 L .3866 .57362 L p
1 g
F P
s
P
p
.002 w
.3866 .57362 m .34482 .54568 L .35524 .56378 L p
1 g
F P
s
P
p
.002 w
.40691 .60309 m .45333 .61677 L .44515 .60512 L p
1 g
F P
s
P
p
.002 w
.44515 .60512 m .39516 .59024 L .40691 .60309 L p
1 g
F P
s
P
p
.002 w
.66928 .33414 m .67607 .37918 L .68792 .39904 L p
1 g
F P
s
P
p
.002 w
.67607 .37918 m .66928 .33414 L .65323 .31886 L p
1 g
F P
s
P
p
.002 w
.59046 .26893 m .55693 .24694 L .5412 .25141 L p
1 g
F P
s
P
p
.002 w
.50603 .24233 m .5412 .25141 L .55693 .24694 L p
1 g
F P
s
P
p
.002 w
.32979 .33137 m .31677 .37582 L .33069 .35821 L p
1 g
F P
s
P
p
.002 w
.33069 .35821 m .34269 .31791 L .32979 .33137 L p
1 g
F P
s
P
p
.002 w
.69502 .42038 m .68115 .46651 L .68318 .48767 L p
1 g
F P
s
P
p
.002 w
.68115 .46651 m .69502 .42038 L .68792 .39904 L p
1 g
F P
s
P
p
.002 w
.42206 .25125 m .38463 .27593 L .40006 .27516 L p
1 g
F P
s
P
p
.002 w
.40006 .27516 m .43078 .25497 L .42206 .25125 L p
1 g
F P
s
P
p
.002 w
.55693 .24694 m .59046 .26893 L .61024 .27278 L p
1 g
F P
s
P
p
.002 w
.30309 .41677 m .3106 .46333 L .31449 .44069 L p
1 g
F P
s
P
p
.002 w
.31449 .44069 m .30742 .39549 L .30309 .41677 L p
1 g
F P
s
P
p
.002 w
.37177 .28099 m .34269 .31791 L .35931 .30789 L p
1 g
F P
s
P
p
.002 w
.35931 .30789 m .38463 .27593 L .37177 .28099 L p
1 g
F P
s
P
p
.002 w
.31821 .5074 m .34482 .54568 L .33888 .5251 L p
1 g
F P
s
P
p
.002 w
.33888 .5251 m .31177 .48577 L .31821 .5074 L p
1 g
F P
s
P
p
.002 w
.55693 .24694 m .5141 .23579 L .50603 .24233 L p
1 g
F P
s
P
p
.002 w
.46763 .24353 m .50603 .24233 L .5141 .23579 L p
1 g
F P
s
P
p
.002 w
.50922 .62579 m .55586 .61774 L .55673 .61011 L p
1 g
F P
s
P
p
.002 w
.55673 .61011 m .50478 .61908 L .50922 .62579 L p
1 g
F P
s
P
p
.002 w
.60477 .59064 m .55673 .61011 L .55586 .61774 L p
1 g
F P
s
P
p
.002 w
.46312 .62377 m .50922 .62579 L .50478 .61908 L p
1 g
F P
s
P
p
.002 w
.50478 .61908 m .45333 .61677 L .46312 .62377 L p
1 g
F P
s
P
p
.002 w
.46713 .23723 m .42206 .25125 L .43078 .25497 L p
1 g
F P
s
P
p
.002 w
.43078 .25497 m .46763 .24353 L .46713 .23723 L p
1 g
F P
s
P
p
.002 w
.62769 .28109 m .65323 .31886 L .66928 .33414 L p
1 g
F P
s
P
p
.002 w
.65323 .31886 m .62769 .28109 L .61024 .27278 L p
1 g
F P
s
P
p
.002 w
.5141 .23579 m .46713 .23723 L .46763 .24353 L p
1 g
F P
s
P
p
.002 w
.60477 .59064 m .6446 .56214 L .65042 .54631 L p
1 g
F P
s
P
p
.002 w
.68027 .50798 m .65042 .54631 L .6446 .56214 L p
1 g
F P
s
P
p
.002 w
.65042 .54631 m .68027 .50798 L .68318 .48767 L p
1 g
F P
s
P
p
.002 w
.68118 .35258 m .68792 .39904 L .69502 .42038 L p
1 g
F P
s
P
p
.002 w
.68792 .39904 m .68118 .35258 L .66928 .33414 L p
1 g
F P
s
P
p
.002 w
.37005 .57878 m .40691 .60309 L .39516 .59024 L p
1 g
F P
s
P
p
.002 w
.39516 .59024 m .35524 .56378 L .37005 .57878 L p
1 g
F P
s
P
p
.002 w
.3212 .34811 m .30742 .39549 L .31677 .37582 L p
1 g
F P
s
P
p
.002 w
.31677 .37582 m .32979 .33137 L .3212 .34811 L p
1 g
F P
s
P
p
.002 w
.55586 .61774 m .59895 .60032 L .60477 .59064 L p
1 g
F P
s
P
p
.002 w
.6446 .56214 m .60477 .59064 L .59895 .60032 L p
1 g
F P
s
P
p
.002 w
.69694 .44267 m .68318 .48767 L .68027 .50798 L p
1 g
F P
s
P
p
.002 w
.68318 .48767 m .69694 .44267 L .69502 .42038 L p
1 g
F P
s
P
p
.002 w
.42169 .61163 m .46312 .62377 L .45333 .61677 L p
1 g
F P
s
P
p
.002 w
.45333 .61677 m .40691 .60309 L .42169 .61163 L p
1 g
F P
s
P
p
.002 w
.61024 .27278 m .57172 .24734 L .55693 .24694 L p
1 g
F P
s
P
p
.002 w
.5141 .23579 m .55693 .24694 L .57172 .24734 L p
1 g
F P
s
P
p
.002 w
.30418 .43915 m .31177 .48577 L .3106 .46333 L p
1 g
F P
s
P
p
.002 w
.3106 .46333 m .30309 .41677 L .30418 .43915 L p
1 g
F P
s
P
p
.002 w
.57172 .24734 m .61024 .27278 L .62769 .28109 L p
1 g
F P
s
P
p
.002 w
.41513 .25236 m .37177 .28099 L .38463 .27593 L p
1 g
F P
s
P
p
.002 w
.38463 .27593 m .42206 .25125 L .41513 .25236 L p
1 g
F P
s
P
p
.002 w
.32999 .52756 m .35524 .56378 L .34482 .54568 L p
1 g
F P
s
P
p
.002 w
.34482 .54568 m .31821 .5074 L .32999 .52756 L p
1 g
F P
s
P
p
.002 w
.36199 .29045 m .32979 .33137 L .34269 .31791 L p
1 g
F P
s
P
p
.002 w
.34269 .31791 m .37177 .28099 L .36199 .29045 L p
1 g
F P
s
P
p
.002 w
.66928 .33414 m .6422 .29387 L .62769 .28109 L p
1 g
F P
s
P
p
.002 w
.6422 .29387 m .66928 .33414 L .68118 .35258 L p
1 g
F P
s
P
p
.002 w
.57172 .24734 m .52211 .23438 L .5141 .23579 L p
1 g
F P
s
P
p
.002 w
.46713 .23723 m .5141 .23579 L .52211 .23438 L p
1 g
F P
s
P
p
.002 w
.69502 .42038 m .68838 .37382 L .68118 .35258 L p
1 g
F P
s
P
p
.002 w
.68838 .37382 m .69502 .42038 L .69694 .44267 L p
1 g
F P
s
P
p
.002 w
.51361 .62736 m .5534 .62049 L .55586 .61774 L p
1 g
F P
s
P
p
.002 w
.55586 .61774 m .50922 .62579 L .51361 .62736 L p
1 g
F P
s
P
p
.002 w
.59895 .60032 m .55586 .61774 L .5534 .62049 L p
1 g
F P
s
P
p
.002 w
.46753 .23606 m .41513 .25236 L .42206 .25125 L p
1 g
F P
s
P
p
.002 w
.42206 .25125 m .46713 .23723 L .46753 .23606 L p
1 g
F P
s
P
p
.002 w
.47435 .62565 m .51361 .62736 L .50922 .62579 L p
1 g
F P
s
P
p
.002 w
.50922 .62579 m .46312 .62377 L .47435 .62565 L p
1 g
F P
s
P
p
.002 w
.59895 .60032 m .63455 .57493 L .6446 .56214 L p
1 g
F P
s
P
p
.002 w
.6446 .56214 m .67225 .52683 L .68027 .50798 L p
1 g
F P
s
P
p
.002 w
.67225 .52683 m .6446 .56214 L .63455 .57493 L p
1 g
F P
s
P
p
.004 w
.53909 .63648 m
.54398 .66229 L
s
P
p
.004 w
.31519 .56136 m
.32624 .55353 L
s
P
p
.004 w
.30569 .56808 m
.31519 .56136 L
s
P
p
.004 w
.26609 .59612 m
.30569 .56808 L
s
P
p
.002 w
.31739 .36781 m .30309 .41677 L .30742 .39549 L p
1 g
F P
s
P
p
.002 w
.30742 .39549 m .3212 .34811 L .31739 .36781 L p
1 g
F P
s
P
p
.002 w
.52211 .23438 m .46753 .23606 L .46713 .23723 L p
1 g
F P
s
P
p
.002 w
.38905 .59007 m .42169 .61163 L .40691 .60309 L p
1 g
F P
s
P
p
.002 w
.40691 .60309 m .37005 .57878 L .38905 .59007 L p
1 g
F P
s
P
p
.002 w
.3109 .462 m .31821 .5074 L .31177 .48577 L p
1 g
F P
s
P
p
.002 w
.31177 .48577 m .30418 .43915 L .3109 .462 L p
1 g
F P
s
P
p
.002 w
.68027 .50798 m .6934 .46535 L .69694 .44267 L p
1 g
F P
s
P
p
.002 w
.6934 .46535 m .68027 .50798 L .67225 .52683 L p
1 g
F P
s
P
p
.002 w
.5534 .62049 m .59011 .60566 L .59895 .60032 L p
1 g
F P
s
P
p
.002 w
.63455 .57493 m .59895 .60032 L .59011 .60566 L p
1 g
F P
s
P
p
.002 w
.62769 .28109 m .58508 .25289 L .57172 .24734 L p
1 g
F P
s
P
p
.002 w
.58508 .25289 m .62769 .28109 L .6422 .29387 L p
1 g
F P
s
P
p
.002 w
.52211 .23438 m .57172 .24734 L .58508 .25289 L p
1 g
F P
s
P
p
.002 w
.43925 .61534 m .47435 .62565 L .46312 .62377 L p
1 g
F P
s
P
p
.002 w
.46312 .62377 m .42169 .61163 L .43925 .61534 L p
1 g
F P
s
P
p
.002 w
.347 .54555 m .37005 .57878 L .35524 .56378 L p
1 g
F P
s
P
p
.002 w
.35524 .56378 m .32999 .52756 L .347 .54555 L p
1 g
F P
s
P
p
.002 w
.35577 .3043 m .3212 .34811 L .32979 .33137 L p
1 g
F P
s
P
p
.002 w
.32979 .33137 m .36199 .29045 L .35577 .3043 L p
1 g
F P
s
P
p
.002 w
.41031 .25858 m .36199 .29045 L .37177 .28099 L p
1 g
F P
s
P
p
.002 w
.37177 .28099 m .41513 .25236 L .41031 .25858 L p
1 g
F P
s
P
p
.002 w
.65319 .31098 m .68118 .35258 L .68838 .37382 L p
1 g
F P
s
P
p
.002 w
.68118 .35258 m .65319 .31098 L .6422 .29387 L p
1 g
F P
s
P
p
.002 w
.69045 .39734 m .69694 .44267 L .6934 .46535 L p
1 g
F P
s
P
p
.002 w
.69694 .44267 m .69045 .39734 L .68838 .37382 L p
1 g
F P
s
P
p
.002 w
.31874 .39 m .30418 .43915 L .30309 .41677 L p
1 g
F P
s
P
p
.002 w
.30309 .41677 m .31739 .36781 L .31874 .39 L p
1 g
F P
s
P
p
.002 w
.59011 .60566 m .6203 .58412 L .63455 .57493 L p
1 g
F P
s
P
p
.002 w
.65907 .54361 m .63455 .57493 L .6203 .58412 L p
1 g
F P
s
P
p
.002 w
.63455 .57493 m .65907 .54361 L .67225 .52683 L p
1 g
F P
s
P
p
.002 w
.32332 .48462 m .32999 .52756 L .31821 .5074 L p
1 g
F P
s
P
p
.002 w
.31821 .5074 m .3109 .462 L .32332 .48462 L p
1 g
F P
s
P
p
.002 w
.58508 .25289 m .52985 .23848 L .52211 .23438 L p
1 g
F P
s
P
p
.002 w
.46753 .23606 m .52211 .23438 L .52985 .23848 L p
1 g
F P
s
P
p
.002 w
.68423 .48774 m .67225 .52683 L .65907 .54361 L p
1 g
F P
s
P
p
.002 w
.67225 .52683 m .68423 .48774 L .6934 .46535 L p
1 g
F P
s
P
p
.002 w
.5178 .6234 m .54931 .61796 L .5534 .62049 L p
1 g
F P
s
P
p
.002 w
.5534 .62049 m .51361 .62736 L .5178 .6234 L p
1 g
F P
s
P
p
.002 w
.59011 .60566 m .5534 .62049 L .54931 .61796 L p
1 g
F P
s
P
p
.002 w
.46887 .24038 m .41031 .25858 L .41513 .25236 L p
1 g
F P
s
P
p
.002 w
.41513 .25236 m .46753 .23606 L .46887 .24038 L p
1 g
F P
s
P
p
.002 w
.48678 .62203 m .5178 .6234 L .51361 .62736 L p
1 g
F P
s
P
p
.002 w
.51361 .62736 m .47435 .62565 L .48678 .62203 L p
1 g
F P
s
P
p
.002 w
.41186 .59713 m .43925 .61534 L .42169 .61163 L p
1 g
F P
s
P
p
.002 w
.42169 .61163 m .38905 .59007 L .41186 .59713 L p
1 g
F P
s
P
p
.002 w
.59655 .26372 m .6422 .29387 L .65319 .31098 L p
1 g
F P
s
P
p
.002 w
.6422 .29387 m .59655 .26372 L .58508 .25289 L p
1 g
F P
s
P
p
.002 w
.36894 .56072 m .38905 .59007 L .37005 .57878 L p
1 g
F P
s
P
p
.002 w
.37005 .57878 m .347 .54555 L .36894 .56072 L p
1 g
F P
s
P
p
.002 w
.52985 .23848 m .46887 .24038 L .46753 .23606 L p
1 g
F P
s
P
p
.002 w
.54931 .61796 m .57833 .60622 L .59011 .60566 L p
1 g
F P
s
P
p
.002 w
.6203 .58412 m .59011 .60566 L .57833 .60622 L p
1 g
F P
s
P
p
.002 w
.52985 .23848 m .58508 .25289 L .59655 .26372 L p
1 g
F P
s
P
p
.002 w
.35351 .32237 m .31739 .36781 L .3212 .34811 L p
1 g
F P
s
P
p
.002 w
.3212 .34811 m .35577 .3043 L .35351 .32237 L p
1 g
F P
s
P
p
.002 w
.45922 .61386 m .48678 .62203 L .47435 .62565 L p
1 g
F P
s
P
p
.002 w
.47435 .62565 m .43925 .61534 L .45922 .61386 L p
1 g
F P
s
P
p
.002 w
.66014 .33214 m .68838 .37382 L .69045 .39734 L p
1 g
F P
s
P
p
.002 w
.68838 .37382 m .66014 .33214 L .65319 .31098 L p
1 g
F P
s
P
p
.002 w
.40789 .27005 m .35577 .3043 L .36199 .29045 L p
1 g
F P
s
P
p
.002 w
.36199 .29045 m .41031 .25858 L .40789 .27005 L p
1 g
F P
s
P
p
.002 w
.68707 .42255 m .6934 .46535 L .68423 .48774 L p
1 g
F P
s
P
p
.002 w
.6934 .46535 m .68707 .42255 L .69045 .39734 L p
1 g
F P
s
P
p
.002 w
.32548 .41411 m .3109 .462 L .30418 .43915 L p
1 g
F P
s
P
p
.002 w
.30418 .43915 m .31874 .39 L .32548 .41411 L p
1 g
F P
s
P
p
.002 w
.34128 .50628 m .347 .54555 L .32999 .52756 L p
1 g
F P
s
P
p
.004 w
.32624 .55353 m
.33858 .54479 L
s
P
p
.002 w
.32999 .52756 m .32332 .48462 L .34128 .50628 L p
1 g
F P
s
P
p
.002 w
.6203 .58412 m .64087 .55769 L .65907 .54361 L p
1 g
F P
s
P
p
.002 w
.66945 .50914 m .65907 .54361 L .64087 .55769 L p
1 g
F P
s
P
p
.002 w
.65907 .54361 m .66945 .50914 L .68423 .48774 L p
1 g
F P
s
P
p
.002 w
.57833 .60622 m .60204 .58922 L .6203 .58412 L p
1 g
F P
s
P
p
.002 w
.64087 .55769 m .6203 .58412 L .60204 .58922 L p
1 g
F P
s
P
p
.002 w
.43795 .59953 m .45922 .61386 L .43925 .61534 L p
1 g
F P
s
P
p
.002 w
.43925 .61534 m .41186 .59713 L .43795 .59953 L p
1 g
F P
s
P
p
.002 w
.39532 .57247 m .41186 .59713 L .38905 .59007 L p
1 g
F P
s
P
p
.002 w
.38905 .59007 m .36894 .56072 L .39532 .57247 L p
1 g
F P
s
P
p
.002 w
.59655 .26372 m .53705 .24833 L .52985 .23848 L p
1 g
F P
s
P
p
.002 w
.46887 .24038 m .52985 .23848 L .53705 .24833 L p
1 g
F P
s
P
p
.002 w
.60565 .27982 m .65319 .31098 L .66014 .33214 L p
1 g
F P
s
P
p
.002 w
.65319 .31098 m .60565 .27982 L .59655 .26372 L p
1 g
F P
s
P
p
.002 w
.47118 .25044 m .40789 .27005 L .41031 .25858 L p
1 g
F P
s
P
p
.002 w
.41031 .25858 m .46887 .24038 L .47118 .25044 L p
1 g
F P
s
P
p
.002 w
.52166 .61366 m .54361 .60987 L .54931 .61796 L p
1 g
F P
s
P
p
.002 w
.54931 .61796 m .5178 .6234 L .52166 .61366 L p
1 g
F P
s
P
p
.002 w
.57833 .60622 m .54931 .61796 L .54361 .60987 L p
1 g
F P
s
P
p
.002 w
.50009 .61267 m .52166 .61366 L .5178 .6234 L p
1 g
F P
s
P
p
.002 w
.5178 .6234 m .48678 .62203 L .50009 .61267 L p
1 g
F P
s
P
p
.002 w
.66262 .35686 m .69045 .39734 L .68707 .42255 L p
1 g
F P
s
P
p
.002 w
.69045 .39734 m .66262 .35686 L .66014 .33214 L p
1 g
F P
s
P
p
.002 w
.35551 .3443 m .31874 .39 L .31739 .36781 L p
1 g
F P
s
P
p
.002 w
.31739 .36781 m .35351 .32237 L .35551 .3443 L p
1 g
F P
s
P
p
.002 w
.67812 .4487 m .68423 .48774 L .66945 .50914 L p
1 g
F P
s
P
p
.002 w
.68423 .48774 m .67812 .4487 L .68707 .42255 L p
1 g
F P
s
P
p
.002 w
.53705 .24833 m .59655 .26372 L .60565 .27982 L p
1 g
F P
s
P
p
.002 w
.53705 .24833 m .47118 .25044 L .46887 .24038 L p
1 g
F P
s
P
p
.002 w
.54361 .60987 m .56378 .60168 L .57833 .60622 L p
1 g
F P
s
P
p
.002 w
.60204 .58922 m .57833 .60622 L .56378 .60168 L p
1 g
F P
s
P
p
.002 w
.48107 .60694 m .50009 .61267 L .48678 .62203 L p
1 g
F P
s
P
p
.002 w
.48678 .62203 m .45922 .61386 L .48107 .60694 L p
1 g
F P
s
P
p
.002 w
.33761 .43939 m .32332 .48462 L .3109 .462 L p
1 g
F P
s
P
p
.002 w
.3109 .462 m .32548 .41411 L .33761 .43939 L p
1 g
F P
s
P
p
.002 w
.4081 .28675 m .35351 .32237 L .35577 .3043 L p
1 g
F P
s
P
p
.002 w
.35577 .3043 m .40789 .27005 L .4081 .28675 L p
1 g
F P
s
P
p
.002 w
.36439 .5262 m .36894 .56072 L .347 .54555 L p
1 g
F P
s
P
p
.004 w
.36443 .5265 m
.5 .43051 L
s
P
p
.002 w
.347 .54555 m .34128 .50628 L .36439 .5262 L p
1 g
F P
s
P
p
.004 w
.34507 .5402 m
.34968 .53693 L
s
P
p
.004 w
.34968 .53693 m
.35084 .53612 L
s
P
p
.004 w
.33858 .54479 m
.34507 .5402 L
s
P
p
.002 w
.60204 .58922 m .61799 .56851 L .64087 .55769 L p
1 g
F P
s
P
p
.002 w
.64931 .52881 m .64087 .55769 L .61799 .56851 L p
1 g
F P
s
P
p
.002 w
.64087 .55769 m .64931 .52881 L .66945 .50914 L p
1 g
F P
s
P
p
.002 w
.56378 .60168 m .58014 .58986 L .60204 .58922 L p
1 g
F P
s
P
p
.002 w
.61799 .56851 m .60204 .58922 L .58014 .58986 L p
1 g
F P
s
P
p
.002 w
.42539 .58026 m .43795 .59953 L .41186 .59713 L p
1 g
F P
s
P
p
.002 w
.41186 .59713 m .39532 .57247 L .42539 .58026 L p
1 g
F P
s
P
p
.002 w
.61195 .30096 m .66014 .33214 L .66262 .35686 L p
1 g
F P
s
P
p
.002 w
.66014 .33214 m .61195 .30096 L .60565 .27982 L p
1 g
F P
s
P
p
.002 w
.46657 .59698 m .48107 .60694 L .45922 .61386 L p
1 g
F P
s
P
p
.002 w
.45922 .61386 m .43795 .59953 L .46657 .59698 L p
1 g
F P
s
P
p
.002 w
.66033 .38449 m .68707 .42255 L .67812 .4487 L p
1 g
F P
s
P
p
.002 w
.68707 .42255 m .66033 .38449 L .66262 .35686 L p
1 g
F P
s
P
p
.002 w
.66367 .47495 m .66945 .50914 L .64931 .52881 L p
1 g
F P
s
P
p
.002 w
.66945 .50914 m .66367 .47495 L .67812 .4487 L p
1 g
F P
s
P
p
.002 w
.60565 .27982 m .54345 .26395 L .53705 .24833 L p
1 g
F P
s
P
p
.002 w
.47118 .25044 m .53705 .24833 L .54345 .26395 L p
1 g
F P
s
P
p
.002 w
.36193 .36954 m .32548 .41411 L .31874 .39 L p
1 g
F P
s
P
p
.002 w
.31874 .39 m .35551 .3443 L .36193 .36954 L p
1 g
F P
s
P
p
.002 w
.47444 .26626 m .4081 .28675 L .40789 .27005 L p
1 g
F P
s
P
p
.002 w
.40789 .27005 m .47118 .25044 L .47444 .26626 L p
1 g
F P
s
P
p
.002 w
.35493 .46503 m .34128 .50628 L .32332 .48462 L p
1 g
F P
s
P
p
.002 w
.32332 .48462 m .33761 .43939 L .35493 .46503 L p
1 g
F P
s
P
p
.002 w
.39201 .54364 m .39532 .57247 L .36894 .56072 L p
1 g
F P
s
P
p
.002 w
.36894 .56072 m .36439 .5262 L .39201 .54364 L p
1 g
F P
s
P
p
.002 w
.52503 .59809 m .53638 .59614 L .54361 .60987 L p
1 g
F P
s
P
p
.002 w
.54361 .60987 m .52166 .61366 L .52503 .59809 L p
1 g
F P
s
P
p
.002 w
.56378 .60168 m .54361 .60987 L .53638 .59614 L p
1 g
F P
s
P
p
.002 w
.51391 .59755 m .52503 .59809 L .52166 .61366 L p
1 g
F P
s
P
p
.002 w
.52166 .61366 m .50009 .61267 L .51391 .59755 L p
1 g
F P
s
P
p
.002 w
.54345 .26395 m .60565 .27982 L .61195 .30096 L p
1 g
F P
s
P
p
.002 w
.53638 .59614 m .54678 .59188 L .56378 .60168 L p
1 g
F P
s
P
p
.002 w
.58014 .58986 m .56378 .60168 L .54678 .59188 L p
1 g
F P
s
P
p
.002 w
.54345 .26395 m .47444 .26626 L .47118 .25044 L p
1 g
F P
s
P
p
.002 w
.50417 .59456 m .51391 .59755 L .50009 .61267 L p
1 g
F P
s
P
p
.002 w
.50009 .61267 m .48107 .60694 L .50417 .59456 L p
1 g
F P
s
P
p
.002 w
.41109 .30838 m .35551 .3443 L .35351 .32237 L p
1 g
F P
s
P
p
.002 w
.35351 .32237 m .4081 .28675 L .41109 .30838 L p
1 g
F P
s
P
p
.002 w
.58014 .58986 m .59098 .57554 L .61799 .56851 L p
1 g
F P
s
P
p
.002 w
.62426 .54605 m .61799 .56851 L .59098 .57554 L p
1 g
F P
s
P
p
.002 w
.61799 .56851 m .62426 .54605 L .64931 .52881 L p
1 g
F P
s
P
p
.002 w
.45824 .58371 m .46657 .59698 L .43795 .59953 L p
1 g
F P
s
P
p
.002 w
.43795 .59953 m .42539 .58026 L .45824 .58371 L p
1 g
F P
s
P
p
.002 w
.65318 .41418 m .67812 .4487 L .66367 .47495 L p
1 g
F P
s
P
p
.002 w
.67812 .4487 m .65318 .41418 L .66033 .38449 L p
1 g
F P
s
P
p
.002 w
.64403 .50041 m .64931 .52881 L .62426 .54605 L p
1 g
F P
s
P
p
.002 w
.64931 .52881 m .64403 .50041 L .66367 .47495 L p
1 g
F P
s
P
p
.002 w
.6151 .32667 m .66262 .35686 L .66033 .38449 L p
1 g
F P
s
P
p
.002 w
.66262 .35686 m .6151 .32667 L .61195 .30096 L p
1 g
F P
s
P
p
.002 w
.54678 .59188 m .55515 .58577 L .58014 .58986 L p
1 g
F P
s
P
p
.002 w
.59098 .57554 m .58014 .58986 L .55515 .58577 L p
1 g
F P
s
P
p
.002 w
.49686 .5894 m .50417 .59456 L .48107 .60694 L p
1 g
F P
s
P
p
.002 w
.48107 .60694 m .46657 .59698 L .49686 .5894 L p
1 g
F P
s
P
p
.002 w
.42328 .55791 m .42539 .58026 L .39532 .57247 L p
1 g
F P
s
P
p
.002 w
.39532 .57247 m .39201 .54364 L .42328 .55791 L p
1 g
F P
s
P
p
.002 w
.37699 .49009 m .36439 .5262 L .34128 .50628 L p
1 g
F P
s
P
p
.002 w
.34128 .50628 m .35493 .46503 L .37699 .49009 L p
1 g
F P
s
P
p
.002 w
.37274 .39733 m .33761 .43939 L .32548 .41411 L p
1 g
F P
s
P
p
.002 w
.32548 .41411 m .36193 .36954 L .37274 .39733 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52169 .54479 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.61195 .30096 m .54877 .28516 L .54345 .26395 L p
1 g
F P
s
P
p
.002 w
.47444 .26626 m .54345 .26395 L .54877 .28516 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.54877 .28516 m .61195 .30096 L .6151 .32667 L p
1 g
F P
s
P
p
.002 w
.55515 .58577 m .56059 .57842 L .59098 .57554 L p
1 g
F P
s
P
p
.002 w
.59502 .56016 m .59098 .57554 L .56059 .57842 L p
1 g
F P
s
P
p
.002 w
.59098 .57554 m .59502 .56016 L .62426 .54605 L p
1 g
F P
s
P
p
.002 w
.47859 .28764 m .41109 .30838 L .4081 .28675 L p
1 g
F P
s
P
p
.002 w
.4081 .28675 m .47444 .26626 L .47859 .28764 L p
1 g
F P
s
P
p
.002 w
.49277 .58259 m .49686 .5894 L .46657 .59698 L p
1 g
F P
s
P
p
.002 w
.46657 .59698 m .45824 .58371 L .49277 .58259 L p
1 g
F P
s
P
p
.002 w
.61976 .52416 m .62426 .54605 L .59502 .56016 L p
1 g
F P
s
P
p
.002 w
.62426 .54605 m .61976 .52416 L .64403 .50041 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.64124 .44495 m .66367 .47495 L .64403 .50041 L p
1 g
F P
s
P
p
.002 w
.66367 .47495 m .64124 .44495 L .65318 .41418 L p
1 g
F P
s
P
p
.002 w
.53638 .59614 m .52503 .59809 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.54678 .59188 m .53638 .59614 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .59809 m .51391 .59755 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.41688 .33446 m .36193 .36954 L .35551 .3443 L p
1 g
F P
s
P
p
.002 w
.35551 .3443 m .41109 .30838 L .41688 .33446 L p
1 g
F P
s
P
p
.002 w
.55515 .58577 m .54678 .59188 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.51391 .59755 m .50417 .59456 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.45714 .56845 m .45824 .58371 L .42539 .58026 L p
1 g
F P
s
P
p
.002 w
.42539 .58026 m .42328 .55791 L .45714 .56845 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.61484 .35625 m .66033 .38449 L .65318 .41418 L p
1 g
F P
s
P
p
.002 w
.66033 .38449 m .61484 .35625 L .6151 .32667 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54877 .28516 m .47859 .28764 L .47444 .26626 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.4031 .51367 m .39201 .54364 L .36439 .5262 L p
1 g
F P
s
P
p
.002 w
.36439 .5262 m .37699 .49009 L .4031 .51367 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.56059 .57842 m .55515 .58577 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.50417 .59456 m .49686 .5894 L .52778 .57688 L closepath p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.38769 .42674 m .35493 .46503 L .33761 .43939 L p
1 g
F P
s
P
p
.002 w
.33761 .43939 m .37274 .39733 L .38769 .42674 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.56059 .57842 m .56249 .57059 L .59502 .56016 L p
1 g
F P
s
P
p
.002 w
.59162 .54533 m .59502 .56016 L .56249 .57059 L p
1 g
F P
s
P
p
.002 w
.59502 .56016 m .59162 .54533 L .61976 .52416 L p
1 g
F P
s
P
p
.002 w
.62483 .47571 m .64403 .50041 L .61976 .52416 L p
1 g
F P
s
P
p
.002 w
.64403 .50041 m .62483 .47571 L .64124 .44495 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53178 .57493 L p
1 g
F P
s
P
p
.54854 .56129 m .53178 .57493 L .53214 .57469 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56321 L p
1 g
F P
s
P
p
.002 w
.55643 .55841 m .56059 .56312 L .54265 .57065 L p
1 g
F P
s
P
p
.55643 .55841 m .54265 .57065 L .54595 .56693 L 1 g
F
P
p
.54926 .56321 m .54004 .57174 L .53178 .57493 L 1 g
F
P
p
.55643 .55841 m .54595 .56693 L .54926 .56321 L 1 g
F
P
p
.54595 .56693 m .54004 .57174 L .54926 .56321 L 1 g
F
P
p
.56075 .54566 m .55403 .55784 L .55471 .55708 L 1 g
F
P
p
.56075 .54566 m .55471 .55708 L .55496 .5568 L 1 g
F
P
p
.002 w
.58093 .53271 m .55504 .55684 L p
.55511 .55659 L 1 g
F P
s
P
p
.002 w
.57419 .52917 m .58093 .53271 L p
.56006 .55201 L 1 g
F P
s
P
p
.5616 .54726 m .56006 .55201 L .55511 .55659 L 1 g
F
P
p
.57419 .52917 m .56006 .55201 L .5616 .54726 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54726 L p
1 g
F P
s
P
p
.56654 .52734 m .5616 .54726 L .56458 .53806 L 1 g
F
P
p
.002 w
.5616 .54726 m .56075 .54566 L p
.55496 .5568 L 1 g
F P
s
P
p
.56075 .54566 m .54926 .56321 L .55403 .55784 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56757 .52884 m .56654 .52734 L p
.56458 .53806 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56757 .52884 L p
1 g
F P
s
P
p
.002 w
.56748 .52564 m .56845 .52615 L p
.56755 .52819 L 1 g
F P
s
P
p
.002 w
.56845 .52615 m .57419 .52917 L p
.5616 .54726 L 1 g
F P
s
P
p
.56515 .50826 m .56757 .52884 L .56748 .52564 L 1 g
F
P
p
.002 w
.56687 .5179 m .57977 .49187 L p
.56748 .52564 L 1 g
F P
s
P
p
.56712 .52101 m .56748 .52564 L .56739 .52279 L 1 g
F
P
p
.56515 .50826 m .56748 .52564 L .56712 .52101 L 1 g
F
P
p
.002 w
.58093 .53271 m .56748 .52564 L p
.57977 .49187 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56755 .52819 m .5616 .54726 L .55511 .55659 L 1 g
F
P
p
.56845 .52615 m .56757 .52884 L .56755 .52819 L 1 g
F
P
p
.56757 .52884 m .5616 .54726 L .56755 .52819 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56599 .50926 L p
1 g
F P
s
P
p
.002 w
.55531 .487 m .56389 .48871 L p
.5639 .49762 L 1 g
F P
s
P
p
.55739 .49133 m .5639 .49762 L .56392 .50494 L 1 g
F
P
p
.55531 .487 m .5639 .49762 L .55739 .49133 L 1 g
F
P
p
.55661 .4905 m .56599 .50926 L .56126 .49939 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56389 .48871 m .56853 .51456 L .56599 .50926 L 1 g
F
P
p
.002 w
.56599 .50926 m .56515 .50826 L p
.56734 .52249 L 1 g
F P
s
P
p
.002 w
.56687 .5179 m .56396 .52379 L p
.56389 .48871 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55739 .49133 L p
1 g
F P
s
P
p
.002 w
.55739 .49133 m .55661 .4905 L p
.56126 .49939 L 1 g
F P
s
P
p
.56126 .49939 m .56713 .51061 L .55739 .49133 L 1 g
F
P
p
.002 w
.56389 .48871 m .57977 .49187 L .56853 .51456 L p
1 g
F P
s
P
p
.002 w
.56853 .51456 m .56687 .5179 L p
.56599 .50926 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55228 .4864 L 1 g
F
P
p
.002 w
.55228 .4864 m .54824 .48559 L .54857 .4828 L p
1 g
F P
s
P
p
.55164 .48577 m .55228 .4864 L .5518 .48594 L 1 g
F
P
p
.54174 .47608 m .55228 .4864 L .55164 .48577 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.57977 .49187 m .55228 .4864 L p
.55252 .44937 L 1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.54824 .48559 m .55228 .4864 L p
.56396 .52379 L 1 g
F P
s
P
p
.002 w
.55228 .4864 m .55531 .487 L p
.55602 .49001 L 1 g
F P
s
P
p
.55228 .4864 m .55602 .49001 L .56396 .52379 L 1 g
F
P
p
.55531 .487 m .56392 .50494 L .56396 .52379 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54227 .47666 L p
1 g
F P
s
P
p
.53117 .4713 m .53797 .47458 L .54824 .48559 L 1 g
F
P
p
.52214 .46667 m .54227 .47666 L .52983 .47065 L 1 g
F
P
p
.002 w
.54857 .4828 m .54824 .48559 L p
.53797 .47458 L 1 g
F P
s
P
p
.51614 .45119 m .54227 .47666 L .53797 .47458 L 1 g
F
P
p
.54227 .47666 m .54857 .4828 L .53797 .47458 L 1 g
F
P
p
.002 w
.52237 .46705 m .52214 .46667 L p
.52983 .47065 L 1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54824 .48559 m .51362 .48744 L .50995 .4654 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46705 L p
1 g
F P
s
P
p
.5 .4634 m .52237 .46705 L .51146 .4656 L 1 g
F
P
p
.52679 .46763 m .54824 .48559 L .50995 .4654 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50995 .4654 m .51362 .48744 L p
.48569 .46591 L 1 g
F P
s
P
p
.002 w
.4776 .4671 m .47786 .46667 L p
.48636 .46581 L 1 g
F P
s
P
p
.5 .46379 m .50995 .4654 L .48569 .46591 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46379 L p
1 g
F P
s
P
p
.002 w
.5 .46379 m .5 .46442 L p
.48636 .46581 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46379 L .48636 .46581 L 1 g
F
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.46433 .46443 m .47838 .46027 L p
.48569 .46591 L 1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.47393 .46891 m .48569 .46591 L .51362 .48744 L 1 g
F
P
p
.4776 .4671 m .48569 .46591 L .47393 .46891 L 1 g
F
P
p
.45826 .47608 m .46857 .47156 L .46792 .47188 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .4671 L p
1 g
F P
s
P
p
.45826 .47608 m .4776 .4671 L .46857 .47156 L 1 g
F
P
p
.002 w
.51362 .48744 m .48016 .49724 L .46433 .46443 L p
1 g
F P
s
P
p
.002 w
.4776 .4671 m .47718 .46778 L p
.46857 .47156 L 1 g
F P
s
P
p
.46433 .46443 m .48072 .46556 L .47188 .46795 L 1 g
F
P
p
.48072 .46556 m .48569 .46591 L .4776 .4671 L 1 g
F
P
p
.48072 .46556 m .4776 .4671 L .47188 .46795 L 1 g
F
P
p
.002 w
.42803 .48609 m .46433 .46443 L .46792 .47188 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46792 .47188 m .48016 .49724 L p
.44439 .48959 L 1 g
F P
s
P
p
.45778 .4766 m .46792 .47188 L .44439 .48959 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44274 .49119 L p
1 g
F P
s
P
p
.43485 .50826 m .44274 .49119 L .4403 .49611 L 1 g
F
P
p
.002 w
.43899 .49875 m .42803 .48609 L p
.44362 .48942 L 1 g
F P
s
P
p
.43485 .50826 m .44229 .49167 L .43816 .50052 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.48016 .49724 m .45197 .51376 L .43899 .49875 L p
1 g
F P
s
P
p
.002 w
.44274 .49119 m .44339 .4905 L p
.44848 .48562 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45778 .4766 L p
1 g
F P
s
P
p
.002 w
.45778 .4766 m .45698 .47747 L p
.44848 .48562 L 1 g
F P
s
P
p
.44339 .4905 m .45778 .4766 L .44848 .48562 L 1 g
F
P
p
.44274 .49119 m .48016 .49724 L .43899 .49875 L 1 g
F
P
p
.44362 .48942 m .44439 .48959 L .44274 .49119 L 1 g
F
P
p
.44439 .48959 m .48016 .49724 L .44274 .49119 L 1 g
F
P
p
.002 w
.44274 .49119 m .44229 .49167 L p
.4403 .49611 L 1 g
F P
s
P
p
.002 w
.4031 .51367 m .42803 .48609 L .43899 .49875 L p
1 g
F P
s
P
p
.4031 .51367 m .43491 .50045 L .432 .51372 L 1 g
F
P
p
.43491 .50045 m .43899 .49875 L .43418 .50906 L 1 g
F
P
p
.43491 .50045 m .43418 .50906 L .432 .51372 L 1 g
F
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43418 .50906 L p
1 g
F P
s
P
p
.43346 .52734 m .43418 .50906 L .43322 .52037 L 1 g
F
P
p
.002 w
.43899 .49875 m .45197 .51376 L p
.43378 .51373 L 1 g
F P
s
P
p
.432 .51372 m .43418 .50906 L .43378 .51373 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.43418 .50906 m .43899 .49875 L .43378 .51373 L 1 g
F
P
p
.002 w
.43251 .52872 m .43346 .52734 L p
.43322 .52037 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43234 .53485 m .4031 .51367 L p
.42896 .51372 L 1 g
F P
s
P
p
.002 w
.43363 .53346 m .43234 .53485 L p
.42896 .51372 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43228 .52906 L p
1 g
F P
s
P
p
.43925 .54566 m .43228 .52906 L .43331 .53242 L 1 g
F
P
p
.002 w
.43443 .53606 m .43234 .53485 L p
.43411 .535 L 1 g
F P
s
P
p
.43925 .54566 m .43331 .53242 L .43452 .53631 L 1 g
F
P
p
.002 w
.43234 .53485 m .43363 .53346 L p
.43411 .535 L 1 g
F P
s
P
p
.43331 .53242 m .43199 .52948 L .43443 .53606 L 1 g
F
P
p
.43331 .53242 m .43443 .53606 L .43452 .53631 L 1 g
F
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45197 .51376 m .47721 .53868 L p
.43411 .535 L 1 g
F P
s
P
p
.002 w
.43363 .53346 m .45197 .51376 L p
.43411 .535 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.47721 .53868 m .46364 .55285 L .43443 .53606 L p
1 g
F P
s
P
p
.43411 .535 m .47721 .53868 L .43443 .53606 L 1 g
F
P
p
.002 w
.43228 .52906 m .43199 .52948 L p
.43331 .53242 L 1 g
F P
s
P
p
.002 w
.42328 .55791 m .43234 .53485 L .43443 .53606 L p
1 g
F P
s
P
p
.42328 .55791 m .4327 .53945 L .44168 .5556 L 1 g
F
P
p
.4327 .53945 m .43443 .53606 L .43851 .54706 L 1 g
F
P
p
.4327 .53945 m .43851 .54706 L .44168 .5556 L 1 g
F
P
p
.002 w
.43743 .5491 m .43925 .54566 L p
.43411 .5355 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43851 .54706 L p
1 g
F P
s
P
p
.45146 .56129 m .43851 .54706 L .44527 .55591 L 1 g
F
P
p
.002 w
.43443 .53606 m .46364 .55285 L p
.44474 .55522 L 1 g
F P
s
P
p
.44168 .5556 m .43851 .54706 L .44474 .55522 L 1 g
F
P
p
.43851 .54706 m .43443 .53606 L .44474 .55522 L 1 g
F
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44527 .55591 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45714 .56845 m .42328 .55791 L p
.44127 .55566 L 1 g
F P
s
P
p
.46872 .57265 m .4569 .56793 L .45725 .5682 L 1 g
F
P
p
.46872 .57265 m .45725 .5682 L .45746 .56833 L 1 g
F
P
p
.002 w
.4683 .57456 m .46872 .57265 L p
.45746 .56833 L 1 g
F P
s
P
p
.002 w
.45714 .56845 m .45725 .5682 L p
.45763 .56843 L 1 g
F P
s
P
p
.45746 .56833 m .45737 .5683 L .45787 .56858 L 1 g
F
P
p
.45746 .56833 m .45787 .56858 L .4683 .57456 L 1 g
F
P
p
.002 w
.45725 .5682 m .45714 .56845 L p
.44127 .55566 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.46364 .55285 m .49585 .56702 L p
.45763 .56843 L 1 g
F P
s
P
p
.002 w
.45725 .5682 m .46364 .55285 L p
.45763 .56843 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49585 .56702 m .4924 .57485 L .45787 .56858 L p
1 g
F P
s
P
p
.002 w
.45787 .56858 m .45714 .56845 L p
.45763 .56843 L 1 g
F P
s
P
p
.45763 .56843 m .49585 .56702 L .45787 .56858 L 1 g
F
P
p
.45746 .56833 m .45725 .5682 L .45737 .5683 L 1 g
F
P
p
.002 w
.45824 .58371 m .45714 .56845 L .45787 .56858 L p
1 g
F P
s
P
p
.45824 .58371 m .45794 .57136 L .47615 .57906 L 1 g
F
P
p
.45794 .57136 m .45787 .56858 L .4683 .57456 L 1 g
F
P
p
.45794 .57136 m .4683 .57456 L .47615 .57906 L 1 g
F
P
p
.002 w
.48903 .58098 m .48921 .57862 L p
.47858 .57775 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57456 L p
1 g
F P
s
P
p
.48921 .57862 m .4683 .57456 L .47858 .57775 L 1 g
F
P
p
.002 w
.45787 .56858 m .4924 .57485 L p
.47979 .57812 L 1 g
F P
s
P
p
.47615 .57906 m .4683 .57456 L .47979 .57812 L 1 g
F
P
p
.4683 .57456 m .45787 .56858 L .47979 .57812 L 1 g
F
P
p
.002 w
.4683 .57456 m .4678 .57686 L p
.47858 .57775 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.49277 .58259 m .45824 .58371 L p
.47419 .57957 L 1 g
F P
s
P
p
.002 w
.49271 .58133 m .49277 .58259 L p
.47419 .57957 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .489 .58146 L p
1 g
F P
s
P
p
.002 w
.50262 .58099 m .49277 .58259 L .49271 .58133 L p
1 g
F P
s
P
p
.002 w
.489 .58146 m .48889 .583 L p
.49818 .58114 L 1 g
F P
s
P
p
.51079 .57862 m .489 .58146 L .49818 .58114 L 1 g
F
P
p
.002 w
.49686 .5894 m .49277 .58259 L .50262 .58099 L p
1 g
F P
s
P
p
.002 w
.51923 .58034 m .49686 .5894 L p
.50119 .58307 L 1 g
F P
s
P
p
.50119 .58307 m .50262 .58099 L .51094 .58066 L 1 g
F
P
p
.50119 .58307 m .51094 .58066 L .51923 .58034 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58066 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58066 L .52004 .57842 L 1 g
F
P
p
.002 w
.51094 .58066 m .51079 .57862 L p
.49807 .58116 L 1 g
F P
s
P
p
.002 w
.52778 .57688 m .51923 .58034 L p
.51094 .58066 L 1 g
F P
s
P
p
.002 w
.52327 .57762 m .52778 .57688 L p
.51094 .58066 L 1 g
F P
s
P
p
.002 w
.53178 .57493 m .53128 .57265 L p
.52 .57844 L 1 g
F P
s
P
p
.002 w
.52651 .57681 m .52778 .57688 L .52327 .57762 L p
1 g
F P
s
P
p
.52 .57844 m .52651 .57681 L .53178 .57493 L 1 g
F
P
p
.52651 .57681 m .52689 .57671 L .53178 .57493 L 1 g
F
P
p
.52685 .57672 m .52713 .57665 L .53178 .57493 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.4924 .57485 m .49585 .56702 L .52707 .57667 L p
1 g
F P
s
P
p
.002 w
.52707 .57667 m .52778 .57688 L .52651 .57681 L p
1 g
F P
s
P
p
.002 w
.52651 .57681 m .4924 .57485 L p
.52707 .57667 L 1 g
F P
s
P
p
.52651 .57681 m .52685 .57672 L .52689 .57671 L 1 g
F
P
p
.52685 .57672 m .52707 .57667 L .52713 .57665 L 1 g
F
P
p
.52707 .57667 m .5275 .57654 L .53178 .57493 L 1 g
F
P
p
.002 w
.49585 .56702 m .5028 .55995 L .52734 .57659 L p
1 g
F P
s
P
p
.002 w
.52734 .57659 m .52778 .57688 L .52707 .57667 L p
1 g
F P
s
P
p
.002 w
.52707 .57667 m .49585 .56702 L p
.52734 .57659 L 1 g
F P
s
P
p
.52734 .5766 m .5277 .57648 L .53178 .57493 L 1 g
F
P
p
.002 w
.5028 .55995 m .51249 .55446 L .52754 .57653 L p
1 g
F P
s
P
p
.002 w
.52754 .57653 m .52778 .57688 L .52734 .57659 L p
1 g
F P
s
P
p
.002 w
.52734 .57659 m .5028 .55995 L p
.52754 .57653 L 1 g
F P
s
P
p
.52707 .57667 m .52734 .5766 L .5275 .57654 L 1 g
F
P
p
.52734 .5766 m .52745 .57658 L .5277 .57648 L 1 g
F
P
p
.52745 .57658 m .52804 .57636 L .53178 .57493 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52385 .55118 m .5356 .55049 L .52792 .57641 L p
1 g
F P
s
P
p
.002 w
.52792 .57641 m .52778 .57688 L .52772 .57648 L p
1 g
F P
s
P
p
.002 w
.52772 .57648 m .52385 .55118 L p
.52792 .57641 L 1 g
F P
s
P
p
.52754 .57655 m .52895 .57602 L .53178 .57493 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5356 .55049 m .5464 .55246 L .52823 .57629 L p
1 g
F P
s
P
p
.002 w
.52823 .57629 m .52778 .57688 L .52792 .57641 L p
1 g
F P
s
P
p
.002 w
.52792 .57641 m .5356 .55049 L p
.52823 .57629 L 1 g
F P
s
P
p
.002 w
.52772 .57648 m .52778 .57688 L .52754 .57653 L p
1 g
F P
s
P
p
.52745 .57658 m .52754 .57655 L .52804 .57636 L 1 g
F
P
p
.002 w
.54004 .57174 m .53067 .57567 L p
.53178 .57493 L 1 g
F P
s
P
p
.5399 .56953 m .53179 .57497 L .53921 .57018 L 1 g
F
P
p
.54854 .56129 m .53196 .57483 L .5399 .56953 L 1 g
F
P
p
.53196 .57483 m .53179 .57497 L .5399 .56953 L 1 g
F
P
p
.002 w
.54265 .57065 m .54004 .57174 L p
.54595 .56693 L 1 g
F P
s
P
p
.002 w
.56249 .57059 m .56059 .57842 L .52876 .57693 L p
1 g
F P
s
P
p
.002 w
.52924 .57662 m .56249 .57059 L p
.52876 .57693 L 1 g
F P
s
P
p
.002 w
.56059 .56312 m .56249 .57059 L .52924 .57662 L p
1 g
F P
s
P
p
.002 w
.53067 .57567 m .56059 .56312 L p
.52924 .57662 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5493 .56333 L p
1 g
F P
s
P
p
.002 w
.5493 .56333 m .54854 .56129 L p
.53978 .56964 L 1 g
F P
s
P
p
.53978 .56964 m .5322 .57686 L .5493 .56333 L 1 g
F
P
p
.002 w
.52924 .57662 m .52778 .57688 L .53067 .57567 L p
1 g
F P
s
P
p
.002 w
.55471 .55708 m .52895 .57602 L p
.55496 .5568 L 1 g
F P
s
P
p
.002 w
.52895 .57602 m .52778 .57688 L p
.52894 .57602 L 1 g
F P
s
P
p
.55496 .5568 m .52895 .57602 L .52894 .57602 L 1 g
F
P
p
.002 w
.55504 .55684 m .55643 .55841 L p
.52936 .57586 L 1 g
F P
s
P
p
.002 w
.52778 .57688 m .52895 .57602 L p
.52936 .57586 L 1 g
F P
s
P
p
.002 w
.52895 .57602 m .55504 .55684 L p
.52936 .57586 L 1 g
F P
s
P
p
.002 w
.53067 .57567 m .52778 .57688 L p
.55643 .55841 L 1 g
F P
s
P
p
.002 w
.5319 .57549 m .53178 .57495 L p
.52767 .57653 L 1 g
F P
s
P
p
.002 w
.53178 .57495 m .53178 .57493 L p
.5299 .57566 L 1 g
F P
s
P
p
.5299 .57566 m .52767 .57653 L .53178 .57495 L 1 g
F
P
p
.52754 .57655 m .52763 .57653 L .52895 .57602 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.5464 .55246 m .55496 .5568 L p
.52894 .57602 L 1 g
F P
s
P
p
.002 w
.52778 .57688 m .52823 .57629 L p
.52894 .57602 L 1 g
F P
s
P
p
.002 w
.52823 .57629 m .5464 .55246 L p
.52894 .57602 L 1 g
F P
s
P
p
.002 w
.51249 .55446 m .52385 .55118 L .52772 .57648 L p
1 g
F P
s
P
p
.002 w
.52754 .57653 m .51249 .55446 L p
.52772 .57648 L 1 g
F P
s
P
p
.52722 .57663 m .51182 .58263 L .52763 .57653 L 1 g
F
P
p
.52 .57844 m .51742 .57976 L .52722 .57663 L 1 g
F
P
p
.51742 .57976 m .51182 .58263 L .52722 .57663 L 1 g
F
P
p
.002 w
.4924 .57485 m .52651 .57681 L p
.50262 .58099 L 1 g
F P
s
P
p
.002 w
.52327 .57762 m .50262 .58099 L p
.52651 .57681 L 1 g
F P
s
P
p
.002 w
.50262 .58099 m .52327 .57762 L p
.51094 .58066 L 1 g
F P
s
P
p
.002 w
.52876 .57693 m .52778 .57688 L .52924 .57662 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5319 .57549 L p
1 g
F P
s
P
p
.52767 .57653 m .51111 .583 L .5319 .57549 L 1 g
F
P
p
.002 w
.51094 .58066 m .51111 .583 L p
.52004 .57842 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51094 .58066 L p
.49577 .58162 L 1 g
F P
s
P
p
.49807 .58116 m .49577 .58162 L .51094 .58066 L 1 g
F
P
p
.002 w
.49271 .58133 m .4924 .57485 L p
.50262 .58099 L 1 g
F P
s
P
p
.002 w
.4924 .57485 m .49271 .58133 L p
.47419 .57957 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51025 .583 L p
.49577 .58162 L 1 g
F P
s
P
p
.002 w
.51025 .583 m .51111 .583 L p
.49577 .58162 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58098 L p
1 g
F P
s
P
p
.47858 .57775 m .4678 .57686 L .48903 .58098 L 1 g
F
P
p
.002 w
.46787 .57654 m .4683 .57456 L p
.45737 .5683 L 1 g
F P
s
P
p
.002 w
.46364 .55285 m .45725 .5682 L p
.44127 .55566 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46787 .57654 L p
1 g
F P
s
P
p
.4569 .56793 m .45002 .56518 L .46787 .57654 L 1 g
F
P
p
.002 w
.43851 .54706 m .43743 .5491 L p
.44527 .55591 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.44527 .55591 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.002 w
.43199 .52948 m .43146 .53025 L p
.43452 .53631 L 1 g
F P
s
P
p
.002 w
.45197 .51376 m .43363 .53346 L p
.42896 .51372 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43703 .54783 L p
.43411 .5355 L 1 g
F P
s
P
p
.002 w
.43703 .54783 m .43743 .5491 L p
.43411 .5355 L 1 g
F P
s
P
p
.002 w
.43418 .50906 m .43287 .51061 L p
.43322 .52037 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52872 L p
1 g
F P
s
P
p
.43322 .52037 m .43287 .51061 L .43251 .52872 L 1 g
F
P
p
.002 w
.44229 .49167 m .44166 .49233 L p
.43816 .50052 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44274 .49119 L p
1 g
F P
s
P
p
.44848 .48562 m .45698 .47747 L .44274 .49119 L 1 g
F
P
p
.43446 .48746 m .45778 .4766 L .44439 .48959 L 1 g
F
P
p
.002 w
.45778 .4766 m .45826 .47608 L p
.46792 .47188 L 1 g
F P
s
P
p
.42803 .48609 m .46792 .47188 L .43446 .48746 L 1 g
F
P
p
.002 w
.45731 .47712 m .45778 .4766 L p
.46792 .47188 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45731 .47712 L p
1 g
F P
s
P
p
.46857 .47156 m .47718 .46778 L .45731 .47712 L 1 g
F
P
p
.47188 .46795 m .4776 .4671 L .47393 .46891 L 1 g
F
P
p
.47838 .46027 m .5 .46379 L .48569 .46591 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .4671 L p
1 g
F P
s
P
p
.48636 .46581 m .5 .46442 L .4776 .4671 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46379 L p
1 g
F P
s
P
p
.002 w
.5 .46379 m .5 .4634 L p
.51301 .4659 L 1 g
F P
s
P
p
.51301 .4659 m .52282 .46778 L .5 .46379 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.47838 .46027 m .50765 .45162 L .50995 .4654 L p
1 g
F P
s
P
p
.002 w
.50995 .4654 m .50765 .45162 L p
.52679 .46763 L 1 g
F P
s
P
p
.002 w
.52237 .46705 m .52282 .46778 L p
.51146 .4656 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46705 L p
1 g
F P
s
P
p
.52983 .47065 m .54302 .47747 L .52237 .46705 L 1 g
F
P
p
.002 w
.54227 .47666 m .54302 .47747 L p
.52983 .47065 L 1 g
F P
s
P
p
.002 w
.50765 .45162 m .51614 .45119 L p
.53797 .47458 L 1 g
F P
s
P
p
.50765 .45162 m .53797 .47458 L .53117 .4713 L 1 g
F
P
p
.54174 .47608 m .5518 .48594 L .55002 .48421 L 1 g
F
P
p
.002 w
.54227 .47666 m .54174 .47608 L p
.55002 .48421 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51614 .45119 m .55252 .44937 L .54857 .4828 L p
1 g
F P
s
P
p
.002 w
.54282 .47726 m .54227 .47666 L p
.55002 .48421 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54282 .47726 L p
1 g
F P
s
P
p
.5518 .48594 m .55834 .49233 L .54282 .47726 L 1 g
F
P
p
.002 w
.54857 .4828 m .55252 .44937 L p
.55228 .4864 L 1 g
F P
s
P
p
.002 w
.55739 .49133 m .55834 .49233 L p
.5518 .48594 L 1 g
F P
s
P
p
.002 w
.56599 .50926 m .56713 .51061 L p
.56126 .49939 L 1 g
F P
s
P
p
.002 w
.56702 .51049 m .56599 .50926 L p
.56739 .52279 L 1 g
F P
s
P
p
.56734 .52249 m .56739 .52279 L .56599 .50926 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56702 .51049 L p
1 g
F P
s
P
p
.56739 .52279 m .56854 .53025 L .56702 .51049 L 1 g
F
P
p
.002 w
.56748 .52564 m .56396 .52379 L .56687 .5179 L p
1 g
F P
s
P
p
.002 w
.56757 .52884 m .56854 .53025 L p
.56739 .52279 L 1 g
F P
s
P
p
.002 w
.56396 .52379 m .56748 .52564 L p
.55511 .55659 L 1 g
F P
s
P
p
.56748 .52564 m .56755 .52819 L .55511 .55659 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56757 .52884 L p
1 g
F P
s
P
p
.56458 .53806 m .56257 .5491 L .56757 .52884 L 1 g
F
P
p
.002 w
.5616 .54726 m .56257 .5491 L p
.56458 .53806 L 1 g
F P
s
P
p
.002 w
.56226 .5485 m .5616 .54726 L p
.55496 .5568 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.5464 .55246 m .56396 .52379 L p
.55511 .55659 L 1 g
F P
s
P
p
.002 w
.55504 .55684 m .55496 .5568 L p
.55511 .55659 L 1 g
F P
s
P
p
.002 w
.55496 .5568 m .5464 .55246 L p
.55511 .55659 L 1 g
F P
s
P
p
.002 w
.56228 .54856 m .56226 .5485 L p
.55496 .5568 L 1 g
F P
s
P
p
.002 w
.55496 .5568 m .55504 .55684 L .55471 .55708 L p
1 g
F P
s
P
p
.55496 .5568 m .55471 .55708 L .55495 .55681 L 1 g
F
P
p
.55496 .5568 m .55495 .55681 L .56228 .54856 L 1 g
F
P
p
.002 w
.56059 .56312 m .55504 .55684 L .58093 .53271 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56228 .54856 L p
1 g
F P
s
P
p
.55403 .55784 m .54998 .56518 L .56228 .54856 L 1 g
F
P
p
.002 w
.54926 .56321 m .54998 .56518 L p
.55403 .55784 L 1 g
F P
s
P
p
.51182 .58263 m .51111 .583 L .53178 .57493 L 1 g
F
P
p
.002 w
.53178 .57493 m .53179 .57497 L p
.53214 .57469 L 1 g
F P
s
P
p
.002 w
.53179 .57497 m .5322 .57686 L p
.53921 .57018 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.43234 .53485 m .42328 .55791 L .39201 .54364 L p
1 g
F P
s
P
p
.002 w
.39201 .54364 m .4031 .51367 L .43234 .53485 L p
1 g
F P
s
P
p
.002 w
.55278 .31149 m .6151 .32667 L .61484 .35625 L p
1 g
F P
s
P
p
.002 w
.6151 .32667 m .55278 .31149 L .54877 .28516 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.61104 .38875 m .65318 .41418 L .64124 .44495 L p
1 g
F P
s
P
p
.002 w
.65318 .41418 m .61104 .38875 L .61484 .35625 L p
1 g
F P
s
P
p
.002 w
.56249 .57059 m .56059 .56312 L .59162 .54533 L p
1 g
F P
s
P
p
.002 w
.47859 .28764 m .54877 .28516 L .55278 .31149 L p
1 g
F P
s
P
p
.002 w
.60449 .50533 m .61976 .52416 L .59162 .54533 L p
1 g
F P
s
P
p
.002 w
.61976 .52416 m .60449 .50533 L .62483 .47571 L p
1 g
F P
s
P
p
.002 w
.48354 .3141 m .41688 .33446 L .41109 .30838 L p
1 g
F P
s
P
p
.002 w
.41109 .30838 m .47859 .28764 L .48354 .3141 L p
1 g
F P
s
P
p
.002 w
.4254 .36419 m .37274 .39733 L .36193 .36954 L p
1 g
F P
s
P
p
.002 w
.36193 .36954 m .41688 .33446 L .4254 .36419 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40634 .4567 m .37699 .49009 L .35493 .46503 L p
1 g
F P
s
P
p
.002 w
.35493 .46503 m .38769 .42674 L .40634 .4567 L p
1 g
F P
s
P
p
.002 w
.58093 .53271 m .59162 .54533 L .56059 .56312 L p
1 g
F P
s
P
p
.002 w
.59162 .54533 m .58093 .53271 L .60449 .50533 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.55278 .31149 m .48354 .3141 L .47859 .28764 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.60376 .42304 m .64124 .44495 L .62483 .47571 L p
1 g
F P
s
P
p
.002 w
.64124 .44495 m .60376 .42304 L .61104 .38875 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.55528 .34219 m .61484 .35625 L .61104 .38875 L p
1 g
F P
s
P
p
.002 w
.61484 .35625 m .55528 .34219 L .55278 .31149 L p
1 g
F P
s
P
p
.002 w
.42803 .48609 m .4031 .51367 L .37699 .49009 L p
1 g
F P
s
P
p
.002 w
.37699 .49009 m .40634 .4567 L .42803 .48609 L p
1 g
F P
s
P
p
.002 w
.5028 .55995 m .49585 .56702 L .46364 .55285 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.59321 .45786 m .62483 .47571 L .60449 .50533 L p
1 g
F P
s
P
p
.002 w
.62483 .47571 m .59321 .45786 L .60376 .42304 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.43641 .39658 m .38769 .42674 L .37274 .39733 L p
1 g
F P
s
P
p
.002 w
.37274 .39733 m .4254 .36419 L .43641 .39658 L p
1 g
F P
s
P
p
.002 w
.5464 .55246 m .5356 .55049 L .54252 .51972 L p
1 g
F P
s
P
p
.002 w
.54252 .51972 m .56396 .52379 L .5464 .55246 L p
1 g
F P
s
P
p
.002 w
.57977 .49187 m .60449 .50533 L .58093 .53271 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48354 .3141 m .55278 .31149 L .55528 .34219 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51249 .55446 m .5028 .55995 L .47721 .53868 L p
1 g
F P
s
P
p
.002 w
.46364 .55285 m .47721 .53868 L .5028 .55995 L p
1 g
F P
s
P
p
.002 w
.60449 .50533 m .57977 .49187 L .59321 .45786 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48913 .34487 m .4254 .36419 L .41688 .33446 L p
1 g
F P
s
P
p
.002 w
.41688 .33446 m .48354 .3141 L .48913 .34487 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5356 .55049 m .52385 .55118 L .51908 .52103 L p
1 g
F P
s
P
p
.002 w
.51908 .52103 m .54252 .51972 L .5356 .55049 L p
1 g
F P
s
P
p
.002 w
.52385 .55118 m .51249 .55446 L .49642 .52762 L p
1 g
F P
s
P
p
.002 w
.47721 .53868 m .49642 .52762 L .51249 .55446 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.49642 .52762 m .51908 .52103 L .52385 .55118 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5561 .37626 m .61104 .38875 L .60376 .42304 L p
1 g
F P
s
P
p
.002 w
.61104 .38875 m .5561 .37626 L .55528 .34219 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.55528 .34219 m .48913 .34487 L .48354 .3141 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56396 .52379 m .54252 .51972 L .54824 .48559 L p
1 g
F P
s
P
p
.002 w
.44955 .43043 m .40634 .4567 L .38769 .42674 L p
1 g
F P
s
P
p
.002 w
.38769 .42674 m .43641 .39658 L .44955 .43043 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.49642 .52762 m .47721 .53868 L .45197 .51376 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.48913 .34487 m .55528 .34219 L .5561 .37626 L p
1 g
F P
s
P
p
.002 w
.55517 .41244 m .60376 .42304 L .59321 .45786 L p
1 g
F P
s
P
p
.002 w
.60376 .42304 m .55517 .41244 L .5561 .37626 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55252 .44937 m .59321 .45786 L .57977 .49187 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49517 .37891 m .43641 .39658 L .4254 .36419 L p
1 g
F P
s
P
p
.002 w
.4254 .36419 m .48913 .34487 L .49517 .37891 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54252 .51972 m .51908 .52103 L .51362 .48744 L p
1 g
F P
s
P
p
.002 w
.51362 .48744 m .54824 .48559 L .54252 .51972 L p
1 g
F P
s
P
p
.002 w
.46433 .46443 m .42803 .48609 L .40634 .4567 L p
1 g
F P
s
P
p
.002 w
.40634 .4567 m .44955 .43043 L .46433 .46443 L p
1 g
F P
s
P
p
.002 w
.51908 .52103 m .49642 .52762 L .48016 .49724 L p
1 g
F P
s
P
p
.002 w
.45197 .51376 m .48016 .49724 L .49642 .52762 L p
1 g
F P
s
P
p
.002 w
.59321 .45786 m .55252 .44937 L .55517 .41244 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.48016 .49724 m .51362 .48744 L .51908 .52103 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.5561 .37626 m .49517 .37891 L .48913 .34487 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.53716 .62635 m
.53909 .63648 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49517 .37891 m .5561 .37626 L .55517 .41244 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.50142 .41496 m .44955 .43043 L .43641 .39658 L p
1 g
F P
s
P
p
.002 w
.43641 .39658 m .49517 .37891 L .50142 .41496 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.50142 .41496 m .55517 .41244 L .55252 .44937 L p
1 g
F P
s
P
p
.002 w
.55517 .41244 m .50142 .41496 L .49517 .37891 L p
1 g
F P
s
P
p
.002 w
.55252 .44937 m .50765 .45162 L .50142 .41496 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50765 .45162 m .46433 .46443 L .44955 .43043 L p
1 g
F P
s
P
p
.002 w
.44955 .43043 m .50142 .41496 L .50765 .45162 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .26609 .59612 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .54398 .66229 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.331008)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.331008)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.43087 .45251 m .4762 .46528 L .48033 .43717 L p
1 g
F P
s
P
p
.002 w
.48033 .43717 m .44066 .42582 L .43087 .45251 L p
1 g
F P
s
P
p
.002 w
.52222 .43888 m .48033 .43717 L .4762 .46528 L p
1 g
F P
s
P
p
.002 w
.44066 .42582 m .48033 .43717 L .48493 .40896 L p
1 g
F P
s
P
p
.002 w
.48033 .43717 m .52222 .43888 L .51992 .41038 L p
1 g
F P
s
P
p
.002 w
.51992 .41038 m .48493 .40896 L .48033 .43717 L p
1 g
F P
s
P
p
.002 w
.4762 .46528 m .52398 .46724 L .52222 .43888 L p
1 g
F P
s
P
p
.002 w
.56257 .4308 m .52222 .43888 L .52398 .46724 L p
1 g
F P
s
P
p
.002 w
.52222 .43888 m .56257 .4308 L .55357 .40348 L p
1 g
F P
s
P
p
.002 w
.55357 .40348 m .51992 .41038 L .52222 .43888 L p
1 g
F P
s
P
p
.002 w
.48493 .40896 m .45186 .39934 L .44066 .42582 L p
1 g
F P
s
P
p
.002 w
.45186 .39934 m .48493 .40896 L .48992 .38115 L p
1 g
F P
s
P
p
.002 w
.48493 .40896 m .51992 .41038 L .51713 .38225 L p
1 g
F P
s
P
p
.002 w
.51713 .38225 m .48992 .38115 L .48493 .40896 L p
1 g
F P
s
P
p
.002 w
.51992 .41038 m .55357 .40348 L .54325 .37677 L p
1 g
F P
s
P
p
.002 w
.54325 .37677 m .51713 .38225 L .51992 .41038 L p
1 g
F P
s
P
p
.002 w
.42267 .47894 m .4726 .49278 L .4762 .46528 L p
1 g
F P
s
P
p
.002 w
.4762 .46528 m .43087 .45251 L .42267 .47894 L p
1 g
F P
s
P
p
.002 w
.52398 .46724 m .4762 .46528 L .4726 .49278 L p
1 g
F P
s
P
p
.002 w
.4726 .49278 m .52518 .49495 L .52398 .46724 L p
1 g
F P
s
P
p
.002 w
.57007 .45822 m .52398 .46724 L .52518 .49495 L p
1 g
F P
s
P
p
.002 w
.52398 .46724 m .57007 .45822 L .56257 .4308 L p
1 g
F P
s
P
p
.002 w
.48992 .38115 m .46425 .37357 L .45186 .39934 L p
1 g
F P
s
P
p
.002 w
.46425 .37357 m .48992 .38115 L .49521 .35426 L p
1 g
F P
s
P
p
.002 w
.48992 .38115 m .51713 .38225 L .51389 .35501 L p
1 g
F P
s
P
p
.002 w
.51389 .35501 m .49521 .35426 L .48992 .38115 L p
1 g
F P
s
P
p
.002 w
.51713 .38225 m .54325 .37677 L .5318 .35117 L p
1 g
F P
s
P
p
.002 w
.5318 .35117 m .51389 .35501 L .51713 .38225 L p
1 g
F P
s
P
p
.002 w
.40688 .40569 m .44066 .42582 L .45186 .39934 L p
1 g
F P
s
P
p
.002 w
.45186 .39934 m .42384 .38231 L .40688 .40569 L p
1 g
F P
s
P
p
.002 w
.42384 .38231 m .45186 .39934 L .46425 .37357 L p
1 g
F P
s
P
p
.002 w
.39209 .42986 m .43087 .45251 L .44066 .42582 L p
1 g
F P
s
P
p
.002 w
.44066 .42582 m .40688 .40569 L .39209 .42986 L p
1 g
F P
s
P
p
.002 w
.58268 .38876 m .55357 .40348 L .56257 .4308 L p
1 g
F P
s
P
p
.002 w
.55357 .40348 m .58268 .38876 L .56573 .36514 L p
1 g
F P
s
P
p
.002 w
.56573 .36514 m .54325 .37677 L .55357 .40348 L p
1 g
F P
s
P
p
.002 w
.59765 .41346 m .56257 .4308 L .57007 .45822 L p
1 g
F P
s
P
p
.002 w
.56257 .4308 m .59765 .41346 L .58268 .38876 L p
1 g
F P
s
P
p
.002 w
.46425 .37357 m .44263 .36017 L .42384 .38231 L p
1 g
F P
s
P
p
.002 w
.44263 .36017 m .46425 .37357 L .47761 .34898 L p
1 g
F P
s
P
p
.002 w
.49521 .35426 m .47761 .34898 L .46425 .37357 L p
1 g
F P
s
P
p
.002 w
.41626 .50459 m .46963 .51916 L .4726 .49278 L p
1 g
F P
s
P
p
.002 w
.4726 .49278 m .42267 .47894 L .41626 .50459 L p
1 g
F P
s
P
p
.002 w
.52518 .49495 m .4726 .49278 L .46963 .51916 L p
1 g
F P
s
P
p
.002 w
.54325 .37677 m .56573 .36514 L .54711 .34307 L p
1 g
F P
s
P
p
.002 w
.54711 .34307 m .5318 .35117 L .54325 .37677 L p
1 g
F P
s
P
p
.002 w
.46963 .51916 m .52578 .52148 L .52518 .49495 L p
1 g
F P
s
P
p
.002 w
.57594 .48525 m .52518 .49495 L .52578 .52148 L p
1 g
F P
s
P
p
.002 w
.52518 .49495 m .57594 .48525 L .57007 .45822 L p
1 g
F P
s
P
p
.002 w
.37979 .45437 m .42267 .47894 L .43087 .45251 L p
1 g
F P
s
P
p
.002 w
.43087 .45251 m .39209 .42986 L .37979 .45437 L p
1 g
F P
s
P
p
.002 w
.61032 .43878 m .57007 .45822 L .57594 .48525 L p
1 g
F P
s
P
p
.002 w
.57007 .45822 m .61032 .43878 L .59765 .41346 L p
1 g
F P
s
P
p
.002 w
.47761 .34898 m .49521 .35426 L .5007 .3288 L p
1 g
F P
s
P
p
.002 w
.49521 .35426 m .51389 .35501 L .51026 .32918 L p
1 g
F P
s
P
p
.002 w
.51026 .32918 m .5007 .3288 L .49521 .35426 L p
1 g
F P
s
P
p
.002 w
.51389 .35501 m .5318 .35117 L .51941 .32718 L p
1 g
F P
s
P
p
.002 w
.51941 .32718 m .51026 .32918 L .51389 .35501 L p
1 g
F P
s
P
p
.002 w
.47761 .34898 m .46289 .33968 L .44263 .36017 L p
1 g
F P
s
P
p
.002 w
.46289 .33968 m .47761 .34898 L .49171 .32606 L p
1 g
F P
s
P
p
.002 w
.5007 .3288 m .49171 .32606 L .47761 .34898 L p
1 g
F P
s
P
p
.002 w
.5318 .35117 m .54711 .34307 L .52718 .32298 L p
1 g
F P
s
P
p
.002 w
.52718 .32298 m .51941 .32718 L .5318 .35117 L p
1 g
F P
s
P
p
.002 w
.3824 .37838 m .40688 .40569 L .42384 .38231 L p
1 g
F P
s
P
p
.002 w
.42384 .38231 m .40375 .3593 L .3824 .37838 L p
1 g
F P
s
P
p
.002 w
.40375 .3593 m .42384 .38231 L .44263 .36017 L p
1 g
F P
s
P
p
.002 w
.44263 .36017 m .42731 .34215 L .40375 .3593 L p
1 g
F P
s
P
p
.002 w
.42731 .34215 m .44263 .36017 L .46289 .33968 L p
1 g
F P
s
P
p
.002 w
.37029 .47873 m .41626 .50459 L .42267 .47894 L p
1 g
F P
s
P
p
.002 w
.42267 .47894 m .37979 .45437 L .37029 .47873 L p
1 g
F P
s
P
p
.002 w
.60428 .36742 m .58268 .38876 L .59765 .41346 L p
1 g
F P
s
P
p
.002 w
.58268 .38876 m .60428 .36742 L .58222 .3484 L p
1 g
F P
s
P
p
.002 w
.58222 .3484 m .56573 .36514 L .58268 .38876 L p
1 g
F P
s
P
p
.002 w
.56573 .36514 m .58222 .3484 L .55822 .33149 L p
1 g
F P
s
P
p
.002 w
.55822 .33149 m .54711 .34307 L .56573 .36514 L p
1 g
F P
s
P
p
.002 w
.52578 .52148 m .58002 .51136 L .57594 .48525 L p
1 g
F P
s
P
p
.002 w
.62041 .46425 m .57594 .48525 L .58002 .51136 L p
1 g
F P
s
P
p
.002 w
.57594 .48525 m .62041 .46425 L .61032 .43878 L p
1 g
F P
s
P
p
.002 w
.41181 .52893 m .46735 .54387 L .46963 .51916 L p
1 g
F P
s
P
p
.002 w
.46963 .51916 m .41626 .50459 L .41181 .52893 L p
1 g
F P
s
P
p
.002 w
.52578 .52148 m .46963 .51916 L .46735 .54387 L p
1 g
F P
s
P
p
.002 w
.46735 .54387 m .52575 .5463 L .52578 .52148 L p
1 g
F P
s
P
p
.002 w
.58002 .51136 m .52578 .52148 L .52575 .5463 L p
1 g
F P
s
P
p
.002 w
.36373 .39902 m .39209 .42986 L .40688 .40569 L p
1 g
F P
s
P
p
.002 w
.40688 .40569 m .3824 .37838 L .36373 .39902 L p
1 g
F P
s
P
p
.002 w
.46289 .33968 m .45259 .32724 L .42731 .34215 L p
1 g
F P
s
P
p
.002 w
.45259 .32724 m .46289 .33968 L .48424 .32126 L p
1 g
F P
s
P
p
.002 w
.49171 .32606 m .48424 .32126 L .46289 .33968 L p
1 g
F P
s
P
p
.002 w
.62392 .38818 m .59765 .41346 L .61032 .43878 L p
1 g
F P
s
P
p
.002 w
.59765 .41346 m .62392 .38818 L .60428 .36742 L p
1 g
F P
s
P
p
.002 w
.54711 .34307 m .55822 .33149 L .53274 .31703 L p
1 g
F P
s
P
p
.002 w
.53274 .31703 m .52718 .32298 L .54711 .34307 L p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .49171 .32606 L .5007 .3288 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .5007 .3288 L .51026 .32918 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .51026 .32918 L .51941 .32718 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .48424 .32126 L .49171 .32606 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .51941 .32718 L .52718 .32298 L closepath p
1 g
F P
s
P
p
.002 w
.3482 .42083 m .37979 .45437 L .39209 .42986 L p
1 g
F P
s
P
p
.002 w
.39209 .42986 m .36373 .39902 L .3482 .42083 L p
1 g
F P
s
P
p
.002 w
.48424 .32126 m .47909 .31487 L .45259 .32724 L p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .47909 .31487 L .48424 .32126 L closepath p
1 g
F P
s
P
p
.002 w
.6407 .41029 m .61032 .43878 L .62041 .46425 L p
1 g
F P
s
P
p
.002 w
.61032 .43878 m .6407 .41029 L .62392 .38818 L p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .52718 .32298 L .53274 .31703 L closepath p
1 g
F P
s
P
p
.002 w
.36387 .50242 m .41181 .52893 L .41626 .50459 L p
1 g
F P
s
P
p
.002 w
.41626 .50459 m .37029 .47873 L .36387 .50242 L p
1 g
F P
s
P
p
.002 w
.42008 .32123 m .42731 .34215 L .45259 .32724 L p
1 g
F P
s
P
p
.002 w
.45259 .32724 m .4479 .31291 L .42008 .32123 L p
1 g
F P
s
P
p
.002 w
.4479 .31291 m .45259 .32724 L .47909 .31487 L p
1 g
F P
s
P
p
.002 w
.52575 .5463 m .58218 .536 L .58002 .51136 L p
1 g
F P
s
P
p
.002 w
.62765 .48933 m .58002 .51136 L .58218 .536 L p
1 g
F P
s
P
p
.002 w
.58002 .51136 m .62765 .48933 L .62041 .46425 L p
1 g
F P
s
P
p
.002 w
.39396 .33242 m .40375 .3593 L .42731 .34215 L p
1 g
F P
s
P
p
.002 w
.42731 .34215 m .42008 .32123 L .39396 .33242 L p
1 g
F P
s
P
p
.002 w
.56385 .31756 m .55822 .33149 L .58222 .3484 L p
1 g
F P
s
P
p
.002 w
.55822 .33149 m .56385 .31756 L .53548 .30992 L p
1 g
F P
s
P
p
.002 w
.53548 .30992 m .53274 .31703 L .55822 .33149 L p
1 g
F P
s
P
p
.002 w
.59084 .3281 m .58222 .3484 L .60428 .36742 L p
1 g
F P
s
P
p
.002 w
.58222 .3484 m .59084 .3281 L .56385 .31756 L p
1 g
F P
s
P
p
.002 w
.47909 .31487 m .47684 .30757 L .4479 .31291 L p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .47684 .30757 L .47909 .31487 L closepath p
1 g
F P
s
P
p
.002 w
.40947 .55142 m .46584 .56638 L .46735 .54387 L p
1 g
F P
s
P
p
.002 w
.46735 .54387 m .41181 .52893 L .40947 .55142 L p
1 g
F P
s
P
p
.002 w
.52575 .5463 m .46735 .54387 L .46584 .56638 L p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .53274 .31703 L .53548 .30992 L closepath p
1 g
F P
s
P
p
.002 w
.46584 .56638 m .52506 .56885 L .52575 .5463 L p
1 g
F P
s
P
p
.002 w
.58218 .536 m .52575 .5463 L .52506 .56885 L p
1 g
F P
s
P
p
.002 w
.37014 .34627 m .3824 .37838 L .40375 .3593 L p
1 g
F P
s
P
p
.002 w
.40375 .3593 m .39396 .33242 L .37014 .34627 L p
1 g
F P
s
P
p
.002 w
.61584 .34135 m .60428 .36742 L .62392 .38818 L p
1 g
F P
s
P
p
.002 w
.60428 .36742 m .61584 .34135 L .59084 .3281 L p
1 g
F P
s
P
p
.002 w
.33623 .44336 m .37029 .47873 L .37979 .45437 L p
1 g
F P
s
P
p
.002 w
.37979 .45437 m .3482 .42083 L .33623 .44336 L p
1 g
F P
s
P
p
.002 w
.6542 .43332 m .62041 .46425 L .62765 .48933 L p
1 g
F P
s
P
p
.002 w
.62041 .46425 m .6542 .43332 L .6407 .41029 L p
1 g
F P
s
P
p
.002 w
.44946 .29816 m .4479 .31291 L .47684 .30757 L p
1 g
F P
s
P
p
.002 w
.47684 .30757 m .47775 .30012 L .44946 .29816 L p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .47775 .30012 L .47684 .30757 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .53548 .30992 L .53505 .30241 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .53505 .30241 L .53148 .29533 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .53148 .29533 L .52511 .28946 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .52511 .28946 L .51663 .28546 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .51663 .28546 L .50698 .28381 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .50698 .28381 L .49725 .28469 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .49725 .28469 L .48853 .28799 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .48853 .28799 L .48179 .29334 L closepath p
1 g
F P
s
P
p
.002 w
.50629 .3053 m .48179 .29334 L .47775 .30012 L closepath p
1 g
F P
s
P
p
.002 w
.53505 .30241 m .53548 .30992 L .56385 .31756 L p
1 g
F P
s
P
p
.002 w
.42201 .29954 m .42008 .32123 L .4479 .31291 L p
1 g
F P
s
P
p
.002 w
.4479 .31291 m .44946 .29816 L .42201 .29954 L p
1 g
F P
s
P
p
.002 w
.3492 .36257 m .36373 .39902 L .3824 .37838 L p
1 g
F P
s
P
p
.002 w
.3824 .37838 m .37014 .34627 L .3492 .36257 L p
1 g
F P
s
P
p
.002 w
.56327 .30272 m .56385 .31756 L .59084 .3281 L p
1 g
F P
s
P
p
.002 w
.56385 .31756 m .56327 .30272 L .53505 .30241 L p
1 g
F P
s
P
p
.002 w
.63829 .3571 m .62392 .38818 L .6407 .41029 L p
1 g
F P
s
P
p
.002 w
.62392 .38818 m .63829 .3571 L .61584 .34135 L p
1 g
F P
s
P
p
.002 w
.3608 .52491 m .40947 .55142 L .41181 .52893 L p
1 g
F P
s
P
p
.002 w
.41181 .52893 m .36387 .50242 L .3608 .52491 L p
1 g
F P
s
P
p
.002 w
.45726 .28463 m .44946 .29816 L .47775 .30012 L p
1 g
F P
s
P
p
.002 w
.47775 .30012 m .48179 .29334 L .45726 .28463 L p
1 g
F P
s
P
p
.002 w
.53148 .29533 m .53505 .30241 L .56327 .30272 L p
1 g
F P
s
P
p
.002 w
.52506 .56885 m .58231 .55862 L .58218 .536 L p
1 g
F P
s
P
p
.002 w
.63181 .5135 m .58218 .536 L .58231 .55862 L p
1 g
F P
s
P
p
.002 w
.58218 .536 m .63181 .5135 L .62765 .48933 L p
1 g
F P
s
P
p
.002 w
.39602 .30432 m .39396 .33242 L .42008 .32123 L p
1 g
F P
s
P
p
.002 w
.42008 .32123 m .42201 .29954 L .39602 .30432 L p
1 g
F P
s
P
p
.002 w
.59034 .30629 m .59084 .3281 L .61584 .34135 L p
1 g
F P
s
P
p
.002 w
.59084 .3281 m .59034 .30629 L .56327 .30272 L p
1 g
F P
s
P
p
.002 w
.47058 .27387 m .45726 .28463 L .48179 .29334 L p
1 g
F P
s
P
p
.002 w
.48179 .29334 m .48853 .28799 L .47058 .27387 L p
1 g
F P
s
P
p
.002 w
.32823 .46614 m .36387 .50242 L .37029 .47873 L p
1 g
F P
s
P
p
.002 w
.37029 .47873 m .33623 .44336 L .32823 .46614 L p
1 g
F P
s
P
p
.002 w
.56327 .30272 m .55638 .28859 L .53148 .29533 L p
1 g
F P
s
P
p
.002 w
.52511 .28946 m .53148 .29533 L .55638 .28859 L p
1 g
F P
s
P
p
.002 w
.33171 .38102 m .3482 .42083 L .36373 .39902 L p
1 g
F P
s
P
p
.002 w
.36373 .39902 m .3492 .36257 L .33171 .38102 L p
1 g
F P
s
P
p
.002 w
.40941 .57149 m .46515 .58611 L .46584 .56638 L p
1 g
F P
s
P
p
.002 w
.46584 .56638 m .40947 .55142 L .40941 .57149 L p
1 g
F P
s
P
p
.002 w
.52506 .56885 m .46584 .56638 L .46515 .58611 L p
1 g
F P
s
P
p
.002 w
.66403 .45679 m .62765 .48933 L .63181 .5135 L p
1 g
F P
s
P
p
.002 w
.62765 .48933 m .66403 .45679 L .6542 .43332 L p
1 g
F P
s
P
p
.002 w
.46515 .58611 m .52372 .58856 L .52506 .56885 L p
1 g
F P
s
P
p
.002 w
.58231 .55862 m .52506 .56885 L .52372 .58856 L p
1 g
F P
s
P
p
.002 w
.43325 .27947 m .42201 .29954 L .44946 .29816 L p
1 g
F P
s
P
p
.002 w
.44946 .29816 m .45726 .28463 L .43325 .27947 L p
1 g
F P
s
P
p
.002 w
.65763 .37506 m .6407 .41029 L .6542 .43332 L p
1 g
F P
s
P
p
.002 w
.6407 .41029 m .65763 .37506 L .63829 .3571 L p
1 g
F P
s
P
p
.002 w
.55638 .28859 m .56327 .30272 L .59034 .30629 L p
1 g
F P
s
P
p
.002 w
.48799 .26718 m .47058 .27387 L .48853 .28799 L p
1 g
F P
s
P
p
.002 w
.48853 .28799 m .49725 .28469 L .48799 .26718 L p
1 g
F P
s
P
p
.002 w
.55638 .28859 m .54379 .27679 L .52511 .28946 L p
1 g
F P
s
P
p
.002 w
.51663 .28546 m .52511 .28946 L .54379 .27679 L p
1 g
F P
s
P
p
.002 w
.37214 .31249 m .37014 .34627 L .39396 .33242 L p
1 g
F P
s
P
p
.002 w
.39396 .33242 m .39602 .30432 L .37214 .31249 L p
1 g
F P
s
P
p
.002 w
.50751 .26538 m .48799 .26718 L .49725 .28469 L p
1 g
F P
s
P
p
.002 w
.49725 .28469 m .50698 .28381 L .50751 .26538 L p
1 g
F P
s
P
p
.002 w
.54379 .27679 m .52686 .26873 L .51663 .28546 L p
1 g
F P
s
P
p
.002 w
.50698 .28381 m .51663 .28546 L .52686 .26873 L p
1 g
F P
s
P
p
.002 w
.61563 .31313 m .61584 .34135 L .63829 .3571 L p
1 g
F P
s
P
p
.002 w
.61584 .34135 m .61563 .31313 L .59034 .30629 L p
1 g
F P
s
P
p
.002 w
.52686 .26873 m .50751 .26538 L .50698 .28381 L p
1 g
F P
s
P
p
.002 w
.36128 .54563 m .40941 .57149 L .40947 .55142 L p
1 g
F P
s
P
p
.002 w
.40947 .55142 m .3608 .52491 L .36128 .54563 L p
1 g
F P
s
P
p
.002 w
.45284 .26339 m .43325 .27947 L .45726 .28463 L p
1 g
F P
s
P
p
.002 w
.45726 .28463 m .47058 .27387 L .45284 .26339 L p
1 g
F P
s
P
p
.002 w
.3182 .40127 m .33623 .44336 L .3482 .42083 L p
1 g
F P
s
P
p
.002 w
.3482 .42083 m .33171 .38102 L .3182 .40127 L p
1 g
F P
s
P
p
.002 w
.52372 .58856 m .58031 .57863 L .58231 .55862 L p
1 g
F P
s
P
p
.002 w
.63267 .53619 m .58231 .55862 L .58031 .57863 L p
1 g
F P
s
P
p
.002 w
.58231 .55862 m .63267 .53619 L .63181 .5135 L p
1 g
F P
s
P
p
.002 w
.41031 .27811 m .39602 .30432 L .42201 .29954 L p
1 g
F P
s
P
p
.002 w
.42201 .29954 m .43325 .27947 L .41031 .27811 L p
1 g
F P
s
P
p
.002 w
.59034 .30629 m .58044 .28535 L .55638 .28859 L p
1 g
F P
s
P
p
.002 w
.54379 .27679 m .55638 .28859 L .58044 .28535 L p
1 g
F P
s
P
p
.002 w
.58044 .28535 m .59034 .30629 L .61563 .31313 L p
1 g
F P
s
P
p
.002 w
.32454 .48863 m .3608 .52491 L .36387 .50242 L p
1 g
F P
s
P
p
.002 w
.36387 .50242 m .32823 .46614 L .32454 .48863 L p
1 g
F P
s
P
p
.002 w
.6733 .39489 m .6542 .43332 L .66403 .45679 L p
1 g
F P
s
P
p
.002 w
.6542 .43332 m .6733 .39489 L .65763 .37506 L p
1 g
F P
s
P
p
.002 w
.35099 .324 m .3492 .36257 L .37014 .34627 L p
1 g
F P
s
P
p
.002 w
.37014 .34627 m .37214 .31249 L .35099 .324 L p
1 g
F P
s
P
p
.002 w
.66982 .48018 m .63181 .5135 L .63267 .53619 L p
1 g
F P
s
P
p
.002 w
.63181 .5135 m .66982 .48018 L .66403 .45679 L p
1 g
F P
s
P
p
.002 w
.63852 .32319 m .63829 .3571 L .65763 .37506 L p
1 g
F P
s
P
p
.002 w
.63829 .3571 m .63852 .32319 L .61563 .31313 L p
1 g
F P
s
P
p
.002 w
.47871 .25332 m .45284 .26339 L .47058 .27387 L p
1 g
F P
s
P
p
.002 w
.47058 .27387 m .48799 .26718 L .47871 .25332 L p
1 g
F P
s
P
p
.002 w
.41172 .58856 m .46534 .60248 L .46515 .58611 L p
1 g
F P
s
P
p
.002 w
.46515 .58611 m .40941 .57149 L .41172 .58856 L p
1 g
F P
s
P
p
.002 w
.52372 .58856 m .46515 .58611 L .46534 .60248 L p
1 g
F P
s
P
p
.002 w
.46534 .60248 m .52171 .60485 L .52372 .58856 L p
1 g
F P
s
P
p
.002 w
.58031 .57863 m .52372 .58856 L .52171 .60485 L p
1 g
F P
s
P
p
.002 w
.58044 .28535 m .56193 .26773 L .54379 .27679 L p
1 g
F P
s
P
p
.002 w
.52686 .26873 m .54379 .27679 L .56193 .26773 L p
1 g
F P
s
P
p
.002 w
.38905 .28076 m .37214 .31249 L .39602 .30432 L p
1 g
F P
s
P
p
.002 w
.39602 .30432 m .41031 .27811 L .38905 .28076 L p
1 g
F P
s
P
p
.002 w
.50786 .25061 m .47871 .25332 L .48799 .26718 L p
1 g
F P
s
P
p
.002 w
.48799 .26718 m .50751 .26538 L .50786 .25061 L p
1 g
F P
s
P
p
.002 w
.56193 .26773 m .53676 .25563 L .52686 .26873 L p
1 g
F P
s
P
p
.002 w
.50751 .26538 m .52686 .26873 L .53676 .25563 L p
1 g
F P
s
P
p
.002 w
.30919 .42288 m .32823 .46614 L .33623 .44336 L p
1 g
F P
s
P
p
.002 w
.33623 .44336 m .3182 .40127 L .30919 .42288 L p
1 g
F P
s
P
p
.002 w
.60307 .28581 m .61563 .31313 L .63852 .32319 L p
1 g
F P
s
P
p
.002 w
.61563 .31313 m .60307 .28581 L .58044 .28535 L p
1 g
F P
s
P
p
.002 w
.43574 .25697 m .41031 .27811 L .43325 .27947 L p
1 g
F P
s
P
p
.002 w
.43325 .27947 m .45284 .26339 L .43574 .25697 L p
1 g
F P
s
P
p
.002 w
.53676 .25563 m .50786 .25061 L .50751 .26538 L p
1 g
F P
s
P
p
.002 w
.33321 .33869 m .33171 .38102 L .3492 .36257 L p
1 g
F P
s
P
p
.002 w
.3492 .36257 m .35099 .324 L .33321 .33869 L p
1 g
F P
s
P
p
.002 w
.56193 .26773 m .58044 .28535 L .60307 .28581 L p
1 g
F P
s
P
p
.002 w
.6848 .4162 m .66403 .45679 L .66982 .48018 L p
1 g
F P
s
P
p
.002 w
.66403 .45679 m .6848 .4162 L .6733 .39489 L p
1 g
F P
s
P
p
.002 w
.65836 .33637 m .65763 .37506 L .6733 .39489 L p
1 g
F P
s
P
p
.002 w
.65763 .37506 m .65836 .33637 L .63852 .32319 L p
1 g
F P
s
P
p
.002 w
.36549 .56397 m .41172 .58856 L .40941 .57149 L p
1 g
F P
s
P
p
.002 w
.40941 .57149 m .36128 .54563 L .36549 .56397 L p
1 g
F P
s
P
p
.002 w
.32546 .51026 m .36128 .54563 L .3608 .52491 L p
1 g
F P
s
P
p
.002 w
.3608 .52491 m .32454 .48863 L .32546 .51026 L p
1 g
F P
s
P
p
.002 w
.52171 .60485 m .57613 .59544 L .58031 .57863 L p
1 g
F P
s
P
p
.002 w
.63007 .55681 m .58031 .57863 L .57613 .59544 L p
1 g
F P
s
P
p
.002 w
.58031 .57863 m .63007 .55681 L .63267 .53619 L p
1 g
F P
s
P
p
.002 w
.67127 .50294 m .63267 .53619 L .63007 .55681 L p
1 g
F P
s
P
p
.002 w
.63267 .53619 m .67127 .50294 L .66982 .48018 L p
1 g
F P
s
P
p
.002 w
.46965 .24366 m .43574 .25697 L .45284 .26339 L p
1 g
F P
s
P
p
.002 w
.45284 .26339 m .47871 .25332 L .46965 .24366 L p
1 g
F P
s
P
p
.002 w
.37007 .28754 m .35099 .324 L .37214 .31249 L p
1 g
F P
s
P
p
.002 w
.37214 .31249 m .38905 .28076 L .37007 .28754 L p
1 g
F P
s
P
p
.002 w
.60307 .28581 m .57905 .26267 L .56193 .26773 L p
1 g
F P
s
P
p
.002 w
.53676 .25563 m .56193 .26773 L .57905 .26267 L p
1 g
F P
s
P
p
.002 w
.62368 .29014 m .63852 .32319 L .65836 .33637 L p
1 g
F P
s
P
p
.002 w
.63852 .32319 m .62368 .29014 L .60307 .28581 L p
1 g
F P
s
P
p
.002 w
.31943 .35635 m .3182 .40127 L .33171 .38102 L p
1 g
F P
s
P
p
.002 w
.33171 .38102 m .33321 .33869 L .31943 .35635 L p
1 g
F P
s
P
p
.002 w
.3051 .44535 m .32454 .48863 L .32823 .46614 L p
1 g
F P
s
P
p
.002 w
.32823 .46614 m .30919 .42288 L .3051 .44535 L p
1 g
F P
s
P
p
.002 w
.41649 .60204 m .46647 .61493 L .46534 .60248 L p
1 g
F P
s
P
p
.002 w
.46534 .60248 m .41172 .58856 L .41649 .60204 L p
1 g
F P
s
P
p
.002 w
.52171 .60485 m .46534 .60248 L .46647 .61493 L p
1 g
F P
s
P
p
.002 w
.46647 .61493 m .51904 .61714 L .52171 .60485 L p
1 g
F P
s
P
p
.002 w
.57613 .59544 m .52171 .60485 L .51904 .61714 L p
1 g
F P
s
P
p
.002 w
.41974 .25499 m .38905 .28076 L .41031 .27811 L p
1 g
F P
s
P
p
.002 w
.41031 .27811 m .43574 .25697 L .41974 .25499 L p
1 g
F P
s
P
p
.002 w
.67454 .35246 m .6733 .39489 L .6848 .4162 L p
1 g
F P
s
P
p
.002 w
.6733 .39489 m .67454 .35246 L .65836 .33637 L p
1 g
F P
s
P
p
.002 w
.69166 .43851 m .66982 .48018 L .67127 .50294 L p
1 g
F P
s
P
p
.002 w
.66982 .48018 m .69166 .43851 L .6848 .4162 L p
1 g
F P
s
P
p
.002 w
.57905 .26267 m .60307 .28581 L .62368 .29014 L p
1 g
F P
s
P
p
.002 w
.50802 .24006 m .46965 .24366 L .47871 .25332 L p
1 g
F P
s
P
p
.002 w
.47871 .25332 m .50786 .25061 L .50802 .24006 L p
1 g
F P
s
P
p
.002 w
.57905 .26267 m .54607 .2467 L .53676 .25563 L p
1 g
F P
s
P
p
.002 w
.50786 .25061 m .53676 .25563 L .54607 .2467 L p
1 g
F P
s
P
p
.002 w
.54607 .2467 m .50802 .24006 L .50786 .25061 L p
1 g
F P
s
P
p
.002 w
.33118 .53043 m .36549 .56397 L .36128 .54563 L p
1 g
F P
s
P
p
.002 w
.36128 .54563 m .32546 .51026 L .33118 .53043 L p
1 g
F P
s
P
p
.002 w
.37352 .57936 m .41649 .60204 L .41172 .58856 L p
1 g
F P
s
P
p
.002 w
.41172 .58856 m .36549 .56397 L .37352 .57936 L p
1 g
F P
s
P
p
.002 w
.57613 .59544 m .62389 .57475 L .63007 .55681 L p
1 g
F P
s
P
p
.002 w
.66816 .52445 m .63007 .55681 L .62389 .57475 L p
1 g
F P
s
P
p
.002 w
.63007 .55681 m .66816 .52445 L .67127 .50294 L p
1 g
F P
s
P
p
.002 w
.51904 .61714 m .56974 .60847 L .57613 .59544 L p
1 g
F P
s
P
p
.002 w
.62389 .57475 m .57613 .59544 L .56974 .60847 L p
1 g
F P
s
P
p
.002 w
.354 .29849 m .33321 .33869 L .35099 .324 L p
1 g
F P
s
P
p
.002 w
.35099 .324 m .37007 .28754 L .354 .29849 L p
1 g
F P
s
P
p
.002 w
.31019 .37661 m .30919 .42288 L .3182 .40127 L p
1 g
F P
s
P
p
.002 w
.3182 .40127 m .31943 .35635 L .31019 .37661 L p
1 g
F P
s
P
p
.002 w
.64164 .29841 m .65836 .33637 L .67454 .35246 L p
1 g
F P
s
P
p
.002 w
.65836 .33637 m .64164 .29841 L .62368 .29014 L p
1 g
F P
s
P
p
.002 w
.30628 .46813 m .32546 .51026 L .32454 .48863 L p
1 g
F P
s
P
p
.002 w
.32454 .48863 m .3051 .44535 L .30628 .46813 L p
1 g
F P
s
P
p
.002 w
.46103 .2387 m .41974 .25499 L .43574 .25697 L p
1 g
F P
s
P
p
.002 w
.43574 .25697 m .46965 .24366 L .46103 .2387 L p
1 g
F P
s
P
p
.002 w
.68647 .37119 m .6848 .4162 L .69166 .43851 L p
1 g
F P
s
P
p
.002 w
.6848 .4162 m .68647 .37119 L .67454 .35246 L p
1 g
F P
s
P
p
.002 w
.62368 .29014 m .59469 .26196 L .57905 .26267 L p
1 g
F P
s
P
p
.002 w
.54607 .2467 m .57905 .26267 L .59469 .26196 L p
1 g
F P
s
P
p
.002 w
.6935 .46128 m .67127 .50294 L .66816 .52445 L p
1 g
F P
s
P
p
.002 w
.67127 .50294 m .6935 .46128 L .69166 .43851 L p
1 g
F P
s
P
p
.002 w
.40532 .25777 m .37007 .28754 L .38905 .28076 L p
1 g
F P
s
P
p
.002 w
.38905 .28076 m .41974 .25499 L .40532 .25777 L p
1 g
F P
s
P
p
.002 w
.59469 .26196 m .62368 .29014 L .64164 .29841 L p
1 g
F P
s
P
p
.002 w
.42374 .61138 m .46855 .62288 L .46647 .61493 L p
1 g
F P
s
P
p
.002 w
.46647 .61493 m .41649 .60204 L .42374 .61138 L p
1 g
F P
s
P
p
.002 w
.51904 .61714 m .46647 .61493 L .46855 .62288 L p
1 g
F P
s
P
p
.002 w
.46855 .62288 m .51574 .62487 L .51904 .61714 L p
1 g
F P
s
P
p
.002 w
.56974 .60847 m .51904 .61714 L .51574 .62487 L p
1 g
F P
s
P
p
.002 w
.50796 .23426 m .46103 .2387 L .46965 .24366 L p
1 g
F P
s
P
p
.002 w
.46965 .24366 m .50802 .24006 L .50796 .23426 L p
1 g
F P
s
P
p
.002 w
.34179 .5485 m .37352 .57936 L .36549 .56397 L p
1 g
F P
s
P
p
.002 w
.36549 .56397 m .33118 .53043 L .34179 .5485 L p
1 g
F P
s
P
p
.002 w
.59469 .26196 m .5545 .24241 L .54607 .2467 L p
1 g
F P
s
P
p
.002 w
.50802 .24006 m .54607 .2467 L .5545 .24241 L p
1 g
F P
s
P
p
.002 w
.56974 .60847 m .61411 .58942 L .62389 .57475 L p
1 g
F P
s
P
p
.002 w
.66033 .5441 m .62389 .57475 L .61411 .58942 L p
1 g
F P
s
P
p
.002 w
.62389 .57475 m .66033 .5441 L .66816 .52445 L p
1 g
F P
s
P
p
.002 w
.34144 .31352 m .31943 .35635 L .33321 .33869 L p
1 g
F P
s
P
p
.002 w
.33321 .33869 m .354 .29849 L .34144 .31352 L p
1 g
F P
s
P
p
.002 w
.5545 .24241 m .50796 .23426 L .50802 .24006 L p
1 g
F P
s
P
p
.002 w
.38536 .5912 m .42374 .61138 L .41649 .60204 L p
1 g
F P
s
P
p
.002 w
.41649 .60204 m .37352 .57936 L .38536 .5912 L p
1 g
F P
s
P
p
.002 w
.30599 .39905 m .3051 .44535 L .30919 .42288 L p
1 g
F P
s
P
p
.002 w
.30919 .42288 m .31019 .37661 L .30599 .39905 L p
1 g
F P
s
P
p
.002 w
.51574 .62487 m .56119 .61715 L .56974 .60847 L p
1 g
F P
s
P
p
.002 w
.61411 .58942 m .56974 .60847 L .56119 .61715 L p
1 g
F P
s
P
p
.002 w
.65634 .31061 m .67454 .35246 L .68647 .37119 L p
1 g
F P
s
P
p
.002 w
.67454 .35246 m .65634 .31061 L .64164 .29841 L p
1 g
F P
s
P
p
.002 w
.69362 .39217 m .69166 .43851 L .6935 .46128 L p
1 g
F P
s
P
p
.002 w
.69166 .43851 m .69362 .39217 L .68647 .37119 L p
1 g
F P
s
P
p
.002 w
.31294 .49056 m .33118 .53043 L .32546 .51026 L p
1 g
F P
s
P
p
.002 w
.32546 .51026 m .30628 .46813 L .31294 .49056 L p
1 g
F P
s
P
p
.002 w
.69002 .48392 m .66816 .52445 L .66033 .5441 L p
1 g
F P
s
P
p
.002 w
.66816 .52445 m .69002 .48392 L .6935 .46128 L p
1 g
F P
s
P
p
.002 w
.45314 .23887 m .40532 .25777 L .41974 .25499 L p
1 g
F P
s
P
p
.002 w
.41974 .25499 m .46103 .2387 L .45314 .23887 L p
1 g
F P
s
P
p
.002 w
.39298 .26551 m .354 .29849 L .37007 .28754 L p
1 g
F P
s
P
p
.002 w
.37007 .28754 m .40532 .25777 L .39298 .26551 L p
1 g
F P
s
P
p
.002 w
.64164 .29841 m .60833 .26586 L .59469 .26196 L p
1 g
F P
s
P
p
.002 w
.5545 .24241 m .59469 .26196 L .60833 .26586 L p
1 g
F P
s
P
p
.002 w
.60833 .26586 m .64164 .29841 L .65634 .31061 L p
1 g
F P
s
P
p
.002 w
.43343 .61606 m .4716 .62584 L .46855 .62288 L p
1 g
F P
s
P
p
.002 w
.46855 .62288 m .42374 .61138 L .43343 .61606 L p
1 g
F P
s
P
p
.002 w
.51574 .62487 m .46855 .62288 L .4716 .62584 L p
1 g
F P
s
P
p
.002 w
.4716 .62584 m .51186 .62754 L .51574 .62487 L p
1 g
F P
s
P
p
.002 w
.56119 .61715 m .51574 .62487 L .51186 .62754 L p
1 g
F P
s
P
p
.002 w
.33295 .33241 m .31019 .37661 L .31943 .35635 L p
1 g
F P
s
P
p
.002 w
.31943 .35635 m .34144 .31352 L .33295 .33241 L p
1 g
F P
s
P
p
.002 w
.35724 .56385 m .38536 .5912 L .37352 .57936 L p
1 g
F P
s
P
p
.002 w
.37352 .57936 m .34179 .5485 L .35724 .56385 L p
1 g
F P
s
P
p
.002 w
.3072 .4231 m .30628 .46813 L .3051 .44535 L p
1 g
F P
s
P
p
.002 w
.3051 .44535 m .30599 .39905 L .3072 .4231 L p
1 g
F P
s
P
p
.002 w
.56119 .61715 m .60079 .60022 L .61411 .58942 L p
1 g
F P
s
P
p
.002 w
.61411 .58942 m .64777 .56124 L .66033 .5441 L p
1 g
F P
s
P
p
.002 w
.64777 .56124 m .61411 .58942 L .60079 .60022 L p
1 g
F P
s
P
p
.004 w
.48799 .6696 m
.48932 .64304 L
s
P
p
.004 w
.28789 .47853 m
.29854 .47612 L
s
P
p
.004 w
.27863 .48062 m
.28789 .47853 L
s
P
p
.004 w
.24316 .48865 m
.27863 .48062 L
s
P
p
.002 w
.68647 .37119 m .66719 .32661 L .65634 .31061 L p
1 g
F P
s
P
p
.002 w
.66719 .32661 m .68647 .37119 L .69362 .39217 L p
1 g
F P
s
P
p
.002 w
.50768 .23371 m .45314 .23887 L .46103 .2387 L p
1 g
F P
s
P
p
.002 w
.46103 .2387 m .50796 .23426 L .50768 .23371 L p
1 g
F P
s
P
p
.002 w
.60833 .26586 m .56178 .24318 L .5545 .24241 L p
1 g
F P
s
P
p
.002 w
.50796 .23426 m .5545 .24241 L .56178 .24318 L p
1 g
F P
s
P
p
.002 w
.6935 .46128 m .69554 .41491 L .69362 .39217 L p
1 g
F P
s
P
p
.002 w
.69554 .41491 m .6935 .46128 L .69002 .48392 L p
1 g
F P
s
P
p
.002 w
.32514 .51198 m .34179 .5485 L .33118 .53043 L p
1 g
F P
s
P
p
.002 w
.33118 .53043 m .31294 .49056 L .32514 .51198 L p
1 g
F P
s
P
p
.002 w
.40089 .59894 m .43343 .61606 L .42374 .61138 L p
1 g
F P
s
P
p
.002 w
.42374 .61138 m .38536 .5912 L .40089 .59894 L p
1 g
F P
s
P
p
.002 w
.56178 .24318 m .50768 .23371 L .50796 .23426 L p
1 g
F P
s
P
p
.002 w
.51186 .62754 m .55057 .62098 L .56119 .61715 L p
1 g
F P
s
P
p
.002 w
.60079 .60022 m .56119 .61715 L .55057 .62098 L p
1 g
F P
s
P
p
.002 w
.66033 .5441 m .68109 .50576 L .69002 .48392 L p
1 g
F P
s
P
p
.002 w
.68109 .50576 m .66033 .5441 L .64777 .56124 L p
1 g
F P
s
P
p
.002 w
.38322 .27828 m .34144 .31352 L .354 .29849 L p
1 g
F P
s
P
p
.002 w
.354 .29849 m .39298 .26551 L .38322 .27828 L p
1 g
F P
s
P
p
.002 w
.44623 .2445 m .39298 .26551 L .40532 .25777 L p
1 g
F P
s
P
p
.002 w
.40532 .25777 m .45314 .23887 L .44623 .2445 L p
1 g
F P
s
P
p
.002 w
.65634 .31061 m .61947 .27454 L .60833 .26586 L p
1 g
F P
s
P
p
.002 w
.61947 .27454 m .65634 .31061 L .66719 .32661 L p
1 g
F P
s
P
p
.002 w
.56178 .24318 m .60833 .26586 L .61947 .27454 L p
1 g
F P
s
P
p
.002 w
.329 .35479 m .30599 .39905 L .31019 .37661 L p
1 g
F P
s
P
p
.002 w
.31019 .37661 m .33295 .33241 L .329 .35479 L p
1 g
F P
s
P
p
.002 w
.31401 .44807 m .31294 .49056 L .30628 .46813 L p
1 g
F P
s
P
p
.004 w
.29854 .47612 m
.3109 .47332 L
s
P
p
.002 w
.30628 .46813 m .3072 .4231 L .31401 .44807 L p
1 g
F P
s
P
p
.002 w
.67365 .34614 m .69362 .39217 L .69554 .41491 L p
1 g
F P
s
P
p
.002 w
.69362 .39217 m .67365 .34614 L .66719 .32661 L p
1 g
F P
s
P
p
.002 w
.69194 .43882 m .69002 .48392 L .68109 .50576 L p
1 g
F P
s
P
p
.002 w
.69002 .48392 m .69194 .43882 L .69554 .41491 L p
1 g
F P
s
P
p
.002 w
.3773 .57588 m .40089 .59894 L .38536 .5912 L p
1 g
F P
s
P
p
.002 w
.38536 .5912 m .35724 .56385 L .3773 .57588 L p
1 g
F P
s
P
p
.002 w
.44542 .61564 m .47559 .62339 L .4716 .62584 L p
1 g
F P
s
P
p
.002 w
.4716 .62584 m .43343 .61606 L .44542 .61564 L p
1 g
F P
s
P
p
.002 w
.51186 .62754 m .4716 .62584 L .47559 .62339 L p
1 g
F P
s
P
p
.002 w
.55057 .62098 m .58412 .60662 L .60079 .60022 L p
1 g
F P
s
P
p
.002 w
.6306 .57526 m .60079 .60022 L .58412 .60662 L p
1 g
F P
s
P
p
.002 w
.60079 .60022 m .6306 .57526 L .64777 .56124 L p
1 g
F P
s
P
p
.002 w
.47559 .62339 m .50747 .62473 L .51186 .62754 L p
1 g
F P
s
P
p
.002 w
.55057 .62098 m .51186 .62754 L .50747 .62473 L p
1 g
F P
s
P
p
.002 w
.34275 .53166 m .35724 .56385 L .34179 .5485 L p
1 g
F P
s
P
p
.002 w
.34179 .5485 m .32514 .51198 L .34275 .53166 L p
1 g
F P
s
P
p
.002 w
.6667 .52612 m .64777 .56124 L .6306 .57526 L p
1 g
F P
s
P
p
.002 w
.64777 .56124 m .6667 .52612 L .68109 .50576 L p
1 g
F P
s
P
p
.002 w
.50716 .23877 m .44623 .2445 L .45314 .23887 L p
1 g
F P
s
P
p
.002 w
.45314 .23887 m .50768 .23371 L .50716 .23877 L p
1 g
F P
s
P
p
.002 w
.61947 .27454 m .56762 .24932 L .56178 .24318 L p
1 g
F P
s
P
p
.002 w
.50768 .23371 m .56178 .24318 L .56762 .24932 L p
1 g
F P
s
P
p
.002 w
.41986 .60213 m .44542 .61564 L .43343 .61606 L p
1 g
F P
s
P
p
.002 w
.43343 .61606 m .40089 .59894 L .41986 .60213 L p
1 g
F P
s
P
p
.002 w
.50747 .62473 m .53806 .61953 L .55057 .62098 L p
1 g
F P
s
P
p
.002 w
.58412 .60662 m .55057 .62098 L .53806 .61953 L p
1 g
F P
s
P
p
.002 w
.37649 .29597 m .33295 .33241 L .34144 .31352 L p
1 g
F P
s
P
p
.002 w
.34144 .31352 m .38322 .27828 L .37649 .29597 L p
1 g
F P
s
P
p
.002 w
.56762 .24932 m .50716 .23877 L .50768 .23371 L p
1 g
F P
s
P
p
.002 w
.62764 .28805 m .66719 .32661 L .67365 .34614 L p
1 g
F P
s
P
p
.002 w
.66719 .32661 m .62764 .28805 L .61947 .27454 L p
1 g
F P
s
P
p
.002 w
.44059 .25577 m .38322 .27828 L .39298 .26551 L p
1 g
F P
s
P
p
.002 w
.39298 .26551 m .44623 .2445 L .44059 .25577 L p
1 g
F P
s
P
p
.002 w
.32994 .3801 m .3072 .4231 L .30599 .39905 L p
1 g
F P
s
P
p
.002 w
.30599 .39905 m .329 .35479 L .32994 .3801 L p
1 g
F P
s
P
p
.002 w
.56762 .24932 m .61947 .27454 L .62764 .28805 L p
1 g
F P
s
P
p
.002 w
.32647 .47322 m .32514 .51198 L .31294 .49056 L p
1 g
F P
s
P
p
.002 w
.31294 .49056 m .31401 .44807 L .32647 .47322 L p
1 g
F P
s
P
p
.002 w
.6753 .36879 m .69554 .41491 L .69194 .43882 L p
1 g
F P
s
P
p
.002 w
.69554 .41491 m .6753 .36879 L .67365 .34614 L p
1 g
F P
s
P
p
.002 w
.68266 .4632 m .68109 .50576 L .6667 .52612 L p
1 g
F P
s
P
p
.002 w
.68109 .50576 m .68266 .4632 L .69194 .43882 L p
1 g
F P
s
P
p
.002 w
.40155 .58404 m .41986 .60213 L .40089 .59894 L p
1 g
F P
s
P
p
.002 w
.40089 .59894 m .3773 .57588 L .40155 .58404 L p
1 g
F P
s
P
p
.002 w
.36544 .5489 m .3773 .57588 L .35724 .56385 L p
1 g
F P
s
P
p
.002 w
.35724 .56385 m .34275 .53166 L .36544 .5489 L p
1 g
F P
s
P
p
.002 w
.53806 .61953 m .5644 .60819 L .58412 .60662 L p
1 g
F P
s
P
p
.002 w
.60911 .58557 m .58412 .60662 L .5644 .60819 L p
1 g
F P
s
P
p
.002 w
.58412 .60662 m .60911 .58557 L .6306 .57526 L p
1 g
F P
s
P
p
.002 w
.64707 .5443 m .6306 .57526 L .60911 .58557 L p
1 g
F P
s
P
p
.002 w
.6306 .57526 m .64707 .5443 L .6667 .52612 L p
1 g
F P
s
P
p
.002 w
.45949 .60981 m .48047 .61523 L .47559 .62339 L p
1 g
F P
s
P
p
.002 w
.47559 .62339 m .44542 .61564 L .45949 .60981 L p
1 g
F P
s
P
p
.002 w
.50747 .62473 m .47559 .62339 L .48047 .61523 L p
1 g
F P
s
P
p
.002 w
.48047 .61523 m .50268 .61617 L .50747 .62473 L p
1 g
F P
s
P
p
.002 w
.53806 .61953 m .50747 .62473 L .50268 .61617 L p
1 g
F P
s
P
p
.002 w
.37317 .31828 m .329 .35479 L .33295 .33241 L p
1 g
F P
s
P
p
.002 w
.33295 .33241 m .37649 .29597 L .37317 .31828 L p
1 g
F P
s
P
p
.002 w
.50642 .24964 m .44059 .25577 L .44623 .2445 L p
1 g
F P
s
P
p
.002 w
.44623 .2445 m .50716 .23877 L .50642 .24964 L p
1 g
F P
s
P
p
.002 w
.62764 .28805 m .57173 .26099 L .56762 .24932 L p
1 g
F P
s
P
p
.002 w
.50716 .23877 m .56762 .24932 L .57173 .26099 L p
1 g
F P
s
P
p
.002 w
.6324 .30622 m .67365 .34614 L .6753 .36879 L p
1 g
F P
s
P
p
.002 w
.67365 .34614 m .6324 .30622 L .62764 .28805 L p
1 g
F P
s
P
p
.002 w
.44185 .60041 m .45949 .60981 L .44542 .61564 L p
1 g
F P
s
P
p
.002 w
.44542 .61564 m .41986 .60213 L .44185 .60041 L p
1 g
F P
s
P
p
.002 w
.33597 .40762 m .31401 .44807 L .3072 .4231 L p
1 g
F P
s
P
p
.002 w
.3072 .4231 m .32994 .3801 L .33597 .40762 L p
1 g
F P
s
P
p
.002 w
.34436 .4977 m .34275 .53166 L .32514 .51198 L p
1 g
F P
s
P
p
.002 w
.32514 .51198 m .32647 .47322 L .34436 .4977 L p
1 g
F P
s
P
p
.002 w
.50268 .61617 m .52394 .61252 L .53806 .61953 L p
1 g
F P
s
P
p
.002 w
.5644 .60819 m .53806 .61953 L .52394 .61252 L p
1 g
F P
s
P
p
.002 w
.66776 .48727 m .6667 .52612 L .64707 .5443 L p
1 g
F P
s
P
p
.002 w
.6667 .52612 m .66776 .48727 L .68266 .4632 L p
1 g
F P
s
P
p
.002 w
.67185 .39397 m .69194 .43882 L .68266 .4632 L p
1 g
F P
s
P
p
.002 w
.69194 .43882 m .67185 .39397 L .6753 .36879 L p
1 g
F P
s
P
p
.002 w
.57173 .26099 m .50642 .24964 L .50716 .23877 L p
1 g
F P
s
P
p
.002 w
.43649 .27267 m .37649 .29597 L .38322 .27828 L p
1 g
F P
s
P
p
.002 w
.38322 .27828 m .44059 .25577 L .43649 .27267 L p
1 g
F P
s
P
p
.002 w
.57173 .26099 m .62764 .28805 L .6324 .30622 L p
1 g
F P
s
P
p
.002 w
.39263 .56303 m .40155 .58404 L .3773 .57588 L p
1 g
F P
s
P
p
.002 w
.3773 .57588 m .36544 .5489 L .39263 .56303 L p
1 g
F P
s
P
p
.002 w
.5644 .60819 m .58379 .59166 L .60911 .58557 L p
1 g
F P
s
P
p
.002 w
.62261 .55961 m .60911 .58557 L .58379 .59166 L p
1 g
F P
s
P
p
.002 w
.60911 .58557 m .62261 .55961 L .64707 .5443 L p
1 g
F P
s
P
p
.002 w
.42939 .58789 m .44185 .60041 L .41986 .60213 L p
1 g
F P
s
P
p
.002 w
.41986 .60213 m .40155 .58404 L .42939 .58789 L p
1 g
F P
s
P
p
.002 w
.52394 .61252 m .54211 .60461 L .5644 .60819 L p
1 g
F P
s
P
p
.002 w
.58379 .59166 m .5644 .60819 L .54211 .60461 L p
1 g
F P
s
P
p
.002 w
.37357 .34467 m .32994 .3801 L .329 .35479 L p
1 g
F P
s
P
p
.002 w
.329 .35479 m .37317 .31828 L .37357 .34467 L p
1 g
F P
s
P
p
.002 w
.36726 .52066 m .36544 .5489 L .34275 .53166 L p
1 g
F P
s
P
p
.002 w
.34275 .53166 m .34436 .4977 L .36726 .52066 L p
1 g
F P
s
P
p
.002 w
.34708 .43649 m .32647 .47322 L .31401 .44807 L p
1 g
F P
s
P
p
.004 w
.3109 .47332 m
.32465 .47021 L
s
P
p
.002 w
.31401 .44807 m .33597 .40762 L .34708 .43649 L p
1 g
F P
s
P
p
.002 w
.64753 .51023 m .64707 .5443 L .62261 .55961 L p
1 g
F P
s
P
p
.002 w
.64707 .5443 m .64753 .51023 L .66776 .48727 L p
1 g
F P
s
P
p
.002 w
.63339 .32874 m .6753 .36879 L .67185 .39397 L p
1 g
F P
s
P
p
.002 w
.6753 .36879 m .63339 .32874 L .6324 .30622 L p
1 g
F P
s
P
p
.002 w
.4753 .59846 m .48612 .60128 L .48047 .61523 L p
1 g
F P
s
P
p
.002 w
.48047 .61523 m .45949 .60981 L .4753 .59846 L p
1 g
F P
s
P
p
.002 w
.50268 .61617 m .48047 .61523 L .48612 .60128 L p
1 g
F P
s
P
p
.002 w
.48612 .60128 m .4976 .60176 L .50268 .61617 L p
1 g
F P
s
P
p
.002 w
.52394 .61252 m .50268 .61617 L .4976 .60176 L p
1 g
F P
s
P
p
.002 w
.66318 .42096 m .68266 .4632 L .66776 .48727 L p
1 g
F P
s
P
p
.002 w
.68266 .4632 m .66318 .42096 L .67185 .39397 L p
1 g
F P
s
P
p
.002 w
.50545 .26635 m .43649 .27267 L .44059 .25577 L p
1 g
F P
s
P
p
.002 w
.44059 .25577 m .50642 .24964 L .50545 .26635 L p
1 g
F P
s
P
p
.002 w
.6324 .30622 m .57389 .27816 L .57173 .26099 L p
1 g
F P
s
P
p
.002 w
.50642 .24964 m .57173 .26099 L .57389 .27816 L p
1 g
F P
s
P
p
.002 w
.46627 .59358 m .4753 .59846 L .45949 .60981 L p
1 g
F P
s
P
p
.002 w
.45949 .60981 m .44185 .60041 L .46627 .59358 L p
1 g
F P
s
P
p
.002 w
.4976 .60176 m .50856 .59985 L .52394 .61252 L p
1 g
F P
s
P
p
.002 w
.54211 .60461 m .52394 .61252 L .50856 .59985 L p
1 g
F P
s
P
p
.002 w
.43415 .29495 m .37317 .31828 L .37649 .29597 L p
1 g
F P
s
P
p
.002 w
.37649 .29597 m .43649 .27267 L .43415 .29495 L p
1 g
F P
s
P
p
.002 w
.42354 .57348 m .42939 .58789 L .40155 .58404 L p
1 g
F P
s
P
p
.002 w
.40155 .58404 m .39263 .56303 L .42354 .57348 L p
1 g
F P
s
P
p
.002 w
.54211 .60461 m .55531 .59316 L .58379 .59166 L p
1 g
F P
s
P
p
.002 w
.59397 .57143 m .58379 .59166 L .55531 .59316 L p
1 g
F P
s
P
p
.002 w
.58379 .59166 m .59397 .57143 L .62261 .55961 L p
1 g
F P
s
P
p
.002 w
.57389 .27816 m .6324 .30622 L .63339 .32874 L p
1 g
F P
s
P
p
.002 w
.57389 .27816 m .50545 .26635 L .50642 .24964 L p
1 g
F P
s
P
p
.002 w
.46 .58713 m .46627 .59358 L .44185 .60041 L p
1 g
F P
s
P
p
.002 w
.44185 .60041 m .42939 .58789 L .46 .58713 L p
1 g
F P
s
P
p
.002 w
.39448 .54124 m .39263 .56303 L .36544 .5489 L p
1 g
F P
s
P
p
.002 w
.36544 .5489 m .36726 .52066 L .39448 .54124 L p
1 g
F P
s
P
p
.002 w
.50856 .59985 m .51786 .59574 L .54211 .60461 L p
1 g
F P
s
P
p
.002 w
.55531 .59316 m .54211 .60461 L .51786 .59574 L p
1 g
F P
s
P
p
.002 w
.36303 .46572 m .34436 .4977 L .32647 .47322 L p
1 g
F P
s
P
p
.002 w
.32647 .47322 m .34708 .43649 L .36303 .46572 L p
1 g
F P
s
P
p
.004 w
.33186 .46857 m
.33697 .46742 L
s
P
p
.004 w
.32465 .47021 m
.33186 .46857 L
s
P
p
.004 w
.36099 .46198 m
.5 .43051 L
s
P
p
.004 w
.33697 .46742 m
.33825 .46713 L
s
P
p
.002 w
.62251 .53124 m .62261 .55961 L .59397 .57143 L p
1 g
F P
s
P
p
.002 w
.62261 .55961 m .62251 .53124 L .64753 .51023 L p
1 g
F P
s
P
p
.002 w
.37782 .37439 m .33597 .40762 L .32994 .3801 L p
1 g
F P
s
P
p
.002 w
.32994 .3801 m .37357 .34467 L .37782 .37439 L p
1 g
F P
s
P
p
.002 w
.64938 .44886 m .66776 .48727 L .64753 .51023 L p
1 g
F P
s
P
p
.002 w
.66776 .48727 m .64938 .44886 L .66318 .42096 L p
1 g
F P
s
P
p
.002 w
.6304 .35504 m .67185 .39397 L .66318 .42096 L p
1 g
F P
s
P
p
.002 w
.67185 .39397 m .6304 .35504 L .63339 .32874 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.49406 .54865 m
.5 .43051 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45718 .57978 m .46 .58713 L .42939 .58789 L p
1 g
F P
s
P
p
.002 w
.42939 .58789 m .42354 .57348 L .45718 .57978 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.51786 .59574 m .52451 .58983 L .55531 .59316 L p
1 g
F P
s
P
p
.002 w
.56201 .57926 m .55531 .59316 L .52451 .58983 L p
1 g
F P
s
P
p
.002 w
.55531 .59316 m .56201 .57926 L .59397 .57143 L p
1 g
F P
s
P
p
.002 w
.48612 .60128 m .4753 .59846 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.4976 .60176 m .48612 .60128 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.50856 .59985 m .4976 .60176 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.42514 .55868 m .42354 .57348 L .39263 .56303 L p
1 g
F P
s
P
p
.002 w
.39263 .56303 m .39448 .54124 L .42514 .55868 L p
1 g
F P
s
P
p
.002 w
.50428 .28864 m .43415 .29495 L .43649 .27267 L p
1 g
F P
s
P
p
.002 w
.43649 .27267 m .50545 .26635 L .50428 .28864 L p
1 g
F P
s
P
p
.002 w
.4753 .59846 m .46627 .59358 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.51786 .59574 m .50856 .59985 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.38336 .49426 m .36726 .52066 L .34436 .4977 L p
1 g
F P
s
P
p
.002 w
.34436 .4977 m .36303 .46572 L .38336 .49426 L p
1 g
F P
s
P
p
.002 w
.59344 .54951 m .59397 .57143 L .56201 .57926 L p
1 g
F P
s
P
p
.002 w
.59397 .57143 m .59344 .54951 L .62251 .53124 L p
1 g
F P
s
P
p
.002 w
.43374 .32207 m .37357 .34467 L .37317 .31828 L p
1 g
F P
s
P
p
.002 w
.37317 .31828 m .43415 .29495 L .43374 .32207 L p
1 g
F P
s
P
p
.002 w
.63339 .32874 m .5739 .30054 L .57389 .27816 L p
1 g
F P
s
P
p
.002 w
.50545 .26635 m .57389 .27816 L .5739 .30054 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.5739 .30054 m .63339 .32874 L .6304 .35504 L p
1 g
F P
s
P
p
.002 w
.6308 .47673 m .64753 .51023 L .62251 .53124 L p
1 g
F P
s
P
p
.002 w
.64753 .51023 m .6308 .47673 L .64938 .44886 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.46627 .59358 m .46 .58713 L .49153 .5818 L p
1 g
F P
s
P
p
.002 w
.46 .58713 m .45718 .57978 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.45718 .57978 m .45818 .57231 L .46941 .57538 L p
1 g
F P
s
P
p
.45718 .57978 m .46941 .57538 L .47465 .57833 L 1 g
F
P
p
.002 w
.46827 .57472 m .46872 .57265 L p
.45765 .56823 L 1 g
F P
s
P
p
.002 w
.45988 .5699 m .45818 .57231 L p
.45122 .56341 L 1 g
F P
s
P
p
.45765 .56823 m .45542 .56734 L .45988 .5699 L 1 g
F
P
p
.45765 .56823 m .45988 .5699 L .46827 .57472 L 1 g
F
P
p
.002 w
.45818 .57231 m .42514 .55868 L p
.45102 .56337 L 1 g
F P
s
P
p
.002 w
.45079 .56308 m .45146 .56129 L p
.44441 .55517 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56308 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56308 L .45765 .56823 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43827 .54751 L p
1 g
F P
s
P
p
.45146 .56129 m .43827 .54751 L .43842 .5477 L 1 g
F
P
p
.45146 .56129 m .43826 .54753 L .44441 .55517 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.471 .56021 m .46294 .56553 L .43907 .54854 L p
1 g
F P
s
P
p
.43425 .5451 m .43742 .54641 L .43827 .54751 L 1 g
F
P
p
.002 w
.4385 .54813 m .43425 .5451 L p
.43827 .54751 L 1 g
F P
s
P
p
.002 w
.43827 .54751 m .43925 .54566 L p
.43518 .53761 L 1 g
F P
s
P
p
.002 w
.43677 .54339 m .43425 .5451 L p
.4328 .52898 L 1 g
F P
s
P
p
.43518 .53761 m .43333 .53396 L .43677 .54339 L 1 g
F
P
p
.43518 .53761 m .43677 .54339 L .43827 .54751 L 1 g
F
P
p
.002 w
.43182 .54293 m .40739 .52106 L p
.43264 .52893 L 1 g
F P
s
P
p
.002 w
.43267 .52849 m .43346 .52734 L p
.43319 .51967 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43267 .52849 L p
1 g
F P
s
P
p
.43925 .54566 m .43267 .52849 L .43518 .53761 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43381 .50949 L p
1 g
F P
s
P
p
.43346 .52734 m .43381 .50949 L .43379 .50974 L 1 g
F
P
p
.43346 .52734 m .43379 .50952 L .43319 .51967 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.47083 .52772 m .45004 .53434 L .43376 .51004 L p
1 g
F P
s
P
p
.43033 .50491 m .43403 .507 L .43381 .50949 L 1 g
F
P
p
.002 w
.43364 .50986 m .43033 .50491 L p
.43381 .50949 L 1 g
F P
s
P
p
.002 w
.43381 .50949 m .43485 .50826 L p
.43837 .50002 L 1 g
F P
s
P
p
.002 w
.43704 .50271 m .43033 .50491 L p
.43702 .49673 L 1 g
F P
s
P
p
.44459 .48748 m .44276 .49117 L .43702 .49673 L 1 g
F
P
p
.44276 .49117 m .43704 .50271 L .43702 .49673 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43381 .50949 m .47083 .52772 L .43376 .51004 L 1 g
F
P
p
.43403 .507 m .4348 .50743 L .43381 .50949 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4423 .49165 L p
1 g
F P
s
P
p
.43485 .50826 m .4423 .49165 L .43884 .49892 L 1 g
F
P
p
.43837 .50002 m .43704 .50271 L .43381 .50949 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.4348 .50743 m .47083 .52772 L .43381 .50949 L 1 g
F
P
p
.002 w
.4423 .49165 m .44166 .49233 L p
.43884 .49892 L 1 g
F P
s
P
p
.002 w
.44276 .49117 m .44339 .4905 L p
.44907 .48506 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46089 .49489 m .43704 .50271 L p
.44276 .49117 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45769 .47671 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45769 .47671 m .49549 .49237 L .4566 .47777 L 1 g
F
P
p
.002 w
.45769 .47671 m .45826 .47608 L p
.46582 .47277 L 1 g
F P
s
P
p
.46804 .47169 m .49549 .49237 L .45769 .47671 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47764 .46704 L p
1 g
F P
s
P
p
.45826 .47608 m .47764 .46704 L .46582 .47277 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49657 .46445 m .49549 .49237 L p
.46428 .46886 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.52987 .49774 m .49549 .49237 L .49657 .46445 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46388 m .52987 .49774 L .49657 .46445 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46706 L p
1 g
F P
s
P
p
.5 .4634 m .52237 .46706 L .5095 .46523 L 1 g
F
P
p
.50332 .46435 m .52987 .49774 L .5 .46388 L 1 g
F
P
p
.002 w
.5 .46388 m .5 .4634 L p
.5095 .46523 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.49689 .45625 m .50188 .45705 L p
.52987 .49774 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54226 .47665 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54226 .47665 m .55979 .51026 L .53767 .47453 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56609 .50937 L p
1 g
F P
s
P
p
.58001 .47986 m .57067 .51919 L .56609 .50937 L 1 g
F
P
p
.002 w
.56373 .50433 m .5654 .50183 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.5654 .50183 m .58001 .47986 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.56609 .50937 m .56515 .50826 L p
.56687 .51942 L 1 g
F P
s
P
p
.002 w
.58175 .52828 m .56791 .53876 L p
.56736 .52853 L 1 g
F P
s
P
p
.002 w
.56668 .51592 m .57021 .51881 L p
.56736 .52853 L 1 g
F P
s
P
p
.002 w
.57021 .51881 m .58175 .52828 L p
.56736 .52853 L 1 g
F P
s
P
p
.002 w
.56736 .52853 m .56654 .52734 L p
.56461 .53793 L 1 g
F P
s
P
p
.56687 .51942 m .56668 .51592 L .56609 .50937 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54726 L p
1 g
F P
s
P
p
.58175 .52828 m .55778 .55827 L .5616 .54726 L 1 g
F
P
p
.002 w
.56335 .54222 m .56726 .53926 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.56726 .53926 m .58175 .52828 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.5616 .54726 m .56075 .54566 L p
.5546 .5568 L 1 g
F P
s
P
p
.002 w
.5613 .56435 m .54311 .57014 L p
.5492 .56307 L 1 g
F P
s
P
p
.002 w
.55599 .55519 m .55733 .5575 L p
.5492 .56307 L 1 g
F P
s
P
p
.002 w
.55733 .5575 m .5613 .56435 L p
.5492 .56307 L 1 g
F P
s
P
p
.002 w
.5492 .56307 m .54854 .56129 L p
.54021 .56923 L 1 g
F P
s
P
p
.5546 .5568 m .55599 .55519 L .5616 .54726 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58066 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58066 L .51129 .58057 L 1 g
F
P
p
.002 w
.52776 .58273 m .50536 .58205 L p
.51094 .58066 L 1 g
F P
s
P
p
.002 w
.52731 .5766 m .52756 .58004 L p
.51094 .58066 L 1 g
F P
s
P
p
.002 w
.52756 .58004 m .52776 .58273 L p
.51094 .58066 L 1 g
F P
s
P
p
.002 w
.51094 .58066 m .51079 .57862 L p
.49819 .58114 L 1 g
F P
s
P
p
.52008 .57839 m .51095 .58071 L .51959 .57865 L 1 g
F
P
p
.53128 .57265 m .51129 .58057 L .52008 .57839 L 1 g
F
P
p
.51129 .58057 m .51095 .58071 L .52008 .57839 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58104 L p
1 g
F P
s
P
p
.002 w
.49241 .58165 m .49073 .58156 L p
.48903 .58104 L 1 g
F P
s
P
p
.002 w
.48903 .58104 m .48903 .58105 L p
.48908 .58105 L 1 g
F P
s
P
p
.51079 .57862 m .48903 .58104 L .48908 .58105 L 1 g
F
P
p
.51079 .57862 m .48908 .58105 L .49098 .58122 L 1 g
F
P
p
.002 w
.49078 .5812 m .49241 .58165 L p
.48903 .58104 L 1 g
F P
s
P
p
.48908 .58105 m .48903 .58105 L .49078 .5812 L 1 g
F
P
p
.48908 .58105 m .49078 .5812 L .49098 .58122 L 1 g
F
P
p
.002 w
.49073 .58156 m .45718 .57978 L p
.4667 .57899 L 1 g
F P
s
P
p
.4667 .57899 m .47894 .57797 L .48903 .58104 L 1 g
F
P
p
.4667 .57899 m .48903 .58104 L .49073 .58156 L 1 g
F
P
p
.002 w
.48903 .58104 m .48921 .57862 L p
.47805 .5777 L 1 g
F P
s
P
p
.47805 .5777 m .47894 .57797 L .48903 .58104 L 1 g
F
P
p
.002 w
.49175 .58129 m .49241 .58165 L .49078 .5812 L p
1 g
F P
s
P
p
.51079 .57862 m .49094 .58123 L .49819 .58114 L 1 g
F
P
p
.49094 .58123 m .49083 .58124 L .49108 .58124 L 1 g
F
P
p
.49094 .58123 m .49108 .58124 L .49819 .58114 L 1 g
F
P
p
.49083 .58124 m .49111 .58126 L .49819 .58114 L 1 g
F
P
p
.49066 .58126 m .49116 .58128 L .49819 .58114 L 1 g
F
P
p
.4904 .5813 m .49131 .58131 L .49819 .58114 L 1 g
F
P
p
.49006 .58134 m .49169 .58133 L .49819 .58114 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49078 .5812 m .47894 .57797 L p
.49175 .58129 L 1 g
F P
s
P
p
.002 w
.47894 .57797 m .46941 .57538 L p
.47703 .57739 L 1 g
F P
s
P
p
.48921 .57862 m .46827 .57472 L .47805 .5777 L 1 g
F
P
p
.47703 .57739 m .49175 .58129 L .47894 .57797 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46827 .57472 L p
1 g
F P
s
P
p
.46941 .57538 m .46916 .57499 L .47703 .57739 L 1 g
F
P
p
.002 w
.46941 .57538 m .45818 .57231 L .45988 .5699 L p
1 g
F P
s
P
p
.002 w
.45988 .5699 m .46294 .56553 L p
.46941 .57538 L 1 g
F P
s
P
p
.002 w
.46941 .57538 m .47894 .57797 L p
.47465 .57833 L 1 g
F P
s
P
p
.002 w
.46827 .57472 m .4678 .57686 L p
.47805 .5777 L 1 g
F P
s
P
p
.002 w
.46294 .56553 m .471 .56021 L .49207 .58131 L p
1 g
F P
s
P
p
.002 w
.49207 .58131 m .49241 .58165 L .49175 .58129 L p
1 g
F P
s
P
p
.002 w
.49175 .58129 m .46294 .56553 L p
.49207 .58131 L 1 g
F P
s
P
p
.48965 .5814 m .49254 .58133 L .49819 .58114 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.471 .56021 m .48148 .55696 L .49226 .58132 L p
1 g
F P
s
P
p
.002 w
.49226 .58132 m .49241 .58165 L .49207 .58131 L p
1 g
F P
s
P
p
.002 w
.49207 .58131 m .471 .56021 L p
.49226 .58132 L 1 g
F P
s
P
p
.49083 .58124 m .49066 .58126 L .49111 .58126 L 1 g
F
P
p
.49066 .58126 m .4904 .5813 L .49116 .58128 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48148 .55696 m .49321 .55617 L .49242 .58133 L p
1 g
F P
s
P
p
.002 w
.49242 .58133 m .49241 .58165 L .49226 .58132 L p
1 g
F P
s
P
p
.002 w
.49226 .58132 m .48148 .55696 L p
.49242 .58133 L 1 g
F P
s
P
p
.002 w
.49321 .55617 m .50487 .55794 L .49257 .58133 L p
1 g
F P
s
P
p
.002 w
.49257 .58133 m .49241 .58165 L .49242 .58133 L p
1 g
F P
s
P
p
.002 w
.49242 .58133 m .49321 .55617 L p
.49257 .58133 L 1 g
F P
s
P
p
.4904 .5813 m .49006 .58134 L .49131 .58131 L 1 g
F
P
p
.49006 .58134 m .48965 .5814 L .49169 .58133 L 1 g
F
P
p
.48926 .58145 m .49439 .58128 L .49819 .58114 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.50487 .55794 m .51514 .56205 L .49278 .58133 L p
1 g
F P
s
P
p
.002 w
.49278 .58133 m .49241 .58165 L .49257 .58133 L p
1 g
F P
s
P
p
.002 w
.49257 .58133 m .50487 .55794 L p
.49278 .58133 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51514 .56205 m .52286 .56803 L .49314 .58132 L p
1 g
F P
s
P
p
.002 w
.49314 .58132 m .49241 .58165 L .49278 .58133 L p
1 g
F P
s
P
p
.002 w
.49278 .58133 m .51514 .56205 L p
.49314 .58132 L 1 g
F P
s
P
p
.48965 .5814 m .48926 .58145 L .49254 .58133 L 1 g
F
P
p
.48926 .58145 m .489 .58148 L .49439 .58128 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.50536 .58205 m .52776 .58273 L p
.49948 .58345 L 1 g
F P
s
P
p
.002 w
.52776 .58273 m .5274 .57773 L p
.5613 .56435 L 1 g
F P
s
P
p
.002 w
.5274 .57773 m .52731 .5766 L p
.53141 .57513 L 1 g
F P
s
P
p
.5613 .56435 m .5274 .57773 L .53141 .57513 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53177 .57489 L p
1 g
F P
s
P
p
.54854 .56129 m .53177 .57489 L .53522 .57265 L 1 g
F
P
p
.54854 .56129 m .53522 .57265 L .54021 .56923 L 1 g
F
P
p
.002 w
.53177 .57489 m .53128 .57265 L p
.51246 .58231 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54962 .5642 L p
1 g
F P
s
P
p
.56075 .54566 m .54962 .5642 L .55371 .55842 L 1 g
F
P
p
.56654 .52734 m .5616 .54726 L .56239 .545 L 1 g
F
P
p
.56654 .52734 m .56177 .54759 L .56461 .53793 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55301 .55004 m .56335 .54222 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.55778 .55827 m .55599 .55519 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.55599 .55519 m .55301 .55004 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.54962 .5642 m .54998 .56518 L p
.55371 .55842 L 1 g
F P
s
P
p
.55599 .55519 m .5492 .56307 L .52721 .57519 L 1 g
F
P
p
.002 w
.54311 .57014 m .53522 .57265 L p
.5492 .56307 L 1 g
F P
s
P
p
.002 w
.53522 .57265 m .52721 .57519 L p
.5492 .56307 L 1 g
F P
s
P
p
.54021 .56923 m .53522 .57265 L .53964 .56977 L 1 g
F
P
p
.002 w
.52731 .5766 m .52721 .57519 L .54916 .56821 L p
1 g
F P
s
P
p
.002 w
.54916 .56821 m .5613 .56435 L p
.52731 .5766 L 1 g
F P
s
P
p
.002 w
.53177 .57489 m .5322 .57686 L p
.53964 .56977 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53177 .57489 L p
1 g
F P
s
P
p
.51246 .58231 m .51111 .583 L .53177 .57489 L 1 g
F
P
p
.002 w
.52286 .56803 m .52721 .57519 L .49439 .58128 L p
1 g
F P
s
P
p
.002 w
.49439 .58128 m .49241 .58165 L .49314 .58132 L p
1 g
F P
s
P
p
.002 w
.49314 .58132 m .52286 .56803 L p
.49439 .58128 L 1 g
F P
s
P
p
.47805 .5777 m .47805 .5777 L .47894 .57797 L 1 g
F
P
p
.002 w
.46294 .56553 m .49175 .58129 L p
.47703 .57739 L 1 g
F P
s
P
p
.46916 .57499 m .46294 .56553 L .47703 .57739 L 1 g
F
P
p
.002 w
.47894 .57797 m .49078 .5812 L p
.48903 .58104 L 1 g
F P
s
P
p
.002 w
.48903 .58105 m .489 .58148 L p
.49098 .58122 L 1 g
F P
s
P
p
.002 w
.50536 .58205 m .49241 .58165 L p
.49515 .58125 L 1 g
F P
s
P
p
.51094 .58066 m .50536 .58205 L .49515 .58125 L 1 g
F
P
p
.002 w
.49241 .58165 m .52721 .57519 L .52731 .5766 L p
1 g
F P
s
P
p
.002 w
.49948 .58345 m .49241 .58165 L .50536 .58205 L p
1 g
F P
s
P
p
.002 w
.49153 .5818 m .49241 .58165 L .49187 .58189 L p
1 g
F P
s
P
p
.002 w
.49187 .58189 m .46627 .59358 L p
.49153 .5818 L 1 g
F P
s
P
p
.002 w
.52451 .58983 m .51786 .59574 L .49241 .58165 L closepath p
1 g
F P
s
P
p
.002 w
.489 .58148 m .48889 .583 L p
.49819 .58114 L 1 g
F P
s
P
p
.52731 .5766 m .51094 .58066 L .49515 .58125 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58066 L p
1 g
F P
s
P
p
.49819 .58114 m .48889 .583 L .51094 .58066 L 1 g
F
P
p
.002 w
.51094 .58066 m .51095 .58071 L p
.51129 .58057 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51111 .583 L p
.51959 .57865 L 1 g
F P
s
P
p
.002 w
.52776 .58273 m .52451 .58983 L .49948 .58345 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5492 .56307 L p
1 g
F P
s
P
p
.54021 .56923 m .5322 .57686 L .5492 .56307 L 1 g
F
P
p
.5546 .5568 m .55371 .55842 L .55599 .55519 L 1 g
F
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55301 .55004 m .55599 .55519 L p
.52721 .57519 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5616 .54726 L p
1 g
F P
s
P
p
.55371 .55842 m .54998 .56518 L .5616 .54726 L 1 g
F
P
p
.002 w
.5616 .54726 m .56177 .54759 L p
.56239 .545 L 1 g
F P
s
P
p
.002 w
.5613 .56435 m .55778 .55827 L p
.58175 .52828 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56791 .52933 L p
1 g
F P
s
P
p
.56515 .50826 m .56791 .52933 L .5672 .52153 L 1 g
F
P
p
.55661 .4905 m .56609 .50937 L .56373 .50433 L 1 g
F
P
p
.002 w
.54395 .4644 m .58001 .47986 L .56651 .50015 L p
1 g
F P
s
P
p
.002 w
.56651 .50015 m .56373 .50433 L p
.55718 .49111 L 1 g
F P
s
P
p
.54395 .4644 m .56651 .50015 L .55718 .49111 L 1 g
F
P
p
.55661 .4905 m .56373 .50433 L .56179 .5004 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55718 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55718 .49111 L .54805 .48226 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54144 .46332 m .54395 .4644 L p
.55116 .48527 L 1 g
F P
s
P
p
.54932 .48349 m .55116 .48527 L .55979 .51026 L 1 g
F
P
p
.54144 .46332 m .55116 .48527 L .54932 .48349 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56373 .50433 m .55979 .51026 L p
.54395 .4644 L 1 g
F P
s
P
p
.54932 .48349 m .55979 .51026 L .54226 .47665 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54226 .47665 L p
1 g
F P
s
P
p
.002 w
.54226 .47665 m .54174 .47608 L p
.54805 .48226 L 1 g
F P
s
P
p
.54805 .48226 m .55834 .49233 L .54226 .47665 L 1 g
F
P
p
.56179 .5004 m .56373 .50433 L .56284 .50241 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55979 .51026 m .56373 .50433 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.57067 .51919 m .56668 .51592 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.56668 .51592 m .55979 .51026 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.56791 .52933 m .56854 .53025 L p
.5672 .52153 L 1 g
F P
s
P
p
.56668 .51592 m .56736 .52853 L .55301 .55004 L 1 g
F
P
p
.002 w
.56791 .53876 m .56335 .54222 L p
.56736 .52853 L 1 g
F P
s
P
p
.002 w
.56335 .54222 m .55301 .55004 L p
.56736 .52853 L 1 g
F P
s
P
p
.002 w
.56177 .54759 m .56257 .5491 L p
.56461 .53793 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56736 .52853 L p
1 g
F P
s
P
p
.56461 .53793 m .56257 .5491 L .56736 .52853 L 1 g
F
P
p
.56687 .51942 m .5672 .52153 L .56668 .51592 L 1 g
F
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55979 .51026 m .56668 .51592 L p
.55301 .55004 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56609 .50937 L p
1 g
F P
s
P
p
.5672 .52153 m .56854 .53025 L .56609 .50937 L 1 g
F
P
p
.002 w
.56609 .50937 m .56713 .51061 L p
.56284 .50241 L 1 g
F P
s
P
p
.002 w
.58175 .52828 m .57067 .51919 L p
.58001 .47986 L 1 g
F P
s
P
p
.54761 .47912 m .54932 .48349 L .54226 .47665 L 1 g
F
P
p
.002 w
.55718 .49111 m .55834 .49233 L p
.54805 .48226 L 1 g
F P
s
P
p
.002 w
.54226 .47665 m .54247 .47688 L p
.53923 .47525 L 1 g
F P
s
P
p
.52214 .46667 m .54226 .47665 L .53923 .47525 L 1 g
F
P
p
.002 w
.55979 .51026 m .52987 .49774 L .53767 .47453 L p
1 g
F P
s
P
p
.52214 .46667 m .54247 .47688 L .53161 .47157 L 1 g
F
P
p
.002 w
.53767 .47453 m .54144 .46332 L p
.54761 .47912 L 1 g
F P
s
P
p
.002 w
.53767 .47453 m .52987 .49774 L p
.50188 .45705 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.50188 .45705 m .54144 .46332 L .53767 .47453 L p
1 g
F P
s
P
p
.002 w
.54247 .47688 m .54302 .47747 L p
.53161 .47157 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.5095 .46523 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.49689 .45625 m .5026 .46344 L .5 .46388 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .49178 .46525 L 1 g
F
P
p
.002 w
.49657 .46445 m .49661 .46339 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.49661 .46339 m .49689 .45625 L p
.5 .46388 L 1 g
F P
s
P
p
.5026 .46344 m .50332 .46435 L .5 .46388 L 1 g
F
P
p
.002 w
.52237 .46706 m .52282 .46778 L p
.5095 .46523 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49178 .46525 L 1 g
F P
s
P
p
.002 w
.45205 .45965 m .49689 .45625 L .49657 .46445 L p
1 g
F P
s
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48749 .46569 L 1 g
F P
s
P
p
.45205 .45965 m .49657 .46445 L .46428 .46886 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48749 .46569 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47764 .46704 m .47718 .46778 L p
.46582 .47277 L 1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.45205 .45965 m .4651 .46948 L .45769 .47671 L 1 g
F
P
p
.44339 .4905 m .45769 .47671 L .45702 .47736 L 1 g
F
P
p
.002 w
.4566 .47777 m .45648 .47729 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.45648 .47729 m .45205 .45965 L p
.45769 .47671 L 1 g
F P
s
P
p
.4651 .46948 m .46804 .47169 L .45769 .47671 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .47671 L p
1 g
F P
s
P
p
.46582 .47277 m .47718 .46778 L .45769 .47671 L 1 g
F
P
p
.002 w
.45769 .47671 m .45763 .47676 L p
.45702 .47736 L 1 g
F P
s
P
p
.002 w
.49549 .49237 m .46089 .49489 L .4566 .47777 L p
1 g
F P
s
P
p
.44339 .4905 m .45763 .47676 L .44907 .48506 L 1 g
F
P
p
.44459 .48748 m .44593 .4881 L .44276 .49117 L 1 g
F
P
p
.44593 .4881 m .46089 .49489 L .44276 .49117 L 1 g
F
P
p
.002 w
.41263 .47297 m .45205 .45965 L .46089 .49489 L p
1 g
F P
s
P
p
.002 w
.45763 .47676 m .45698 .47747 L p
.44907 .48506 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44276 .49117 L p
1 g
F P
s
P
p
.44907 .48506 m .45698 .47747 L .44276 .49117 L 1 g
F
P
p
.43837 .50002 m .43884 .49892 L .43704 .50271 L 1 g
F
P
p
.002 w
.43033 .50491 m .41263 .47297 L p
.44459 .48748 L 1 g
F P
s
P
p
.4327 .52797 m .43135 .51489 L .43376 .51004 L 1 g
F
P
p
.002 w
.43033 .50491 m .43364 .50986 L p
.43135 .51489 L 1 g
F P
s
P
p
.002 w
.43364 .50986 m .43376 .51004 L p
.43135 .51489 L 1 g
F P
s
P
p
.002 w
.43033 .50491 m .46089 .49489 L .47083 .52772 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .44039 .49498 L p
.43381 .50949 L 1 g
F P
s
P
p
.002 w
.44039 .49498 m .43287 .51061 L .43379 .50952 L p
1 g
F P
s
P
p
.002 w
.43379 .50952 m .43381 .50949 L p
.44039 .49498 L 1 g
F P
s
P
p
.43884 .49892 m .44166 .49233 L .43381 .50949 L 1 g
F
P
p
.002 w
.43376 .51004 m .43364 .50986 L p
.43381 .50949 L 1 g
F P
s
P
p
.002 w
.43381 .50949 m .43379 .50952 L p
.43379 .50974 L 1 g
F P
s
P
p
.002 w
.43379 .50952 m .43287 .51061 L p
.43319 .51967 L 1 g
F P
s
P
p
.4328 .52898 m .4327 .52797 L .45004 .53434 L 1 g
F
P
p
.002 w
.43376 .51004 m .45004 .53434 L p
.4327 .52797 L 1 g
F P
s
P
p
.002 w
.40739 .52106 m .42685 .50735 L p
.4328 .52898 L 1 g
F P
s
P
p
.002 w
.42685 .50735 m .43033 .50491 L p
.4328 .52898 L 1 g
F P
s
P
p
.002 w
.43425 .5451 m .43182 .54293 L p
.4328 .52898 L 1 g
F P
s
P
p
.43264 .52893 m .4328 .52898 L .43182 .54293 L 1 g
F
P
p
.002 w
.43267 .52849 m .43146 .53025 L p
.43518 .53761 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43267 .52849 L p
1 g
F P
s
P
p
.43319 .51967 m .43287 .51061 L .43267 .52849 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45004 .53434 m .43677 .54339 L p
.4328 .52898 L 1 g
F P
s
P
p
.43742 .54641 m .471 .56021 L .43907 .54854 L 1 g
F
P
p
.44993 .56201 m .4396 .55087 L .43907 .54854 L 1 g
F
P
p
.002 w
.43425 .5451 m .4385 .54813 L p
.4396 .55087 L 1 g
F P
s
P
p
.002 w
.4385 .54813 m .43907 .54854 L p
.4396 .55087 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.43425 .5451 m .45004 .53434 L .471 .56021 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .4319 .53164 L p
.43827 .54751 L 1 g
F P
s
P
p
.002 w
.43176 .54881 m .43425 .5451 L p
.45122 .56341 L 1 g
F P
s
P
p
.002 w
.4319 .53164 m .43743 .5491 L .43826 .54753 L p
1 g
F P
s
P
p
.002 w
.43826 .54753 m .43827 .54751 L p
.4319 .53164 L 1 g
F P
s
P
p
.43333 .53396 m .43146 .53025 L .43827 .54751 L 1 g
F
P
p
.002 w
.43907 .54854 m .4385 .54813 L p
.43827 .54751 L 1 g
F P
s
P
p
.002 w
.43827 .54751 m .43826 .54753 L p
.43842 .5477 L 1 g
F P
s
P
p
.002 w
.43826 .54753 m .43743 .5491 L p
.44441 .55517 L 1 g
F P
s
P
p
.45122 .56341 m .44993 .56201 L .46294 .56553 L 1 g
F
P
p
.002 w
.43907 .54854 m .46294 .56553 L p
.44993 .56201 L 1 g
F P
s
P
p
.002 w
.42514 .55868 m .43176 .54881 L p
.45122 .56341 L 1 g
F P
s
P
p
.45102 .56337 m .45122 .56341 L .45665 .57036 L 1 g
F
P
p
.45102 .56337 m .45665 .57036 L .45818 .57231 L 1 g
F
P
p
.002 w
.45079 .56308 m .45002 .56518 L p
.45765 .56823 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56308 L p
1 g
F P
s
P
p
.44441 .55517 m .43743 .5491 L .45079 .56308 L 1 g
F
P
p
.002 w
.46294 .56553 m .45988 .5699 L p
.45122 .56341 L 1 g
F P
s
P
p
.002 w
.46827 .57473 m .46827 .57472 L p
.45457 .567 L 1 g
F P
s
P
p
.45542 .56734 m .45457 .567 L .46827 .57472 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57473 L p
1 g
F P
s
P
p
.45457 .567 m .45002 .56518 L .46827 .57473 L 1 g
F
P
p
.002 w
.48903 .58109 m .48903 .58104 L p
.4765 .57758 L 1 g
F P
s
P
p
.47805 .5777 m .4765 .57758 L .48903 .58104 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58109 L p
1 g
F P
s
P
p
.4765 .57758 m .4678 .57686 L .48903 .58109 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.38591 .40645 m .34708 .43649 L .33597 .40762 L p
1 g
F P
s
P
p
.002 w
.33597 .40762 m .37782 .37439 L .38591 .40645 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5739 .30054 m .50428 .28864 L .50545 .26635 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62336 .38434 m .66318 .42096 L .64938 .44886 L p
1 g
F P
s
P
p
.002 w
.66318 .42096 m .62336 .38434 L .6304 .35504 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45818 .57231 m .45718 .57978 L .42354 .57348 L p
1 g
F P
s
P
p
.002 w
.42354 .57348 m .42514 .55868 L .45818 .57231 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.52451 .58983 m .52776 .58273 L .56201 .57926 L p
1 g
F P
s
P
p
.002 w
.5613 .56435 m .56201 .57926 L .52776 .58273 L p
1 g
F P
s
P
p
.002 w
.56201 .57926 m .5613 .56435 L .59344 .54951 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.40739 .52106 m .39448 .54124 L .36726 .52066 L p
1 g
F P
s
P
p
.002 w
.36726 .52066 m .38336 .49426 L .40739 .52106 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.608 .50354 m .62251 .53124 L .59344 .54951 L p
1 g
F P
s
P
p
.002 w
.62251 .53124 m .608 .50354 L .6308 .47673 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.39765 .43973 m .36303 .46572 L .34708 .43649 L p
1 g
F P
s
P
p
.002 w
.34708 .43649 m .38591 .40645 L .39765 .43973 L p
1 g
F P
s
P
p
.002 w
.43425 .5451 m .42514 .55868 L .39448 .54124 L p
1 g
F P
s
P
p
.002 w
.39448 .54124 m .40739 .52106 L .43425 .5451 L p
1 g
F P
s
P
p
.002 w
.43538 .35325 m .37782 .37439 L .37357 .34467 L p
1 g
F P
s
P
p
.002 w
.37357 .34467 m .43374 .32207 L .43538 .35325 L p
1 g
F P
s
P
p
.002 w
.58175 .52828 m .59344 .54951 L .5613 .56435 L p
1 g
F P
s
P
p
.002 w
.59344 .54951 m .58175 .52828 L .608 .50354 L p
1 g
F P
s
P
p
.002 w
.50295 .31601 m .43374 .32207 L .43415 .29495 L p
1 g
F P
s
P
p
.002 w
.43415 .29495 m .50428 .28864 L .50295 .31601 L p
1 g
F P
s
P
p
.002 w
.57165 .32761 m .6304 .35504 L .62336 .38434 L p
1 g
F P
s
P
p
.002 w
.6304 .35504 m .57165 .32761 L .5739 .30054 L p
1 g
F P
s
P
p
.002 w
.61238 .41568 m .64938 .44886 L .6308 .47673 L p
1 g
F P
s
P
p
.002 w
.64938 .44886 m .61238 .41568 L .62336 .38434 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.50428 .28864 m .5739 .30054 L .57165 .32761 L p
1 g
F P
s
P
p
.002 w
.52721 .57519 m .52286 .56803 L .55301 .55004 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.57165 .32761 m .50295 .31601 L .50428 .28864 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41263 .47297 m .38336 .49426 L .36303 .46572 L p
1 g
F P
s
P
p
.002 w
.36303 .46572 m .39765 .43973 L .41263 .47297 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52286 .56803 m .51514 .56205 L .53788 .53799 L p
1 g
F P
s
P
p
.002 w
.53788 .53799 m .55301 .55004 L .52286 .56803 L p
1 g
F P
s
P
p
.002 w
.59776 .44792 m .6308 .47673 L .608 .50354 L p
1 g
F P
s
P
p
.002 w
.6308 .47673 m .59776 .44792 L .61238 .41568 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.43905 .38743 m .38591 .40645 L .37782 .37439 L p
1 g
F P
s
P
p
.002 w
.37782 .37439 m .43538 .35325 L .43905 .38743 L p
1 g
F P
s
P
p
.002 w
.43033 .50491 m .40739 .52106 L .38336 .49426 L p
1 g
F P
s
P
p
.002 w
.38336 .49426 m .41263 .47297 L .43033 .50491 L p
1 g
F P
s
P
p
.002 w
.48148 .55696 m .471 .56021 L .45004 .53434 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.51514 .56205 m .50487 .55794 L .51752 .52966 L p
1 g
F P
s
P
p
.002 w
.51752 .52966 m .53788 .53799 L .51514 .56205 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.56713 .35857 m .62336 .38434 L .61238 .41568 L p
1 g
F P
s
P
p
.002 w
.62336 .38434 m .56713 .35857 L .57165 .32761 L p
1 g
F P
s
P
p
.002 w
.55301 .55004 m .53788 .53799 L .55979 .51026 L p
1 g
F P
s
P
p
.002 w
.58001 .47986 m .608 .50354 L .58175 .52828 L p
1 g
F P
s
P
p
.002 w
.608 .50354 m .58001 .47986 L .59776 .44792 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.49321 .55617 m .48148 .55696 L .47083 .52772 L p
1 g
F P
s
P
p
.002 w
.45004 .53434 m .47083 .52772 L .48148 .55696 L p
1 g
F P
s
P
p
.002 w
.50487 .55794 m .49321 .55617 L .49425 .52609 L p
1 g
F P
s
P
p
.002 w
.49425 .52609 m .51752 .52966 L .50487 .55794 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.50148 .34763 m .43538 .35325 L .43374 .32207 L p
1 g
F P
s
P
p
.002 w
.43374 .32207 m .50295 .31601 L .50148 .34763 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.47083 .52772 m .49425 .52609 L .49321 .55617 L p
1 g
F P
s
P
p
.002 w
.50295 .31601 m .57165 .32761 L .56713 .35857 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44468 .42336 m .39765 .43973 L .38591 .40645 L p
1 g
F P
s
P
p
.002 w
.38591 .40645 m .43905 .38743 L .44468 .42336 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56713 .35857 m .50148 .34763 L .50295 .31601 L p
1 g
F P
s
P
p
.002 w
.53788 .53799 m .51752 .52966 L .52987 .49774 L p
1 g
F P
s
P
p
.002 w
.52987 .49774 m .55979 .51026 L .53788 .53799 L p
1 g
F P
s
P
p
.002 w
.56042 .39236 m .61238 .41568 L .59776 .44792 L p
1 g
F P
s
P
p
.002 w
.61238 .41568 m .56042 .39236 L .56713 .35857 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.45205 .45965 m .41263 .47297 L .39765 .43973 L p
1 g
F P
s
P
p
.002 w
.39765 .43973 m .44468 .42336 L .45205 .45965 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.49425 .52609 m .47083 .52772 L .46089 .49489 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.49995 .38244 m .43905 .38743 L .43538 .35325 L p
1 g
F P
s
P
p
.002 w
.43538 .35325 m .50148 .34763 L .49995 .38244 L p
1 g
F P
s
P
p
.002 w
.51752 .52966 m .49425 .52609 L .49549 .49237 L p
1 g
F P
s
P
p
.002 w
.49549 .49237 m .52987 .49774 L .51752 .52966 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55176 .42773 m .59776 .44792 L .58001 .47986 L p
1 g
F P
s
P
p
.002 w
.59776 .44792 m .55176 .42773 L .56042 .39236 L p
1 g
F P
s
P
p
.002 w
.50148 .34763 m .56713 .35857 L .56042 .39236 L p
1 g
F P
s
P
p
.002 w
.46089 .49489 m .49549 .49237 L .49425 .52609 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.58001 .47986 m .54144 .46332 L .55176 .42773 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.48932 .64304 m
.48984 .63276 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56042 .39236 m .49995 .38244 L .50148 .34763 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.49839 .41912 m .44468 .42336 L .43905 .38743 L p
1 g
F P
s
P
p
.002 w
.43905 .38743 m .49995 .38244 L .49839 .41912 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.49995 .38244 m .56042 .39236 L .55176 .42773 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49689 .45625 m .45205 .45965 L .44468 .42336 L p
1 g
F P
s
P
p
.002 w
.44468 .42336 m .49839 .41912 L .49689 .45625 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54144 .46332 m .49689 .45625 L .49839 .41912 L p
1 g
F P
s
P
p
.002 w
.49839 .41912 m .55176 .42773 L .54144 .46332 L p
1 g
F P
s
P
p
.002 w
.55176 .42773 m .49839 .41912 L .49995 .38244 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .24316 .48865 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .48799 .6696 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.336434)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.336434)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44537 .42136 m .48193 .44094 L .49222 .41427 L p
1 g
F P
s
P
p
.002 w
.49222 .41427 m .46178 .39783 L .44537 .42136 L p
1 g
F P
s
P
p
.002 w
.52615 .4228 m .49222 .41427 L .48193 .44094 L p
1 g
F P
s
P
p
.002 w
.46178 .39783 m .49222 .41427 L .50273 .38793 L p
1 g
F P
s
P
p
.002 w
.49222 .41427 m .52615 .4228 L .5291 .39454 L p
1 g
F P
s
P
p
.002 w
.5291 .39454 m .50273 .38793 L .49222 .41427 L p
1 g
F P
s
P
p
.002 w
.43021 .44523 m .47204 .46744 L .48193 .44094 L p
1 g
F P
s
P
p
.002 w
.48193 .44094 m .44537 .42136 L .43021 .44523 L p
1 g
F P
s
P
p
.002 w
.52258 .45118 m .48193 .44094 L .47204 .46744 L p
1 g
F P
s
P
p
.002 w
.48193 .44094 m .52258 .45118 L .52615 .4228 L p
1 g
F P
s
P
p
.002 w
.5604 .42258 m .52615 .4228 L .52258 .45118 L p
1 g
F P
s
P
p
.002 w
.52615 .4228 m .5604 .42258 L .55569 .39424 L p
1 g
F P
s
P
p
.002 w
.55569 .39424 m .5291 .39454 L .52615 .4228 L p
1 g
F P
s
P
p
.002 w
.47204 .46744 m .51844 .47916 L .52258 .45118 L p
1 g
F P
s
P
p
.002 w
.56365 .45112 m .52258 .45118 L .51844 .47916 L p
1 g
F P
s
P
p
.002 w
.52258 .45118 m .56365 .45112 L .5604 .42258 L p
1 g
F P
s
P
p
.002 w
.50273 .38793 m .47913 .37508 L .46178 .39783 L p
1 g
F P
s
P
p
.002 w
.47913 .37508 m .50273 .38793 L .51326 .36239 L p
1 g
F P
s
P
p
.002 w
.50273 .38793 m .5291 .39454 L .53136 .36691 L p
1 g
F P
s
P
p
.002 w
.53136 .36691 m .51326 .36239 L .50273 .38793 L p
1 g
F P
s
P
p
.002 w
.5291 .39454 m .55569 .39424 L .54959 .36662 L p
1 g
F P
s
P
p
.002 w
.54959 .36662 m .53136 .36691 L .5291 .39454 L p
1 g
F P
s
P
p
.002 w
.41659 .46902 m .46273 .49331 L .47204 .46744 L p
1 g
F P
s
P
p
.002 w
.47204 .46744 m .43021 .44523 L .41659 .46902 L p
1 g
F P
s
P
p
.002 w
.51844 .47916 m .47204 .46744 L .46273 .49331 L p
1 g
F P
s
P
p
.002 w
.41633 .3941 m .44537 .42136 L .46178 .39783 L p
1 g
F P
s
P
p
.002 w
.46178 .39783 m .43775 .37492 L .41633 .3941 L p
1 g
F P
s
P
p
.002 w
.43775 .37492 m .46178 .39783 L .47913 .37508 L p
1 g
F P
s
P
p
.002 w
.46273 .49331 m .51382 .50625 L .51844 .47916 L p
1 g
F P
s
P
p
.002 w
.56535 .47933 m .51844 .47916 L .51382 .50625 L p
1 g
F P
s
P
p
.002 w
.51844 .47916 m .56535 .47933 L .56365 .45112 L p
1 g
F P
s
P
p
.002 w
.39678 .41433 m .43021 .44523 L .44537 .42136 L p
1 g
F P
s
P
p
.002 w
.44537 .42136 m .41633 .3941 L .39678 .41433 L p
1 g
F P
s
P
p
.002 w
.47913 .37508 m .46063 .35716 L .43775 .37492 L p
1 g
F P
s
P
p
.002 w
.46063 .35716 m .47913 .37508 L .49711 .35351 L p
1 g
F P
s
P
p
.002 w
.51326 .36239 m .49711 .35351 L .47913 .37508 L p
1 g
F P
s
P
p
.002 w
.59172 .41349 m .5604 .42258 L .56365 .45112 L p
1 g
F P
s
P
p
.002 w
.5604 .42258 m .59172 .41349 L .5799 .38697 L p
1 g
F P
s
P
p
.002 w
.5799 .38697 m .55569 .39424 L .5604 .42258 L p
1 g
F P
s
P
p
.002 w
.55569 .39424 m .5799 .38697 L .56611 .3615 L p
1 g
F P
s
P
p
.002 w
.56611 .3615 m .54959 .36662 L .55569 .39424 L p
1 g
F P
s
P
p
.002 w
.60134 .44055 m .56365 .45112 L .56535 .47933 L p
1 g
F P
s
P
p
.002 w
.56365 .45112 m .60134 .44055 L .59172 .41349 L p
1 g
F P
s
P
p
.002 w
.49711 .35351 m .51326 .36239 L .52363 .33813 L p
1 g
F P
s
P
p
.002 w
.51326 .36239 m .53136 .36691 L .53289 .34043 L p
1 g
F P
s
P
p
.002 w
.53289 .34043 m .52363 .33813 L .51326 .36239 L p
1 g
F P
s
P
p
.002 w
.53136 .36691 m .54959 .36662 L .5422 .34024 L p
1 g
F P
s
P
p
.002 w
.5422 .34024 m .53289 .34043 L .53136 .36691 L p
1 g
F P
s
P
p
.002 w
.37953 .43526 m .41659 .46902 L .43021 .44523 L p
1 g
F P
s
P
p
.002 w
.43021 .44523 m .39678 .41433 L .37953 .43526 L p
1 g
F P
s
P
p
.002 w
.4048 .49225 m .45419 .51805 L .46273 .49331 L p
1 g
F P
s
P
p
.002 w
.46273 .49331 m .41659 .46902 L .4048 .49225 L p
1 g
F P
s
P
p
.002 w
.51382 .50625 m .46273 .49331 L .45419 .51805 L p
1 g
F P
s
P
p
.002 w
.45419 .51805 m .50878 .53191 L .51382 .50625 L p
1 g
F P
s
P
p
.002 w
.56547 .50667 m .51382 .50625 L .50878 .53191 L p
1 g
F P
s
P
p
.002 w
.51382 .50625 m .56547 .50667 L .56535 .47933 L p
1 g
F P
s
P
p
.002 w
.49711 .35351 m .48454 .34115 L .46063 .35716 L p
1 g
F P
s
P
p
.002 w
.48454 .34115 m .49711 .35351 L .51539 .33356 L p
1 g
F P
s
P
p
.002 w
.52363 .33813 m .51539 .33356 L .49711 .35351 L p
1 g
F P
s
P
p
.002 w
.54959 .36662 m .56611 .3615 L .55059 .33756 L p
1 g
F P
s
P
p
.002 w
.55059 .33756 m .5422 .34024 L .54959 .36662 L p
1 g
F P
s
P
p
.002 w
.60854 .46764 m .56535 .47933 L .56547 .50667 L p
1 g
F P
s
P
p
.002 w
.56535 .47933 m .60854 .46764 L .60134 .44055 L p
1 g
F P
s
P
p
.002 w
.42265 .3476 m .43775 .37492 L .46063 .35716 L p
1 g
F P
s
P
p
.002 w
.46063 .35716 m .4492 .33588 L .42265 .3476 L p
1 g
F P
s
P
p
.002 w
.4492 .33588 m .46063 .35716 L .48454 .34115 L p
1 g
F P
s
P
p
.002 w
.3978 .36149 m .41633 .3941 L .43775 .37492 L p
1 g
F P
s
P
p
.002 w
.43775 .37492 m .42265 .3476 L .3978 .36149 L p
1 g
F P
s
P
p
.002 w
.48454 .34115 m .47691 .32653 L .4492 .33588 L p
1 g
F P
s
P
p
.002 w
.47691 .32653 m .48454 .34115 L .50903 .32722 L p
1 g
F P
s
P
p
.002 w
.51539 .33356 m .50903 .32722 L .48454 .34115 L p
1 g
F P
s
P
p
.002 w
.59922 .37331 m .5799 .38697 L .59172 .41349 L p
1 g
F P
s
P
p
.002 w
.5799 .38697 m .59922 .37331 L .57917 .352 L p
1 g
F P
s
P
p
.002 w
.57917 .352 m .56611 .3615 L .5799 .38697 L p
1 g
F P
s
P
p
.002 w
.37518 .3773 m .39678 .41433 L .41633 .3941 L p
1 g
F P
s
P
p
.002 w
.41633 .3941 m .3978 .36149 L .37518 .3773 L p
1 g
F P
s
P
p
.002 w
.36497 .45648 m .4048 .49225 L .41659 .46902 L p
1 g
F P
s
P
p
.002 w
.41659 .46902 m .37953 .43526 L .36497 .45648 L p
1 g
F P
s
P
p
.002 w
.61693 .39616 m .59172 .41349 L .60134 .44055 L p
1 g
F P
s
P
p
.002 w
.59172 .41349 m .61693 .39616 L .59922 .37331 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .51539 .33356 L .52363 .33813 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .52363 .33813 L .53289 .34043 L closepath p
1 g
F P
s
P
p
.002 w
.56611 .3615 m .57917 .352 L .55716 .33265 L p
1 g
F P
s
P
p
.002 w
.55716 .33265 m .55059 .33756 L .56611 .3615 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .53289 .34043 L .5422 .34024 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .50903 .32722 L .51539 .33356 L closepath p
1 g
F P
s
P
p
.002 w
.39514 .51446 m .44661 .54115 L .45419 .51805 L p
1 g
F P
s
P
p
.002 w
.45419 .51805 m .4048 .49225 L .39514 .51446 L p
1 g
F P
s
P
p
.002 w
.50878 .53191 m .45419 .51805 L .44661 .54115 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .5422 .34024 L .55059 .33756 L closepath p
1 g
F P
s
P
p
.002 w
.50878 .53191 m .56396 .53261 L .56547 .50667 L p
1 g
F P
s
P
p
.002 w
.61313 .49421 m .56547 .50667 L .56396 .53261 L p
1 g
F P
s
P
p
.002 w
.56547 .50667 m .61313 .49421 L .60854 .46764 L p
1 g
F P
s
P
p
.002 w
.44661 .54115 m .5034 .55561 L .50878 .53191 L p
1 g
F P
s
P
p
.002 w
.56396 .53261 m .50878 .53191 L .5034 .55561 L p
1 g
F P
s
P
p
.002 w
.63189 .42012 m .60134 .44055 L .60854 .46764 L p
1 g
F P
s
P
p
.002 w
.60134 .44055 m .63189 .42012 L .61693 .39616 L p
1 g
F P
s
P
p
.002 w
.50903 .32722 m .50524 .31974 L .47691 .32653 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .50524 .31974 L .50903 .32722 L closepath p
1 g
F P
s
P
p
.002 w
.35531 .39476 m .37953 .43526 L .39678 .41433 L p
1 g
F P
s
P
p
.002 w
.39678 .41433 m .37518 .3773 L .35531 .39476 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .55059 .33756 L .55716 .33265 L closepath p
1 g
F P
s
P
p
.002 w
.44621 .31331 m .4492 .33588 L .47691 .32653 L p
1 g
F P
s
P
p
.002 w
.47691 .32653 m .47511 .31112 L .44621 .31331 L p
1 g
F P
s
P
p
.002 w
.47511 .31112 m .47691 .32653 L .50524 .31974 L p
1 g
F P
s
P
p
.002 w
.41835 .31847 m .42265 .3476 L .4492 .33588 L p
1 g
F P
s
P
p
.002 w
.4492 .33588 m .44621 .31331 L .41835 .31847 L p
1 g
F P
s
P
p
.002 w
.50524 .31974 m .50445 .31191 L .47511 .31112 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .50445 .31191 L .50524 .31974 L closepath p
1 g
F P
s
P
p
.002 w
.58732 .33903 m .57917 .352 L .59922 .37331 L p
1 g
F P
s
P
p
.002 w
.57917 .352 m .58732 .33903 L .56119 .32602 L p
1 g
F P
s
P
p
.002 w
.56119 .32602 m .55716 .33265 L .57917 .352 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .55716 .33265 L .56119 .32602 L closepath p
1 g
F P
s
P
p
.002 w
.39213 .32655 m .3978 .36149 L .42265 .3476 L p
1 g
F P
s
P
p
.002 w
.42265 .3476 m .41835 .31847 L .39213 .32655 L p
1 g
F P
s
P
p
.002 w
.35349 .47754 m .39514 .51446 L .4048 .49225 L p
1 g
F P
s
P
p
.002 w
.4048 .49225 m .36497 .45648 L .35349 .47754 L p
1 g
F P
s
P
p
.002 w
.6115 .35446 m .59922 .37331 L .61693 .39616 L p
1 g
F P
s
P
p
.002 w
.59922 .37331 m .6115 .35446 L .58732 .33903 L p
1 g
F P
s
P
p
.002 w
.64375 .4447 m .60854 .46764 L .61313 .49421 L p
1 g
F P
s
P
p
.002 w
.60854 .46764 m .64375 .4447 L .63189 .42012 L p
1 g
F P
s
P
p
.002 w
.47947 .29657 m .47511 .31112 L .50445 .31191 L p
1 g
F P
s
P
p
.002 w
.50445 .31191 m .50677 .30458 L .47947 .29657 L p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .50677 .30458 L .50445 .31191 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .56119 .32602 L .56221 .31835 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .56221 .31835 L .56007 .31049 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .56007 .31049 L .55497 .30329 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .55497 .30329 L .54747 .29756 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .54747 .29756 L .53837 .29397 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .53837 .29397 L .52872 .29292 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .52872 .29292 L .51959 .29451 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .51959 .29451 L .512 .29855 L closepath p
1 g
F P
s
P
p
.002 w
.53364 .31565 m .512 .29855 L .50677 .30458 L closepath p
1 g
F P
s
P
p
.002 w
.5034 .55561 m .56081 .55657 L .56396 .53261 L p
1 g
F P
s
P
p
.002 w
.61496 .51971 m .56396 .53261 L .56081 .55657 L p
1 g
F P
s
P
p
.002 w
.56396 .53261 m .61496 .51971 L .61313 .49421 L p
1 g
F P
s
P
p
.002 w
.3387 .41352 m .36497 .45648 L .37953 .43526 L p
1 g
F P
s
P
p
.002 w
.37953 .43526 m .35531 .39476 L .3387 .41352 L p
1 g
F P
s
P
p
.002 w
.56221 .31835 m .56119 .32602 L .58732 .33903 L p
1 g
F P
s
P
p
.002 w
.63318 .37202 m .61693 .39616 L .63189 .42012 L p
1 g
F P
s
P
p
.002 w
.61693 .39616 m .63318 .37202 L .6115 .35446 L p
1 g
F P
s
P
p
.002 w
.45228 .29182 m .44621 .31331 L .47511 .31112 L p
1 g
F P
s
P
p
.002 w
.47511 .31112 m .47947 .29657 L .45228 .29182 L p
1 g
F P
s
P
p
.002 w
.38787 .53516 m .44016 .56209 L .44661 .54115 L p
1 g
F P
s
P
p
.002 w
.44661 .54115 m .39514 .51446 L .38787 .53516 L p
1 g
F P
s
P
p
.002 w
.5034 .55561 m .44661 .54115 L .44016 .56209 L p
1 g
F P
s
P
p
.002 w
.36816 .33746 m .37518 .3773 L .3978 .36149 L p
1 g
F P
s
P
p
.002 w
.3978 .36149 m .39213 .32655 L .36816 .33746 L p
1 g
F P
s
P
p
.002 w
.44016 .56209 m .4978 .57679 L .5034 .55561 L p
1 g
F P
s
P
p
.002 w
.56081 .55657 m .5034 .55561 L .4978 .57679 L p
1 g
F P
s
P
p
.002 w
.48966 .28449 m .47947 .29657 L .50677 .30458 L p
1 g
F P
s
P
p
.002 w
.50677 .30458 m .512 .29855 L .48966 .28449 L p
1 g
F P
s
P
p
.002 w
.58958 .32391 m .58732 .33903 L .6115 .35446 L p
1 g
F P
s
P
p
.002 w
.58732 .33903 m .58958 .32391 L .56221 .31835 L p
1 g
F P
s
P
p
.002 w
.56007 .31049 m .56221 .31835 L .58958 .32391 L p
1 g
F P
s
P
p
.002 w
.4258 .29054 m .41835 .31847 L .44621 .31331 L p
1 g
F P
s
P
p
.002 w
.44621 .31331 m .45228 .29182 L .4258 .29054 L p
1 g
F P
s
P
p
.002 w
.65218 .46942 m .61313 .49421 L .61496 .51971 L p
1 g
F P
s
P
p
.002 w
.61313 .49421 m .65218 .46942 L .64375 .4447 L p
1 g
F P
s
P
p
.002 w
.65184 .39138 m .63189 .42012 L .64375 .4447 L p
1 g
F P
s
P
p
.002 w
.63189 .42012 m .65184 .39138 L .63318 .37202 L p
1 g
F P
s
P
p
.002 w
.50469 .2763 m .48966 .28449 L .512 .29855 L p
1 g
F P
s
P
p
.002 w
.512 .29855 m .51959 .29451 L .50469 .2763 L p
1 g
F P
s
P
p
.002 w
.58958 .32391 m .58552 .30826 L .56007 .31049 L p
1 g
F P
s
P
p
.002 w
.55497 .30329 m .56007 .31049 L .58552 .30826 L p
1 g
F P
s
P
p
.002 w
.34547 .498 m .38787 .53516 L .39514 .51446 L p
1 g
F P
s
P
p
.002 w
.39514 .51446 m .35349 .47754 L .34547 .498 L p
1 g
F P
s
P
p
.002 w
.61514 .33228 m .6115 .35446 L .63318 .37202 L p
1 g
F P
s
P
p
.002 w
.6115 .35446 m .61514 .33228 L .58958 .32391 L p
1 g
F P
s
P
p
.002 w
.46709 .27384 m .45228 .29182 L .47947 .29657 L p
1 g
F P
s
P
p
.002 w
.47947 .29657 m .48966 .28449 L .46709 .27384 L p
1 g
F P
s
P
p
.002 w
.34705 .35105 m .35531 .39476 L .37518 .3773 L p
1 g
F P
s
P
p
.002 w
.37518 .3773 m .36816 .33746 L .34705 .35105 L p
1 g
F P
s
P
p
.002 w
.52292 .27302 m .50469 .2763 L .51959 .29451 L p
1 g
F P
s
P
p
.002 w
.51959 .29451 m .52872 .29292 L .52292 .27302 L p
1 g
F P
s
P
p
.002 w
.32585 .43323 m .35349 .47754 L .36497 .45648 L p
1 g
F P
s
P
p
.002 w
.36497 .45648 m .3387 .41352 L .32585 .43323 L p
1 g
F P
s
P
p
.002 w
.58552 .30826 m .57548 .29384 L .55497 .30329 L p
1 g
F P
s
P
p
.002 w
.54747 .29756 m .55497 .30329 L .57548 .29384 L p
1 g
F P
s
P
p
.002 w
.40064 .29285 m .39213 .32655 L .41835 .31847 L p
1 g
F P
s
P
p
.002 w
.41835 .31847 m .4258 .29054 L .40064 .29285 L p
1 g
F P
s
P
p
.002 w
.58552 .30826 m .58958 .32391 L .61514 .33228 L p
1 g
F P
s
P
p
.002 w
.4978 .57679 m .55601 .57798 L .56081 .55657 L p
1 g
F P
s
P
p
.002 w
.61389 .54356 m .56081 .55657 L .55601 .57798 L p
1 g
F P
s
P
p
.002 w
.56081 .55657 m .61389 .54356 L .61496 .51971 L p
1 g
F P
s
P
p
.002 w
.54228 .2751 m .52292 .27302 L .52872 .29292 L p
1 g
F P
s
P
p
.002 w
.52872 .29292 m .53837 .29397 L .54228 .2751 L p
1 g
F P
s
P
p
.002 w
.57548 .29384 m .56051 .28233 L .54747 .29756 L p
1 g
F P
s
P
p
.002 w
.53837 .29397 m .54747 .29756 L .56051 .28233 L p
1 g
F P
s
P
p
.002 w
.56051 .28233 m .54228 .2751 L .53837 .29397 L p
1 g
F P
s
P
p
.002 w
.66699 .41218 m .64375 .4447 L .65218 .46942 L p
1 g
F P
s
P
p
.002 w
.64375 .4447 m .66699 .41218 L .65184 .39138 L p
1 g
F P
s
P
p
.002 w
.38327 .55381 m .43504 .58033 L .44016 .56209 L p
1 g
F P
s
P
p
.002 w
.44016 .56209 m .38787 .53516 L .38327 .55381 L p
1 g
F P
s
P
p
.002 w
.4978 .57679 m .44016 .56209 L .43504 .58033 L p
1 g
F P
s
P
p
.002 w
.6383 .34335 m .63318 .37202 L .65184 .39138 L p
1 g
F P
s
P
p
.002 w
.63318 .37202 m .6383 .34335 L .61514 .33228 L p
1 g
F P
s
P
p
.002 w
.65687 .49372 m .61496 .51971 L .61389 .54356 L p
1 g
F P
s
P
p
.002 w
.61496 .51971 m .65687 .49372 L .65218 .46942 L p
1 g
F P
s
P
p
.002 w
.43504 .58033 m .49207 .5949 L .4978 .57679 L p
1 g
F P
s
P
p
.002 w
.55601 .57798 m .4978 .57679 L .49207 .5949 L p
1 g
F P
s
P
p
.002 w
.48923 .26154 m .46709 .27384 L .48966 .28449 L p
1 g
F P
s
P
p
.002 w
.48966 .28449 m .50469 .2763 L .48923 .26154 L p
1 g
F P
s
P
p
.002 w
.44476 .26698 m .4258 .29054 L .45228 .29182 L p
1 g
F P
s
P
p
.002 w
.45228 .29182 m .46709 .27384 L .44476 .26698 L p
1 g
F P
s
P
p
.002 w
.32941 .36709 m .3387 .41352 L .35531 .39476 L p
1 g
F P
s
P
p
.002 w
.35531 .39476 m .34705 .35105 L .32941 .36709 L p
1 g
F P
s
P
p
.002 w
.61514 .33228 m .60942 .30912 L .58552 .30826 L p
1 g
F P
s
P
p
.002 w
.57548 .29384 m .58552 .30826 L .60942 .30912 L p
1 g
F P
s
P
p
.002 w
.37741 .29883 m .36816 .33746 L .39213 .32655 L p
1 g
F P
s
P
p
.002 w
.39213 .32655 m .40064 .29285 L .37741 .29883 L p
1 g
F P
s
P
p
.002 w
.60942 .30912 m .61514 .33228 L .6383 .34335 L p
1 g
F P
s
P
p
.002 w
.34126 .51734 m .38327 .55381 L .38787 .53516 L p
1 g
F P
s
P
p
.002 w
.38787 .53516 m .34547 .498 L .34126 .51734 L p
1 g
F P
s
P
p
.002 w
.31722 .45346 m .34547 .498 L .35349 .47754 L p
1 g
F P
s
P
p
.002 w
.35349 .47754 m .32585 .43323 L .31722 .45346 L p
1 g
F P
s
P
p
.002 w
.51633 .25655 m .48923 .26154 L .50469 .2763 L p
1 g
F P
s
P
p
.002 w
.50469 .2763 m .52292 .27302 L .51633 .25655 L p
1 g
F P
s
P
p
.002 w
.60942 .30912 m .59468 .28764 L .57548 .29384 L p
1 g
F P
s
P
p
.002 w
.56051 .28233 m .57548 .29384 L .59468 .28764 L p
1 g
F P
s
P
p
.002 w
.65843 .35697 m .65184 .39138 L .66699 .41218 L p
1 g
F P
s
P
p
.002 w
.65184 .39138 m .65843 .35697 L .6383 .34335 L p
1 g
F P
s
P
p
.002 w
.67815 .43398 m .65218 .46942 L .65687 .49372 L p
1 g
F P
s
P
p
.002 w
.65218 .46942 m .67815 .43398 L .66699 .41218 L p
1 g
F P
s
P
p
.002 w
.49207 .5949 m .54961 .59626 L .55601 .57798 L p
1 g
F P
s
P
p
.002 w
.60982 .56516 m .55601 .57798 L .54961 .59626 L p
1 g
F P
s
P
p
.002 w
.55601 .57798 m .60982 .56516 L .61389 .54356 L p
1 g
F P
s
P
p
.002 w
.42321 .26422 m .40064 .29285 L .4258 .29054 L p
1 g
F P
s
P
p
.002 w
.4258 .29054 m .44476 .26698 L .42321 .26422 L p
1 g
F P
s
P
p
.002 w
.54522 .25961 m .51633 .25655 L .52292 .27302 L p
1 g
F P
s
P
p
.002 w
.52292 .27302 m .54228 .2751 L .54522 .25961 L p
1 g
F P
s
P
p
.002 w
.59468 .28764 m .57243 .27042 L .56051 .28233 L p
1 g
F P
s
P
p
.002 w
.54228 .2751 m .56051 .28233 L .57243 .27042 L p
1 g
F P
s
P
p
.002 w
.47354 .25074 m .44476 .26698 L .46709 .27384 L p
1 g
F P
s
P
p
.002 w
.46709 .27384 m .48923 .26154 L .47354 .25074 L p
1 g
F P
s
P
p
.002 w
.65757 .51703 m .61389 .54356 L .60982 .56516 L p
1 g
F P
s
P
p
.002 w
.61389 .54356 m .65757 .51703 L .65687 .49372 L p
1 g
F P
s
P
p
.002 w
.57243 .27042 m .54522 .25961 L .54228 .2751 L p
1 g
F P
s
P
p
.002 w
.35678 .3085 m .34705 .35105 L .36816 .33746 L p
1 g
F P
s
P
p
.002 w
.36816 .33746 m .37741 .29883 L .35678 .3085 L p
1 g
F P
s
P
p
.002 w
.3158 .3853 m .32585 .43323 L .3387 .41352 L p
1 g
F P
s
P
p
.002 w
.3387 .41352 m .32941 .36709 L .3158 .3853 L p
1 g
F P
s
P
p
.002 w
.38159 .56989 m .43144 .59531 L .43504 .58033 L p
1 g
F P
s
P
p
.002 w
.43504 .58033 m .38327 .55381 L .38159 .56989 L p
1 g
F P
s
P
p
.002 w
.49207 .5949 m .43504 .58033 L .43144 .59531 L p
1 g
F P
s
P
p
.002 w
.6383 .34335 m .63115 .31318 L .60942 .30912 L p
1 g
F P
s
P
p
.002 w
.59468 .28764 m .60942 .30912 L .63115 .31318 L p
1 g
F P
s
P
p
.002 w
.63115 .31318 m .6383 .34335 L .65843 .35697 L p
1 g
F P
s
P
p
.002 w
.43144 .59531 m .48634 .60935 L .49207 .5949 L p
1 g
F P
s
P
p
.002 w
.54961 .59626 m .49207 .5949 L .48634 .60935 L p
1 g
F P
s
P
p
.002 w
.67495 .37293 m .66699 .41218 L .67815 .43398 L p
1 g
F P
s
P
p
.002 w
.66699 .41218 m .67495 .37293 L .65843 .35697 L p
1 g
F P
s
P
p
.002 w
.31322 .47373 m .34126 .51734 L .34547 .498 L p
1 g
F P
s
P
p
.002 w
.34547 .498 m .31722 .45346 L .31322 .47373 L p
1 g
F P
s
P
p
.002 w
.68489 .45631 m .65687 .49372 L .65757 .51703 L p
1 g
F P
s
P
p
.002 w
.65687 .49372 m .68489 .45631 L .67815 .43398 L p
1 g
F P
s
P
p
.002 w
.50905 .24408 m .47354 .25074 L .48923 .26154 L p
1 g
F P
s
P
p
.002 w
.48923 .26154 m .51633 .25655 L .50905 .24408 L p
1 g
F P
s
P
p
.002 w
.40302 .26585 m .37741 .29883 L .40064 .29285 L p
1 g
F P
s
P
p
.002 w
.40064 .29285 m .42321 .26422 L .40302 .26585 L p
1 g
F P
s
P
p
.002 w
.34115 .53505 m .38159 .56989 L .38327 .55381 L p
1 g
F P
s
P
p
.002 w
.38327 .55381 m .34126 .51734 L .34115 .53505 L p
1 g
F P
s
P
p
.002 w
.63115 .31318 m .61205 .28499 L .59468 .28764 L p
1 g
F P
s
P
p
.002 w
.57243 .27042 m .59468 .28764 L .61205 .28499 L p
1 g
F P
s
P
p
.002 w
.33937 .32178 m .32941 .36709 L .34705 .35105 L p
1 g
F P
s
P
p
.002 w
.34705 .35105 m .35678 .3085 L .33937 .32178 L p
1 g
F P
s
P
p
.002 w
.45799 .24437 m .42321 .26422 L .44476 .26698 L p
1 g
F P
s
P
p
.002 w
.44476 .26698 m .47354 .25074 L .45799 .24437 L p
1 g
F P
s
P
p
.002 w
.48634 .60935 m .54165 .6108 L .54961 .59626 L p
1 g
F P
s
P
p
.002 w
.60272 .5839 m .54961 .59626 L .54165 .6108 L p
1 g
F P
s
P
p
.002 w
.54961 .59626 m .60272 .5839 L .60982 .56516 L p
1 g
F P
s
P
p
.002 w
.65409 .53874 m .60982 .56516 L .60272 .5839 L p
1 g
F P
s
P
p
.002 w
.60982 .56516 m .65409 .53874 L .65757 .51703 L p
1 g
F P
s
P
p
.002 w
.30677 .40532 m .31722 .45346 L .32585 .43323 L p
1 g
F P
s
P
p
.002 w
.32585 .43323 m .3158 .3853 L .30677 .40532 L p
1 g
F P
s
P
p
.002 w
.65011 .32048 m .65843 .35697 L .67495 .37293 L p
1 g
F P
s
P
p
.002 w
.65843 .35697 m .65011 .32048 L .63115 .31318 L p
1 g
F P
s
P
p
.002 w
.54707 .24806 m .50905 .24408 L .51633 .25655 L p
1 g
F P
s
P
p
.002 w
.51633 .25655 m .54522 .25961 L .54707 .24806 L p
1 g
F P
s
P
p
.002 w
.61205 .28499 m .58288 .26231 L .57243 .27042 L p
1 g
F P
s
P
p
.002 w
.54522 .25961 m .57243 .27042 L .58288 .26231 L p
1 g
F P
s
P
p
.002 w
.61205 .28499 m .63115 .31318 L .65011 .32048 L p
1 g
F P
s
P
p
.002 w
.58288 .26231 m .54707 .24806 L .54522 .25961 L p
1 g
F P
s
P
p
.002 w
.68729 .39093 m .67815 .43398 L .68489 .45631 L p
1 g
F P
s
P
p
.002 w
.67815 .43398 m .68729 .39093 L .67495 .37293 L p
1 g
F P
s
P
p
.002 w
.38302 .58285 m .42953 .60648 L .43144 .59531 L p
1 g
F P
s
P
p
.002 w
.43144 .59531 m .38159 .56989 L .38302 .58285 L p
1 g
F P
s
P
p
.002 w
.48634 .60935 m .43144 .59531 L .42953 .60648 L p
1 g
F P
s
P
p
.002 w
.42953 .60648 m .48074 .6196 L .48634 .60935 L p
1 g
F P
s
P
p
.002 w
.54165 .6108 m .48634 .60935 L .48074 .6196 L p
1 g
F P
s
P
p
.002 w
.68685 .47863 m .65757 .51703 L .65409 .53874 L p
1 g
F P
s
P
p
.002 w
.65757 .51703 m .68685 .47863 L .68489 .45631 L p
1 g
F P
s
P
p
.002 w
.38477 .27202 m .35678 .3085 L .37741 .29883 L p
1 g
F P
s
P
p
.002 w
.37741 .29883 m .40302 .26585 L .38477 .27202 L p
1 g
F P
s
P
p
.002 w
.3142 .49351 m .34115 .53505 L .34126 .51734 L p
1 g
F P
s
P
p
.002 w
.34126 .51734 m .31322 .47373 L .3142 .49351 L p
1 g
F P
s
P
p
.002 w
.50123 .23615 m .45799 .24437 L .47354 .25074 L p
1 g
F P
s
P
p
.002 w
.47354 .25074 m .50905 .24408 L .50123 .23615 L p
1 g
F P
s
P
p
.002 w
.32582 .33848 m .3158 .3853 L .32941 .36709 L p
1 g
F P
s
P
p
.002 w
.32941 .36709 m .33937 .32178 L .32582 .33848 L p
1 g
F P
s
P
p
.002 w
.34537 .55057 m .38302 .58285 L .38159 .56989 L p
1 g
F P
s
P
p
.002 w
.38159 .56989 m .34115 .53505 L .34537 .55057 L p
1 g
F P
s
P
p
.002 w
.44298 .24284 m .40302 .26585 L .42321 .26422 L p
1 g
F P
s
P
p
.002 w
.42321 .26422 m .45799 .24437 L .44298 .24284 L p
1 g
F P
s
P
p
.002 w
.65011 .32048 m .62706 .28617 L .61205 .28499 L p
1 g
F P
s
P
p
.002 w
.58288 .26231 m .61205 .28499 L .62706 .28617 L p
1 g
F P
s
P
p
.002 w
.66567 .33101 m .67495 .37293 L .68729 .39093 L p
1 g
F P
s
P
p
.002 w
.67495 .37293 m .66567 .33101 L .65011 .32048 L p
1 g
F P
s
P
p
.002 w
.30279 .42669 m .31322 .47373 L .31722 .45346 L p
1 g
F P
s
P
p
.002 w
.31722 .45346 m .30677 .40532 L .30279 .42669 L p
1 g
F P
s
P
p
.002 w
.54165 .6108 m .59259 .59917 L .60272 .5839 L p
1 g
F P
s
P
p
.002 w
.64632 .55823 m .60272 .5839 L .59259 .59917 L p
1 g
F P
s
P
p
.002 w
.60272 .5839 m .64632 .55823 L .65409 .53874 L p
1 g
F P
s
P
p
.002 w
.48074 .6196 m .53227 .62104 L .54165 .6108 L p
1 g
F P
s
P
p
.002 w
.59259 .59917 m .54165 .6108 L .53227 .62104 L p
1 g
F P
s
P
p
.002 w
.62706 .28617 m .65011 .32048 L .66567 .33101 L p
1 g
F P
s
P
p
.002 w
.54772 .24099 m .50123 .23615 L .50905 .24408 L p
1 g
F P
s
P
p
.002 w
.50905 .24408 m .54707 .24806 L .54772 .24099 L p
1 g
F P
s
P
p
.002 w
.69491 .4106 m .68489 .45631 L .68685 .47863 L p
1 g
F P
s
P
p
.002 w
.68489 .45631 m .69491 .4106 L .68729 .39093 L p
1 g
F P
s
P
p
.002 w
.62706 .28617 m .59152 .25843 L .58288 .26231 L p
1 g
F P
s
P
p
.002 w
.54707 .24806 m .58288 .26231 L .59152 .25843 L p
1 g
F P
s
P
p
.002 w
.36907 .28283 m .33937 .32178 L .35678 .3085 L p
1 g
F P
s
P
p
.002 w
.35678 .3085 m .38477 .27202 L .36907 .28283 L p
1 g
F P
s
P
p
.002 w
.68374 .50034 m .65409 .53874 L .64632 .55823 L p
1 g
F P
s
P
p
.002 w
.65409 .53874 m .68374 .50034 L .68685 .47863 L p
1 g
F P
s
P
p
.002 w
.59152 .25843 m .54772 .24099 L .54707 .24806 L p
1 g
F P
s
P
p
.002 w
.38773 .59217 m .42946 .61333 L .42953 .60648 L p
1 g
F P
s
P
p
.002 w
.42953 .60648 m .38302 .58285 L .38773 .59217 L p
1 g
F P
s
P
p
.002 w
.48074 .6196 m .42953 .60648 L .42946 .61333 L p
1 g
F P
s
P
p
.002 w
.31669 .35832 m .30677 .40532 L .3158 .3853 L p
1 g
F P
s
P
p
.002 w
.3158 .3853 m .32582 .33848 L .31669 .35832 L p
1 g
F P
s
P
p
.002 w
.42946 .61333 m .47543 .62511 L .48074 .6196 L p
1 g
F P
s
P
p
.002 w
.53227 .62104 m .48074 .6196 L .47543 .62511 L p
1 g
F P
s
P
p
.002 w
.32038 .51225 m .34537 .55057 L .34115 .53505 L p
1 g
F P
s
P
p
.002 w
.34115 .53505 m .3142 .49351 L .32038 .51225 L p
1 g
F P
s
P
p
.002 w
.49305 .23327 m .44298 .24284 L .45799 .24437 L p
1 g
F P
s
P
p
.002 w
.45799 .24437 m .50123 .23615 L .49305 .23327 L p
1 g
F P
s
P
p
.002 w
.42897 .24649 m .38477 .27202 L .40302 .26585 L p
1 g
F P
s
P
p
.002 w
.40302 .26585 m .44298 .24284 L .42897 .24649 L p
1 g
F P
s
P
p
.002 w
.67724 .34466 m .68729 .39093 L .69491 .4106 L p
1 g
F P
s
P
p
.002 w
.68729 .39093 m .67724 .34466 L .66567 .33101 L p
1 g
F P
s
P
p
.002 w
.3042 .44887 m .3142 .49351 L .31322 .47373 L p
1 g
F P
s
P
p
.002 w
.31322 .47373 m .30279 .42669 L .3042 .44887 L p
1 g
F P
s
P
p
.002 w
.35405 .56336 m .38773 .59217 L .38302 .58285 L p
1 g
F P
s
P
p
.002 w
.38302 .58285 m .34537 .55057 L .35405 .56336 L p
1 g
F P
s
P
p
.002 w
.66567 .33101 m .63917 .29136 L .62706 .28617 L p
1 g
F P
s
P
p
.002 w
.59152 .25843 m .62706 .28617 L .63917 .29136 L p
1 g
F P
s
P
p
.002 w
.53227 .62104 m .57955 .61037 L .59259 .59917 L p
1 g
F P
s
P
p
.002 w
.63425 .57485 m .59259 .59917 L .57955 .61037 L p
1 g
F P
s
P
p
.002 w
.59259 .59917 m .63425 .57485 L .64632 .55823 L p
1 g
F P
s
P
p
.002 w
.69738 .43149 m .68685 .47863 L .68374 .50034 L p
1 g
F P
s
P
p
.002 w
.68685 .47863 m .69738 .43149 L .69491 .4106 L p
1 g
F P
s
P
p
.002 w
.47543 .62511 m .5216 .62645 L .53227 .62104 L p
1 g
F P
s
P
p
.002 w
.57955 .61037 m .53227 .62104 L .5216 .62645 L p
1 g
F P
s
P
p
.002 w
.63917 .29136 m .66567 .33101 L .67724 .34466 L p
1 g
F P
s
P
p
.002 w
.3565 .2982 m .32582 .33848 L .33937 .32178 L p
1 g
F P
s
P
p
.002 w
.33937 .32178 m .36907 .28283 L .3565 .2982 L p
1 g
F P
s
P
p
.002 w
.67541 .52081 m .64632 .55823 L .63425 .57485 L p
1 g
F P
s
P
p
.002 w
.64632 .55823 m .67541 .52081 L .68374 .50034 L p
1 g
F P
s
P
p
.002 w
.54707 .23888 m .49305 .23327 L .50123 .23615 L p
1 g
F P
s
P
p
.002 w
.50123 .23615 m .54772 .24099 L .54707 .23888 L p
1 g
F P
s
P
p
.002 w
.31247 .38086 m .30279 .42669 L .30677 .40532 L p
1 g
F P
s
P
p
.002 w
.30677 .40532 m .31669 .35832 L .31247 .38086 L p
1 g
F P
s
P
p
.002 w
.63917 .29136 m .59799 .25917 L .59152 .25843 L p
1 g
F P
s
P
p
.002 w
.54772 .24099 m .59152 .25843 L .59799 .25917 L p
1 g
F P
s
P
p
.002 w
.59799 .25917 m .54707 .23888 L .54772 .24099 L p
1 g
F P
s
P
p
.004 w
.28234 .37905 m
.28461 .37959 L
s
P
p
.002 w
.33187 .52932 m .35405 .56336 L .34537 .55057 L p
1 g
F P
s
P
p
.002 w
.34537 .55057 m .32038 .51225 L .33187 .52932 L p
1 g
F P
s
P
p
.002 w
.69491 .4106 m .68428 .36122 L .67724 .34466 L p
1 g
F P
s
P
p
.002 w
.68428 .36122 m .69491 .4106 L .69738 .43149 L p
1 g
F P
s
P
p
.002 w
.39579 .59734 m .43136 .61537 L .42946 .61333 L p
1 g
F P
s
P
p
.002 w
.42946 .61333 m .38773 .59217 L .39579 .59734 L p
1 g
F P
s
P
p
.002 w
.47543 .62511 m .42946 .61333 L .43136 .61537 L p
1 g
F P
s
P
p
.004 w
.43514 .65199 m
.44239 .62725 L
s
P
p
.002 w
.41642 .25551 m .36907 .28283 L .38477 .27202 L p
1 g
F P
s
P
p
.002 w
.38477 .27202 m .42897 .24649 L .41642 .25551 L p
1 g
F P
s
P
p
.002 w
.4847 .23585 m .42897 .24649 L .44298 .24284 L p
1 g
F P
s
P
p
.002 w
.44298 .24284 m .49305 .23327 L .4847 .23585 L p
1 g
F P
s
P
p
.002 w
.43136 .61537 m .47058 .62542 L .47543 .62511 L p
1 g
F P
s
P
p
.002 w
.5216 .62645 m .47543 .62511 L .47058 .62542 L p
1 g
F P
s
P
p
.002 w
.31125 .47124 m .32038 .51225 L .3142 .49351 L p
1 g
F P
s
P
p
.002 w
.3142 .49351 m .3042 .44887 L .31125 .47124 L p
1 g
F P
s
P
p
.002 w
.68374 .50034 m .69436 .45306 L .69738 .43149 L p
1 g
F P
s
P
p
.002 w
.69436 .45306 m .68374 .50034 L .67541 .52081 L p
1 g
F P
s
P
p
.002 w
.5216 .62645 m .56379 .61697 L .57955 .61037 L p
1 g
F P
s
P
p
.002 w
.57955 .61037 m .618 .58801 L .63425 .57485 L p
1 g
F P
s
P
p
.002 w
.618 .58801 m .57955 .61037 L .56379 .61697 L p
1 g
F P
s
P
p
.002 w
.67724 .34466 m .64789 .30066 L .63917 .29136 L p
1 g
F P
s
P
p
.002 w
.59799 .25917 m .63917 .29136 L .64789 .30066 L p
1 g
F P
s
P
p
.002 w
.36722 .57288 m .39579 .59734 L .38773 .59217 L p
1 g
F P
s
P
p
.002 w
.38773 .59217 m .35405 .56336 L .36722 .57288 L p
1 g
F P
s
P
p
.002 w
.64789 .30066 m .67724 .34466 L .68428 .36122 L p
1 g
F P
s
P
p
.002 w
.34763 .31792 m .31669 .35832 L .32582 .33848 L p
1 g
F P
s
P
p
.002 w
.32582 .33848 m .3565 .2982 L .34763 .31792 L p
1 g
F P
s
P
p
.002 w
.63425 .57485 m .66185 .5394 L .67541 .52081 L p
1 g
F P
s
P
p
.002 w
.66185 .5394 m .63425 .57485 L .618 .58801 L p
1 g
F P
s
P
p
.002 w
.47058 .62542 m .50989 .62657 L .5216 .62645 L p
1 g
F P
s
P
p
.002 w
.56379 .61697 m .5216 .62645 L .50989 .62657 L p
1 g
F P
s
P
p
.002 w
.31353 .40555 m .3042 .44887 L .30279 .42669 L p
1 g
F P
s
P
p
.002 w
.30279 .42669 m .31247 .38086 L .31353 .40555 L p
1 g
F P
s
P
p
.002 w
.54505 .24213 m .4847 .23585 L .49305 .23327 L p
1 g
F P
s
P
p
.002 w
.49305 .23327 m .54707 .23888 L .54505 .24213 L p
1 g
F P
s
P
p
.002 w
.64789 .30066 m .60197 .2648 L .59799 .25917 L p
1 g
F P
s
P
p
.002 w
.54707 .23888 m .59799 .25917 L .60197 .2648 L p
1 g
F P
s
P
p
.002 w
.68632 .38037 m .69738 .43149 L .69436 .45306 L p
1 g
F P
s
P
p
.002 w
.69738 .43149 m .68632 .38037 L .68428 .36122 L p
1 g
F P
s
P
p
.002 w
.4058 .26996 m .3565 .2982 L .36907 .28283 L p
1 g
F P
s
P
p
.002 w
.36907 .28283 m .41642 .25551 L .4058 .26996 L p
1 g
F P
s
P
p
.002 w
.34859 .54414 m .36722 .57288 L .35405 .56336 L p
1 g
F P
s
P
p
.002 w
.35405 .56336 m .33187 .52932 L .34859 .54414 L p
1 g
F P
s
P
p
.002 w
.32398 .49313 m .33187 .52932 L .32038 .51225 L p
1 g
F P
s
P
p
.002 w
.32038 .51225 m .31125 .47124 L .32398 .49313 L p
1 g
F P
s
P
p
.002 w
.60197 .2648 m .54505 .24213 L .54707 .23888 L p
1 g
F P
s
P
p
.002 w
.68566 .47469 m .67541 .52081 L .66185 .5394 L p
1 g
F P
s
P
p
.002 w
.67541 .52081 m .68566 .47469 L .69436 .45306 L p
1 g
F P
s
P
p
.002 w
.47645 .24415 m .41642 .25551 L .42897 .24649 L p
1 g
F P
s
P
p
.002 w
.42897 .24649 m .4847 .23585 L .47645 .24415 L p
1 g
F P
s
P
p
.002 w
.40718 .59795 m .4353 .61223 L .43136 .61537 L p
1 g
F P
s
P
p
.002 w
.43136 .61537 m .39579 .59734 L .40718 .59795 L p
1 g
F P
s
P
p
.002 w
.47058 .62542 m .43136 .61537 L .4353 .61223 L p
1 g
F P
s
P
p
.002 w
.4353 .61223 m .46635 .62019 L .47058 .62542 L p
1 g
F P
s
P
p
.002 w
.50989 .62657 m .47058 .62542 L .46635 .62019 L p
1 g
F P
s
P
p
.002 w
.50989 .62657 m .54562 .61851 L .56379 .61697 L p
1 g
F P
s
P
p
.002 w
.59784 .59712 m .56379 .61697 L .54562 .61851 L p
1 g
F P
s
P
p
.002 w
.56379 .61697 m .59784 .59712 L .618 .58801 L p
1 g
F P
s
P
p
.002 w
.34292 .34158 m .31247 .38086 L .31669 .35832 L p
1 g
F P
s
P
p
.002 w
.31669 .35832 m .34763 .31792 L .34292 .34158 L p
1 g
F P
s
P
p
.002 w
.65273 .31406 m .68428 .36122 L .68632 .38037 L p
1 g
F P
s
P
p
.002 w
.68428 .36122 m .65273 .31406 L .64789 .30066 L p
1 g
F P
s
P
p
.002 w
.60197 .2648 m .64789 .30066 L .65273 .31406 L p
1 g
F P
s
P
p
.002 w
.64321 .55543 m .618 .58801 L .59784 .59712 L p
1 g
F P
s
P
p
.002 w
.618 .58801 m .64321 .55543 L .66185 .5394 L p
1 g
F P
s
P
p
.002 w
.38472 .57866 m .40718 .59795 L .39579 .59734 L p
1 g
F P
s
P
p
.002 w
.39579 .59734 m .36722 .57288 L .38472 .57866 L p
1 g
F P
s
P
p
.002 w
.32008 .43168 m .31125 .47124 L .3042 .44887 L p
1 g
F P
s
P
p
.002 w
.3042 .44887 m .31353 .40555 L .32008 .43168 L p
1 g
F P
s
P
p
.002 w
.46635 .62019 m .49741 .62106 L .50989 .62657 L p
1 g
F P
s
P
p
.002 w
.54562 .61851 m .50989 .62657 L .49741 .62106 L p
1 g
F P
s
P
p
.002 w
.68302 .40166 m .69436 .45306 L .68566 .47469 L p
1 g
F P
s
P
p
.002 w
.69436 .45306 m .68302 .40166 L .68632 .38037 L p
1 g
F P
s
P
p
.002 w
.54164 .25101 m .47645 .24415 L .4847 .23585 L p
1 g
F P
s
P
p
.002 w
.4847 .23585 m .54505 .24213 L .54164 .25101 L p
1 g
F P
s
P
p
.002 w
.39757 .28966 m .34763 .31792 L .3565 .2982 L p
1 g
F P
s
P
p
.002 w
.3565 .2982 m .4058 .26996 L .39757 .28966 L p
1 g
F P
s
P
p
.002 w
.67129 .49571 m .66185 .5394 L .64321 .55543 L p
1 g
F P
s
P
p
.002 w
.66185 .5394 m .67129 .49571 L .68566 .47469 L p
1 g
F P
s
P
p
.002 w
.34222 .51379 m .34859 .54414 L .33187 .52932 L p
1 g
F P
s
P
p
.002 w
.33187 .52932 m .32398 .49313 L .34222 .51379 L p
1 g
F P
s
P
p
.002 w
.37028 .55611 m .38472 .57866 L .36722 .57288 L p
1 g
F P
s
P
p
.002 w
.36722 .57288 m .34859 .54414 L .37028 .55611 L p
1 g
F P
s
P
p
.002 w
.65273 .31406 m .60316 .27547 L .60197 .2648 L p
1 g
F P
s
P
p
.002 w
.54505 .24213 m .60197 .2648 L .60316 .27547 L p
1 g
F P
s
P
p
.002 w
.34273 .36859 m .31353 .40555 L .31247 .38086 L p
1 g
F P
s
P
p
.002 w
.31247 .38086 m .34292 .34158 L .34273 .36859 L p
1 g
F P
s
P
p
.004 w
.28461 .37959 m
.31328 .38637 L
s
P
p
.002 w
.46855 .25829 m .4058 .26996 L .41642 .25551 L p
1 g
F P
s
P
p
.002 w
.41642 .25551 m .47645 .24415 L .46855 .25829 L p
1 g
F P
s
P
p
.002 w
.60316 .27547 m .54164 .25101 L .54505 .24213 L p
1 g
F P
s
P
p
.002 w
.49741 .62106 m .52546 .61465 L .54562 .61851 L p
1 g
F P
s
P
p
.002 w
.57419 .6017 m .54562 .61851 L .52546 .61465 L p
1 g
F P
s
P
p
.002 w
.54562 .61851 m .57419 .6017 L .59784 .59712 L p
1 g
F P
s
P
p
.002 w
.61984 .5683 m .59784 .59712 L .57419 .6017 L p
1 g
F P
s
P
p
.002 w
.59784 .59712 m .61984 .5683 L .64321 .55543 L p
1 g
F P
s
P
p
.002 w
.33212 .45845 m .32398 .49313 L .31125 .47124 L p
1 g
F P
s
P
p
.002 w
.31125 .47124 m .32008 .43168 L .33212 .45845 L p
1 g
F P
s
P
p
.002 w
.65331 .33138 m .68632 .38037 L .68302 .40166 L p
1 g
F P
s
P
p
.002 w
.68632 .38037 m .65331 .33138 L .65273 .31406 L p
1 g
F P
s
P
p
.002 w
.42175 .5937 m .44129 .60366 L .4353 .61223 L p
1 g
F P
s
P
p
.002 w
.4353 .61223 m .40718 .59795 L .42175 .5937 L p
1 g
F P
s
P
p
.002 w
.46635 .62019 m .4353 .61223 L .44129 .60366 L p
1 g
F P
s
P
p
.002 w
.44129 .60366 m .46293 .60919 L .46635 .62019 L p
1 g
F P
s
P
p
.002 w
.49741 .62106 m .46635 .62019 L .46293 .60919 L p
1 g
F P
s
P
p
.002 w
.60316 .27547 m .65273 .31406 L .65331 .33138 L p
1 g
F P
s
P
p
.002 w
.40625 .58028 m .42175 .5937 L .40718 .59795 L p
1 g
F P
s
P
p
.002 w
.40718 .59795 m .38472 .57866 L .40625 .58028 L p
1 g
F P
s
P
p
.002 w
.67423 .4245 m .68566 .47469 L .67129 .49571 L p
1 g
F P
s
P
p
.002 w
.68566 .47469 m .67423 .4245 L .68302 .40166 L p
1 g
F P
s
P
p
.002 w
.46293 .60919 m .4845 .60976 L .49741 .62106 L p
1 g
F P
s
P
p
.002 w
.52546 .61465 m .49741 .62106 L .4845 .60976 L p
1 g
F P
s
P
p
.002 w
.65147 .51539 m .64321 .55543 L .61984 .5683 L p
1 g
F P
s
P
p
.002 w
.64321 .55543 m .65147 .51539 L .67129 .49571 L p
1 g
F P
s
P
p
.002 w
.39214 .31423 m .34292 .34158 L .34763 .31792 L p
1 g
F P
s
P
p
.002 w
.34763 .31792 m .39757 .28966 L .39214 .31423 L p
1 g
F P
s
P
p
.002 w
.3656 .5325 m .37028 .55611 L .34859 .54414 L p
1 g
F P
s
P
p
.002 w
.34859 .54414 m .34222 .51379 L .3656 .5325 L p
1 g
F P
s
P
p
.002 w
.34725 .39815 m .32008 .43168 L .31353 .40555 L p
1 g
F P
s
P
p
.002 w
.31353 .40555 m .34273 .36859 L .34725 .39815 L p
1 g
F P
s
P
p
.004 w
.31328 .38637 m
.33052 .39044 L
s
P
p
.002 w
.53684 .26557 m .46855 .25829 L .47645 .24415 L p
1 g
F P
s
P
p
.002 w
.47645 .24415 m .54164 .25101 L .53684 .26557 L p
1 g
F P
s
P
p
.002 w
.39644 .56471 m .40625 .58028 L .38472 .57866 L p
1 g
F P
s
P
p
.002 w
.38472 .57866 m .37028 .55611 L .39644 .56471 L p
1 g
F P
s
P
p
.002 w
.34944 .48497 m .34222 .51379 L .32398 .49313 L p
1 g
F P
s
P
p
.002 w
.32398 .49313 m .33212 .45845 L .34944 .48497 L p
1 g
F P
s
P
p
.002 w
.52546 .61465 m .54765 .6014 L .57419 .6017 L p
1 g
F P
s
P
p
.002 w
.59234 .57744 m .57419 .6017 L .54765 .6014 L p
1 g
F P
s
P
p
.002 w
.57419 .6017 m .59234 .57744 L .61984 .5683 L p
1 g
F P
s
P
p
.002 w
.65331 .33138 m .60136 .29116 L .60316 .27547 L p
1 g
F P
s
P
p
.002 w
.54164 .25101 m .60316 .27547 L .60136 .29116 L p
1 g
F P
s
P
p
.002 w
.46129 .27811 m .39757 .28966 L .4058 .26996 L p
1 g
F P
s
P
p
.002 w
.4058 .26996 m .46855 .25829 L .46129 .27811 L p
1 g
F P
s
P
p
.002 w
.4845 .60976 m .50387 .60524 L .52546 .61465 L p
1 g
F P
s
P
p
.002 w
.54765 .6014 m .52546 .61465 L .50387 .60524 L p
1 g
F P
s
P
p
.002 w
.64937 .35228 m .68302 .40166 L .67423 .4245 L p
1 g
F P
s
P
p
.002 w
.68302 .40166 m .64937 .35228 L .65331 .33138 L p
1 g
F P
s
P
p
.002 w
.60136 .29116 m .53684 .26557 L .54164 .25101 L p
1 g
F P
s
P
p
.002 w
.65997 .4482 m .67129 .49571 L .65147 .51539 L p
1 g
F P
s
P
p
.002 w
.67129 .49571 m .65997 .4482 L .67423 .4245 L p
1 g
F P
s
P
p
.002 w
.4392 .58443 m .44928 .58959 L .44129 .60366 L p
1 g
F P
s
P
p
.002 w
.44129 .60366 m .42175 .5937 L .4392 .58443 L p
1 g
F P
s
P
p
.002 w
.46293 .60919 m .44129 .60366 L .44928 .58959 L p
1 g
F P
s
P
p
.002 w
.62664 .53302 m .61984 .5683 L .59234 .57744 L p
1 g
F P
s
P
p
.002 w
.61984 .5683 m .62664 .53302 L .65147 .51539 L p
1 g
F P
s
P
p
.002 w
.60136 .29116 m .65331 .33138 L .64937 .35228 L p
1 g
F P
s
P
p
.002 w
.44928 .58959 m .46046 .59245 L .46293 .60919 L p
1 g
F P
s
P
p
.002 w
.4845 .60976 m .46293 .60919 L .46046 .59245 L p
1 g
F P
s
P
p
.002 w
.43128 .5775 m .4392 .58443 L .42175 .5937 L p
1 g
F P
s
P
p
.002 w
.42175 .5937 m .40625 .58028 L .43128 .5775 L p
1 g
F P
s
P
p
.002 w
.39347 .54854 m .39644 .56471 L .37028 .55611 L p
1 g
F P
s
P
p
.002 w
.37028 .55611 m .3656 .5325 L .39347 .54854 L p
1 g
F P
s
P
p
.002 w
.38982 .34303 m .34273 .36859 L .34292 .34158 L p
1 g
F P
s
P
p
.002 w
.34292 .34158 m .39214 .31423 L .38982 .34303 L p
1 g
F P
s
P
p
.002 w
.35648 .42931 m .33212 .45845 L .32008 .43168 L p
1 g
F P
s
P
p
.002 w
.32008 .43168 m .34725 .39815 L .35648 .42931 L p
1 g
F P
s
P
p
.002 w
.46046 .59245 m .47158 .59271 L .4845 .60976 L p
1 g
F P
s
P
p
.002 w
.50387 .60524 m .4845 .60976 L .47158 .59271 L p
1 g
F P
s
P
p
.002 w
.37159 .51029 m .3656 .5325 L .34222 .51379 L p
1 g
F P
s
P
p
.002 w
.34222 .51379 m .34944 .48497 L .37159 .51029 L p
1 g
F P
s
P
p
.002 w
.50387 .60524 m .519 .59601 L .54765 .6014 L p
1 g
F P
s
P
p
.002 w
.56146 .5824 m .54765 .6014 L .519 .59601 L p
1 g
F P
s
P
p
.002 w
.54765 .6014 m .56146 .5824 L .59234 .57744 L p
1 g
F P
s
P
p
.002 w
.42635 .5695 m .43128 .5775 L .40625 .58028 L p
1 g
F P
s
P
p
.002 w
.40625 .58028 m .39644 .56471 L .42635 .5695 L p
1 g
F P
s
P
p
.002 w
.53076 .28566 m .46129 .27811 L .46855 .25829 L p
1 g
F P
s
P
p
.002 w
.46855 .25829 m .53684 .26557 L .53076 .28566 L p
1 g
F P
s
P
p
.002 w
.47158 .59271 m .4815 .59033 L .50387 .60524 L p
1 g
F P
s
P
p
.002 w
.519 .59601 m .50387 .60524 L .4815 .59033 L p
1 g
F P
s
P
p
.002 w
.64079 .37623 m .67423 .4245 L .65997 .4482 L p
1 g
F P
s
P
p
.002 w
.67423 .4245 m .64079 .37623 L .64937 .35228 L p
1 g
F P
s
P
p
.002 w
.45498 .30323 m .39214 .31423 L .39757 .28966 L p
1 g
F P
s
P
p
.002 w
.39757 .28966 m .46129 .27811 L .45498 .30323 L p
1 g
F P
s
P
p
.002 w
.64052 .47195 m .65147 .51539 L .62664 .53302 L p
1 g
F P
s
P
p
.002 w
.65147 .51539 m .64052 .47195 L .65997 .4482 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.59752 .54791 m .59234 .57744 L .56146 .5824 L p
1 g
F P
s
P
p
.002 w
.59234 .57744 m .59752 .54791 L .62664 .53302 L p
1 g
F P
s
P
p
.002 w
.64937 .35228 m .59644 .31163 L .60136 .29116 L p
1 g
F P
s
P
p
.002 w
.53684 .26557 m .60136 .29116 L .59644 .31163 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.46816 .53924 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37023 .46099 m .34944 .48497 L .33212 .45845 L p
1 g
F P
s
P
p
.002 w
.33212 .45845 m .35648 .42931 L .37023 .46099 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.42499 .56128 m .42635 .5695 L .39644 .56471 L p
1 g
F P
s
P
p
.002 w
.39644 .56471 m .39347 .54854 L .42499 .56128 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.39082 .37518 m .34725 .39815 L .34273 .36859 L p
1 g
F P
s
P
p
.002 w
.34273 .36859 m .38982 .34303 L .39082 .37518 L p
1 g
F P
s
P
p
.002 w
.59644 .31163 m .53076 .28566 L .53684 .26557 L p
1 g
F P
s
P
p
.002 w
.39787 .53349 m .39347 .54854 L .3656 .5325 L p
1 g
F P
s
P
p
.002 w
.3656 .5325 m .37159 .51029 L .39787 .53349 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.59644 .31163 m .64937 .35228 L .64079 .37623 L p
1 g
F P
s
P
p
.002 w
.44928 .58959 m .4392 .58443 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.46046 .59245 m .44928 .58959 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47158 .59271 m .46046 .59245 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.4815 .59033 m .48914 .58553 L .519 .59601 L p
1 g
F P
s
P
p
.002 w
.5282 .58289 m .519 .59601 L .48914 .58553 L p
1 g
F P
s
P
p
.002 w
.519 .59601 m .5282 .58289 L .56146 .5824 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.4392 .58443 m .43128 .5775 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.4815 .59033 m .47158 .59271 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.56504 .55947 m .56146 .5824 L .5282 .58289 L p
1 g
F P
s
P
p
.002 w
.56146 .5824 m .56504 .55947 L .59752 .54791 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.61641 .4949 m .62664 .53302 L .59752 .54791 L p
1 g
F P
s
P
p
.002 w
.62664 .53302 m .61641 .4949 L .64052 .47195 L p
1 g
F P
s
P
p
.002 w
.43128 .5775 m .42635 .5695 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.62769 .40251 m .65997 .4482 L .64052 .47195 L p
1 g
F P
s
P
p
.002 w
.65997 .4482 m .62769 .40251 L .64079 .37623 L p
1 g
F P
s
P
p
.002 w
.4815 .59033 m .46196 .57276 L p
.47844 .5805 L 1 g
F P
s
P
p
.002 w
.48914 .58553 m .48825 .58609 L p
.47844 .5805 L 1 g
F P
s
P
p
.002 w
.48825 .58609 m .4815 .59033 L p
.47844 .5805 L 1 g
F P
s
P
p
.002 w
.46196 .57276 m .4591 .57019 L .4675 .57448 L p
1 g
F P
s
P
p
.002 w
.4675 .57448 m .47853 .58011 L p
.46196 .57276 L 1 g
F P
s
P
p
.002 w
.47853 .58011 m .48914 .58553 L p
.47736 .57999 L 1 g
F P
s
P
p
.47736 .57999 m .46196 .57276 L .47853 .58011 L 1 g
F
P
p
.002 w
.49164 .58182 m .48914 .58553 L p
.48058 .58029 L 1 g
F P
s
P
p
.48903 .58103 m .48058 .58029 L .47462 .57664 L 1 g
F
P
p
.49164 .58182 m .48058 .58029 L .48903 .58103 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58067 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58067 L .51107 .58063 L 1 g
F
P
p
.002 w
.5282 .58289 m .51048 .58079 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.52915 .57581 m .52861 .57984 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.52861 .57984 m .5282 .58289 L p
.51094 .58067 L 1 g
F P
s
P
p
.51079 .57862 m .49848 .58108 L .50987 .58072 L 1 g
F
P
p
.002 w
.51094 .58067 m .51079 .57862 L p
.50987 .58072 L 1 g
F P
s
P
p
.52075 .57805 m .51094 .58068 L .51945 .57872 L 1 g
F
P
p
.53128 .57265 m .51107 .58063 L .52075 .57805 L 1 g
F
P
p
.51107 .58063 m .51094 .58068 L .52075 .57805 L 1 g
F
P
p
.002 w
.48914 .58553 m .49199 .58129 L p
.5057 .5819 L 1 g
F P
s
P
p
.002 w
.50987 .58072 m .5282 .58289 L p
.49199 .58129 L 1 g
F P
s
P
p
.50987 .58072 m .49578 .58162 L .51094 .58068 L 1 g
F
P
p
.49848 .58108 m .49735 .58131 L .50987 .58072 L 1 g
F
P
p
.49735 .58131 m .49578 .58162 L .50987 .58072 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58103 L p
1 g
F P
s
P
p
.002 w
.49199 .58129 m .49164 .58182 L p
.48903 .58103 L 1 g
F P
s
P
p
.002 w
.48903 .58103 m .48889 .583 L p
.49578 .58162 L 1 g
F P
s
P
p
.51079 .57862 m .48903 .58103 L .49578 .58162 L 1 g
F
P
p
.002 w
.48903 .58103 m .48921 .57862 L p
.47812 .57771 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48914 .58553 m .47092 .57623 L p
.47462 .57664 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46827 .57471 L p
1 g
F P
s
P
p
.002 w
.47092 .57623 m .4675 .57448 L p
.46827 .57471 L 1 g
F P
s
P
p
.48921 .57862 m .46827 .57471 L .47812 .57771 L 1 g
F
P
p
.002 w
.46827 .57471 m .46872 .57265 L p
.4574 .56813 L 1 g
F P
s
P
p
.4574 .56813 m .45744 .56816 L .46827 .57471 L 1 g
F
P
p
.45737 .56812 m .45754 .56824 L .46827 .57471 L 1 g
F
P
p
.002 w
.45813 .56867 m .4591 .57019 L .45307 .56491 L p
1 g
F P
s
P
p
.45727 .56808 m .45761 .56832 L .46827 .57471 L 1 g
F
P
p
.45708 .568 m .4577 .56842 L .46827 .57471 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45076 .56318 L p
1 g
F P
s
P
p
.002 w
.42739 .55371 m .43191 .5491 L p
.45193 .56463 L 1 g
F P
s
P
p
.002 w
.4591 .57019 m .45449 .56779 L p
.45193 .56463 L 1 g
F P
s
P
p
.002 w
.45449 .56779 m .42739 .55371 L p
.45193 .56463 L 1 g
F P
s
P
p
.002 w
.45076 .56318 m .45146 .56129 L p
.44412 .55491 L 1 g
F P
s
P
p
.002 w
.43335 .54763 m .437 .54603 L p
.43823 .54758 L 1 g
F P
s
P
p
.4407 .55387 m .43823 .54758 L .4488 .56075 L 1 g
F
P
p
.43335 .54763 m .43823 .54758 L .4407 .55387 L 1 g
F
P
p
.002 w
.43335 .54763 m .40937 .52126 L p
.43562 .5392 L 1 g
F P
s
P
p
.43925 .54566 m .43512 .53749 L .43514 .53756 L 1 g
F
P
p
.002 w
.43754 .5458 m .43335 .54763 L p
.43562 .5392 L 1 g
F P
s
P
p
.002 w
.43823 .54758 m .43925 .54566 L p
.43514 .53756 L 1 g
F P
s
P
p
.40937 .52126 m .42973 .51897 L .43255 .52866 L 1 g
F
P
p
.43217 .53684 m .43255 .52866 L .43562 .5392 L 1 g
F
P
p
.40937 .52126 m .43255 .52866 L .43217 .53684 L 1 g
F
P
p
.002 w
.43255 .52866 m .43346 .52734 L p
.43314 .51824 L 1 g
F P
s
P
p
.002 w
.43273 .5249 m .42687 .51331 L p
.43302 .52015 L 1 g
F P
s
P
p
.43314 .51824 m .43273 .5249 L .43255 .52866 L 1 g
F
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42687 .51331 m .4335 .5125 L p
.43302 .52015 L 1 g
F P
s
P
p
.43514 .53756 m .43754 .5458 L .43823 .54758 L 1 g
F
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.43562 .5392 m .43255 .52866 L .44225 .54374 L 1 g
F
P
p
.002 w
.42973 .51897 m .43273 .5249 L p
.43255 .52866 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43385 .50945 L p
1 g
F P
s
P
p
.43508 .49889 m .43385 .50945 L .42687 .51331 L 1 g
F
P
p
.002 w
.4335 .5125 m .4323 .51265 L p
.43385 .50945 L 1 g
F P
s
P
p
.002 w
.4323 .51265 m .42687 .51331 L p
.43385 .50945 L 1 g
F P
s
P
p
.002 w
.43385 .50945 m .43485 .50826 L p
.43803 .50083 L 1 g
F P
s
P
p
.43346 .52734 m .43385 .50945 L .43344 .51305 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44848 .51067 m .4335 .5125 L p
.43385 .50945 L 1 g
F P
s
P
p
.43508 .49889 m .43781 .50129 L .43385 .50945 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44265 .49129 L p
1 g
F P
s
P
p
.43485 .50826 m .44265 .49129 L .43803 .50083 L 1 g
F
P
p
.43781 .50129 m .44848 .51067 L .43385 .50945 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44265 .49129 m .44339 .4905 L p
.45035 .48383 L 1 g
F P
s
P
p
.4507 .4835 m .47172 .51374 L .44641 .48765 L 1 g
F
P
p
.002 w
.47967 .48021 m .47172 .51374 L p
.4507 .4835 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45708 .47731 m .47967 .48021 L p
.4507 .4835 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45765 .47675 L p
1 g
F P
s
P
p
.002 w
.45765 .47675 m .45698 .47747 L p
.45233 .48194 L 1 g
F P
s
P
p
.44339 .4905 m .45765 .47675 L .45233 .48194 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.44535 .4758 m .44389 .43917 L p
.46792 .46673 L 1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47967 .48021 m .45708 .47731 L p
.45765 .47675 L 1 g
F P
s
P
p
.47103 .47029 m .47967 .48021 L .45765 .47675 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.44389 .43917 m .48836 .44473 L .48358 .46424 L p
1 g
F P
s
P
p
.47103 .47029 m .47758 .46713 L .47967 .48021 L 1 g
F
P
p
.002 w
.48305 .46642 m .47967 .48021 L p
.47758 .46713 L 1 g
F P
s
P
p
.002 w
.51234 .49274 m .47967 .48021 L .48305 .46642 L p
1 g
F P
s
P
p
.49801 .46405 m .51234 .49274 L .48305 .46642 L 1 g
F
P
p
.002 w
.47758 .46713 m .47786 .46667 L p
.49321 .46511 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53933 .51181 m .51234 .49274 L .52605 .46897 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54219 .47657 L p
1 g
F P
s
P
p
.52214 .46667 m .54219 .47657 L .5324 .47196 L 1 g
F
P
p
.53251 .47201 m .53933 .51181 L .52605 .46897 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56577 .509 L p
1 g
F P
s
P
p
.56536 .48596 m .57344 .52531 L .56577 .509 L 1 g
F
P
p
.56432 .49244 m .56577 .509 L .56271 .5025 L 1 g
F
P
p
.56536 .48596 m .56577 .509 L .56432 .49244 L 1 g
F
P
p
.002 w
.56577 .509 m .56515 .50826 L p
.56644 .51663 L 1 g
F P
s
P
p
.55661 .4905 m .56577 .509 L .5612 .49927 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56504 .55947 m .56146 .54782 L p
.58842 .51619 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .5473 L p
1 g
F P
s
P
p
.56654 .52734 m .56162 .5473 L .56173 .54697 L 1 g
F
P
p
.58842 .51619 m .56146 .54782 L .56162 .5473 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5675 .52874 L p
1 g
F P
s
P
p
.56515 .50826 m .5675 .52874 L .56747 .5284 L 1 g
F
P
p
.002 w
.57344 .52531 m .56752 .52891 L p
.5675 .52874 L 1 g
F P
s
P
p
.56577 .509 m .57005 .51809 L .5675 .52874 L 1 g
F
P
p
.57005 .51809 m .57344 .52531 L .5675 .52874 L 1 g
F
P
p
.002 w
.56745 .52895 m .56752 .52891 L p
.56162 .5473 L 1 g
F P
s
P
p
.56773 .53806 m .56162 .5473 L .56752 .52891 L 1 g
F
P
p
.002 w
.57801 .52252 m .58842 .51619 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56287 .54813 L p
.56654 .52734 L 1 g
F P
s
P
p
.002 w
.5675 .52874 m .56654 .52734 L p
.56287 .54813 L 1 g
F P
s
P
p
.56644 .51663 m .56751 .52876 L .56737 .52268 L 1 g
F
P
p
.56515 .50826 m .56747 .5284 L .56644 .51663 L 1 g
F
P
p
.56747 .5284 m .56751 .52876 L .56644 .51663 L 1 g
F
P
p
.56654 .52734 m .56164 .54733 L .56409 .54074 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56577 .509 m .5675 .52874 L .55752 .535 L 1 g
F
P
p
.002 w
.56752 .52891 m .56745 .52895 L p
.5675 .52874 L 1 g
F P
s
P
p
.002 w
.56745 .52895 m .55752 .535 L p
.5675 .52874 L 1 g
F P
s
P
p
.002 w
.56752 .52891 m .57801 .52252 L p
.56773 .53806 L 1 g
F P
s
P
p
.002 w
.56287 .54813 m .56854 .53025 L .5675 .52874 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56271 .5025 m .56577 .509 L .55752 .535 L 1 g
F
P
p
.002 w
.5675 .52874 m .56751 .52876 L p
.56747 .5284 L 1 g
F P
s
P
p
.002 w
.56751 .52876 m .56854 .53025 L p
.56737 .52268 L 1 g
F P
s
P
p
.002 w
.56162 .5473 m .56075 .54566 L p
.55557 .55505 L 1 g
F P
s
P
p
.55557 .55505 m .5614 .54763 L .56162 .5473 L 1 g
F
P
p
.002 w
.55639 .56139 m .54935 .56296 L p
.56146 .54782 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53175 .57478 L p
1 g
F P
s
P
p
.002 w
.5282 .58289 m .52904 .57659 L p
.53834 .57216 L 1 g
F P
s
P
p
.56504 .55947 m .55624 .56506 L .53834 .57216 L 1 g
F
P
p
.55624 .56506 m .5282 .58289 L .53834 .57216 L 1 g
F
P
p
.5282 .58289 m .49033 .58545 L .5057 .5819 L 1 g
F
P
p
.002 w
.53175 .57478 m .53128 .57265 L p
.51136 .58287 L 1 g
F P
s
P
p
.54854 .56129 m .53175 .57478 L .54057 .56889 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54948 .56293 m .56504 .55947 L p
.54298 .56996 L 1 g
F P
s
P
p
.54298 .56996 m .52904 .57659 L .54922 .56311 L 1 g
F
P
p
.54298 .56996 m .54922 .56311 L .54948 .56293 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54922 .56311 L p
1 g
F P
s
P
p
.56146 .54782 m .54935 .56296 L .56106 .54806 L 1 g
F
P
p
.56075 .54566 m .54922 .56311 L .55405 .55781 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54922 .56311 L p
1 g
F P
s
P
p
.002 w
.54922 .56311 m .54854 .56129 L p
.54057 .56889 L 1 g
F P
s
P
p
.54057 .56889 m .5322 .57686 L .54922 .56311 L 1 g
F
P
p
.002 w
.52904 .57659 m .5303 .56721 L .54935 .56296 L p
1 g
F P
s
P
p
.002 w
.54935 .56296 m .54948 .56293 L p
.54922 .56311 L 1 g
F P
s
P
p
.54922 .56311 m .52904 .57659 L .54935 .56296 L 1 g
F
P
p
.002 w
.54922 .56311 m .54998 .56518 L p
.55405 .55781 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53175 .57478 L p
1 g
F P
s
P
p
.51136 .58287 m .51111 .583 L .53175 .57478 L 1 g
F
P
p
.002 w
.53175 .57478 m .5322 .57686 L p
.54057 .56889 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54935 .56296 m .5303 .56721 L p
.56106 .54806 L 1 g
F P
s
P
p
.002 w
.55752 .535 m .56745 .52895 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56146 .54782 m .5614 .54763 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.5614 .54763 m .55752 .535 L p
.56162 .5473 L 1 g
F P
s
P
p
.002 w
.56146 .54782 m .56504 .55947 L .55639 .56139 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56164 .54733 L p
1 g
F P
s
P
p
.002 w
.56164 .54733 m .56162 .5473 L p
.56142 .54761 L 1 g
F P
s
P
p
.002 w
.5614 .54763 m .56146 .54782 L p
.56106 .54806 L 1 g
F P
s
P
p
.56142 .54761 m .54998 .56518 L .56164 .54733 L 1 g
F
P
p
.55557 .55505 m .55096 .5634 L .5614 .54763 L 1 g
F
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55752 .535 m .5614 .54763 L p
.5303 .56721 L 1 g
F P
s
P
p
.5614 .54763 m .56106 .54806 L .5303 .56721 L 1 g
F
P
p
.55096 .5634 m .54998 .56518 L .56162 .5473 L 1 g
F
P
p
.002 w
.56162 .5473 m .56164 .54733 L p
.56173 .54697 L 1 g
F P
s
P
p
.002 w
.56164 .54733 m .56257 .5491 L p
.56409 .54074 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56577 .509 L p
1 g
F P
s
P
p
.56644 .51663 m .56854 .53025 L .56577 .509 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.55661 .4905 m .5612 .49927 L .55825 .49302 L 1 g
F
P
p
.002 w
.55742 .49137 m .55661 .4905 L p
.55825 .49302 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55742 .49137 L p
1 g
F P
s
P
p
.54219 .47657 m .55087 .485 L .53933 .51181 L 1 g
F
P
p
.002 w
.56431 .48699 m .55868 .49259 L p
.55243 .48139 L 1 g
F P
s
P
p
.002 w
.55868 .49259 m .55825 .49302 L p
.55742 .49137 L 1 g
F P
s
P
p
.55243 .48139 m .55868 .49259 L .55742 .49137 L 1 g
F
P
p
.54174 .47608 m .55742 .49137 L .54841 .48261 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55825 .49302 m .53933 .51181 L p
.55243 .48139 L 1 g
F P
s
P
p
.002 w
.55753 .49147 m .55742 .49137 L p
.55825 .49302 L 1 g
F P
s
P
p
.002 w
.55825 .49302 m .56536 .48596 L p
.56271 .5025 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55753 .49147 L p
1 g
F P
s
P
p
.5612 .49927 m .56713 .51061 L .55753 .49147 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54219 .47657 L p
1 g
F P
s
P
p
.002 w
.54219 .47657 m .54174 .47608 L p
.54841 .48261 L 1 g
F P
s
P
p
.54841 .48261 m .55834 .49233 L .54219 .47657 L 1 g
F
P
p
.002 w
.55742 .49137 m .55834 .49233 L p
.54841 .48261 L 1 g
F P
s
P
p
.53251 .47201 m .54219 .47657 L .53933 .51181 L 1 g
F
P
p
.54219 .47657 m .55243 .48139 L .55087 .485 L 1 g
F
P
p
.002 w
.55752 .535 m .53933 .51181 L .55825 .49302 L p
1 g
F P
s
P
p
.56271 .5025 m .55752 .535 L .55825 .49302 L 1 g
F
P
p
.002 w
.56577 .509 m .56713 .51061 L p
.5612 .49927 L 1 g
F P
s
P
p
.002 w
.56536 .48596 m .58842 .51619 L .57344 .52531 L p
1 g
F P
s
P
p
.53188 .47171 m .54293 .47738 L .54037 .4761 L 1 g
F
P
p
.52214 .46667 m .5324 .47196 L .53188 .47171 L 1 g
F
P
p
.5324 .47196 m .54293 .47738 L .53188 .47171 L 1 g
F
P
p
.002 w
.53063 .46103 m .56536 .48596 L .56431 .48699 L p
1 g
F P
s
P
p
.53063 .46103 m .56431 .48699 L .53251 .47201 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52605 .46897 m .51234 .49274 L p
.51324 .46576 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .50841 .46502 L 1 g
F
P
p
.51334 .46263 m .52244 .46717 L .51324 .46576 L 1 g
F
P
p
.52244 .46717 m .52605 .46897 L .51324 .46576 L 1 g
F
P
p
.49801 .46405 m .50054 .46381 L .51234 .49274 L 1 g
F
P
p
.002 w
.5 .46373 m .5 .4634 L p
.50841 .46502 L 1 g
F P
s
P
p
.50054 .46381 m .51334 .46263 L .51324 .46576 L 1 g
F
P
p
.50054 .46381 m .51324 .46576 L .51234 .49274 L 1 g
F
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.52665 .4595 m .53063 .46103 L p
.49801 .46405 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46373 L p
1 g
F P
s
P
p
.50841 .46502 m .52282 .46778 L .5 .46373 L 1 g
F
P
p
.002 w
.52244 .46717 m .52282 .46778 L p
.50841 .46502 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52605 .46897 m .53063 .46103 L p
.53251 .47201 L 1 g
F P
s
P
p
.002 w
.54219 .47657 m .54293 .47738 L p
.5324 .47196 L 1 g
F P
s
P
p
.002 w
.54293 .47738 m .54302 .47747 L p
.54037 .4761 L 1 g
F P
s
P
p
.002 w
.53063 .46103 m .52605 .46897 L p
.51334 .46263 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46373 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46373 L .48974 .46536 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48836 .44473 m .52665 .4595 L p
.49801 .46405 L 1 g
F P
s
P
p
.002 w
.5 .46373 m .5 .46423 L p
.48974 .46536 L 1 g
F P
s
P
p
.002 w
.5 .46423 m .5 .46442 L p
.49321 .46511 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46423 L .49321 .46511 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47758 .46713 L p
1 g
F P
s
P
p
.44389 .43917 m .48358 .46424 L .47758 .46713 L 1 g
F
P
p
.45826 .47608 m .47758 .46713 L .46678 .47234 L 1 g
F
P
p
.46922 .46822 m .47758 .46713 L .47103 .47029 L 1 g
F
P
p
.44389 .43917 m .47758 .46713 L .46922 .46822 L 1 g
F
P
p
.002 w
.48305 .46642 m .48836 .44473 L p
.49801 .46405 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47747 .46731 L p
1 g
F P
s
P
p
.002 w
.47747 .46731 m .47758 .46713 L p
.48184 .46662 L 1 g
F P
s
P
p
.48184 .46662 m .5 .46442 L .47747 .46731 L 1 g
F
P
p
.49321 .46511 m .5 .46442 L .47758 .46713 L 1 g
F
P
p
.002 w
.48358 .46424 m .48305 .46642 L p
.47758 .46713 L 1 g
F P
s
P
p
.002 w
.47758 .46713 m .47718 .46778 L p
.46678 .47234 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47675 L p
1 g
F P
s
P
p
.002 w
.45765 .47675 m .45826 .47608 L p
.46678 .47234 L 1 g
F P
s
P
p
.46678 .47234 m .47718 .46778 L .45765 .47675 L 1 g
F
P
p
.46792 .46673 m .47103 .47029 L .45765 .47675 L 1 g
F
P
p
.002 w
.45708 .47731 m .44535 .4758 L p
.46792 .46673 L 1 g
F P
s
P
p
.002 w
.44535 .4758 m .45708 .47731 L p
.4507 .4835 L 1 g
F P
s
P
p
.002 w
.47172 .51374 m .44848 .51067 L .44641 .48765 L p
1 g
F P
s
P
p
.002 w
.44641 .48765 m .44848 .51067 L p
.43492 .49875 L 1 g
F P
s
P
p
.002 w
.44265 .49129 m .44166 .49233 L p
.43803 .50083 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44248 .49147 L p
1 g
F P
s
P
p
.002 w
.44248 .49147 m .44265 .49129 L p
.44502 .489 L 1 g
F P
s
P
p
.44502 .489 m .45698 .47747 L .44248 .49147 L 1 g
F
P
p
.45035 .48383 m .45247 .4818 L .44641 .48765 L 1 g
F
P
p
.45035 .48383 m .44641 .48765 L .44265 .49129 L 1 g
F
P
p
.002 w
.44641 .48765 m .44535 .4758 L p
.4507 .4835 L 1 g
F P
s
P
p
.002 w
.41356 .47997 m .44535 .4758 L .44641 .48765 L p
1 g
F P
s
P
p
.41356 .47997 m .44641 .48765 L .43492 .49875 L 1 g
F
P
p
.45247 .4818 m .45698 .47747 L .44265 .49129 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43385 .50945 L p
1 g
F P
s
P
p
.43803 .50083 m .44166 .49233 L .43385 .50945 L 1 g
F
P
p
.002 w
.43385 .50945 m .43343 .50995 L p
.43344 .51305 L 1 g
F P
s
P
p
.002 w
.42687 .51331 m .41356 .47997 L p
.43508 .49889 L 1 g
F P
s
P
p
.43346 .52734 m .43343 .50995 L .4331 .517 L 1 g
F
P
p
.002 w
.43273 .5249 m .44225 .54374 L p
.43255 .52866 L 1 g
F P
s
P
p
.002 w
.43343 .50995 m .43287 .51061 L p
.4331 .517 L 1 g
F P
s
P
p
.002 w
.44848 .51067 m .45313 .5425 L p
.43302 .52015 L 1 g
F P
s
P
p
.002 w
.4335 .5125 m .44848 .51067 L p
.43302 .52015 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43249 .52876 L p
1 g
F P
s
P
p
.002 w
.43249 .52876 m .43255 .52866 L p
.43257 .52737 L 1 g
F P
s
P
p
.43257 .52737 m .43287 .51061 L .43249 .52876 L 1 g
F
P
p
.43314 .51824 m .4331 .517 L .43273 .5249 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45313 .5425 m .44225 .54374 L .43273 .5249 L p
1 g
F P
s
P
p
.43302 .52015 m .45313 .5425 L .43273 .5249 L 1 g
F
P
p
.4331 .517 m .43287 .51061 L .43255 .52866 L 1 g
F
P
p
.43514 .53756 m .43151 .53039 L .43754 .5458 L 1 g
F
P
p
.002 w
.40937 .52126 m .42687 .51331 L .42973 .51897 L p
1 g
F P
s
P
p
.002 w
.44225 .54374 m .43754 .5458 L p
.43562 .5392 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43151 .53039 L p
.43514 .53756 L 1 g
F P
s
P
p
.43512 .53749 m .43146 .53025 L .43514 .53756 L 1 g
F
P
p
.44412 .55491 m .44993 .56215 L .45076 .56318 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.437 .54603 m .44225 .54374 L p
.4488 .56075 L 1 g
F P
s
P
p
.002 w
.43151 .53039 m .43743 .5491 L .43823 .54758 L p
1 g
F P
s
P
p
.46872 .57265 m .45076 .56318 L .45736 .56811 L 1 g
F
P
p
.002 w
.45307 .56491 m .44993 .56215 L p
.45813 .56867 L 1 g
F P
s
P
p
.002 w
.44993 .56215 m .43335 .54763 L p
.4488 .56075 L 1 g
F P
s
P
p
.4488 .56075 m .45813 .56867 L .44993 .56215 L 1 g
F
P
p
.002 w
.43191 .5491 m .43335 .54763 L .44993 .56215 L p
1 g
F P
s
P
p
.002 w
.44993 .56215 m .45307 .56491 L p
.45076 .56318 L 1 g
F P
s
P
p
.43191 .5491 m .44993 .56215 L .45076 .56318 L 1 g
F
P
p
.002 w
.45307 .56491 m .4591 .57019 L p
.43191 .5491 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45075 .56319 L p
1 g
F P
s
P
p
.002 w
.45075 .56319 m .45076 .56318 L p
.45071 .56313 L 1 g
F P
s
P
p
.45071 .56313 m .43743 .5491 L .45075 .56319 L 1 g
F
P
p
.44412 .55491 m .44396 .55477 L .44993 .56215 L 1 g
F
P
p
.002 w
.44225 .54374 m .45813 .56867 L p
.4488 .56075 L 1 g
F P
s
P
p
.44396 .55477 m .43743 .5491 L .45076 .56318 L 1 g
F
P
p
.002 w
.45076 .56318 m .45002 .56518 L p
.45736 .56811 L 1 g
F P
s
P
p
.4574 .56813 m .45737 .56812 L .45744 .56816 L 1 g
F
P
p
.45737 .56812 m .45727 .56808 L .45754 .56824 L 1 g
F
P
p
.002 w
.45889 .56923 m .4591 .57019 L .45813 .56867 L p
1 g
F P
s
P
p
.45681 .56789 m .45789 .5686 L .46827 .57471 L 1 g
F
P
p
.002 w
.45925 .56948 m .4591 .57019 L .45889 .56923 L p
1 g
F P
s
P
p
.45643 .56774 m .45831 .56892 L .46827 .57471 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44225 .54374 m .45313 .5425 L .45889 .56923 L p
1 g
F P
s
P
p
.002 w
.45813 .56867 m .44225 .54374 L p
.45889 .56923 L 1 g
F P
s
P
p
.45599 .56756 m .45923 .56951 L .46827 .57471 L 1 g
F
P
p
.002 w
.45313 .5425 m .46479 .54407 L .45925 .56948 L p
1 g
F P
s
P
p
.002 w
.45889 .56923 m .45313 .5425 L p
.45925 .56948 L 1 g
F P
s
P
p
.45727 .56808 m .45708 .568 L .45761 .56832 L 1 g
F
P
p
.45708 .568 m .45681 .56789 L .4577 .56842 L 1 g
F
P
p
.002 w
.46479 .54407 m .47589 .54829 L .45951 .56966 L p
1 g
F P
s
P
p
.002 w
.45951 .56966 m .4591 .57019 L .45925 .56948 L p
1 g
F P
s
P
p
.002 w
.45925 .56948 m .46479 .54407 L p
.45951 .56966 L 1 g
F P
s
P
p
.002 w
.45974 .56981 m .4591 .57019 L .45951 .56966 L p
1 g
F P
s
P
p
.45553 .56738 m .4613 .57074 L .46827 .57471 L 1 g
F
P
p
.002 w
.47589 .54829 m .48518 .55467 L .45974 .56981 L p
1 g
F P
s
P
p
.002 w
.45951 .56966 m .47589 .54829 L p
.45974 .56981 L 1 g
F P
s
P
p
.45681 .56789 m .45643 .56774 L .45789 .5686 L 1 g
F
P
p
.45643 .56774 m .45599 .56756 L .45831 .56892 L 1 g
F
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48518 .55467 m .49163 .56247 L .46 .56997 L p
1 g
F P
s
P
p
.002 w
.46 .56997 m .4591 .57019 L .45974 .56981 L p
1 g
F P
s
P
p
.002 w
.45974 .56981 m .48518 .55467 L p
.46 .56997 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.49163 .56247 m .49455 .57082 L .4604 .57021 L p
1 g
F P
s
P
p
.002 w
.4604 .57021 m .4591 .57019 L .46 .56997 L p
1 g
F P
s
P
p
.002 w
.46 .56997 m .49163 .56247 L p
.4604 .57021 L 1 g
F P
s
P
p
.45599 .56756 m .45553 .56738 L .45923 .56951 L 1 g
F
P
p
.45553 .56738 m .45517 .56724 L .4613 .57074 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.49455 .57082 m .49367 .5788 L .4613 .57074 L p
1 g
F P
s
P
p
.002 w
.4613 .57074 m .4591 .57019 L .4604 .57021 L p
1 g
F P
s
P
p
.002 w
.4604 .57021 m .49455 .57082 L p
.4613 .57074 L 1 g
F P
s
P
p
.002 w
.4613 .57074 m .49367 .5788 L p
.47092 .57623 L 1 g
F P
s
P
p
.002 w
.46827 .57471 m .4678 .57686 L p
.47812 .57771 L 1 g
F P
s
P
p
.002 w
.4591 .57019 m .4613 .57074 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.4675 .57448 m .4591 .57019 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.49367 .5788 m .49199 .58129 L p
.47462 .57664 L 1 g
F P
s
P
p
.49199 .58129 m .48903 .58103 L .47462 .57664 L 1 g
F
P
p
.52915 .57581 m .51094 .58067 L .49367 .5788 L 1 g
F
P
p
.002 w
.51048 .58079 m .50987 .58072 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.50987 .58072 m .49367 .5788 L p
.51094 .58067 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51094 .58067 L p
.50987 .58072 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.5303 .56721 m .52915 .57581 L p
.49367 .5788 L 1 g
F P
s
P
p
.002 w
.51094 .58067 m .51094 .58068 L p
.51107 .58063 L 1 g
F P
s
P
p
.002 w
.51094 .58068 m .51111 .583 L p
.51945 .57872 L 1 g
F P
s
P
p
.49033 .58545 m .48914 .58553 L .5057 .5819 L 1 g
F
P
p
.002 w
.49199 .58129 m .49367 .5788 L .50987 .58072 L p
1 g
F P
s
P
p
.002 w
.51111 .58296 m .51094 .58068 L p
.49578 .58162 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51111 .58296 L p
1 g
F P
s
P
p
.49578 .58162 m .48889 .583 L .51111 .58296 L 1 g
F
P
p
.002 w
.48902 .58115 m .48903 .58103 L p
.47785 .57769 L 1 g
F P
s
P
p
.47812 .57771 m .47785 .57769 L .48903 .58103 L 1 g
F
P
p
.002 w
.46827 .57472 m .46827 .57471 L p
.455 .56717 L 1 g
F P
s
P
p
.45517 .56724 m .455 .56717 L .46827 .57471 L 1 g
F
P
p
.002 w
.48889 .583 m .48857 .5874 L p
.50995 .58322 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .50767 .583 L p
.50995 .58322 L 1 g
F P
s
P
p
.002 w
.50767 .583 m .48889 .583 L p
.50995 .58322 L 1 g
F P
s
P
p
.002 w
.42635 .5695 m .42499 .56128 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.42499 .56128 m .42739 .55371 L .4591 .57019 L closepath p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57472 L p
1 g
F P
s
P
p
.455 .56717 m .45002 .56518 L .46827 .57472 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58115 L p
1 g
F P
s
P
p
.47785 .57769 m .4678 .57686 L .48902 .58115 L 1 g
F
P
p
.002 w
.38807 .49202 m .37159 .51029 L .34944 .48497 L p
1 g
F P
s
P
p
.002 w
.34944 .48497 m .37023 .46099 L .38807 .49202 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.42739 .55371 m .42499 .56128 L .39347 .54854 L p
1 g
F P
s
P
p
.002 w
.39347 .54854 m .39787 .53349 L .42739 .55371 L p
1 g
F P
s
P
p
.002 w
.44987 .33296 m .38982 .34303 L .39214 .31423 L p
1 g
F P
s
P
p
.002 w
.39214 .31423 m .45498 .30323 L .44987 .33296 L p
1 g
F P
s
P
p
.002 w
.52352 .31085 m .45498 .30323 L .46129 .27811 L p
1 g
F P
s
P
p
.002 w
.46129 .27811 m .53076 .28566 L .52352 .31085 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.3952 .40957 m .35648 .42931 L .34725 .39815 L p
1 g
F P
s
P
p
.002 w
.34725 .39815 m .39082 .37518 L .3952 .40957 L p
1 g
F P
s
P
p
.004 w
.36078 .3976 m
.36354 .39825 L
s
P
p
.004 w
.3947 .40562 m
.5 .43051 L
s
P
p
.004 w
.36354 .39825 m
.36463 .39851 L
s
P
p
.004 w
.33052 .39044 m
.35299 .39576 L
s
P
p
.004 w
.35299 .39576 m
.36078 .3976 L
s
P
p
.002 w
.64079 .37623 m .58841 .33641 L .59644 .31163 L p
1 g
F P
s
P
p
.002 w
.53076 .28566 m .59644 .31163 L .58841 .33641 L p
1 g
F P
s
P
p
.002 w
.58842 .51619 m .59752 .54791 L .56504 .55947 L p
1 g
F P
s
P
p
.002 w
.59752 .54791 m .58842 .51619 L .61641 .4949 L p
1 g
F P
s
P
p
.002 w
.40937 .52126 m .39787 .53349 L .37159 .51029 L p
1 g
F P
s
P
p
.002 w
.37159 .51029 m .38807 .49202 L .40937 .52126 L p
1 g
F P
s
P
p
.002 w
.58841 .33641 m .64079 .37623 L .62769 .40251 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.49367 .5788 m .49455 .57082 L .5303 .56721 L p
1 g
F P
s
P
p
.002 w
.58841 .33641 m .52352 .31085 L .53076 .28566 L p
1 g
F P
s
P
p
.002 w
.61035 .43024 m .64052 .47195 L .61641 .4949 L p
1 g
F P
s
P
p
.002 w
.64052 .47195 m .61035 .43024 L .62769 .40251 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.43335 .54763 m .42739 .55371 L .39787 .53349 L p
1 g
F P
s
P
p
.002 w
.39787 .53349 m .40937 .52126 L .43335 .54763 L p
1 g
F P
s
P
p
.002 w
.40287 .44494 m .37023 .46099 L .35648 .42931 L p
1 g
F P
s
P
p
.002 w
.35648 .42931 m .3952 .40957 L .40287 .44494 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.44622 .36635 m .39082 .37518 L .38982 .34303 L p
1 g
F P
s
P
p
.002 w
.38982 .34303 m .44987 .33296 L .44622 .36635 L p
1 g
F P
s
P
p
.002 w
.49455 .57082 m .49163 .56247 L .52485 .55062 L p
1 g
F P
s
P
p
.002 w
.52485 .55062 m .5303 .56721 L .49455 .57082 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.5303 .56721 m .52485 .55062 L .55752 .535 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.51537 .34044 m .44987 .33296 L .45498 .30323 L p
1 g
F P
s
P
p
.002 w
.45498 .30323 m .52352 .31085 L .51537 .34044 L p
1 g
F P
s
P
p
.002 w
.41356 .47997 m .38807 .49202 L .37023 .46099 L p
1 g
F P
s
P
p
.002 w
.37023 .46099 m .40287 .44494 L .41356 .47997 L p
1 g
F P
s
P
p
.002 w
.58933 .45841 m .61641 .4949 L .58842 .51619 L p
1 g
F P
s
P
p
.002 w
.61641 .4949 m .58933 .45841 L .61035 .43024 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.49163 .56247 m .48518 .55467 L .51226 .535 L p
1 g
F P
s
P
p
.002 w
.51226 .535 m .52485 .55062 L .49163 .56247 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57743 .36478 m .62769 .40251 L .61035 .43024 L p
1 g
F P
s
P
p
.002 w
.62769 .40251 m .57743 .36478 L .58841 .33641 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52352 .31085 m .58841 .33641 L .57743 .36478 L p
1 g
F P
s
P
p
.002 w
.42687 .51331 m .40937 .52126 L .38807 .49202 L p
1 g
F P
s
P
p
.002 w
.38807 .49202 m .41356 .47997 L .42687 .51331 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48518 .55467 m .47589 .54829 L .49385 .52218 L p
1 g
F P
s
P
p
.002 w
.49385 .52218 m .51226 .535 L .48518 .55467 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58842 .51619 m .56536 .48596 L .58933 .45841 L p
1 g
F P
s
P
p
.002 w
.52485 .55062 m .51226 .535 L .53933 .51181 L p
1 g
F P
s
P
p
.002 w
.53933 .51181 m .55752 .535 L .52485 .55062 L p
1 g
F P
s
P
p
.002 w
.44419 .40221 m .3952 .40957 L .39082 .37518 L p
1 g
F P
s
P
p
.002 w
.39082 .37518 m .44622 .36635 L .44419 .40221 L p
1 g
F P
s
P
p
.002 w
.57743 .36478 m .51537 .34044 L .52352 .31085 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46479 .54407 m .45313 .5425 L .44848 .51067 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.47589 .54829 m .46479 .54407 L .47172 .51374 L p
1 g
F P
s
P
p
.002 w
.47172 .51374 m .49385 .52218 L .47589 .54829 L p
1 g
F P
s
P
p
.002 w
.44848 .51067 m .47172 .51374 L .46479 .54407 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56381 .39578 m .61035 .43024 L .58933 .45841 L p
1 g
F P
s
P
p
.002 w
.61035 .43024 m .56381 .39578 L .57743 .36478 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.50656 .37345 m .44622 .36635 L .44987 .33296 L p
1 g
F P
s
P
p
.002 w
.44987 .33296 m .51537 .34044 L .50656 .37345 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44389 .43917 m .40287 .44494 L .3952 .40957 L p
1 g
F P
s
P
p
.002 w
.3952 .40957 m .44419 .40221 L .44389 .43917 L p
1 g
F P
s
P
p
.002 w
.51226 .535 m .49385 .52218 L .51234 .49274 L p
1 g
F P
s
P
p
.002 w
.51234 .49274 m .53933 .51181 L .51226 .535 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.51537 .34044 m .57743 .36478 L .56381 .39578 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44535 .4758 m .41356 .47997 L .40287 .44494 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.40287 .44494 m .44389 .43917 L .44535 .4758 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54802 .42829 m .58933 .45841 L .56536 .48596 L p
1 g
F P
s
P
p
.002 w
.58933 .45841 m .54802 .42829 L .56381 .39578 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.49385 .52218 m .47172 .51374 L .47967 .48021 L p
1 g
F P
s
P
p
.002 w
.47967 .48021 m .51234 .49274 L .49385 .52218 L p
1 g
F P
s
P
p
.002 w
.56381 .39578 m .50656 .37345 L .51537 .34044 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56536 .48596 m .53063 .46103 L .54802 .42829 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49744 .40866 m .44419 .40221 L .44622 .36635 L p
1 g
F P
s
P
p
.002 w
.44622 .36635 m .50656 .37345 L .49744 .40866 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.004 w
.44239 .62725 m
.44536 .61709 L
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.50656 .37345 m .56381 .39578 L .54802 .42829 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.48836 .44473 m .44389 .43917 L .44419 .40221 L p
1 g
F P
s
P
p
.002 w
.44419 .40221 m .49744 .40866 L .48836 .44473 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54802 .42829 m .49744 .40866 L .50656 .37345 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49744 .40866 m .54802 .42829 L .53063 .46103 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53063 .46103 m .48836 .44473 L .49744 .40866 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28234 .37905 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .43514 .65199 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.34186)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.34186)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4441 .42656 m .47615 .45325 L .49127 .42912 L p
1 g
F P
s
P
p
.002 w
.49127 .42912 m .46464 .40681 L .4441 .42656 L p
1 g
F P
s
P
p
.002 w
.52302 .44374 m .49127 .42912 L .47615 .45325 L p
1 g
F P
s
P
p
.002 w
.46464 .40681 m .49127 .42912 L .50659 .40504 L p
1 g
F P
s
P
p
.002 w
.49127 .42912 m .52302 .44374 L .53123 .41636 L p
1 g
F P
s
P
p
.002 w
.53123 .41636 m .50659 .40504 L .49127 .42912 L p
1 g
F P
s
P
p
.002 w
.50659 .40504 m .48598 .38768 L .46464 .40681 L p
1 g
F P
s
P
p
.002 w
.48598 .38768 m .50659 .40504 L .52183 .38144 L p
1 g
F P
s
P
p
.002 w
.50659 .40504 m .53123 .41636 L .53872 .38918 L p
1 g
F P
s
P
p
.002 w
.53872 .38918 m .52183 .38144 L .50659 .40504 L p
1 g
F P
s
P
p
.002 w
.47615 .45325 m .51425 .47084 L .52302 .44374 L p
1 g
F P
s
P
p
.002 w
.55688 .44925 m .52302 .44374 L .51425 .47084 L p
1 g
F P
s
P
p
.002 w
.52302 .44374 m .55688 .44925 L .55749 .42051 L p
1 g
F P
s
P
p
.002 w
.55749 .42051 m .53123 .41636 L .52302 .44374 L p
1 g
F P
s
P
p
.002 w
.42476 .44657 m .46151 .477 L .47615 .45325 L p
1 g
F P
s
P
p
.002 w
.47615 .45325 m .4441 .42656 L .42476 .44657 L p
1 g
F P
s
P
p
.002 w
.51425 .47084 m .47615 .45325 L .46151 .477 L p
1 g
F P
s
P
p
.002 w
.53123 .41636 m .55749 .42051 L .55671 .39194 L p
1 g
F P
s
P
p
.002 w
.55671 .39194 m .53872 .38918 L .53123 .41636 L p
1 g
F P
s
P
p
.002 w
.42115 .39314 m .4441 .42656 L .46464 .40681 L p
1 g
F P
s
P
p
.002 w
.46464 .40681 m .44572 .37888 L .42115 .39314 L p
1 g
F P
s
P
p
.002 w
.44572 .37888 m .46464 .40681 L .48598 .38768 L p
1 g
F P
s
P
p
.002 w
.46151 .477 m .50506 .49716 L .51425 .47084 L p
1 g
F P
s
P
p
.002 w
.55488 .47765 m .51425 .47084 L .50506 .49716 L p
1 g
F P
s
P
p
.002 w
.51425 .47084 m .55488 .47765 L .55688 .44925 L p
1 g
F P
s
P
p
.002 w
.48598 .38768 m .47147 .36595 L .44572 .37888 L p
1 g
F P
s
P
p
.002 w
.47147 .36595 m .48598 .38768 L .50775 .36952 L p
1 g
F P
s
P
p
.002 w
.52183 .38144 m .50775 .36952 L .48598 .38768 L p
1 g
F P
s
P
p
.002 w
.50775 .36952 m .52183 .38144 L .53672 .35877 L p
1 g
F P
s
P
p
.002 w
.52183 .38144 m .53872 .38918 L .54535 .36271 L p
1 g
F P
s
P
p
.002 w
.54535 .36271 m .53672 .35877 L .52183 .38144 L p
1 g
F P
s
P
p
.002 w
.39825 .40848 m .42476 .44657 L .4441 .42656 L p
1 g
F P
s
P
p
.002 w
.4441 .42656 m .42115 .39314 L .39825 .40848 L p
1 g
F P
s
P
p
.002 w
.53872 .38918 m .55671 .39194 L .55453 .36407 L p
1 g
F P
s
P
p
.002 w
.55453 .36407 m .54535 .36271 L .53872 .38918 L p
1 g
F P
s
P
p
.002 w
.58278 .41698 m .55749 .42051 L .55688 .44925 L p
1 g
F P
s
P
p
.002 w
.55749 .42051 m .58278 .41698 L .57396 .38938 L p
1 g
F P
s
P
p
.002 w
.57396 .38938 m .55671 .39194 L .55749 .42051 L p
1 g
F P
s
P
p
.002 w
.58959 .44497 m .55688 .44925 L .55488 .47765 L p
1 g
F P
s
P
p
.002 w
.55688 .44925 m .58959 .44497 L .58278 .41698 L p
1 g
F P
s
P
p
.002 w
.40699 .46647 m .44761 .49993 L .46151 .477 L p
1 g
F P
s
P
p
.002 w
.46151 .477 m .42476 .44657 L .40699 .46647 L p
1 g
F P
s
P
p
.002 w
.50506 .49716 m .46151 .477 L .44761 .49993 L p
1 g
F P
s
P
p
.002 w
.50775 .36952 m .49792 .35459 L .47147 .36595 L p
1 g
F P
s
P
p
.002 w
.49792 .35459 m .50775 .36952 L .52955 .35266 L p
1 g
F P
s
P
p
.002 w
.53672 .35877 m .52955 .35266 L .50775 .36952 L p
1 g
F P
s
P
p
.002 w
.44761 .49993 m .49562 .52221 L .50506 .49716 L p
1 g
F P
s
P
p
.002 w
.55151 .50517 m .50506 .49716 L .49562 .52221 L p
1 g
F P
s
P
p
.002 w
.50506 .49716 m .55151 .50517 L .55488 .47765 L p
1 g
F P
s
P
p
.002 w
.55671 .39194 m .57396 .38938 L .5633 .3627 L p
1 g
F P
s
P
p
.002 w
.5633 .3627 m .55453 .36407 L .55671 .39194 L p
1 g
F P
s
P
p
.002 w
.43655 .34793 m .44572 .37888 L .47147 .36595 L p
1 g
F P
s
P
p
.002 w
.47147 .36595 m .46462 .34195 L .43655 .34793 L p
1 g
F P
s
P
p
.002 w
.46462 .34195 m .47147 .36595 L .49792 .35459 L p
1 g
F P
s
P
p
.002 w
.59425 .47283 m .55488 .47765 L .55151 .50517 L p
1 g
F P
s
P
p
.002 w
.55488 .47765 m .59425 .47283 L .58959 .44497 L p
1 g
F P
s
P
p
.002 w
.40976 .35603 m .42115 .39314 L .44572 .37888 L p
1 g
F P
s
P
p
.002 w
.44572 .37888 m .43655 .34793 L .40976 .35603 L p
1 g
F P
s
P
p
.002 w
.49792 .35459 m .49341 .33817 L .46462 .34195 L p
1 g
F P
s
P
p
.002 w
.49341 .33817 m .49792 .35459 L .52459 .34502 L p
1 g
F P
s
P
p
.002 w
.52955 .35266 m .52459 .34502 L .49792 .35459 L p
1 g
F P
s
P
p
.002 w
.3775 .42464 m .40699 .46647 L .42476 .44657 L p
1 g
F P
s
P
p
.002 w
.42476 .44657 m .39825 .40848 L .3775 .42464 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .52955 .35266 L .53672 .35877 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .53672 .35877 L .54535 .36271 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .54535 .36271 L .55453 .36407 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .52459 .34502 L .52955 .35266 L closepath p
1 g
F P
s
P
p
.002 w
.6045 .40597 m .58278 .41698 L .58959 .44497 L p
1 g
F P
s
P
p
.002 w
.58278 .41698 m .6045 .40597 L .58868 .3817 L p
1 g
F P
s
P
p
.002 w
.58868 .3817 m .57396 .38938 L .58278 .41698 L p
1 g
F P
s
P
p
.002 w
.57396 .38938 m .58868 .3817 L .57072 .35872 L p
1 g
F P
s
P
p
.002 w
.57072 .35872 m .5633 .3627 L .57396 .38938 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .55453 .36407 L .5633 .3627 L closepath p
1 g
F P
s
P
p
.002 w
.39117 .48588 m .43473 .52159 L .44761 .49993 L p
1 g
F P
s
P
p
.002 w
.44761 .49993 m .40699 .46647 L .39117 .48588 L p
1 g
F P
s
P
p
.002 w
.49562 .52221 m .44761 .49993 L .43473 .52159 L p
1 g
F P
s
P
p
.002 w
.38482 .36611 m .39825 .40848 L .42115 .39314 L p
1 g
F P
s
P
p
.002 w
.42115 .39314 m .40976 .35603 L .38482 .36611 L p
1 g
F P
s
P
p
.002 w
.52459 .34502 m .52238 .33666 L .49341 .33817 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .52238 .33666 L .52459 .34502 L closepath p
1 g
F P
s
P
p
.002 w
.49562 .52221 m .54682 .53128 L .55151 .50517 L p
1 g
F P
s
P
p
.002 w
.59662 .50001 m .55151 .50517 L .54682 .53128 L p
1 g
F P
s
P
p
.002 w
.55151 .50517 m .59662 .50001 L .59425 .47283 L p
1 g
F P
s
P
p
.002 w
.61786 .43104 m .58959 .44497 L .59425 .47283 L p
1 g
F P
s
P
p
.002 w
.58959 .44497 m .61786 .43104 L .6045 .40597 L p
1 g
F P
s
P
p
.002 w
.43473 .52159 m .48611 .54548 L .49562 .52221 L p
1 g
F P
s
P
p
.002 w
.54682 .53128 m .49562 .52221 L .48611 .54548 L p
1 g
F P
s
P
p
.002 w
.46633 .31811 m .46462 .34195 L .49341 .33817 L p
1 g
F P
s
P
p
.002 w
.49341 .33817 m .49478 .32195 L .46633 .31811 L p
1 g
F P
s
P
p
.002 w
.49478 .32195 m .49341 .33817 L .52238 .33666 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .5633 .3627 L .57072 .35872 L closepath p
1 g
F P
s
P
p
.002 w
.43839 .31703 m .43655 .34793 L .46462 .34195 L p
1 g
F P
s
P
p
.002 w
.46462 .34195 m .46633 .31811 L .43839 .31703 L p
1 g
F P
s
P
p
.002 w
.52238 .33666 m .52318 .32845 L .49478 .32195 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .52318 .32845 L .52238 .33666 L closepath p
1 g
F P
s
P
p
.002 w
.35937 .4413 m .39117 .48588 L .40699 .46647 L p
1 g
F P
s
P
p
.002 w
.40699 .46647 m .3775 .42464 L .35937 .4413 L p
1 g
F P
s
P
p
.002 w
.57599 .35253 m .57072 .35872 L .58868 .3817 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .57072 .35872 L .57599 .35253 L closepath p
1 g
F P
s
P
p
.002 w
.59924 .36962 m .58868 .3817 L .6045 .40597 L p
1 g
F P
s
P
p
.002 w
.58868 .3817 m .59924 .36962 L .57599 .35253 L p
1 g
F P
s
P
p
.002 w
.62845 .45644 m .59425 .47283 L .59662 .50001 L p
1 g
F P
s
P
p
.002 w
.59425 .47283 m .62845 .45644 L .61786 .43104 L p
1 g
F P
s
P
p
.002 w
.36227 .37804 m .3775 .42464 L .39825 .40848 L p
1 g
F P
s
P
p
.002 w
.39825 .40848 m .38482 .36611 L .36227 .37804 L p
1 g
F P
s
P
p
.002 w
.41154 .3188 m .40976 .35603 L .43655 .34793 L p
1 g
F P
s
P
p
.002 w
.43655 .34793 m .43839 .31703 L .41154 .3188 L p
1 g
F P
s
P
p
.002 w
.50201 .30767 m .49478 .32195 L .52318 .32845 L p
1 g
F P
s
P
p
.002 w
.52318 .32845 m .52694 .32128 L .50201 .30767 L p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .52694 .32128 L .52318 .32845 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .53327 .31594 L .52694 .32128 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .57599 .35253 L .5785 .34478 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .5785 .34478 L .57797 .33629 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .57797 .33629 L .5744 .32801 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .5744 .32801 L .56819 .32086 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .56819 .32086 L .56 .31563 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .56 .31563 L .55077 .31293 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .55077 .31293 L .54151 .31304 L closepath p
1 g
F P
s
P
p
.002 w
.55097 .33745 m .54151 .31304 L .53327 .31594 L closepath p
1 g
F P
s
P
p
.002 w
.62026 .38841 m .6045 .40597 L .61786 .43104 L p
1 g
F P
s
P
p
.002 w
.6045 .40597 m .62026 .38841 L .59924 .36962 L p
1 g
F P
s
P
p
.002 w
.47669 .29697 m .46633 .31811 L .49478 .32195 L p
1 g
F P
s
P
p
.002 w
.49478 .32195 m .50201 .30767 L .47669 .29697 L p
1 g
F P
s
P
p
.002 w
.5785 .34478 m .57599 .35253 L .59924 .36962 L p
1 g
F P
s
P
p
.002 w
.48611 .54548 m .54085 .55541 L .54682 .53128 L p
1 g
F P
s
P
p
.002 w
.59662 .52596 m .54682 .53128 L .54085 .55541 L p
1 g
F P
s
P
p
.002 w
.54682 .53128 m .59662 .52596 L .59662 .50001 L p
1 g
F P
s
P
p
.002 w
.37769 .50439 m .42318 .5415 L .43473 .52159 L p
1 g
F P
s
P
p
.002 w
.43473 .52159 m .39117 .48588 L .37769 .50439 L p
1 g
F P
s
P
p
.002 w
.48611 .54548 m .43473 .52159 L .42318 .5415 L p
1 g
F P
s
P
p
.002 w
.51444 .29695 m .50201 .30767 L .52694 .32128 L p
1 g
F P
s
P
p
.002 w
.52694 .32128 m .53327 .31594 L .51444 .29695 L p
1 g
F P
s
P
p
.002 w
.42318 .5415 m .4767 .56645 L .48611 .54548 L p
1 g
F P
s
P
p
.002 w
.54085 .55541 m .48611 .54548 L .4767 .56645 L p
1 g
F P
s
P
p
.002 w
.59924 .36962 m .60443 .35434 L .5785 .34478 L p
1 g
F P
s
P
p
.002 w
.57797 .33629 m .5785 .34478 L .60443 .35434 L p
1 g
F P
s
P
p
.002 w
.60443 .35434 m .59924 .36962 L .62026 .38841 L p
1 g
F P
s
P
p
.002 w
.38638 .32345 m .38482 .36611 L .40976 .35603 L p
1 g
F P
s
P
p
.002 w
.40976 .35603 m .41154 .3188 L .38638 .32345 L p
1 g
F P
s
P
p
.002 w
.45149 .28944 m .43839 .31703 L .46633 .31811 L p
1 g
F P
s
P
p
.002 w
.46633 .31811 m .47669 .29697 L .45149 .28944 L p
1 g
F P
s
P
p
.002 w
.63858 .40854 m .61786 .43104 L .62845 .45644 L p
1 g
F P
s
P
p
.002 w
.61786 .43104 m .63858 .40854 L .62026 .38841 L p
1 g
F P
s
P
p
.002 w
.63599 .48165 m .59662 .50001 L .59662 .52596 L p
1 g
F P
s
P
p
.002 w
.59662 .50001 m .63599 .48165 L .62845 .45644 L p
1 g
F P
s
P
p
.002 w
.53079 .29104 m .51444 .29695 L .53327 .31594 L p
1 g
F P
s
P
p
.002 w
.53327 .31594 m .54151 .31304 L .53079 .29104 L p
1 g
F P
s
P
p
.002 w
.34435 .45814 m .37769 .50439 L .39117 .48588 L p
1 g
F P
s
P
p
.002 w
.39117 .48588 m .35937 .4413 L .34435 .45814 L p
1 g
F P
s
P
p
.002 w
.60443 .35434 m .60353 .33748 L .57797 .33629 L p
1 g
F P
s
P
p
.002 w
.5744 .32801 m .57797 .33629 L .60353 .33748 L p
1 g
F P
s
P
p
.002 w
.3427 .39161 m .35937 .4413 L .3775 .42464 L p
1 g
F P
s
P
p
.002 w
.3775 .42464 m .36227 .37804 L .3427 .39161 L p
1 g
F P
s
P
p
.002 w
.49485 .28094 m .47669 .29697 L .50201 .30767 L p
1 g
F P
s
P
p
.002 w
.50201 .30767 m .51444 .29695 L .49485 .28094 L p
1 g
F P
s
P
p
.002 w
.54927 .29073 m .53079 .29104 L .54151 .31304 L p
1 g
F P
s
P
p
.002 w
.54151 .31304 m .55077 .31293 L .54927 .29073 L p
1 g
F P
s
P
p
.002 w
.60353 .33748 m .59654 .32093 L .5744 .32801 L p
1 g
F P
s
P
p
.002 w
.56819 .32086 m .5744 .32801 L .59654 .32093 L p
1 g
F P
s
P
p
.002 w
.62818 .36599 m .62026 .38841 L .63858 .40854 L p
1 g
F P
s
P
p
.002 w
.62026 .38841 m .62818 .36599 L .60443 .35434 L p
1 g
F P
s
P
p
.002 w
.56777 .2961 m .54927 .29073 L .55077 .31293 L p
1 g
F P
s
P
p
.002 w
.55077 .31293 m .56 .31563 L .56777 .2961 L p
1 g
F P
s
P
p
.002 w
.59654 .32093 m .58416 .30657 L .56819 .32086 L p
1 g
F P
s
P
p
.002 w
.56 .31563 m .56819 .32086 L .58416 .30657 L p
1 g
F P
s
P
p
.002 w
.42694 .28537 m .41154 .3188 L .43839 .31703 L p
1 g
F P
s
P
p
.002 w
.43839 .31703 m .45149 .28944 L .42694 .28537 L p
1 g
F P
s
P
p
.002 w
.60353 .33748 m .60443 .35434 L .62818 .36599 L p
1 g
F P
s
P
p
.002 w
.58416 .30657 m .56777 .2961 L .56 .31563 L p
1 g
F P
s
P
p
.002 w
.65373 .42964 m .62845 .45644 L .63599 .48165 L p
1 g
F P
s
P
p
.002 w
.62845 .45644 m .65373 .42964 L .63858 .40854 L p
1 g
F P
s
P
p
.002 w
.4767 .56645 m .53369 .577 L .54085 .55541 L p
1 g
F P
s
P
p
.002 w
.59416 .55009 m .54085 .55541 L .53369 .577 L p
1 g
F P
s
P
p
.002 w
.54085 .55541 m .59416 .55009 L .59662 .52596 L p
1 g
F P
s
P
p
.002 w
.36353 .331 m .36227 .37804 L .38482 .36611 L p
1 g
F P
s
P
p
.002 w
.38482 .36611 m .38638 .32345 L .36353 .331 L p
1 g
F P
s
P
p
.002 w
.51899 .27201 m .49485 .28094 L .51444 .29695 L p
1 g
F P
s
P
p
.002 w
.51444 .29695 m .53079 .29104 L .51899 .27201 L p
1 g
F P
s
P
p
.002 w
.36694 .52157 m .41323 .55919 L .42318 .5415 L p
1 g
F P
s
P
p
.002 w
.42318 .5415 m .37769 .50439 L .36694 .52157 L p
1 g
F P
s
P
p
.002 w
.4767 .56645 m .42318 .5415 L .41323 .55919 L p
1 g
F P
s
P
p
.002 w
.47488 .26837 m .45149 .28944 L .47669 .29697 L p
1 g
F P
s
P
p
.002 w
.47669 .29697 m .49485 .28094 L .47488 .26837 L p
1 g
F P
s
P
p
.002 w
.64022 .50613 m .59662 .52596 L .59416 .55009 L p
1 g
F P
s
P
p
.002 w
.59662 .52596 m .64022 .50613 L .63599 .48165 L p
1 g
F P
s
P
p
.002 w
.41323 .55919 m .4676 .58458 L .4767 .56645 L p
1 g
F P
s
P
p
.002 w
.53369 .577 m .4767 .56645 L .4676 .58458 L p
1 g
F P
s
P
p
.002 w
.62818 .36599 m .62709 .34107 L .60353 .33748 L p
1 g
F P
s
P
p
.002 w
.59654 .32093 m .60353 .33748 L .62709 .34107 L p
1 g
F P
s
P
p
.002 w
.64918 .37956 m .63858 .40854 L .65373 .42964 L p
1 g
F P
s
P
p
.002 w
.63858 .40854 m .64918 .37956 L .62818 .36599 L p
1 g
F P
s
P
p
.002 w
.32665 .4066 m .34435 .45814 L .35937 .4413 L p
1 g
F P
s
P
p
.002 w
.35937 .4413 m .3427 .39161 L .32665 .4066 L p
1 g
F P
s
P
p
.002 w
.40364 .28497 m .38638 .32345 L .41154 .3188 L p
1 g
F P
s
P
p
.002 w
.41154 .3188 m .42694 .28537 L .40364 .28497 L p
1 g
F P
s
P
p
.002 w
.54645 .27142 m .51899 .27201 L .53079 .29104 L p
1 g
F P
s
P
p
.002 w
.53079 .29104 m .54927 .29073 L .54645 .27142 L p
1 g
F P
s
P
p
.002 w
.3329 .47478 m .36694 .52157 L .37769 .50439 L p
1 g
F P
s
P
p
.002 w
.37769 .50439 m .34435 .45814 L .3329 .47478 L p
1 g
F P
s
P
p
.002 w
.62709 .34107 m .62818 .36599 L .64918 .37956 L p
1 g
F P
s
P
p
.002 w
.66528 .45127 m .63599 .48165 L .64022 .50613 L p
1 g
F P
s
P
p
.002 w
.63599 .48165 m .66528 .45127 L .65373 .42964 L p
1 g
F P
s
P
p
.002 w
.62709 .34107 m .61686 .31645 L .59654 .32093 L p
1 g
F P
s
P
p
.002 w
.58416 .30657 m .59654 .32093 L .61686 .31645 L p
1 g
F P
s
P
p
.002 w
.3436 .34137 m .3427 .39161 L .36227 .37804 L p
1 g
F P
s
P
p
.002 w
.36227 .37804 m .36353 .331 L .3436 .34137 L p
1 g
F P
s
P
p
.002 w
.57405 .27938 m .54645 .27142 L .54927 .29073 L p
1 g
F P
s
P
p
.002 w
.54927 .29073 m .56777 .2961 L .57405 .27938 L p
1 g
F P
s
P
p
.002 w
.45498 .25966 m .42694 .28537 L .45149 .28944 L p
1 g
F P
s
P
p
.002 w
.45149 .28944 m .47488 .26837 L .45498 .25966 L p
1 g
F P
s
P
p
.002 w
.50631 .25651 m .47488 .26837 L .49485 .28094 L p
1 g
F P
s
P
p
.002 w
.49485 .28094 m .51899 .27201 L .50631 .25651 L p
1 g
F P
s
P
p
.002 w
.61686 .31645 m .59849 .29501 L .58416 .30657 L p
1 g
F P
s
P
p
.002 w
.56777 .2961 m .58416 .30657 L .59849 .29501 L p
1 g
F P
s
P
p
.002 w
.4676 .58458 m .52544 .59549 L .53369 .577 L p
1 g
F P
s
P
p
.002 w
.5892 .57181 m .53369 .577 L .52544 .59549 L p
1 g
F P
s
P
p
.002 w
.53369 .577 m .5892 .57181 L .59416 .55009 L p
1 g
F P
s
P
p
.002 w
.59849 .29501 m .57405 .27938 L .56777 .2961 L p
1 g
F P
s
P
p
.002 w
.64092 .52931 m .59416 .55009 L .5892 .57181 L p
1 g
F P
s
P
p
.002 w
.59416 .55009 m .64092 .52931 L .64022 .50613 L p
1 g
F P
s
P
p
.002 w
.66688 .39481 m .65373 .42964 L .66528 .45127 L p
1 g
F P
s
P
p
.002 w
.65373 .42964 m .66688 .39481 L .64918 .37956 L p
1 g
F P
s
P
p
.002 w
.35929 .53698 m .40519 .57415 L .41323 .55919 L p
1 g
F P
s
P
p
.002 w
.41323 .55919 m .36694 .52157 L .35929 .53698 L p
1 g
F P
s
P
p
.002 w
.4676 .58458 m .41323 .55919 L .40519 .57415 L p
1 g
F P
s
P
p
.002 w
.64918 .37956 m .64804 .34709 L .62709 .34107 L p
1 g
F P
s
P
p
.002 w
.61686 .31645 m .62709 .34107 L .64804 .34709 L p
1 g
F P
s
P
p
.002 w
.38218 .28841 m .36353 .331 L .38638 .32345 L p
1 g
F P
s
P
p
.002 w
.38638 .32345 m .40364 .28497 L .38218 .28841 L p
1 g
F P
s
P
p
.002 w
.40519 .57415 m .45903 .59933 L .4676 .58458 L p
1 g
F P
s
P
p
.002 w
.52544 .59549 m .4676 .58458 L .45903 .59933 L p
1 g
F P
s
P
p
.002 w
.64804 .34709 m .64918 .37956 L .66688 .39481 L p
1 g
F P
s
P
p
.002 w
.31468 .4227 m .3329 .47478 L .34435 .45814 L p
1 g
F P
s
P
p
.002 w
.34435 .45814 m .32665 .4066 L .31468 .4227 L p
1 g
F P
s
P
p
.002 w
.67283 .47296 m .64022 .50613 L .64092 .52931 L p
1 g
F P
s
P
p
.002 w
.64022 .50613 m .67283 .47296 L .66528 .45127 L p
1 g
F P
s
P
p
.002 w
.54231 .25559 m .50631 .25651 L .51899 .27201 L p
1 g
F P
s
P
p
.002 w
.51899 .27201 m .54645 .27142 L .54231 .25559 L p
1 g
F P
s
P
p
.002 w
.32548 .49084 m .35929 .53698 L .36694 .52157 L p
1 g
F P
s
P
p
.002 w
.36694 .52157 m .3329 .47478 L .32548 .49084 L p
1 g
F P
s
P
p
.002 w
.32722 .35446 m .32665 .4066 L .3427 .39161 L p
1 g
F P
s
P
p
.002 w
.3427 .39161 m .3436 .34137 L .32722 .35446 L p
1 g
F P
s
P
p
.002 w
.43562 .25521 m .40364 .28497 L .42694 .28537 L p
1 g
F P
s
P
p
.002 w
.42694 .28537 m .45498 .25966 L .43562 .25521 L p
1 g
F P
s
P
p
.002 w
.64804 .34709 m .63482 .3148 L .61686 .31645 L p
1 g
F P
s
P
p
.002 w
.59849 .29501 m .61686 .31645 L .63482 .3148 L p
1 g
F P
s
P
p
.002 w
.49302 .24507 m .45498 .25966 L .47488 .26837 L p
1 g
F P
s
P
p
.002 w
.47488 .26837 m .50631 .25651 L .49302 .24507 L p
1 g
F P
s
P
p
.002 w
.57862 .26601 m .54231 .25559 L .54645 .27142 L p
1 g
F P
s
P
p
.002 w
.54645 .27142 m .57405 .27938 L .57862 .26601 L p
1 g
F P
s
P
p
.002 w
.68072 .41146 m .66528 .45127 L .67283 .47296 L p
1 g
F P
s
P
p
.002 w
.66528 .45127 m .68072 .41146 L .66688 .39481 L p
1 g
F P
s
P
p
.002 w
.45903 .59933 m .51624 .61028 L .52544 .59549 L p
1 g
F P
s
P
p
.002 w
.58174 .59052 m .52544 .59549 L .51624 .61028 L p
1 g
F P
s
P
p
.002 w
.52544 .59549 m .58174 .59052 L .5892 .57181 L p
1 g
F P
s
P
p
.002 w
.63793 .55059 m .5892 .57181 L .58174 .59052 L p
1 g
F P
s
P
p
.002 w
.5892 .57181 m .63793 .55059 L .64092 .52931 L p
1 g
F P
s
P
p
.002 w
.63482 .3148 m .61076 .28659 L .59849 .29501 L p
1 g
F P
s
P
p
.002 w
.57405 .27938 m .59849 .29501 L .61076 .28659 L p
1 g
F P
s
P
p
.002 w
.61076 .28659 m .57862 .26601 L .57405 .27938 L p
1 g
F P
s
P
p
.002 w
.36318 .29578 m .3436 .34137 L .36353 .331 L p
1 g
F P
s
P
p
.002 w
.36353 .331 m .38218 .28841 L .36318 .29578 L p
1 g
F P
s
P
p
.002 w
.66688 .39481 m .66577 .35549 L .64804 .34709 L p
1 g
F P
s
P
p
.002 w
.63482 .3148 m .64804 .34709 L .66577 .35549 L p
1 g
F P
s
P
p
.002 w
.66577 .35549 m .66688 .39481 L .68072 .41146 L p
1 g
F P
s
P
p
.002 w
.67601 .4942 m .64092 .52931 L .63793 .55059 L p
1 g
F P
s
P
p
.002 w
.64092 .52931 m .67601 .4942 L .67283 .47296 L p
1 g
F P
s
P
p
.002 w
.3551 .55014 m .39934 .58589 L .40519 .57415 L p
1 g
F P
s
P
p
.002 w
.40519 .57415 m .35929 .53698 L .3551 .55014 L p
1 g
F P
s
P
p
.002 w
.45903 .59933 m .40519 .57415 L .39934 .58589 L p
1 g
F P
s
P
p
.002 w
.30729 .43958 m .32548 .49084 L .3329 .47478 L p
1 g
F P
s
P
p
.002 w
.3329 .47478 m .31468 .4227 L .30729 .43958 L p
1 g
F P
s
P
p
.002 w
.39934 .58589 m .45121 .61018 L .45903 .59933 L p
1 g
F P
s
P
p
.002 w
.51624 .61028 m .45903 .59933 L .45121 .61018 L p
1 g
F P
s
P
p
.002 w
.53688 .24383 m .49302 .24507 L .50631 .25651 L p
1 g
F P
s
P
p
.002 w
.50631 .25651 m .54231 .25559 L .53688 .24383 L p
1 g
F P
s
P
p
.002 w
.41732 .25534 m .38218 .28841 L .40364 .28497 L p
1 g
F P
s
P
p
.002 w
.40364 .28497 m .43562 .25521 L .41732 .25534 L p
1 g
F P
s
P
p
.002 w
.31496 .37005 m .31468 .4227 L .32665 .4066 L p
1 g
F P
s
P
p
.002 w
.32665 .4066 m .32722 .35446 L .31496 .37005 L p
1 g
F P
s
P
p
.002 w
.32248 .50588 m .3551 .55014 L .35929 .53698 L p
1 g
F P
s
P
p
.002 w
.35929 .53698 m .32548 .49084 L .32248 .50588 L p
1 g
F P
s
P
p
.002 w
.47942 .2382 m .43562 .25521 L .45498 .25966 L p
1 g
F P
s
P
p
.002 w
.45498 .25966 m .49302 .24507 L .47942 .2382 L p
1 g
F P
s
P
p
.002 w
.66577 .35549 m .64985 .31617 L .63482 .3148 L p
1 g
F P
s
P
p
.002 w
.61076 .28659 m .63482 .3148 L .64985 .31617 L p
1 g
F P
s
P
p
.002 w
.69018 .42917 m .67283 .47296 L .67601 .4942 L p
1 g
F P
s
P
p
.002 w
.67283 .47296 m .69018 .42917 L .68072 .41146 L p
1 g
F P
s
P
p
.002 w
.51624 .61028 m .57183 .60561 L .58174 .59052 L p
1 g
F P
s
P
p
.002 w
.63113 .56935 m .58174 .59052 L .57183 .60561 L p
1 g
F P
s
P
p
.002 w
.58174 .59052 m .63113 .56935 L .63793 .55059 L p
1 g
F P
s
P
p
.002 w
.58125 .25651 m .53688 .24383 L .54231 .25559 L p
1 g
F P
s
P
p
.002 w
.54231 .25559 m .57862 .26601 L .58125 .25651 L p
1 g
F P
s
P
p
.002 w
.34727 .30711 m .32722 .35446 L .3436 .34137 L p
1 g
F P
s
P
p
.002 w
.3436 .34137 m .36318 .29578 L .34727 .30711 L p
1 g
F P
s
P
p
.002 w
.45121 .61018 m .50624 .62082 L .51624 .61028 L p
1 g
F P
s
P
p
.002 w
.57183 .60561 m .51624 .61028 L .50624 .62082 L p
1 g
F P
s
P
p
.002 w
.64985 .31617 m .62055 .2817 L .61076 .28659 L p
1 g
F P
s
P
p
.002 w
.57862 .26601 m .61076 .28659 L .62055 .2817 L p
1 g
F P
s
P
p
.002 w
.67969 .36621 m .68072 .41146 L .69018 .42917 L p
1 g
F P
s
P
p
.002 w
.68072 .41146 m .67969 .36621 L .66577 .35549 L p
1 g
F P
s
P
p
.002 w
.64985 .31617 m .66577 .35549 L .67969 .36621 L p
1 g
F P
s
P
p
.002 w
.62055 .2817 m .58125 .25651 L .57862 .26601 L p
1 g
F P
s
P
p
.002 w
.67454 .51442 m .63793 .55059 L .63113 .56935 L p
1 g
F P
s
P
p
.002 w
.63793 .55059 m .67454 .51442 L .67601 .4942 L p
1 g
F P
s
P
p
.002 w
.40061 .26031 m .36318 .29578 L .38218 .28841 L p
1 g
F P
s
P
p
.002 w
.38218 .28841 m .41732 .25534 L .40061 .26031 L p
1 g
F P
s
P
p
.002 w
.30492 .45684 m .32248 .50588 L .32548 .49084 L p
1 g
F P
s
P
p
.002 w
.32548 .49084 m .30729 .43958 L .30492 .45684 L p
1 g
F P
s
P
p
.002 w
.35467 .56059 m .39598 .59391 L .39934 .58589 L p
1 g
F P
s
P
p
.002 w
.39934 .58589 m .3551 .55014 L .35467 .56059 L p
1 g
F P
s
P
p
.002 w
.45121 .61018 m .39934 .58589 L .39598 .59391 L p
1 g
F P
s
P
p
.002 w
.30739 .38787 m .30729 .43958 L .31468 .4227 L p
1 g
F P
s
P
p
.002 w
.31468 .4227 m .31496 .37005 L .30739 .38787 L p
1 g
F P
s
P
p
.002 w
.53021 .23668 m .47942 .2382 L .49302 .24507 L p
1 g
F P
s
P
p
.002 w
.49302 .24507 m .53688 .24383 L .53021 .23668 L p
1 g
F P
s
P
p
.002 w
.39598 .59391 m .44439 .6166 L .45121 .61018 L p
1 g
F P
s
P
p
.002 w
.50624 .62082 m .45121 .61018 L .44439 .6166 L p
1 g
F P
s
P
p
.002 w
.46584 .23637 m .41732 .25534 L .43562 .25521 L p
1 g
F P
s
P
p
.002 w
.43562 .25521 m .47942 .2382 L .46584 .23637 L p
1 g
F P
s
P
p
.002 w
.69479 .44754 m .67601 .4942 L .67454 .51442 L p
1 g
F P
s
P
p
.002 w
.67601 .4942 m .69479 .44754 L .69018 .42917 L p
1 g
F P
s
P
p
.002 w
.32425 .51944 m .35467 .56059 L .3551 .55014 L p
1 g
F P
s
P
p
.002 w
.3551 .55014 m .32248 .50588 L .32425 .51944 L p
1 g
F P
s
P
p
.002 w
.67969 .36621 m .66142 .32071 L .64985 .31617 L p
1 g
F P
s
P
p
.002 w
.62055 .2817 m .64985 .31617 L .66142 .32071 L p
1 g
F P
s
P
p
.002 w
.33505 .32227 m .31496 .37005 L .32722 .35446 L p
1 g
F P
s
P
p
.002 w
.32722 .35446 m .34727 .30711 L .33505 .32227 L p
1 g
F P
s
P
p
.002 w
.50624 .62082 m .55959 .6165 L .57183 .60561 L p
1 g
F P
s
P
p
.002 w
.62051 .58499 m .57183 .60561 L .55959 .6165 L p
1 g
F P
s
P
p
.002 w
.57183 .60561 m .62051 .58499 L .63113 .56935 L p
1 g
F P
s
P
p
.002 w
.68923 .37909 m .69018 .42917 L .69479 .44754 L p
1 g
F P
s
P
p
.002 w
.69018 .42917 m .68923 .37909 L .67969 .36621 L p
1 g
F P
s
P
p
.002 w
.58177 .25139 m .53021 .23668 L .53688 .24383 L p
1 g
F P
s
P
p
.002 w
.53688 .24383 m .58125 .25651 L .58177 .25139 L p
1 g
F P
s
P
p
.002 w
.44439 .6166 m .49567 .62659 L .50624 .62082 L p
1 g
F P
s
P
p
.002 w
.55959 .6165 m .50624 .62082 L .49567 .62659 L p
1 g
F P
s
P
p
.002 w
.66142 .32071 m .67969 .36621 L .68923 .37909 L p
1 g
F P
s
P
p
.002 w
.66821 .53303 m .63113 .56935 L .62051 .58499 L p
1 g
F P
s
P
p
.002 w
.63113 .56935 m .66821 .53303 L .67454 .51442 L p
1 g
F P
s
P
p
.002 w
.66142 .32071 m .62745 .28068 L .62055 .2817 L p
1 g
F P
s
P
p
.002 w
.58125 .25651 m .62055 .2817 L .62745 .28068 L p
1 g
F P
s
P
p
.002 w
.38607 .27024 m .34727 .30711 L .36318 .29578 L p
1 g
F P
s
P
p
.002 w
.36318 .29578 m .40061 .26031 L .38607 .27024 L p
1 g
F P
s
P
p
.002 w
.62745 .28068 m .58177 .25139 L .58125 .25651 L p
1 g
F P
s
P
p
.002 w
.30792 .47401 m .32425 .51944 L .32248 .50588 L p
1 g
F P
s
P
p
.002 w
.32248 .50588 m .30492 .45684 L .30792 .47401 L p
1 g
F P
s
P
p
.002 w
.30496 .40752 m .30492 .45684 L .30729 .43958 L p
1 g
F P
s
P
p
.002 w
.30729 .43958 m .30739 .38787 L .30496 .40752 L p
1 g
F P
s
P
p
.002 w
.52241 .23465 m .46584 .23637 L .47942 .2382 L p
1 g
F P
s
P
p
.002 w
.47942 .2382 m .53021 .23668 L .52241 .23465 L p
1 g
F P
s
P
p
.002 w
.69415 .4661 m .67454 .51442 L .66821 .53303 L p
1 g
F P
s
P
p
.002 w
.67454 .51442 m .69415 .4661 L .69479 .44754 L p
1 g
F P
s
P
p
.002 w
.35826 .56788 m .39534 .59777 L .39598 .59391 L p
1 g
F P
s
P
p
.002 w
.39598 .59391 m .35467 .56059 L .35826 .56788 L p
1 g
F P
s
P
p
.002 w
.44439 .6166 m .39598 .59391 L .39534 .59777 L p
1 g
F P
s
P
p
.002 w
.45267 .23992 m .40061 .26031 L .41732 .25534 L p
1 g
F P
s
P
p
.002 w
.41732 .25534 m .46584 .23637 L .45267 .23992 L p
1 g
F P
s
P
p
.002 w
.39534 .59777 m .43882 .61815 L .44439 .6166 L p
1 g
F P
s
P
p
.002 w
.49567 .62659 m .44439 .6166 L .43882 .61815 L p
1 g
F P
s
P
p
.002 w
.32707 .34104 m .30739 .38787 L .31496 .37005 L p
1 g
F P
s
P
p
.002 w
.31496 .37005 m .33505 .32227 L .32707 .34104 L p
1 g
F P
s
P
p
.002 w
.33102 .53106 m .35826 .56788 L .35467 .56059 L p
1 g
F P
s
P
p
.002 w
.35467 .56059 m .32425 .51944 L .33102 .53106 L p
1 g
F P
s
P
p
.002 w
.68923 .37909 m .66897 .32849 L .66142 .32071 L p
1 g
F P
s
P
p
.002 w
.62745 .28068 m .66142 .32071 L .66897 .32849 L p
1 g
F P
s
P
p
.002 w
.49567 .62659 m .54523 .62265 L .55959 .6165 L p
1 g
F P
s
P
p
.002 w
.60616 .5969 m .55959 .6165 L .54523 .62265 L p
1 g
F P
s
P
p
.002 w
.55959 .6165 m .60616 .5969 L .62051 .58499 L p
1 g
F P
s
P
p
.002 w
.69479 .44754 m .69387 .39391 L .68923 .37909 L p
1 g
F P
s
P
p
.002 w
.69387 .39391 m .69479 .44754 L .69415 .4661 L p
1 g
F P
s
P
p
.002 w
.62051 .58499 m .65695 .54943 L .66821 .53303 L p
1 g
F P
s
P
p
.002 w
.65695 .54943 m .62051 .58499 L .60616 .5969 L p
1 g
F P
s
P
p
.002 w
.66897 .32849 m .68923 .37909 L .69387 .39391 L p
1 g
F P
s
P
p
.002 w
.43882 .61815 m .48478 .62712 L .49567 .62659 L p
1 g
F P
s
P
p
.002 w
.54523 .62265 m .49567 .62659 L .48478 .62712 L p
1 g
F P
s
P
p
.002 w
.58001 .25108 m .52241 .23465 L .53021 .23668 L p
1 g
F P
s
P
p
.002 w
.53021 .23668 m .58177 .25139 L .58001 .25108 L p
1 g
F P
s
P
p
.002 w
.37424 .28512 m .33505 .32227 L .34727 .30711 L p
1 g
F P
s
P
p
.002 w
.34727 .30711 m .38607 .27024 L .37424 .28512 L p
1 g
F P
s
P
p
.002 w
.66897 .32849 m .63108 .28382 L .62745 .28068 L p
1 g
F P
s
P
p
.002 w
.58177 .25139 m .62745 .28068 L .63108 .28382 L p
1 g
F P
s
P
p
.002 w
.30803 .42852 m .30792 .47401 L .30492 .45684 L p
1 g
F P
s
P
p
.002 w
.30492 .45684 m .30496 .40752 L .30803 .42852 L p
1 g
F P
s
P
p
.002 w
.63108 .28382 m .58001 .25108 L .58177 .25139 L p
1 g
F P
s
P
p
.002 w
.31652 .49058 m .33102 .53106 L .32425 .51944 L p
1 g
F P
s
P
p
.002 w
.32425 .51944 m .30792 .47401 L .31652 .49058 L p
1 g
F P
s
P
p
.002 w
.66821 .53303 m .68801 .48434 L .69415 .4661 L p
1 g
F P
s
P
p
.002 w
.68801 .48434 m .66821 .53303 L .65695 .54943 L p
1 g
F P
s
P
p
.002 w
.44033 .24908 m .38607 .27024 L .40061 .26031 L p
1 g
F P
s
P
p
.002 w
.40061 .26031 m .45267 .23992 L .44033 .24908 L p
1 g
F P
s
P
p
.002 w
.51363 .23811 m .45267 .23992 L .46584 .23637 L p
1 g
F P
s
P
p
.002 w
.46584 .23637 m .52241 .23465 L .51363 .23811 L p
1 g
F P
s
P
p
.002 w
.3238 .36304 m .30496 .40752 L .30739 .38787 L p
1 g
F P
s
P
p
.002 w
.30739 .38787 m .32707 .34104 L .3238 .36304 L p
1 g
F P
s
P
p
.002 w
.36602 .57158 m .39764 .59707 L .39534 .59777 L p
1 g
F P
s
P
p
.002 w
.39534 .59777 m .35826 .56788 L .36602 .57158 L p
1 g
F P
s
P
p
.002 w
.43882 .61815 m .39534 .59777 L .39764 .59707 L p
1 g
F P
s
P
p
.002 w
.39764 .59707 m .43473 .61446 L .43882 .61815 L p
1 g
F P
s
P
p
.002 w
.48478 .62712 m .43882 .61815 L .43473 .61446 L p
1 g
F P
s
P
p
.002 w
.69317 .41035 m .69415 .4661 L .68801 .48434 L p
1 g
F P
s
P
p
.002 w
.69415 .4661 m .69317 .41035 L .69387 .39391 L p
1 g
F P
s
P
p
.002 w
.48478 .62712 m .52903 .6236 L .54523 .62265 L p
1 g
F P
s
P
p
.002 w
.54523 .62265 m .58828 .60453 L .60616 .5969 L p
1 g
F P
s
P
p
.002 w
.58828 .60453 m .54523 .62265 L .52903 .6236 L p
1 g
F P
s
P
p
.002 w
.34291 .54027 m .36602 .57158 L .35826 .56788 L p
1 g
F P
s
P
p
.002 w
.35826 .56788 m .33102 .53106 L .34291 .54027 L p
1 g
F P
s
P
p
.002 w
.69387 .39391 m .67206 .3395 L .66897 .32849 L p
1 g
F P
s
P
p
.002 w
.63108 .28382 m .66897 .32849 L .67206 .3395 L p
1 g
F P
s
P
p
.002 w
.64082 .56302 m .60616 .5969 L .58828 .60453 L p
1 g
F P
s
P
p
.002 w
.60616 .5969 m .64082 .56302 L .65695 .54943 L p
1 g
F P
s
P
p
.002 w
.36565 .30476 m .32707 .34104 L .33505 .32227 L p
1 g
F P
s
P
p
.002 w
.33505 .32227 m .37424 .28512 L .36565 .30476 L p
1 g
F P
s
P
p
.002 w
.67206 .3395 m .69387 .39391 L .69317 .41035 L p
1 g
F P
s
P
p
.002 w
.43473 .61446 m .47386 .62208 L .48478 .62712 L p
1 g
F P
s
P
p
.002 w
.52903 .6236 m .48478 .62712 L .47386 .62208 L p
1 g
F P
s
P
p
.002 w
.57588 .2559 m .51363 .23811 L .52241 .23465 L p
1 g
F P
s
P
p
.002 w
.52241 .23465 m .58001 .25108 L .57588 .2559 L p
1 g
F P
s
P
p
.002 w
.31678 .45028 m .31652 .49058 L .30792 .47401 L p
1 g
F P
s
P
p
.002 w
.30792 .47401 m .30803 .42852 L .31678 .45028 L p
1 g
F P
s
P
p
.002 w
.67625 .50168 m .65695 .54943 L .64082 .56302 L p
1 g
F P
s
P
p
.002 w
.65695 .54943 m .67625 .50168 L .68801 .48434 L p
1 g
F P
s
P
p
.002 w
.67206 .3395 m .63111 .2913 L .63108 .28382 L p
1 g
F P
s
P
p
.002 w
.58001 .25108 m .63108 .28382 L .63111 .2913 L p
1 g
F P
s
P
p
.002 w
.42925 .26389 m .37424 .28512 L .38607 .27024 L p
1 g
F P
s
P
p
.002 w
.38607 .27024 m .44033 .24908 L .42925 .26389 L p
1 g
F P
s
P
p
.002 w
.33075 .50601 m .34291 .54027 L .33102 .53106 L p
1 g
F P
s
P
p
.002 w
.33102 .53106 m .31652 .49058 L .33075 .50601 L p
1 g
F P
s
P
p
.002 w
.63111 .2913 m .57588 .2559 L .58001 .25108 L p
1 g
F P
s
P
p
.002 w
.32559 .38773 m .30803 .42852 L .30496 .40752 L p
1 g
F P
s
P
p
.002 w
.30496 .40752 m .3238 .36304 L .32559 .38773 L p
1 g
F P
s
P
p
.002 w
.50409 .24732 m .44033 .24908 L .45267 .23992 L p
1 g
F P
s
P
p
.002 w
.45267 .23992 m .51363 .23811 L .50409 .24732 L p
1 g
F P
s
P
p
.002 w
.68687 .428 m .68801 .48434 L .67625 .50168 L p
1 g
F P
s
P
p
.002 w
.68801 .48434 m .68687 .428 L .69317 .41035 L p
1 g
F P
s
P
p
.002 w
.378 .57135 m .40299 .59154 L .39764 .59707 L p
1 g
F P
s
P
p
.002 w
.39764 .59707 m .36602 .57158 L .378 .57135 L p
1 g
F P
s
P
p
.002 w
.43473 .61446 m .39764 .59707 L .40299 .59154 L p
1 g
F P
s
P
p
.002 w
.47386 .62208 m .51137 .61902 L .52903 .6236 L p
1 g
F P
s
P
p
.002 w
.56722 .60742 m .52903 .6236 L .51137 .61902 L p
1 g
F P
s
P
p
.002 w
.52903 .6236 m .56722 .60742 L .58828 .60453 L p
1 g
F P
s
P
p
.002 w
.40299 .59154 m .43235 .60529 L .43473 .61446 L p
1 g
F P
s
P
p
.002 w
.47386 .62208 m .43473 .61446 L .43235 .60529 L p
1 g
F P
s
P
p
.002 w
.62007 .57324 m .58828 .60453 L .56722 .60742 L p
1 g
F P
s
P
p
.002 w
.58828 .60453 m .62007 .57324 L .64082 .56302 L p
1 g
F P
s
P
p
.002 w
.36074 .32877 m .3238 .36304 L .32707 .34104 L p
1 g
F P
s
P
p
.002 w
.32707 .34104 m .36565 .30476 L .36074 .32877 L p
1 g
F P
s
P
p
.002 w
.69317 .41035 m .67029 .35359 L .67206 .3395 L p
1 g
F P
s
P
p
.002 w
.63111 .2913 m .67206 .3395 L .67029 .35359 L p
1 g
F P
s
P
p
.002 w
.35984 .54663 m .378 .57135 L .36602 .57158 L p
1 g
F P
s
P
p
.002 w
.36602 .57158 m .34291 .54027 L .35984 .54663 L p
1 g
F P
s
P
p
.002 w
.67029 .35359 m .69317 .41035 L .68687 .428 L p
1 g
F P
s
P
p
.002 w
.65894 .51752 m .64082 .56302 L .62007 .57324 L p
1 g
F P
s
P
p
.002 w
.64082 .56302 m .65894 .51752 L .67625 .50168 L p
1 g
F P
s
P
p
.002 w
.43235 .60529 m .46326 .61126 L .47386 .62208 L p
1 g
F P
s
P
p
.002 w
.51137 .61902 m .47386 .62208 L .46326 .61126 L p
1 g
F P
s
P
p
.002 w
.3312 .47213 m .33075 .50601 L .31652 .49058 L p
1 g
F P
s
P
p
.002 w
.31652 .49058 m .31678 .45028 L .3312 .47213 L p
1 g
F P
s
P
p
.002 w
.56934 .26605 m .50409 .24732 L .51363 .23811 L p
1 g
F P
s
P
p
.002 w
.51363 .23811 m .57588 .2559 L .56934 .26605 L p
1 g
F P
s
P
p
.002 w
.41988 .28419 m .36565 .30476 L .37424 .28512 L p
1 g
F P
s
P
p
.002 w
.37424 .28512 m .42925 .26389 L .41988 .28419 L p
1 g
F P
s
P
p
.002 w
.3326 .4144 m .31678 .45028 L .30803 .42852 L p
1 g
F P
s
P
p
.002 w
.30803 .42852 m .32559 .38773 L .3326 .4144 L p
1 g
F P
s
P
p
.002 w
.35044 .51973 m .35984 .54663 L .34291 .54027 L p
1 g
F P
s
P
p
.002 w
.34291 .54027 m .33075 .50601 L .35044 .51973 L p
1 g
F P
s
P
p
.002 w
.67029 .35359 m .62731 .30317 L .63111 .2913 L p
1 g
F P
s
P
p
.002 w
.57588 .2559 m .63111 .2913 L .62731 .30317 L p
1 g
F P
s
P
p
.002 w
.49405 .26233 m .42925 .26389 L .44033 .24908 L p
1 g
F P
s
P
p
.002 w
.44033 .24908 m .50409 .24732 L .49405 .26233 L p
1 g
F P
s
P
p
.002 w
.62731 .30317 m .56934 .26605 L .57588 .2559 L p
1 g
F P
s
P
p
.002 w
.67484 .44635 m .67625 .50168 L .65894 .51752 L p
1 g
F P
s
P
p
.002 w
.67625 .50168 m .67484 .44635 L .68687 .428 L p
1 g
F P
s
P
p
.002 w
.51137 .61902 m .5435 .60523 L .56722 .60742 L p
1 g
F P
s
P
p
.002 w
.59514 .57957 m .56722 .60742 L .5435 .60523 L p
1 g
F P
s
P
p
.002 w
.56722 .60742 m .59514 .57957 L .62007 .57324 L p
1 g
F P
s
P
p
.002 w
.46326 .61126 m .49273 .60875 L .51137 .61902 L p
1 g
F P
s
P
p
.002 w
.5435 .60523 m .51137 .61902 L .49273 .60875 L p
1 g
F P
s
P
p
.002 w
.35985 .35652 m .32559 .38773 L .3238 .36304 L p
1 g
F P
s
P
p
.002 w
.3238 .36304 m .36074 .32877 L .35985 .35652 L p
1 g
F P
s
P
p
.002 w
.39407 .56696 m .41143 .58102 L .40299 .59154 L p
1 g
F P
s
P
p
.002 w
.40299 .59154 m .378 .57135 L .39407 .56696 L p
1 g
F P
s
P
p
.002 w
.43235 .60529 m .40299 .59154 L .41143 .58102 L p
1 g
F P
s
P
p
.004 w
.39964 .61373 m
.41099 .59301 L
s
P
p
.002 w
.41143 .58102 m .43186 .59058 L .43235 .60529 L p
1 g
F P
s
P
p
.002 w
.46326 .61126 m .43235 .60529 L .43186 .59058 L p
1 g
F P
s
P
p
.002 w
.66344 .3705 m .68687 .428 L .67484 .44635 L p
1 g
F P
s
P
p
.002 w
.68687 .428 m .66344 .3705 L .67029 .35359 L p
1 g
F P
s
P
p
.002 w
.62731 .30317 m .67029 .35359 L .66344 .3705 L p
1 g
F P
s
P
p
.002 w
.63639 .53128 m .62007 .57324 L .59514 .57957 L p
1 g
F P
s
P
p
.002 w
.62007 .57324 m .63639 .53128 L .65894 .51752 L p
1 g
F P
s
P
p
.002 w
.38154 .54979 m .39407 .56696 L .378 .57135 L p
1 g
F P
s
P
p
.002 w
.378 .57135 m .35984 .54663 L .38154 .54979 L p
1 g
F P
s
P
p
.002 w
.35105 .49333 m .35044 .51973 L .33075 .50601 L p
1 g
F P
s
P
p
.002 w
.33075 .50601 m .3312 .47213 L .35105 .49333 L p
1 g
F P
s
P
p
.002 w
.43186 .59058 m .45334 .59468 L .46326 .61126 L p
1 g
F P
s
P
p
.002 w
.49273 .60875 m .46326 .61126 L .45334 .59468 L p
1 g
F P
s
P
p
.002 w
.34481 .44222 m .3312 .47213 L .31678 .45028 L p
1 g
F P
s
P
p
.002 w
.31678 .45028 m .3326 .4144 L .34481 .44222 L p
1 g
F P
s
P
p
.002 w
.41262 .30954 m .36074 .32877 L .36565 .30476 L p
1 g
F P
s
P
p
.002 w
.36565 .30476 m .41988 .28419 L .41262 .30954 L p
1 g
F P
s
P
p
.004 w
.38115 .29649 m
.38242 .29791 L
s
P
p
.002 w
.56047 .28153 m .49405 .26233 L .50409 .24732 L p
1 g
F P
s
P
p
.002 w
.50409 .24732 m .56934 .26605 L .56047 .28153 L p
1 g
F P
s
P
p
.002 w
.3752 .5312 m .38154 .54979 L .35984 .54663 L p
1 g
F P
s
P
p
.002 w
.35984 .54663 m .35044 .51973 L .3752 .5312 L p
1 g
F P
s
P
p
.002 w
.65719 .46483 m .65894 .51752 L .63639 .53128 L p
1 g
F P
s
P
p
.002 w
.65894 .51752 m .65719 .46483 L .67484 .44635 L p
1 g
F P
s
P
p
.002 w
.48382 .28295 m .41988 .28419 L .42925 .26389 L p
1 g
F P
s
P
p
.002 w
.42925 .26389 m .49405 .26233 L .48382 .28295 L p
1 g
F P
s
P
p
.002 w
.66344 .3705 m .61956 .31931 L .62731 .30317 L p
1 g
F P
s
P
p
.002 w
.56934 .26605 m .62731 .30317 L .61956 .31931 L p
1 g
F P
s
P
p
.002 w
.49273 .60875 m .51776 .59779 L .5435 .60523 L p
1 g
F P
s
P
p
.002 w
.5667 .58165 m .5435 .60523 L .51776 .59779 L p
1 g
F P
s
P
p
.002 w
.5435 .60523 m .5667 .58165 L .59514 .57957 L p
1 g
F P
s
P
p
.002 w
.36318 .38721 m .3326 .4144 L .32559 .38773 L p
1 g
F P
s
P
p
.002 w
.32559 .38773 m .35985 .35652 L .36318 .38721 L p
1 g
F P
s
P
p
.002 w
.61956 .31931 m .56047 .28153 L .56934 .26605 L p
1 g
F P
s
P
p
.002 w
.45334 .59468 m .4737 .59284 L .49273 .60875 L p
1 g
F P
s
P
p
.002 w
.51776 .59779 m .49273 .60875 L .4737 .59284 L p
1 g
F P
s
P
p
.002 w
.60915 .54238 m .59514 .57957 L .5667 .58165 L p
1 g
F P
s
P
p
.002 w
.59514 .57957 m .60915 .54238 L .63639 .53128 L p
1 g
F P
s
P
p
.002 w
.65143 .38982 m .67484 .44635 L .65719 .46483 L p
1 g
F P
s
P
p
.002 w
.67484 .44635 m .65143 .38982 L .66344 .3705 L p
1 g
F P
s
P
p
.002 w
.41391 .55831 m .42285 .56557 L .41143 .58102 L p
1 g
F P
s
P
p
.002 w
.41143 .58102 m .39407 .56696 L .41391 .55831 L p
1 g
F P
s
P
p
.002 w
.43186 .59058 m .41143 .58102 L .42285 .56557 L p
1 g
F P
s
P
p
.002 w
.37583 .51311 m .3752 .5312 L .35044 .51973 L p
1 g
F P
s
P
p
.002 w
.35044 .51973 m .35105 .49333 L .37583 .51311 L p
1 g
F P
s
P
p
.002 w
.61956 .31931 m .66344 .3705 L .65143 .38982 L p
1 g
F P
s
P
p
.002 w
.42285 .56557 m .4334 .5705 L .43186 .59058 L p
1 g
F P
s
P
p
.002 w
.45334 .59468 m .43186 .59058 L .4334 .5705 L p
1 g
F P
s
P
p
.002 w
.36196 .47024 m .35105 .49333 L .3312 .47213 L p
1 g
F P
s
P
p
.002 w
.3312 .47213 m .34481 .44222 L .36196 .47024 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.40752 .54945 m .41391 .55831 L .39407 .56696 L p
1 g
F P
s
P
p
.002 w
.39407 .56696 m .38154 .54979 L .40752 .54945 L p
1 g
F P
s
P
p
.002 w
.40783 .33928 m .35985 .35652 L .36074 .32877 L p
1 g
F P
s
P
p
.002 w
.36074 .32877 m .41262 .30954 L .40783 .33928 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.4334 .5705 m .44447 .57257 L .45334 .59468 L p
1 g
F P
s
P
p
.002 w
.4737 .59284 m .45334 .59468 L .44447 .57257 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.63429 .48278 m .63639 .53128 L .60915 .54238 L p
1 g
F P
s
P
p
.002 w
.63639 .53128 m .63429 .48278 L .65719 .46483 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.54944 .30208 m .48382 .28295 L .49405 .26233 L p
1 g
F P
s
P
p
.002 w
.49405 .26233 m .56047 .28153 L .54944 .30208 L p
1 g
F P
s
P
p
.002 w
.4737 .59284 m .49082 .58514 L .51776 .59779 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58039 L p
1 g
F P
s
P
p
.002 w
.53558 .57923 m .51776 .59779 L .49125 .58534 L p
1 g
F P
s
P
p
.53558 .57923 m .49125 .58534 L .49342 .5848 L 1 g
F
P
p
.53128 .57265 m .51092 .58039 L .52124 .5778 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49082 .58514 m .49448 .5812 L p
.53558 .57923 L 1 g
F P
s
P
p
.002 w
.51092 .58039 m .51079 .57862 L p
.49898 .58098 L 1 g
F P
s
P
p
.002 w
.5354 .57919 m .53558 .57923 L p
.49448 .5812 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58087 L p
1 g
F P
s
P
p
.002 w
.49082 .58514 m .48371 .58054 L p
.48904 .58087 L 1 g
F P
s
P
p
.002 w
.49448 .5812 m .49358 .58217 L p
.48904 .58087 L 1 g
F P
s
P
p
.002 w
.49358 .58217 m .49082 .58514 L p
.48904 .58087 L 1 g
F P
s
P
p
.002 w
.48904 .58087 m .48921 .57862 L p
.47821 .57772 L 1 g
F P
s
P
p
.002 w
.48038 .57839 m .49082 .58514 L p
.47609 .57906 L 1 g
F P
s
P
p
.47609 .57906 m .45633 .57089 L .46829 .57462 L 1 g
F
P
p
.47609 .57906 m .46829 .57462 L .48038 .57839 L 1 g
F
P
p
.002 w
.4549 .57156 m .45633 .57089 L p
.47836 .57999 L 1 g
F P
s
P
p
.49082 .58514 m .47678 .57983 L .47836 .57999 L 1 g
F
P
p
.47678 .57983 m .4549 .57156 L .47836 .57999 L 1 g
F
P
p
.002 w
.49125 .58534 m .49082 .58514 L p
.49342 .5848 L 1 g
F P
s
P
p
.002 w
.49082 .58514 m .4737 .59284 L .4549 .57156 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .48857 .5874 L p
.50991 .58323 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .50762 .583 L p
.50991 .58323 L 1 g
F P
s
P
p
.002 w
.50762 .583 m .48889 .583 L p
.50991 .58323 L 1 g
F P
s
P
p
.002 w
.46829 .57462 m .46872 .57265 L p
.45747 .56816 L 1 g
F P
s
P
p
.002 w
.4549 .57156 m .4475 .56076 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.4593 .56951 m .45679 .57068 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.45679 .57068 m .4549 .57156 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.45076 .56318 m .45146 .56129 L p
.44409 .55489 L 1 g
F P
s
P
p
.45747 .56816 m .4593 .56951 L .46829 .57462 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4503 .5644 L p
1 g
F P
s
P
p
.46872 .57265 m .4503 .5644 L .45559 .5674 L 1 g
F
P
p
.47821 .57772 m .48038 .57839 L .48904 .58087 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46822 .57492 L p
1 g
F P
s
P
p
.48921 .57862 m .46822 .57492 L .47793 .57769 L 1 g
F
P
p
.51079 .57862 m .48904 .58087 L .49708 .58136 L 1 g
F
P
p
.49448 .5812 m .48904 .58087 L .46358 .56753 L 1 g
F
P
p
.002 w
.48371 .58054 m .48038 .57839 L p
.48904 .58087 L 1 g
F P
s
P
p
.002 w
.48038 .57839 m .46358 .56753 L p
.48904 .58087 L 1 g
F P
s
P
p
.002 w
.46822 .57492 m .4678 .57686 L p
.47793 .57769 L 1 g
F P
s
P
p
.002 w
.46358 .56753 m .48038 .57839 L p
.46829 .57462 L 1 g
F P
s
P
p
.002 w
.45633 .57089 m .4593 .56951 L p
.46829 .57462 L 1 g
F P
s
P
p
.002 w
.4593 .56951 m .46358 .56753 L p
.46829 .57462 L 1 g
F P
s
P
p
.4549 .57156 m .43959 .5548 L .44715 .5605 L 1 g
F
P
p
.002 w
.42588 .51437 m .4284 .51446 L p
.4325 .5292 L 1 g
F P
s
P
p
.002 w
.43233 .53238 m .42588 .51437 L p
.4325 .5292 L 1 g
F P
s
P
p
.002 w
.43253 .5287 m .43346 .52734 L p
.43312 .51745 L 1 g
F P
s
P
p
.43925 .54566 m .43501 .53728 L .43522 .538 L 1 g
F
P
p
.002 w
.43703 .54547 m .43233 .53238 L p
.4325 .5292 L 1 g
F P
s
P
p
.002 w
.43703 .54423 m .43703 .54547 L p
.4284 .51446 L 1 g
F P
s
P
p
.002 w
.43739 .54544 m .43703 .54547 L .43736 .54533 L p
1 g
F P
s
P
p
.002 w
.43743 .54555 m .43703 .54547 L .43739 .54544 L p
1 g
F P
s
P
p
.002 w
.43823 .54759 m .43925 .54566 L p
.43516 .53788 L 1 g
F P
s
P
p
.43516 .53788 m .43501 .5376 L .43577 .53996 L 1 g
F
P
p
.43516 .53788 m .43577 .53996 L .43823 .54759 L 1 g
F
P
p
.43501 .5376 m .436 .54087 L .43823 .54759 L 1 g
F
P
p
.43476 .53712 m .43715 .54469 L .43823 .54759 L 1 g
F
P
p
.002 w
.43724 .54496 m .43703 .54547 L .43703 .54423 L p
1 g
F P
s
P
p
.43334 .53442 m .43706 .54455 L .43823 .54759 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.41615 .51718 m .42588 .51437 L .43233 .53238 L p
1 g
F P
s
P
p
.002 w
.43233 .53238 m .43703 .54547 L .43203 .5387 L p
1 g
F P
s
P
p
.002 w
.43203 .5387 m .41615 .51718 L p
.43233 .53238 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43253 .5287 L p
1 g
F P
s
P
p
.002 w
.43253 .5287 m .43146 .53025 L p
.43501 .53728 L 1 g
F P
s
P
p
.43925 .54566 m .43253 .5287 L .43501 .53728 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4284 .51446 m .43326 .51464 L p
.43253 .5287 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43383 .50948 L p
1 g
F P
s
P
p
.43384 .50935 m .43383 .50948 L .42588 .51437 L 1 g
F
P
p
.002 w
.43326 .51464 m .43138 .51457 L p
.43383 .50948 L 1 g
F P
s
P
p
.002 w
.43138 .51457 m .42588 .51437 L p
.43383 .50948 L 1 g
F P
s
P
p
.002 w
.42588 .51437 m .41686 .48022 L p
.43384 .50935 L 1 g
F P
s
P
p
.002 w
.43383 .50948 m .43485 .50826 L p
.43836 .50005 L 1 g
F P
s
P
p
.002 w
.43777 .50127 m .43809 .49571 L p
.4419 .49276 L 1 g
F P
s
P
p
.002 w
.43809 .49571 m .43893 .48083 L p
.44175 .49216 L 1 g
F P
s
P
p
.44175 .49216 m .4419 .49276 L .43809 .49571 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .44173 .49312 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46138 .48788 m .44827 .51835 L p
.4419 .49276 L 1 g
F P
s
P
p
.002 w
.43893 .48083 m .44653 .48322 L p
.4419 .49276 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45112 .4831 L 1 g
F P
s
P
p
.002 w
.46138 .48788 m .4499 .48428 L p
.45689 .47748 L 1 g
F P
s
P
p
.45112 .4831 m .45191 .48233 L .4499 .48428 L 1 g
F
P
p
.45112 .4831 m .4499 .48428 L .44258 .49136 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4428 .44488 m .47591 .45515 L .47292 .46188 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45689 .47748 m .4577 .47669 L .46138 .48788 L 1 g
F
P
p
.002 w
.46865 .4715 m .46138 .48788 L p
.4577 .47669 L 1 g
F P
s
P
p
.002 w
.48158 .5006 m .46138 .48788 L .46865 .4715 L p
1 g
F P
s
P
p
.47741 .46723 m .48158 .5006 L .46865 .4715 L 1 g
F
P
p
.002 w
.50565 .47392 m .48158 .5006 L p
.47741 .46723 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47757 .46716 L p
1 g
F P
s
P
p
.45826 .47608 m .47757 .46716 L .4738 .46899 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47757 .46716 m .47786 .46667 L p
.48918 .46552 L 1 g
F P
s
P
p
.47757 .46716 m .50565 .47392 L .47741 .46723 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46384 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50565 .47392 m .49176 .46516 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46708 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.52239 .46708 m .52842 .49888 L .51256 .46581 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54219 .47658 L p
1 g
F P
s
P
p
.52214 .46667 m .54219 .47658 L .52973 .4706 L 1 g
F
P
p
.52911 .4703 m .52842 .49888 L .52239 .46708 L 1 g
F
P
p
.002 w
.52239 .46708 m .52214 .46667 L p
.52973 .4706 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56594 .5092 L p
1 g
F P
s
P
p
.002 w
.57552 .51447 m .56954 .51667 L p
.56594 .5092 L 1 g
F P
s
P
p
.558 .49273 m .56515 .5016 L .56594 .5092 L 1 g
F
P
p
.56515 .5016 m .57552 .51447 L .56594 .5092 L 1 g
F
P
p
.002 w
.56594 .5092 m .56515 .50826 L p
.56689 .51957 L 1 g
F P
s
P
p
.002 w
.56682 .51767 m .57552 .51447 L p
.56712 .52521 L 1 g
F P
s
P
p
.56689 .51957 m .56727 .52201 L .56682 .51767 L 1 g
F
P
p
.56689 .51957 m .56682 .51767 L .56594 .5092 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56724 .52836 L p
1 g
F P
s
P
p
.57552 .51447 m .56815 .55162 L .56724 .52836 L 1 g
F
P
p
.56895 .52287 m .56724 .52836 L .56712 .52521 L 1 g
F
P
p
.57552 .51447 m .56724 .52836 L .56895 .52287 L 1 g
F
P
p
.002 w
.56724 .52836 m .56654 .52734 L p
.5651 .53524 L 1 g
F P
s
P
p
.56515 .50826 m .56724 .52836 L .56698 .52165 L 1 g
F
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56144 .54697 L p
1 g
F P
s
P
p
.56724 .52836 m .56761 .53788 L .56332 .54094 L 1 g
F
P
p
.002 w
.56815 .55162 m .55733 .55303 L p
.56761 .53788 L 1 g
F P
s
P
p
.56654 .52734 m .56144 .54697 L .5651 .53524 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54909 .56278 L p
1 g
F P
s
P
p
.578 .55034 m .53584 .57846 L .54909 .56278 L 1 g
F
P
p
.002 w
.55733 .55303 m .56358 .55222 L p
.54909 .56278 L 1 g
F P
s
P
p
.002 w
.56358 .55222 m .578 .55034 L p
.54909 .56278 L 1 g
F P
s
P
p
.002 w
.54909 .56278 m .54854 .56129 L p
.5401 .56934 L 1 g
F P
s
P
p
.56075 .54566 m .54909 .56278 L .55412 .55683 L 1 g
F
P
p
.56075 .54566 m .54967 .56433 L .55387 .55814 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57466 L p
1 g
F P
s
P
p
.002 w
.53558 .57923 m .52719 .57744 L p
.53172 .57466 L 1 g
F P
s
P
p
.002 w
.5386 .57043 m .53783 .57268 L p
.53172 .57466 L 1 g
F P
s
P
p
.002 w
.53783 .57268 m .53558 .57923 L p
.53172 .57466 L 1 g
F P
s
P
p
.002 w
.53172 .57466 m .53128 .57265 L p
.52124 .5778 L 1 g
F P
s
P
p
.002 w
.52473 .57692 m .5354 .57919 L p
.51092 .58039 L 1 g
F P
s
P
p
.52124 .5778 m .51991 .57848 L .52473 .57692 L 1 g
F
P
p
.52124 .5778 m .52473 .57692 L .53172 .57466 L 1 g
F
P
p
.002 w
.49448 .5812 m .50282 .57226 L .52473 .57692 L p
1 g
F P
s
P
p
.51092 .58039 m .49448 .5812 L .52473 .57692 L 1 g
F
P
p
.54854 .56129 m .53172 .57466 L .53525 .57249 L 1 g
F
P
p
.54854 .56129 m .53187 .57534 L .5401 .56934 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52719 .57744 m .50282 .57226 L p
.5386 .57043 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57466 L p
1 g
F P
s
P
p
.51991 .57848 m .51111 .583 L .53172 .57466 L 1 g
F
P
p
.002 w
.53172 .57466 m .53187 .57534 L p
.53525 .57249 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.54398 .55477 m .5386 .57043 L p
.50282 .57226 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.54398 .55477 m .55733 .55303 L p
.54909 .56278 L 1 g
F P
s
P
p
.002 w
.53584 .57846 m .5386 .57043 L p
.54909 .56278 L 1 g
F P
s
P
p
.002 w
.5386 .57043 m .54398 .55477 L p
.54909 .56278 L 1 g
F P
s
P
p
.002 w
.53187 .57534 m .5322 .57686 L p
.5401 .56934 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54909 .56278 L p
1 g
F P
s
P
p
.5401 .56934 m .5322 .57686 L .54909 .56278 L 1 g
F
P
p
.002 w
.54909 .56278 m .54967 .56433 L p
.55412 .55683 L 1 g
F P
s
P
p
.002 w
.53558 .57923 m .53584 .57846 L p
.578 .55034 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55733 .55303 m .54398 .55477 L p
.56761 .53788 L 1 g
F P
s
P
p
.002 w
.56144 .54697 m .56257 .5491 L p
.5651 .53524 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56712 .52521 m .56724 .52836 L .54398 .55477 L 1 g
F
P
p
.56724 .52836 m .56332 .54094 L .54398 .55477 L 1 g
F
P
p
.002 w
.54967 .56433 m .54998 .56518 L p
.55387 .55814 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56724 .52836 L p
1 g
F P
s
P
p
.5651 .53524 m .56257 .5491 L .56724 .52836 L 1 g
F
P
p
.002 w
.56724 .52836 m .56805 .52954 L p
.56698 .52165 L 1 g
F P
s
P
p
.002 w
.57552 .51447 m .578 .55034 L .56815 .55162 L p
1 g
F P
s
P
p
.56515 .50826 m .56805 .52954 L .56727 .52201 L 1 g
F
P
p
.55661 .4905 m .56594 .5092 L .56071 .49835 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55727 .4912 m .55661 .4905 L p
.56071 .49835 L 1 g
F P
s
P
p
.002 w
.57091 .50439 m .57552 .51447 L p
.55504 .48904 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55727 .4912 L p
1 g
F P
s
P
p
.56071 .49835 m .56713 .51061 L .55727 .4912 L 1 g
F
P
p
.002 w
.5589 .47811 m .57091 .50439 L p
.55727 .4912 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55727 .4912 L p
1 g
F P
s
P
p
.54174 .47608 m .55727 .4912 L .55252 .48661 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55554 .48762 m .55727 .4912 L .55504 .48904 L 1 g
F
P
p
.5589 .47811 m .55727 .4912 L .55554 .48762 L 1 g
F
P
p
.558 .49273 m .56594 .5092 L .54163 .52695 L 1 g
F
P
p
.002 w
.56954 .51667 m .56682 .51767 L p
.56594 .5092 L 1 g
F P
s
P
p
.002 w
.56682 .51767 m .54163 .52695 L p
.56594 .5092 L 1 g
F P
s
P
p
.002 w
.56805 .52954 m .56854 .53025 L p
.56727 .52201 L 1 g
F P
s
P
p
.002 w
.54398 .55477 m .54163 .52695 L .56682 .51767 L p
1 g
F P
s
P
p
.56712 .52521 m .54398 .55477 L .56682 .51767 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56594 .5092 L p
1 g
F P
s
P
p
.56727 .52201 m .56854 .53025 L .56594 .5092 L 1 g
F
P
p
.002 w
.56594 .5092 m .56713 .51061 L p
.56071 .49835 L 1 g
F P
s
P
p
.55504 .48904 m .558 .49273 L .54163 .52695 L 1 g
F
P
p
.002 w
.54163 .52695 m .52842 .49888 L .55 .48418 L p
1 g
F P
s
P
p
.54174 .47608 m .55252 .48661 L .55054 .4847 L 1 g
F
P
p
.55504 .48904 m .54163 .52695 L .55 .48418 L 1 g
F
P
p
.002 w
.55 .48418 m .52842 .49888 L p
.52926 .46398 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.55 .48418 m .5589 .47811 L p
.55504 .48904 L 1 g
F P
s
P
p
.55054 .4847 m .55787 .49183 L .55121 .48536 L 1 g
F
P
p
.55252 .48661 m .55787 .49183 L .55054 .4847 L 1 g
F
P
p
.002 w
.55727 .4912 m .55787 .49183 L p
.55252 .48661 L 1 g
F P
s
P
p
.002 w
.52969 .44571 m .5589 .47811 L .55 .48418 L p
1 g
F P
s
P
p
.52969 .44571 m .55 .48418 L .52926 .46398 L 1 g
F
P
p
.002 w
.55787 .49183 m .55834 .49233 L p
.55121 .48536 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52239 .46708 L p
1 g
F P
s
P
p
.52973 .4706 m .54302 .47747 L .52239 .46708 L 1 g
F
P
p
.52969 .44571 m .52916 .46796 L .52239 .46708 L 1 g
F
P
p
.5 .4634 m .52239 .46708 L .5167 .46634 L 1 g
F
P
p
.5 .4634 m .52257 .46737 L .5123 .46576 L 1 g
F
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.51256 .46581 m .51464 .46337 L p
.52239 .46708 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51464 .46337 m .52969 .44571 L p
.52239 .46708 L 1 g
F P
s
P
p
.52916 .46796 m .52911 .4703 L .52239 .46708 L 1 g
F
P
p
.002 w
.54219 .47658 m .54302 .47747 L p
.52973 .4706 L 1 g
F P
s
P
p
.002 w
.52239 .46708 m .52257 .46737 L p
.5167 .46634 L 1 g
F P
s
P
p
.002 w
.52842 .49888 m .50565 .47392 L .51256 .46581 L p
1 g
F P
s
P
p
.50302 .46431 m .50565 .47392 L .5 .46384 L 1 g
F
P
p
.002 w
.5 .46384 m .5 .4634 L p
.5123 .46576 L 1 g
F P
s
P
p
.002 w
.49129 .42141 m .52969 .44571 L .50565 .47392 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46384 L p
1 g
F P
s
P
p
.5123 .46576 m .52282 .46778 L .5 .46384 L 1 g
F
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.50277 .46339 m .5 .46384 L .47591 .45515 L 1 g
F
P
p
.47786 .46667 m .5 .46384 L .49597 .46448 L 1 g
F
P
p
.47786 .46667 m .5 .46399 L .48918 .46552 L 1 g
F
P
p
.002 w
.49176 .46516 m .48625 .46168 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.48625 .46168 m .47591 .45515 L p
.5 .46384 L 1 g
F P
s
P
p
.50277 .46339 m .50302 .46431 L .5 .46384 L 1 g
F
P
p
.002 w
.52257 .46737 m .52282 .46778 L p
.5123 .46576 L 1 g
F P
s
P
p
.002 w
.5 .46384 m .5 .46399 L p
.49597 .46448 L 1 g
F P
s
P
p
.002 w
.47591 .45515 m .49129 .42141 L p
.50277 .46339 L 1 g
F P
s
P
p
.002 w
.48737 .46238 m .49176 .46516 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.49176 .46516 m .50565 .47392 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.5 .46399 m .5 .46442 L p
.48918 .46552 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47757 .46716 L p
1 g
F P
s
P
p
.48918 .46552 m .5 .46442 L .47757 .46716 L 1 g
F
P
p
.002 w
.47591 .45515 m .48737 .46238 L p
.47757 .46716 L 1 g
F P
s
P
p
.47741 .46718 m .47757 .46716 L .47741 .46723 L 1 g
F
P
p
.47591 .45515 m .47757 .46716 L .47741 .46718 L 1 g
F
P
p
.002 w
.47757 .46716 m .47747 .46732 L p
.4738 .46899 L 1 g
F P
s
P
p
.002 w
.47747 .46732 m .47718 .46778 L p
.46795 .47183 L 1 g
F P
s
P
p
.45826 .47608 m .47747 .46732 L .46795 .47183 L 1 g
F
P
p
.002 w
.4577 .47669 m .45826 .47608 L p
.46795 .47183 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4577 .47669 L p
1 g
F P
s
P
p
.4428 .44488 m .47292 .46188 L .4577 .47669 L 1 g
F
P
p
.45674 .47715 m .4577 .47669 L .45689 .47748 L 1 g
F
P
p
.4428 .44488 m .4577 .47669 L .45674 .47715 L 1 g
F
P
p
.002 w
.46865 .4715 m .47591 .45515 L p
.47741 .46723 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45747 .47694 L p
1 g
F P
s
P
p
.002 w
.45747 .47694 m .4577 .47669 L p
.46242 .47453 L 1 g
F P
s
P
p
.46242 .47453 m .47718 .46778 L .45747 .47694 L 1 g
F
P
p
.46795 .47183 m .47718 .46778 L .4577 .47669 L 1 g
F
P
p
.002 w
.47292 .46188 m .46865 .4715 L p
.4577 .47669 L 1 g
F P
s
P
p
.002 w
.4577 .47669 m .45734 .47708 L p
.4535 .48078 L 1 g
F P
s
P
p
.44339 .4905 m .4577 .47669 L .4535 .48078 L 1 g
F
P
p
.002 w
.45734 .47708 m .45698 .47747 L p
.45191 .48233 L 1 g
F P
s
P
p
.44339 .4905 m .45734 .47708 L .45191 .48233 L 1 g
F
P
p
.44258 .49136 m .46138 .48788 L .4419 .49276 L 1 g
F
P
p
.002 w
.44653 .48322 m .4499 .48428 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.4499 .48428 m .46138 .48788 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.43893 .48083 m .4428 .44488 L p
.45689 .47748 L 1 g
F P
s
P
p
.002 w
.4499 .48428 m .43893 .48083 L p
.45689 .47748 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44248 .49147 L p
.44173 .49312 L 1 g
F P
s
P
p
.002 w
.44248 .49147 m .44166 .49233 L p
.43841 .49993 L 1 g
F P
s
P
p
.43485 .50826 m .44248 .49147 L .43841 .49993 L 1 g
F
P
p
.002 w
.41686 .48022 m .43893 .48083 L .43777 .50127 L p
1 g
F P
s
P
p
.43836 .50005 m .43777 .50127 L .43383 .50948 L 1 g
F
P
p
.002 w
.43777 .50127 m .437 .51477 L p
.43387 .50939 L 1 g
F P
s
P
p
.41686 .48022 m .43777 .50127 L .43387 .50939 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44258 .49136 L p
1 g
F P
s
P
p
.45191 .48233 m .45698 .47747 L .44258 .49136 L 1 g
F
P
p
.43836 .50005 m .43841 .49993 L .43777 .50127 L 1 g
F
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44827 .51835 m .437 .51477 L .43777 .50127 L p
1 g
F P
s
P
p
.4419 .49276 m .44827 .51835 L .43777 .50127 L 1 g
F
P
p
.43346 .52734 m .43383 .50948 L .43308 .51634 L 1 g
F
P
p
.002 w
.437 .51477 m .43326 .51464 L p
.43384 .50935 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43383 .50948 L p
1 g
F P
s
P
p
.43841 .49993 m .44166 .49233 L .43383 .50948 L 1 g
F
P
p
.002 w
.43383 .50948 m .43287 .51061 L p
.43308 .51634 L 1 g
F P
s
P
p
.002 w
.437 .51477 m .43703 .54423 L p
.43253 .5287 L 1 g
F P
s
P
p
.002 w
.43326 .51464 m .437 .51477 L p
.43253 .5287 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52872 L p
1 g
F P
s
P
p
.002 w
.43251 .52872 m .43253 .5287 L p
.43254 .5282 L 1 g
F P
s
P
p
.43254 .5282 m .43287 .51061 L .43251 .52872 L 1 g
F
P
p
.002 w
.437 .51477 m .44827 .51835 L .43724 .54496 L p
1 g
F P
s
P
p
.002 w
.43703 .54423 m .437 .51477 L p
.43724 .54496 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44827 .51835 m .45842 .52473 L .43731 .5452 L p
1 g
F P
s
P
p
.002 w
.43731 .5452 m .43703 .54547 L .43724 .54496 L p
1 g
F P
s
P
p
.002 w
.43724 .54496 m .44827 .51835 L p
.43731 .5452 L 1 g
F P
s
P
p
.43501 .5376 m .43476 .53712 L .436 .54087 L 1 g
F
P
p
.43476 .53712 m .43334 .53442 L .43715 .54469 L 1 g
F
P
p
.43273 .53325 m .43744 .54559 L .43823 .54759 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45842 .52473 m .46631 .53317 L .43736 .54533 L p
1 g
F P
s
P
p
.002 w
.43736 .54533 m .43703 .54547 L .43731 .5452 L p
1 g
F P
s
P
p
.002 w
.43731 .5452 m .45842 .52473 L p
.43736 .54533 L 1 g
F P
s
P
p
.4322 .53226 m .43788 .54672 L .43823 .54759 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43823 .54759 L p
1 g
F P
s
P
p
.002 w
.4475 .56076 m .43995 .54973 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.43995 .54973 m .4475 .56076 L p
.43836 .54792 L 1 g
F P
s
P
p
.43836 .54792 m .43823 .54759 L .43995 .54973 L 1 g
F
P
p
.44715 .5605 m .43729 .54641 L .4475 .56076 L 1 g
F
P
p
.002 w
.43959 .5548 m .43729 .54641 L p
.44715 .5605 L 1 g
F P
s
P
p
.002 w
.44447 .57257 m .4334 .5705 L .43695 .54599 L p
1 g
F P
s
P
p
.002 w
.43695 .54599 m .43703 .54547 L .43729 .54641 L p
1 g
F P
s
P
p
.002 w
.43729 .54641 m .44447 .57257 L p
.43695 .54599 L 1 g
F P
s
P
p
.002 w
.43823 .54759 m .43822 .5476 L p
.44409 .55489 L 1 g
F P
s
P
p
.002 w
.43822 .5476 m .43743 .5491 L p
.44371 .55456 L 1 g
F P
s
P
p
.44409 .55489 m .43822 .5476 L .44371 .55456 L 1 g
F
P
p
.45146 .56129 m .43823 .54759 L .44409 .55489 L 1 g
F
P
p
.4593 .56951 m .45076 .56318 L .43788 .54672 L 1 g
F
P
p
.002 w
.43995 .54973 m .43788 .54672 L p
.45076 .56318 L 1 g
F P
s
P
p
.002 w
.47217 .55231 m .46956 .56089 L .43748 .54569 L p
1 g
F P
s
P
p
.002 w
.43748 .54569 m .43703 .54547 L .43743 .54555 L p
1 g
F P
s
P
p
.002 w
.43743 .54555 m .47217 .55231 L p
.43748 .54569 L 1 g
F P
s
P
p
.43334 .53442 m .43273 .53325 L .43706 .54455 L 1 g
F
P
p
.43273 .53325 m .4322 .53226 L .43744 .54559 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46956 .56089 m .46358 .56753 L .43757 .54592 L p
1 g
F P
s
P
p
.002 w
.43757 .54592 m .43703 .54547 L .43748 .54569 L p
1 g
F P
s
P
p
.002 w
.43748 .54569 m .46956 .56089 L p
.43757 .54592 L 1 g
F P
s
P
p
.002 w
.43788 .54672 m .43703 .54547 L p
.43766 .54616 L 1 g
F P
s
P
p
.4593 .56951 m .43788 .54672 L .43766 .54616 L 1 g
F
P
p
.002 w
.46358 .56753 m .4593 .56951 L p
.43766 .54616 L 1 g
F P
s
P
p
.002 w
.43703 .54547 m .43757 .54592 L p
.43766 .54616 L 1 g
F P
s
P
p
.002 w
.43757 .54592 m .46358 .56753 L p
.43766 .54616 L 1 g
F P
s
P
p
.43836 .54792 m .43729 .54641 L .43823 .54759 L 1 g
F
P
p
.002 w
.43729 .54641 m .43703 .54547 L .43995 .54973 L p
1 g
F P
s
P
p
.002 w
.42285 .56557 m .41391 .55831 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.4334 .5705 m .42285 .56557 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.41391 .55831 m .40752 .54945 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.40752 .54945 m .40436 .53992 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.40436 .53992 m .40482 .53072 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.40482 .53072 m .40888 .52285 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.40888 .52285 m .41615 .51718 L .43703 .54547 L closepath p
1 g
F P
s
P
p
.002 w
.43193 .53174 m .43743 .5491 L .43823 .54759 L p
1 g
F P
s
P
p
.002 w
.43823 .54759 m .43823 .54759 L p
.43788 .54672 L 1 g
F P
s
P
p
.43788 .54672 m .43193 .53174 L .43823 .54759 L 1 g
F
P
p
.4322 .53226 m .43193 .53174 L .43788 .54672 L 1 g
F
P
p
.43312 .51745 m .43287 .51061 L .43253 .5287 L 1 g
F
P
p
.43522 .538 m .43404 .53535 L .4344 .53643 L 1 g
F
P
p
.43501 .53728 m .43404 .53535 L .43522 .538 L 1 g
F
P
p
.4344 .53643 m .43345 .5342 L .43392 .53552 L 1 g
F
P
p
.43404 .53535 m .43345 .5342 L .4344 .53643 L 1 g
F
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.46631 .53317 m .47105 .54272 L .43739 .54544 L p
1 g
F P
s
P
p
.002 w
.43736 .54533 m .46631 .53317 L p
.43739 .54544 L 1 g
F P
s
P
p
.002 w
.47105 .54272 m .47217 .55231 L .43743 .54555 L p
1 g
F P
s
P
p
.002 w
.43739 .54544 m .47105 .54272 L p
.43743 .54555 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43193 .53174 L p
.43392 .53552 L 1 g
F P
s
P
p
.43345 .5342 m .43146 .53025 L .43392 .53552 L 1 g
F
P
p
.002 w
.4475 .56076 m .4549 .57156 L p
.44715 .5605 L 1 g
F P
s
P
p
.45559 .5674 m .45002 .56518 L .46066 .57068 L 1 g
F
P
p
.45854 .56908 m .46066 .57068 L .46829 .57462 L 1 g
F
P
p
.45559 .5674 m .46066 .57068 L .45854 .56908 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46795 .57617 L p
1 g
F P
s
P
p
.002 w
.46795 .57617 m .46829 .57462 L p
.46066 .57068 L 1 g
F P
s
P
p
.46066 .57068 m .45002 .56518 L .46795 .57617 L 1 g
F
P
p
.002 w
.4549 .57156 m .44447 .57257 L .43959 .5548 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45075 .56321 L p
1 g
F P
s
P
p
.002 w
.45075 .56321 m .45076 .56318 L p
.45052 .56293 L 1 g
F P
s
P
p
.45052 .56293 m .43743 .5491 L .45075 .56321 L 1 g
F
P
p
.002 w
.4503 .5644 m .45002 .56518 L p
.45559 .5674 L 1 g
F P
s
P
p
.44409 .55489 m .43743 .5491 L .45076 .56318 L 1 g
F
P
p
.45747 .56816 m .45559 .5674 L .4593 .56951 L 1 g
F
P
p
.47821 .57772 m .47793 .57769 L .48038 .57839 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58087 L p
1 g
F P
s
P
p
.47793 .57769 m .4678 .57686 L .48904 .58087 L 1 g
F
P
p
.002 w
.48904 .58087 m .48889 .583 L p
.49708 .58136 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.50282 .57226 m .49448 .5812 L p
.46358 .56753 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58039 L p
1 g
F P
s
P
p
.49898 .58098 m .48889 .583 L .51092 .58039 L 1 g
F
P
p
.002 w
.51092 .58039 m .51111 .583 L p
.52124 .5778 L 1 g
F P
s
P
p
.002 w
.51776 .59779 m .53558 .57923 L .5667 .58165 L p
1 g
F P
s
P
p
.002 w
.37075 .41981 m .34481 .44222 L .3326 .4144 L p
1 g
F P
s
P
p
.002 w
.3326 .4144 m .36318 .38721 L .37075 .41981 L p
1 g
F P
s
P
p
.002 w
.40436 .53992 m .40752 .54945 L .38154 .54979 L p
1 g
F P
s
P
p
.002 w
.38154 .54979 m .3752 .5312 L .40436 .53992 L p
1 g
F P
s
P
p
.004 w
.45099 .51998 m
.46673 .49125 L
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47378 .30873 m .41262 .30954 L .41988 .28419 L p
1 g
F P
s
P
p
.002 w
.41988 .28419 m .48382 .28295 L .47378 .30873 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.578 .55034 m .5667 .58165 L .53558 .57923 L p
1 g
F P
s
P
p
.002 w
.5667 .58165 m .578 .55034 L .60915 .54238 L p
1 g
F P
s
P
p
.002 w
.44447 .57257 m .4549 .57156 L .4737 .59284 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.65143 .38982 m .6079 .33941 L .61956 .31931 L p
1 g
F P
s
P
p
.002 w
.56047 .28153 m .61956 .31931 L .6079 .33941 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.38355 .49745 m .37583 .51311 L .35105 .49333 L p
1 g
F P
s
P
p
.002 w
.35105 .49333 m .36196 .47024 L .38355 .49745 L p
1 g
F P
s
P
p
.002 w
.63445 .41099 m .65719 .46483 L .63429 .48278 L p
1 g
F P
s
P
p
.002 w
.65719 .46483 m .63445 .41099 L .65143 .38982 L p
1 g
F P
s
P
p
.002 w
.6079 .33941 m .54944 .30208 L .56047 .28153 L p
1 g
F P
s
P
p
.002 w
.40482 .53072 m .40436 .53992 L .3752 .5312 L p
1 g
F P
s
P
p
.002 w
.3752 .5312 m .37583 .51311 L .40482 .53072 L p
1 g
F P
s
P
p
.002 w
.40578 .37244 m .36318 .38721 L .35985 .35652 L p
1 g
F P
s
P
p
.002 w
.35985 .35652 m .40783 .33928 L .40578 .37244 L p
1 g
F P
s
P
p
.002 w
.6079 .33941 m .65143 .38982 L .63445 .41099 L p
1 g
F P
s
P
p
.002 w
.60678 .49955 m .60915 .54238 L .578 .55034 L p
1 g
F P
s
P
p
.002 w
.60915 .54238 m .60678 .49955 L .63429 .48278 L p
1 g
F P
s
P
p
.002 w
.38239 .45316 m .36196 .47024 L .34481 .44222 L p
1 g
F P
s
P
p
.002 w
.34481 .44222 m .37075 .41981 L .38239 .45316 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.46428 .33893 m .40783 .33928 L .41262 .30954 L p
1 g
F P
s
P
p
.002 w
.41262 .30954 m .47378 .30873 L .46428 .33893 L p
1 g
F P
s
P
p
.004 w
.38242 .29791 m
.41383 .33334 L
s
P
p
.002 w
.40888 .52285 m .40482 .53072 L .37583 .51311 L p
1 g
F P
s
P
p
.002 w
.37583 .51311 m .38355 .49745 L .40888 .52285 L p
1 g
F P
s
P
p
.002 w
.53655 .32723 m .47378 .30873 L .48382 .28295 L p
1 g
F P
s
P
p
.002 w
.48382 .28295 m .54944 .30208 L .53655 .32723 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61289 .4333 m .63429 .48278 L .60678 .49955 L p
1 g
F P
s
P
p
.002 w
.63429 .48278 m .61289 .4333 L .63445 .41099 L p
1 g
F P
s
P
p
.002 w
.39771 .48602 m .38355 .49745 L .36196 .47024 L p
1 g
F P
s
P
p
.002 w
.36196 .47024 m .38239 .45316 L .39771 .48602 L p
1 g
F P
s
P
p
.002 w
.40662 .40787 m .37075 .41981 L .36318 .38721 L p
1 g
F P
s
P
p
.002 w
.36318 .38721 m .40578 .37244 L .40662 .40787 L p
1 g
F P
s
P
p
.002 w
.578 .55034 m .57552 .51447 L .60678 .49955 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46358 .56753 m .46956 .56089 L .50282 .57226 L p
1 g
F P
s
P
p
.002 w
.50826 .55545 m .50282 .57226 L .46956 .56089 L p
1 g
F P
s
P
p
.002 w
.50282 .57226 m .50826 .55545 L .54398 .55477 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.63445 .41099 m .59258 .36293 L .6079 .33941 L p
1 g
F P
s
P
p
.002 w
.54944 .30208 m .6079 .33941 L .59258 .36293 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59258 .36293 m .53655 .32723 L .54944 .30208 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59258 .36293 m .63445 .41099 L .61289 .4333 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.41615 .51718 m .40888 .52285 L .38355 .49745 L p
1 g
F P
s
P
p
.002 w
.38355 .49745 m .39771 .48602 L .41615 .51718 L p
1 g
F P
s
P
p
.002 w
.46956 .56089 m .47217 .55231 L .50826 .55545 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.54163 .52695 m .54398 .55477 L .50826 .55545 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41035 .44427 m .38239 .45316 L .37075 .41981 L p
1 g
F P
s
P
p
.002 w
.37075 .41981 m .40662 .40787 L .41035 .44427 L p
1 g
F P
s
P
p
.002 w
.45573 .37253 m .40578 .37244 L .40783 .33928 L p
1 g
F P
s
P
p
.004 w
.44857 .37252 m
.49276 .42234 L
s
P
p
.002 w
.40783 .33928 m .46428 .33893 L .45573 .37253 L p
1 g
F P
s
P
p
.004 w
.42615 .34723 m
.42675 .3479 L
s
P
p
.004 w
.41383 .33334 m
.42615 .34723 L
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.58741 .45596 m .60678 .49955 L .57552 .51447 L p
1 g
F P
s
P
p
.002 w
.60678 .49955 m .58741 .45596 L .61289 .4333 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.50636 .53648 m .50826 .55545 L .47217 .55231 L p
1 g
F P
s
P
p
.002 w
.50826 .55545 m .50636 .53648 L .54163 .52695 L p
1 g
F P
s
P
p
.002 w
.47217 .55231 m .47105 .54272 L .50636 .53648 L p
1 g
F P
s
P
p
.002 w
.52221 .3562 m .46428 .33893 L .47378 .30873 L p
1 g
F P
s
P
p
.002 w
.47378 .30873 m .53655 .32723 L .52221 .3562 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42588 .51437 m .41615 .51718 L .39771 .48602 L p
1 g
F P
s
P
p
.002 w
.41686 .48022 m .39771 .48602 L .38239 .45316 L p
1 g
F P
s
P
p
.002 w
.38239 .45316 m .41035 .44427 L .41686 .48022 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.39771 .48602 m .41686 .48022 L .42588 .51437 L p
1 g
F P
s
P
p
.002 w
.47105 .54272 m .46631 .53317 L .49716 .51746 L p
1 g
F P
s
P
p
.002 w
.49716 .51746 m .50636 .53648 L .47105 .54272 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.61289 .4333 m .57399 .38912 L .59258 .36293 L p
1 g
F P
s
P
p
.002 w
.53655 .32723 m .59258 .36293 L .57399 .38912 L p
1 g
F P
s
P
p
.002 w
.57552 .51447 m .5589 .47811 L .58741 .45596 L p
1 g
F P
s
P
p
.002 w
.57399 .38912 m .61289 .4333 L .58741 .45596 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.44847 .40831 m .40662 .40787 L .40578 .37244 L p
1 g
F P
s
P
p
.002 w
.40578 .37244 m .45573 .37253 L .44847 .40831 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57399 .38912 m .52221 .3562 L .53655 .32723 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46631 .53317 m .45842 .52473 L .48158 .5006 L p
1 g
F P
s
P
p
.002 w
.48158 .5006 m .49716 .51746 L .46631 .53317 L p
1 g
F P
s
P
p
.002 w
.50636 .53648 m .49716 .51746 L .52842 .49888 L p
1 g
F P
s
P
p
.002 w
.52842 .49888 m .54163 .52695 L .50636 .53648 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.45842 .52473 m .44827 .51835 L .46138 .48788 L p
1 g
F P
s
P
p
.002 w
.46138 .48788 m .48158 .5006 L .45842 .52473 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50693 .38799 m .45573 .37253 L .46428 .33893 L p
1 g
F P
s
P
p
.002 w
.46428 .33893 m .52221 .3562 L .50693 .38799 L p
1 g
F P
s
P
p
.002 w
.43893 .48083 m .41686 .48022 L .41035 .44427 L p
1 g
F P
s
P
p
.002 w
.4428 .44488 m .41035 .44427 L .40662 .40787 L p
1 g
F P
s
P
p
.002 w
.40662 .40787 m .44847 .40831 L .4428 .44488 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.55277 .41707 m .58741 .45596 L .5589 .47811 L p
1 g
F P
s
P
p
.002 w
.58741 .45596 m .55277 .41707 L .57399 .38912 L p
1 g
F P
s
P
p
.002 w
.41035 .44427 m .4428 .44488 L .43893 .48083 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.49716 .51746 m .48158 .5006 L .50565 .47392 L p
1 g
F P
s
P
p
.002 w
.50565 .47392 m .52842 .49888 L .49716 .51746 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52221 .3562 m .57399 .38912 L .55277 .41707 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.55277 .41707 m .50693 .38799 L .52221 .3562 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.5589 .47811 m .52969 .44571 L .55277 .41707 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.49129 .42141 m .44847 .40831 L .45573 .37253 L p
1 g
F P
s
P
p
.002 w
.45573 .37253 m .50693 .38799 L .49129 .42141 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.47591 .45515 m .4428 .44488 L .44847 .40831 L p
1 g
F P
s
P
p
.002 w
.44847 .40831 m .49129 .42141 L .47591 .45515 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.50693 .38799 m .55277 .41707 L .52969 .44571 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52969 .44571 m .49129 .42141 L .50693 .38799 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.004 w
.41099 .59301 m
.41549 .58478 L
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .38115 .29649 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39964 .61373 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.347287)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.347287)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45592 .42018 m .47828 .44698 L .49731 .42572 L p
1 g
F P
s
P
p
.002 w
.49731 .42572 m .48005 .40496 L .45592 .42018 L p
1 g
F P
s
P
p
.002 w
.51985 .44073 m .49731 .42572 L .47828 .44698 L p
1 g
F P
s
P
p
.002 w
.48005 .40496 m .49731 .42572 L .5164 .40458 L p
1 g
F P
s
P
p
.002 w
.49731 .42572 m .51985 .44073 L .53182 .41482 L p
1 g
F P
s
P
p
.002 w
.53182 .41482 m .5164 .40458 L .49731 .42572 L p
1 g
F P
s
P
p
.002 w
.47828 .44698 m .5074 .4664 L .51985 .44073 L p
1 g
F P
s
P
p
.002 w
.54544 .44846 m .51985 .44073 L .5074 .4664 L p
1 g
F P
s
P
p
.002 w
.51985 .44073 m .54544 .44846 L .54931 .42003 L p
1 g
F P
s
P
p
.002 w
.54931 .42003 m .53182 .41482 L .51985 .44073 L p
1 g
F P
s
P
p
.002 w
.43269 .43577 m .45967 .46796 L .47828 .44698 L p
1 g
F P
s
P
p
.002 w
.47828 .44698 m .45592 .42018 L .43269 .43577 L p
1 g
F P
s
P
p
.002 w
.5074 .4664 m .47828 .44698 L .45967 .46796 L p
1 g
F P
s
P
p
.002 w
.5164 .40458 m .50464 .39037 L .48005 .40496 L p
1 g
F P
s
P
p
.002 w
.50464 .39037 m .5164 .40458 L .53523 .38392 L p
1 g
F P
s
P
p
.002 w
.5164 .40458 m .53182 .41482 L .54308 .38913 L p
1 g
F P
s
P
p
.002 w
.54308 .38913 m .53523 .38392 L .5164 .40458 L p
1 g
F P
s
P
p
.002 w
.44257 .3886 m .45592 .42018 L .48005 .40496 L p
1 g
F P
s
P
p
.002 w
.48005 .40496 m .46985 .38049 L .44257 .3886 L p
1 g
F P
s
P
p
.002 w
.46985 .38049 m .48005 .40496 L .50464 .39037 L p
1 g
F P
s
P
p
.002 w
.53182 .41482 m .54931 .42003 L .552 .39174 L p
1 g
F P
s
P
p
.002 w
.552 .39174 m .54308 .38913 L .53182 .41482 L p
1 g
F P
s
P
p
.002 w
.45967 .46796 m .49469 .49137 L .5074 .4664 L p
1 g
F P
s
P
p
.002 w
.54045 .47653 m .5074 .4664 L .49469 .49137 L p
1 g
F P
s
P
p
.002 w
.5074 .4664 m .54045 .47653 L .54544 .44846 L p
1 g
F P
s
P
p
.002 w
.50464 .39037 m .49777 .37364 L .46985 .38049 L p
1 g
F P
s
P
p
.002 w
.49777 .37364 m .50464 .39037 L .52926 .37667 L p
1 g
F P
s
P
p
.002 w
.53523 .38392 m .52926 .37667 L .50464 .39037 L p
1 g
F P
s
P
p
.002 w
.41642 .39781 m .43269 .43577 L .45592 .42018 L p
1 g
F P
s
P
p
.002 w
.45592 .42018 m .44257 .3886 L .41642 .39781 L p
1 g
F P
s
P
p
.002 w
.57151 .44805 m .54544 .44846 L .54045 .47653 L p
1 g
F P
s
P
p
.002 w
.54544 .44846 m .57151 .44805 L .56708 .41963 L p
1 g
F P
s
P
p
.002 w
.56708 .41963 m .54931 .42003 L .54544 .44846 L p
1 g
F P
s
P
p
.002 w
.54931 .42003 m .56708 .41963 L .56102 .39148 L p
1 g
F P
s
P
p
.002 w
.56102 .39148 m .552 .39174 L .54931 .42003 L p
1 g
F P
s
P
p
.002 w
.41081 .45143 m .44182 .48828 L .45967 .46796 L p
1 g
F P
s
P
p
.002 w
.45967 .46796 m .43269 .43577 L .41081 .45143 L p
1 g
F P
s
P
p
.002 w
.49469 .49137 m .45967 .46796 L .44182 .48828 L p
1 g
F P
s
P
p
.002 w
.46784 .35477 m .46985 .38049 L .49777 .37364 L p
1 g
F P
s
P
p
.002 w
.49777 .37364 m .49653 .3561 L .46784 .35477 L p
1 g
F P
s
P
p
.002 w
.49653 .3561 m .49777 .37364 L .5258 .36814 L p
1 g
F P
s
P
p
.002 w
.52926 .37667 m .5258 .36814 L .49777 .37364 L p
1 g
F P
s
P
p
.002 w
.43971 .35529 m .44257 .3886 L .46985 .38049 L p
1 g
F P
s
P
p
.002 w
.46985 .38049 m .46784 .35477 L .43971 .35529 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .52926 .37667 L .53523 .38392 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .53523 .38392 L .54308 .38913 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .54308 .38913 L .552 .39174 L closepath p
1 g
F P
s
P
p
.002 w
.44182 .48828 m .48195 .51516 L .49469 .49137 L p
1 g
F P
s
P
p
.002 w
.53444 .50371 m .49469 .49137 L .48195 .51516 L p
1 g
F P
s
P
p
.002 w
.49469 .49137 m .53444 .50371 L .54045 .47653 L p
1 g
F P
s
P
p
.002 w
.57421 .47622 m .54045 .47653 L .53444 .50371 L p
1 g
F P
s
P
p
.002 w
.54045 .47653 m .57421 .47622 L .57151 .44805 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .5258 .36814 L .52926 .37667 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .552 .39174 L .56102 .39148 L closepath p
1 g
F P
s
P
p
.002 w
.5258 .36814 m .52524 .35924 L .49653 .3561 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .52524 .35924 L .5258 .36814 L closepath p
1 g
F P
s
P
p
.002 w
.39194 .40797 m .41081 .45143 L .43269 .43577 L p
1 g
F P
s
P
p
.002 w
.43269 .43577 m .41642 .39781 L .39194 .40797 L p
1 g
F P
s
P
p
.002 w
.58328 .4136 m .56708 .41963 L .57151 .44805 L p
1 g
F P
s
P
p
.002 w
.56708 .41963 m .58328 .4136 L .5692 .38835 L p
1 g
F P
s
P
p
.002 w
.5692 .38835 m .56102 .39148 L .56708 .41963 L p
1 g
F P
s
P
p
.002 w
.41269 .35768 m .41642 .39781 L .44257 .3886 L p
1 g
F P
s
P
p
.002 w
.44257 .3886 m .43971 .35529 L .41269 .35768 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .56102 .39148 L .5692 .38835 L closepath p
1 g
F P
s
P
p
.002 w
.59538 .4394 m .57151 .44805 L .57421 .47622 L p
1 g
F P
s
P
p
.002 w
.57151 .44805 m .59538 .4394 L .58328 .4136 L p
1 g
F P
s
P
p
.002 w
.4744 .33044 m .46784 .35477 L .49653 .3561 L p
1 g
F P
s
P
p
.002 w
.49653 .3561 m .50115 .33959 L .4744 .33044 L p
1 g
F P
s
P
p
.002 w
.50115 .33959 m .49653 .3561 L .52524 .35924 L p
1 g
F P
s
P
p
.002 w
.52524 .35924 m .52766 .3509 L .50115 .33959 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .52766 .3509 L .52524 .35924 L closepath p
1 g
F P
s
P
p
.002 w
.48195 .51516 m .52748 .52949 L .53444 .50371 L p
1 g
F P
s
P
p
.002 w
.57512 .50361 m .53444 .50371 L .52748 .52949 L p
1 g
F P
s
P
p
.002 w
.53444 .50371 m .57512 .50361 L .57421 .47622 L p
1 g
F P
s
P
p
.002 w
.57565 .38266 m .5692 .38835 L .58328 .4136 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .5692 .38835 L .57565 .38266 L closepath p
1 g
F P
s
P
p
.002 w
.39072 .46687 m .42508 .50755 L .44182 .48828 L p
1 g
F P
s
P
p
.002 w
.44182 .48828 m .41081 .45143 L .39072 .46687 L p
1 g
F P
s
P
p
.002 w
.48195 .51516 m .44182 .48828 L .42508 .50755 L p
1 g
F P
s
P
p
.002 w
.44793 .32365 m .43971 .35529 L .46784 .35477 L p
1 g
F P
s
P
p
.002 w
.46784 .35477 m .4744 .33044 L .44793 .32365 L p
1 g
F P
s
P
p
.002 w
.51122 .32591 m .50115 .33959 L .52766 .3509 L p
1 g
F P
s
P
p
.002 w
.52766 .3509 m .53282 .34404 L .51122 .32591 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .53282 .34404 L .52766 .3509 L closepath p
1 g
F P
s
P
p
.002 w
.59614 .40248 m .58328 .4136 L .59538 .4394 L p
1 g
F P
s
P
p
.002 w
.58328 .4136 m .59614 .40248 L .57565 .38266 L p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .54896 .33754 L .54018 .33941 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .54018 .33941 L .53282 .34404 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .57565 .38266 L .57966 .37502 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .57966 .37502 L .58075 .36623 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .58075 .36623 L .5788 .35725 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .5788 .35725 L .57399 .34909 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .57399 .34909 L .56686 .34266 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .56686 .34266 L .55819 .33866 L closepath p
1 g
F P
s
P
p
.002 w
.55344 .36413 m .55819 .33866 L .54896 .33754 L closepath p
1 g
F P
s
P
p
.002 w
.42508 .50755 m .46942 .5373 L .48195 .51516 L p
1 g
F P
s
P
p
.002 w
.52748 .52949 m .48195 .51516 L .46942 .5373 L p
1 g
F P
s
P
p
.002 w
.60526 .46528 m .57421 .47622 L .57512 .50361 L p
1 g
F P
s
P
p
.002 w
.57421 .47622 m .60526 .46528 L .59538 .4394 L p
1 g
F P
s
P
p
.002 w
.57966 .37502 m .57565 .38266 L .59614 .40248 L p
1 g
F P
s
P
p
.002 w
.38734 .36195 m .39194 .40797 L .41642 .39781 L p
1 g
F P
s
P
p
.002 w
.41642 .39781 m .41269 .35768 L .38734 .36195 L p
1 g
F P
s
P
p
.002 w
.48904 .31013 m .4744 .33044 L .50115 .33959 L p
1 g
F P
s
P
p
.002 w
.50115 .33959 m .51122 .32591 L .48904 .31013 L p
1 g
F P
s
P
p
.002 w
.36965 .41891 m .39072 .46687 L .41081 .45143 L p
1 g
F P
s
P
p
.002 w
.41081 .45143 m .39194 .40797 L .36965 .41891 L p
1 g
F P
s
P
p
.002 w
.52574 .31659 m .51122 .32591 L .53282 .34404 L p
1 g
F P
s
P
p
.002 w
.53282 .34404 m .54018 .33941 L .52574 .31659 L p
1 g
F P
s
P
p
.002 w
.61448 .42323 m .59538 .4394 L .60526 .46528 L p
1 g
F P
s
P
p
.002 w
.59538 .4394 m .61448 .42323 L .59614 .40248 L p
1 g
F P
s
P
p
.002 w
.42228 .31941 m .41269 .35768 L .43971 .35529 L p
1 g
F P
s
P
p
.002 w
.43971 .35529 m .44793 .32365 L .42228 .31941 L p
1 g
F P
s
P
p
.002 w
.59614 .40248 m .60422 .38741 L .57966 .37502 L p
1 g
F P
s
P
p
.002 w
.58075 .36623 m .57966 .37502 L .60422 .38741 L p
1 g
F P
s
P
p
.002 w
.54317 .31275 m .52574 .31659 L .54018 .33941 L p
1 g
F P
s
P
p
.002 w
.54018 .33941 m .54896 .33754 L .54317 .31275 L p
1 g
F P
s
P
p
.002 w
.60422 .38741 m .59614 .40248 L .61448 .42323 L p
1 g
F P
s
P
p
.002 w
.46942 .5373 m .51971 .55332 L .52748 .52949 L p
1 g
F P
s
P
p
.002 w
.57417 .52966 m .52748 .52949 L .51971 .55332 L p
1 g
F P
s
P
p
.002 w
.52748 .52949 m .57417 .52966 L .57512 .50361 L p
1 g
F P
s
P
p
.002 w
.60422 .38741 m .60654 .36996 L .58075 .36623 L p
1 g
F P
s
P
p
.002 w
.5788 .35725 m .58075 .36623 L .60654 .36996 L p
1 g
F P
s
P
p
.002 w
.46671 .29708 m .44793 .32365 L .4744 .33044 L p
1 g
F P
s
P
p
.002 w
.4744 .33044 m .48904 .31013 L .46671 .29708 L p
1 g
F P
s
P
p
.002 w
.61268 .49071 m .57512 .50361 L .57417 .52966 L p
1 g
F P
s
P
p
.002 w
.57512 .50361 m .61268 .49071 L .60526 .46528 L p
1 g
F P
s
P
p
.002 w
.5616 .3149 m .54317 .31275 L .54896 .33754 L p
1 g
F P
s
P
p
.002 w
.54896 .33754 m .55819 .33866 L .5616 .3149 L p
1 g
F P
s
P
p
.002 w
.51036 .29618 m .48904 .31013 L .51122 .32591 L p
1 g
F P
s
P
p
.002 w
.51122 .32591 m .52574 .31659 L .51036 .29618 L p
1 g
F P
s
P
p
.002 w
.37287 .48178 m .40981 .52535 L .42508 .50755 L p
1 g
F P
s
P
p
.002 w
.42508 .50755 m .39072 .46687 L .37287 .48178 L p
1 g
F P
s
P
p
.002 w
.46942 .5373 m .42508 .50755 L .40981 .52535 L p
1 g
F P
s
P
p
.002 w
.60654 .36996 m .60274 .35206 L .5788 .35725 L p
1 g
F P
s
P
p
.002 w
.57399 .34909 m .5788 .35725 L .60274 .35206 L p
1 g
F P
s
P
p
.002 w
.57894 .32285 m .5616 .3149 L .55819 .33866 L p
1 g
F P
s
P
p
.002 w
.55819 .33866 m .56686 .34266 L .57894 .32285 L p
1 g
F P
s
P
p
.002 w
.60274 .35206 m .59319 .33573 L .57399 .34909 L p
1 g
F P
s
P
p
.002 w
.56686 .34266 m .57399 .34909 L .59319 .33573 L p
1 g
F P
s
P
p
.002 w
.36424 .36805 m .36965 .41891 L .39194 .40797 L p
1 g
F P
s
P
p
.002 w
.39194 .40797 m .38734 .36195 L .36424 .36805 L p
1 g
F P
s
P
p
.002 w
.59319 .33573 m .57894 .32285 L .56686 .34266 L p
1 g
F P
s
P
p
.002 w
.63026 .4445 m .60526 .46528 L .61268 .49071 L p
1 g
F P
s
P
p
.002 w
.60526 .46528 m .63026 .4445 L .61448 .42323 L p
1 g
F P
s
P
p
.002 w
.40981 .52535 m .45735 .5573 L .46942 .5373 L p
1 g
F P
s
P
p
.002 w
.51971 .55332 m .46942 .5373 L .45735 .5573 L p
1 g
F P
s
P
p
.002 w
.61448 .42323 m .62661 .40109 L .60422 .38741 L p
1 g
F P
s
P
p
.002 w
.60654 .36996 m .60422 .38741 L .62661 .40109 L p
1 g
F P
s
P
p
.002 w
.398 .3179 m .38734 .36195 L .41269 .35768 L p
1 g
F P
s
P
p
.002 w
.41269 .35768 m .42228 .31941 L .398 .3179 L p
1 g
F P
s
P
p
.002 w
.62661 .40109 m .61448 .42323 L .63026 .4445 L p
1 g
F P
s
P
p
.002 w
.35007 .43043 m .37287 .48178 L .39072 .46687 L p
1 g
F P
s
P
p
.002 w
.39072 .46687 m .36965 .41891 L .35007 .43043 L p
1 g
F P
s
P
p
.002 w
.53615 .29033 m .51036 .29618 L .52574 .31659 L p
1 g
F P
s
P
p
.002 w
.52574 .31659 m .54317 .31275 L .53615 .29033 L p
1 g
F P
s
P
p
.002 w
.4447 .28711 m .42228 .31941 L .44793 .32365 L p
1 g
F P
s
P
p
.002 w
.44793 .32365 m .46671 .29708 L .4447 .28711 L p
1 g
F P
s
P
p
.002 w
.49435 .27869 m .46671 .29708 L .48904 .31013 L p
1 g
F P
s
P
p
.002 w
.48904 .31013 m .51036 .29618 L .49435 .27869 L p
1 g
F P
s
P
p
.002 w
.62661 .40109 m .63023 .3753 L .60654 .36996 L p
1 g
F P
s
P
p
.002 w
.60274 .35206 m .60654 .36996 L .63023 .3753 L p
1 g
F P
s
P
p
.002 w
.51971 .55332 m .57132 .5538 L .57417 .52966 L p
1 g
F P
s
P
p
.002 w
.61741 .51518 m .57417 .52966 L .57132 .5538 L p
1 g
F P
s
P
p
.002 w
.57417 .52966 m .61741 .51518 L .61268 .49071 L p
1 g
F P
s
P
p
.002 w
.45735 .5573 m .51123 .57466 L .51971 .55332 L p
1 g
F P
s
P
p
.002 w
.57132 .5538 m .51971 .55332 L .51123 .57466 L p
1 g
F P
s
P
p
.002 w
.56354 .29341 m .53615 .29033 L .54317 .31275 L p
1 g
F P
s
P
p
.002 w
.54317 .31275 m .5616 .3149 L .56354 .29341 L p
1 g
F P
s
P
p
.002 w
.6431 .46589 m .61268 .49071 L .61741 .51518 L p
1 g
F P
s
P
p
.002 w
.61268 .49071 m .6431 .46589 L .63026 .4445 L p
1 g
F P
s
P
p
.002 w
.63023 .3753 m .62473 .34871 L .60274 .35206 L p
1 g
F P
s
P
p
.002 w
.59319 .33573 m .60274 .35206 L .62473 .34871 L p
1 g
F P
s
P
p
.002 w
.63026 .4445 m .64629 .41583 L .62661 .40109 L p
1 g
F P
s
P
p
.002 w
.63023 .3753 m .62661 .40109 L .64629 .41583 L p
1 g
F P
s
P
p
.002 w
.34397 .37594 m .35007 .43043 L .36965 .41891 L p
1 g
F P
s
P
p
.002 w
.36965 .41891 m .36424 .36805 L .34397 .37594 L p
1 g
F P
s
P
p
.002 w
.35774 .49582 m .39638 .54127 L .40981 .52535 L p
1 g
F P
s
P
p
.002 w
.40981 .52535 m .37287 .48178 L .35774 .49582 L p
1 g
F P
s
P
p
.002 w
.45735 .5573 m .40981 .52535 L .39638 .54127 L p
1 g
F P
s
P
p
.002 w
.58936 .3052 m .56354 .29341 L .5616 .3149 L p
1 g
F P
s
P
p
.002 w
.5616 .3149 m .57894 .32285 L .58936 .3052 L p
1 g
F P
s
P
p
.002 w
.64629 .41583 m .63026 .4445 L .6431 .46589 L p
1 g
F P
s
P
p
.002 w
.37568 .31926 m .36424 .36805 L .38734 .36195 L p
1 g
F P
s
P
p
.002 w
.38734 .36195 m .398 .3179 L .37568 .31926 L p
1 g
F P
s
P
p
.002 w
.62473 .34871 m .61058 .32439 L .59319 .33573 L p
1 g
F P
s
P
p
.002 w
.57894 .32285 m .59319 .33573 L .61058 .32439 L p
1 g
F P
s
P
p
.002 w
.61058 .32439 m .58936 .3052 L .57894 .32285 L p
1 g
F P
s
P
p
.002 w
.39638 .54127 m .44601 .57467 L .45735 .5573 L p
1 g
F P
s
P
p
.002 w
.51123 .57466 m .45735 .5573 L .44601 .57467 L p
1 g
F P
s
P
p
.002 w
.528 .27084 m .49435 .27869 L .51036 .29618 L p
1 g
F P
s
P
p
.002 w
.51036 .29618 m .53615 .29033 L .528 .27084 L p
1 g
F P
s
P
p
.002 w
.42349 .28057 m .398 .3179 L .42228 .31941 L p
1 g
F P
s
P
p
.002 w
.42228 .31941 m .4447 .28711 L .42349 .28057 L p
1 g
F P
s
P
p
.002 w
.33376 .44231 m .35774 .49582 L .37287 .48178 L p
1 g
F P
s
P
p
.002 w
.37287 .48178 m .35007 .43043 L .33376 .44231 L p
1 g
F P
s
P
p
.002 w
.47801 .2646 m .4447 .28711 L .46671 .29708 L p
1 g
F P
s
P
p
.002 w
.46671 .29708 m .49435 .27869 L .47801 .2646 L p
1 g
F P
s
P
p
.002 w
.64629 .41583 m .65124 .38221 L .63023 .3753 L p
1 g
F P
s
P
p
.002 w
.62473 .34871 m .63023 .3753 L .65124 .38221 L p
1 g
F P
s
P
p
.002 w
.51123 .57466 m .56658 .57546 L .57132 .5538 L p
1 g
F P
s
P
p
.002 w
.61926 .53813 m .57132 .5538 L .56658 .57546 L p
1 g
F P
s
P
p
.002 w
.57132 .5538 m .61926 .53813 L .61741 .51518 L p
1 g
F P
s
P
p
.002 w
.44601 .57467 m .50221 .59295 L .51123 .57466 L p
1 g
F P
s
P
p
.002 w
.56658 .57546 m .51123 .57466 L .50221 .59295 L p
1 g
F P
s
P
p
.002 w
.65259 .48694 m .61741 .51518 L .61926 .53813 L p
1 g
F P
s
P
p
.002 w
.61741 .51518 m .65259 .48694 L .6431 .46589 L p
1 g
F P
s
P
p
.002 w
.5639 .27475 m .528 .27084 L .53615 .29033 L p
1 g
F P
s
P
p
.002 w
.53615 .29033 m .56354 .29341 L .5639 .27475 L p
1 g
F P
s
P
p
.002 w
.6431 .46589 m .66276 .43135 L .64629 .41583 L p
1 g
F P
s
P
p
.002 w
.65124 .38221 m .64629 .41583 L .66276 .43135 L p
1 g
F P
s
P
p
.002 w
.66276 .43135 m .6431 .46589 L .65259 .48694 L p
1 g
F P
s
P
p
.002 w
.65124 .38221 m .6442 .34737 L .62473 .34871 L p
1 g
F P
s
P
p
.002 w
.61058 .32439 m .62473 .34871 L .6442 .34737 L p
1 g
F P
s
P
p
.002 w
.35591 .32358 m .34397 .37594 L .36424 .36805 L p
1 g
F P
s
P
p
.002 w
.36424 .36805 m .37568 .31926 L .35591 .32358 L p
1 g
F P
s
P
p
.002 w
.32712 .38552 m .33376 .44231 L .35007 .43043 L p
1 g
F P
s
P
p
.002 w
.35007 .43043 m .34397 .37594 L .32712 .38552 L p
1 g
F P
s
P
p
.002 w
.59783 .29018 m .5639 .27475 L .56354 .29341 L p
1 g
F P
s
P
p
.002 w
.56354 .29341 m .58936 .3052 L .59783 .29018 L p
1 g
F P
s
P
p
.002 w
.34579 .50865 m .38518 .55486 L .39638 .54127 L p
1 g
F P
s
P
p
.002 w
.39638 .54127 m .35774 .49582 L .34579 .50865 L p
1 g
F P
s
P
p
.002 w
.44601 .57467 m .39638 .54127 L .38518 .55486 L p
1 g
F P
s
P
p
.002 w
.51883 .25487 m .47801 .2646 L .49435 .27869 L p
1 g
F P
s
P
p
.002 w
.49435 .27869 m .528 .27084 L .51883 .25487 L p
1 g
F P
s
P
p
.002 w
.40361 .27776 m .37568 .31926 L .398 .3179 L p
1 g
F P
s
P
p
.002 w
.398 .3179 m .42349 .28057 L .40361 .27776 L p
1 g
F P
s
P
p
.002 w
.6442 .34737 m .62571 .3154 L .61058 .32439 L p
1 g
F P
s
P
p
.002 w
.58936 .3052 m .61058 .32439 L .62571 .3154 L p
1 g
F P
s
P
p
.002 w
.46171 .25441 m .42349 .28057 L .4447 .28711 L p
1 g
F P
s
P
p
.002 w
.4447 .28711 m .47801 .2646 L .46171 .25441 L p
1 g
F P
s
P
p
.002 w
.62571 .3154 m .59783 .29018 L .58936 .3052 L p
1 g
F P
s
P
p
.002 w
.38518 .55486 m .43568 .58889 L .44601 .57467 L p
1 g
F P
s
P
p
.002 w
.50221 .59295 m .44601 .57467 L .43568 .58889 L p
1 g
F P
s
P
p
.002 w
.32124 .4543 m .34579 .50865 L .35774 .49582 L p
1 g
F P
s
P
p
.002 w
.35774 .49582 m .33376 .44231 L .32124 .4543 L p
1 g
F P
s
P
p
.002 w
.66276 .43135 m .669 .39059 L .65124 .38221 L p
1 g
F P
s
P
p
.002 w
.6442 .34737 m .65124 .38221 L .669 .39059 L p
1 g
F P
s
P
p
.002 w
.50221 .59295 m .55994 .59403 L .56658 .57546 L p
1 g
F P
s
P
p
.002 w
.61805 .55897 m .56658 .57546 L .55994 .59403 L p
1 g
F P
s
P
p
.002 w
.56658 .57546 m .61805 .55897 L .61926 .53813 L p
1 g
F P
s
P
p
.002 w
.65839 .50716 m .61926 .53813 L .61805 .55897 L p
1 g
F P
s
P
p
.002 w
.61926 .53813 m .65839 .50716 L .65259 .48694 L p
1 g
F P
s
P
p
.002 w
.56259 .25951 m .51883 .25487 L .528 .27084 L p
1 g
F P
s
P
p
.002 w
.528 .27084 m .5639 .27475 L .56259 .25951 L p
1 g
F P
s
P
p
.002 w
.43568 .58889 m .49281 .60762 L .50221 .59295 L p
1 g
F P
s
P
p
.002 w
.55994 .59403 m .50221 .59295 L .49281 .60762 L p
1 g
F P
s
P
p
.002 w
.67549 .44734 m .65259 .48694 L .65839 .50716 L p
1 g
F P
s
P
p
.002 w
.65259 .48694 m .67549 .44734 L .66276 .43135 L p
1 g
F P
s
P
p
.002 w
.669 .39059 m .66276 .43135 L .67549 .44734 L p
1 g
F P
s
P
p
.002 w
.33929 .3309 m .32712 .38552 L .34397 .37594 L p
1 g
F P
s
P
p
.002 w
.34397 .37594 m .35591 .32358 L .33929 .3309 L p
1 g
F P
s
P
p
.002 w
.669 .39059 m .66058 .34816 L .6442 .34737 L p
1 g
F P
s
P
p
.002 w
.62571 .3154 m .6442 .34737 L .66058 .34816 L p
1 g
F P
s
P
p
.002 w
.31428 .39665 m .32124 .4543 L .33376 .44231 L p
1 g
F P
s
P
p
.002 w
.33376 .44231 m .32712 .38552 L .31428 .39665 L p
1 g
F P
s
P
p
.002 w
.38561 .27894 m .35591 .32358 L .37568 .31926 L p
1 g
F P
s
P
p
.002 w
.37568 .31926 m .40361 .27776 L .38561 .27894 L p
1 g
F P
s
P
p
.002 w
.50883 .24298 m .46171 .25441 L .47801 .2646 L p
1 g
F P
s
P
p
.002 w
.47801 .2646 m .51883 .25487 L .50883 .24298 L p
1 g
F P
s
P
p
.002 w
.44584 .24856 m .40361 .27776 L .42349 .28057 L p
1 g
F P
s
P
p
.002 w
.42349 .28057 m .46171 .25441 L .44584 .24856 L p
1 g
F P
s
P
p
.002 w
.60404 .2783 m .56259 .25951 L .5639 .27475 L p
1 g
F P
s
P
p
.002 w
.5639 .27475 m .59783 .29018 L .60404 .2783 L p
1 g
F P
s
P
p
.002 w
.33747 .5199 m .37658 .56569 L .38518 .55486 L p
1 g
F P
s
P
p
.002 w
.38518 .55486 m .34579 .50865 L .33747 .5199 L p
1 g
F P
s
P
p
.002 w
.43568 .58889 m .38518 .55486 L .37658 .56569 L p
1 g
F P
s
P
p
.002 w
.66058 .34816 m .63809 .30912 L .62571 .3154 L p
1 g
F P
s
P
p
.002 w
.59783 .29018 m .62571 .3154 L .63809 .30912 L p
1 g
F P
s
P
p
.002 w
.37658 .56569 m .42665 .59947 L .43568 .58889 L p
1 g
F P
s
P
p
.002 w
.49281 .60762 m .43568 .58889 L .42665 .59947 L p
1 g
F P
s
P
p
.002 w
.63809 .30912 m .60404 .2783 L .59783 .29018 L p
1 g
F P
s
P
p
.002 w
.31303 .46612 m .33747 .5199 L .34579 .50865 L p
1 g
F P
s
P
p
.002 w
.34579 .50865 m .32124 .4543 L .31303 .46612 L p
1 g
F P
s
P
p
.002 w
.67549 .44734 m .68291 .40033 L .669 .39059 L p
1 g
F P
s
P
p
.002 w
.66058 .34816 m .669 .39059 L .68291 .40033 L p
1 g
F P
s
P
p
.002 w
.49281 .60762 m .55148 .60894 L .55994 .59403 L p
1 g
F P
s
P
p
.002 w
.61368 .57713 m .55994 .59403 L .55148 .60894 L p
1 g
F P
s
P
p
.002 w
.55994 .59403 m .61368 .57713 L .61805 .55897 L p
1 g
F P
s
P
p
.002 w
.66018 .52602 m .61805 .55897 L .61368 .57713 L p
1 g
F P
s
P
p
.002 w
.61805 .55897 m .66018 .52602 L .65839 .50716 L p
1 g
F P
s
P
p
.002 w
.684 .46343 m .65839 .50716 L .66018 .52602 L p
1 g
F P
s
P
p
.002 w
.65839 .50716 m .684 .46343 L .67549 .44734 L p
1 g
F P
s
P
p
.002 w
.68291 .40033 m .67549 .44734 L .684 .46343 L p
1 g
F P
s
P
p
.002 w
.55954 .24825 m .50883 .24298 L .51883 .25487 L p
1 g
F P
s
P
p
.002 w
.51883 .25487 m .56259 .25951 L .55954 .24825 L p
1 g
F P
s
P
p
.002 w
.42665 .59947 m .48325 .61814 L .49281 .60762 L p
1 g
F P
s
P
p
.002 w
.55148 .60894 m .49281 .60762 L .48325 .61814 L p
1 g
F P
s
P
p
.002 w
.32643 .34121 m .31428 .39665 L .32712 .38552 L p
1 g
F P
s
P
p
.002 w
.32712 .38552 m .33929 .3309 L .32643 .34121 L p
1 g
F P
s
P
p
.002 w
.37006 .28429 m .33929 .3309 L .35591 .32358 L p
1 g
F P
s
P
p
.002 w
.35591 .32358 m .38561 .27894 L .37006 .28429 L p
1 g
F P
s
P
p
.002 w
.49818 .23571 m .44584 .24856 L .46171 .25441 L p
1 g
F P
s
P
p
.002 w
.46171 .25441 m .50883 .24298 L .49818 .23571 L p
1 g
F P
s
P
p
.002 w
.30599 .40912 m .31303 .46612 L .32124 .4543 L p
1 g
F P
s
P
p
.002 w
.32124 .4543 m .31428 .39665 L .30599 .40912 L p
1 g
F P
s
P
p
.002 w
.68291 .40033 m .6733 .35119 L .66058 .34816 L p
1 g
F P
s
P
p
.002 w
.63809 .30912 m .66058 .34816 L .6733 .35119 L p
1 g
F P
s
P
p
.002 w
.43084 .24745 m .38561 .27894 L .40361 .27776 L p
1 g
F P
s
P
p
.002 w
.40361 .27776 m .44584 .24856 L .43084 .24745 L p
1 g
F P
s
P
p
.002 w
.6077 .27004 m .55954 .24825 L .56259 .25951 L p
1 g
F P
s
P
p
.002 w
.56259 .25951 m .60404 .2783 L .6077 .27004 L p
1 g
F P
s
P
p
.002 w
.33321 .5292 m .37095 .57332 L .37658 .56569 L p
1 g
F P
s
P
p
.002 w
.37658 .56569 m .33747 .5199 L .33321 .5292 L p
1 g
F P
s
P
p
.002 w
.42665 .59947 m .37658 .56569 L .37095 .57332 L p
1 g
F P
s
P
p
.002 w
.6733 .35119 m .64725 .30585 L .63809 .30912 L p
1 g
F P
s
P
p
.002 w
.60404 .2783 m .63809 .30912 L .64725 .30585 L p
1 g
F P
s
P
p
.002 w
.37095 .57332 m .41924 .60593 L .42665 .59947 L p
1 g
F P
s
P
p
.002 w
.48325 .61814 m .42665 .59947 L .41924 .60593 L p
1 g
F P
s
P
p
.002 w
.64725 .30585 m .6077 .27004 L .60404 .2783 L p
1 g
F P
s
P
p
.002 w
.684 .46343 m .69242 .41127 L .68291 .40033 L p
1 g
F P
s
P
p
.002 w
.6733 .35119 m .68291 .40033 L .69242 .41127 L p
1 g
F P
s
P
p
.002 w
.30959 .47743 m .33321 .5292 L .33747 .5199 L p
1 g
F P
s
P
p
.002 w
.33747 .5199 m .31303 .46612 L .30959 .47743 L p
1 g
F P
s
P
p
.002 w
.55148 .60894 m .60607 .59199 L .61368 .57713 L p
1 g
F P
s
P
p
.002 w
.65771 .54299 m .61368 .57713 L .60607 .59199 L p
1 g
F P
s
P
p
.002 w
.61368 .57713 m .65771 .54299 L .66018 .52602 L p
1 g
F P
s
P
p
.002 w
.48325 .61814 m .5413 .61959 L .55148 .60894 L p
1 g
F P
s
P
p
.002 w
.60607 .59199 m .55148 .60894 L .5413 .61959 L p
1 g
F P
s
P
p
.002 w
.68784 .47923 m .66018 .52602 L .65771 .54299 L p
1 g
F P
s
P
p
.002 w
.66018 .52602 m .68784 .47923 L .684 .46343 L p
1 g
F P
s
P
p
.002 w
.69242 .41127 m .684 .46343 L .68784 .47923 L p
1 g
F P
s
P
p
.002 w
.55473 .24152 m .49818 .23571 L .50883 .24298 L p
1 g
F P
s
P
p
.002 w
.50883 .24298 m .55954 .24825 L .55473 .24152 L p
1 g
F P
s
P
p
.002 w
.41924 .60593 m .47376 .62398 L .48325 .61814 L p
1 g
F P
s
P
p
.002 w
.5413 .61959 m .48325 .61814 L .47376 .62398 L p
1 g
F P
s
P
p
.002 w
.31788 .3544 m .30599 .40912 L .31428 .39665 L p
1 g
F P
s
P
p
.002 w
.31428 .39665 m .32643 .34121 L .31788 .3544 L p
1 g
F P
s
P
p
.002 w
.35752 .29392 m .32643 .34121 L .33929 .3309 L p
1 g
F P
s
P
p
.002 w
.33929 .3309 m .37006 .28429 L .35752 .29392 L p
1 g
F P
s
P
p
.002 w
.48715 .23355 m .43084 .24745 L .44584 .24856 L p
1 g
F P
s
P
p
.002 w
.44584 .24856 m .49818 .23571 L .48715 .23355 L p
1 g
F P
s
P
p
.002 w
.41716 .25138 m .37006 .28429 L .38561 .27894 L p
1 g
F P
s
P
p
.002 w
.38561 .27894 m .43084 .24745 L .41716 .25138 L p
1 g
F P
s
P
p
.002 w
.30277 .42269 m .30959 .47743 L .31303 .46612 L p
1 g
F P
s
P
p
.002 w
.31303 .46612 m .30599 .40912 L .30277 .42269 L p
1 g
F P
s
P
p
.002 w
.69242 .41127 m .6818 .35652 L .6733 .35119 L p
1 g
F P
s
P
p
.002 w
.64725 .30585 m .6733 .35119 L .6818 .35652 L p
1 g
F P
s
P
p
.002 w
.60854 .26584 m .55473 .24152 L .55954 .24825 L p
1 g
F P
s
P
p
.002 w
.55954 .24825 m .6077 .27004 L .60854 .26584 L p
1 g
F P
s
P
p
.002 w
.33337 .53616 m .36863 .57736 L .37095 .57332 L p
1 g
F P
s
P
p
.002 w
.37095 .57332 m .33321 .5292 L .33337 .53616 L p
1 g
F P
s
P
p
.002 w
.41924 .60593 m .37095 .57332 L .36863 .57736 L p
1 g
F P
s
P
p
.002 w
.6818 .35652 m .65275 .30588 L .64725 .30585 L p
1 g
F P
s
P
p
.002 w
.6077 .27004 m .64725 .30585 L .65275 .30588 L p
1 g
F P
s
P
p
.002 w
.36863 .57736 m .41373 .60782 L .41924 .60593 L p
1 g
F P
s
P
p
.002 w
.47376 .62398 m .41924 .60593 L .41373 .60782 L p
1 g
F P
s
P
p
.002 w
.5413 .61959 m .59525 .60298 L .60607 .59199 L p
1 g
F P
s
P
p
.002 w
.65079 .55751 m .60607 .59199 L .59525 .60298 L p
1 g
F P
s
P
p
.002 w
.60607 .59199 m .65079 .55751 L .65771 .54299 L p
1 g
F P
s
P
p
.002 w
.65275 .30588 m .60854 .26584 L .6077 .27004 L p
1 g
F P
s
P
p
.002 w
.68784 .47923 m .69701 .42317 L .69242 .41127 L p
1 g
F P
s
P
p
.002 w
.6818 .35652 m .69242 .41127 L .69701 .42317 L p
1 g
F P
s
P
p
.002 w
.47376 .62398 m .52958 .62545 L .5413 .61959 L p
1 g
F P
s
P
p
.002 w
.59525 .60298 m .5413 .61959 L .52958 .62545 L p
1 g
F P
s
P
p
.002 w
.68665 .4943 m .65771 .54299 L .65079 .55751 L p
1 g
F P
s
P
p
.002 w
.65771 .54299 m .68665 .4943 L .68784 .47923 L p
1 g
F P
s
P
p
.002 w
.31133 .48792 m .33337 .53616 L .33321 .5292 L p
1 g
F P
s
P
p
.002 w
.33321 .5292 m .30959 .47743 L .31133 .48792 L p
1 g
F P
s
P
p
.002 w
.69701 .42317 m .68784 .47923 L .68665 .4943 L p
1 g
F P
s
P
p
.002 w
.54818 .2398 m .48715 .23355 L .49818 .23571 L p
1 g
F P
s
P
p
.002 w
.49818 .23571 m .55473 .24152 L .54818 .2398 L p
1 g
F P
s
P
p
.002 w
.31415 .37025 m .30277 .42269 L .30599 .40912 L p
1 g
F P
s
P
p
.002 w
.30599 .40912 m .31788 .3544 L .31415 .37025 L p
1 g
F P
s
P
p
.002 w
.34853 .30779 m .31788 .3544 L .32643 .34121 L p
1 g
F P
s
P
p
.002 w
.32643 .34121 m .35752 .29392 L .34853 .30779 L p
1 g
F P
s
P
p
.002 w
.41373 .60782 m .46459 .62468 L .47376 .62398 L p
1 g
F P
s
P
p
.002 w
.52958 .62545 m .47376 .62398 L .46459 .62468 L p
1 g
F P
s
P
p
.002 w
.40529 .26056 m .35752 .29392 L .37006 .28429 L p
1 g
F P
s
P
p
.002 w
.37006 .28429 m .41716 .25138 L .40529 .26056 L p
1 g
F P
s
P
p
.002 w
.47602 .23687 m .41716 .25138 L .43084 .24745 L p
1 g
F P
s
P
p
.002 w
.43084 .24745 m .48715 .23355 L .47602 .23687 L p
1 g
F P
s
P
p
.002 w
.30499 .43702 m .31133 .48792 L .30959 .47743 L p
1 g
F P
s
P
p
.002 w
.30959 .47743 m .30277 .42269 L .30499 .43702 L p
1 g
F P
s
P
p
.002 w
.69701 .42317 m .68559 .36415 L .6818 .35652 L p
1 g
F P
s
P
p
.002 w
.65275 .30588 m .6818 .35652 L .68559 .36415 L p
1 g
F P
s
P
p
.002 w
.60636 .26611 m .54818 .2398 L .55473 .24152 L p
1 g
F P
s
P
p
.002 w
.55473 .24152 m .60854 .26584 L .60636 .26611 L p
1 g
F P
s
P
p
.002 w
.52958 .62545 m .58133 .60955 L .59525 .60298 L p
1 g
F P
s
P
p
.002 w
.59525 .60298 m .63936 .56902 L .65079 .55751 L p
1 g
F P
s
P
p
.002 w
.63936 .56902 m .59525 .60298 L .58133 .60955 L p
1 g
F P
s
P
p
.002 w
.33825 .54045 m .3699 .57744 L .36863 .57736 L p
1 g
F P
s
P
p
.002 w
.36863 .57736 m .33337 .53616 L .33825 .54045 L p
1 g
F P
s
P
p
.002 w
.41373 .60782 m .36863 .57736 L .3699 .57744 L p
1 g
F P
s
P
p
.002 w
.68559 .36415 m .65419 .30942 L .65275 .30588 L p
1 g
F P
s
P
p
.002 w
.60854 .26584 m .65275 .30588 L .65419 .30942 L p
1 g
F P
s
P
p
.002 w
.68665 .4943 m .69624 .43578 L .69701 .42317 L p
1 g
F P
s
P
p
.002 w
.68559 .36415 m .69701 .42317 L .69624 .43578 L p
1 g
F P
s
P
p
.002 w
.65079 .55751 m .68015 .50817 L .68665 .4943 L p
1 g
F P
s
P
p
.002 w
.68015 .50817 m .65079 .55751 L .63936 .56902 L p
1 g
F P
s
P
p
.002 w
.46459 .62468 m .51654 .62607 L .52958 .62545 L p
1 g
F P
s
P
p
.002 w
.58133 .60955 m .52958 .62545 L .51654 .62607 L p
1 g
F P
s
P
p
.002 w
.3699 .57744 m .41041 .60479 L .41373 .60782 L p
1 g
F P
s
P
p
.002 w
.46459 .62468 m .41373 .60782 L .41041 .60479 L p
1 g
F P
s
P
p
.002 w
.65419 .30942 m .60636 .26611 L .60854 .26584 L p
1 g
F P
s
P
p
.002 w
.69624 .43578 m .68665 .4943 L .68015 .50817 L p
1 g
F P
s
P
p
.002 w
.31852 .49721 m .33825 .54045 L .33337 .53616 L p
1 g
F P
s
P
p
.002 w
.33337 .53616 m .31133 .48792 L .31852 .49721 L p
1 g
F P
s
P
p
.002 w
.53996 .24347 m .47602 .23687 L .48715 .23355 L p
1 g
F P
s
P
p
.002 w
.48715 .23355 m .54818 .2398 L .53996 .24347 L p
1 g
F P
s
P
p
.002 w
.34356 .32573 m .31415 .37025 L .31788 .3544 L p
1 g
F P
s
P
p
.002 w
.31788 .3544 m .34853 .30779 L .34356 .32573 L p
1 g
F P
s
P
p
.002 w
.31563 .38844 m .30499 .43702 L .30277 .42269 L p
1 g
F P
s
P
p
.002 w
.30277 .42269 m .31415 .37025 L .31563 .38844 L p
1 g
F P
s
P
p
.002 w
.39569 .27501 m .34853 .30779 L .35752 .29392 L p
1 g
F P
s
P
p
.002 w
.35752 .29392 m .40529 .26056 L .39569 .27501 L p
1 g
F P
s
P
p
.002 w
.41041 .60479 m .45603 .61991 L .46459 .62468 L p
1 g
F P
s
P
p
.002 w
.51654 .62607 m .46459 .62468 L .45603 .61991 L p
1 g
F P
s
P
p
.002 w
.46512 .24591 m .40529 .26056 L .41716 .25138 L p
1 g
F P
s
P
p
.002 w
.41716 .25138 m .47602 .23687 L .46512 .24591 L p
1 g
F P
s
P
p
.002 w
.31293 .45174 m .31852 .49721 L .31133 .48792 L p
1 g
F P
s
P
p
.002 w
.31133 .48792 m .30499 .43702 L .31293 .45174 L p
1 g
F P
s
P
p
.002 w
.69624 .43578 m .68424 .37399 L .68559 .36415 L p
1 g
F P
s
P
p
.002 w
.65419 .30942 m .68559 .36415 L .68424 .37399 L p
1 g
F P
s
P
p
.002 w
.60102 .27113 m .53996 .24347 L .54818 .2398 L p
1 g
F P
s
P
p
.002 w
.54818 .2398 m .60636 .26611 L .60102 .27113 L p
1 g
F P
s
P
p
.002 w
.51654 .62607 m .56454 .61127 L .58133 .60955 L p
1 g
F P
s
P
p
.002 w
.6235 .57701 m .58133 .60955 L .56454 .61127 L p
1 g
F P
s
P
p
.002 w
.58133 .60955 m .6235 .57701 L .63936 .56902 L p
1 g
F P
s
P
p
.002 w
.66822 .52036 m .63936 .56902 L .6235 .57701 L p
1 g
F P
s
P
p
.002 w
.63936 .56902 m .66822 .52036 L .68015 .50817 L p
1 g
F P
s
P
p
.002 w
.68015 .50817 m .6898 .44875 L .69624 .43578 L p
1 g
F P
s
P
p
.002 w
.68424 .37399 m .69624 .43578 L .6898 .44875 L p
1 g
F P
s
P
p
.002 w
.45603 .61991 m .50249 .6211 L .51654 .62607 L p
1 g
F P
s
P
p
.002 w
.56454 .61127 m .51654 .62607 L .50249 .6211 L p
1 g
F P
s
P
p
.002 w
.348 .54175 m .37497 .5733 L .3699 .57744 L p
1 g
F P
s
P
p
.002 w
.3699 .57744 m .33825 .54045 L .348 .54175 L p
1 g
F P
s
P
p
.002 w
.41041 .60479 m .3699 .57744 L .37497 .5733 L p
1 g
F P
s
P
p
.002 w
.6898 .44875 m .68015 .50817 L .66822 .52036 L p
1 g
F P
s
P
p
.002 w
.68424 .37399 m .65125 .31661 L .65419 .30942 L p
1 g
F P
s
P
p
.002 w
.60636 .26611 m .65419 .30942 L .65125 .31661 L p
1 g
F P
s
P
p
.002 w
.37497 .5733 m .40953 .59662 L .41041 .60479 L p
1 g
F P
s
P
p
.002 w
.45603 .61991 m .41041 .60479 L .40953 .59662 L p
1 g
F P
s
P
p
.002 w
.65125 .31661 m .60102 .27113 L .60636 .26611 L p
1 g
F P
s
P
p
.002 w
.33128 .50494 m .348 .54175 L .33825 .54045 L p
1 g
F P
s
P
p
.002 w
.33825 .54045 m .31852 .49721 L .33128 .50494 L p
1 g
F P
s
P
p
.002 w
.34301 .34739 m .31563 .38844 L .31415 .37025 L p
1 g
F P
s
P
p
.002 w
.31415 .37025 m .34356 .32573 L .34301 .34739 L p
1 g
F P
s
P
p
.002 w
.53022 .25277 m .46512 .24591 L .47602 .23687 L p
1 g
F P
s
P
p
.002 w
.47602 .23687 m .53996 .24347 L .53022 .25277 L p
1 g
F P
s
P
p
.002 w
.32257 .40853 m .31293 .45174 L .30499 .43702 L p
1 g
F P
s
P
p
.002 w
.30499 .43702 m .31563 .38844 L .32257 .40853 L p
1 g
F P
s
P
p
.002 w
.38881 .29457 m .34356 .32573 L .34853 .30779 L p
1 g
F P
s
P
p
.002 w
.34853 .30779 m .39569 .27501 L .38881 .29457 L p
1 g
F P
s
P
p
.002 w
.45481 .26075 m .39569 .27501 L .40529 .26056 L p
1 g
F P
s
P
p
.002 w
.40529 .26056 m .46512 .24591 L .45481 .26075 L p
1 g
F P
s
P
p
.002 w
.40953 .59662 m .44838 .60945 L .45603 .61991 L p
1 g
F P
s
P
p
.002 w
.50249 .6211 m .45603 .61991 L .44838 .60945 L p
1 g
F P
s
P
p
.002 w
.32667 .46638 m .33128 .50494 L .31852 .49721 L p
1 g
F P
s
P
p
.002 w
.31852 .49721 m .31293 .45174 L .32667 .46638 L p
1 g
F P
s
P
p
.002 w
.6898 .44875 m .67746 .3859 L .68424 .37399 L p
1 g
F P
s
P
p
.002 w
.65125 .31661 m .68424 .37399 L .67746 .3859 L p
1 g
F P
s
P
p
.002 w
.50249 .6211 m .54524 .60778 L .56454 .61127 L p
1 g
F P
s
P
p
.002 w
.60346 .58102 m .56454 .61127 L .54524 .60778 L p
1 g
F P
s
P
p
.002 w
.56454 .61127 m .60346 .58102 L .6235 .57701 L p
1 g
F P
s
P
p
.002 w
.65094 .53037 m .6235 .57701 L .60346 .58102 L p
1 g
F P
s
P
p
.002 w
.6235 .57701 m .65094 .53037 L .66822 .52036 L p
1 g
F P
s
P
p
.002 w
.59247 .28105 m .53022 .25277 L .53996 .24347 L p
1 g
F P
s
P
p
.002 w
.53996 .24347 m .60102 .27113 L .59247 .28105 L p
1 g
F P
s
P
p
.002 w
.67757 .46169 m .66822 .52036 L .65094 .53037 L p
1 g
F P
s
P
p
.002 w
.66822 .52036 m .67757 .46169 L .6898 .44875 L p
1 g
F P
s
P
p
.002 w
.67746 .3859 m .6898 .44875 L .67757 .46169 L p
1 g
F P
s
P
p
.002 w
.44838 .60945 m .48783 .61036 L .50249 .6211 L p
1 g
F P
s
P
p
.002 w
.54524 .60778 m .50249 .6211 L .48783 .61036 L p
1 g
F P
s
P
p
.002 w
.36264 .53983 m .38393 .56478 L .37497 .5733 L p
1 g
F P
s
P
p
.002 w
.37497 .5733 m .348 .54175 L .36264 .53983 L p
1 g
F P
s
P
p
.002 w
.40953 .59662 m .37497 .5733 L .38393 .56478 L p
1 g
F P
s
P
p
.002 w
.67746 .3859 m .64375 .32744 L .65125 .31661 L p
1 g
F P
s
P
p
.002 w
.60102 .27113 m .65125 .31661 L .64375 .32744 L p
1 g
F P
s
P
p
.002 w
.38393 .56478 m .41126 .58322 L .40953 .59662 L p
1 g
F P
s
P
p
.002 w
.44838 .60945 m .40953 .59662 L .41126 .58322 L p
1 g
F P
s
P
p
.002 w
.34711 .37224 m .32257 .40853 L .31563 .38844 L p
1 g
F P
s
P
p
.002 w
.31563 .38844 m .34301 .34739 L .34711 .37224 L p
1 g
F P
s
P
p
.002 w
.64375 .32744 m .59247 .28105 L .60102 .27113 L p
1 g
F P
s
P
p
.002 w
.34952 .51077 m .36264 .53983 L .348 .54175 L p
1 g
F P
s
P
p
.002 w
.348 .54175 m .33128 .50494 L .34952 .51077 L p
1 g
F P
s
P
p
.002 w
.38501 .31885 m .34301 .34739 L .34356 .32573 L p
1 g
F P
s
P
p
.002 w
.34356 .32573 m .38881 .29457 L .38501 .31885 L p
1 g
F P
s
P
p
.002 w
.33502 .42994 m .32667 .46638 L .31293 .45174 L p
1 g
F P
s
P
p
.002 w
.31293 .45174 m .32257 .40853 L .33502 .42994 L p
1 g
F P
s
P
p
.002 w
.5192 .26773 m .45481 .26075 L .46512 .24591 L p
1 g
F P
s
P
p
.002 w
.46512 .24591 m .53022 .25277 L .5192 .26773 L p
1 g
F P
s
P
p
.002 w
.44549 .2812 m .38881 .29457 L .39569 .27501 L p
1 g
F P
s
P
p
.002 w
.39569 .27501 m .45481 .26075 L .44549 .2812 L p
1 g
F P
s
P
p
.002 w
.41126 .58322 m .44196 .59329 L .44838 .60945 L p
1 g
F P
s
P
p
.002 w
.48783 .61036 m .44838 .60945 L .44196 .59329 L p
1 g
F P
s
P
p
.002 w
.34605 .48046 m .34952 .51077 L .33128 .50494 L p
1 g
F P
s
P
p
.002 w
.33128 .50494 m .32667 .46638 L .34605 .48046 L p
1 g
F P
s
P
p
.002 w
.67757 .46169 m .66516 .3996 L .67746 .3859 L p
1 g
F P
s
P
p
.002 w
.64375 .32744 m .67746 .3859 L .66516 .3996 L p
1 g
F P
s
P
p
.002 w
.48783 .61036 m .52392 .59892 L .54524 .60778 L p
1 g
F P
s
P
p
.002 w
.57967 .58071 m .54524 .60778 L .52392 .59892 L p
1 g
F P
s
P
p
.002 w
.54524 .60778 m .57967 .58071 L .60346 .58102 L p
1 g
F P
s
P
p
.002 w
.62858 .53777 m .60346 .58102 L .57967 .58071 L p
1 g
F P
s
P
p
.002 w
.60346 .58102 m .62858 .53777 L .65094 .53037 L p
1 g
F P
s
P
p
.002 w
.6596 .47418 m .65094 .53037 L .62858 .53777 L p
1 g
F P
s
P
p
.002 w
.65094 .53037 m .6596 .47418 L .67757 .46169 L p
1 g
F P
s
P
p
.002 w
.58082 .29584 m .5192 .26773 L .53022 .25277 L p
1 g
F P
s
P
p
.002 w
.53022 .25277 m .59247 .28105 L .58082 .29584 L p
1 g
F P
s
P
p
.002 w
.66516 .3996 m .67757 .46169 L .6596 .47418 L p
1 g
F P
s
P
p
.002 w
.44196 .59329 m .473 .59388 L .48783 .61036 L p
1 g
F P
s
P
p
.002 w
.52392 .59892 m .48783 .61036 L .473 .59388 L p
1 g
F P
s
P
p
.002 w
.35595 .39956 m .33502 .42994 L .32257 .40853 L p
1 g
F P
s
P
p
.002 w
.32257 .40853 m .34711 .37224 L .35595 .39956 L p
1 g
F P
s
P
p
.002 w
.38459 .34723 m .34711 .37224 L .34301 .34739 L p
1 g
F P
s
P
p
.002 w
.34301 .34739 m .38501 .31885 L .38459 .34723 L p
1 g
F P
s
P
p
.002 w
.38195 .53456 m .39672 .55192 L .38393 .56478 L p
1 g
F P
s
P
p
.002 w
.38393 .56478 m .36264 .53983 L .38195 .53456 L p
1 g
F P
s
P
p
.002 w
.41126 .58322 m .38393 .56478 L .39672 .55192 L p
1 g
F P
s
P
p
.002 w
.35281 .45199 m .34605 .48046 L .32667 .46638 L p
1 g
F P
s
P
p
.002 w
.32667 .46638 m .33502 .42994 L .35281 .45199 L p
1 g
F P
s
P
p
.002 w
.66516 .3996 m .63164 .34179 L .64375 .32744 L p
1 g
F P
s
P
p
.002 w
.59247 .28105 m .64375 .32744 L .63164 .34179 L p
1 g
F P
s
P
p
.002 w
.39672 .55192 m .41572 .56471 L .41126 .58322 L p
1 g
F P
s
P
p
.002 w
.44196 .59329 m .41126 .58322 L .41572 .56471 L p
1 g
F P
s
P
p
.002 w
.63164 .34179 m .58082 .29584 L .59247 .28105 L p
1 g
F P
s
P
p
.002 w
.5072 .28815 m .44549 .2812 L .45481 .26075 L p
1 g
F P
s
P
p
.002 w
.45481 .26075 m .5192 .26773 L .5072 .28815 L p
1 g
F P
s
P
p
.002 w
.43753 .30683 m .38501 .31885 L .38881 .29457 L p
1 g
F P
s
P
p
.002 w
.38881 .29457 m .44549 .2812 L .43753 .30683 L p
1 g
F P
s
P
p
.002 w
.37294 .51439 m .38195 .53456 L .36264 .53983 L p
1 g
F P
s
P
p
.002 w
.36264 .53983 m .34952 .51077 L .37294 .51439 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.41572 .56471 m .43704 .57164 L .44196 .59329 L p
1 g
F P
s
P
p
.002 w
.473 .59388 m .44196 .59329 L .43704 .57164 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37067 .49345 m .37294 .51439 L .34952 .51077 L p
1 g
F P
s
P
p
.002 w
.34952 .51077 m .34605 .48046 L .37067 .49345 L p
1 g
F P
s
P
p
.002 w
.473 .59388 m .50122 .58473 L .52392 .59892 L p
1 g
F P
s
P
p
.002 w
.55277 .57589 m .52392 .59892 L .50122 .58473 L p
1 g
F P
s
P
p
.002 w
.52392 .59892 m .55277 .57589 L .57967 .58071 L p
1 g
F P
s
P
p
.002 w
.60166 .54216 m .57967 .58071 L .55277 .57589 L p
1 g
F P
s
P
p
.002 w
.57967 .58071 m .60166 .54216 L .62858 .53777 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.6596 .47418 m .64743 .41472 L .66516 .3996 L p
1 g
F P
s
P
p
.002 w
.63164 .34179 m .66516 .3996 L .64743 .41472 L p
1 g
F P
s
P
p
.002 w
.63623 .48575 m .62858 .53777 L .60166 .54216 L p
1 g
F P
s
P
p
.002 w
.62858 .53777 m .63623 .48575 L .6596 .47418 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.43704 .57164 m .4585 .57194 L .473 .59388 L p
1 g
F P
s
P
p
.002 w
.50122 .58473 m .473 .59388 L .46283 .57849 L p
1 g
F P
s
P
p
.50122 .58473 m .46283 .57849 L .48639 .58029 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53163 .57427 L p
1 g
F P
s
P
p
.55277 .57589 m .54593 .57706 L .53549 .57214 L 1 g
F
P
p
.002 w
.53755 .571 m .55277 .57589 L p
.53549 .57214 L 1 g
F P
s
P
p
.54854 .56129 m .53163 .57427 L .53755 .571 L 1 g
F
P
p
.002 w
.56788 .54877 m .55277 .57589 L .54126 .57219 L p
1 g
F P
s
P
p
.002 w
.54126 .57219 m .53755 .571 L p
.54902 .56259 L 1 g
F P
s
P
p
.56788 .54877 m .54126 .57219 L .54902 .56259 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54902 .56259 L p
1 g
F P
s
P
p
.56075 .54566 m .54902 .56259 L .55653 .55332 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.57095 .54327 m .56788 .54877 L p
.55652 .55332 L 1 g
F P
s
P
p
.002 w
.56153 .54713 m .56075 .54566 L p
.55653 .55332 L 1 g
F P
s
P
p
.56051 .54839 m .55652 .55332 L .52358 .56652 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56153 .54713 L p
1 g
F P
s
P
p
.57095 .54327 m .56007 .55085 L .56116 .54807 L 1 g
F
P
p
.56654 .52734 m .56153 .54713 L .56326 .54273 L 1 g
F
P
p
.002 w
.57596 .50436 m .57095 .54327 L .56819 .54307 L p
1 g
F P
s
P
p
.002 w
.56819 .54307 m .56326 .54273 L p
.56737 .5303 L 1 g
F P
s
P
p
.57596 .50436 m .56819 .54307 L .56737 .5303 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56725 .52837 L p
1 g
F P
s
P
p
.56515 .50826 m .56725 .52837 L .56653 .51721 L 1 g
F
P
p
.56654 .52734 m .56326 .54273 L .56463 .53781 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.57596 .50436 m .56737 .5303 L .57319 .50699 L 1 g
F
P
p
.56737 .5303 m .56326 .54273 L .56725 .52837 L 1 g
F
P
p
.56737 .5303 m .56725 .52837 L .57319 .50699 L 1 g
F
P
p
.002 w
.56602 .5093 m .56515 .50826 L p
.56653 .51721 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56326 .54273 m .53746 .54093 L p
.56629 .51354 L 1 g
F P
s
P
p
.57319 .50699 m .56725 .52837 L .56629 .51354 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52358 .56652 m .53746 .54093 L .56326 .54273 L p
1 g
F P
s
P
p
.002 w
.56326 .54273 m .57095 .54327 L p
.56116 .54807 L 1 g
F P
s
P
p
.56116 .54807 m .52358 .56652 L .56326 .54273 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5683 .5299 L p
1 g
F P
s
P
p
.002 w
.5683 .5299 m .56725 .52837 L p
.56502 .53826 L 1 g
F P
s
P
p
.56502 .53826 m .56257 .5491 L .5683 .5299 L 1 g
F
P
p
.002 w
.56725 .52837 m .56654 .52734 L p
.56463 .53781 L 1 g
F P
s
P
p
.56463 .53781 m .56257 .5491 L .56725 .52837 L 1 g
F
P
p
.56725 .52837 m .56326 .54273 L .56629 .51354 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56602 .5093 L p
1 g
F P
s
P
p
.55661 .4905 m .56602 .5093 L .56468 .50637 L 1 g
F
P
p
.56672 .46349 m .56504 .49872 L .55455 .4858 L 1 g
F
P
p
.56504 .49872 m .56468 .50637 L .55715 .49108 L 1 g
F
P
p
.56504 .49872 m .55715 .49108 L .55455 .4858 L 1 g
F
P
p
.55661 .4905 m .56468 .50637 L .56101 .49891 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56672 .46349 m .57596 .50436 L .56468 .50637 L p
1 g
F P
s
P
p
.002 w
.56468 .50637 m .57596 .50436 L p
.56746 .51243 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55715 .49108 L p
1 g
F P
s
P
p
.54174 .47608 m .55715 .49108 L .54854 .48274 L 1 g
F
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56468 .50637 m .54103 .51059 L p
.55455 .4858 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47674 L p
1 g
F P
s
P
p
.002 w
.54103 .51059 m .53358 .47887 L .54024 .47578 L p
1 g
F P
s
P
p
.54099 .47612 m .54103 .51059 L .54024 .47578 L 1 g
F
P
p
.52214 .46667 m .54235 .47674 L .54024 .47578 L 1 g
F
P
p
.002 w
.54024 .47578 m .53358 .47887 L p
.5347 .47312 L 1 g
F P
s
P
p
.52214 .46667 m .54024 .47578 L .53339 .47249 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51575 .44946 m .54394 .42553 L p
.5347 .47312 L 1 g
F P
s
P
p
.002 w
.53358 .47887 m .52821 .47001 L p
.5347 .47312 L 1 g
F P
s
P
p
.52214 .46667 m .53339 .47249 L .52821 .47001 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52821 .47001 m .53358 .47887 L p
.51742 .46643 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .51033 .46539 L 1 g
F
P
p
.52244 .46717 m .51742 .46643 L .51114 .4616 L 1 g
F
P
p
.52821 .47001 m .51742 .46643 L .52244 .46717 L 1 g
F
P
p
.002 w
.53358 .47887 m .49931 .49278 L p
.50974 .4653 L 1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .4634 L p
.51033 .46539 L 1 g
F P
s
P
p
.51114 .4616 m .51742 .46643 L .50974 .4653 L 1 g
F
P
p
.51742 .46643 m .53358 .47887 L .50974 .4653 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49931 .49278 m .48707 .4728 L .49755 .46427 L p
1 g
F P
s
P
p
.51096 .46207 m .49931 .49278 L .49755 .46427 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4639 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .4639 L .49049 .46534 L 1 g
F
P
p
.002 w
.49755 .46427 m .48707 .4728 L p
.48743 .46581 L 1 g
F P
s
P
p
.48963 .46547 m .5 .46434 L .49723 .4647 L 1 g
F
P
p
.47786 .46667 m .49049 .46534 L .48963 .46547 L 1 g
F
P
p
.49049 .46534 m .5 .46434 L .48963 .46547 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.48952 .42589 m .51575 .44946 L .49755 .46427 L p
1 g
F P
s
P
p
.002 w
.48707 .4728 m .48046 .46687 L p
.48743 .46581 L 1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48046 .46687 m .48707 .4728 L p
.47198 .46989 L 1 g
F P
s
P
p
.48046 .46687 m .47198 .46989 L .47751 .46725 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46725 L p
1 g
F P
s
P
p
.47198 .46989 m .48707 .4728 L .46474 .47335 L 1 g
F
P
p
.002 w
.47751 .46725 m .47718 .46778 L p
.46763 .47197 L 1 g
F P
s
P
p
.45826 .47608 m .47751 .46725 L .46763 .47197 L 1 g
F
P
p
.002 w
.48707 .4728 m .45902 .49463 L p
.46474 .47335 L 1 g
F P
s
P
p
.002 w
.45766 .47674 m .45826 .47608 L p
.46763 .47197 L 1 g
F P
s
P
p
.46598 .46874 m .47198 .46989 L .46474 .47335 L 1 g
F
P
p
.47751 .46725 m .47198 .46989 L .46598 .46874 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45902 .49463 m .45001 .48656 L .45412 .48018 L p
1 g
F P
s
P
p
.46602 .4686 m .45902 .49463 L .45412 .48018 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45764 .47676 L p
1 g
F P
s
P
p
.44339 .4905 m .45764 .47676 L .45261 .48165 L 1 g
F
P
p
.002 w
.45412 .48018 m .45001 .48656 L p
.44988 .4843 L 1 g
F P
s
P
p
.4514 .48283 m .45717 .47727 L .45387 .48046 L 1 g
F
P
p
.44339 .4905 m .45261 .48165 L .4514 .48283 L 1 g
F
P
p
.45261 .48165 m .45717 .47727 L .4514 .48283 L 1 g
F
P
p
.002 w
.44777 .44655 m .4692 .45677 L .45412 .48018 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44253 .49141 L p
1 g
F P
s
P
p
.43595 .49777 m .44166 .49322 L .43379 .50952 L 1 g
F
P
p
.002 w
.43346 .5102 m .43403 .50739 L p
.43379 .50952 L 1 g
F P
s
P
p
.002 w
.43403 .50739 m .43595 .49777 L p
.43379 .50952 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43379 .50952 L p
1 g
F P
s
P
p
.43346 .52734 m .43379 .50952 L .43342 .51296 L 1 g
F
P
p
.43346 .52734 m .43342 .51296 L .43337 .51341 L 1 g
F
P
p
.43346 .52734 m .43337 .51339 L .43334 .51367 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.45001 .48656 m .45902 .49463 L .43334 .51364 L p
1 g
F P
s
P
p
.002 w
.43334 .51364 m .43268 .51414 L .43342 .51296 L p
1 g
F P
s
P
p
.002 w
.43342 .51296 m .45001 .48656 L p
.43334 .51364 L 1 g
F P
s
P
p
.43337 .51341 m .43342 .51296 L .43337 .51339 L 1 g
F
P
p
.43334 .51367 m .43337 .51339 L .43334 .51365 L 1 g
F
P
p
.43346 .52734 m .43334 .51365 L .43332 .51386 L 1 g
F
P
p
.43346 .52734 m .43332 .51383 L .43331 .514 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45902 .49463 m .46524 .50468 L .43331 .51395 L p
1 g
F P
s
P
p
.002 w
.43331 .51395 m .43268 .51414 L .43334 .51364 L p
1 g
F P
s
P
p
.002 w
.43334 .51364 m .45902 .49463 L p
.43331 .51395 L 1 g
F P
s
P
p
.43346 .52734 m .43331 .51396 L .4333 .51413 L 1 g
F
P
p
.43346 .52734 m .4333 .51408 L .43328 .51424 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.46524 .50468 m .46799 .51558 L .43329 .51417 L p
1 g
F P
s
P
p
.002 w
.43329 .51417 m .43268 .51414 L .43331 .51395 L p
1 g
F P
s
P
p
.002 w
.43331 .51395 m .46524 .50468 L p
.43329 .51417 L 1 g
F P
s
P
p
.43332 .51386 m .43334 .51365 L .43332 .51383 L 1 g
F
P
p
.43331 .514 m .43332 .51383 L .43331 .51396 L 1 g
F
P
p
.43346 .52734 m .43328 .51418 L .43327 .51435 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.46799 .51558 m .467 .52612 L .43328 .51435 L p
1 g
F P
s
P
p
.002 w
.43328 .51435 m .43268 .51414 L .43329 .51417 L p
1 g
F P
s
P
p
.002 w
.43329 .51417 m .46799 .51558 L p
.43328 .51435 L 1 g
F P
s
P
p
.43346 .52734 m .43327 .51428 L .43311 .51736 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.467 .52612 m .4624 .53514 L .43326 .51456 L p
1 g
F P
s
P
p
.002 w
.43326 .51456 m .43268 .51414 L .43328 .51435 L p
1 g
F P
s
P
p
.002 w
.43328 .51435 m .467 .52612 L p
.43326 .51456 L 1 g
F P
s
P
p
.4333 .51413 m .43331 .51396 L .4333 .51408 L 1 g
F
P
p
.43328 .51424 m .4333 .51408 L .43328 .51418 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4624 .53514 m .45475 .54169 L .43325 .51485 L p
1 g
F P
s
P
p
.002 w
.43325 .51485 m .43268 .51414 L .43326 .51456 L p
1 g
F P
s
P
p
.002 w
.43326 .51456 m .4624 .53514 L p
.43325 .51485 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45475 .54169 m .44488 .54509 L .43321 .51549 L p
1 g
F P
s
P
p
.002 w
.43321 .51549 m .43268 .51414 L .43325 .51485 L p
1 g
F P
s
P
p
.002 w
.43325 .51485 m .45475 .54169 L p
.43321 .51549 L 1 g
F P
s
P
p
.43327 .51435 m .43328 .51418 L .43327 .51428 L 1 g
F
P
p
.002 w
.43293 .52076 m .43268 .51414 L .43321 .51549 L p
1 g
F P
s
P
p
.43311 .51736 m .43327 .51428 L .43307 .51615 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43727 .54503 m .43388 .54501 L .43336 .53159 L p
1 g
F P
s
P
p
.002 w
.43704 .57164 m .43388 .54501 L p
.43989 .55158 L 1 g
F P
s
P
p
.45616 .56976 m .44796 .5718 L .44178 .55632 L 1 g
F
P
p
.002 w
.4585 .57194 m .45791 .57194 L p
.45616 .56976 L 1 g
F P
s
P
p
.002 w
.45791 .57194 m .44796 .5718 L p
.45616 .56976 L 1 g
F P
s
P
p
.44956 .56216 m .44178 .55632 L .43989 .55158 L 1 g
F
P
p
.4585 .57194 m .44178 .55632 L .44956 .56216 L 1 g
F
P
p
.002 w
.44796 .5718 m .43704 .57164 L p
.43989 .55158 L 1 g
F P
s
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44443 .55518 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56309 L p
1 g
F P
s
P
p
.002 w
.45599 .56699 m .4585 .57194 L p
.44956 .56216 L 1 g
F P
s
P
p
.002 w
.46157 .57092 m .4585 .57194 L .45599 .56699 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56309 L .45763 .56822 L 1 g
F
P
p
.46872 .57265 m .45763 .56822 L .46033 .57025 L 1 g
F
P
p
.002 w
.46283 .57849 m .4585 .57194 L p
.4696 .57527 L 1 g
F P
s
P
p
.002 w
.4683 .57456 m .46872 .57265 L p
.46033 .57025 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.48706 .58034 m .4696 .57527 L .46982 .575 L 1 g
F
P
p
.50122 .58473 m .48639 .58029 L .48706 .58034 L 1 g
F
P
p
.48639 .58029 m .4696 .57527 L .48706 .58034 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .5805 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .5805 L .49681 .58109 L 1 g
F
P
p
.002 w
.50572 .58107 m .50122 .58473 L .49681 .58109 L p
1 g
F P
s
P
p
.49845 .58109 m .49681 .58109 L .49798 .58118 L 1 g
F
P
p
.51079 .57862 m .49681 .58109 L .49845 .58109 L 1 g
F
P
p
.51079 .57862 m .49798 .58118 L .50174 .58147 L 1 g
F
P
p
.002 w
.51093 .58055 m .51079 .57862 L p
.50174 .58147 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52358 .56652 m .50572 .58107 L p
.47789 .56548 L 1 g
F P
s
P
p
.002 w
.49681 .58109 m .47789 .56548 L p
.50572 .58107 L 1 g
F P
s
P
p
.002 w
.48907 .5805 m .48921 .57862 L p
.47979 .57785 L 1 g
F P
s
P
p
.002 w
.4998 .58356 m .50122 .58473 L p
.46982 .575 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57456 L p
1 g
F P
s
P
p
.002 w
.4585 .57194 m .45879 .57185 L p
.4696 .57527 L 1 g
F P
s
P
p
.4696 .57527 m .45879 .57185 L .4683 .57456 L 1 g
F
P
p
.48921 .57862 m .4683 .57456 L .47979 .57785 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46157 .57092 m .47789 .56548 L p
.4696 .57527 L 1 g
F P
s
P
p
.48639 .58029 m .47764 .57962 L .4696 .57527 L 1 g
F
P
p
.47764 .57962 m .46283 .57849 L .4696 .57527 L 1 g
F
P
p
.002 w
.4683 .57456 m .4678 .57686 L p
.47979 .57785 L 1 g
F P
s
P
p
.002 w
.45879 .57185 m .46157 .57092 L p
.4683 .57456 L 1 g
F P
s
P
p
.002 w
.47789 .56548 m .4998 .58356 L p
.46982 .575 L 1 g
F P
s
P
p
.002 w
.48907 .5805 m .48889 .583 L p
.49798 .58118 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .5805 L p
1 g
F P
s
P
p
.47979 .57785 m .4678 .57686 L .48907 .5805 L 1 g
F
P
p
.46033 .57025 m .45002 .56518 L .46799 .576 L 1 g
F
P
p
.45763 .56822 m .45365 .56663 L .46033 .57025 L 1 g
F
P
p
.45365 .56663 m .45002 .56518 L .46033 .57025 L 1 g
F
P
p
.002 w
.46799 .576 m .4683 .57456 L p
.46033 .57025 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47789 .56548 m .46157 .57092 L p
.44488 .54509 L 1 g
F P
s
P
p
.002 w
.45599 .56699 m .44488 .54509 L p
.46157 .57092 L 1 g
F P
s
P
p
.45763 .56822 m .45599 .56699 L .45002 .56518 L 1 g
F
P
p
.002 w
.45079 .56309 m .45072 .56328 L p
.45599 .56699 L 1 g
F P
s
P
p
.002 w
.45072 .56328 m .45002 .56518 L p
.45599 .56699 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43826 .54752 L p
1 g
F P
s
P
p
.44704 .55843 m .43989 .55158 L .44069 .55053 L 1 g
F
P
p
.002 w
.43388 .54501 m .43727 .54503 L p
.43989 .55158 L 1 g
F P
s
P
p
.45146 .56129 m .43826 .54752 L .44443 .55518 L 1 g
F
P
p
.43925 .54566 m .43501 .53728 L .43727 .54503 L 1 g
F
P
p
.002 w
.43826 .54752 m .43925 .54566 L p
.43727 .54503 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43253 .5287 L p
1 g
F P
s
P
p
.002 w
.42291 .54148 m .43027 .52087 L p
.43225 .53409 L 1 g
F P
s
P
p
.002 w
.43388 .54501 m .43172 .54431 L p
.43225 .53409 L 1 g
F P
s
P
p
.002 w
.43172 .54431 m .42291 .54148 L p
.43225 .53409 L 1 g
F P
s
P
p
.002 w
.43253 .5287 m .43346 .52734 L p
.43311 .51733 L 1 g
F P
s
P
p
.43925 .54566 m .43253 .5287 L .43497 .53719 L 1 g
F
P
p
.002 w
.43027 .52087 m .43268 .51414 L .43336 .53159 L p
1 g
F P
s
P
p
.002 w
.43336 .53159 m .43388 .54501 L p
.43027 .52087 L 1 g
F P
s
P
p
.002 w
.43268 .51414 m .43346 .5102 L p
.43377 .50977 L 1 g
F P
s
P
p
.43485 .50826 m .44253 .49141 L .43835 .50007 L 1 g
F
P
p
.44253 .49141 m .44166 .49322 L .43595 .49777 L 1 g
F
P
p
.002 w
.43342 .51296 m .43268 .51414 L p
.43377 .50977 L 1 g
F P
s
P
p
.002 w
.43379 .50952 m .43485 .50826 L p
.43835 .50007 L 1 g
F P
s
P
p
.44166 .49322 m .45001 .48656 L .43346 .5102 L 1 g
F
P
p
.002 w
.43379 .50952 m .43379 .50952 L p
.43307 .51615 L 1 g
F P
s
P
p
.002 w
.42787 .47965 m .43692 .48103 L p
.43346 .5102 L 1 g
F P
s
P
p
.002 w
.43403 .50739 m .43346 .5102 L p
.43692 .48103 L 1 g
F P
s
P
p
.002 w
.43346 .5102 m .43268 .51414 L .43243 .51235 L p
1 g
F P
s
P
p
.002 w
.43243 .51235 m .42787 .47965 L p
.43346 .5102 L 1 g
F P
s
P
p
.002 w
.43379 .50952 m .43287 .51061 L p
.43307 .5161 L 1 g
F P
s
P
p
.43307 .51615 m .43379 .50952 L .43307 .5161 L 1 g
F
P
p
.002 w
.43692 .48103 m .43923 .48138 L .43403 .50739 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43379 .50952 L p
1 g
F P
s
P
p
.002 w
.43379 .50952 m .43379 .50952 L p
.43381 .50948 L 1 g
F P
s
P
p
.43381 .50948 m .44166 .49233 L .43379 .50952 L 1 g
F
P
p
.43835 .50007 m .44166 .49233 L .43379 .50952 L 1 g
F
P
p
.002 w
.44837 .48577 m .45001 .48656 L p
.44166 .49322 L 1 g
F P
s
P
p
.44837 .48577 m .44166 .49322 L .44253 .49141 L 1 g
F
P
p
.002 w
.45001 .48656 m .43342 .51296 L p
.43377 .50977 L 1 g
F P
s
P
p
.002 w
.41311 .5349 m .40552 .52594 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.42291 .54148 m .41311 .5349 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.40552 .52594 m .40093 .51556 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.40093 .51556 m .39986 .50483 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.39986 .50483 m .40243 .4949 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.40243 .4949 m .40843 .48684 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.40843 .48684 m .41722 .48156 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.41722 .48156 m .42787 .47965 L .43268 .51414 L closepath p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43154 .53013 L p
1 g
F P
s
P
p
.002 w
.43154 .53013 m .43253 .5287 L p
.4327 .5195 L 1 g
F P
s
P
p
.4327 .5195 m .43287 .51061 L .43154 .53013 L 1 g
F
P
p
.43311 .51733 m .43287 .51061 L .43253 .5287 L 1 g
F
P
p
.002 w
.43253 .5287 m .43146 .53025 L p
.43497 .53719 L 1 g
F P
s
P
p
.002 w
.43727 .54503 m .44488 .54509 L p
.43989 .55158 L 1 g
F P
s
P
p
.002 w
.43826 .54752 m .43743 .5491 L p
.44443 .55518 L 1 g
F P
s
P
p
.002 w
.44488 .54509 m .45599 .56699 L p
.44704 .55843 L 1 g
F P
s
P
p
.44704 .55843 m .44069 .55053 L .44488 .54509 L 1 g
F
P
p
.44956 .56216 m .43989 .55158 L .45599 .56699 L 1 g
F
P
p
.002 w
.43809 .54785 m .43826 .54752 L p
.43727 .54503 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56309 L p
1 g
F P
s
P
p
.44443 .55518 m .43743 .5491 L .45079 .56309 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46799 .576 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43809 .54785 L p
.433 .53434 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43181 .53137 L p
.433 .53434 L 1 g
F P
s
P
p
.002 w
.43181 .53137 m .43743 .5491 L p
.433 .53434 L 1 g
F P
s
P
p
.43501 .53728 m .43146 .53025 L .43809 .54785 L 1 g
F
P
p
.002 w
.44488 .54509 m .43727 .54503 L p
.43293 .52076 L 1 g
F P
s
P
p
.002 w
.43336 .53159 m .43293 .52076 L p
.43727 .54503 L 1 g
F P
s
P
p
.002 w
.43321 .51549 m .44488 .54509 L p
.43293 .52076 L 1 g
F P
s
P
p
.002 w
.44253 .49141 m .44166 .49233 L p
.43835 .50007 L 1 g
F P
s
P
p
.002 w
.44202 .49196 m .44339 .4905 L p
.45152 .48271 L 1 g
F P
s
P
p
.44777 .44655 m .45412 .48018 L .44988 .4843 L 1 g
F
P
p
.002 w
.43923 .48138 m .44777 .44655 L p
.44988 .4843 L 1 g
F P
s
P
p
.002 w
.45001 .48656 m .44837 .48577 L p
.44988 .4843 L 1 g
F P
s
P
p
.002 w
.44837 .48577 m .43923 .48138 L p
.44988 .4843 L 1 g
F P
s
P
p
.002 w
.45764 .47676 m .45717 .47727 L p
.45261 .48165 L 1 g
F P
s
P
p
.002 w
.45717 .47727 m .45698 .47747 L p
.45387 .48046 L 1 g
F P
s
P
p
.002 w
.43595 .49777 m .43923 .48138 L .44837 .48577 L p
1 g
F P
s
P
p
.002 w
.45412 .48018 m .4692 .45677 L p
.46602 .4686 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44202 .49196 L p
1 g
F P
s
P
p
.45152 .48271 m .45698 .47747 L .44202 .49196 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45766 .47674 L p
1 g
F P
s
P
p
.46763 .47197 m .47718 .46778 L .45766 .47674 L 1 g
F
P
p
.002 w
.47731 .46758 m .47786 .46667 L p
.49113 .46532 L 1 g
F P
s
P
p
.48952 .42589 m .49755 .46427 L .48743 .46581 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.4692 .45677 m .48952 .42589 L p
.48743 .46581 L 1 g
F P
s
P
p
.002 w
.48046 .46687 m .4692 .45677 L p
.48743 .46581 L 1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .46434 L p
.49049 .46534 L 1 g
F P
s
P
p
.002 w
.5 .46434 m .5 .46442 L p
.49723 .4647 L 1 g
F P
s
P
p
.002 w
.4692 .45677 m .48046 .46687 L p
.46598 .46874 L 1 g
F P
s
P
p
.002 w
.49755 .46427 m .51575 .44946 L p
.51096 .46207 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47731 .46758 L p
1 g
F P
s
P
p
.49113 .46532 m .5 .46442 L .47731 .46758 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.51033 .46539 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.002 w
.52244 .46717 m .52282 .46778 L p
.51033 .46539 L 1 g
F P
s
P
p
.002 w
.52251 .46728 m .52244 .46717 L p
.52821 .47001 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.52821 .47001 L 1 g
F P
s
P
p
.002 w
.51575 .44946 m .52821 .47001 L p
.51114 .4616 L 1 g
F P
s
P
p
.002 w
.52821 .47001 m .51575 .44946 L p
.5347 .47312 L 1 g
F P
s
P
p
.55357 .48761 m .54103 .51059 L .54099 .47612 L 1 g
F
P
p
.54235 .47674 m .54099 .47612 L .54099 .47543 L 1 g
F
P
p
.55357 .48761 m .54099 .47612 L .54235 .47674 L 1 g
F
P
p
.002 w
.52282 .46778 m .52251 .46728 L p
.53229 .47214 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52384 .46827 L p
.53229 .47214 L 1 g
F P
s
P
p
.002 w
.52384 .46827 m .52282 .46778 L p
.53229 .47214 L 1 g
F P
s
P
p
.53339 .47249 m .54302 .47747 L .52251 .46728 L 1 g
F
P
p
.53339 .47249 m .54024 .47578 L .5359 .47379 L 1 g
F
P
p
.002 w
.54394 .42553 m .56672 .46349 L .54024 .47578 L p
1 g
F P
s
P
p
.54394 .42553 m .54024 .47578 L .5347 .47312 L 1 g
F
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.5359 .47379 L 1 g
F P
s
P
p
.002 w
.54024 .47578 m .54099 .47543 L p
.54099 .47612 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54174 .47608 L p
.54854 .48274 L 1 g
F P
s
P
p
.002 w
.54099 .47543 m .56672 .46349 L p
.55357 .48761 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54235 .47674 L p
1 g
F P
s
P
p
.54854 .48274 m .55834 .49233 L .54235 .47674 L 1 g
F
P
p
.002 w
.55715 .49108 m .55834 .49233 L p
.54854 .48274 L 1 g
F P
s
P
p
.56101 .49891 m .56468 .50637 L .56298 .50269 L 1 g
F
P
p
.002 w
.53746 .54093 m .54103 .51059 L .56468 .50637 L p
1 g
F P
s
P
p
.56746 .51243 m .53746 .54093 L .56468 .50637 L 1 g
F
P
p
.002 w
.56602 .5093 m .56713 .51061 L p
.56298 .50269 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56602 .5093 L p
1 g
F P
s
P
p
.56653 .51721 m .56854 .53025 L .56602 .5093 L 1 g
F
P
p
.002 w
.56725 .52837 m .56854 .53025 L p
.56653 .51721 L 1 g
F P
s
P
p
.56463 .53781 m .56326 .54273 L .56414 .5405 L 1 g
F
P
p
.002 w
.56153 .54713 m .56257 .5491 L p
.56414 .5405 L 1 g
F P
s
P
p
.56116 .54807 m .55652 .55332 L .56051 .54839 L 1 g
F
P
p
.56007 .55085 m .55652 .55332 L .56116 .54807 L 1 g
F
P
p
.54854 .56129 m .53755 .571 L .54102 .56845 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58055 L p
1 g
F P
s
P
p
.52232 .57941 m .51093 .58055 L .53163 .57427 L 1 g
F
P
p
.002 w
.50122 .58473 m .50572 .58107 L p
.54593 .57706 L 1 g
F P
s
P
p
.002 w
.51093 .58055 m .51111 .583 L p
.52304 .57688 L 1 g
F P
s
P
p
.53128 .57265 m .51093 .58055 L .52304 .57688 L 1 g
F
P
p
.54593 .57706 m .52232 .57941 L .53163 .57427 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53163 .57427 L p
1 g
F P
s
P
p
.002 w
.53163 .57427 m .53128 .57265 L p
.52304 .57688 L 1 g
F P
s
P
p
.52304 .57688 m .51111 .583 L .53163 .57427 L 1 g
F
P
p
.53673 .57272 m .53163 .57427 L .53549 .57214 L 1 g
F
P
p
.54593 .57706 m .53163 .57427 L .53673 .57272 L 1 g
F
P
p
.53163 .57427 m .50572 .58107 L .53549 .57214 L 1 g
F
P
p
.51093 .58055 m .50572 .58107 L .53163 .57427 L 1 g
F
P
p
.002 w
.50572 .58107 m .52358 .56652 L p
.53549 .57214 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54966 .56431 L p
1 g
F P
s
P
p
.002 w
.54966 .56431 m .54854 .56129 L p
.53946 .56994 L 1 g
F P
s
P
p
.53946 .56994 m .5322 .57686 L .54966 .56431 L 1 g
F
P
p
.002 w
.53755 .571 m .52358 .56652 L p
.56788 .54877 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56153 .54713 L p
1 g
F P
s
P
p
.55653 .55332 m .54998 .56518 L .56153 .54713 L 1 g
F
P
p
.002 w
.54902 .56259 m .54998 .56518 L p
.55653 .55332 L 1 g
F P
s
P
p
.54102 .56845 m .53755 .571 L .53946 .56994 L 1 g
F
P
p
.002 w
.53163 .57427 m .5322 .57686 L p
.53946 .56994 L 1 g
F P
s
P
p
.002 w
.52358 .56652 m .53755 .571 L p
.53549 .57214 L 1 g
F P
s
P
p
.002 w
.51105 .58218 m .51093 .58055 L p
.50174 .58147 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51105 .58218 L p
1 g
F P
s
P
p
.49798 .58118 m .48889 .583 L .51105 .58218 L 1 g
F
P
p
.002 w
.64743 .41472 m .6596 .47418 L .63623 .48575 L p
1 g
F P
s
P
p
.002 w
.36939 .42845 m .35281 .45199 L .33502 .42994 L p
1 g
F P
s
P
p
.002 w
.33502 .42994 m .35595 .39956 L .36939 .42845 L p
1 g
F P
s
P
p
.004 w
.49776 .4333 m
.5 .43051 L
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.56629 .31525 m .5072 .28815 L .5192 .26773 L p
1 g
F P
s
P
p
.002 w
.5192 .26773 m .58082 .29584 L .56629 .31525 L p
1 g
F P
s
P
p
.002 w
.38769 .37884 m .35595 .39956 L .34711 .37224 L p
1 g
F P
s
P
p
.002 w
.34711 .37224 m .38459 .34723 L .38769 .37884 L p
1 g
F P
s
P
p
.002 w
.37551 .47391 m .37067 .49345 L .34605 .48046 L p
1 g
F P
s
P
p
.002 w
.34605 .48046 m .35281 .45199 L .37551 .47391 L p
1 g
F P
s
P
p
.002 w
.43127 .33694 m .38459 .34723 L .38501 .31885 L p
1 g
F P
s
P
p
.002 w
.38501 .31885 m .43753 .30683 L .43127 .33694 L p
1 g
F P
s
P
p
.002 w
.40552 .52594 m .41311 .5349 L .39672 .55192 L p
1 g
F P
s
P
p
.002 w
.39672 .55192 m .38195 .53456 L .40552 .52594 L p
1 g
F P
s
P
p
.002 w
.41572 .56471 m .39672 .55192 L .41311 .5349 L p
1 g
F P
s
P
p
.002 w
.49462 .31356 m .43753 .30683 L .44549 .2812 L p
1 g
F P
s
P
p
.002 w
.44549 .2812 m .5072 .28815 L .49462 .31356 L p
1 g
F P
s
P
p
.002 w
.64743 .41472 m .61511 .35935 L .63164 .34179 L p
1 g
F P
s
P
p
.002 w
.58082 .29584 m .63164 .34179 L .61511 .35935 L p
1 g
F P
s
P
p
.002 w
.41311 .5349 m .42291 .54148 L .41572 .56471 L p
1 g
F P
s
P
p
.002 w
.43704 .57164 m .41572 .56471 L .42291 .54148 L p
1 g
F P
s
P
p
.002 w
.40093 .51556 m .40552 .52594 L .38195 .53456 L p
1 g
F P
s
P
p
.002 w
.38195 .53456 m .37294 .51439 L .40093 .51556 L p
1 g
F P
s
P
p
.002 w
.61511 .35935 m .56629 .31525 L .58082 .29584 L p
1 g
F P
s
P
p
.002 w
.55277 .57589 m .57095 .54327 L .60166 .54216 L p
1 g
F P
s
P
p
.002 w
.42291 .54148 m .43388 .54501 L .43704 .57164 L p
1 g
F P
s
P
p
.002 w
.39986 .50483 m .40093 .51556 L .37294 .51439 L p
1 g
F P
s
P
p
.002 w
.37294 .51439 m .37067 .49345 L .39986 .50483 L p
1 g
F P
s
P
p
.002 w
.60806 .49596 m .60166 .54216 L .57095 .54327 L p
1 g
F P
s
P
p
.002 w
.60166 .54216 m .60806 .49596 L .63623 .48575 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.38707 .45791 m .37551 .47391 L .35281 .45199 L p
1 g
F P
s
P
p
.002 w
.35281 .45199 m .36939 .42845 L .38707 .45791 L p
1 g
F P
s
P
p
.002 w
.63623 .48575 m .62465 .43079 L .64743 .41472 L p
1 g
F P
s
P
p
.002 w
.61511 .35935 m .64743 .41472 L .62465 .43079 L p
1 g
F P
s
P
p
.002 w
.3943 .41259 m .36939 .42845 L .35595 .39956 L p
1 g
F P
s
P
p
.002 w
.35595 .39956 m .38769 .37884 L .3943 .41259 L p
1 g
F P
s
P
p
.002 w
.62465 .43079 m .63623 .48575 L .60806 .49596 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40243 .4949 m .39986 .50483 L .37067 .49345 L p
1 g
F P
s
P
p
.002 w
.37067 .49345 m .37551 .47391 L .40243 .4949 L p
1 g
F P
s
P
p
.002 w
.54929 .3388 m .49462 .31356 L .5072 .28815 L p
1 g
F P
s
P
p
.002 w
.5072 .28815 m .56629 .31525 L .54929 .3388 L p
1 g
F P
s
P
p
.004 w
.51204 .31232 m
.51664 .26723 L
s
P
p
.002 w
.42702 .37055 m .38769 .37884 L .38459 .34723 L p
1 g
F P
s
P
p
.002 w
.38459 .34723 m .43127 .33694 L .42702 .37055 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48191 .34321 m .43127 .33694 L .43753 .30683 L p
1 g
F P
s
P
p
.002 w
.43753 .30683 m .49462 .31356 L .48191 .34321 L p
1 g
F P
s
P
p
.002 w
.47789 .56548 m .49309 .55281 L .52358 .56652 L p
1 g
F P
s
P
p
.002 w
.53746 .54093 m .52358 .56652 L .49309 .55281 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.44488 .54509 m .45475 .54169 L .47789 .56548 L p
1 g
F P
s
P
p
.002 w
.49309 .55281 m .47789 .56548 L .45475 .54169 L p
1 g
F P
s
P
p
.002 w
.62465 .43079 m .59453 .37962 L .61511 .35935 L p
1 g
F P
s
P
p
.002 w
.56629 .31525 m .61511 .35935 L .59453 .37962 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.57095 .54327 m .57596 .50436 L .60806 .49596 L p
1 g
F P
s
P
p
.002 w
.59453 .37962 m .54929 .3388 L .56629 .31525 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.40843 .48684 m .40243 .4949 L .37551 .47391 L p
1 g
F P
s
P
p
.002 w
.37551 .47391 m .38707 .45791 L .40843 .48684 L p
1 g
F P
s
P
p
.002 w
.40426 .44727 m .38707 .45791 L .36939 .42845 L p
1 g
F P
s
P
p
.002 w
.36939 .42845 m .3943 .41259 L .40426 .44727 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59745 .44726 m .60806 .49596 L .57596 .50436 L p
1 g
F P
s
P
p
.002 w
.60806 .49596 m .59745 .44726 L .62465 .43079 L p
1 g
F P
s
P
p
.002 w
.59453 .37962 m .62465 .43079 L .59745 .44726 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42498 .40645 m .3943 .41259 L .38769 .37884 L p
1 g
F P
s
P
p
.002 w
.38769 .37884 m .42702 .37055 L .42498 .40645 L p
1 g
F P
s
P
p
.002 w
.45475 .54169 m .4624 .53514 L .49309 .55281 L p
1 g
F P
s
P
p
.002 w
.50238 .53516 m .49309 .55281 L .4624 .53514 L p
1 g
F P
s
P
p
.002 w
.49309 .55281 m .50238 .53516 L .53746 .54093 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53036 .36575 m .48191 .34321 L .49462 .31356 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50767 .3552 L
s
P
p
.002 w
.49462 .31356 m .54929 .3388 L .53036 .36575 L p
1 g
F P
s
P
p
.004 w
.51074 .32516 m
.51204 .31232 L
s
P
p
.004 w
.51023 .3301 m
.51032 .32927 L
s
P
p
.004 w
.51032 .32927 m
.51074 .32516 L
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.54103 .51059 m .53746 .54093 L .50238 .53516 L p
1 g
F P
s
P
p
.002 w
.41722 .48156 m .40843 .48684 L .38707 .45791 L p
1 g
F P
s
P
p
.002 w
.38707 .45791 m .40426 .44727 L .41722 .48156 L p
1 g
F P
s
P
p
.002 w
.46954 .3761 m .42702 .37055 L .43127 .33694 L p
1 g
F P
s
P
p
.002 w
.43127 .33694 m .48191 .34321 L .46954 .3761 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.4624 .53514 m .467 .52612 L .50238 .53516 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59745 .44726 m .57053 .40195 L .59453 .37962 L p
1 g
F P
s
P
p
.002 w
.54929 .3388 m .59453 .37962 L .57053 .40195 L p
1 g
F P
s
P
p
.002 w
.42527 .44329 m .40426 .44727 L .3943 .41259 L p
1 g
F P
s
P
p
.002 w
.3943 .41259 m .42498 .40645 L .42527 .44329 L p
1 g
F P
s
P
p
.002 w
.57596 .50436 m .56672 .46349 L .59745 .44726 L p
1 g
F P
s
P
p
.002 w
.50458 .51439 m .50238 .53516 L .467 .52612 L p
1 g
F P
s
P
p
.002 w
.50238 .53516 m .50458 .51439 L .54103 .51059 L p
1 g
F P
s
P
p
.002 w
.57053 .40195 m .53036 .36575 L .54929 .3388 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.467 .52612 m .46799 .51558 L .50458 .51439 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57053 .40195 m .59745 .44726 L .56672 .46349 L p
1 g
F P
s
P
p
.002 w
.42787 .47965 m .41722 .48156 L .40426 .44727 L p
1 g
F P
s
P
p
.002 w
.40426 .44727 m .42527 .44329 L .42787 .47965 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.45801 .411 m .42498 .40645 L .42702 .37055 L p
1 g
F P
s
P
p
.002 w
.42702 .37055 m .46954 .3761 L .45801 .411 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46799 .51558 m .46524 .50468 L .49931 .49278 L p
1 g
F P
s
P
p
.002 w
.49931 .49278 m .50458 .51439 L .46799 .51558 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.53358 .47887 m .54103 .51059 L .50458 .51439 L p
1 g
F P
s
P
p
.002 w
.51018 .39515 m .46954 .3761 L .48191 .34321 L p
1 g
F P
s
P
p
.002 w
.48191 .34321 m .53036 .36575 L .51018 .39515 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.43923 .48138 m .42787 .47965 L .42527 .44329 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.50458 .51439 m .49931 .49278 L .53358 .47887 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46524 .50468 m .45902 .49463 L .48707 .4728 L p
1 g
F P
s
P
p
.002 w
.48707 .4728 m .49931 .49278 L .46524 .50468 L p
1 g
F P
s
P
p
.002 w
.42527 .44329 m .44777 .44655 L .43923 .48138 L p
1 g
F P
s
P
p
.002 w
.44777 .44655 m .42527 .44329 L .42498 .40645 L p
1 g
F P
s
P
p
.002 w
.42498 .40645 m .45801 .411 L .44777 .44655 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56672 .46349 m .54394 .42553 L .57053 .40195 L p
1 g
F P
s
P
p
.002 w
.53036 .36575 m .57053 .40195 L .54394 .42553 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54394 .42553 m .51018 .39515 L .53036 .36575 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.48952 .42589 m .45801 .411 L .46954 .3761 L p
1 g
F P
s
P
p
.002 w
.46954 .3761 m .51018 .39515 L .48952 .42589 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.4692 .45677 m .44777 .44655 L .45801 .411 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45801 .411 m .48952 .42589 L .4692 .45677 L p
1 g
F P
s
P
p
.002 w
.51018 .39515 m .54394 .42553 L .51575 .44946 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51575 .44946 m .48952 .42589 L .51018 .39515 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.392 .56467 m
.40991 .54242 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .51664 .26723 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .392 .56467 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.352713)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.352713)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46141 .4192 m .47541 .44236 L .49721 .42397 L p
1 g
F P
s
P
p
.002 w
.49721 .42397 m .48771 .40817 L .46141 .4192 L p
1 g
F P
s
P
p
.002 w
.51115 .43611 m .49721 .42397 L .47541 .44236 L p
1 g
F P
s
P
p
.002 w
.48771 .40817 m .49721 .42397 L .5191 .40573 L p
1 g
F P
s
P
p
.002 w
.49721 .42397 m .51115 .43611 L .52618 .41189 L p
1 g
F P
s
P
p
.002 w
.52618 .41189 m .5191 .40573 L .49721 .42397 L p
1 g
F P
s
P
p
.002 w
.47541 .44236 m .49586 .4602 L .51115 .43611 L p
1 g
F P
s
P
p
.002 w
.52806 .44334 m .51115 .43611 L .49586 .4602 L p
1 g
F P
s
P
p
.002 w
.51115 .43611 m .52806 .44334 L .53477 .41554 L p
1 g
F P
s
P
p
.002 w
.53477 .41554 m .52618 .41189 L .51115 .43611 L p
1 g
F P
s
P
p
.002 w
.45534 .39306 m .46141 .4192 L .48771 .40817 L p
1 g
F P
s
P
p
.002 w
.48771 .40817 m .48365 .39037 L .45534 .39306 L p
1 g
F P
s
P
p
.002 w
.48365 .39037 m .48771 .40817 L .51429 .3977 L p
1 g
F P
s
P
p
.002 w
.5191 .40573 m .51429 .3977 L .48771 .40817 L p
1 g
F P
s
P
p
.002 w
.43587 .43057 m .45407 .46057 L .47541 .44236 L p
1 g
F P
s
P
p
.002 w
.47541 .44236 m .46141 .4192 L .43587 .43057 L p
1 g
F P
s
P
p
.002 w
.49586 .4602 m .47541 .44236 L .45407 .46057 L p
1 g
F P
s
P
p
.002 w
.45407 .46057 m .48057 .4837 L .49586 .4602 L p
1 g
F P
s
P
p
.002 w
.52066 .47087 m .49586 .4602 L .48057 .4837 L p
1 g
F P
s
P
p
.002 w
.49586 .4602 m .52066 .47087 L .52806 .44334 L p
1 g
F P
s
P
p
.002 w
.54619 .44487 m .52806 .44334 L .52066 .47087 L p
1 g
F P
s
P
p
.002 w
.52806 .44334 m .54619 .44487 L .54397 .41628 L p
1 g
F P
s
P
p
.002 w
.54397 .41628 m .53477 .41554 L .52806 .44334 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .51429 .3977 L .5191 .40573 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .5191 .40573 L .52618 .41189 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .52618 .41189 L .53477 .41554 L closepath p
1 g
F P
s
P
p
.002 w
.51429 .3977 m .51226 .38866 L .48365 .39037 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .51226 .38866 L .51429 .3977 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .53477 .41554 L .54397 .41628 L closepath p
1 g
F P
s
P
p
.002 w
.42787 .39669 m .43587 .43057 L .46141 .4192 L p
1 g
F P
s
P
p
.002 w
.46141 .4192 m .45534 .39306 L .42787 .39669 L p
1 g
F P
s
P
p
.002 w
.45791 .36666 m .45534 .39306 L .48365 .39037 L p
1 g
F P
s
P
p
.002 w
.48365 .39037 m .48549 .37243 L .45791 .36666 L p
1 g
F P
s
P
p
.002 w
.48549 .37243 m .48365 .39037 L .51226 .38866 L p
1 g
F P
s
P
p
.002 w
.51226 .38866 m .51324 .37958 L .48549 .37243 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .51324 .37958 L .51226 .38866 L closepath p
1 g
F P
s
P
p
.002 w
.48057 .4837 m .51271 .49762 L .52066 .47087 L p
1 g
F P
s
P
p
.002 w
.5473 .47323 m .52066 .47087 L .51271 .49762 L p
1 g
F P
s
P
p
.002 w
.52066 .47087 m .5473 .47323 L .54619 .44487 L p
1 g
F P
s
P
p
.002 w
.55278 .41401 m .54397 .41628 L .54619 .44487 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .54397 .41628 L .55278 .41401 L closepath p
1 g
F P
s
P
p
.002 w
.56363 .44049 m .54619 .44487 L .5473 .47323 L p
1 g
F P
s
P
p
.002 w
.54619 .44487 m .56363 .44049 L .55278 .41401 L p
1 g
F P
s
P
p
.002 w
.4931 .35626 m .48549 .37243 L .51324 .37958 L p
1 g
F P
s
P
p
.002 w
.51324 .37958 m .51715 .37143 L .4931 .35626 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .51715 .37143 L .51324 .37958 L closepath p
1 g
F P
s
P
p
.002 w
.41156 .44209 m .43359 .47827 L .45407 .46057 L p
1 g
F P
s
P
p
.002 w
.45407 .46057 m .43587 .43057 L .41156 .44209 L p
1 g
F P
s
P
p
.002 w
.48057 .4837 m .45407 .46057 L .43359 .47827 L p
1 g
F P
s
P
p
.002 w
.56027 .40897 m .55278 .41401 L .56363 .44049 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .55278 .41401 L .56027 .40897 L closepath p
1 g
F P
s
P
p
.002 w
.43359 .47827 m .46557 .5062 L .48057 .4837 L p
1 g
F P
s
P
p
.002 w
.51271 .49762 m .48057 .4837 L .46557 .5062 L p
1 g
F P
s
P
p
.002 w
.43103 .36238 m .42787 .39669 L .45534 .39306 L p
1 g
F P
s
P
p
.002 w
.45534 .39306 m .45791 .36666 L .43103 .36238 L p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .55013 .36258 L .54101 .3604 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .54101 .3604 L .53182 .36127 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .53182 .36127 L .52356 .36509 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .52356 .36509 L .51715 .37143 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .56027 .40897 L .5656 .40168 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .5656 .40168 L .56819 .39293 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .56819 .39293 L .56774 .38366 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .56774 .38366 L .56428 .37489 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .56428 .37489 L .55819 .3676 L closepath p
1 g
F P
s
P
p
.002 w
.54067 .38796 m .55819 .3676 L .55013 .36258 L closepath p
1 g
F P
s
P
p
.002 w
.46898 .34276 m .45791 .36666 L .48549 .37243 L p
1 g
F P
s
P
p
.002 w
.48549 .37243 m .4931 .35626 L .46898 .34276 L p
1 g
F P
s
P
p
.002 w
.50573 .34362 m .4931 .35626 L .51715 .37143 L p
1 g
F P
s
P
p
.002 w
.51715 .37143 m .52356 .36509 L .50573 .34362 L p
1 g
F P
s
P
p
.002 w
.51271 .49762 m .54726 .50083 L .5473 .47323 L p
1 g
F P
s
P
p
.002 w
.573 .46693 m .5473 .47323 L .54726 .50083 L p
1 g
F P
s
P
p
.002 w
.5473 .47323 m .573 .46693 L .56363 .44049 L p
1 g
F P
s
P
p
.002 w
.56363 .44049 m .5785 .43062 L .56027 .40897 L p
1 g
F P
s
P
p
.002 w
.5656 .40168 m .56027 .40897 L .5785 .43062 L p
1 g
F P
s
P
p
.002 w
.40176 .40121 m .41156 .44209 L .43587 .43057 L p
1 g
F P
s
P
p
.002 w
.43587 .43057 m .42787 .39669 L .40176 .40121 L p
1 g
F P
s
P
p
.002 w
.5785 .43062 m .56363 .44049 L .573 .46693 L p
1 g
F P
s
P
p
.002 w
.46557 .5062 m .50433 .52309 L .51271 .49762 L p
1 g
F P
s
P
p
.002 w
.54726 .50083 m .51271 .49762 L .50433 .52309 L p
1 g
F P
s
P
p
.002 w
.52207 .33594 m .50573 .34362 L .52356 .36509 L p
1 g
F P
s
P
p
.002 w
.52356 .36509 m .53182 .36127 L .52207 .33594 L p
1 g
F P
s
P
p
.002 w
.5785 .43062 m .58917 .41624 L .5656 .40168 L p
1 g
F P
s
P
p
.002 w
.56819 .39293 m .5656 .40168 L .58917 .41624 L p
1 g
F P
s
P
p
.002 w
.48751 .32399 m .46898 .34276 L .4931 .35626 L p
1 g
F P
s
P
p
.002 w
.4931 .35626 m .50573 .34362 L .48751 .32399 L p
1 g
F P
s
P
p
.002 w
.54034 .33412 m .52207 .33594 L .53182 .36127 L p
1 g
F P
s
P
p
.002 w
.53182 .36127 m .54101 .3604 L .54034 .33412 L p
1 g
F P
s
P
p
.002 w
.44524 .33122 m .43103 .36238 L .45791 .36666 L p
1 g
F P
s
P
p
.002 w
.45791 .36666 m .46898 .34276 L .44524 .33122 L p
1 g
F P
s
P
p
.002 w
.58917 .41624 m .59441 .39888 L .56819 .39293 L p
1 g
F P
s
P
p
.002 w
.56774 .38366 m .56819 .39293 L .59441 .39888 L p
1 g
F P
s
P
p
.002 w
.573 .46693 m .59501 .45251 L .5785 .43062 L p
1 g
F P
s
P
p
.002 w
.58917 .41624 m .5785 .43062 L .59501 .45251 L p
1 g
F P
s
P
p
.002 w
.40538 .35972 m .40176 .40121 L .42787 .39669 L p
1 g
F P
s
P
p
.002 w
.42787 .39669 m .43103 .36238 L .40538 .35972 L p
1 g
F P
s
P
p
.002 w
.55853 .33842 m .54034 .33412 L .54101 .3604 L p
1 g
F P
s
P
p
.002 w
.54101 .3604 m .55013 .36258 L .55853 .33842 L p
1 g
F P
s
P
p
.002 w
.54726 .50083 m .58069 .49283 L .573 .46693 L p
1 g
F P
s
P
p
.002 w
.59501 .45251 m .573 .46693 L .58069 .49283 L p
1 g
F P
s
P
p
.002 w
.38898 .45355 m .41438 .49511 L .43359 .47827 L p
1 g
F P
s
P
p
.002 w
.43359 .47827 m .41156 .44209 L .38898 .45355 L p
1 g
F P
s
P
p
.002 w
.46557 .5062 m .43359 .47827 L .41438 .49511 L p
1 g
F P
s
P
p
.002 w
.59441 .39888 m .59359 .38044 L .56774 .38366 L p
1 g
F P
s
P
p
.002 w
.56428 .37489 m .56774 .38366 L .59359 .38044 L p
1 g
F P
s
P
p
.002 w
.41438 .49511 m .45115 .52724 L .46557 .5062 L p
1 g
F P
s
P
p
.002 w
.50433 .52309 m .46557 .5062 L .45115 .52724 L p
1 g
F P
s
P
p
.002 w
.5746 .3484 m .55853 .33842 L .55013 .36258 L p
1 g
F P
s
P
p
.002 w
.55013 .36258 m .55819 .3676 L .5746 .3484 L p
1 g
F P
s
P
p
.002 w
.50433 .52309 m .54606 .52713 L .54726 .50083 L p
1 g
F P
s
P
p
.002 w
.58069 .49283 m .54726 .50083 L .54606 .52713 L p
1 g
F P
s
P
p
.002 w
.59359 .38044 m .58674 .36296 L .56428 .37489 L p
1 g
F P
s
P
p
.002 w
.55819 .3676 m .56428 .37489 L .58674 .36296 L p
1 g
F P
s
P
p
.002 w
.58674 .36296 m .5746 .3484 L .55819 .3676 L p
1 g
F P
s
P
p
.002 w
.51159 .31249 m .48751 .32399 L .50573 .34362 L p
1 g
F P
s
P
p
.002 w
.50573 .34362 m .52207 .33594 L .51159 .31249 L p
1 g
F P
s
P
p
.002 w
.37755 .40655 m .38898 .45355 L .41156 .44209 L p
1 g
F P
s
P
p
.002 w
.41156 .44209 m .40176 .40121 L .37755 .40655 L p
1 g
F P
s
P
p
.002 w
.59501 .45251 m .6109 .43138 L .58917 .41624 L p
1 g
F P
s
P
p
.002 w
.59441 .39888 m .58917 .41624 L .6109 .43138 L p
1 g
F P
s
P
p
.002 w
.45115 .52724 m .49569 .54676 L .50433 .52309 L p
1 g
F P
s
P
p
.002 w
.54606 .52713 m .50433 .52309 L .49569 .54676 L p
1 g
F P
s
P
p
.002 w
.46922 .30662 m .44524 .33122 L .46898 .34276 L p
1 g
F P
s
P
p
.002 w
.46898 .34276 m .48751 .32399 L .46922 .30662 L p
1 g
F P
s
P
p
.002 w
.42236 .32191 m .40538 .35972 L .43103 .36238 L p
1 g
F P
s
P
p
.002 w
.43103 .36238 m .44524 .33122 L .42236 .32191 L p
1 g
F P
s
P
p
.002 w
.53864 .30968 m .51159 .31249 L .52207 .33594 L p
1 g
F P
s
P
p
.002 w
.52207 .33594 m .54034 .33412 L .53864 .30968 L p
1 g
F P
s
P
p
.002 w
.58069 .49283 m .60945 .47424 L .59501 .45251 L p
1 g
F P
s
P
p
.002 w
.6109 .43138 m .59501 .45251 L .60945 .47424 L p
1 g
F P
s
P
p
.002 w
.6109 .43138 m .61879 .40574 L .59441 .39888 L p
1 g
F P
s
P
p
.002 w
.59359 .38044 m .59441 .39888 L .61879 .40574 L p
1 g
F P
s
P
p
.002 w
.54606 .52713 m .58653 .51766 L .58069 .49283 L p
1 g
F P
s
P
p
.002 w
.60945 .47424 m .58069 .49283 L .58653 .51766 L p
1 g
F P
s
P
p
.002 w
.3815 .35877 m .37755 .40655 L .40176 .40121 L p
1 g
F P
s
P
p
.002 w
.40176 .40121 m .40538 .35972 L .3815 .35877 L p
1 g
F P
s
P
p
.002 w
.56566 .31599 m .53864 .30968 L .54034 .33412 L p
1 g
F P
s
P
p
.002 w
.54034 .33412 m .55853 .33842 L .56566 .31599 L p
1 g
F P
s
P
p
.002 w
.61879 .40574 m .61768 .3784 L .59359 .38044 L p
1 g
F P
s
P
p
.002 w
.58674 .36296 m .59359 .38044 L .61768 .3784 L p
1 g
F P
s
P
p
.002 w
.49569 .54676 m .54368 .55158 L .54606 .52713 L p
1 g
F P
s
P
p
.002 w
.58653 .51766 m .54606 .52713 L .54368 .55158 L p
1 g
F P
s
P
p
.002 w
.50057 .29146 m .46922 .30662 L .48751 .32399 L p
1 g
F P
s
P
p
.002 w
.48751 .32399 m .51159 .31249 L .50057 .29146 L p
1 g
F P
s
P
p
.002 w
.36862 .46471 m .39685 .51074 L .41438 .49511 L p
1 g
F P
s
P
p
.002 w
.41438 .49511 m .38898 .45355 L .36862 .46471 L p
1 g
F P
s
P
p
.002 w
.45115 .52724 m .41438 .49511 L .39685 .51074 L p
1 g
F P
s
P
p
.002 w
.39685 .51074 m .4376 .54636 L .45115 .52724 L p
1 g
F P
s
P
p
.002 w
.49569 .54676 m .45115 .52724 L .4376 .54636 L p
1 g
F P
s
P
p
.002 w
.58955 .33079 m .56566 .31599 L .55853 .33842 L p
1 g
F P
s
P
p
.002 w
.55853 .33842 m .5746 .3484 L .58955 .33079 L p
1 g
F P
s
P
p
.002 w
.61768 .3784 m .60757 .35242 L .58674 .36296 L p
1 g
F P
s
P
p
.002 w
.5746 .3484 m .58674 .36296 L .60757 .35242 L p
1 g
F P
s
P
p
.002 w
.60945 .47424 m .63031 .44682 L .6109 .43138 L p
1 g
F P
s
P
p
.002 w
.61879 .40574 m .6109 .43138 L .63031 .44682 L p
1 g
F P
s
P
p
.002 w
.60757 .35242 m .58955 .33079 L .5746 .3484 L p
1 g
F P
s
P
p
.002 w
.35579 .41264 m .36862 .46471 L .38898 .45355 L p
1 g
F P
s
P
p
.002 w
.38898 .45355 m .37755 .40655 L .35579 .41264 L p
1 g
F P
s
P
p
.002 w
.45125 .29195 m .42236 .32191 L .44524 .33122 L p
1 g
F P
s
P
p
.002 w
.44524 .33122 m .46922 .30662 L .45125 .29195 L p
1 g
F P
s
P
p
.002 w
.4376 .54636 m .48693 .5681 L .49569 .54676 L p
1 g
F P
s
P
p
.002 w
.54368 .55158 m .49569 .54676 L .48693 .5681 L p
1 g
F P
s
P
p
.002 w
.58653 .51766 m .62147 .49536 L .60945 .47424 L p
1 g
F P
s
P
p
.002 w
.63031 .44682 m .60945 .47424 L .62147 .49536 L p
1 g
F P
s
P
p
.002 w
.40084 .31512 m .3815 .35877 L .40538 .35972 L p
1 g
F P
s
P
p
.002 w
.40538 .35972 m .42236 .32191 L .40084 .31512 L p
1 g
F P
s
P
p
.002 w
.53593 .28764 m .50057 .29146 L .51159 .31249 L p
1 g
F P
s
P
p
.002 w
.51159 .31249 m .53864 .30968 L .53593 .28764 L p
1 g
F P
s
P
p
.002 w
.63031 .44682 m .64079 .4134 L .61879 .40574 L p
1 g
F P
s
P
p
.002 w
.61768 .3784 m .61879 .40574 L .64079 .4134 L p
1 g
F P
s
P
p
.002 w
.54368 .55158 m .59032 .54091 L .58653 .51766 L p
1 g
F P
s
P
p
.002 w
.62147 .49536 m .58653 .51766 L .59032 .54091 L p
1 g
F P
s
P
p
.002 w
.35997 .35963 m .35579 .41264 L .37755 .40655 L p
1 g
F P
s
P
p
.002 w
.37755 .40655 m .3815 .35877 L .35997 .35963 L p
1 g
F P
s
P
p
.002 w
.57133 .29581 m .53593 .28764 L .53864 .30968 L p
1 g
F P
s
P
p
.002 w
.53864 .30968 m .56566 .31599 L .57133 .29581 L p
1 g
F P
s
P
p
.002 w
.48922 .27336 m .45125 .29195 L .46922 .30662 L p
1 g
F P
s
P
p
.002 w
.46922 .30662 m .50057 .29146 L .48922 .27336 L p
1 g
F P
s
P
p
.002 w
.64079 .4134 m .63946 .37762 L .61768 .3784 L p
1 g
F P
s
P
p
.002 w
.60757 .35242 m .61768 .3784 L .63946 .37762 L p
1 g
F P
s
P
p
.002 w
.48693 .5681 m .54013 .57363 L .54368 .55158 L p
1 g
F P
s
P
p
.002 w
.59032 .54091 m .54368 .55158 L .54013 .57363 L p
1 g
F P
s
P
p
.002 w
.35101 .47533 m .38143 .52479 L .39685 .51074 L p
1 g
F P
s
P
p
.002 w
.39685 .51074 m .36862 .46471 L .35101 .47533 L p
1 g
F P
s
P
p
.002 w
.4376 .54636 m .39685 .51074 L .38143 .52479 L p
1 g
F P
s
P
p
.002 w
.62147 .49536 m .64693 .46226 L .63031 .44682 L p
1 g
F P
s
P
p
.002 w
.64079 .4134 m .63031 .44682 L .64693 .46226 L p
1 g
F P
s
P
p
.002 w
.38143 .52479 m .42523 .5631 L .4376 .54636 L p
1 g
F P
s
P
p
.002 w
.48693 .5681 m .4376 .54636 L .42523 .5631 L p
1 g
F P
s
P
p
.002 w
.60267 .31519 m .57133 .29581 L .56566 .31599 L p
1 g
F P
s
P
p
.002 w
.56566 .31599 m .58955 .33079 L .60267 .31519 L p
1 g
F P
s
P
p
.002 w
.63946 .37762 m .62629 .34356 L .60757 .35242 L p
1 g
F P
s
P
p
.002 w
.58955 .33079 m .60757 .35242 L .62629 .34356 L p
1 g
F P
s
P
p
.002 w
.434 .2804 m .40084 .31512 L .42236 .32191 L p
1 g
F P
s
P
p
.002 w
.42236 .32191 m .45125 .29195 L .434 .2804 L p
1 g
F P
s
P
p
.002 w
.62629 .34356 m .60267 .31519 L .58955 .33079 L p
1 g
F P
s
P
p
.002 w
.33707 .41938 m .35101 .47533 L .36862 .46471 L p
1 g
F P
s
P
p
.002 w
.36862 .46471 m .35579 .41264 L .33707 .41938 L p
1 g
F P
s
P
p
.002 w
.59032 .54091 m .63071 .51541 L .62147 .49536 L p
1 g
F P
s
P
p
.002 w
.64693 .46226 m .62147 .49536 L .63071 .51541 L p
1 g
F P
s
P
p
.002 w
.42523 .5631 m .47824 .58657 L .48693 .5681 L p
1 g
F P
s
P
p
.002 w
.54013 .57363 m .48693 .5681 L .47824 .58657 L p
1 g
F P
s
P
p
.002 w
.38121 .3111 m .35997 .35963 L .3815 .35877 L p
1 g
F P
s
P
p
.002 w
.3815 .35877 m .40084 .31512 L .38121 .3111 L p
1 g
F P
s
P
p
.002 w
.5322 .26857 m .48922 .27336 L .50057 .29146 L p
1 g
F P
s
P
p
.002 w
.50057 .29146 m .53593 .28764 L .5322 .26857 L p
1 g
F P
s
P
p
.002 w
.64693 .46226 m .65983 .42172 L .64079 .4134 L p
1 g
F P
s
P
p
.002 w
.63946 .37762 m .64079 .4134 L .65983 .42172 L p
1 g
F P
s
P
p
.002 w
.54013 .57363 m .59192 .56201 L .59032 .54091 L p
1 g
F P
s
P
p
.002 w
.63071 .51541 m .59032 .54091 L .59192 .56201 L p
1 g
F P
s
P
p
.002 w
.34136 .36236 m .33707 .41938 L .35579 .41264 L p
1 g
F P
s
P
p
.002 w
.35579 .41264 m .35997 .35963 L .34136 .36236 L p
1 g
F P
s
P
p
.002 w
.47777 .25876 m .434 .2804 L .45125 .29195 L p
1 g
F P
s
P
p
.002 w
.45125 .29195 m .48922 .27336 L .47777 .25876 L p
1 g
F P
s
P
p
.002 w
.57534 .27844 m .5322 .26857 L .53593 .28764 L p
1 g
F P
s
P
p
.002 w
.53593 .28764 m .57133 .29581 L .57534 .27844 L p
1 g
F P
s
P
p
.002 w
.47824 .58657 m .53543 .59268 L .54013 .57363 L p
1 g
F P
s
P
p
.002 w
.59192 .56201 m .54013 .57363 L .53543 .59268 L p
1 g
F P
s
P
p
.002 w
.65983 .42172 m .65835 .37819 L .63946 .37762 L p
1 g
F P
s
P
p
.002 w
.62629 .34356 m .63946 .37762 L .65835 .37819 L p
1 g
F P
s
P
p
.002 w
.63071 .51541 m .66028 .47735 L .64693 .46226 L p
1 g
F P
s
P
p
.002 w
.65983 .42172 m .64693 .46226 L .66028 .47735 L p
1 g
F P
s
P
p
.002 w
.33666 .48515 m .36855 .53688 L .38143 .52479 L p
1 g
F P
s
P
p
.002 w
.38143 .52479 m .35101 .47533 L .33666 .48515 L p
1 g
F P
s
P
p
.002 w
.42523 .5631 m .38143 .52479 L .36855 .53688 L p
1 g
F P
s
P
p
.002 w
.41788 .27239 m .38121 .3111 L .40084 .31512 L p
1 g
F P
s
P
p
.002 w
.40084 .31512 m .434 .2804 L .41788 .27239 L p
1 g
F P
s
P
p
.002 w
.36855 .53688 m .41439 .57699 L .42523 .5631 L p
1 g
F P
s
P
p
.002 w
.47824 .58657 m .42523 .5631 L .41439 .57699 L p
1 g
F P
s
P
p
.002 w
.61358 .30203 m .57534 .27844 L .57133 .29581 L p
1 g
F P
s
P
p
.002 w
.57133 .29581 m .60267 .31519 L .61358 .30203 L p
1 g
F P
s
P
p
.002 w
.65835 .37819 m .64237 .33665 L .62629 .34356 L p
1 g
F P
s
P
p
.002 w
.60267 .31519 m .62629 .34356 L .64237 .33665 L p
1 g
F P
s
P
p
.002 w
.64237 .33665 m .61358 .30203 L .60267 .31519 L p
1 g
F P
s
P
p
.002 w
.32195 .42665 m .33666 .48515 L .35101 .47533 L p
1 g
F P
s
P
p
.002 w
.35101 .47533 m .33707 .41938 L .32195 .42665 L p
1 g
F P
s
P
p
.002 w
.59192 .56201 m .63687 .5339 L .63071 .51541 L p
1 g
F P
s
P
p
.002 w
.66028 .47735 m .63071 .51541 L .63687 .5339 L p
1 g
F P
s
P
p
.002 w
.36402 .31008 m .34136 .36236 L .35997 .35963 L p
1 g
F P
s
P
p
.002 w
.35997 .35963 m .38121 .3111 L .36402 .31008 L p
1 g
F P
s
P
p
.002 w
.52749 .25307 m .47777 .25876 L .48922 .27336 L p
1 g
F P
s
P
p
.002 w
.48922 .27336 m .5322 .26857 L .52749 .25307 L p
1 g
F P
s
P
p
.002 w
.41439 .57699 m .46982 .60162 L .47824 .58657 L p
1 g
F P
s
P
p
.002 w
.53543 .59268 m .47824 .58657 L .46982 .60162 L p
1 g
F P
s
P
p
.002 w
.66028 .47735 m .67536 .43056 L .65983 .42172 L p
1 g
F P
s
P
p
.002 w
.65835 .37819 m .65983 .42172 L .67536 .43056 L p
1 g
F P
s
P
p
.002 w
.53543 .59268 m .59116 .58039 L .59192 .56201 L p
1 g
F P
s
P
p
.002 w
.63687 .5339 m .59192 .56201 L .59116 .58039 L p
1 g
F P
s
P
p
.002 w
.32627 .367 m .32195 .42665 L .33707 .41938 L p
1 g
F P
s
P
p
.002 w
.33707 .41938 m .34136 .36236 L .32627 .367 L p
1 g
F P
s
P
p
.002 w
.46648 .24816 m .41788 .27239 L .434 .2804 L p
1 g
F P
s
P
p
.002 w
.434 .2804 m .47777 .25876 L .46648 .24816 L p
1 g
F P
s
P
p
.002 w
.57752 .26442 m .52749 .25307 L .5322 .26857 L p
1 g
F P
s
P
p
.002 w
.5322 .26857 m .57534 .27844 L .57752 .26442 L p
1 g
F P
s
P
p
.002 w
.46982 .60162 m .52963 .60816 L .53543 .59268 L p
1 g
F P
s
P
p
.002 w
.59116 .58039 m .53543 .59268 L .52963 .60816 L p
1 g
F P
s
P
p
.002 w
.67536 .43056 m .67377 .38015 L .65835 .37819 L p
1 g
F P
s
P
p
.002 w
.64237 .33665 m .65835 .37819 L .67377 .38015 L p
1 g
F P
s
P
p
.002 w
.63687 .5339 m .66988 .49175 L .66028 .47735 L p
1 g
F P
s
P
p
.002 w
.67536 .43056 m .66028 .47735 L .66988 .49175 L p
1 g
F P
s
P
p
.002 w
.40335 .2683 m .36402 .31008 L .38121 .3111 L p
1 g
F P
s
P
p
.002 w
.38121 .3111 m .41788 .27239 L .40335 .2683 L p
1 g
F P
s
P
p
.002 w
.32609 .49391 m .35865 .54662 L .36855 .53688 L p
1 g
F P
s
P
p
.002 w
.36855 .53688 m .33666 .48515 L .32609 .49391 L p
1 g
F P
s
P
p
.002 w
.41439 .57699 m .36855 .53688 L .35865 .54662 L p
1 g
F P
s
P
p
.002 w
.35865 .54662 m .40539 .58753 L .41439 .57699 L p
1 g
F P
s
P
p
.002 w
.46982 .60162 m .41439 .57699 L .40539 .58753 L p
1 g
F P
s
P
p
.002 w
.62191 .29177 m .57752 .26442 L .57534 .27844 L p
1 g
F P
s
P
p
.002 w
.57534 .27844 m .61358 .30203 L .62191 .29177 L p
1 g
F P
s
P
p
.002 w
.67377 .38015 m .6553 .33196 L .64237 .33665 L p
1 g
F P
s
P
p
.002 w
.61358 .30203 m .64237 .33665 L .6553 .33196 L p
1 g
F P
s
P
p
.002 w
.6553 .33196 m .62191 .29177 L .61358 .30203 L p
1 g
F P
s
P
p
.002 w
.59116 .58039 m .63963 .55033 L .63687 .5339 L p
1 g
F P
s
P
p
.002 w
.66988 .49175 m .63687 .5339 L .63963 .55033 L p
1 g
F P
s
P
p
.002 w
.31099 .43431 m .32609 .49391 L .33666 .48515 L p
1 g
F P
s
P
p
.002 w
.33666 .48515 m .32195 .42665 L .31099 .43431 L p
1 g
F P
s
P
p
.002 w
.34982 .31226 m .32627 .367 L .34136 .36236 L p
1 g
F P
s
P
p
.002 w
.34136 .36236 m .36402 .31008 L .34982 .31226 L p
1 g
F P
s
P
p
.002 w
.52186 .2417 m .46648 .24816 L .47777 .25876 L p
1 g
F P
s
P
p
.002 w
.47777 .25876 m .52749 .25307 L .52186 .2417 L p
1 g
F P
s
P
p
.002 w
.40539 .58753 m .46188 .61271 L .46982 .60162 L p
1 g
F P
s
P
p
.002 w
.52963 .60816 m .46982 .60162 L .46188 .61271 L p
1 g
F P
s
P
p
.002 w
.66988 .49175 m .68681 .43973 L .67536 .43056 L p
1 g
F P
s
P
p
.002 w
.67377 .38015 m .67536 .43056 L .68681 .43973 L p
1 g
F P
s
P
p
.002 w
.52963 .60816 m .58796 .59546 L .59116 .58039 L p
1 g
F P
s
P
p
.002 w
.63963 .55033 m .59116 .58039 L .58796 .59546 L p
1 g
F P
s
P
p
.002 w
.31527 .37354 m .31099 .43431 L .32195 .42665 L p
1 g
F P
s
P
p
.002 w
.32195 .42665 m .32627 .367 L .31527 .37354 L p
1 g
F P
s
P
p
.002 w
.45565 .24207 m .40335 .2683 L .41788 .27239 L p
1 g
F P
s
P
p
.002 w
.41788 .27239 m .46648 .24816 L .45565 .24207 L p
1 g
F P
s
P
p
.002 w
.5777 .2543 m .52186 .2417 L .52749 .25307 L p
1 g
F P
s
P
p
.002 w
.52749 .25307 m .57752 .26442 L .5777 .2543 L p
1 g
F P
s
P
p
.002 w
.46188 .61271 m .52281 .61948 L .52963 .60816 L p
1 g
F P
s
P
p
.002 w
.58796 .59546 m .52963 .60816 L .52281 .61948 L p
1 g
F P
s
P
p
.002 w
.63963 .55033 m .6753 .50505 L .66988 .49175 L p
1 g
F P
s
P
p
.002 w
.68681 .43973 m .66988 .49175 L .6753 .50505 L p
1 g
F P
s
P
p
.002 w
.68681 .43973 m .68514 .38354 L .67377 .38015 L p
1 g
F P
s
P
p
.002 w
.6553 .33196 m .67377 .38015 L .68514 .38354 L p
1 g
F P
s
P
p
.002 w
.39086 .26846 m .34982 .31226 L .36402 .31008 L p
1 g
F P
s
P
p
.002 w
.36402 .31008 m .40335 .2683 L .39086 .26846 L p
1 g
F P
s
P
p
.002 w
.31978 .50131 m .35215 .55364 L .35865 .54662 L p
1 g
F P
s
P
p
.002 w
.35865 .54662 m .32609 .49391 L .31978 .50131 L p
1 g
F P
s
P
p
.002 w
.40539 .58753 m .35865 .54662 L .35215 .55364 L p
1 g
F P
s
P
p
.002 w
.62729 .28483 m .5777 .2543 L .57752 .26442 L p
1 g
F P
s
P
p
.002 w
.57752 .26442 m .62191 .29177 L .62729 .28483 L p
1 g
F P
s
P
p
.002 w
.35215 .55364 m .39856 .59427 L .40539 .58753 L p
1 g
F P
s
P
p
.002 w
.46188 .61271 m .40539 .58753 L .39856 .59427 L p
1 g
F P
s
P
p
.002 w
.68514 .38354 m .66458 .32973 L .6553 .33196 L p
1 g
F P
s
P
p
.002 w
.62191 .29177 m .6553 .33196 L .66458 .32973 L p
1 g
F P
s
P
p
.002 w
.58796 .59546 m .63873 .56416 L .63963 .55033 L p
1 g
F P
s
P
p
.002 w
.6753 .50505 m .63963 .55033 L .63873 .56416 L p
1 g
F P
s
P
p
.002 w
.66458 .32973 m .62729 .28483 L .62191 .29177 L p
1 g
F P
s
P
p
.002 w
.33915 .31776 m .31527 .37354 L .32627 .367 L p
1 g
F P
s
P
p
.002 w
.32627 .367 m .34982 .31226 L .33915 .31776 L p
1 g
F P
s
P
p
.002 w
.30474 .44218 m .31978 .50131 L .32609 .49391 L p
1 g
F P
s
P
p
.002 w
.32609 .49391 m .31099 .43431 L .30474 .44218 L p
1 g
F P
s
P
p
.002 w
.5154 .23502 m .45565 .24207 L .46648 .24816 L p
1 g
F P
s
P
p
.002 w
.46648 .24816 m .52186 .2417 L .5154 .23502 L p
1 g
F P
s
P
p
.002 w
.39856 .59427 m .45463 .61932 L .46188 .61271 L p
1 g
F P
s
P
p
.002 w
.52281 .61948 m .46188 .61271 L .45463 .61932 L p
1 g
F P
s
P
p
.002 w
.52281 .61948 m .58224 .60667 L .58796 .59546 L p
1 g
F P
s
P
p
.002 w
.63873 .56416 m .58796 .59546 L .58224 .60667 L p
1 g
F P
s
P
p
.002 w
.6753 .50505 m .69366 .44902 L .68681 .43973 L p
1 g
F P
s
P
p
.002 w
.68514 .38354 m .68681 .43973 L .69366 .44902 L p
1 g
F P
s
P
p
.002 w
.44559 .24093 m .39086 .26846 L .40335 .2683 L p
1 g
F P
s
P
p
.002 w
.40335 .2683 m .45565 .24207 L .44559 .24093 L p
1 g
F P
s
P
p
.002 w
.30891 .38192 m .30474 .44218 L .31099 .43431 L p
1 g
F P
s
P
p
.002 w
.31099 .43431 m .31527 .37354 L .30891 .38192 L p
1 g
F P
s
P
p
.002 w
.57574 .2486 m .5154 .23502 L .52186 .2417 L p
1 g
F P
s
P
p
.002 w
.52186 .2417 m .5777 .2543 L .57574 .2486 L p
1 g
F P
s
P
p
.002 w
.45463 .61932 m .51508 .6261 L .52281 .61948 L p
1 g
F P
s
P
p
.002 w
.58224 .60667 m .52281 .61948 L .51508 .6261 L p
1 g
F P
s
P
p
.002 w
.63873 .56416 m .67614 .51686 L .6753 .50505 L p
1 g
F P
s
P
p
.002 w
.69366 .44902 m .6753 .50505 L .67614 .51686 L p
1 g
F P
s
P
p
.002 w
.69366 .44902 m .69192 .38836 L .68514 .38354 L p
1 g
F P
s
P
p
.002 w
.66458 .32973 m .68514 .38354 L .69192 .38836 L p
1 g
F P
s
P
p
.002 w
.38089 .27313 m .33915 .31776 L .34982 .31226 L p
1 g
F P
s
P
p
.002 w
.34982 .31226 m .39086 .26846 L .38089 .27313 L p
1 g
F P
s
P
p
.002 w
.31818 .50707 m .34943 .55757 L .35215 .55364 L p
1 g
F P
s
P
p
.002 w
.35215 .55364 m .31978 .50131 L .31818 .50707 L p
1 g
F P
s
P
p
.002 w
.39856 .59427 m .35215 .55364 L .34943 .55757 L p
1 g
F P
s
P
p
.002 w
.62939 .28161 m .57574 .2486 L .5777 .2543 L p
1 g
F P
s
P
p
.002 w
.5777 .2543 m .62729 .28483 L .62939 .28161 L p
1 g
F P
s
P
p
.002 w
.34943 .55757 m .39424 .5968 L .39856 .59427 L p
1 g
F P
s
P
p
.002 w
.45463 .61932 m .39856 .59427 L .39424 .5968 L p
1 g
F P
s
P
p
.002 w
.58224 .60667 m .63397 .57489 L .63873 .56416 L p
1 g
F P
s
P
p
.002 w
.67614 .51686 m .63873 .56416 L .63397 .57489 L p
1 g
F P
s
P
p
.002 w
.69192 .38836 m .66972 .33019 L .66458 .32973 L p
1 g
F P
s
P
p
.002 w
.62729 .28483 m .66458 .32973 L .66972 .33019 L p
1 g
F P
s
P
p
.002 w
.33254 .32665 m .30891 .38192 L .31527 .37354 L p
1 g
F P
s
P
p
.002 w
.31527 .37354 m .33915 .31776 L .33254 .32665 L p
1 g
F P
s
P
p
.002 w
.66972 .33019 m .62939 .28161 L .62729 .28483 L p
1 g
F P
s
P
p
.002 w
.50823 .23352 m .44559 .24093 L .45565 .24207 L p
1 g
F P
s
P
p
.002 w
.45565 .24207 m .5154 .23502 L .50823 .23352 L p
1 g
F P
s
P
p
.002 w
.30365 .45006 m .31818 .50707 L .31978 .50131 L p
1 g
F P
s
P
p
.002 w
.31978 .50131 m .30474 .44218 L .30365 .45006 L p
1 g
F P
s
P
p
.002 w
.39424 .5968 m .44834 .62098 L .45463 .61932 L p
1 g
F P
s
P
p
.002 w
.51508 .6261 m .45463 .61932 L .44834 .62098 L p
1 g
F P
s
P
p
.002 w
.51508 .6261 m .57401 .61347 L .58224 .60667 L p
1 g
F P
s
P
p
.002 w
.63397 .57489 m .58224 .60667 L .57401 .61347 L p
1 g
F P
s
P
p
.002 w
.67614 .51686 m .69542 .45819 L .69366 .44902 L p
1 g
F P
s
P
p
.002 w
.69192 .38836 m .69366 .44902 L .69542 .45819 L p
1 g
F P
s
P
p
.002 w
.43664 .24509 m .38089 .27313 L .39086 .26846 L p
1 g
F P
s
P
p
.002 w
.39086 .26846 m .44559 .24093 L .43664 .24509 L p
1 g
F P
s
P
p
.002 w
.30767 .39202 m .30365 .45006 L .30474 .44218 L p
1 g
F P
s
P
p
.002 w
.30474 .44218 m .30891 .38192 L .30767 .39202 L p
1 g
F P
s
P
p
.002 w
.57157 .24777 m .50823 .23352 L .5154 .23502 L p
1 g
F P
s
P
p
.002 w
.5154 .23502 m .57574 .2486 L .57157 .24777 L p
1 g
F P
s
P
p
.002 w
.63397 .57489 m .6721 .52675 L .67614 .51686 L p
1 g
F P
s
P
p
.002 w
.69542 .45819 m .67614 .51686 L .6721 .52675 L p
1 g
F P
s
P
p
.002 w
.44834 .62098 m .5066 .62755 L .51508 .6261 L p
1 g
F P
s
P
p
.002 w
.57401 .61347 m .51508 .6261 L .5066 .62755 L p
1 g
F P
s
P
p
.002 w
.37389 .28246 m .33254 .32665 L .33915 .31776 L p
1 g
F P
s
P
p
.002 w
.33915 .31776 m .38089 .27313 L .37389 .28246 L p
1 g
F P
s
P
p
.002 w
.69542 .45819 m .69362 .39457 L .69192 .38836 L p
1 g
F P
s
P
p
.002 w
.66972 .33019 m .69192 .38836 L .69362 .39457 L p
1 g
F P
s
P
p
.002 w
.57401 .61347 m .62526 .582 L .63397 .57489 L p
1 g
F P
s
P
p
.002 w
.6721 .52675 m .63397 .57489 L .62526 .582 L p
1 g
F P
s
P
p
.002 w
.32165 .51093 m .35084 .5581 L .34943 .55757 L p
1 g
F P
s
P
p
.002 w
.34943 .55757 m .31818 .50707 L .32165 .51093 L p
1 g
F P
s
P
p
.002 w
.39424 .5968 m .34943 .55757 L .35084 .5581 L p
1 g
F P
s
P
p
.002 w
.62792 .28245 m .57157 .24777 L .57574 .2486 L p
1 g
F P
s
P
p
.002 w
.57574 .2486 m .62939 .28161 L .62792 .28245 L p
1 g
F P
s
P
p
.002 w
.35084 .5581 m .3927 .59476 L .39424 .5968 L p
1 g
F P
s
P
p
.002 w
.44834 .62098 m .39424 .5968 L .3927 .59476 L p
1 g
F P
s
P
p
.002 w
.69362 .39457 m .67031 .33349 L .66972 .33019 L p
1 g
F P
s
P
p
.002 w
.62939 .28161 m .66972 .33019 L .67031 .33349 L p
1 g
F P
s
P
p
.002 w
.33043 .33887 m .30767 .39202 L .30891 .38192 L p
1 g
F P
s
P
p
.002 w
.30891 .38192 m .33254 .32665 L .33043 .33887 L p
1 g
F P
s
P
p
.002 w
.50051 .23756 m .43664 .24509 L .44559 .24093 L p
1 g
F P
s
P
p
.002 w
.44559 .24093 m .50823 .23352 L .50051 .23756 L p
1 g
F P
s
P
p
.002 w
.67031 .33349 m .62792 .28245 L .62939 .28161 L p
1 g
F P
s
P
p
.002 w
.30811 .45772 m .32165 .51093 L .31818 .50707 L p
1 g
F P
s
P
p
.002 w
.31818 .50707 m .30365 .45006 L .30811 .45772 L p
1 g
F P
s
P
p
.002 w
.3927 .59476 m .44322 .61733 L .44834 .62098 L p
1 g
F P
s
P
p
.002 w
.5066 .62755 m .44834 .62098 L .44322 .61733 L p
1 g
F P
s
P
p
.002 w
.5066 .62755 m .56333 .61538 L .57401 .61347 L p
1 g
F P
s
P
p
.002 w
.62526 .582 m .57401 .61347 L .56333 .61538 L p
1 g
F P
s
P
p
.002 w
.6721 .52675 m .69174 .46698 L .69542 .45819 L p
1 g
F P
s
P
p
.002 w
.69362 .39457 m .69542 .45819 L .69174 .46698 L p
1 g
F P
s
P
p
.002 w
.42913 .25476 m .37389 .28246 L .38089 .27313 L p
1 g
F P
s
P
p
.002 w
.38089 .27313 m .43664 .24509 L .42913 .25476 L p
1 g
F P
s
P
p
.002 w
.3119 .40366 m .30811 .45772 L .30365 .45006 L p
1 g
F P
s
P
p
.002 w
.30365 .45006 m .30767 .39202 L .3119 .40366 L p
1 g
F P
s
P
p
.002 w
.62526 .582 m .66298 .53432 L .6721 .52675 L p
1 g
F P
s
P
p
.002 w
.69174 .46698 m .6721 .52675 L .66298 .53432 L p
1 g
F P
s
P
p
.002 w
.56516 .25216 m .50051 .23756 L .50823 .23352 L p
1 g
F P
s
P
p
.002 w
.50823 .23352 m .57157 .24777 L .56516 .25216 L p
1 g
F P
s
P
p
.002 w
.44322 .61733 m .49757 .62343 L .5066 .62755 L p
1 g
F P
s
P
p
.002 w
.56333 .61538 m .5066 .62755 L .49757 .62343 L p
1 g
F P
s
P
p
.002 w
.37024 .29647 m .33043 .33887 L .33254 .32665 L p
1 g
F P
s
P
p
.002 w
.33254 .32665 m .37389 .28246 L .37024 .29647 L p
1 g
F P
s
P
p
.002 w
.69174 .46698 m .68986 .40209 L .69362 .39457 L p
1 g
F P
s
P
p
.002 w
.67031 .33349 m .69362 .39457 L .68986 .40209 L p
1 g
F P
s
P
p
.002 w
.56333 .61538 m .61259 .58507 L .62526 .582 L p
1 g
F P
s
P
p
.002 w
.66298 .53432 m .62526 .582 L .61259 .58507 L p
1 g
F P
s
P
p
.002 w
.33041 .51264 m .35659 .55499 L .35084 .5581 L p
1 g
F P
s
P
p
.002 w
.35084 .5581 m .32165 .51093 L .33041 .51264 L p
1 g
F P
s
P
p
.002 w
.3927 .59476 m .35084 .5581 L .35659 .55499 L p
1 g
F P
s
P
p
.002 w
.62271 .2876 m .56516 .25216 L .57157 .24777 L p
1 g
F P
s
P
p
.002 w
.57157 .24777 m .62792 .28245 L .62271 .2876 L p
1 g
F P
s
P
p
.002 w
.35659 .55499 m .39418 .5879 L .3927 .59476 L p
1 g
F P
s
P
p
.002 w
.44322 .61733 m .3927 .59476 L .39418 .5879 L p
1 g
F P
s
P
p
.002 w
.33317 .35426 m .3119 .40366 L .30767 .39202 L p
1 g
F P
s
P
p
.002 w
.30767 .39202 m .33043 .33887 L .33317 .35426 L p
1 g
F P
s
P
p
.002 w
.68986 .40209 m .66602 .33973 L .67031 .33349 L p
1 g
F P
s
P
p
.002 w
.62792 .28245 m .67031 .33349 L .66602 .33973 L p
1 g
F P
s
P
p
.002 w
.49245 .2474 m .42913 .25476 L .43664 .24509 L p
1 g
F P
s
P
p
.002 w
.43664 .24509 m .50051 .23756 L .49245 .2474 L p
1 g
F P
s
P
p
.002 w
.66602 .33973 m .62271 .2876 L .62792 .28245 L p
1 g
F P
s
P
p
.002 w
.31832 .46493 m .33041 .51264 L .32165 .51093 L p
1 g
F P
s
P
p
.002 w
.32165 .51093 m .30811 .45772 L .31832 .46493 L p
1 g
F P
s
P
p
.002 w
.49757 .62343 m .55039 .61203 L .56333 .61538 L p
1 g
F P
s
P
p
.002 w
.61259 .58507 m .56333 .61538 L .55039 .61203 L p
1 g
F P
s
P
p
.002 w
.39418 .5879 m .43953 .60813 L .44322 .61733 L p
1 g
F P
s
P
p
.002 w
.49757 .62343 m .44322 .61733 L .43953 .60813 L p
1 g
F P
s
P
p
.002 w
.66298 .53432 m .68236 .47508 L .69174 .46698 L p
1 g
F P
s
P
p
.002 w
.68986 .40209 m .69174 .46698 L .68236 .47508 L p
1 g
F P
s
P
p
.002 w
.4234 .26997 m .37024 .29647 L .37389 .28246 L p
1 g
F P
s
P
p
.002 w
.37389 .28246 m .42913 .25476 L .4234 .26997 L p
1 g
F P
s
P
p
.002 w
.32182 .41655 m .31832 .46493 L .30811 .45772 L p
1 g
F P
s
P
p
.002 w
.30811 .45772 m .3119 .40366 L .32182 .41655 L p
1 g
F P
s
P
p
.002 w
.61259 .58507 m .64876 .53917 L .66298 .53432 L p
1 g
F P
s
P
p
.002 w
.68236 .47508 m .66298 .53432 L .64876 .53917 L p
1 g
F P
s
P
p
.002 w
.55656 .26196 m .49245 .2474 L .50051 .23756 L p
1 g
F P
s
P
p
.002 w
.50051 .23756 m .56516 .25216 L .55656 .26196 L p
1 g
F P
s
P
p
.002 w
.43953 .60813 m .48824 .61353 L .49757 .62343 L p
1 g
F P
s
P
p
.002 w
.55039 .61203 m .49757 .62343 L .48824 .61353 L p
1 g
F P
s
P
p
.002 w
.37028 .31498 m .33317 .35426 L .33043 .33887 L p
1 g
F P
s
P
p
.002 w
.33043 .33887 m .37024 .29647 L .37028 .31498 L p
1 g
F P
s
P
p
.002 w
.68236 .47508 m .68039 .41075 L .68986 .40209 L p
1 g
F P
s
P
p
.002 w
.66602 .33973 m .68986 .40209 L .68039 .41075 L p
1 g
F P
s
P
p
.002 w
.55039 .61203 m .59612 .58375 L .61259 .58507 L p
1 g
F P
s
P
p
.002 w
.64876 .53917 m .61259 .58507 L .59612 .58375 L p
1 g
F P
s
P
p
.002 w
.34096 .3725 m .32182 .41655 L .3119 .40366 L p
1 g
F P
s
P
p
.002 w
.3119 .40366 m .33317 .35426 L .34096 .3725 L p
1 g
F P
s
P
p
.002 w
.34453 .512 m .3668 .54809 L .35659 .55499 L p
1 g
F P
s
P
p
.002 w
.35659 .55499 m .33041 .51264 L .34453 .512 L p
1 g
F P
s
P
p
.002 w
.39418 .5879 m .35659 .55499 L .3668 .54809 L p
1 g
F P
s
P
p
.002 w
.61365 .29718 m .55656 .26196 L .56516 .25216 L p
1 g
F P
s
P
p
.002 w
.56516 .25216 m .62271 .2876 L .61365 .29718 L p
1 g
F P
s
P
p
.002 w
.3668 .54809 m .39883 .57612 L .39418 .5879 L p
1 g
F P
s
P
p
.002 w
.43953 .60813 m .39418 .5879 L .39883 .57612 L p
1 g
F P
s
P
p
.002 w
.48429 .26306 m .4234 .26997 L .42913 .25476 L p
1 g
F P
s
P
p
.002 w
.42913 .25476 m .49245 .2474 L .48429 .26306 L p
1 g
F P
s
P
p
.002 w
.68039 .41075 m .65666 .34891 L .66602 .33973 L p
1 g
F P
s
P
p
.002 w
.62271 .2876 m .66602 .33973 L .65666 .34891 L p
1 g
F P
s
P
p
.002 w
.33432 .4714 m .34453 .512 L .33041 .51264 L p
1 g
F P
s
P
p
.002 w
.33041 .51264 m .31832 .46493 L .33432 .4714 L p
1 g
F P
s
P
p
.002 w
.48824 .61353 m .53544 .60322 L .55039 .61203 L p
1 g
F P
s
P
p
.002 w
.59612 .58375 m .55039 .61203 L .53544 .60322 L p
1 g
F P
s
P
p
.002 w
.65666 .34891 m .61365 .29718 L .62271 .2876 L p
1 g
F P
s
P
p
.002 w
.64876 .53917 m .66723 .48219 L .68236 .47508 L p
1 g
F P
s
P
p
.002 w
.68039 .41075 m .68236 .47508 L .66723 .48219 L p
1 g
F P
s
P
p
.002 w
.39883 .57612 m .43746 .59331 L .43953 .60813 L p
1 g
F P
s
P
p
.002 w
.48824 .61353 m .43953 .60813 L .43746 .59331 L p
1 g
F P
s
P
p
.002 w
.41974 .29056 m .37028 .31498 L .37024 .29647 L p
1 g
F P
s
P
p
.002 w
.37024 .29647 m .4234 .26997 L .41974 .29056 L p
1 g
F P
s
P
p
.002 w
.33742 .43035 m .33432 .4714 L .31832 .46493 L p
1 g
F P
s
P
p
.002 w
.31832 .46493 m .32182 .41655 L .33742 .43035 L p
1 g
F P
s
P
p
.002 w
.59612 .58375 m .62957 .541 L .64876 .53917 L p
1 g
F P
s
P
p
.002 w
.66723 .48219 m .64876 .53917 L .62957 .541 L p
1 g
F P
s
P
p
.002 w
.37421 .33761 m .34096 .3725 L .33317 .35426 L p
1 g
F P
s
P
p
.002 w
.33317 .35426 m .37028 .31498 L .37421 .33761 L p
1 g
F P
s
P
p
.002 w
.43746 .59331 m .47888 .59781 L .48824 .61353 L p
1 g
F P
s
P
p
.002 w
.53544 .60322 m .48824 .61353 L .47888 .59781 L p
1 g
F P
s
P
p
.002 w
.54592 .2772 m .48429 .26306 L .49245 .2474 L p
1 g
F P
s
P
p
.002 w
.49245 .2474 m .55656 .26196 L .54592 .2772 L p
1 g
F P
s
P
p
.002 w
.66723 .48219 m .66518 .42034 L .68039 .41075 L p
1 g
F P
s
P
p
.002 w
.65666 .34891 m .68039 .41075 L .66518 .42034 L p
1 g
F P
s
P
p
.002 w
.53544 .60322 m .57618 .57782 L .59612 .58375 L p
1 g
F P
s
P
p
.002 w
.62957 .541 m .59612 .58375 L .57618 .57782 L p
1 g
F P
s
P
p
.002 w
.3538 .39311 m .33742 .43035 L .32182 .41655 L p
1 g
F P
s
P
p
.002 w
.32182 .41655 m .34096 .3725 L .3538 .39311 L p
1 g
F P
s
P
p
.002 w
.47631 .28434 m .41974 .29056 L .4234 .26997 L p
1 g
F P
s
P
p
.002 w
.4234 .26997 m .48429 .26306 L .47631 .28434 L p
1 g
F P
s
P
p
.002 w
.60084 .31113 m .54592 .2772 L .55656 .26196 L p
1 g
F P
s
P
p
.002 w
.55656 .26196 m .61365 .29718 L .60084 .31113 L p
1 g
F P
s
P
p
.002 w
.36386 .50889 m .3814 .53739 L .3668 .54809 L p
1 g
F P
s
P
p
.002 w
.3668 .54809 m .34453 .512 L .36386 .50889 L p
1 g
F P
s
P
p
.002 w
.39883 .57612 m .3668 .54809 L .3814 .53739 L p
1 g
F P
s
P
p
.002 w
.3814 .53739 m .4067 .55953 L .39883 .57612 L p
1 g
F P
s
P
p
.002 w
.43746 .59331 m .39883 .57612 L .4067 .55953 L p
1 g
F P
s
P
p
.002 w
.66518 .42034 m .64225 .36089 L .65666 .34891 L p
1 g
F P
s
P
p
.002 w
.61365 .29718 m .65666 .34891 L .64225 .36089 L p
1 g
F P
s
P
p
.002 w
.47888 .59781 m .51889 .58892 L .53544 .60322 L p
1 g
F P
s
P
p
.002 w
.57618 .57782 m .53544 .60322 L .51889 .58892 L p
1 g
F P
s
P
p
.002 w
.3559 .47688 m .36386 .50889 L .34453 .512 L p
1 g
F P
s
P
p
.002 w
.34453 .512 m .33432 .4714 L .3559 .47688 L p
1 g
F P
s
P
p
.002 w
.64225 .36089 m .60084 .31113 L .61365 .29718 L p
1 g
F P
s
P
p
.002 w
.62957 .541 m .64652 .48802 L .66723 .48219 L p
1 g
F P
s
P
p
.002 w
.66518 .42034 m .66723 .48219 L .64652 .48802 L p
1 g
F P
s
P
p
.002 w
.4067 .55953 m .43719 .57304 L .43746 .59331 L p
1 g
F P
s
P
p
.002 w
.47888 .59781 m .43746 .59331 L .43719 .57304 L p
1 g
F P
s
P
p
.002 w
.41839 .31607 m .37421 .33761 L .37028 .31498 L p
1 g
F P
s
P
p
.002 w
.37028 .31498 m .41974 .29056 L .41839 .31607 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.35847 .44461 m .3559 .47688 L .33432 .4714 L p
1 g
F P
s
P
p
.002 w
.33432 .4714 m .33742 .43035 L .35847 .44461 L p
1 g
F P
s
P
p
.002 w
.57618 .57782 m .60582 .53957 L .62957 .541 L p
1 g
F P
s
P
p
.002 w
.64652 .48802 m .62957 .541 L .60582 .53957 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.38209 .36378 m .3538 .39311 L .34096 .3725 L p
1 g
F P
s
P
p
.002 w
.34096 .3725 m .37421 .33761 L .38209 .36378 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.43719 .57304 m .46982 .57648 L .47888 .59781 L p
1 g
F P
s
P
p
.51889 .58892 m .47118 .57968 L .48365 .57999 L 1 g
F
P
p
.002 w
.51094 .58066 m .51079 .57862 L p
.50174 .58043 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58012 L p
1 g
F P
s
P
p
.51889 .58892 m .48365 .57999 L .48592 .58004 L 1 g
F
P
p
.51079 .57862 m .4891 .58012 L .50174 .58043 L 1 g
F
P
p
.002 w
.4891 .58012 m .48921 .57862 L p
.47857 .57775 L 1 g
F P
s
P
p
.002 w
.46982 .57648 m .47138 .57612 L p
.48592 .58004 L 1 g
F P
s
P
p
.48365 .57999 m .46982 .57648 L .48592 .58004 L 1 g
F
P
p
.002 w
.51653 .5863 m .51889 .58892 L p
.49718 .58307 L 1 g
F P
s
P
p
.49718 .58307 m .47138 .57612 L .5 .58258 L 1 g
F
P
p
.49718 .58307 m .5 .58258 L .51653 .5863 L 1 g
F
P
p
.002 w
.46982 .57648 m .43719 .57304 L .43787 .56251 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46821 .575 L p
1 g
F P
s
P
p
.48921 .57862 m .46821 .575 L .46952 .57554 L 1 g
F
P
p
.002 w
.47138 .57612 m .46982 .57648 L .46952 .57554 L p
1 g
F P
s
P
p
.46992 .57566 m .46952 .57554 L .46977 .57564 L 1 g
F
P
p
.48921 .57862 m .46952 .57554 L .46992 .57566 L 1 g
F
P
p
.46982 .57648 m .43787 .56251 L .46821 .575 L 1 g
F
P
p
.46829 .57506 m .46821 .575 L .46824 .57501 L 1 g
F
P
p
.46982 .57648 m .46821 .575 L .46829 .57506 L 1 g
F
P
p
.002 w
.46821 .575 m .46872 .57265 L p
.45986 .56911 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4509 .56279 L p
1 g
F P
s
P
p
.46872 .57265 m .4509 .56279 L .45986 .56911 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.41768 .53841 m .43791 .54733 L p
.43719 .57304 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43818 .54768 L p
1 g
F P
s
P
p
.45146 .56129 m .43818 .54768 L .43845 .54805 L 1 g
F
P
p
.45146 .56129 m .43815 .54774 L .44453 .55527 L 1 g
F
P
p
.002 w
.43791 .54733 m .43807 .5474 L p
.43818 .54768 L 1 g
F P
s
P
p
.002 w
.43878 .54848 m .43719 .57304 L p
.43791 .54733 L 1 g
F P
s
P
p
.002 w
.41768 .53841 m .4293 .51738 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.43807 .5474 m .43179 .54463 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.43179 .54463 m .41768 .53841 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.43258 .52862 m .43346 .52734 L p
.43312 .51766 L 1 g
F P
s
P
p
.002 w
.43818 .54768 m .43925 .54566 L p
.43525 .53775 L 1 g
F P
s
P
p
.43525 .53775 m .43155 .53042 L .43807 .5474 L 1 g
F
P
p
.43525 .53775 m .43807 .5474 L .43818 .54768 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43153 .51333 m .42251 .50545 L .43538 .4951 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43538 .4951 m .44416 .48804 L p
.44251 .49143 L 1 g
F P
s
P
p
.4338 .5094 m .43498 .49871 L .44251 .49143 L 1 g
F
P
p
.43498 .49871 m .43538 .4951 L .44251 .49143 L 1 g
F
P
p
.002 w
.4341 .50888 m .4338 .5094 L p
.44416 .48804 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44252 .49143 L p
1 g
F P
s
P
p
.002 w
.44252 .49143 m .44166 .49233 L p
.43839 .49999 L 1 g
F P
s
P
p
.43485 .50826 m .44252 .49143 L .43839 .49999 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45397 .51921 m .4424 .51809 L .4476 .48651 L p
1 g
F P
s
P
p
.002 w
.47435 .51039 m .46502 .51656 L .44827 .48587 L p
1 g
F P
s
P
p
.002 w
.48404 .4904 m .48094 .50135 L .44866 .48549 L p
1 g
F P
s
P
p
.002 w
.47877 .46761 m .4833 .47872 L .44936 .48481 L p
1 g
F P
s
P
p
.002 w
.44253 .49142 m .44339 .4905 L p
.45141 .48282 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47877 .46761 m .4508 .48341 L p
.45765 .47674 L 1 g
F P
s
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.46836 .47165 L 1 g
F P
s
P
p
.47747 .46732 m .47877 .46761 L .45765 .47674 L 1 g
F
P
p
.002 w
.47747 .46732 m .47786 .46667 L p
.48775 .46576 L 1 g
F P
s
P
p
.002 w
.4833 .47872 m .47877 .46761 L .47983 .46699 L p
1 g
F P
s
P
p
.49639 .46441 m .4833 .47872 L .47983 .46699 L 1 g
F
P
p
.002 w
.5195 .47081 m .4833 .47872 L p
.49639 .46441 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46385 m .5195 .47081 L .49639 .46441 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46725 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54224 .47662 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55674 .49532 m .52082 .49385 L p
.54016 .47564 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54224 .47662 m .55674 .49532 L .54016 .47564 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56581 .50905 L p
1 g
F P
s
P
p
.59043 .49478 m .56717 .51197 L .56581 .50905 L 1 g
F
P
p
.002 w
.55941 .49528 m .5647 .4952 L p
.56581 .50905 L 1 g
F P
s
P
p
.002 w
.5647 .4952 m .59043 .49478 L p
.56581 .50905 L 1 g
F P
s
P
p
.002 w
.56581 .50905 m .56515 .50826 L p
.56641 .51642 L 1 g
F P
s
P
p
.55661 .4905 m .56581 .50905 L .56184 .50051 L 1 g
F
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56739 .52858 L p
1 g
F P
s
P
p
.56515 .50826 m .56739 .52858 L .56641 .51642 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.58845 .45164 m .59043 .49478 L .55941 .49528 L p
1 g
F P
s
P
p
.58845 .45164 m .55941 .49528 L .55834 .49312 L 1 g
F
P
p
.002 w
.55754 .49148 m .55661 .4905 L p
.56449 .50556 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55754 .49148 L p
1 g
F P
s
P
p
.002 w
.55674 .49532 m .55649 .49047 L p
.55871 .49262 L 1 g
F P
s
P
p
.002 w
.55754 .49148 m .55759 .49154 L p
.557 .49096 L 1 g
F P
s
P
p
.54174 .47608 m .55754 .49148 L .557 .49096 L 1 g
F
P
p
.002 w
.555 .46167 m .58845 .45164 L p
.55871 .49262 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55754 .49148 L p
1 g
F P
s
P
p
.56449 .50556 m .56713 .51061 L .55754 .49148 L 1 g
F
P
p
.54174 .47608 m .55759 .49154 L .54966 .48383 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55649 .49047 m .555 .46167 L p
.55871 .49262 L 1 g
F P
s
P
p
.002 w
.55941 .49528 m .55674 .49532 L p
.55834 .49312 L 1 g
F P
s
P
p
.56581 .50905 m .54734 .52664 L .55941 .49528 L 1 g
F
P
p
.56717 .51197 m .56611 .51276 L .56581 .50905 L 1 g
F
P
p
.56611 .51276 m .54734 .52664 L .56581 .50905 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.59043 .49478 m .57812 .53477 L .56662 .53173 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56137 .54683 L p
1 g
F P
s
P
p
.002 w
.57812 .53477 m .5551 .56484 L p
.56137 .54683 L 1 g
F P
s
P
p
.56757 .53844 m .56137 .54683 L .56383 .53974 L 1 g
F
P
p
.57812 .53477 m .56137 .54683 L .56757 .53844 L 1 g
F
P
p
.002 w
.56137 .54683 m .56075 .54566 L p
.55641 .55353 L 1 g
F P
s
P
p
.56654 .52734 m .56137 .54683 L .56458 .53759 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .56321 L p
1 g
F P
s
P
p
.56083 .54755 m .55727 .55682 L .55432 .55635 L 1 g
F
P
p
.002 w
.55326 .56725 m .54807 .56415 L p
.55727 .55682 L 1 g
F P
s
P
p
.56075 .54566 m .54925 .56321 L .55641 .55353 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53159 .57405 L p
1 g
F P
s
P
p
.002 w
.55326 .56725 m .51889 .58892 L .51466 .58423 L p
1 g
F P
s
P
p
.55326 .56725 m .51466 .58423 L .53159 .57405 L 1 g
F
P
p
.55258 .56728 m .53159 .57405 L .54216 .5677 L 1 g
F
P
p
.55326 .56725 m .53159 .57405 L .55258 .56728 L 1 g
F
P
p
.002 w
.53159 .57405 m .53128 .57265 L p
.52338 .5767 L 1 g
F P
s
P
p
.54854 .56129 m .53159 .57405 L .54113 .56832 L 1 g
F
P
p
.54123 .56826 m .53219 .5768 L .53268 .5764 L 1 g
F
P
p
.54854 .56129 m .54113 .56832 L .54123 .56826 L 1 g
F
P
p
.54113 .56832 m .53219 .5768 L .54123 .56826 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54807 .56415 m .55326 .56725 L p
.54216 .5677 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.50123 .56935 m .52807 .55219 L .54807 .56415 L p
1 g
F P
s
P
p
.54216 .5677 m .50123 .56935 L .54807 .56415 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51136 .58058 m .51653 .5863 L p
.5 .58258 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58072 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58072 L .52338 .5767 L 1 g
F
P
p
.54216 .5677 m .53159 .57405 L .50123 .56935 L 1 g
F
P
p
.002 w
.51466 .58423 m .51136 .58058 L p
.53159 .57405 L 1 g
F P
s
P
p
.002 w
.51136 .58058 m .50123 .56935 L p
.53159 .57405 L 1 g
F P
s
P
p
.002 w
.51095 .58072 m .51111 .583 L p
.52338 .5767 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53159 .57405 L p
1 g
F P
s
P
p
.52338 .5767 m .51111 .583 L .53159 .57405 L 1 g
F
P
p
.002 w
.53159 .57405 m .53219 .5768 L p
.54113 .56832 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54807 .56415 m .52807 .55219 L p
.55727 .55682 L 1 g
F P
s
P
p
.002 w
.54925 .56321 m .54998 .56518 L p
.55641 .55353 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56383 .53974 m .56083 .54755 L .52807 .55219 L 1 g
F
P
p
.56083 .54755 m .55432 .55635 L .52807 .55219 L 1 g
F
P
p
.002 w
.53219 .5768 m .5322 .57686 L p
.53268 .5764 L 1 g
F P
s
P
p
.002 w
.5551 .56484 m .55326 .56725 L p
.56383 .53974 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56137 .54683 L p
1 g
F P
s
P
p
.55641 .55353 m .54998 .56518 L .56137 .54683 L 1 g
F
P
p
.56654 .52734 m .56458 .53759 L .56476 .53707 L 1 g
F
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.56662 .53173 m .57812 .53477 L p
.56383 .53974 L 1 g
F P
s
P
p
.59043 .49478 m .56662 .53173 L .57239 .50811 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.52807 .55219 m .54734 .52664 L .56662 .53173 L p
1 g
F P
s
P
p
.56383 .53974 m .52807 .55219 L .56662 .53173 L 1 g
F
P
p
.56476 .53707 m .56244 .54885 L .56314 .54595 L 1 g
F
P
p
.56458 .53759 m .56244 .54885 L .56476 .53707 L 1 g
F
P
p
.002 w
.56137 .54683 m .56244 .54885 L p
.56458 .53759 L 1 g
F P
s
P
p
.002 w
.56662 .53173 m .54734 .52664 L p
.57239 .50811 L 1 g
F P
s
P
p
.002 w
.56244 .54885 m .56257 .5491 L p
.56314 .54595 L 1 g
F P
s
P
p
.002 w
.56739 .52858 m .56854 .53025 L p
.56641 .51642 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56581 .50905 L p
1 g
F P
s
P
p
.56641 .51642 m .56854 .53025 L .56581 .50905 L 1 g
F
P
p
.002 w
.56581 .50905 m .56713 .51061 L p
.56184 .50051 L 1 g
F P
s
P
p
.002 w
.54734 .52664 m .55674 .49532 L .55941 .49528 L p
1 g
F P
s
P
p
.002 w
.55649 .49047 m .55674 .49532 L p
.54224 .47662 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54224 .47662 L p
1 g
F P
s
P
p
.002 w
.54224 .47662 m .54174 .47608 L p
.54966 .48383 L 1 g
F P
s
P
p
.54966 .48383 m .55834 .49233 L .54224 .47662 L 1 g
F
P
p
.002 w
.555 .46167 m .55611 .48317 L p
.54224 .47662 L 1 g
F P
s
P
p
.52214 .46667 m .54224 .47662 L .53236 .47196 L 1 g
F
P
p
.5407 .47513 m .54224 .47662 L .54016 .47564 L 1 g
F
P
p
.555 .46167 m .54224 .47662 L .5407 .47513 L 1 g
F
P
p
.002 w
.55611 .48317 m .55649 .49047 L p
.54224 .47662 L 1 g
F P
s
P
p
.002 w
.55759 .49154 m .55834 .49233 L p
.54966 .48383 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52082 .49385 m .5195 .47081 L .52625 .46908 L p
1 g
F P
s
P
p
.52152 .46713 m .52249 .46725 L .5195 .47081 L 1 g
F
P
p
.52214 .46667 m .53236 .47196 L .52625 .46908 L 1 g
F
P
p
.002 w
.52249 .46725 m .52214 .46667 L p
.52625 .46908 L 1 g
F P
s
P
p
.002 w
.52966 .4682 m .52625 .46908 L p
.52249 .46725 L 1 g
F P
s
P
p
.002 w
.52625 .46908 m .5195 .47081 L p
.52249 .46725 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52249 .46725 L p
.52625 .46908 L 1 g
F P
s
P
p
.002 w
.52625 .46908 m .555 .46167 L p
.54016 .47564 L 1 g
F P
s
P
p
.54016 .47564 m .52082 .49385 L .52625 .46908 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52253 .46732 L p
1 g
F P
s
P
p
.53236 .47196 m .54302 .47747 L .52253 .46732 L 1 g
F
P
p
.002 w
.54224 .47662 m .54302 .47747 L p
.53236 .47196 L 1 g
F P
s
P
p
.5 .4634 m .52249 .46725 L .5199 .46691 L 1 g
F
P
p
.002 w
.51063 .44883 m .54215 .42948 L p
.52152 .46713 L 1 g
F P
s
P
p
.002 w
.5195 .47081 m .51781 .46664 L p
.52152 .46713 L 1 g
F P
s
P
p
.5 .4634 m .52257 .46738 L .51259 .46582 L 1 g
F
P
p
.002 w
.51781 .46664 m .51063 .44883 L p
.52152 .46713 L 1 g
F P
s
P
p
.002 w
.51781 .46664 m .5195 .47081 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.52257 .46738 m .52282 .46778 L p
.51476 .46624 L 1 g
F P
s
P
p
.51259 .46582 m .51781 .46664 L .51476 .46624 L 1 g
F
P
p
.51781 .46664 m .52257 .46738 L .51476 .46624 L 1 g
F
P
p
.002 w
.52249 .46725 m .52257 .46738 L p
.5199 .46691 L 1 g
F P
s
P
p
.002 w
.54215 .42948 m .555 .46167 L .52966 .4682 L p
1 g
F P
s
P
p
.54215 .42948 m .52966 .4682 L .52152 .46713 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46385 L p
1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .4634 L p
.51259 .46582 L 1 g
F P
s
P
p
.51259 .46582 m .52282 .46778 L .5 .46385 L 1 g
F
P
p
.002 w
.51063 .44883 m .5157 .4614 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46385 L p
1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .46442 L p
.48945 .46549 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46385 L .48945 .46549 L 1 g
F
P
p
.49729 .46342 m .5 .46385 L .49639 .46441 L 1 g
F
P
p
.51063 .44883 m .5 .46385 L .49729 .46342 L 1 g
F
P
p
.002 w
.5157 .4614 m .51781 .46664 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .49627 .46497 L p
.48775 .46576 L 1 g
F P
s
P
p
.47786 .46667 m .48945 .46549 L .48775 .46576 L 1 g
F
P
p
.48945 .46549 m .5 .46442 L .48775 .46576 L 1 g
F
P
p
.48775 .46576 m .47983 .46699 L .47747 .46732 L 1 g
F
P
p
.002 w
.47877 .46761 m .47842 .4672 L p
.47899 .46711 L 1 g
F P
s
P
p
.47983 .46699 m .47867 .46717 L .47842 .4672 L 1 g
F
P
p
.47983 .46699 m .47842 .4672 L .47747 .46732 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.49517 .43041 m .51063 .44883 L .47983 .46699 L p
1 g
F P
s
P
p
.002 w
.47983 .46699 m .47877 .46761 L p
.47899 .46711 L 1 g
F P
s
P
p
.49517 .43041 m .47983 .46699 L .47899 .46711 L 1 g
F
P
p
.002 w
.47094 .4583 m .49517 .43041 L p
.47899 .46711 L 1 g
F P
s
P
p
.002 w
.47842 .4672 m .47094 .4583 L p
.47899 .46711 L 1 g
F P
s
P
p
.47983 .46699 m .49627 .46497 L .47867 .46717 L 1 g
F
P
p
.48775 .46576 m .48848 .46569 L .47983 .46699 L 1 g
F
P
p
.48848 .46569 m .49627 .46497 L .47983 .46699 L 1 g
F
P
p
.002 w
.47983 .46699 m .51063 .44883 L p
.49639 .46441 L 1 g
F P
s
P
p
.002 w
.47822 .46696 m .47842 .4672 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.47842 .4672 m .47877 .46761 L p
.47747 .46732 L 1 g
F P
s
P
p
.002 w
.49627 .46497 m .47718 .46778 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47718 .46778 L p
.46836 .47165 L 1 g
F P
s
P
p
.45826 .47608 m .47747 .46732 L .46836 .47165 L 1 g
F
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45719 .47725 L p
1 g
F P
s
P
p
.002 w
.45719 .47725 m .45698 .47747 L p
.45375 .48057 L 1 g
F P
s
P
p
.44339 .4905 m .45719 .47725 L .45375 .48057 L 1 g
F
P
p
.002 w
.43379 .50953 m .43485 .50826 L p
.43837 .50004 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43379 .50952 L p
1 g
F P
s
P
p
.43188 .51349 m .43379 .50952 L .43371 .51021 L 1 g
F
P
p
.002 w
.43379 .50952 m .43379 .50953 L p
.43379 .50953 L 1 g
F P
s
P
p
.43346 .52734 m .43379 .50952 L .43379 .50953 L 1 g
F
P
p
.43346 .52734 m .43379 .50953 L .4335 .5122 L 1 g
F
P
p
.002 w
.4333 .51411 m .43188 .51349 L p
.43371 .51022 L 1 g
F P
s
P
p
.43188 .51349 m .43371 .51021 L .43371 .51022 L 1 g
F
P
p
.43346 .52734 m .4335 .5122 L .43312 .51766 L 1 g
F
P
p
.002 w
.43188 .51349 m .43153 .51333 L .4338 .5094 L p
1 g
F P
s
P
p
.43188 .51349 m .4338 .5094 L .43379 .50952 L 1 g
F
P
p
.4335 .5122 m .43351 .50986 L .4333 .51411 L 1 g
F
P
p
.4335 .5122 m .4333 .51411 L .43312 .51766 L 1 g
F
P
p
.002 w
.4338 .5094 m .4341 .50888 L p
.43379 .50952 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4424 .51809 m .4333 .51411 L p
.44636 .48772 L 1 g
F P
s
P
p
.4333 .51411 m .43371 .51022 L .44636 .48772 L 1 g
F
P
p
.002 w
.4338 .5094 m .43153 .51333 L p
.43538 .4951 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43153 .51333 m .4424 .51809 L .43883 .54773 L p
1 g
F P
s
P
p
.002 w
.43351 .50986 m .43287 .51061 L p
.43307 .51622 L 1 g
F P
s
P
p
.43312 .51766 m .4333 .51411 L .43307 .51622 L 1 g
F
P
p
.4333 .51411 m .43351 .50986 L .43307 .51622 L 1 g
F
P
p
.4335 .5122 m .43379 .50953 L .4335 .51212 L 1 g
F
P
p
.43379 .50953 m .43379 .50953 L .4335 .5122 L 1 g
F
P
p
.43371 .51022 m .44627 .48781 L .44636 .48772 L 1 g
F
P
p
.43371 .51021 m .44627 .48781 L .43371 .51022 L 1 g
F
P
p
.002 w
.4341 .50888 m .44627 .48781 L p
.43371 .51021 L 1 g
F P
s
P
p
.43379 .50952 m .4341 .50888 L .43371 .51021 L 1 g
F
P
p
.002 w
.44627 .48781 m .44784 .48508 L p
.44636 .48772 L 1 g
F P
s
P
p
.002 w
.4508 .48341 m .44784 .48508 L p
.456 .47753 L 1 g
F P
s
P
p
.47349 .46133 m .45765 .47674 L .456 .47753 L 1 g
F
P
p
.45765 .47674 m .4508 .48341 L .456 .47753 L 1 g
F
P
p
.002 w
.47349 .46133 m .47822 .46696 L p
.45765 .47674 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.46836 .47165 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.45141 .48282 m .45142 .48281 L .45139 .48284 L 1 g
F
P
p
.45141 .48282 m .45139 .48284 L .44253 .49142 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44784 .48508 m .47094 .4583 L .47349 .46133 L p
1 g
F P
s
P
p
.002 w
.44936 .48481 m .44784 .48508 L .4508 .48341 L p
1 g
F P
s
P
p
.002 w
.4508 .48341 m .47877 .46761 L p
.44936 .48481 L 1 g
F P
s
P
p
.45142 .48281 m .45151 .48272 L .45122 .483 L 1 g
F
P
p
.45142 .48281 m .45122 .483 L .44253 .49142 L 1 g
F
P
p
.45151 .48272 m .45168 .48256 L .45109 .48313 L 1 g
F
P
p
.45151 .48272 m .45109 .48313 L .44253 .49142 L 1 g
F
P
p
.002 w
.4833 .47872 m .48404 .4904 L .44892 .48524 L p
1 g
F P
s
P
p
.002 w
.44892 .48524 m .44784 .48508 L .44936 .48481 L p
1 g
F P
s
P
p
.002 w
.44936 .48481 m .4833 .47872 L p
.44892 .48524 L 1 g
F P
s
P
p
.002 w
.44866 .48549 m .44784 .48508 L .44892 .48524 L p
1 g
F P
s
P
p
.002 w
.44892 .48524 m .48404 .4904 L p
.44866 .48549 L 1 g
F P
s
P
p
.45168 .48256 m .45195 .4823 L .45095 .48327 L 1 g
F
P
p
.45168 .48256 m .45095 .48327 L .44253 .49142 L 1 g
F
P
p
.45195 .4823 m .45232 .48195 L .45073 .48348 L 1 g
F
P
p
.45195 .4823 m .45073 .48348 L .44253 .49142 L 1 g
F
P
p
.002 w
.48094 .50135 m .47435 .51039 L .44846 .48568 L p
1 g
F P
s
P
p
.002 w
.44846 .48568 m .44784 .48508 L .44866 .48549 L p
1 g
F P
s
P
p
.002 w
.44866 .48549 m .48094 .50135 L p
.44846 .48568 L 1 g
F P
s
P
p
.45232 .48195 m .45034 .48386 L .44253 .49142 L 1 g
F
P
p
.45278 .48151 m .44964 .48454 L .44253 .49142 L 1 g
F
P
p
.002 w
.44827 .48587 m .44784 .48508 L .44846 .48568 L p
1 g
F P
s
P
p
.002 w
.44846 .48568 m .47435 .51039 L p
.44827 .48587 L 1 g
F P
s
P
p
.45232 .48195 m .45278 .48151 L .45034 .48386 L 1 g
F
P
p
.45278 .48151 m .45328 .48102 L .44964 .48454 L 1 g
F
P
p
.002 w
.46502 .51656 m .45397 .51921 L .44802 .48611 L p
1 g
F P
s
P
p
.45328 .48102 m .44841 .48573 L .44253 .49142 L 1 g
F
P
p
.002 w
.44802 .48611 m .44784 .48508 L .44827 .48587 L p
1 g
F P
s
P
p
.002 w
.44827 .48587 m .46502 .51656 L p
.44802 .48611 L 1 g
F P
s
P
p
.002 w
.4476 .48651 m .44784 .48508 L .44802 .48611 L p
1 g
F P
s
P
p
.002 w
.44802 .48611 m .45397 .51921 L p
.4476 .48651 L 1 g
F P
s
P
p
.45328 .48102 m .45375 .48057 L .44841 .48573 L 1 g
F
P
p
.45375 .48057 m .45404 .4803 L .44627 .48781 L 1 g
F
P
p
.45375 .48057 m .44627 .48781 L .44253 .49142 L 1 g
F
P
p
.002 w
.44784 .48508 m .4476 .48651 L p
.44636 .48772 L 1 g
F P
s
P
p
.002 w
.4476 .48651 m .4424 .51809 L p
.44636 .48772 L 1 g
F P
s
P
p
.002 w
.44416 .48804 m .44784 .48508 L .4341 .50888 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44253 .49142 L p
1 g
F P
s
P
p
.45404 .4803 m .45698 .47747 L .44253 .49142 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43379 .50953 L p
1 g
F P
s
P
p
.43837 .50004 m .44166 .49233 L .43379 .50953 L 1 g
F
P
p
.002 w
.43379 .50953 m .43351 .50986 L p
.4335 .51212 L 1 g
F P
s
P
p
.002 w
.43883 .54773 m .43807 .5474 L p
.43297 .52083 L 1 g
F P
s
P
p
.43299 .52025 m .43297 .52083 L .43153 .51333 L 1 g
F
P
p
.43883 .54773 m .43297 .52083 L .43299 .52025 L 1 g
F
P
p
.002 w
.4293 .51738 m .43153 .51333 L p
.43807 .5474 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43258 .52862 L p
1 g
F P
s
P
p
.43312 .51766 m .43287 .51061 L .43258 .52862 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43816 .54771 L p
1 g
F P
s
P
p
.002 w
.43816 .54771 m .43818 .54768 L p
.43807 .5474 L 1 g
F P
s
P
p
.43807 .5474 m .43146 .53025 L .43816 .54771 L 1 g
F
P
p
.43155 .53042 m .43146 .53025 L .43818 .54768 L 1 g
F
P
p
.002 w
.43883 .54773 m .43878 .54848 L p
.43818 .54768 L 1 g
F P
s
P
p
.002 w
.43807 .5474 m .43883 .54773 L p
.43818 .54768 L 1 g
F P
s
P
p
.002 w
.43818 .54768 m .43815 .54774 L p
.43845 .54805 L 1 g
F P
s
P
p
.002 w
.43843 .55398 m .43878 .54848 L p
.4509 .56279 L 1 g
F P
s
P
p
.002 w
.43815 .54774 m .43743 .5491 L p
.44453 .55527 L 1 g
F P
s
P
p
.002 w
.43787 .56251 m .43843 .55398 L p
.4509 .56279 L 1 g
F P
s
P
p
.45752 .5706 m .43787 .56251 L .4509 .56279 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4509 .56279 L p
1 g
F P
s
P
p
.002 w
.4509 .56279 m .45146 .56129 L p
.44453 .55527 L 1 g
F P
s
P
p
.44453 .55527 m .43743 .5491 L .4509 .56279 L 1 g
F
P
p
.46821 .575 m .45752 .5706 L .4509 .56279 L 1 g
F
P
p
.46821 .575 m .4509 .56279 L .43883 .54773 L 1 g
F
P
p
.002 w
.43878 .54848 m .43883 .54773 L p
.4509 .56279 L 1 g
F P
s
P
p
.46824 .57501 m .46821 .575 L .43883 .54773 L 1 g
F
P
p
.002 w
.4509 .56279 m .45002 .56518 L p
.45986 .56911 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46821 .575 L p
1 g
F P
s
P
p
.45986 .56911 m .45002 .56518 L .46821 .575 L 1 g
F
P
p
.48921 .57862 m .46977 .57564 L .47857 .57775 L 1 g
F
P
p
.002 w
.46952 .57554 m .46982 .57648 L p
.46824 .57501 L 1 g
F P
s
P
p
.46977 .57564 m .46812 .57539 L .47041 .5759 L 1 g
F
P
p
.46977 .57564 m .47041 .5759 L .47857 .57775 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43883 .54773 m .46141 .55002 L .46952 .57554 L p
1 g
F P
s
P
p
.46824 .57501 m .43883 .54773 L .46952 .57554 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.50123 .56935 m .47138 .57612 L p
.46141 .55002 L 1 g
F P
s
P
p
.002 w
.46952 .57554 m .46141 .55002 L p
.47138 .57612 L 1 g
F P
s
P
p
.002 w
.46821 .575 m .46812 .57539 L p
.46977 .57564 L 1 g
F P
s
P
p
.002 w
.47118 .57968 m .46982 .57648 L p
.48365 .57999 L 1 g
F P
s
P
p
.002 w
.46812 .57539 m .4678 .57686 L p
.47857 .57775 L 1 g
F P
s
P
p
.002 w
.47138 .57612 m .50123 .56935 L .51136 .58058 L p
1 g
F P
s
P
p
.5 .58258 m .47138 .57612 L .51136 .58058 L 1 g
F
P
p
.002 w
.51111 .583 m .51143 .5874 L p
.53201 .57696 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53166 .57702 L p
.53201 .57696 L 1 g
F P
s
P
p
.002 w
.53166 .57702 m .51111 .583 L p
.53201 .57696 L 1 g
F P
s
P
p
.002 w
.4891 .58012 m .48889 .583 L p
.50174 .58043 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58012 L p
1 g
F P
s
P
p
.47857 .57775 m .4678 .57686 L .4891 .58012 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58066 L p
1 g
F P
s
P
p
.50174 .58043 m .48889 .583 L .51094 .58066 L 1 g
F
P
p
.002 w
.51889 .58892 m .47888 .59781 L .47118 .57968 L p
1 g
F P
s
P
p
.002 w
.53352 .29763 m .47631 .28434 L .48429 .26306 L p
1 g
F P
s
P
p
.002 w
.48429 .26306 m .54592 .2772 L .53352 .29763 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.51889 .58892 m .55326 .56725 L .57618 .57782 L p
1 g
F P
s
P
p
.002 w
.60582 .53957 m .57618 .57782 L .55326 .56725 L p
1 g
F P
s
P
p
.002 w
.64652 .48802 m .64442 .43059 L .66518 .42034 L p
1 g
F P
s
P
p
.002 w
.64225 .36089 m .66518 .42034 L .64442 .43059 L p
1 g
F P
s
P
p
.004 w
.49747 .43316 m
.5 .43051 L
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.37149 .41547 m .35847 .44461 L .33742 .43035 L p
1 g
F P
s
P
p
.002 w
.33742 .43035 m .3538 .39311 L .37149 .41547 L p
1 g
F P
s
P
p
.002 w
.4688 .31077 m .41839 .31607 L .41974 .29056 L p
1 g
F P
s
P
p
.002 w
.41974 .29056 m .47631 .28434 L .4688 .31077 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5845 .32921 m .53352 .29763 L .54592 .2772 L p
1 g
F P
s
P
p
.002 w
.54592 .2772 m .60084 .31113 L .5845 .32921 L p
1 g
F P
s
P
p
.002 w
.388 .50329 m .40013 .52307 L .3814 .53739 L p
1 g
F P
s
P
p
.002 w
.3814 .53739 m .36386 .50889 L .388 .50329 L p
1 g
F P
s
P
p
.002 w
.4067 .55953 m .3814 .53739 L .40013 .52307 L p
1 g
F P
s
P
p
.002 w
.40013 .52307 m .41768 .53841 L .4067 .55953 L p
1 g
F P
s
P
p
.002 w
.43719 .57304 m .4067 .55953 L .41768 .53841 L p
1 g
F P
s
P
p
.002 w
.64442 .43059 m .62299 .37542 L .64225 .36089 L p
1 g
F P
s
P
p
.002 w
.60084 .31113 m .64225 .36089 L .62299 .37542 L p
1 g
F P
s
P
p
.004 w
.63842 .31195 m
.65011 .30193 L
s
P
p
.002 w
.60582 .53957 m .62069 .49229 L .64652 .48802 L p
1 g
F P
s
P
p
.002 w
.64442 .43059 m .64652 .48802 L .62069 .49229 L p
1 g
F P
s
P
p
.002 w
.38256 .48112 m .388 .50329 L .36386 .50889 L p
1 g
F P
s
P
p
.002 w
.36386 .50889 m .3559 .47688 L .38256 .48112 L p
1 g
F P
s
P
p
.002 w
.41951 .34582 m .38209 .36378 L .37421 .33761 L p
1 g
F P
s
P
p
.002 w
.37421 .33761 m .41839 .31607 L .41951 .34582 L p
1 g
F P
s
P
p
.002 w
.62299 .37542 m .5845 .32921 L .60084 .31113 L p
1 g
F P
s
P
p
.002 w
.55326 .56725 m .57812 .53477 L .60582 .53957 L p
1 g
F P
s
P
p
.002 w
.62069 .49229 m .60582 .53957 L .57812 .53477 L p
1 g
F P
s
P
p
.002 w
.38446 .45885 m .38256 .48112 L .3559 .47688 L p
1 g
F P
s
P
p
.002 w
.3559 .47688 m .35847 .44461 L .38446 .45885 L p
1 g
F P
s
P
p
.002 w
.3938 .39267 m .37149 .41547 L .3538 .39311 L p
1 g
F P
s
P
p
.002 w
.3538 .39311 m .38209 .36378 L .3938 .39267 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.51971 .32277 m .4688 .31077 L .47631 .28434 L p
1 g
F P
s
P
p
.002 w
.47631 .28434 m .53352 .29763 L .51971 .32277 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.62069 .49229 m .6186 .44115 L .64442 .43059 L p
1 g
F P
s
P
p
.002 w
.62299 .37542 m .64442 .43059 L .6186 .44115 L p
1 g
F P
s
P
p
.002 w
.39357 .43884 m .38446 .45885 L .35847 .44461 L p
1 g
F P
s
P
p
.002 w
.35847 .44461 m .37149 .41547 L .39357 .43884 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.46207 .34158 m .41951 .34582 L .41839 .31607 L p
1 g
F P
s
P
p
.002 w
.41839 .31607 m .4688 .31077 L .46207 .34158 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46141 .55002 m .48305 .54498 L .50123 .56935 L p
1 g
F P
s
P
p
.002 w
.52807 .55219 m .50123 .56935 L .48305 .54498 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.56506 .35096 m .51971 .32277 L .53352 .29763 L p
1 g
F P
s
P
p
.002 w
.53352 .29763 m .5845 .32921 L .56506 .35096 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.4163 .49529 m .42251 .50545 L .40013 .52307 L p
1 g
F P
s
P
p
.002 w
.40013 .52307 m .388 .50329 L .4163 .49529 L p
1 g
F P
s
P
p
.002 w
.41768 .53841 m .40013 .52307 L .42251 .50545 L p
1 g
F P
s
P
p
.002 w
.42251 .50545 m .43153 .51333 L .41768 .53841 L p
1 g
F P
s
P
p
.002 w
.57812 .53477 m .59043 .49478 L .62069 .49229 L p
1 g
F P
s
P
p
.002 w
.6186 .44115 m .62069 .49229 L .59043 .49478 L p
1 g
F P
s
P
p
.002 w
.42314 .37883 m .3938 .39267 L .38209 .36378 L p
1 g
F P
s
P
p
.002 w
.38209 .36378 m .41951 .34582 L .42314 .37883 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.6186 .44115 m .59938 .39207 L .62299 .37542 L p
1 g
F P
s
P
p
.002 w
.5845 .32921 m .62299 .37542 L .59938 .39207 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.59019 .35326 L
s
P
p
.004 w
.6048 .34075 m
.61741 .32994 L
s
P
p
.004 w
.61741 .32994 m
.63842 .31195 L
s
P
p
.002 w
.41355 .4839 m .4163 .49529 L .388 .50329 L p
1 g
F P
s
P
p
.002 w
.388 .50329 m .38256 .48112 L .41355 .4839 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46141 .55002 m .43883 .54773 L .4424 .51809 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59938 .39207 m .56506 .35096 L .5845 .32921 L p
1 g
F P
s
P
p
.004 w
.59735 .34712 m
.6048 .34075 L
s
P
p
.004 w
.59358 .35035 m
.59735 .34712 L
s
P
p
.004 w
.59283 .351 m
.59358 .35035 L
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.40902 .42328 m .39357 .43884 L .37149 .41547 L p
1 g
F P
s
P
p
.002 w
.37149 .41547 m .3938 .39267 L .40902 .42328 L p
1 g
F P
s
P
p
.002 w
.41459 .47252 m .41355 .4839 L .38256 .48112 L p
1 g
F P
s
P
p
.002 w
.38256 .48112 m .38446 .45885 L .41459 .47252 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.4424 .51809 m .45397 .51921 L .46141 .55002 L p
1 g
F P
s
P
p
.002 w
.48305 .54498 m .46141 .55002 L .45397 .51921 L p
1 g
F P
s
P
p
.002 w
.48305 .54498 m .50144 .53303 L .52807 .55219 L p
1 g
F P
s
P
p
.002 w
.54734 .52664 m .52807 .55219 L .50144 .53303 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.50496 .35186 m .46207 .34158 L .4688 .31077 L p
1 g
F P
s
P
p
.002 w
.4688 .31077 m .51971 .32277 L .50496 .35186 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59043 .49478 m .58845 .45164 L .6186 .44115 L p
1 g
F P
s
P
p
.002 w
.59938 .39207 m .6186 .44115 L .58845 .45164 L p
1 g
F P
s
P
p
.002 w
.41932 .46234 m .41459 .47252 L .38446 .45885 L p
1 g
F P
s
P
p
.002 w
.38446 .45885 m .39357 .43884 L .41932 .46234 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45639 .37573 m .42314 .37883 L .41951 .34582 L p
1 g
F P
s
P
p
.002 w
.41951 .34582 m .46207 .34158 L .45639 .37573 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45397 .51921 m .46502 .51656 L .48305 .54498 L p
1 g
F P
s
P
p
.002 w
.50144 .53303 m .48305 .54498 L .46502 .51656 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42923 .41395 m .40902 .42328 L .3938 .39267 L p
1 g
F P
s
P
p
.002 w
.3938 .39267 m .42314 .37883 L .42923 .41395 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.54316 .37568 m .50496 .35186 L .51971 .32277 L p
1 g
F P
s
P
p
.002 w
.51971 .32277 m .56506 .35096 L .54316 .37568 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.42251 .50545 m .4163 .49529 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.50144 .53303 m .51454 .51537 L .54734 .52664 L p
1 g
F P
s
P
p
.002 w
.55674 .49532 m .54734 .52664 L .51454 .51537 L p
1 g
F P
s
P
p
.002 w
.42726 .45449 m .41932 .46234 L .39357 .43884 L p
1 g
F P
s
P
p
.002 w
.39357 .43884 m .40902 .42328 L .42726 .45449 L p
1 g
F P
s
P
p
.002 w
.58845 .45164 m .57211 .41031 L .59938 .39207 L p
1 g
F P
s
P
p
.002 w
.56506 .35096 m .59938 .39207 L .57211 .41031 L p
1 g
F P
s
P
p
.002 w
.4163 .49529 m .41355 .4839 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.57211 .41031 m .54316 .37568 L .56506 .35096 L p
1 g
F P
s
P
p
.002 w
.46502 .51656 m .47435 .51039 L .50144 .53303 L p
1 g
F P
s
P
p
.002 w
.51454 .51537 m .50144 .53303 L .47435 .51039 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.41355 .4839 m .41459 .47252 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48981 .38389 m .45639 .37573 L .46207 .34158 L p
1 g
F P
s
P
p
.002 w
.46207 .34158 m .50496 .35186 L .48981 .38389 L p
1 g
F P
s
P
p
.002 w
.41459 .47252 m .41932 .46234 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.45202 .41197 m .42923 .41395 L .42314 .37883 L p
1 g
F P
s
P
p
.002 w
.42314 .37883 m .45639 .37573 L .45202 .41197 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43756 .44983 m .42726 .45449 L .40902 .42328 L p
1 g
F P
s
P
p
.002 w
.40902 .42328 m .42923 .41395 L .43756 .44983 L p
1 g
F P
s
P
p
.002 w
.57211 .41031 m .58845 .45164 L .555 .46167 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.41932 .46234 m .42726 .45449 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.51454 .51537 m .52082 .49385 L .55674 .49532 L p
1 g
F P
s
P
p
.002 w
.47435 .51039 m .48094 .50135 L .51454 .51537 L p
1 g
F P
s
P
p
.002 w
.52082 .49385 m .51454 .51537 L .48094 .50135 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.51956 .40251 m .48981 .38389 L .50496 .35186 L p
1 g
F P
s
P
p
.002 w
.50496 .35186 m .54316 .37568 L .51956 .40251 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.42726 .45449 m .43756 .44983 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.44913 .4489 m .46068 .45183 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.43756 .44983 m .44913 .4489 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.46068 .45183 m .47094 .4583 L .44784 .48508 L closepath p
1 g
F P
s
P
p
.002 w
.555 .46167 m .54215 .42948 L .57211 .41031 L p
1 g
F P
s
P
p
.002 w
.54316 .37568 m .57211 .41031 L .54215 .42948 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.48094 .50135 m .48404 .4904 L .52082 .49385 L p
1 g
F P
s
P
p
.002 w
.44913 .4489 m .43756 .44983 L .42923 .41395 L p
1 g
F P
s
P
p
.002 w
.42923 .41395 m .45202 .41197 L .44913 .4489 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.47486 .41765 m .45202 .41197 L .45639 .37573 L p
1 g
F P
s
P
p
.002 w
.45639 .37573 m .48981 .38389 L .47486 .41765 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54215 .42948 m .51956 .40251 L .54316 .37568 L p
1 g
F P
s
P
p
.002 w
.5195 .47081 m .52082 .49385 L .48404 .4904 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.004 w
.44616 .48684 m
.44784 .48508 L
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.48404 .4904 m .4833 .47872 L .5195 .47081 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.46068 .45183 m .44913 .4489 L .45202 .41197 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45202 .41197 m .47486 .41765 L .46068 .45183 L p
1 g
F P
s
P
p
.002 w
.49517 .43041 m .47486 .41765 L .48981 .38389 L p
1 g
F P
s
P
p
.002 w
.48981 .38389 m .51956 .40251 L .49517 .43041 L p
1 g
F P
s
P
p
.002 w
.47094 .4583 m .46068 .45183 L .47486 .41765 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51956 .40251 m .54215 .42948 L .51063 .44883 L p
1 g
F P
s
P
p
.002 w
.47486 .41765 m .49517 .43041 L .47094 .4583 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51063 .44883 m .49517 .43041 L .51956 .40251 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.41581 .51859 m
.44616 .48684 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .65011 .30193 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .41581 .51859 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.35814)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.35814)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46864 .4333 m .48108 .44698 L .4988 .42461 L p
1 g
F P
s
P
p
.002 w
.4988 .42461 m .49251 .41768 L .46864 .4333 L p
1 g
F P
s
P
p
.002 w
.50698 .42917 m .4988 .42461 L .48108 .44698 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .49251 .41768 L .4988 .42461 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .4988 .42461 L .50698 .42917 L closepath p
1 g
F P
s
P
p
.002 w
.48108 .44698 m .49725 .456 L .50698 .42917 L p
1 g
F P
s
P
p
.002 w
.51618 .43088 m .50698 .42917 L .49725 .456 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .50698 .42917 L .51618 .43088 L closepath p
1 g
F P
s
P
p
.002 w
.46126 .41641 m .46864 .4333 L .49251 .41768 L p
1 g
F P
s
P
p
.002 w
.49251 .41768 m .48879 .40912 L .46126 .41641 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .48879 .40912 L .49251 .41768 L closepath p
1 g
F P
s
P
p
.002 w
.49725 .456 m .51542 .45939 L .51618 .43088 L p
1 g
F P
s
P
p
.002 w
.52541 .42954 m .51618 .43088 L .51542 .45939 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .51618 .43088 L .52541 .42954 L closepath p
1 g
F P
s
P
p
.002 w
.45974 .39808 m .46126 .41641 L .48879 .40912 L p
1 g
F P
s
P
p
.002 w
.48879 .40912 m .48805 .39985 L .45974 .39808 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .48805 .39985 L .48879 .40912 L closepath p
1 g
F P
s
P
p
.002 w
.44539 .44896 m .46373 .46908 L .48108 .44698 L p
1 g
F P
s
P
p
.002 w
.48108 .44698 m .46864 .4333 L .44539 .44896 L p
1 g
F P
s
P
p
.002 w
.49725 .456 m .48108 .44698 L .46373 .46908 L p
1 g
F P
s
P
p
.002 w
.51542 .45939 m .53367 .45678 L .52541 .42954 L p
1 g
F P
s
P
p
.002 w
.53368 .42529 m .52541 .42954 L .53367 .45678 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .52541 .42954 L .53368 .42529 L closepath p
1 g
F P
s
P
p
.002 w
.46373 .46908 m .48752 .48235 L .49725 .456 L p
1 g
F P
s
P
p
.002 w
.51542 .45939 m .49725 .456 L .48752 .48235 L p
1 g
F P
s
P
p
.002 w
.43446 .42409 m .44539 .44896 L .46864 .4333 L p
1 g
F P
s
P
p
.002 w
.46864 .4333 m .46126 .41641 L .43446 .42409 L p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .53749 .38387 L .53011 .37799 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .53011 .37799 L .52123 .3748 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .52123 .3748 L .51183 .37465 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .51183 .37465 L .50294 .37754 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .50294 .37754 L .49552 .38315 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .49552 .38315 L .49037 .39087 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .49037 .39087 L .48805 .39985 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .53368 .42529 L .54009 .41859 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .54009 .41859 L .54394 .41015 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .54394 .41015 L .5448 .40087 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .5448 .40087 L .54257 .39178 L closepath p
1 g
F P
s
P
p
.002 w
.51656 .40236 m .54257 .39178 L .53749 .38387 L closepath p
1 g
F P
s
P
p
.002 w
.48752 .48235 m .51427 .48738 L .51542 .45939 L p
1 g
F P
s
P
p
.002 w
.53367 .45678 m .51542 .45939 L .51427 .48738 L p
1 g
F P
s
P
p
.002 w
.46427 .38029 m .45974 .39808 L .48805 .39985 L p
1 g
F P
s
P
p
.002 w
.48805 .39985 m .49037 .39087 L .46427 .38029 L p
1 g
F P
s
P
p
.002 w
.53367 .45678 m .55004 .44843 L .53368 .42529 L p
1 g
F P
s
P
p
.002 w
.54009 .41859 m .53368 .42529 L .55004 .44843 L p
1 g
F P
s
P
p
.002 w
.47442 .36495 m .46427 .38029 L .49037 .39087 L p
1 g
F P
s
P
p
.002 w
.49037 .39087 m .49552 .38315 L .47442 .36495 L p
1 g
F P
s
P
p
.002 w
.43214 .39708 m .43446 .42409 L .46126 .41641 L p
1 g
F P
s
P
p
.002 w
.46126 .41641 m .45974 .39808 L .43214 .39708 L p
1 g
F P
s
P
p
.002 w
.55004 .44843 m .56278 .43521 L .54009 .41859 L p
1 g
F P
s
P
p
.002 w
.54394 .41015 m .54009 .41859 L .56278 .43521 L p
1 g
F P
s
P
p
.002 w
.51427 .48738 m .54116 .4836 L .53367 .45678 L p
1 g
F P
s
P
p
.002 w
.55004 .44843 m .53367 .45678 L .54116 .4836 L p
1 g
F P
s
P
p
.002 w
.48911 .35377 m .47442 .36495 L .49552 .38315 L p
1 g
F P
s
P
p
.002 w
.49552 .38315 m .50294 .37754 L .48911 .35377 L p
1 g
F P
s
P
p
.002 w
.56278 .43521 m .57047 .4185 L .54394 .41015 L p
1 g
F P
s
P
p
.002 w
.5448 .40087 m .54394 .41015 L .57047 .4185 L p
1 g
F P
s
P
p
.002 w
.43875 .37081 m .43214 .39708 L .45974 .39808 L p
1 g
F P
s
P
p
.002 w
.45974 .39808 m .46427 .38029 L .43875 .37081 L p
1 g
F P
s
P
p
.002 w
.42319 .46436 m .44706 .4905 L .46373 .46908 L p
1 g
F P
s
P
p
.002 w
.46373 .46908 m .44539 .44896 L .42319 .46436 L p
1 g
F P
s
P
p
.002 w
.48752 .48235 m .46373 .46908 L .44706 .4905 L p
1 g
F P
s
P
p
.002 w
.50676 .34798 m .48911 .35377 L .50294 .37754 L p
1 g
F P
s
P
p
.002 w
.50294 .37754 m .51183 .37465 L .50676 .34798 L p
1 g
F P
s
P
p
.002 w
.54116 .4836 m .56535 .47137 L .55004 .44843 L p
1 g
F P
s
P
p
.002 w
.56278 .43521 m .55004 .44843 L .56535 .47137 L p
1 g
F P
s
P
p
.002 w
.44706 .4905 m .47799 .50776 L .48752 .48235 L p
1 g
F P
s
P
p
.002 w
.51427 .48738 m .48752 .48235 L .47799 .50776 L p
1 g
F P
s
P
p
.002 w
.57047 .4185 m .57224 .4001 L .5448 .40087 L p
1 g
F P
s
P
p
.002 w
.54257 .39178 m .5448 .40087 L .57224 .4001 L p
1 g
F P
s
P
p
.002 w
.52545 .34826 m .50676 .34798 L .51183 .37465 L p
1 g
F P
s
P
p
.002 w
.51183 .37465 m .52123 .3748 L .52545 .34826 L p
1 g
F P
s
P
p
.002 w
.57224 .4001 m .56786 .38203 L .54257 .39178 L p
1 g
F P
s
P
p
.002 w
.53749 .38387 m .54257 .39178 L .56786 .38203 L p
1 g
F P
s
P
p
.002 w
.4089 .43204 m .42319 .46436 L .44539 .44896 L p
1 g
F P
s
P
p
.002 w
.44539 .44896 m .43446 .42409 L .4089 .43204 L p
1 g
F P
s
P
p
.002 w
.47799 .50776 m .51276 .51433 L .51427 .48738 L p
1 g
F P
s
P
p
.002 w
.54116 .4836 m .51427 .48738 L .51276 .51433 L p
1 g
F P
s
P
p
.002 w
.54311 .35458 m .52545 .34826 L .52123 .3748 L p
1 g
F P
s
P
p
.002 w
.52123 .3748 m .53011 .37799 L .54311 .35458 L p
1 g
F P
s
P
p
.002 w
.53011 .37799 m .53749 .38387 L .55778 .36628 L p
1 g
F P
s
P
p
.002 w
.56786 .38203 m .55778 .36628 L .53749 .38387 L p
1 g
F P
s
P
p
.002 w
.55778 .36628 m .54311 .35458 L .53011 .37799 L p
1 g
F P
s
P
p
.002 w
.45366 .34811 m .43875 .37081 L .46427 .38029 L p
1 g
F P
s
P
p
.002 w
.46427 .38029 m .47442 .36495 L .45366 .34811 L p
1 g
F P
s
P
p
.002 w
.56535 .47137 m .58421 .45191 L .56278 .43521 L p
1 g
F P
s
P
p
.002 w
.57047 .4185 m .56278 .43521 L .58421 .45191 L p
1 g
F P
s
P
p
.002 w
.40578 .39689 m .4089 .43204 L .43446 .42409 L p
1 g
F P
s
P
p
.002 w
.43446 .42409 m .43214 .39708 L .40578 .39689 L p
1 g
F P
s
P
p
.002 w
.51276 .51433 m .54776 .50949 L .54116 .4836 L p
1 g
F P
s
P
p
.002 w
.56535 .47137 m .54116 .4836 L .54776 .50949 L p
1 g
F P
s
P
p
.002 w
.47533 .3315 m .45366 .34811 L .47442 .36495 L p
1 g
F P
s
P
p
.002 w
.47442 .36495 m .48911 .35377 L .47533 .3315 L p
1 g
F P
s
P
p
.002 w
.58421 .45191 m .59565 .42726 L .57047 .4185 L p
1 g
F P
s
P
p
.002 w
.57224 .4001 m .57047 .4185 L .59565 .42726 L p
1 g
F P
s
P
p
.002 w
.41428 .36264 m .40578 .39689 L .43214 .39708 L p
1 g
F P
s
P
p
.002 w
.43214 .39708 m .43875 .37081 L .41428 .36264 L p
1 g
F P
s
P
p
.002 w
.54776 .50949 m .57928 .49365 L .56535 .47137 L p
1 g
F P
s
P
p
.002 w
.58421 .45191 m .56535 .47137 L .57928 .49365 L p
1 g
F P
s
P
p
.002 w
.50143 .32287 m .47533 .3315 L .48911 .35377 L p
1 g
F P
s
P
p
.002 w
.48911 .35377 m .50676 .34798 L .50143 .32287 L p
1 g
F P
s
P
p
.002 w
.59565 .42726 m .59835 .40007 L .57224 .4001 L p
1 g
F P
s
P
p
.002 w
.56786 .38203 m .57224 .4001 L .59835 .40007 L p
1 g
F P
s
P
p
.002 w
.40247 .47921 m .43139 .51082 L .44706 .4905 L p
1 g
F P
s
P
p
.002 w
.44706 .4905 m .42319 .46436 L .40247 .47921 L p
1 g
F P
s
P
p
.002 w
.47799 .50776 m .44706 .4905 L .43139 .51082 L p
1 g
F P
s
P
p
.002 w
.43139 .51082 m .46883 .53171 L .47799 .50776 L p
1 g
F P
s
P
p
.002 w
.51276 .51433 m .47799 .50776 L .46883 .53171 L p
1 g
F P
s
P
p
.002 w
.52911 .32323 m .50143 .32287 L .50676 .34798 L p
1 g
F P
s
P
p
.002 w
.50676 .34798 m .52545 .34826 L .52911 .32323 L p
1 g
F P
s
P
p
.002 w
.59835 .40007 m .59193 .3733 L .56786 .38203 L p
1 g
F P
s
P
p
.002 w
.55778 .36628 m .56786 .38203 L .59193 .3733 L p
1 g
F P
s
P
p
.002 w
.3851 .44011 m .40247 .47921 L .42319 .46436 L p
1 g
F P
s
P
p
.002 w
.42319 .46436 m .4089 .43204 L .3851 .44011 L p
1 g
F P
s
P
p
.002 w
.46883 .53171 m .51091 .53972 L .51276 .51433 L p
1 g
F P
s
P
p
.002 w
.54776 .50949 m .51276 .51433 L .51091 .53972 L p
1 g
F P
s
P
p
.002 w
.43363 .33297 m .41428 .36264 L .43875 .37081 L p
1 g
F P
s
P
p
.002 w
.43875 .37081 m .45366 .34811 L .43363 .33297 L p
1 g
F P
s
P
p
.002 w
.55529 .3326 m .52911 .32323 L .52545 .34826 L p
1 g
F P
s
P
p
.002 w
.52545 .34826 m .54311 .35458 L .55529 .3326 L p
1 g
F P
s
P
p
.002 w
.59193 .3733 m .57704 .34994 L .55778 .36628 L p
1 g
F P
s
P
p
.002 w
.54311 .35458 m .55778 .36628 L .57704 .34994 L p
1 g
F P
s
P
p
.002 w
.57928 .49365 m .60393 .46838 L .58421 .45191 L p
1 g
F P
s
P
p
.002 w
.59565 .42726 m .58421 .45191 L .60393 .46838 L p
1 g
F P
s
P
p
.002 w
.57704 .34994 m .55529 .3326 L .54311 .35458 L p
1 g
F P
s
P
p
.002 w
.38121 .39754 m .3851 .44011 L .4089 .43204 L p
1 g
F P
s
P
p
.002 w
.4089 .43204 m .40578 .39689 L .38121 .39754 L p
1 g
F P
s
P
p
.002 w
.51091 .53972 m .5533 .53394 L .54776 .50949 L p
1 g
F P
s
P
p
.002 w
.57928 .49365 m .54776 .50949 L .5533 .53394 L p
1 g
F P
s
P
p
.002 w
.46186 .31121 m .43363 .33297 L .45366 .34811 L p
1 g
F P
s
P
p
.002 w
.45366 .34811 m .47533 .3315 L .46186 .31121 L p
1 g
F P
s
P
p
.002 w
.60393 .46838 m .61896 .43628 L .59565 .42726 L p
1 g
F P
s
P
p
.002 w
.59835 .40007 m .59565 .42726 L .61896 .43628 L p
1 g
F P
s
P
p
.002 w
.39139 .35597 m .38121 .39754 L .40578 .39689 L p
1 g
F P
s
P
p
.002 w
.40578 .39689 m .41428 .36264 L .39139 .35597 L p
1 g
F P
s
P
p
.002 w
.5533 .53394 m .59154 .51485 L .57928 .49365 L p
1 g
F P
s
P
p
.002 w
.60393 .46838 m .57928 .49365 L .59154 .51485 L p
1 g
F P
s
P
p
.002 w
.49594 .29986 m .46186 .31121 L .47533 .3315 L p
1 g
F P
s
P
p
.002 w
.47533 .3315 m .50143 .32287 L .49594 .29986 L p
1 g
F P
s
P
p
.002 w
.61896 .43628 m .62258 .40079 L .59835 .40007 L p
1 g
F P
s
P
p
.002 w
.59193 .3733 m .59835 .40007 L .62258 .40079 L p
1 g
F P
s
P
p
.002 w
.3837 .49319 m .41707 .52961 L .43139 .51082 L p
1 g
F P
s
P
p
.002 w
.43139 .51082 m .40247 .47921 L .3837 .49319 L p
1 g
F P
s
P
p
.002 w
.46883 .53171 m .43139 .51082 L .41707 .52961 L p
1 g
F P
s
P
p
.002 w
.41707 .52961 m .46023 .5537 L .46883 .53171 L p
1 g
F P
s
P
p
.002 w
.51091 .53972 m .46883 .53171 L .46023 .5537 L p
1 g
F P
s
P
p
.002 w
.53214 .30028 m .49594 .29986 L .50143 .32287 L p
1 g
F P
s
P
p
.002 w
.50143 .32287 m .52911 .32323 L .53214 .30028 L p
1 g
F P
s
P
p
.002 w
.62258 .40079 m .61427 .36579 L .59193 .3733 L p
1 g
F P
s
P
p
.002 w
.57704 .34994 m .59193 .3733 L .61427 .36579 L p
1 g
F P
s
P
p
.002 w
.36359 .44814 m .3837 .49319 L .40247 .47921 L p
1 g
F P
s
P
p
.002 w
.40247 .47921 m .3851 .44011 L .36359 .44814 L p
1 g
F P
s
P
p
.002 w
.41477 .31991 m .39139 .35597 L .41428 .36264 L p
1 g
F P
s
P
p
.002 w
.41428 .36264 m .43363 .33297 L .41477 .31991 L p
1 g
F P
s
P
p
.002 w
.46023 .5537 m .50874 .56298 L .51091 .53972 L p
1 g
F P
s
P
p
.002 w
.5533 .53394 m .51091 .53972 L .50874 .56298 L p
1 g
F P
s
P
p
.002 w
.59154 .51485 m .62153 .48429 L .60393 .46838 L p
1 g
F P
s
P
p
.002 w
.61896 .43628 m .60393 .46838 L .62153 .48429 L p
1 g
F P
s
P
p
.002 w
.56639 .31252 m .53214 .30028 L .52911 .32323 L p
1 g
F P
s
P
p
.002 w
.52911 .32323 m .55529 .3326 L .56639 .31252 L p
1 g
F P
s
P
p
.002 w
.55529 .3326 m .57704 .34994 L .59483 .33521 L p
1 g
F P
s
P
p
.002 w
.61427 .36579 m .59483 .33521 L .57704 .34994 L p
1 g
F P
s
P
p
.002 w
.59483 .33521 m .56639 .31252 L .55529 .3326 L p
1 g
F P
s
P
p
.002 w
.35898 .39903 m .36359 .44814 L .3851 .44011 L p
1 g
F P
s
P
p
.002 w
.3851 .44011 m .38121 .39754 L .35898 .39903 L p
1 g
F P
s
P
p
.002 w
.50874 .56298 m .55764 .55641 L .5533 .53394 L p
1 g
F P
s
P
p
.002 w
.59154 .51485 m .5533 .53394 L .55764 .55641 L p
1 g
F P
s
P
p
.002 w
.44898 .29339 m .41477 .31991 L .43363 .33297 L p
1 g
F P
s
P
p
.002 w
.43363 .33297 m .46186 .31121 L .44898 .29339 L p
1 g
F P
s
P
p
.002 w
.62153 .48429 m .63987 .44539 L .61896 .43628 L p
1 g
F P
s
P
p
.002 w
.62258 .40079 m .61896 .43628 L .63987 .44539 L p
1 g
F P
s
P
p
.002 w
.37061 .35101 m .35898 .39903 L .38121 .39754 L p
1 g
F P
s
P
p
.002 w
.38121 .39754 m .39139 .35597 L .37061 .35101 L p
1 g
F P
s
P
p
.002 w
.55764 .55641 m .60182 .53448 L .59154 .51485 L p
1 g
F P
s
P
p
.002 w
.62153 .48429 m .59154 .51485 L .60182 .53448 L p
1 g
F P
s
P
p
.002 w
.4904 .2795 m .44898 .29339 L .46186 .31121 L p
1 g
F P
s
P
p
.002 w
.46186 .31121 m .49594 .29986 L .4904 .2795 L p
1 g
F P
s
P
p
.002 w
.63987 .44539 m .64439 .40228 L .62258 .40079 L p
1 g
F P
s
P
p
.002 w
.61427 .36579 m .62258 .40079 L .64439 .40228 L p
1 g
F P
s
P
p
.002 w
.36733 .506 m .40445 .54643 L .41707 .52961 L p
1 g
F P
s
P
p
.002 w
.41707 .52961 m .3837 .49319 L .36733 .506 L p
1 g
F P
s
P
p
.002 w
.46023 .5537 m .41707 .52961 L .40445 .54643 L p
1 g
F P
s
P
p
.002 w
.40445 .54643 m .45239 .57319 L .46023 .5537 L p
1 g
F P
s
P
p
.002 w
.50874 .56298 m .46023 .5537 L .45239 .57319 L p
1 g
F P
s
P
p
.002 w
.53444 .27996 m .4904 .2795 L .49594 .29986 L p
1 g
F P
s
P
p
.002 w
.49594 .29986 m .53214 .30028 L .53444 .27996 L p
1 g
F P
s
P
p
.002 w
.64439 .40228 m .63436 .35971 L .61427 .36579 L p
1 g
F P
s
P
p
.002 w
.59483 .33521 m .61427 .36579 L .63436 .35971 L p
1 g
F P
s
P
p
.002 w
.39751 .30928 m .37061 .35101 L .39139 .35597 L p
1 g
F P
s
P
p
.002 w
.39139 .35597 m .41477 .31991 L .39751 .30928 L p
1 g
F P
s
P
p
.002 w
.3449 .45596 m .36733 .506 L .3837 .49319 L p
1 g
F P
s
P
p
.002 w
.3837 .49319 m .36359 .44814 L .3449 .45596 L p
1 g
F P
s
P
p
.002 w
.45239 .57319 m .50628 .58356 L .50874 .56298 L p
1 g
F P
s
P
p
.002 w
.55764 .55641 m .50874 .56298 L .50628 .58356 L p
1 g
F P
s
P
p
.002 w
.60182 .53448 m .63653 .49929 L .62153 .48429 L p
1 g
F P
s
P
p
.002 w
.63987 .44539 m .62153 .48429 L .63653 .49929 L p
1 g
F P
s
P
p
.002 w
.57614 .29484 m .53444 .27996 L .53214 .30028 L p
1 g
F P
s
P
p
.002 w
.53214 .30028 m .56639 .31252 L .57614 .29484 L p
1 g
F P
s
P
p
.002 w
.56639 .31252 m .59483 .33521 L .61075 .32247 L p
1 g
F P
s
P
p
.002 w
.63436 .35971 m .61075 .32247 L .59483 .33521 L p
1 g
F P
s
P
p
.002 w
.61075 .32247 m .57614 .29484 L .56639 .31252 L p
1 g
F P
s
P
p
.002 w
.33967 .40138 m .3449 .45596 L .36359 .44814 L p
1 g
F P
s
P
p
.002 w
.36359 .44814 m .35898 .39903 L .33967 .40138 L p
1 g
F P
s
P
p
.002 w
.50628 .58356 m .56064 .57634 L .55764 .55641 L p
1 g
F P
s
P
p
.002 w
.60182 .53448 m .55764 .55641 L .56064 .57634 L p
1 g
F P
s
P
p
.002 w
.437 .27852 m .39751 .30928 L .41477 .31991 L p
1 g
F P
s
P
p
.002 w
.41477 .31991 m .44898 .29339 L .437 .27852 L p
1 g
F P
s
P
p
.002 w
.63653 .49929 m .65785 .4544 L .63987 .44539 L p
1 g
F P
s
P
p
.002 w
.64439 .40228 m .63987 .44539 L .65785 .4544 L p
1 g
F P
s
P
p
.002 w
.35248 .34795 m .33967 .40138 L .35898 .39903 L p
1 g
F P
s
P
p
.002 w
.35898 .39903 m .37061 .35101 L .35248 .34795 L p
1 g
F P
s
P
p
.002 w
.56064 .57634 m .60981 .55207 L .60182 .53448 L p
1 g
F P
s
P
p
.002 w
.63653 .49929 m .60182 .53448 L .60981 .55207 L p
1 g
F P
s
P
p
.002 w
.48491 .26237 m .437 .27852 L .44898 .29339 L p
1 g
F P
s
P
p
.002 w
.44898 .29339 m .4904 .2795 L .48491 .26237 L p
1 g
F P
s
P
p
.002 w
.65785 .4544 m .66318 .40455 L .64439 .40228 L p
1 g
F P
s
P
p
.002 w
.63436 .35971 m .64439 .40228 L .66318 .40455 L p
1 g
F P
s
P
p
.002 w
.35383 .51729 m .39386 .56083 L .40445 .54643 L p
1 g
F P
s
P
p
.002 w
.40445 .54643 m .36733 .506 L .35383 .51729 L p
1 g
F P
s
P
p
.002 w
.45239 .57319 m .40445 .54643 L .39386 .56083 L p
1 g
F P
s
P
p
.002 w
.39386 .56083 m .44552 .58967 L .45239 .57319 L p
1 g
F P
s
P
p
.002 w
.50628 .58356 m .45239 .57319 L .44552 .58967 L p
1 g
F P
s
P
p
.002 w
.53593 .26284 m .48491 .26237 L .4904 .2795 L p
1 g
F P
s
P
p
.002 w
.4904 .2795 m .53444 .27996 L .53593 .26284 L p
1 g
F P
s
P
p
.002 w
.38232 .30144 m .35248 .34795 L .37061 .35101 L p
1 g
F P
s
P
p
.002 w
.37061 .35101 m .39751 .30928 L .38232 .30144 L p
1 g
F P
s
P
p
.002 w
.66318 .40455 m .65165 .35525 L .63436 .35971 L p
1 g
F P
s
P
p
.002 w
.61075 .32247 m .63436 .35971 L .65165 .35525 L p
1 g
F P
s
P
p
.002 w
.3296 .46339 m .35383 .51729 L .36733 .506 L p
1 g
F P
s
P
p
.002 w
.36733 .506 m .3449 .45596 L .3296 .46339 L p
1 g
F P
s
P
p
.002 w
.60981 .55207 m .64851 .51302 L .63653 .49929 L p
1 g
F P
s
P
p
.002 w
.65785 .4544 m .63653 .49929 L .64851 .51302 L p
1 g
F P
s
P
p
.002 w
.44552 .58967 m .50358 .60088 L .50628 .58356 L p
1 g
F P
s
P
p
.002 w
.56064 .57634 m .50628 .58356 L .50358 .60088 L p
1 g
F P
s
P
p
.002 w
.58425 .28006 m .53593 .26284 L .53444 .27996 L p
1 g
F P
s
P
p
.002 w
.53444 .27996 m .57614 .29484 L .58425 .28006 L p
1 g
F P
s
P
p
.002 w
.57614 .29484 m .61075 .32247 L .62435 .31209 L p
1 g
F P
s
P
p
.002 w
.65165 .35525 m .62435 .31209 L .61075 .32247 L p
1 g
F P
s
P
p
.002 w
.62435 .31209 m .58425 .28006 L .57614 .29484 L p
1 g
F P
s
P
p
.002 w
.32386 .40458 m .3296 .46339 L .3449 .45596 L p
1 g
F P
s
P
p
.002 w
.3449 .45596 m .33967 .40138 L .32386 .40458 L p
1 g
F P
s
P
p
.002 w
.50358 .60088 m .56216 .59318 L .56064 .57634 L p
1 g
F P
s
P
p
.002 w
.60981 .55207 m .56064 .57634 L .56216 .59318 L p
1 g
F P
s
P
p
.002 w
.42624 .2671 m .38232 .30144 L .39751 .30928 L p
1 g
F P
s
P
p
.002 w
.39751 .30928 m .437 .27852 L .42624 .2671 L p
1 g
F P
s
P
p
.002 w
.64851 .51302 m .67234 .4631 L .65785 .4544 L p
1 g
F P
s
P
p
.002 w
.66318 .40455 m .65785 .4544 L .67234 .4631 L p
1 g
F P
s
P
p
.002 w
.33757 .34695 m .32386 .40458 L .33967 .40138 L p
1 g
F P
s
P
p
.002 w
.33967 .40138 m .35248 .34795 L .33757 .34695 L p
1 g
F P
s
P
p
.002 w
.56216 .59318 m .61521 .56711 L .60981 .55207 L p
1 g
F P
s
P
p
.002 w
.64851 .51302 m .60981 .55207 L .61521 .56711 L p
1 g
F P
s
P
p
.002 w
.47962 .24902 m .42624 .2671 L .437 .27852 L p
1 g
F P
s
P
p
.002 w
.437 .27852 m .48491 .26237 L .47962 .24902 L p
1 g
F P
s
P
p
.002 w
.67234 .4631 m .67837 .40759 L .66318 .40455 L p
1 g
F P
s
P
p
.002 w
.65165 .35525 m .66318 .40455 L .67837 .40759 L p
1 g
F P
s
P
p
.002 w
.34368 .52671 m .38567 .57233 L .39386 .56083 L p
1 g
F P
s
P
p
.002 w
.39386 .56083 m .35383 .51729 L .34368 .52671 L p
1 g
F P
s
P
p
.002 w
.44552 .58967 m .39386 .56083 L .38567 .57233 L p
1 g
F P
s
P
p
.002 w
.38567 .57233 m .43982 .60257 L .44552 .58967 L p
1 g
F P
s
P
p
.002 w
.50358 .60088 m .44552 .58967 L .43982 .60257 L p
1 g
F P
s
P
p
.002 w
.53652 .2495 m .47962 .24902 L .48491 .26237 L p
1 g
F P
s
P
p
.002 w
.48491 .26237 m .53593 .26284 L .53652 .2495 L p
1 g
F P
s
P
p
.002 w
.36967 .29672 m .33757 .34695 L .35248 .34795 L p
1 g
F P
s
P
p
.002 w
.35248 .34795 m .38232 .30144 L .36967 .29672 L p
1 g
F P
s
P
p
.002 w
.67837 .40759 m .6656 .35262 L .65165 .35525 L p
1 g
F P
s
P
p
.002 w
.62435 .31209 m .65165 .35525 L .6656 .35262 L p
1 g
F P
s
P
p
.002 w
.61521 .56711 m .65701 .52508 L .64851 .51302 L p
1 g
F P
s
P
p
.002 w
.67234 .4631 m .64851 .51302 L .65701 .52508 L p
1 g
F P
s
P
p
.002 w
.31822 .47025 m .34368 .52671 L .35383 .51729 L p
1 g
F P
s
P
p
.002 w
.35383 .51729 m .3296 .46339 L .31822 .47025 L p
1 g
F P
s
P
p
.002 w
.43982 .60257 m .50068 .61436 L .50358 .60088 L p
1 g
F P
s
P
p
.002 w
.56216 .59318 m .50358 .60088 L .50068 .61436 L p
1 g
F P
s
P
p
.002 w
.59045 .26869 m .53652 .2495 L .53593 .26284 L p
1 g
F P
s
P
p
.002 w
.53593 .26284 m .58425 .28006 L .59045 .26869 L p
1 g
F P
s
P
p
.002 w
.58425 .28006 m .62435 .31209 L .63518 .30445 L p
1 g
F P
s
P
p
.002 w
.6656 .35262 m .63518 .30445 L .62435 .31209 L p
1 g
F P
s
P
p
.002 w
.63518 .30445 m .59045 .26869 L .58425 .28006 L p
1 g
F P
s
P
p
.002 w
.31213 .4086 m .31822 .47025 L .3296 .46339 L p
1 g
F P
s
P
p
.002 w
.3296 .46339 m .32386 .40458 L .31213 .4086 L p
1 g
F P
s
P
p
.002 w
.50068 .61436 m .5621 .60635 L .56216 .59318 L p
1 g
F P
s
P
p
.002 w
.61521 .56711 m .56216 .59318 L .5621 .60635 L p
1 g
F P
s
P
p
.002 w
.41703 .25959 m .36967 .29672 L .38232 .30144 L p
1 g
F P
s
P
p
.002 w
.38232 .30144 m .42624 .2671 L .41703 .25959 L p
1 g
F P
s
P
p
.002 w
.65701 .52508 m .68281 .47127 L .67234 .4631 L p
1 g
F P
s
P
p
.002 w
.67837 .40759 m .67234 .4631 L .68281 .47127 L p
1 g
F P
s
P
p
.002 w
.32643 .34815 m .31213 .4086 L .32386 .40458 L p
1 g
F P
s
P
p
.002 w
.32386 .40458 m .33757 .34695 L .32643 .34815 L p
1 g
F P
s
P
p
.002 w
.5621 .60635 m .61774 .5791 L .61521 .56711 L p
1 g
F P
s
P
p
.002 w
.65701 .52508 m .61521 .56711 L .61774 .5791 L p
1 g
F P
s
P
p
.002 w
.47465 .24001 m .41703 .25959 L .42624 .2671 L p
1 g
F P
s
P
p
.002 w
.42624 .2671 m .47962 .24902 L .47465 .24001 L p
1 g
F P
s
P
p
.002 w
.68281 .47127 m .6894 .41136 L .67837 .40759 L p
1 g
F P
s
P
p
.002 w
.6656 .35262 m .67837 .40759 L .6894 .41136 L p
1 g
F P
s
P
p
.002 w
.33733 .53394 m .38022 .5805 L .38567 .57233 L p
1 g
F P
s
P
p
.002 w
.38567 .57233 m .34368 .52671 L .33733 .53394 L p
1 g
F P
s
P
p
.002 w
.43982 .60257 m .38567 .57233 L .38022 .5805 L p
1 g
F P
s
P
p
.002 w
.38022 .5805 m .43551 .61137 L .43982 .60257 L p
1 g
F P
s
P
p
.002 w
.50068 .61436 m .43982 .60257 L .43551 .61137 L p
1 g
F P
s
P
p
.002 w
.53615 .24049 m .47465 .24001 L .47962 .24902 L p
1 g
F P
s
P
p
.002 w
.47962 .24902 m .53652 .2495 L .53615 .24049 L p
1 g
F P
s
P
p
.002 w
.36003 .29544 m .32643 .34815 L .33757 .34695 L p
1 g
F P
s
P
p
.002 w
.33757 .34695 m .36967 .29672 L .36003 .29544 L p
1 g
F P
s
P
p
.002 w
.6894 .41136 m .67565 .35197 L .6656 .35262 L p
1 g
F P
s
P
p
.002 w
.63518 .30445 m .6656 .35262 L .67565 .35197 L p
1 g
F P
s
P
p
.002 w
.61774 .5791 m .66162 .53508 L .65701 .52508 L p
1 g
F P
s
P
p
.002 w
.68281 .47127 m .65701 .52508 L .66162 .53508 L p
1 g
F P
s
P
p
.002 w
.3113 .4763 m .33733 .53394 L .34368 .52671 L p
1 g
F P
s
P
p
.002 w
.34368 .52671 m .31822 .47025 L .3113 .4763 L p
1 g
F P
s
P
p
.002 w
.43551 .61137 m .49764 .62343 L .50068 .61436 L p
1 g
F P
s
P
p
.002 w
.5621 .60635 m .50068 .61436 L .49764 .62343 L p
1 g
F P
s
P
p
.002 w
.59445 .26123 m .53615 .24049 L .53652 .2495 L p
1 g
F P
s
P
p
.002 w
.53652 .2495 m .59045 .26869 L .59445 .26123 L p
1 g
F P
s
P
p
.002 w
.59045 .26869 m .63518 .30445 L .64281 .29989 L p
1 g
F P
s
P
p
.002 w
.67565 .35197 m .64281 .29989 L .63518 .30445 L p
1 g
F P
s
P
p
.002 w
.64281 .29989 m .59445 .26123 L .59045 .26869 L p
1 g
F P
s
P
p
.002 w
.30504 .41338 m .3113 .4763 L .31822 .47025 L p
1 g
F P
s
P
p
.002 w
.31822 .47025 m .31213 .4086 L .30504 .41338 L p
1 g
F P
s
P
p
.002 w
.49764 .62343 m .56034 .61531 L .5621 .60635 L p
1 g
F P
s
P
p
.002 w
.61774 .5791 m .5621 .60635 L .56034 .61531 L p
1 g
F P
s
P
p
.002 w
.40969 .25644 m .36003 .29544 L .36967 .29672 L p
1 g
F P
s
P
p
.002 w
.36967 .29672 m .41703 .25959 L .40969 .25644 L p
1 g
F P
s
P
p
.002 w
.66162 .53508 m .68874 .47868 L .68281 .47127 L p
1 g
F P
s
P
p
.002 w
.6894 .41136 m .68281 .47127 L .68874 .47868 L p
1 g
F P
s
P
p
.002 w
.31958 .35167 m .30504 .41338 L .31213 .4086 L p
1 g
F P
s
P
p
.002 w
.31213 .4086 m .32643 .34815 L .31958 .35167 L p
1 g
F P
s
P
p
.002 w
.56034 .61531 m .61716 .58753 L .61774 .5791 L p
1 g
F P
s
P
p
.002 w
.66162 .53508 m .61774 .5791 L .61716 .58753 L p
1 g
F P
s
P
p
.002 w
.47018 .23585 m .40969 .25644 L .41703 .25959 L p
1 g
F P
s
P
p
.002 w
.41703 .25959 m .47465 .24001 L .47018 .23585 L p
1 g
F P
s
P
p
.002 w
.68874 .47868 m .69571 .41582 L .6894 .41136 L p
1 g
F P
s
P
p
.002 w
.67565 .35197 m .6894 .41136 L .69571 .41582 L p
1 g
F P
s
P
p
.002 w
.33519 .53862 m .37782 .58489 L .38022 .5805 L p
1 g
F P
s
P
p
.002 w
.38022 .5805 m .33733 .53394 L .33519 .53862 L p
1 g
F P
s
P
p
.002 w
.43551 .61137 m .38022 .5805 L .37782 .58489 L p
1 g
F P
s
P
p
.002 w
.37782 .58489 m .43278 .61558 L .43551 .61137 L p
1 g
F P
s
P
p
.002 w
.49764 .62343 m .43551 .61137 L .43278 .61558 L p
1 g
F P
s
P
p
.002 w
.35385 .29785 m .31958 .35167 L .32643 .34815 L p
1 g
F P
s
P
p
.002 w
.32643 .34815 m .36003 .29544 L .35385 .29785 L p
1 g
F P
s
P
p
.002 w
.53476 .23634 m .47018 .23585 L .47465 .24001 L p
1 g
F P
s
P
p
.002 w
.47465 .24001 m .53615 .24049 L .53476 .23634 L p
1 g
F P
s
P
p
.002 w
.69571 .41582 m .68131 .35346 L .67565 .35197 L p
1 g
F P
s
P
p
.002 w
.64281 .29989 m .67565 .35197 L .68131 .35346 L p
1 g
F P
s
P
p
.002 w
.61716 .58753 m .66199 .54263 L .66162 .53508 L p
1 g
F P
s
P
p
.002 w
.68874 .47868 m .66162 .53508 L .66199 .54263 L p
1 g
F P
s
P
p
.002 w
.30931 .48136 m .33519 .53862 L .33733 .53394 L p
1 g
F P
s
P
p
.002 w
.33733 .53394 m .3113 .4763 L .30931 .48136 L p
1 g
F P
s
P
p
.002 w
.43278 .61558 m .49453 .62758 L .49764 .62343 L p
1 g
F P
s
P
p
.002 w
.56034 .61531 m .49764 .62343 L .49453 .62758 L p
1 g
F P
s
P
p
.002 w
.59602 .25812 m .53476 .23634 L .53615 .24049 L p
1 g
F P
s
P
p
.002 w
.53615 .24049 m .59445 .26123 L .59602 .25812 L p
1 g
F P
s
P
p
.002 w
.59445 .26123 m .64281 .29989 L .64682 .29875 L p
1 g
F P
s
P
p
.002 w
.68131 .35346 m .64682 .29875 L .64281 .29989 L p
1 g
F P
s
P
p
.002 w
.64682 .29875 m .59602 .25812 L .59445 .26123 L p
1 g
F P
s
P
p
.002 w
.30306 .41885 m .30931 .48136 L .3113 .4763 L p
1 g
F P
s
P
p
.002 w
.3113 .4763 m .30504 .41338 L .30306 .41885 L p
1 g
F P
s
P
p
.002 w
.49453 .62758 m .55684 .61952 L .56034 .61531 L p
1 g
F P
s
P
p
.002 w
.61716 .58753 m .56034 .61531 L .55684 .61952 L p
1 g
F P
s
P
p
.002 w
.40455 .25801 m .35385 .29785 L .36003 .29544 L p
1 g
F P
s
P
p
.002 w
.36003 .29544 m .40969 .25644 L .40455 .25801 L p
1 g
F P
s
P
p
.002 w
.66199 .54263 m .6897 .48507 L .68874 .47868 L p
1 g
F P
s
P
p
.002 w
.69571 .41582 m .68874 .47868 L .6897 .48507 L p
1 g
F P
s
P
p
.004 w
.70754 .39531 m
.72456 .39242 L
s
P
p
.004 w
.72456 .39242 m
.74294 .3893 L
s
P
p
.002 w
.31751 .35756 m .30306 .41885 L .30504 .41338 L p
1 g
F P
s
P
p
.002 w
.30504 .41338 m .31958 .35167 L .31751 .35756 L p
1 g
F P
s
P
p
.002 w
.55684 .61952 m .61329 .59195 L .61716 .58753 L p
1 g
F P
s
P
p
.002 w
.66199 .54263 m .61716 .58753 L .61329 .59195 L p
1 g
F P
s
P
p
.002 w
.46634 .23698 m .40455 .25801 L .40969 .25644 L p
1 g
F P
s
P
p
.002 w
.40969 .25644 m .47018 .23585 L .46634 .23698 L p
1 g
F P
s
P
p
.002 w
.6897 .48507 m .69683 .42088 L .69571 .41582 L p
1 g
F P
s
P
p
.002 w
.68131 .35346 m .69571 .41582 L .69683 .42088 L p
1 g
F P
s
P
p
.002 w
.33759 .54047 m .37875 .58514 L .37782 .58489 L p
1 g
F P
s
P
p
.002 w
.37782 .58489 m .33519 .53862 L .33759 .54047 L p
1 g
F P
s
P
p
.002 w
.43278 .61558 m .37782 .58489 L .37875 .58514 L p
1 g
F P
s
P
p
.002 w
.35155 .30412 m .31751 .35756 L .31958 .35167 L p
1 g
F P
s
P
p
.002 w
.31958 .35167 m .35385 .29785 L .35155 .30412 L p
1 g
F P
s
P
p
.002 w
.37875 .58514 m .43182 .61477 L .43278 .61558 L p
1 g
F P
s
P
p
.002 w
.49453 .62758 m .43278 .61558 L .43182 .61477 L p
1 g
F P
s
P
p
.002 w
.53233 .23749 m .46634 .23698 L .47018 .23585 L p
1 g
F P
s
P
p
.002 w
.47018 .23585 m .53476 .23634 L .53233 .23749 L p
1 g
F P
s
P
p
.002 w
.69683 .42088 m .68211 .35718 L .68131 .35346 L p
1 g
F P
s
P
p
.002 w
.64682 .29875 m .68131 .35346 L .68211 .35718 L p
1 g
F P
s
P
p
.002 w
.61329 .59195 m .65781 .54736 L .66199 .54263 L p
1 g
F P
s
P
p
.002 w
.6897 .48507 m .66199 .54263 L .65781 .54736 L p
1 g
F P
s
P
p
.002 w
.31262 .4852 m .33759 .54047 L .33519 .53862 L p
1 g
F P
s
P
p
.002 w
.33519 .53862 m .30931 .48136 L .31262 .4852 L p
1 g
F P
s
P
p
.002 w
.43182 .61477 m .49144 .62636 L .49453 .62758 L p
1 g
F P
s
P
p
.002 w
.55684 .61952 m .49453 .62758 L .49144 .62636 L p
1 g
F P
s
P
p
.002 w
.59494 .25976 m .53233 .23749 L .53476 .23634 L p
1 g
F P
s
P
p
.002 w
.53476 .23634 m .59602 .25812 L .59494 .25976 L p
1 g
F P
s
P
p
.002 w
.68211 .35718 m .64687 .30128 L .64682 .29875 L p
1 g
F P
s
P
p
.002 w
.59602 .25812 m .64682 .29875 L .64687 .30128 L p
1 g
F P
s
P
p
.002 w
.64687 .30128 m .59494 .25976 L .59602 .25812 L p
1 g
F P
s
P
p
.002 w
.30661 .42489 m .31262 .4852 L .30931 .48136 L p
1 g
F P
s
P
p
.002 w
.30931 .48136 m .30306 .41885 L .30661 .42489 L p
1 g
F P
s
P
p
.002 w
.49144 .62636 m .55158 .61858 L .55684 .61952 L p
1 g
F P
s
P
p
.002 w
.61329 .59195 m .55684 .61952 L .55158 .61858 L p
1 g
F P
s
P
p
.002 w
.40191 .26458 m .35155 .30412 L .35385 .29785 L p
1 g
F P
s
P
p
.002 w
.35385 .29785 m .40455 .25801 L .40191 .26458 L p
1 g
F P
s
P
p
.002 w
.65781 .54736 m .68532 .49019 L .6897 .48507 L p
1 g
F P
s
P
p
.002 w
.69683 .42088 m .6897 .48507 L .68532 .49019 L p
1 g
F P
s
P
p
.002 w
.32058 .36581 m .30661 .42489 L .30306 .41885 L p
1 g
F P
s
P
p
.002 w
.30306 .41885 m .31751 .35756 L .32058 .36581 L p
1 g
F P
s
P
p
.002 w
.55158 .61858 m .60602 .59196 L .61329 .59195 L p
1 g
F P
s
P
p
.002 w
.65781 .54736 m .61329 .59195 L .60602 .59196 L p
1 g
F P
s
P
p
.002 w
.4633 .24372 m .40191 .26458 L .40455 .25801 L p
1 g
F P
s
P
p
.002 w
.40455 .25801 m .46634 .23698 L .4633 .24372 L p
1 g
F P
s
P
p
.002 w
.68532 .49019 m .69237 .42644 L .69683 .42088 L p
1 g
F P
s
P
p
.002 w
.68211 .35718 m .69683 .42088 L .69237 .42644 L p
1 g
F P
s
P
p
.002 w
.35344 .31432 m .32058 .36581 L .31751 .35756 L p
1 g
F P
s
P
p
.002 w
.31751 .35756 m .35155 .30412 L .35344 .31432 L p
1 g
F P
s
P
p
.002 w
.34478 .53923 m .38321 .58096 L .37875 .58514 L p
1 g
F P
s
P
p
.002 w
.37875 .58514 m .33759 .54047 L .34478 .53923 L p
1 g
F P
s
P
p
.002 w
.43182 .61477 m .37875 .58514 L .38321 .58096 L p
1 g
F P
s
P
p
.002 w
.38321 .58096 m .43278 .60864 L .43182 .61477 L p
1 g
F P
s
P
p
.002 w
.49144 .62636 m .43182 .61477 L .43278 .60864 L p
1 g
F P
s
P
p
.002 w
.52887 .24426 m .4633 .24372 L .46634 .23698 L p
1 g
F P
s
P
p
.002 w
.46634 .23698 m .53233 .23749 L .52887 .24426 L p
1 g
F P
s
P
p
.002 w
.60602 .59196 m .64892 .54894 L .65781 .54736 L p
1 g
F P
s
P
p
.002 w
.68532 .49019 m .65781 .54736 L .64892 .54894 L p
1 g
F P
s
P
p
.002 w
.69237 .42644 m .67772 .36317 L .68211 .35718 L p
1 g
F P
s
P
p
.002 w
.64687 .30128 m .68211 .35718 L .67772 .36317 L p
1 g
F P
s
P
p
.002 w
.32149 .48762 m .34478 .53923 L .33759 .54047 L p
1 g
F P
s
P
p
.002 w
.33759 .54047 m .31262 .4852 L .32149 .48762 L p
1 g
F P
s
P
p
.002 w
.43278 .60864 m .48846 .61945 L .49144 .62636 L p
1 g
F P
s
P
p
.002 w
.55158 .61858 m .49144 .62636 L .48846 .61945 L p
1 g
F P
s
P
p
.002 w
.59108 .26639 m .52887 .24426 L .53233 .23749 L p
1 g
F P
s
P
p
.002 w
.53233 .23749 m .59494 .25976 L .59108 .26639 L p
1 g
F P
s
P
p
.002 w
.67772 .36317 m .64268 .30764 L .64687 .30128 L p
1 g
F P
s
P
p
.002 w
.59494 .25976 m .64687 .30128 L .64268 .30764 L p
1 g
F P
s
P
p
.002 w
.64268 .30764 m .59108 .26639 L .59494 .25976 L p
1 g
F P
s
P
p
.002 w
.31594 .43136 m .32149 .48762 L .31262 .4852 L p
1 g
F P
s
P
p
.002 w
.31262 .4852 m .30661 .42489 L .31594 .43136 L p
1 g
F P
s
P
p
.002 w
.48846 .61945 m .54459 .61215 L .55158 .61858 L p
1 g
F P
s
P
p
.002 w
.60602 .59196 m .55158 .61858 L .54459 .61215 L p
1 g
F P
s
P
p
.002 w
.40202 .27627 m .35344 .31432 L .35155 .30412 L p
1 g
F P
s
P
p
.002 w
.35155 .30412 m .40191 .26458 L .40202 .27627 L p
1 g
F P
s
P
p
.002 w
.64892 .54894 m .67538 .4938 L .68532 .49019 L p
1 g
F P
s
P
p
.002 w
.69237 .42644 m .68532 .49019 L .67538 .4938 L p
1 g
F P
s
P
p
.002 w
.32903 .37629 m .31594 .43136 L .30661 .42489 L p
1 g
F P
s
P
p
.002 w
.30661 .42489 m .32058 .36581 L .32903 .37629 L p
1 g
F P
s
P
p
.002 w
.54459 .61215 m .59535 .58727 L .60602 .59196 L p
1 g
F P
s
P
p
.002 w
.64892 .54894 m .60602 .59196 L .59535 .58727 L p
1 g
F P
s
P
p
.002 w
.4612 .25622 m .40202 .27627 L .40191 .26458 L p
1 g
F P
s
P
p
.002 w
.40191 .26458 m .4633 .24372 L .4612 .25622 L p
1 g
F P
s
P
p
.002 w
.67538 .4938 m .68211 .43236 L .69237 .42644 L p
1 g
F P
s
P
p
.002 w
.67772 .36317 m .69237 .42644 L .68211 .43236 L p
1 g
F P
s
P
p
.004 w
.68391 .39931 m
.69132 .39806 L
s
P
p
.004 w
.69132 .39806 m
.70754 .39531 L
s
P
p
.002 w
.35973 .32836 m .32903 .37629 L .32058 .36581 L p
1 g
F P
s
P
p
.002 w
.32058 .36581 m .35344 .31432 L .35973 .32836 L p
1 g
F P
s
P
p
.002 w
.35683 .53475 m .39128 .5722 L .38321 .58096 L p
1 g
F P
s
P
p
.002 w
.38321 .58096 m .34478 .53923 L .35683 .53475 L p
1 g
F P
s
P
p
.002 w
.43278 .60864 m .38321 .58096 L .39128 .5722 L p
1 g
F P
s
P
p
.002 w
.39128 .5722 m .43575 .59702 L .43278 .60864 L p
1 g
F P
s
P
p
.002 w
.48846 .61945 m .43278 .60864 L .43575 .59702 L p
1 g
F P
s
P
p
.002 w
.5244 .25679 m .4612 .25622 L .4633 .24372 L p
1 g
F P
s
P
p
.002 w
.4633 .24372 m .52887 .24426 L .5244 .25679 L p
1 g
F P
s
P
p
.002 w
.59535 .58727 m .63529 .54711 L .64892 .54894 L p
1 g
F P
s
P
p
.002 w
.67538 .4938 m .64892 .54894 L .63529 .54711 L p
1 g
F P
s
P
p
.002 w
.68211 .43236 m .66792 .37139 L .67772 .36317 L p
1 g
F P
s
P
p
.002 w
.64268 .30764 m .67772 .36317 L .66792 .37139 L p
1 g
F P
s
P
p
.002 w
.336 .48847 m .35683 .53475 L .34478 .53923 L p
1 g
F P
s
P
p
.002 w
.34478 .53923 m .32149 .48762 L .336 .48847 L p
1 g
F P
s
P
p
.002 w
.43575 .59702 m .48569 .60669 L .48846 .61945 L p
1 g
F P
s
P
p
.002 w
.54459 .61215 m .48846 .61945 L .48569 .60669 L p
1 g
F P
s
P
p
.002 w
.58436 .27814 m .5244 .25679 L .52887 .24426 L p
1 g
F P
s
P
p
.002 w
.52887 .24426 m .59108 .26639 L .58436 .27814 L p
1 g
F P
s
P
p
.002 w
.66792 .37139 m .63411 .3179 L .64268 .30764 L p
1 g
F P
s
P
p
.002 w
.59108 .26639 m .64268 .30764 L .63411 .3179 L p
1 g
F P
s
P
p
.002 w
.63411 .3179 m .58436 .27814 L .59108 .26639 L p
1 g
F P
s
P
p
.002 w
.3311 .43806 m .336 .48847 L .32149 .48762 L p
1 g
F P
s
P
p
.002 w
.32149 .48762 m .31594 .43136 L .3311 .43806 L p
1 g
F P
s
P
p
.002 w
.40504 .293 m .35973 .32836 L .35344 .31432 L p
1 g
F P
s
P
p
.002 w
.35344 .31432 m .40202 .27627 L .40504 .293 L p
1 g
F P
s
P
p
.002 w
.48569 .60669 m .53599 .60009 L .54459 .61215 L p
1 g
F P
s
P
p
.002 w
.59535 .58727 m .54459 .61215 L .53599 .60009 L p
1 g
F P
s
P
p
.002 w
.63529 .54711 m .65985 .4957 L .67538 .4938 L p
1 g
F P
s
P
p
.002 w
.68211 .43236 m .67538 .4938 L .65985 .4957 L p
1 g
F P
s
P
p
.002 w
.34292 .3888 m .3311 .43806 L .31594 .43136 L p
1 g
F P
s
P
p
.002 w
.31594 .43136 m .32903 .37629 L .34292 .3888 L p
1 g
F P
s
P
p
.002 w
.53599 .60009 m .58142 .57774 L .59535 .58727 L p
1 g
F P
s
P
p
.002 w
.63529 .54711 m .59535 .58727 L .58142 .57774 L p
1 g
F P
s
P
p
.002 w
.46018 .27443 m .40504 .293 L .40202 .27627 L p
1 g
F P
s
P
p
.002 w
.40202 .27627 m .4612 .25622 L .46018 .27443 L p
1 g
F P
s
P
p
.002 w
.65985 .4957 m .66602 .43846 L .68211 .43236 L p
1 g
F P
s
P
p
.002 w
.66792 .37139 m .68211 .43236 L .66602 .43846 L p
1 g
F P
s
P
p
.004 w
.67123 .40147 m
.68391 .39931 L
s
P
p
.002 w
.37047 .34601 m .34292 .3888 L .32903 .37629 L p
1 g
F P
s
P
p
.002 w
.32903 .37629 m .35973 .32836 L .37047 .34601 L p
1 g
F P
s
P
p
.002 w
.58142 .57774 m .61708 .54173 L .63529 .54711 L p
1 g
F P
s
P
p
.002 w
.65985 .4957 m .63529 .54711 L .61708 .54173 L p
1 g
F P
s
P
p
.002 w
.37364 .52697 m .40292 .55884 L .39128 .5722 L p
1 g
F P
s
P
p
.002 w
.39128 .5722 m .35683 .53475 L .37364 .52697 L p
1 g
F P
s
P
p
.002 w
.43575 .59702 m .39128 .5722 L .40292 .55884 L p
1 g
F P
s
P
p
.002 w
.51903 .27503 m .46018 .27443 L .4612 .25622 L p
1 g
F P
s
P
p
.002 w
.4612 .25622 m .5244 .25679 L .51903 .27503 L p
1 g
F P
s
P
p
.002 w
.40292 .55884 m .44075 .57996 L .43575 .59702 L p
1 g
F P
s
P
p
.002 w
.48569 .60669 m .43575 .59702 L .44075 .57996 L p
1 g
F P
s
P
p
.002 w
.66602 .43846 m .65272 .38171 L .66792 .37139 L p
1 g
F P
s
P
p
.002 w
.63411 .3179 m .66792 .37139 L .65272 .38171 L p
1 g
F P
s
P
p
.002 w
.35599 .4876 m .37364 .52697 L .35683 .53475 L p
1 g
F P
s
P
p
.002 w
.35683 .53475 m .336 .48847 L .35599 .4876 L p
1 g
F P
s
P
p
.002 w
.44075 .57996 m .48324 .58815 L .48569 .60669 L p
1 g
F P
s
P
p
.002 w
.53599 .60009 m .48569 .60669 L .48324 .58815 L p
1 g
F P
s
P
p
.002 w
.57485 .29493 m .51903 .27503 L .5244 .25679 L p
1 g
F P
s
P
p
.002 w
.5244 .25679 m .58436 .27814 L .57485 .29493 L p
1 g
F P
s
P
p
.002 w
.58436 .27814 m .63411 .3179 L .62118 .33193 L p
1 g
F P
s
P
p
.002 w
.65272 .38171 m .62118 .33193 L .63411 .3179 L p
1 g
F P
s
P
p
.002 w
.62118 .33193 m .57485 .29493 L .58436 .27814 L p
1 g
F P
s
P
p
.002 w
.35192 .44479 m .35599 .4876 L .336 .48847 L p
1 g
F P
s
P
p
.002 w
.336 .48847 m .3311 .43806 L .35192 .44479 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.41104 .31451 m .37047 .34601 L .35973 .32836 L p
1 g
F P
s
P
p
.002 w
.35973 .32836 m .40504 .293 L .41104 .31451 L p
1 g
F P
s
P
p
.002 w
.48324 .58815 m .52599 .58248 L .53599 .60009 L p
1 g
F P
s
P
p
.002 w
.58142 .57774 m .53599 .60009 L .52599 .58248 L p
1 g
F P
s
P
p
.002 w
.61708 .54173 m .63893 .49571 L .65985 .4957 L p
1 g
F P
s
P
p
.002 w
.66602 .43846 m .65985 .4957 L .63893 .49571 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.36206 .40303 m .35192 .44479 L .3311 .43806 L p
1 g
F P
s
P
p
.002 w
.3311 .43806 m .34292 .3888 L .36206 .40303 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52599 .58248 m .56452 .56341 L .58142 .57774 L p
1 g
F P
s
P
p
.002 w
.61708 .54173 m .58142 .57774 L .56452 .56341 L p
1 g
F P
s
P
p
.002 w
.46034 .29803 m .41104 .31451 L .40504 .293 L p
1 g
F P
s
P
p
.002 w
.40504 .293 m .46018 .27443 L .46034 .29803 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.63893 .49571 m .64432 .44454 L .66602 .43846 L p
1 g
F P
s
P
p
.002 w
.65272 .38171 m .66602 .43846 L .64432 .44454 L p
1 g
F P
s
P
p
.004 w
.65327 .40451 m
.65932 .40349 L
s
P
p
.004 w
.65932 .40349 m
.67123 .40147 L
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.38552 .36683 m .36206 .40303 L .34292 .3888 L p
1 g
F P
s
P
p
.002 w
.34292 .3888 m .37047 .34601 L .38552 .36683 L p
1 g
F P
s
P
p
.002 w
.56452 .56341 m .59468 .53278 L .61708 .54173 L p
1 g
F P
s
P
p
.002 w
.63893 .49571 m .61708 .54173 L .59468 .53278 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.51289 .29864 m .46034 .29803 L .46018 .27443 L p
1 g
F P
s
P
p
.002 w
.46018 .27443 m .51903 .27503 L .51289 .29864 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.39489 .51598 m .41793 .54111 L .40292 .55884 L p
1 g
F P
s
P
p
.002 w
.40292 .55884 m .37364 .52697 L .39489 .51598 L p
1 g
F P
s
P
p
.002 w
.44075 .57996 m .40292 .55884 L .41793 .54111 L p
1 g
F P
s
P
p
.002 w
.41793 .54111 m .44461 .556 L p
.44075 .57996 L 1 g
F P
s
P
p
.002 w
.44724 .55935 m .44075 .57996 L p
.44461 .556 L 1 g
F P
s
P
p
.002 w
.47288 .58615 m .44075 .57996 L .44684 .56062 L p
1 g
F P
s
P
p
.002 w
.44684 .56062 m .44724 .55935 L p
.4508 .56307 L 1 g
F P
s
P
p
.47288 .58615 m .44684 .56062 L .4508 .56307 L 1 g
F
P
p
.002 w
.46842 .57403 m .46872 .57265 L p
.46169 .56984 L 1 g
F P
s
P
p
.45146 .56129 m .44347 .55434 L .44724 .55935 L 1 g
F
P
p
.44347 .55434 m .44461 .556 L .44724 .55935 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.41793 .54111 m .42687 .53034 L p
.43847 .54712 L 1 g
F P
s
P
p
.002 w
.44461 .556 m .4406 .55376 L p
.43847 .54712 L 1 g
F P
s
P
p
.002 w
.4406 .55376 m .41793 .54111 L p
.43847 .54712 L 1 g
F P
s
P
p
.002 w
.43847 .54712 m .43925 .54566 L p
.43586 .53895 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43847 .54712 L p
1 g
F P
s
P
p
.002 w
.43847 .54712 m .43743 .5491 L p
.44347 .55434 L 1 g
F P
s
P
p
.45146 .56129 m .43847 .54712 L .44347 .55434 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43256 .52865 L p
1 g
F P
s
P
p
.002 w
.42687 .53034 m .43137 .52492 L p
.43256 .52865 L 1 g
F P
s
P
p
.43847 .54712 m .43224 .53811 L .43256 .52865 L 1 g
F
P
p
.43224 .53811 m .42687 .53034 L .43256 .52865 L 1 g
F
P
p
.002 w
.43256 .52865 m .43346 .52734 L p
.43311 .51722 L 1 g
F P
s
P
p
.002 w
.42002 .50203 m .43316 .51638 L p
.41793 .54111 L 1 g
F P
s
P
p
.002 w
.43274 .52327 m .41793 .54111 L p
.43316 .51638 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42002 .50203 m .43563 .4929 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43316 .51638 m .43144 .5145 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43144 .5145 m .42002 .50203 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43389 .5094 m .43485 .50826 L p
.43816 .50052 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43389 .5094 L p
1 g
F P
s
P
p
.002 w
.43389 .5094 m .43287 .51061 L p
.4331 .51695 L 1 g
F P
s
P
p
.43346 .52734 m .43389 .5094 L .4331 .51695 L 1 g
F
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44255 .4914 L p
1 g
F P
s
P
p
.002 w
.43563 .4929 m .44425 .48785 L p
.44255 .4914 L 1 g
F P
s
P
p
.43389 .5094 m .43502 .49866 L .44255 .4914 L 1 g
F
P
p
.43502 .49866 m .43563 .4929 L .44255 .4914 L 1 g
F
P
p
.002 w
.44255 .4914 m .44166 .49233 L p
.43816 .50052 L 1 g
F P
s
P
p
.43485 .50826 m .44255 .4914 L .43816 .50052 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.44824 .48552 m .44339 .47453 L .46458 .47 L p
1 g
F P
s
P
p
.44929 .48487 m .45765 .47674 L .47804 .46725 L 1 g
F
P
p
.002 w
.46694 .50033 m .45637 .49444 L .47838 .46721 L p
1 g
F P
s
P
p
.002 w
.49067 .50091 m .47879 .50257 L .47853 .46719 L p
1 g
F P
s
P
p
.002 w
.50953 .48696 m .5013 .49552 L .47865 .46717 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51553 .46426 m .55195 .46046 L p
.53266 .46854 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47674 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .566 .50927 L p
1 g
F P
s
P
p
.002 w
.58302 .48974 m .57001 .51762 L p
.566 .50927 L 1 g
F P
s
P
p
.56462 .49625 m .566 .50927 L .56045 .49773 L 1 g
F
P
p
.58302 .48974 m .566 .50927 L .56462 .49625 L 1 g
F
P
p
.002 w
.566 .50927 m .56515 .50826 L p
.56725 .5219 L 1 g
F P
s
P
p
.56725 .5219 m .56725 .52189 L .566 .50927 L 1 g
F
P
p
.002 w
.5687 .52043 m .56725 .5219 L p
.56715 .52047 L 1 g
F P
s
P
p
.56725 .5219 m .56723 .52092 L .56709 .51956 L 1 g
F
P
p
.56725 .52189 m .56709 .51956 L .566 .50927 L 1 g
F
P
p
.56725 .5219 m .56709 .51956 L .56725 .52189 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.59468 .53278 m .56764 .5392 L .56841 .52552 L 1 g
F
P
p
.002 w
.5687 .52043 m .5699 .52099 L p
.56841 .52552 L 1 g
F P
s
P
p
.002 w
.5699 .52099 m .59468 .53278 L p
.56841 .52552 L 1 g
F P
s
P
p
.002 w
.5674 .52859 m .56654 .52734 L p
.56494 .53607 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5674 .52859 L p
1 g
F P
s
P
p
.002 w
.56725 .5219 m .5687 .52043 L p
.56764 .5392 L 1 g
F P
s
P
p
.002 w
.5674 .52859 m .56854 .53025 L p
.56725 .5219 L 1 g
F P
s
P
p
.56515 .50826 m .5674 .52859 L .56725 .5219 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5614 .54687 L p
1 g
F P
s
P
p
.56764 .5392 m .5636 .54016 L .5674 .52859 L 1 g
F
P
p
.56654 .52734 m .5614 .54687 L .56494 .53607 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.59468 .53278 m .56452 .56341 L .55582 .55496 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54906 .56268 L p
1 g
F P
s
P
p
.002 w
.56452 .56341 m .53609 .57748 L p
.54906 .56268 L 1 g
F P
s
P
p
.54965 .56228 m .54906 .56268 L .54942 .56226 L 1 g
F
P
p
.56452 .56341 m .54906 .56268 L .54965 .56228 L 1 g
F
P
p
.002 w
.54906 .56268 m .54854 .56129 L p
.54242 .56712 L 1 g
F P
s
P
p
.56075 .54566 m .54906 .56268 L .55342 .5577 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53165 .57434 L p
1 g
F P
s
P
p
.54853 .56303 m .53835 .57181 L .5367 .57096 L 1 g
F
P
p
.002 w
.52599 .58248 m .52351 .5774 L p
.53835 .57181 L 1 g
F P
s
P
p
.54854 .56129 m .53165 .57434 L .54242 .56712 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58023 L p
1 g
F P
s
P
p
.52599 .58248 m .4831 .58647 L .51091 .58023 L 1 g
F
P
p
.52034 .58017 m .51091 .58023 L .51709 .57884 L 1 g
F
P
p
.52599 .58248 m .51091 .58023 L .52034 .58017 L 1 g
F
P
p
.002 w
.51091 .58023 m .51079 .57862 L p
.50246 .58029 L 1 g
F P
s
P
p
.53128 .57265 m .51091 .58023 L .51887 .57844 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58037 L p
1 g
F P
s
P
p
.51091 .58023 m .5 .58268 L .4976 .58032 L 1 g
F
P
p
.002 w
.4831 .58647 m .48246 .57898 L p
.5 .58268 L 1 g
F P
s
P
p
.51079 .57862 m .48908 .58037 L .50246 .58029 L 1 g
F
P
p
.002 w
.48908 .58037 m .48921 .57862 L p
.4791 .57779 L 1 g
F P
s
P
p
.002 w
.48246 .57898 m .48324 .58815 L p
.46558 .57302 L 1 g
F P
s
P
p
.4791 .57779 m .47541 .57749 L .48246 .57898 L 1 g
F
P
p
.4791 .57779 m .48246 .57898 L .48908 .58037 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46842 .57403 L p
1 g
F P
s
P
p
.48324 .58815 m .4593 .57081 L .46558 .57302 L 1 g
F
P
p
.002 w
.46842 .57403 m .4678 .57686 L p
.4791 .57779 L 1 g
F P
s
P
p
.48921 .57862 m .46842 .57403 L .4791 .57779 L 1 g
F
P
p
.002 w
.48324 .58815 m .47288 .58615 L p
.4593 .57081 L 1 g
F P
s
P
p
.002 w
.4508 .56307 m .45146 .56129 L p
.44724 .55935 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4508 .56307 L p
1 g
F P
s
P
p
.46558 .57302 m .4593 .57081 L .45449 .56537 L 1 g
F
P
p
.46558 .57302 m .45449 .56537 L .46233 .57024 L 1 g
F
P
p
.46872 .57265 m .4508 .56307 L .46169 .56984 L 1 g
F
P
p
.002 w
.44724 .55935 m .44774 .55775 L p
.47288 .58615 L 1 g
F P
s
P
p
.002 w
.4508 .56307 m .45002 .56518 L p
.46169 .56984 L 1 g
F P
s
P
p
.46233 .57024 m .45449 .56537 L .44774 .55775 L 1 g
F
P
p
.002 w
.44774 .55775 m .48121 .56416 L .48246 .57898 L p
1 g
F P
s
P
p
.46558 .57302 m .44774 .55775 L .48246 .57898 L 1 g
F
P
p
.002 w
.48246 .57898 m .48121 .56416 L p
.5 .58268 L 1 g
F P
s
P
p
.002 w
.48908 .58037 m .48889 .583 L p
.50246 .58029 L 1 g
F P
s
P
p
.51709 .57884 m .51091 .58023 L .48121 .56416 L 1 g
F
P
p
.51091 .58023 m .4976 .58032 L .48121 .56416 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58037 L p
1 g
F P
s
P
p
.47541 .57749 m .4678 .57686 L .48908 .58037 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58023 L p
1 g
F P
s
P
p
.50246 .58029 m .48889 .583 L .51091 .58023 L 1 g
F
P
p
.53128 .57265 m .51887 .57844 L .52085 .578 L 1 g
F
P
p
.002 w
.52351 .5774 m .52599 .58248 L p
.51709 .57884 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.48121 .56416 m .51485 .55963 L .52351 .5774 L p
1 g
F P
s
P
p
.51709 .57884 m .48121 .56416 L .52351 .5774 L 1 g
F
P
p
.52085 .578 m .51105 .5821 L .51789 .57952 L 1 g
F
P
p
.51887 .57844 m .51105 .5821 L .52085 .578 L 1 g
F
P
p
.002 w
.51091 .58023 m .51105 .5821 L p
.51887 .57844 L 1 g
F P
s
P
p
.002 w
.52599 .58248 m .48324 .58815 L .4831 .58647 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52351 .5774 m .51485 .55963 L p
.53835 .57181 L 1 g
F P
s
P
p
.002 w
.53165 .57434 m .5322 .57686 L p
.54242 .56712 L 1 g
F P
s
P
p
.54942 .56226 m .54853 .56303 L .51485 .55963 L 1 g
F
P
p
.54853 .56303 m .5367 .57096 L .51485 .55963 L 1 g
F
P
p
.002 w
.51105 .5821 m .51111 .583 L p
.51789 .57952 L 1 g
F P
s
P
p
.002 w
.53609 .57748 m .52599 .58248 L p
.54942 .56226 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54906 .56268 L p
1 g
F P
s
P
p
.54242 .56712 m .5322 .57686 L .54906 .56268 L 1 g
F
P
p
.56075 .54566 m .55342 .5577 L .55528 .55558 L 1 g
F
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55582 .55496 m .56452 .56341 L p
.54942 .56226 L 1 g
F P
s
P
p
.59468 .53278 m .55582 .55496 L .5665 .53947 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.51485 .55963 m .5451 .54456 L .55582 .55496 L p
1 g
F P
s
P
p
.54942 .56226 m .51485 .55963 L .55582 .55496 L 1 g
F
P
p
.55528 .55558 m .54956 .56404 L .55482 .55641 L 1 g
F
P
p
.55342 .5577 m .54956 .56404 L .55528 .55558 L 1 g
F
P
p
.002 w
.54906 .56268 m .54956 .56404 L p
.55342 .5577 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55582 .55496 m .5451 .54456 L p
.5665 .53947 L 1 g
F P
s
P
p
.002 w
.54956 .56404 m .54998 .56518 L p
.55482 .55641 L 1 g
F P
s
P
p
.002 w
.5614 .54687 m .56257 .5491 L p
.56494 .53607 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5451 .54456 m .56725 .5219 L p
.5674 .52859 L 1 g
F P
s
P
p
.5636 .54016 m .5451 .54456 L .5674 .52859 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5674 .52859 L p
1 g
F P
s
P
p
.56494 .53607 m .56257 .5491 L .5674 .52859 L 1 g
F
P
p
.002 w
.52378 .52168 m .53998 .50498 L .56709 .51956 L p
1 g
F P
s
P
p
.002 w
.56709 .51956 m .5687 .52043 L p
.56715 .52047 L 1 g
F P
s
P
p
.56715 .52047 m .52378 .52168 L .56709 .51956 L 1 g
F
P
p
.002 w
.5451 .54456 m .52378 .52168 L p
.56715 .52047 L 1 g
F P
s
P
p
.002 w
.56725 .5219 m .5451 .54456 L p
.56715 .52047 L 1 g
F P
s
P
p
.56725 .5219 m .56725 .5219 L .56725 .52189 L 1 g
F
P
p
.56725 .5219 m .56751 .5236 L .56723 .52092 L 1 g
F
P
p
.55661 .4905 m .566 .50927 L .56119 .49927 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55736 .4913 m .55661 .4905 L p
.56119 .49927 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .4913 L p
1 g
F P
s
P
p
.56306 .49681 m .56045 .49773 L .55736 .4913 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55736 .4913 L p
1 g
F P
s
P
p
.56119 .49927 m .56713 .51061 L .55736 .4913 L 1 g
F
P
p
.54174 .47608 m .55736 .4913 L .55163 .48576 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54974 .48382 m .55415 .4846 L p
.55265 .48675 L 1 g
F P
s
P
p
.002 w
.53998 .50498 m .5497 .4839 L p
.55265 .48675 L 1 g
F P
s
P
p
.002 w
.5497 .4839 m .54974 .48382 L p
.55265 .48675 L 1 g
F P
s
P
p
.56045 .49773 m .53998 .50498 L .55415 .4846 L 1 g
F
P
p
.54235 .47674 m .54937 .48358 L .52869 .4702 L 1 g
F
P
p
.002 w
.53998 .50498 m .50953 .48696 L p
.54963 .48383 L 1 g
F P
s
P
p
.002 w
.54974 .48382 m .5497 .4839 L p
.54963 .48383 L 1 g
F P
s
P
p
.002 w
.5497 .4839 m .53998 .50498 L p
.54963 .48383 L 1 g
F P
s
P
p
.54174 .47608 m .55163 .48576 L .5497 .4839 L 1 g
F
P
p
.54966 .48387 m .5497 .4839 L .54968 .48388 L 1 g
F
P
p
.54174 .47608 m .5497 .4839 L .54966 .48387 L 1 g
F
P
p
.52869 .4702 m .54937 .48358 L .51446 .47616 L 1 g
F
P
p
.002 w
.54958 .48379 m .51446 .47616 L p
.54937 .48358 L 1 g
F P
s
P
p
.002 w
.50953 .48696 m .51446 .47616 L .54958 .48379 L p
1 g
F P
s
P
p
.002 w
.54958 .48379 m .54974 .48382 L p
.54963 .48383 L 1 g
F P
s
P
p
.54963 .48383 m .50953 .48696 L .54958 .48379 L 1 g
F
P
p
.002 w
.54281 .47724 m .54244 .47685 L p
.54968 .48388 L 1 g
F P
s
P
p
.002 w
.54244 .47685 m .54235 .47674 L p
.54958 .48379 L 1 g
F P
s
P
p
.54958 .48379 m .54968 .48388 L .54244 .47685 L 1 g
F
P
p
.002 w
.54235 .47674 m .54174 .47608 L p
.54968 .48388 L 1 g
F P
s
P
p
.002 w
.54974 .48382 m .54958 .48379 L p
.54937 .48358 L 1 g
F P
s
P
p
.002 w
.55006 .48044 m .54974 .48382 L p
.54937 .48358 L 1 g
F P
s
P
p
.55006 .48044 m .54937 .48358 L .54235 .47674 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54281 .47724 L p
1 g
F P
s
P
p
.55163 .48576 m .55834 .49233 L .54281 .47724 L 1 g
F
P
p
.002 w
.55736 .4913 m .55834 .49233 L p
.55163 .48576 L 1 g
F P
s
P
p
.002 w
.55415 .4846 m .58302 .48974 L p
.56306 .49681 L 1 g
F P
s
P
p
.56306 .49681 m .55736 .4913 L .55415 .4846 L 1 g
F
P
p
.002 w
.5687 .52043 m .53998 .50498 L p
.56045 .49773 L 1 g
F P
s
P
p
.002 w
.57001 .51762 m .5687 .52043 L p
.56045 .49773 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .566 .50927 L p
1 g
F P
s
P
p
.56751 .5236 m .56854 .53025 L .566 .50927 L 1 g
F
P
p
.002 w
.566 .50927 m .56713 .51061 L p
.56119 .49927 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.53235 .47196 L 1 g
F P
s
P
p
.52214 .46667 m .54235 .47674 L .53235 .47196 L 1 g
F
P
p
.52869 .4702 m .51446 .47616 L .52248 .46723 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52248 .46723 L p
1 g
F P
s
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.53235 .47196 L 1 g
F P
s
P
p
.53235 .47196 m .54302 .47747 L .52248 .46723 L 1 g
F
P
p
.002 w
.51446 .47616 m .51535 .46631 L p
.52248 .46723 L 1 g
F P
s
P
p
.53266 .46854 m .52869 .4702 L .52248 .46723 L 1 g
F
P
p
.002 w
.55195 .46046 m .55006 .48044 L p
.52869 .4702 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .51842 .46671 L 1 g
F
P
p
.5 .4634 m .52262 .46746 L .5142 .46613 L 1 g
F
P
p
.002 w
.51535 .46631 m .51553 .46426 L p
.53266 .46854 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52262 .46746 L p
.51842 .46671 L 1 g
F P
s
P
p
.002 w
.51535 .46631 m .51446 .47616 L p
.50674 .46495 L 1 g
F P
s
P
p
.002 w
.52262 .46746 m .52282 .46778 L p
.5142 .46613 L 1 g
F P
s
P
p
.002 w
.51446 .47616 m .47894 .46712 L p
.50674 .46495 L 1 g
F P
s
P
p
.002 w
.48065 .46686 m .5066 .46493 L p
.47894 .46712 L 1 g
F P
s
P
p
.50674 .46495 m .47894 .46712 L .5066 .46493 L 1 g
F
P
p
.5 .4634 m .5142 .46613 L .5066 .46493 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.51262 .45258 m .51553 .46426 L .5066 .46493 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47786 .46667 L p
.48795 .46574 L 1 g
F P
s
P
p
.002 w
.5066 .46493 m .48065 .46686 L p
.5 .46388 L 1 g
F P
s
P
p
.48795 .46574 m .48799 .46573 L .48716 .46586 L 1 g
F
P
p
.48795 .46574 m .48716 .46586 L .47747 .46732 L 1 g
F
P
p
.002 w
.5 .46442 m .49627 .46497 L p
.47786 .46667 L 1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.48973 .46546 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .48973 .46546 L 1 g
F
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.48978 .46225 m .51262 .45258 L p
.50769 .4627 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.5066 .46493 L 1 g
F P
s
P
p
.50769 .4627 m .5066 .46493 L .5 .46388 L 1 g
F
P
p
.50769 .4627 m .5 .46388 L .48978 .46225 L 1 g
F
P
p
.002 w
.47853 .46702 m .48978 .46225 L p
.5 .46388 L 1 g
F P
s
P
p
.48799 .46573 m .48435 .46629 L .47747 .46732 L 1 g
F
P
p
.48828 .46571 m .48275 .46655 L .47747 .46732 L 1 g
F
P
p
.002 w
.48065 .46686 m .47853 .46702 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46388 L p
.5066 .46493 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.5142 .46613 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.5066 .46493 m .51553 .46426 L p
.50674 .46495 L 1 g
F P
s
P
p
.002 w
.51553 .46426 m .51535 .46631 L p
.50674 .46495 L 1 g
F P
s
P
p
.002 w
.47894 .46712 m .47853 .46702 L .48065 .46686 L p
1 g
F P
s
P
p
.48799 .46573 m .48828 .46571 L .48435 .46629 L 1 g
F
P
p
.48828 .46571 m .48883 .46566 L .48275 .46655 L 1 g
F
P
p
.002 w
.51446 .47616 m .50953 .48696 L .47874 .46716 L p
1 g
F P
s
P
p
.002 w
.47874 .46716 m .47853 .46702 L .47894 .46712 L p
1 g
F P
s
P
p
.002 w
.47894 .46712 m .51446 .47616 L p
.47874 .46716 L 1 g
F P
s
P
p
.002 w
.47865 .46717 m .47853 .46702 L .47874 .46716 L p
1 g
F P
s
P
p
.002 w
.47874 .46716 m .50953 .48696 L p
.47865 .46717 L 1 g
F P
s
P
p
.48883 .46566 m .48966 .46558 L .48165 .46672 L 1 g
F
P
p
.48883 .46566 m .48165 .46672 L .47747 .46732 L 1 g
F
P
p
.48966 .46558 m .49079 .46547 L .48078 .46686 L 1 g
F
P
p
.48966 .46558 m .48078 .46686 L .47747 .46732 L 1 g
F
P
p
.002 w
.5013 .49552 m .49067 .50091 L .47859 .46718 L p
1 g
F P
s
P
p
.002 w
.47859 .46718 m .47853 .46702 L .47865 .46717 L p
1 g
F P
s
P
p
.002 w
.47865 .46717 m .5013 .49552 L p
.47859 .46718 L 1 g
F P
s
P
p
.002 w
.47853 .46719 m .47853 .46702 L .47859 .46718 L p
1 g
F P
s
P
p
.002 w
.47859 .46718 m .49067 .50091 L p
.47853 .46719 L 1 g
F P
s
P
p
.49079 .46547 m .49218 .46535 L .48004 .46697 L 1 g
F
P
p
.49079 .46547 m .48004 .46697 L .47747 .46732 L 1 g
F
P
p
.49218 .46535 m .49374 .4652 L .47939 .46707 L 1 g
F
P
p
.49218 .46535 m .47939 .46707 L .47747 .46732 L 1 g
F
P
p
.002 w
.47879 .50257 m .46694 .50033 L .47847 .46719 L p
1 g
F P
s
P
p
.002 w
.47847 .46719 m .47853 .46702 L .47853 .46719 L p
1 g
F P
s
P
p
.002 w
.47853 .46719 m .47879 .50257 L p
.47847 .46719 L 1 g
F P
s
P
p
.002 w
.47838 .46721 m .47853 .46702 L .47847 .46719 L p
1 g
F P
s
P
p
.002 w
.47847 .46719 m .46694 .50033 L p
.47838 .46721 L 1 g
F P
s
P
p
.49374 .4652 m .49523 .46506 L .47878 .46715 L 1 g
F
P
p
.49374 .4652 m .47878 .46715 L .47747 .46732 L 1 g
F
P
p
.002 w
.47838 .46721 m .45637 .49444 L p
.47819 .46723 L 1 g
F P
s
P
p
.49523 .46506 m .47819 .46723 L .47747 .46732 L 1 g
F
P
p
.002 w
.44929 .48487 m .47819 .46723 L p
.44842 .48572 L 1 g
F P
s
P
p
.002 w
.47819 .46723 m .47853 .46702 L p
.47819 .46723 L 1 g
F P
s
P
p
.44842 .48572 m .47819 .46723 L .47819 .46723 L 1 g
F
P
p
.002 w
.45637 .49444 m .44842 .48572 L p
.47819 .46723 L 1 g
F P
s
P
p
.002 w
.47819 .46723 m .44929 .48487 L p
.47804 .46725 L 1 g
F P
s
P
p
.002 w
.47775 .46719 m .47853 .46702 L p
.45765 .47674 L 1 g
F P
s
P
p
.002 w
.49627 .46497 m .47718 .46778 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47747 .46732 L p
.47819 .46723 L 1 g
F P
s
P
p
.47819 .46723 m .49627 .46497 L .47747 .46732 L 1 g
F
P
p
.49523 .46506 m .49627 .46497 L .47819 .46723 L 1 g
F
P
p
.002 w
.47853 .46702 m .47838 .46721 L p
.47819 .46723 L 1 g
F P
s
P
p
.002 w
.47853 .46702 m .47819 .46723 L p
.47804 .46725 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.46836 .47165 L 1 g
F P
s
P
p
.46836 .47165 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47747 .46732 L p
1 g
F P
s
P
p
.002 w
.47747 .46732 m .47718 .46778 L p
.46836 .47165 L 1 g
F P
s
P
p
.45826 .47608 m .47747 .46732 L .46836 .47165 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.43316 .51638 m .43389 .5094 L .44769 .48643 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45714 .4773 L p
1 g
F P
s
P
p
.44339 .4905 m .45714 .4773 L .45424 .4801 L 1 g
F
P
p
.002 w
.44255 .4914 m .44339 .4905 L p
.45141 .48281 L 1 g
F P
s
P
p
.44788 .48624 m .44769 .48643 L .44824 .48552 L 1 g
F
P
p
.43316 .51638 m .44769 .48643 L .44788 .48624 L 1 g
F
P
p
.002 w
.45714 .4773 m .45698 .47747 L p
.45424 .4801 L 1 g
F P
s
P
p
.002 w
.44929 .48487 m .44824 .48552 L p
.45731 .47691 L 1 g
F P
s
P
p
.45731 .47691 m .46458 .47 L .45765 .47674 L 1 g
F
P
p
.45731 .47691 m .45765 .47674 L .44929 .48487 L 1 g
F
P
p
.002 w
.46458 .47 m .47775 .46719 L p
.45765 .47674 L 1 g
F P
s
P
p
.45141 .48281 m .45144 .48278 L .45134 .48288 L 1 g
F
P
p
.45141 .48281 m .45134 .48288 L .44255 .4914 L 1 g
F
P
p
.45144 .48278 m .45424 .4801 L .44842 .48572 L 1 g
F
P
p
.45144 .48278 m .44842 .48572 L .44255 .4914 L 1 g
F
P
p
.002 w
.44842 .48572 m .44824 .48552 L .44929 .48487 L p
1 g
F P
s
P
p
.002 w
.44425 .48785 m .44824 .48552 L p
.43389 .5094 L 1 g
F P
s
P
p
.002 w
.43594 .51942 m .43316 .51638 L p
.44824 .48552 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44824 .48552 m .45637 .49444 L .43594 .51942 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44255 .4914 L p
1 g
F P
s
P
p
.45424 .4801 m .45698 .47747 L .44255 .4914 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43389 .5094 L p
1 g
F P
s
P
p
.43816 .50052 m .44166 .49233 L .43389 .5094 L 1 g
F
P
p
.43311 .51722 m .4331 .51695 L .43274 .52327 L 1 g
F
P
p
.4331 .51695 m .43303 .51494 L .43289 .5189 L 1 g
F
P
p
.4331 .51695 m .43289 .5189 L .43274 .52327 L 1 g
F
P
p
.43311 .51722 m .43274 .52327 L .43256 .52865 L 1 g
F
P
p
.002 w
.43316 .51638 m .43594 .51942 L .43274 .52327 L p
1 g
F P
s
P
p
.43925 .54566 m .43256 .52865 L .43586 .53895 L 1 g
F
P
p
.002 w
.43137 .52492 m .43594 .51942 L p
.43847 .54712 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43256 .52865 L p
1 g
F P
s
P
p
.43303 .51494 m .43287 .51061 L .43256 .52865 L 1 g
F
P
p
.002 w
.43256 .52865 m .43146 .53025 L p
.43586 .53895 L 1 g
F P
s
P
p
.44461 .556 m .43847 .54712 L .43594 .51942 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43847 .54712 L p
1 g
F P
s
P
p
.43586 .53895 m .43146 .53025 L .43847 .54712 L 1 g
F
P
p
.002 w
.44774 .55775 m .44461 .556 L p
.43594 .51942 L 1 g
F P
s
P
p
.44347 .55434 m .44299 .55393 L .44461 .556 L 1 g
F
P
p
.002 w
.45059 .56363 m .4508 .56307 L p
.44724 .55935 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46842 .57403 L p
1 g
F P
s
P
p
.46169 .56984 m .45002 .56518 L .46842 .57403 L 1 g
F
P
p
.002 w
.45002 .56518 m .45059 .56363 L p
.43753 .54921 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .43746 .54913 L p
.43753 .54921 L 1 g
F P
s
P
p
.002 w
.43746 .54913 m .45002 .56518 L p
.43753 .54921 L 1 g
F P
s
P
p
.44299 .55393 m .43743 .5491 L .45059 .56363 L 1 g
F
P
p
.002 w
.44461 .556 m .44774 .55775 L .44724 .55935 L p
1 g
F P
s
P
p
.002 w
.64432 .44454 m .63234 .39388 L .65272 .38171 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.63556 .40752 L
s
P
p
.004 w
.65206 .40472 m
.65327 .40451 L
s
P
p
.002 w
.62118 .33193 m .65272 .38171 L .63234 .39388 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.38105 .48497 m .39489 .51598 L .37364 .52697 L p
1 g
F P
s
P
p
.002 w
.37364 .52697 m .35599 .4876 L .38105 .48497 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.56272 .31644 m .51289 .29864 L .51903 .27503 L p
1 g
F P
s
P
p
.002 w
.51903 .27503 m .57485 .29493 L .56272 .31644 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.57485 .29493 m .62118 .33193 L .60411 .34946 L p
1 g
F P
s
P
p
.002 w
.63234 .39388 m .60411 .34946 L .62118 .33193 L p
1 g
F P
s
P
p
.002 w
.37795 .4513 m .38105 .48497 L .35599 .4876 L p
1 g
F P
s
P
p
.002 w
.35599 .4876 m .35192 .44479 L .37795 .4513 L p
1 g
F P
s
P
p
.002 w
.60411 .34946 m .56272 .31644 L .57485 .29493 L p
1 g
F P
s
P
p
.002 w
.41996 .34026 m .38552 .36683 L .37047 .34601 L p
1 g
F P
s
P
p
.002 w
.37047 .34601 m .41104 .31451 L .41996 .34026 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.59468 .53278 m .61308 .49373 L .63893 .49571 L p
1 g
F P
s
P
p
.002 w
.64432 .44454 m .63893 .49571 L .61308 .49373 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.38602 .41852 m .37795 .4513 L .35192 .44479 L p
1 g
F P
s
P
p
.002 w
.35192 .44479 m .36206 .40303 L .38602 .41852 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46171 .32642 m .41996 .34026 L .41104 .31451 L p
1 g
F P
s
P
p
.002 w
.41104 .31451 m .46034 .29803 L .46171 .32642 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.61308 .49373 m .61751 .45039 L .64432 .44454 L p
1 g
F P
s
P
p
.002 w
.63234 .39388 m .64432 .44454 L .61751 .45039 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40453 .3902 m .38602 .41852 L .36206 .40303 L p
1 g
F P
s
P
p
.002 w
.36206 .40303 m .38552 .36683 L .40453 .3902 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.61308 .49373 m .59468 .53278 L .5687 .52043 L p
1 g
F P
s
P
p
.002 w
.50617 .32702 m .46171 .32642 L .46034 .29803 L p
1 g
F P
s
P
p
.002 w
.46034 .29803 m .51289 .29864 L .50617 .32702 L p
1 g
F P
s
P
p
.002 w
.41793 .54111 m .39489 .51598 L .42002 .50203 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.43594 .51942 m .45656 .53093 L .44774 .55775 L p
1 g
F P
s
P
p
.002 w
.48121 .56416 m .44774 .55775 L .45656 .53093 L p
1 g
F P
s
P
p
.002 w
.61751 .45039 m .60726 .40754 L .63234 .39388 L p
1 g
F P
s
P
p
.002 w
.60411 .34946 m .63234 .39388 L .60726 .40754 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41051 .48058 m .42002 .50203 L .39489 .51598 L p
1 g
F P
s
P
p
.002 w
.39489 .51598 m .38105 .48497 L .41051 .48058 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.45656 .53093 m .4797 .53533 L .48121 .56416 L p
1 g
F P
s
P
p
.002 w
.51485 .55963 m .48121 .56416 L .4797 .53533 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.5483 .34211 m .50617 .32702 L .51289 .29864 L p
1 g
F P
s
P
p
.002 w
.51289 .29864 m .56272 .31644 L .5483 .34211 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.56272 .31644 m .60411 .34946 L .58332 .37001 L p
1 g
F P
s
P
p
.002 w
.60726 .40754 m .58332 .37001 L .60411 .34946 L p
1 g
F P
s
P
p
.002 w
.43159 .36948 m .40453 .3902 L .38552 .36683 L p
1 g
F P
s
P
p
.002 w
.38552 .36683 m .41996 .34026 L .43159 .36948 L p
1 g
F P
s
P
p
.002 w
.40844 .45733 m .41051 .48058 L .38105 .48497 L p
1 g
F P
s
P
p
.002 w
.38105 .48497 m .37795 .4513 L .40844 .45733 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58332 .37001 m .5483 .34211 L .56272 .31644 L p
1 g
F P
s
P
p
.002 w
.4797 .53533 m .50293 .53215 L .51485 .55963 L p
1 g
F P
s
P
p
.002 w
.5451 .54456 m .51485 .55963 L .50293 .53215 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5687 .52043 m .58302 .48974 L .61308 .49373 L p
1 g
F P
s
P
p
.002 w
.61751 .45039 m .61308 .49373 L .58302 .48974 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41409 .43476 m .40844 .45733 L .37795 .4513 L p
1 g
F P
s
P
p
.002 w
.37795 .4513 m .38602 .41852 L .41409 .43476 L p
1 g
F P
s
P
p
.002 w
.50293 .53215 m .52378 .52168 L .5451 .54456 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.46432 .35874 m .43159 .36948 L .41996 .34026 L p
1 g
F P
s
P
p
.002 w
.41996 .34026 m .46171 .32642 L .46432 .35874 L p
1 g
F P
s
P
p
.002 w
.58302 .48974 m .58637 .45577 L .61751 .45039 L p
1 g
F P
s
P
p
.002 w
.60726 .40754 m .61751 .45039 L .58637 .45577 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42691 .41532 m .41409 .43476 L .38602 .41852 L p
1 g
F P
s
P
p
.002 w
.38602 .41852 m .40453 .3902 L .42691 .41532 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.4991 .35927 m .46432 .35874 L .46171 .32642 L p
1 g
F P
s
P
p
.002 w
.46171 .32642 m .50617 .32702 L .4991 .35927 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58637 .45577 m .57824 .42225 L .60726 .40754 L p
1 g
F P
s
P
p
.002 w
.58332 .37001 m .60726 .40754 L .57824 .42225 L p
1 g
F P
s
P
p
.002 w
.45656 .53093 m .43594 .51942 L .45637 .49444 L p
1 g
F P
s
P
p
.002 w
.45637 .49444 m .46694 .50033 L .45656 .53093 L p
1 g
F P
s
P
p
.002 w
.4797 .53533 m .45656 .53093 L .46694 .50033 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44339 .47453 m .44824 .48552 L .42002 .50203 L p
1 g
F P
s
P
p
.002 w
.42002 .50203 m .41051 .48058 L .44339 .47453 L p
1 g
F P
s
P
p
.002 w
.46694 .50033 m .47879 .50257 L .4797 .53533 L p
1 g
F P
s
P
p
.002 w
.50293 .53215 m .4797 .53533 L .47879 .50257 L p
1 g
F P
s
P
p
.002 w
.53205 .3711 m .4991 .35927 L .50617 .32702 L p
1 g
F P
s
P
p
.002 w
.50617 .32702 m .5483 .34211 L .53205 .3711 L p
1 g
F P
s
P
p
.002 w
.44558 .40114 m .42691 .41532 L .40453 .3902 L p
1 g
F P
s
P
p
.002 w
.40453 .3902 m .43159 .36948 L .44558 .40114 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.57824 .42225 m .55946 .39292 L .58332 .37001 L p
1 g
F P
s
P
p
.002 w
.5483 .34211 m .58332 .37001 L .55946 .39292 L p
1 g
F P
s
P
p
.002 w
.44238 .46265 m .44339 .47453 L .41051 .48058 L p
1 g
F P
s
P
p
.002 w
.41051 .48058 m .40844 .45733 L .44238 .46265 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58637 .45577 m .58302 .48974 L .54974 .48382 L p
1 g
F P
s
P
p
.002 w
.47879 .50257 m .49067 .50091 L .50293 .53215 L p
1 g
F P
s
P
p
.002 w
.52378 .52168 m .50293 .53215 L .49067 .50091 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55946 .39292 m .53205 .3711 L .5483 .34211 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44531 .45114 m .44238 .46265 L .40844 .45733 L p
1 g
F P
s
P
p
.002 w
.40844 .45733 m .41409 .43476 L .44531 .45114 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49067 .50091 m .5013 .49552 L .52378 .52168 L p
1 g
F P
s
P
p
.002 w
.53998 .50498 m .52378 .52168 L .5013 .49552 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46808 .39384 m .44558 .40114 L .43159 .36948 L p
1 g
F P
s
P
p
.002 w
.43159 .36948 m .46432 .35874 L .46808 .39384 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.54974 .48382 m .55195 .46046 L .58637 .45577 L p
1 g
F P
s
P
p
.002 w
.57824 .42225 m .58637 .45577 L .55195 .46046 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.45189 .44126 m .44531 .45114 L .41409 .43476 L p
1 g
F P
s
P
p
.002 w
.41409 .43476 m .42691 .41532 L .45189 .44126 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5013 .49552 m .50953 .48696 L .53998 .50498 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49195 .39426 m .46808 .39384 L .46432 .35874 L p
1 g
F P
s
P
p
.002 w
.46432 .35874 m .4991 .35927 L .49195 .39426 L p
1 g
F P
s
P
p
.002 w
.55195 .46046 m .5463 .43745 L .57824 .42225 L p
1 g
F P
s
P
p
.002 w
.55946 .39292 m .57824 .42225 L .5463 .43745 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.46142 .43409 m .45189 .44126 L .42691 .41532 L p
1 g
F P
s
P
p
.002 w
.42691 .41532 m .44558 .40114 L .46142 .43409 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.44339 .47453 m .44238 .46265 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.51455 .4024 m .49195 .39426 L .4991 .35927 L p
1 g
F P
s
P
p
.002 w
.4991 .35927 m .53205 .3711 L .51455 .4024 L p
1 g
F P
s
P
p
.002 w
.53205 .3711 m .55946 .39292 L .53337 .41735 L p
1 g
F P
s
P
p
.002 w
.5463 .43745 m .53337 .41735 L .55946 .39292 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.53337 .41735 m .51455 .4024 L .53205 .3711 L p
1 g
F P
s
P
p
.002 w
.44238 .46265 m .44531 .45114 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.47288 .43041 m .46142 .43409 L .44558 .40114 L p
1 g
F P
s
P
p
.002 w
.44558 .40114 m .46808 .39384 L .47288 .43041 L p
1 g
F P
s
P
p
.002 w
.5463 .43745 m .55195 .46046 L .51553 .46426 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.44531 .45114 m .45189 .44126 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45189 .44126 m .46142 .43409 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.485 .43066 m .47288 .43041 L .46808 .39384 L p
1 g
F P
s
P
p
.002 w
.46808 .39384 m .49195 .39426 L .485 .43066 L p
1 g
F P
s
P
p
.002 w
.51553 .46426 m .51262 .45258 L .5463 .43745 L p
1 g
F P
s
P
p
.002 w
.53337 .41735 m .5463 .43745 L .51262 .45258 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49648 .4348 m .50603 .44238 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.004 w
.49716 .43534 m
.5 .43051 L
s
P
p
.002 w
.485 .43066 m .49648 .4348 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.47288 .43041 m .485 .43066 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.46142 .43409 m .47288 .43041 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.50603 .44238 m .51262 .45258 L .47853 .46702 L closepath p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.49648 .4348 m .485 .43066 L .49195 .39426 L p
1 g
F P
s
P
p
.002 w
.49195 .39426 m .51455 .4024 L .49648 .4348 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51455 .4024 m .53337 .41735 L .50603 .44238 L p
1 g
F P
s
P
p
.002 w
.51262 .45258 m .50603 .44238 L .53337 .41735 L p
1 g
F P
s
P
p
.002 w
.50603 .44238 m .49648 .4348 L .51455 .4024 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.46521 .48966 m
.47853 .46702 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .74294 .3893 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .46521 .48966 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.363566)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.363566)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49936 .45933 m .51664 .4527 L .50229 .42806 L p
1 g
F P
s
P
p
.002 w
.50229 .42806 m .49354 .43141 L .49936 .45933 L p
1 g
F P
s
P
p
.002 w
.50951 .42209 m .50229 .42806 L .51664 .4527 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .49354 .43141 L .50229 .42806 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .50229 .42806 L .50951 .42209 L closepath p
1 g
F P
s
P
p
.002 w
.48088 .46007 m .49936 .45933 L .49354 .43141 L p
1 g
F P
s
P
p
.002 w
.49354 .43141 m .48419 .43178 L .48088 .46007 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .48419 .43178 L .49354 .43141 L closepath p
1 g
F P
s
P
p
.002 w
.51664 .4527 m .5309 .44092 L .50951 .42209 L p
1 g
F P
s
P
p
.002 w
.5144 .41413 m .50951 .42209 L .5309 .44092 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .50951 .42209 L .5144 .41413 L closepath p
1 g
F P
s
P
p
.002 w
.46318 .45486 m .48088 .46007 L .48419 .43178 L p
1 g
F P
s
P
p
.002 w
.48419 .43178 m .47525 .42912 L .46318 .45486 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .47525 .42912 L .48419 .43178 L closepath p
1 g
F P
s
P
p
.002 w
.5309 .44092 m .54061 .42521 L .5144 .41413 L p
1 g
F P
s
P
p
.002 w
.51645 .40505 m .5144 .41413 L .54061 .42521 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .5144 .41413 L .51645 .40505 L closepath p
1 g
F P
s
P
p
.002 w
.44816 .44421 m .46318 .45486 L .47525 .42912 L p
1 g
F P
s
P
p
.002 w
.47525 .42912 m .46767 .42372 L .44816 .44421 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .46767 .42372 L .47525 .42912 L closepath p
1 g
F P
s
P
p
.002 w
.50522 .48672 m .53068 .47696 L .51664 .4527 L p
1 g
F P
s
P
p
.002 w
.51664 .4527 m .49936 .45933 L .50522 .48672 L p
1 g
F P
s
P
p
.002 w
.5309 .44092 m .51664 .4527 L .53068 .47696 L p
1 g
F P
s
P
p
.002 w
.47801 .48785 m .50522 .48672 L .49936 .45933 L p
1 g
F P
s
P
p
.002 w
.49936 .45933 m .48088 .46007 L .47801 .48785 L p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .51543 .39581 L .51143 .38742 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .46365 .38921 L .46015 .3979 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .46015 .3979 L .45968 .40722 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .45968 .40722 L .46229 .41614 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .46229 .41614 L .46767 .42372 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .51645 .40505 L .51543 .39581 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .51143 .38742 L .50489 .38079 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .50489 .38079 L .4965 .37664 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .4965 .37664 L .48718 .37545 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .48718 .37545 L .47794 .37733 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .47794 .37733 L .46981 .38209 L closepath p
1 g
F P
s
P
p
.002 w
.48789 .40347 m .46981 .38209 L .46365 .38921 L closepath p
1 g
F P
s
P
p
.002 w
.54061 .42521 m .54472 .40725 L .51645 .40505 L p
1 g
F P
s
P
p
.002 w
.51543 .39581 m .51645 .40505 L .54472 .40725 L p
1 g
F P
s
P
p
.002 w
.53068 .47696 m .55169 .45962 L .5309 .44092 L p
1 g
F P
s
P
p
.002 w
.54061 .42521 m .5309 .44092 L .55169 .45962 L p
1 g
F P
s
P
p
.002 w
.43745 .42924 m .44816 .44421 L .46767 .42372 L p
1 g
F P
s
P
p
.002 w
.46767 .42372 m .46229 .41614 L .43745 .42924 L p
1 g
F P
s
P
p
.002 w
.45191 .48022 m .47801 .48785 L .48088 .46007 L p
1 g
F P
s
P
p
.002 w
.48088 .46007 m .46318 .45486 L .45191 .48022 L p
1 g
F P
s
P
p
.002 w
.51143 .38742 m .51543 .39581 L .54275 .38895 L p
1 g
F P
s
P
p
.002 w
.54472 .40725 m .54275 .38895 L .51543 .39581 L p
1 g
F P
s
P
p
.002 w
.43223 .41156 m .43745 .42924 L .46229 .41614 L p
1 g
F P
s
P
p
.002 w
.46229 .41614 m .45968 .40722 L .43223 .41156 L p
1 g
F P
s
P
p
.002 w
.55169 .45962 m .56604 .4365 L .54061 .42521 L p
1 g
F P
s
P
p
.002 w
.54472 .40725 m .54061 .42521 L .56604 .4365 L p
1 g
F P
s
P
p
.002 w
.42972 .46457 m .45191 .48022 L .46318 .45486 L p
1 g
F P
s
P
p
.002 w
.46318 .45486 m .44816 .44421 L .42972 .46457 L p
1 g
F P
s
P
p
.002 w
.54275 .38895 m .53488 .3723 L .51143 .38742 L p
1 g
F P
s
P
p
.002 w
.50489 .38079 m .51143 .38742 L .53488 .3723 L p
1 g
F P
s
P
p
.002 w
.43311 .39307 m .43223 .41156 L .45968 .40722 L p
1 g
F P
s
P
p
.002 w
.45968 .40722 m .46015 .3979 L .43311 .39307 L p
1 g
F P
s
P
p
.002 w
.53488 .3723 m .52193 .3591 L .50489 .38079 L p
1 g
F P
s
P
p
.002 w
.4965 .37664 m .50489 .38079 L .52193 .3591 L p
1 g
F P
s
P
p
.002 w
.56604 .4365 m .57216 .41004 L .54472 .40725 L p
1 g
F P
s
P
p
.002 w
.54275 .38895 m .54472 .40725 L .57216 .41004 L p
1 g
F P
s
P
p
.002 w
.44002 .37579 m .43311 .39307 L .46015 .3979 L p
1 g
F P
s
P
p
.002 w
.46015 .3979 m .46365 .38921 L .44002 .37579 L p
1 g
F P
s
P
p
.002 w
.41384 .44254 m .42972 .46457 L .44816 .44421 L p
1 g
F P
s
P
p
.002 w
.44816 .44421 m .43745 .42924 L .41384 .44254 L p
1 g
F P
s
P
p
.002 w
.52193 .3591 m .5053 .35083 L .4965 .37664 L p
1 g
F P
s
P
p
.002 w
.48718 .37545 m .4965 .37664 L .5053 .35083 L p
1 g
F P
s
P
p
.002 w
.45223 .36162 m .44002 .37579 L .46365 .38921 L p
1 g
F P
s
P
p
.002 w
.46365 .38921 m .46981 .38209 L .45223 .36162 L p
1 g
F P
s
P
p
.002 w
.51103 .51308 m .54413 .50038 L .53068 .47696 L p
1 g
F P
s
P
p
.002 w
.53068 .47696 m .50522 .48672 L .51103 .51308 L p
1 g
F P
s
P
p
.002 w
.55169 .45962 m .53068 .47696 L .54413 .50038 L p
1 g
F P
s
P
p
.002 w
.47564 .51459 m .51103 .51308 L .50522 .48672 L p
1 g
F P
s
P
p
.002 w
.50522 .48672 m .47801 .48785 L .47564 .51459 L p
1 g
F P
s
P
p
.002 w
.5053 .35083 m .48678 .34842 L .48718 .37545 L p
1 g
F P
s
P
p
.002 w
.47794 .37733 m .48718 .37545 L .48678 .34842 L p
1 g
F P
s
P
p
.002 w
.46841 .35215 m .45223 .36162 L .46981 .38209 L p
1 g
F P
s
P
p
.002 w
.46981 .38209 m .47794 .37733 L .46841 .35215 L p
1 g
F P
s
P
p
.002 w
.48678 .34842 m .46841 .35215 L .47794 .37733 L p
1 g
F P
s
P
p
.002 w
.54413 .50038 m .57149 .47785 L .55169 .45962 L p
1 g
F P
s
P
p
.002 w
.56604 .4365 m .55169 .45962 L .57149 .47785 L p
1 g
F P
s
P
p
.002 w
.53488 .3723 m .54275 .38895 L .56933 .38303 L p
1 g
F P
s
P
p
.002 w
.57216 .41004 m .56933 .38303 L .54275 .38895 L p
1 g
F P
s
P
p
.002 w
.44166 .50473 m .47564 .51459 L .47801 .48785 L p
1 g
F P
s
P
p
.002 w
.47801 .48785 m .45191 .48022 L .44166 .50473 L p
1 g
F P
s
P
p
.002 w
.40605 .41643 m .41384 .44254 L .43745 .42924 L p
1 g
F P
s
P
p
.002 w
.43745 .42924 m .43223 .41156 L .40605 .41643 L p
1 g
F P
s
P
p
.002 w
.57149 .47785 m .59021 .4478 L .56604 .4365 L p
1 g
F P
s
P
p
.002 w
.57216 .41004 m .56604 .4365 L .59021 .4478 L p
1 g
F P
s
P
p
.002 w
.56933 .38303 m .55779 .35839 L .53488 .3723 L p
1 g
F P
s
P
p
.002 w
.52193 .3591 m .53488 .3723 L .55779 .35839 L p
1 g
F P
s
P
p
.002 w
.4127 .48443 m .44166 .50473 L .45191 .48022 L p
1 g
F P
s
P
p
.002 w
.45191 .48022 m .42972 .46457 L .4127 .48443 L p
1 g
F P
s
P
p
.002 w
.40727 .38908 m .40605 .41643 L .43223 .41156 L p
1 g
F P
s
P
p
.002 w
.43223 .41156 m .43311 .39307 L .40727 .38908 L p
1 g
F P
s
P
p
.002 w
.55779 .35839 m .5387 .33883 L .52193 .3591 L p
1 g
F P
s
P
p
.002 w
.5053 .35083 m .52193 .3591 L .5387 .33883 L p
1 g
F P
s
P
p
.002 w
.59021 .4478 m .59825 .41337 L .57216 .41004 L p
1 g
F P
s
P
p
.002 w
.56933 .38303 m .57216 .41004 L .59825 .41337 L p
1 g
F P
s
P
p
.002 w
.41745 .36348 m .40727 .38908 L .43311 .39307 L p
1 g
F P
s
P
p
.002 w
.43311 .39307 m .44002 .37579 L .41745 .36348 L p
1 g
F P
s
P
p
.002 w
.39192 .45577 m .4127 .48443 L .42972 .46457 L p
1 g
F P
s
P
p
.002 w
.42972 .46457 m .41384 .44254 L .39192 .45577 L p
1 g
F P
s
P
p
.002 w
.5387 .33883 m .51411 .32654 L .5053 .35083 L p
1 g
F P
s
P
p
.002 w
.48678 .34842 m .5053 .35083 L .51411 .32654 L p
1 g
F P
s
P
p
.002 w
.43552 .34248 m .41745 .36348 L .44002 .37579 L p
1 g
F P
s
P
p
.002 w
.44002 .37579 m .45223 .36162 L .43552 .34248 L p
1 g
F P
s
P
p
.002 w
.51668 .53788 m .55675 .52251 L .54413 .50038 L p
1 g
F P
s
P
p
.002 w
.54413 .50038 m .51103 .51308 L .51668 .53788 L p
1 g
F P
s
P
p
.002 w
.57149 .47785 m .54413 .50038 L .55675 .52251 L p
1 g
F P
s
P
p
.002 w
.51411 .32654 m .48669 .32293 L .48678 .34842 L p
1 g
F P
s
P
p
.002 w
.46841 .35215 m .48678 .34842 L .48669 .32293 L p
1 g
F P
s
P
p
.002 w
.47382 .53977 m .51668 .53788 L .51103 .51308 L p
1 g
F P
s
P
p
.002 w
.51103 .51308 m .47564 .51459 L .47382 .53977 L p
1 g
F P
s
P
p
.002 w
.45949 .32844 m .43552 .34248 L .45223 .36162 L p
1 g
F P
s
P
p
.002 w
.45223 .36162 m .46841 .35215 L .45949 .32844 L p
1 g
F P
s
P
p
.002 w
.55779 .35839 m .56933 .38303 L .59467 .37818 L p
1 g
F P
s
P
p
.002 w
.59825 .41337 m .59467 .37818 L .56933 .38303 L p
1 g
F P
s
P
p
.002 w
.48669 .32293 m .45949 .32844 L .46841 .35215 L p
1 g
F P
s
P
p
.002 w
.55675 .52251 m .58989 .49525 L .57149 .47785 L p
1 g
F P
s
P
p
.002 w
.59021 .4478 m .57149 .47785 L .58989 .49525 L p
1 g
F P
s
P
p
.002 w
.38166 .42175 m .39192 .45577 L .41384 .44254 L p
1 g
F P
s
P
p
.002 w
.41384 .44254 m .40605 .41643 L .38166 .42175 L p
1 g
F P
s
P
p
.002 w
.43264 .5279 m .47382 .53977 L .47564 .51459 L p
1 g
F P
s
P
p
.002 w
.47564 .51459 m .44166 .50473 L .43264 .5279 L p
1 g
F P
s
P
p
.002 w
.58989 .49525 m .61262 .45891 L .59021 .4478 L p
1 g
F P
s
P
p
.002 w
.59825 .41337 m .59021 .4478 L .61262 .45891 L p
1 g
F P
s
P
p
.002 w
.59467 .37818 m .57971 .34601 L .55779 .35839 L p
1 g
F P
s
P
p
.002 w
.5387 .33883 m .55779 .35839 L .57971 .34601 L p
1 g
F P
s
P
p
.002 w
.39749 .50339 m .43264 .5279 L .44166 .50473 L p
1 g
F P
s
P
p
.002 w
.44166 .50473 m .4127 .48443 L .39749 .50339 L p
1 g
F P
s
P
p
.002 w
.38318 .38604 m .38166 .42175 L .40605 .41643 L p
1 g
F P
s
P
p
.002 w
.40605 .41643 m .40727 .38908 L .38318 .38604 L p
1 g
F P
s
P
p
.002 w
.57971 .34601 m .55487 .32041 L .5387 .33883 L p
1 g
F P
s
P
p
.002 w
.51411 .32654 m .5387 .33883 L .55487 .32041 L p
1 g
F P
s
P
p
.002 w
.61262 .45891 m .62246 .4172 L .59825 .41337 L p
1 g
F P
s
P
p
.002 w
.59467 .37818 m .59825 .41337 L .62246 .4172 L p
1 g
F P
s
P
p
.002 w
.39642 .35256 m .38318 .38604 L .40727 .38908 L p
1 g
F P
s
P
p
.002 w
.40727 .38908 m .41745 .36348 L .39642 .35256 L p
1 g
F P
s
P
p
.002 w
.3722 .46869 m .39749 .50339 L .4127 .48443 L p
1 g
F P
s
P
p
.002 w
.4127 .48443 m .39192 .45577 L .3722 .46869 L p
1 g
F P
s
P
p
.002 w
.55487 .32041 m .52278 .30428 L .51411 .32654 L p
1 g
F P
s
P
p
.002 w
.48669 .32293 m .51411 .32654 L .52278 .30428 L p
1 g
F P
s
P
p
.002 w
.42001 .32507 m .39642 .35256 L .41745 .36348 L p
1 g
F P
s
P
p
.002 w
.41745 .36348 m .43552 .34248 L .42001 .32507 L p
1 g
F P
s
P
p
.002 w
.52204 .56061 m .56825 .54287 L .55675 .52251 L p
1 g
F P
s
P
p
.002 w
.55675 .52251 m .51668 .53788 L .52204 .56061 L p
1 g
F P
s
P
p
.002 w
.58989 .49525 m .55675 .52251 L .56825 .54287 L p
1 g
F P
s
P
p
.002 w
.57971 .34601 m .59467 .37818 L .61823 .37452 L p
1 g
F P
s
P
p
.002 w
.62246 .4172 m .61823 .37452 L .59467 .37818 L p
1 g
F P
s
P
p
.002 w
.52278 .30428 m .48694 .29951 L .48669 .32293 L p
1 g
F P
s
P
p
.002 w
.45949 .32844 m .48669 .32293 L .48694 .29951 L p
1 g
F P
s
P
p
.002 w
.47262 .56283 m .52204 .56061 L .51668 .53788 L p
1 g
F P
s
P
p
.002 w
.51668 .53788 m .47382 .53977 L .47262 .56283 L p
1 g
F P
s
P
p
.002 w
.45135 .3067 m .42001 .32507 L .43552 .34248 L p
1 g
F P
s
P
p
.002 w
.43552 .34248 m .45949 .32844 L .45135 .3067 L p
1 g
F P
s
P
p
.002 w
.48694 .29951 m .45135 .3067 L .45949 .32844 L p
1 g
F P
s
P
p
.002 w
.56825 .54287 m .60649 .51147 L .58989 .49525 L p
1 g
F P
s
P
p
.002 w
.61262 .45891 m .58989 .49525 L .60649 .51147 L p
1 g
F P
s
P
p
.002 w
.35964 .42743 m .3722 .46869 L .39192 .45577 L p
1 g
F P
s
P
p
.002 w
.39192 .45577 m .38166 .42175 L .35964 .42743 L p
1 g
F P
s
P
p
.002 w
.42509 .54921 m .47262 .56283 L .47382 .53977 L p
1 g
F P
s
P
p
.002 w
.47382 .53977 m .43264 .5279 L .42509 .54921 L p
1 g
F P
s
P
p
.002 w
.60649 .51147 m .63277 .46958 L .61262 .45891 L p
1 g
F P
s
P
p
.002 w
.62246 .4172 m .61262 .45891 L .63277 .46958 L p
1 g
F P
s
P
p
.002 w
.61823 .37452 m .60019 .33544 L .57971 .34601 L p
1 g
F P
s
P
p
.002 w
.55487 .32041 m .57971 .34601 L .60019 .33544 L p
1 g
F P
s
P
p
.002 w
.38445 .52101 m .42509 .54921 L .43264 .5279 L p
1 g
F P
s
P
p
.002 w
.43264 .5279 m .39749 .50339 L .38445 .52101 L p
1 g
F P
s
P
p
.002 w
.36137 .38403 m .35964 .42743 L .38166 .42175 L p
1 g
F P
s
P
p
.002 w
.38166 .42175 m .38318 .38604 L .36137 .38403 L p
1 g
F P
s
P
p
.002 w
.60019 .33544 m .57009 .30427 L .55487 .32041 L p
1 g
F P
s
P
p
.002 w
.52278 .30428 m .55487 .32041 L .57009 .30427 L p
1 g
F P
s
P
p
.002 w
.63277 .46958 m .64423 .42148 L .62246 .4172 L p
1 g
F P
s
P
p
.002 w
.61823 .37452 m .62246 .4172 L .64423 .42148 L p
1 g
F P
s
P
p
.002 w
.3774 .3433 m .36137 .38403 L .38318 .38604 L p
1 g
F P
s
P
p
.002 w
.38318 .38604 m .39642 .35256 L .3774 .3433 L p
1 g
F P
s
P
p
.002 w
.35515 .48102 m .38445 .52101 L .39749 .50339 L p
1 g
F P
s
P
p
.002 w
.39749 .50339 m .3722 .46869 L .35515 .48102 L p
1 g
F P
s
P
p
.002 w
.57009 .30427 m .53112 .28459 L .52278 .30428 L p
1 g
F P
s
P
p
.002 w
.48694 .29951 m .52278 .30428 L .53112 .28459 L p
1 g
F P
s
P
p
.002 w
.40607 .30983 m .3774 .3433 L .39642 .35256 L p
1 g
F P
s
P
p
.002 w
.39642 .35256 m .42001 .32507 L .40607 .30983 L p
1 g
F P
s
P
p
.002 w
.60019 .33544 m .61823 .37452 L .63946 .37218 L p
1 g
F P
s
P
p
.002 w
.64423 .42148 m .63946 .37218 L .61823 .37452 L p
1 g
F P
s
P
p
.002 w
.527 .58069 m .57836 .56098 L .56825 .54287 L p
1 g
F P
s
P
p
.002 w
.56825 .54287 m .52204 .56061 L .527 .58069 L p
1 g
F P
s
P
p
.002 w
.60649 .51147 m .56825 .54287 L .57836 .56098 L p
1 g
F P
s
P
p
.002 w
.53112 .28459 m .48753 .27873 L .48694 .29951 L p
1 g
F P
s
P
p
.002 w
.45135 .3067 m .48694 .29951 L .48753 .27873 L p
1 g
F P
s
P
p
.002 w
.47208 .58321 m .527 .58069 L .52204 .56061 L p
1 g
F P
s
P
p
.002 w
.52204 .56061 m .47262 .56283 L .47208 .58321 L p
1 g
F P
s
P
p
.002 w
.44421 .28746 m .40607 .30983 L .42001 .32507 L p
1 g
F P
s
P
p
.002 w
.42001 .32507 m .45135 .3067 L .44421 .28746 L p
1 g
F P
s
P
p
.002 w
.48753 .27873 m .44421 .28746 L .45135 .3067 L p
1 g
F P
s
P
p
.002 w
.34052 .43336 m .35515 .48102 L .3722 .46869 L p
1 g
F P
s
P
p
.002 w
.3722 .46869 m .35964 .42743 L .34052 .43336 L p
1 g
F P
s
P
p
.002 w
.57836 .56098 m .62088 .5261 L .60649 .51147 L p
1 g
F P
s
P
p
.002 w
.63277 .46958 m .60649 .51147 L .62088 .5261 L p
1 g
F P
s
P
p
.002 w
.41922 .56816 m .47208 .58321 L .47262 .56283 L p
1 g
F P
s
P
p
.002 w
.47262 .56283 m .42509 .54921 L .41922 .56816 L p
1 g
F P
s
P
p
.002 w
.63946 .37218 m .61872 .32697 L .60019 .33544 L p
1 g
F P
s
P
p
.002 w
.57009 .30427 m .60019 .33544 L .61872 .32697 L p
1 g
F P
s
P
p
.002 w
.62088 .5261 m .65015 .47958 L .63277 .46958 L p
1 g
F P
s
P
p
.002 w
.64423 .42148 m .63277 .46958 L .65015 .47958 L p
1 g
F P
s
P
p
.002 w
.37397 .53688 m .41922 .56816 L .42509 .54921 L p
1 g
F P
s
P
p
.002 w
.42509 .54921 m .38445 .52101 L .37397 .53688 L p
1 g
F P
s
P
p
.002 w
.34243 .38316 m .34052 .43336 L .35964 .42743 L p
1 g
F P
s
P
p
.002 w
.35964 .42743 m .36137 .38403 L .34243 .38316 L p
1 g
F P
s
P
p
.002 w
.61872 .32697 m .58399 .29087 L .57009 .30427 L p
1 g
F P
s
P
p
.002 w
.53112 .28459 m .57009 .30427 L .58399 .29087 L p
1 g
F P
s
P
p
.002 w
.65015 .47958 m .66299 .42612 L .64423 .42148 L p
1 g
F P
s
P
p
.002 w
.63946 .37218 m .64423 .42148 L .66299 .42612 L p
1 g
F P
s
P
p
.002 w
.36092 .33598 m .34243 .38316 L .36137 .38403 L p
1 g
F P
s
P
p
.002 w
.36137 .38403 m .3774 .3433 L .36092 .33598 L p
1 g
F P
s
P
p
.002 w
.34127 .49245 m .37397 .53688 L .38445 .52101 L p
1 g
F P
s
P
p
.002 w
.38445 .52101 m .35515 .48102 L .34127 .49245 L p
1 g
F P
s
P
p
.002 w
.58399 .29087 m .53893 .26802 L .53112 .28459 L p
1 g
F P
s
P
p
.002 w
.48753 .27873 m .53112 .28459 L .53893 .26802 L p
1 g
F P
s
P
p
.002 w
.39409 .29719 m .36092 .33598 L .3774 .3433 L p
1 g
F P
s
P
p
.002 w
.3774 .3433 m .40607 .30983 L .39409 .29719 L p
1 g
F P
s
P
p
.002 w
.66299 .42612 m .6578 .37127 L .63946 .37218 L p
1 g
F P
s
P
p
.002 w
.61872 .32697 m .63946 .37218 L .6578 .37127 L p
1 g
F P
s
P
p
.002 w
.53144 .59758 m .58678 .57633 L .57836 .56098 L p
1 g
F P
s
P
p
.002 w
.57836 .56098 m .527 .58069 L .53144 .59758 L p
1 g
F P
s
P
p
.002 w
.62088 .5261 m .57836 .56098 L .58678 .57633 L p
1 g
F P
s
P
p
.002 w
.53893 .26802 m .48846 .26118 L .48753 .27873 L p
1 g
F P
s
P
p
.002 w
.44421 .28746 m .48753 .27873 L .48846 .26118 L p
1 g
F P
s
P
p
.002 w
.47224 .60034 m .53144 .59758 L .527 .58069 L p
1 g
F P
s
P
p
.002 w
.527 .58069 m .47208 .58321 L .47224 .60034 L p
1 g
F P
s
P
p
.002 w
.43828 .27127 m .39409 .29719 L .40607 .30983 L p
1 g
F P
s
P
p
.002 w
.40607 .30983 m .44421 .28746 L .43828 .27127 L p
1 g
F P
s
P
p
.002 w
.32489 .43943 m .34127 .49245 L .35515 .48102 L p
1 g
F P
s
P
p
.002 w
.35515 .48102 m .34052 .43336 L .32489 .43943 L p
1 g
F P
s
P
p
.002 w
.48846 .26118 m .43828 .27127 L .44421 .28746 L p
1 g
F P
s
P
p
.002 w
.58678 .57633 m .63262 .53876 L .62088 .5261 L p
1 g
F P
s
P
p
.002 w
.65015 .47958 m .62088 .5261 L .63262 .53876 L p
1 g
F P
s
P
p
.002 w
.41524 .58418 m .47224 .60034 L .47208 .58321 L p
1 g
F P
s
P
p
.002 w
.47208 .58321 m .41922 .56816 L .41524 .58418 L p
1 g
F P
s
P
p
.002 w
.6578 .37127 m .63481 .32091 L .61872 .32697 L p
1 g
F P
s
P
p
.002 w
.58399 .29087 m .61872 .32697 L .63481 .32091 L p
1 g
F P
s
P
p
.002 w
.63262 .53876 m .66423 .48865 L .65015 .47958 L p
1 g
F P
s
P
p
.002 w
.66299 .42612 m .65015 .47958 L .66423 .48865 L p
1 g
F P
s
P
p
.002 w
.32693 .3835 m .32489 .43943 L .34052 .43336 L p
1 g
F P
s
P
p
.002 w
.34052 .43336 m .34243 .38316 L .32693 .3835 L p
1 g
F P
s
P
p
.002 w
.36641 .55054 m .41524 .58418 L .41922 .56816 L p
1 g
F P
s
P
p
.002 w
.41922 .56816 m .37397 .53688 L .36641 .55054 L p
1 g
F P
s
P
p
.002 w
.63481 .32091 m .5962 .28063 L .58399 .29087 L p
1 g
F P
s
P
p
.002 w
.53893 .26802 m .58399 .29087 L .5962 .28063 L p
1 g
F P
s
P
p
.002 w
.66423 .48865 m .67816 .43105 L .66299 .42612 L p
1 g
F P
s
P
p
.002 w
.6578 .37127 m .66299 .42612 L .67816 .43105 L p
1 g
F P
s
P
p
.002 w
.34748 .33088 m .32693 .3835 L .34243 .38316 L p
1 g
F P
s
P
p
.002 w
.34243 .38316 m .36092 .33598 L .34748 .33088 L p
1 g
F P
s
P
p
.002 w
.33107 .50268 m .36641 .55054 L .37397 .53688 L p
1 g
F P
s
P
p
.002 w
.37397 .53688 m .34127 .49245 L .33107 .50268 L p
1 g
F P
s
P
p
.002 w
.5962 .28063 m .54601 .2551 L .53893 .26802 L p
1 g
F P
s
P
p
.002 w
.48846 .26118 m .53893 .26802 L .54601 .2551 L p
1 g
F P
s
P
p
.002 w
.38445 .28759 m .34748 .33088 L .36092 .33598 L p
1 g
F P
s
P
p
.002 w
.36092 .33598 m .39409 .29719 L .38445 .28759 L p
1 g
F P
s
P
p
.002 w
.67816 .43105 m .67265 .37189 L .6578 .37127 L p
1 g
F P
s
P
p
.002 w
.63481 .32091 m .6578 .37127 L .67265 .37189 L p
1 g
F P
s
P
p
.002 w
.53521 .6107 m .59323 .58841 L .58678 .57633 L p
1 g
F P
s
P
p
.002 w
.58678 .57633 m .53144 .59758 L .53521 .6107 L p
1 g
F P
s
P
p
.002 w
.63262 .53876 m .58678 .57633 L .59323 .58841 L p
1 g
F P
s
P
p
.002 w
.54601 .2551 m .48973 .24742 L .48846 .26118 L p
1 g
F P
s
P
p
.002 w
.43828 .27127 m .48846 .26118 L .48973 .24742 L p
1 g
F P
s
P
p
.002 w
.47315 .61363 m .53521 .6107 L .53144 .59758 L p
1 g
F P
s
P
p
.002 w
.53144 .59758 m .47224 .60034 L .47315 .61363 L p
1 g
F P
s
P
p
.002 w
.43374 .25866 m .38445 .28759 L .39409 .29719 L p
1 g
F P
s
P
p
.002 w
.39409 .29719 m .43828 .27127 L .43374 .25866 L p
1 g
F P
s
P
p
.002 w
.31331 .4455 m .33107 .50268 L .34127 .49245 L p
1 g
F P
s
P
p
.002 w
.34127 .49245 m .32489 .43943 L .31331 .4455 L p
1 g
F P
s
P
p
.002 w
.48973 .24742 m .43374 .25866 L .43828 .27127 L p
1 g
F P
s
P
p
.002 w
.59323 .58841 m .64132 .54905 L .63262 .53876 L p
1 g
F P
s
P
p
.002 w
.66423 .48865 m .63262 .53876 L .64132 .54905 L p
1 g
F P
s
P
p
.002 w
.41337 .59675 m .47315 .61363 L .47224 .60034 L p
1 g
F P
s
P
p
.002 w
.47224 .60034 m .41524 .58418 L .41337 .59675 L p
1 g
F P
s
P
p
.002 w
.67265 .37189 m .64794 .31752 L .63481 .32091 L p
1 g
F P
s
P
p
.002 w
.5962 .28063 m .63481 .32091 L .64794 .31752 L p
1 g
F P
s
P
p
.002 w
.64132 .54905 m .6745 .49654 L .66423 .48865 L p
1 g
F P
s
P
p
.002 w
.67816 .43105 m .66423 .48865 L .6745 .49654 L p
1 g
F P
s
P
p
.002 w
.31544 .38511 m .31331 .4455 L .32489 .43943 L p
1 g
F P
s
P
p
.002 w
.32489 .43943 m .32693 .3835 L .31544 .38511 L p
1 g
F P
s
P
p
.002 w
.36213 .56153 m .41337 .59675 L .41524 .58418 L p
1 g
F P
s
P
p
.002 w
.41524 .58418 m .36641 .55054 L .36213 .56153 L p
1 g
F P
s
P
p
.002 w
.64794 .31752 m .60632 .27399 L .5962 .28063 L p
1 g
F P
s
P
p
.002 w
.54601 .2551 m .5962 .28063 L .60632 .27399 L p
1 g
F P
s
P
p
.002 w
.6745 .49654 m .68917 .43615 L .67816 .43105 L p
1 g
F P
s
P
p
.002 w
.67265 .37189 m .67816 .43105 L .68917 .43615 L p
1 g
F P
s
P
p
.002 w
.33759 .32826 m .31544 .38511 L .32693 .3835 L p
1 g
F P
s
P
p
.002 w
.32693 .3835 m .34748 .33088 L .33759 .32826 L p
1 g
F P
s
P
p
.002 w
.32501 .51138 m .36213 .56153 L .36641 .55054 L p
1 g
F P
s
P
p
.002 w
.36641 .55054 m .33107 .50268 L .32501 .51138 L p
1 g
F P
s
P
p
.002 w
.60632 .27399 m .55214 .24636 L .54601 .2551 L p
1 g
F P
s
P
p
.002 w
.48973 .24742 m .54601 .2551 L .55214 .24636 L p
1 g
F P
s
P
p
.002 w
.37752 .28145 m .33759 .32826 L .34748 .33088 L p
1 g
F P
s
P
p
.002 w
.34748 .33088 m .38445 .28759 L .37752 .28145 L p
1 g
F P
s
P
p
.002 w
.68917 .43615 m .68347 .37412 L .67265 .37189 L p
1 g
F P
s
P
p
.002 w
.64794 .31752 m .67265 .37189 L .68347 .37412 L p
1 g
F P
s
P
p
.002 w
.53819 .6195 m .59744 .59674 L .59323 .58841 L p
1 g
F P
s
P
p
.002 w
.59323 .58841 m .53521 .6107 L .53819 .6195 L p
1 g
F P
s
P
p
.002 w
.64132 .54905 m .59323 .58841 L .59744 .59674 L p
1 g
F P
s
P
p
.002 w
.55214 .24636 m .49133 .23804 L .48973 .24742 L p
1 g
F P
s
P
p
.002 w
.43374 .25866 m .48973 .24742 L .49133 .23804 L p
1 g
F P
s
P
p
.002 w
.47482 .62252 m .53819 .6195 L .53521 .6107 L p
1 g
F P
s
P
p
.002 w
.53521 .6107 m .47315 .61363 L .47482 .62252 L p
1 g
F P
s
P
p
.002 w
.30632 .45141 m .32501 .51138 L .33107 .50268 L p
1 g
F P
s
P
p
.002 w
.33107 .50268 m .31331 .4455 L .30632 .45141 L p
1 g
F P
s
P
p
.002 w
.43081 .25017 m .37752 .28145 L .38445 .28759 L p
1 g
F P
s
P
p
.002 w
.38445 .28759 m .43374 .25866 L .43081 .25017 L p
1 g
F P
s
P
p
.002 w
.49133 .23804 m .43081 .25017 L .43374 .25866 L p
1 g
F P
s
P
p
.002 w
.59744 .59674 m .64655 .55656 L .64132 .54905 L p
1 g
F P
s
P
p
.002 w
.6745 .49654 m .64132 .54905 L .64655 .55656 L p
1 g
F P
s
P
p
.002 w
.41378 .60532 m .47482 .62252 L .47315 .61363 L p
1 g
F P
s
P
p
.002 w
.47315 .61363 m .41337 .59675 L .41378 .60532 L p
1 g
F P
s
P
p
.002 w
.68347 .37412 m .6576 .31706 L .64794 .31752 L p
1 g
F P
s
P
p
.002 w
.60632 .27399 m .64794 .31752 L .6576 .31706 L p
1 g
F P
s
P
p
.002 w
.64655 .55656 m .68046 .50296 L .6745 .49654 L p
1 g
F P
s
P
p
.002 w
.68917 .43615 m .6745 .49654 L .68046 .50296 L p
1 g
F P
s
P
p
.002 w
.30851 .38804 m .30632 .45141 L .31331 .4455 L p
1 g
F P
s
P
p
.002 w
.31331 .4455 m .31544 .38511 L .30851 .38804 L p
1 g
F P
s
P
p
.002 w
.36144 .5694 m .41378 .60532 L .41337 .59675 L p
1 g
F P
s
P
p
.002 w
.41337 .59675 m .36213 .56153 L .36144 .5694 L p
1 g
F P
s
P
p
.002 w
.6576 .31706 m .61397 .27134 L .60632 .27399 L p
1 g
F P
s
P
p
.002 w
.55214 .24636 m .60632 .27399 L .61397 .27134 L p
1 g
F P
s
P
p
.002 w
.68046 .50296 m .69548 .44132 L .68917 .43615 L p
1 g
F P
s
P
p
.002 w
.68347 .37412 m .68917 .43615 L .69548 .44132 L p
1 g
F P
s
P
p
.002 w
.33174 .32833 m .30851 .38804 L .31544 .38511 L p
1 g
F P
s
P
p
.002 w
.31544 .38511 m .33759 .32826 L .33174 .32833 L p
1 g
F P
s
P
p
.002 w
.32351 .51823 m .36144 .5694 L .36213 .56153 L p
1 g
F P
s
P
p
.002 w
.36213 .56153 m .32501 .51138 L .32351 .51823 L p
1 g
F P
s
P
p
.002 w
.61397 .27134 m .5571 .24231 L .55214 .24636 L p
1 g
F P
s
P
p
.002 w
.49133 .23804 m .55214 .24636 L .5571 .24231 L p
1 g
F P
s
P
p
.002 w
.37368 .27915 m .33174 .32833 L .33759 .32826 L p
1 g
F P
s
P
p
.002 w
.33759 .32826 m .37752 .28145 L .37368 .27915 L p
1 g
F P
s
P
p
.002 w
.69548 .44132 m .6897 .37798 L .68347 .37412 L p
1 g
F P
s
P
p
.002 w
.6576 .31706 m .68347 .37412 L .6897 .37798 L p
1 g
F P
s
P
p
.002 w
.5571 .24231 m .49324 .23354 L .49133 .23804 L p
1 g
F P
s
P
p
.002 w
.43081 .25017 m .49133 .23804 L .49324 .23354 L p
1 g
F P
s
P
p
.002 w
.54025 .62348 m .59914 .60085 L .59744 .59674 L p
1 g
F P
s
P
p
.002 w
.59744 .59674 m .53819 .6195 L .54025 .62348 L p
1 g
F P
s
P
p
.002 w
.64655 .55656 m .59744 .59674 L .59914 .60085 L p
1 g
F P
s
P
p
.002 w
.3044 .457 m .32351 .51823 L .32501 .51138 L p
1 g
F P
s
P
p
.002 w
.32501 .51138 m .30632 .45141 L .3044 .457 L p
1 g
F P
s
P
p
.002 w
.47726 .62649 m .54025 .62348 L .53819 .6195 L p
1 g
F P
s
P
p
.002 w
.53819 .6195 m .47482 .62252 L .47726 .62649 L p
1 g
F P
s
P
p
.002 w
.42965 .24628 m .37368 .27915 L .37752 .28145 L p
1 g
F P
s
P
p
.002 w
.37752 .28145 m .43081 .25017 L .42965 .24628 L p
1 g
F P
s
P
p
.002 w
.49324 .23354 m .42965 .24628 L .43081 .25017 L p
1 g
F P
s
P
p
.002 w
.59914 .60085 m .64797 .56091 L .64655 .55656 L p
1 g
F P
s
P
p
.002 w
.68046 .50296 m .64655 .55656 L .64797 .56091 L p
1 g
F P
s
P
p
.002 w
.41659 .60941 m .47726 .62649 L .47482 .62252 L p
1 g
F P
s
P
p
.002 w
.47482 .62252 m .41378 .60532 L .41659 .60941 L p
1 g
F P
s
P
p
.002 w
.6897 .37798 m .66332 .31971 L .6576 .31706 L p
1 g
F P
s
P
p
.002 w
.61397 .27134 m .6576 .31706 L .66332 .31971 L p
1 g
F P
s
P
p
.002 w
.64797 .56091 m .68168 .50765 L .68046 .50296 L p
1 g
F P
s
P
p
.002 w
.69548 .44132 m .68046 .50296 L .68168 .50765 L p
1 g
F P
s
P
p
.002 w
.30663 .39227 m .3044 .457 L .30632 .45141 L p
1 g
F P
s
P
p
.002 w
.30632 .45141 m .30851 .38804 L .30663 .39227 L p
1 g
F P
s
P
p
.002 w
.36459 .57374 m .41659 .60941 L .41378 .60532 L p
1 g
F P
s
P
p
.002 w
.41378 .60532 m .36144 .5694 L .36459 .57374 L p
1 g
F P
s
P
p
.004 w
.71643 .48744 m
.77244 .50217 L
s
P
p
.002 w
.66332 .31971 m .61877 .27301 L .61397 .27134 L p
1 g
F P
s
P
p
.002 w
.5571 .24231 m .61397 .27134 L .61877 .27301 L p
1 g
F P
s
P
p
.002 w
.68168 .50765 m .69662 .44641 L .69548 .44132 L p
1 g
F P
s
P
p
.002 w
.6897 .37798 m .69548 .44132 L .69662 .44641 L p
1 g
F P
s
P
p
.002 w
.33036 .33127 m .30663 .39227 L .30851 .38804 L p
1 g
F P
s
P
p
.002 w
.30851 .38804 m .33174 .32833 L .33036 .33127 L p
1 g
F P
s
P
p
.002 w
.32691 .5229 m .36459 .57374 L .36144 .5694 L p
1 g
F P
s
P
p
.002 w
.36144 .5694 m .32351 .51823 L .32691 .5229 L p
1 g
F P
s
P
p
.002 w
.61877 .27301 m .56068 .24335 L .5571 .24231 L p
1 g
F P
s
P
p
.002 w
.49324 .23354 m .5571 .24231 L .56068 .24335 L p
1 g
F P
s
P
p
.002 w
.69662 .44641 m .69088 .3835 L .6897 .37798 L p
1 g
F P
s
P
p
.002 w
.66332 .31971 m .6897 .37798 L .69088 .3835 L p
1 g
F P
s
P
p
.002 w
.37322 .28102 m .33036 .33127 L .33174 .32833 L p
1 g
F P
s
P
p
.002 w
.33174 .32833 m .37368 .27915 L .37322 .28102 L p
1 g
F P
s
P
p
.002 w
.56068 .24335 m .49543 .2344 L .49324 .23354 L p
1 g
F P
s
P
p
.002 w
.42965 .24628 m .49324 .23354 L .49543 .2344 L p
1 g
F P
s
P
p
.002 w
.30794 .46208 m .32691 .5229 L .32351 .51823 L p
1 g
F P
s
P
p
.002 w
.32351 .51823 m .3044 .457 L .30794 .46208 L p
1 g
F P
s
P
p
.002 w
.54126 .6222 m .59813 .60034 L .59914 .60085 L p
1 g
F P
s
P
p
.002 w
.59914 .60085 m .54025 .62348 L .54126 .6222 L p
1 g
F P
s
P
p
.002 w
.64797 .56091 m .59914 .60085 L .59813 .60034 L p
1 g
F P
s
P
p
.002 w
.48045 .6251 m .54126 .6222 L .54025 .62348 L p
1 g
F P
s
P
p
.002 w
.54025 .62348 m .47726 .62649 L .48045 .6251 L p
1 g
F P
s
P
p
.002 w
.43043 .24742 m .37322 .28102 L .37368 .27915 L p
1 g
F P
s
P
p
.002 w
.37368 .27915 m .42965 .24628 L .43043 .24742 L p
1 g
F P
s
P
p
.002 w
.49543 .2344 m .43043 .24742 L .42965 .24628 L p
1 g
F P
s
P
p
.002 w
.59813 .60034 m .64527 .56178 L .64797 .56091 L p
1 g
F P
s
P
p
.002 w
.68168 .50765 m .64797 .56091 L .64527 .56178 L p
1 g
F P
s
P
p
.002 w
.4219 .6086 m .48045 .6251 L .47726 .62649 L p
1 g
F P
s
P
p
.002 w
.47726 .62649 m .41659 .60941 L .4219 .6086 L p
1 g
F P
s
P
p
.002 w
.69088 .3835 m .66467 .32562 L .66332 .31971 L p
1 g
F P
s
P
p
.002 w
.61877 .27301 m .66332 .31971 L .66467 .32562 L p
1 g
F P
s
P
p
.002 w
.64527 .56178 m .67781 .51037 L .68168 .50765 L p
1 g
F P
s
P
p
.002 w
.69662 .44641 m .68168 .50765 L .67781 .51037 L p
1 g
F P
s
P
p
.002 w
.31018 .39779 m .30794 .46208 L .3044 .457 L p
1 g
F P
s
P
p
.002 w
.3044 .457 m .30663 .39227 L .31018 .39779 L p
1 g
F P
s
P
p
.002 w
.37174 .57417 m .4219 .6086 L .41659 .60941 L p
1 g
F P
s
P
p
.002 w
.41659 .60941 m .36459 .57374 L .37174 .57417 L p
1 g
F P
s
P
p
.002 w
.66467 .32562 m .62041 .27925 L .61877 .27301 L p
1 g
F P
s
P
p
.002 w
.56068 .24335 m .61877 .27301 L .62041 .27925 L p
1 g
F P
s
P
p
.002 w
.67781 .51037 m .6922 .45128 L .69662 .44641 L p
1 g
F P
s
P
p
.004 w
.69435 .48163 m
.71643 .48744 L
s
P
p
.002 w
.69088 .3835 m .69662 .44641 L .6922 .45128 L p
1 g
F P
s
P
p
.002 w
.33379 .33719 m .31018 .39779 L .30663 .39227 L p
1 g
F P
s
P
p
.002 w
.30663 .39227 m .33036 .33127 L .33379 .33719 L p
1 g
F P
s
P
p
.002 w
.33544 .52513 m .37174 .57417 L .36459 .57374 L p
1 g
F P
s
P
p
.002 w
.36459 .57374 m .32691 .5229 L .33544 .52513 L p
1 g
F P
s
P
p
.002 w
.62041 .27925 m .56268 .24981 L .56068 .24335 L p
1 g
F P
s
P
p
.002 w
.49543 .2344 m .56068 .24335 L .56268 .24981 L p
1 g
F P
s
P
p
.002 w
.6922 .45128 m .68664 .3906 L .69088 .3835 L p
1 g
F P
s
P
p
.002 w
.66467 .32562 m .69088 .3835 L .68664 .3906 L p
1 g
F P
s
P
p
.002 w
.37639 .28727 m .33379 .33719 L .33036 .33127 L p
1 g
F P
s
P
p
.002 w
.33036 .33127 m .37322 .28102 L .37639 .28727 L p
1 g
F P
s
P
p
.002 w
.3172 .46647 m .33544 .52513 L .32691 .5229 L p
1 g
F P
s
P
p
.002 w
.32691 .5229 m .30794 .46208 L .3172 .46647 L p
1 g
F P
s
P
p
.002 w
.56268 .24981 m .49784 .24094 L .49543 .2344 L p
1 g
F P
s
P
p
.002 w
.43043 .24742 m .49543 .2344 L .49784 .24094 L p
1 g
F P
s
P
p
.002 w
.54114 .61534 m .59425 .59493 L .59813 .60034 L p
1 g
F P
s
P
p
.002 w
.59813 .60034 m .54126 .6222 L .54114 .61534 L p
1 g
F P
s
P
p
.002 w
.64527 .56178 m .59813 .60034 L .59425 .59493 L p
1 g
F P
s
P
p
.002 w
.48435 .61803 m .54114 .61534 L .54126 .6222 L p
1 g
F P
s
P
p
.002 w
.54126 .6222 m .48045 .6251 L .48435 .61803 L p
1 g
F P
s
P
p
.002 w
.43325 .25389 m .37639 .28727 L .37322 .28102 L p
1 g
F P
s
P
p
.002 w
.37322 .28102 m .43043 .24742 L .43325 .25389 L p
1 g
F P
s
P
p
.002 w
.49784 .24094 m .43325 .25389 L .43043 .24742 L p
1 g
F P
s
P
p
.002 w
.59425 .59493 m .63827 .55891 L .64527 .56178 L p
1 g
F P
s
P
p
.002 w
.67781 .51037 m .64527 .56178 L .63827 .55891 L p
1 g
F P
s
P
p
.002 w
.42971 .6026 m .48435 .61803 L .48045 .6251 L p
1 g
F P
s
P
p
.002 w
.48045 .6251 m .4219 .6086 L .42971 .6026 L p
1 g
F P
s
P
p
.002 w
.68664 .3906 m .66132 .33482 L .66467 .32562 L p
1 g
F P
s
P
p
.002 w
.62041 .27925 m .66467 .32562 L .66132 .33482 L p
1 g
F P
s
P
p
.002 w
.63827 .55891 m .66862 .5109 L .67781 .51037 L p
1 g
F P
s
P
p
.002 w
.6922 .45128 m .67781 .51037 L .66862 .5109 L p
1 g
F P
s
P
p
.002 w
.31942 .4045 m .3172 .46647 L .30794 .46208 L p
1 g
F P
s
P
p
.002 w
.30794 .46208 m .31018 .39779 L .31942 .4045 L p
1 g
F P
s
P
p
.002 w
.38295 .57044 m .42971 .6026 L .4219 .6086 L p
1 g
F P
s
P
p
.002 w
.4219 .6086 m .37174 .57417 L .38295 .57044 L p
1 g
F P
s
P
p
.002 w
.66132 .33482 m .61861 .29016 L .62041 .27925 L p
1 g
F P
s
P
p
.002 w
.56268 .24981 m .62041 .27925 L .61861 .29016 L p
1 g
F P
s
P
p
.002 w
.66862 .5109 m .682 .45575 L .6922 .45128 L p
1 g
F P
s
P
p
.002 w
.68664 .3906 m .6922 .45128 L .682 .45575 L p
1 g
F P
s
P
p
.002 w
.34223 .3461 m .31942 .4045 L .31018 .39779 L p
1 g
F P
s
P
p
.002 w
.31018 .39779 m .33379 .33719 L .34223 .3461 L p
1 g
F P
s
P
p
.002 w
.34916 .52467 m .38295 .57044 L .37174 .57417 L p
1 g
F P
s
P
p
.002 w
.37174 .57417 m .33544 .52513 L .34916 .52467 L p
1 g
F P
s
P
p
.002 w
.61861 .29016 m .56293 .26183 L .56268 .24981 L p
1 g
F P
s
P
p
.002 w
.49784 .24094 m .56268 .24981 L .56293 .26183 L p
1 g
F P
s
P
p
.002 w
.66132 .33482 m .68664 .3906 L .67675 .39917 L p
1 g
F P
s
P
p
.002 w
.682 .45575 m .67675 .39917 L .68664 .3906 L p
1 g
F P
s
P
p
.002 w
.38333 .298 m .34223 .3461 L .33379 .33719 L p
1 g
F P
s
P
p
.002 w
.33379 .33719 m .37639 .28727 L .38333 .298 L p
1 g
F P
s
P
p
.002 w
.33225 .46998 m .34916 .52467 L .33544 .52513 L p
1 g
F P
s
P
p
.002 w
.33544 .52513 m .3172 .46647 L .33225 .46998 L p
1 g
F P
s
P
p
.002 w
.56293 .26183 m .50042 .25332 L .49784 .24094 L p
1 g
F P
s
P
p
.002 w
.43325 .25389 m .49784 .24094 L .50042 .25332 L p
1 g
F P
s
P
p
.002 w
.53979 .60275 m .58744 .58445 L .59425 .59493 L p
1 g
F P
s
P
p
.002 w
.59425 .59493 m .54114 .61534 L .53979 .60275 L p
1 g
F P
s
P
p
.002 w
.63827 .55891 m .59425 .59493 L .58744 .58445 L p
1 g
F P
s
P
p
.002 w
.48887 .60514 m .53979 .60275 L .54114 .61534 L p
1 g
F P
s
P
p
.002 w
.54114 .61534 m .48435 .61803 L .48887 .60514 L p
1 g
F P
s
P
p
.002 w
.43815 .26583 m .38333 .298 L .37639 .28727 L p
1 g
F P
s
P
p
.002 w
.37639 .28727 m .43325 .25389 L .43815 .26583 L p
1 g
F P
s
P
p
.002 w
.50042 .25332 m .43815 .26583 L .43325 .25389 L p
1 g
F P
s
P
p
.002 w
.58744 .58445 m .6269 .55213 L .63827 .55891 L p
1 g
F P
s
P
p
.002 w
.66862 .5109 m .63827 .55891 L .6269 .55213 L p
1 g
F P
s
P
p
.002 w
.43991 .59126 m .48887 .60514 L .48435 .61803 L p
1 g
F P
s
P
p
.002 w
.48435 .61803 m .42971 .6026 L .43991 .59126 L p
1 g
F P
s
P
p
.002 w
.67675 .39917 m .65307 .34722 L .66132 .33482 L p
1 g
F P
s
P
p
.002 w
.61861 .29016 m .66132 .33482 L .65307 .34722 L p
1 g
F P
s
P
p
.002 w
.6269 .55213 m .65407 .50907 L .66862 .5109 L p
1 g
F P
s
P
p
.002 w
.682 .45575 m .66862 .5109 L .65407 .50907 L p
1 g
F P
s
P
p
.002 w
.3344 .41225 m .33225 .46998 L .3172 .46647 L p
1 g
F P
s
P
p
.002 w
.3172 .46647 m .31942 .4045 L .3344 .41225 L p
1 g
F P
s
P
p
.002 w
.39808 .56239 m .43991 .59126 L .42971 .6026 L p
1 g
F P
s
P
p
.002 w
.42971 .6026 m .38295 .57044 L .39808 .56239 L p
1 g
F P
s
P
p
.002 w
.65307 .34722 m .61321 .30567 L .61861 .29016 L p
1 g
F P
s
P
p
.002 w
.56293 .26183 m .61861 .29016 L .61321 .30567 L p
1 g
F P
s
P
p
.002 w
.65407 .50907 m .66599 .45965 L .682 .45575 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.6627 .4733 L
s
P
p
.004 w
.67316 .47606 m
.6745 .47641 L
s
P
p
.004 w
.6745 .47641 m
.6812 .47817 L
s
P
p
.004 w
.6812 .47817 m
.69435 .48163 L
s
P
p
.002 w
.67675 .39917 m .682 .45575 L .66599 .45965 L p
1 g
F P
s
P
p
.002 w
.35572 .35789 m .3344 .41225 L .31942 .4045 L p
1 g
F P
s
P
p
.002 w
.31942 .4045 m .34223 .3461 L .35572 .35789 L p
1 g
F P
s
P
p
.002 w
.36792 .52137 m .39808 .56239 L .38295 .57044 L p
1 g
F P
s
P
p
.002 w
.38295 .57044 m .34916 .52467 L .36792 .52137 L p
1 g
F P
s
P
p
.002 w
.61321 .30567 m .56132 .27936 L .56293 .26183 L p
1 g
F P
s
P
p
.002 w
.50042 .25332 m .56293 .26183 L .56132 .27936 L p
1 g
F P
s
P
p
.002 w
.66599 .45965 m .6612 .40902 L .67675 .39917 L p
1 g
F P
s
P
p
.002 w
.65307 .34722 m .67675 .39917 L .6612 .40902 L p
1 g
F P
s
P
p
.002 w
.39404 .31313 m .35572 .35789 L .34223 .3461 L p
1 g
F P
s
P
p
.002 w
.34223 .3461 m .38333 .298 L .39404 .31313 L p
1 g
F P
s
P
p
.002 w
.35291 .47244 m .36792 .52137 L .34916 .52467 L p
1 g
F P
s
P
p
.002 w
.34916 .52467 m .33225 .46998 L .35291 .47244 L p
1 g
F P
s
P
p
.002 w
.56132 .27936 m .50309 .2715 L .50042 .25332 L p
1 g
F P
s
P
p
.002 w
.43815 .26583 m .50042 .25332 L .50309 .2715 L p
1 g
F P
s
P
p
.002 w
.53721 .58451 m .57773 .56895 L .58744 .58445 L p
1 g
F P
s
P
p
.002 w
.58744 .58445 m .53979 .60275 L .53721 .58451 L p
1 g
F P
s
P
p
.002 w
.6269 .55213 m .58744 .58445 L .57773 .56895 L p
1 g
F P
s
P
p
.002 w
.4939 .58651 m .53721 .58451 L .53979 .60275 L p
1 g
F P
s
P
p
.002 w
.53979 .60275 m .48887 .60514 L .4939 .58651 L p
1 g
F P
s
P
p
.002 w
.44511 .28317 m .39404 .31313 L .38333 .298 L p
1 g
F P
s
P
p
.002 w
.38333 .298 m .43815 .26583 L .44511 .28317 L p
1 g
F P
s
P
p
.002 w
.50309 .2715 m .44511 .28317 L .43815 .26583 L p
1 g
F P
s
P
p
.002 w
.57773 .56895 m .61128 .54145 L .6269 .55213 L p
1 g
F P
s
P
p
.002 w
.65407 .50907 m .6269 .55213 L .61128 .54145 L p
1 g
F P
s
P
p
.002 w
.45232 .57465 m .4939 .58651 L .48887 .60514 L p
1 g
F P
s
P
p
.002 w
.48887 .60514 m .43991 .59126 L .45232 .57465 L p
1 g
F P
s
P
p
.002 w
.6612 .40902 m .63992 .36259 L .65307 .34722 L p
1 g
F P
s
P
p
.002 w
.61321 .30567 m .65307 .34722 L .63992 .36259 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.61128 .54145 m .63433 .50481 L .65407 .50907 L p
1 g
F P
s
P
p
.002 w
.66599 .45965 m .65407 .50907 L .63433 .50481 L p
1 g
F P
s
P
p
.002 w
.35495 .42084 m .35291 .47244 L .33225 .46998 L p
1 g
F P
s
P
p
.002 w
.33225 .46998 m .3344 .41225 L .35495 .42084 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.41685 .55007 m .45232 .57465 L .43991 .59126 L p
1 g
F P
s
P
p
.002 w
.43991 .59126 m .39808 .56239 L .41685 .55007 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.63992 .36259 m .60421 .32553 L .61321 .30567 L p
1 g
F P
s
P
p
.002 w
.56132 .27936 m .61321 .30567 L .60421 .32553 L p
1 g
F P
s
P
p
.002 w
.63433 .50481 m .64438 .46282 L .66599 .45965 L p
1 g
F P
s
P
p
.002 w
.6612 .40902 m .66599 .45965 L .64438 .46282 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.39136 .51521 m .41685 .55007 L .39808 .56239 L p
1 g
F P
s
P
p
.002 w
.39808 .56239 m .36792 .52137 L .39136 .51521 L p
1 g
F P
s
P
p
.002 w
.37408 .37231 m .35495 .42084 L .3344 .41225 L p
1 g
F P
s
P
p
.002 w
.3344 .41225 m .35572 .35789 L .37408 .37231 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.60421 .32553 m .55779 .30211 L .56132 .27936 L p
1 g
F P
s
P
p
.002 w
.50309 .2715 m .56132 .27936 L .55779 .30211 L p
1 g
F P
s
P
p
.002 w
.63992 .36259 m .6612 .40902 L .6402 .41986 L p
1 g
F P
s
P
p
.002 w
.64438 .46282 m .6402 .41986 L .6612 .40902 L p
1 g
F P
s
P
p
.002 w
.40835 .33236 m .37408 .37231 L .35572 .35789 L p
1 g
F P
s
P
p
.002 w
.35572 .35789 m .39404 .31313 L .40835 .33236 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.37875 .4737 m .39136 .51521 L .36792 .52137 L p
1 g
F P
s
P
p
.002 w
.36792 .52137 m .35291 .47244 L .37875 .4737 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55779 .30211 m .50576 .29516 L .50309 .2715 L p
1 g
F P
s
P
p
.002 w
.44511 .28317 m .50309 .2715 L .50576 .29516 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .5744 L p
1 g
F P
s
P
p
.54854 .56129 m .53166 .5744 L .53392 .57317 L 1 g
F
P
p
.53721 .58451 m .52552 .57772 L .53166 .5744 L 1 g
F
P
p
.002 w
.53526 .57245 m .5354 .57337 L p
.53166 .5744 L 1 g
F P
s
P
p
.002 w
.5354 .57337 m .53721 .58451 L p
.53166 .5744 L 1 g
F P
s
P
p
.002 w
.53166 .5744 m .53128 .57265 L p
.52349 .57665 L 1 g
F P
s
P
p
.54854 .56129 m .53392 .57317 L .54141 .56808 L 1 g
F
P
p
.53392 .57317 m .53178 .57492 L .53526 .57245 L 1 g
F
P
p
.53392 .57317 m .53526 .57245 L .54141 .56808 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58011 L p
1 g
F P
s
P
p
.53128 .57265 m .5109 .58011 L .52349 .57665 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53721 .58451 m .4939 .58651 L .49513 .58101 L p
1 g
F P
s
P
p
.002 w
.5109 .58011 m .51079 .57862 L p
.50031 .58072 L 1 g
F P
s
P
p
.53721 .58451 m .49513 .58101 L .52795 .57913 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58051 L p
1 g
F P
s
P
p
.4939 .58651 m .489 .58051 L .48907 .58051 L 1 g
F
P
p
.002 w
.49513 .58101 m .49485 .58229 L p
.48907 .58051 L 1 g
F P
s
P
p
.002 w
.49485 .58229 m .4939 .58651 L p
.48907 .58051 L 1 g
F P
s
P
p
.002 w
.48907 .58051 m .48921 .57862 L p
.48061 .57791 L 1 g
F P
s
P
p
.51079 .57862 m .48907 .58051 L .49775 .58123 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46839 .57416 L p
1 g
F P
s
P
p
.48921 .57862 m .46839 .57416 L .48061 .57791 L 1 g
F
P
p
.48907 .58051 m .46659 .55309 L .49513 .58101 L 1 g
F
P
p
.489 .58051 m .48898 .58049 L .48907 .58051 L 1 g
F
P
p
.48898 .58049 m .46659 .55309 L .48907 .58051 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45232 .57465 m .45704 .56752 L p
.47558 .57837 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.45232 .57465 m .4475 .56011 L .45091 .56276 L 1 g
F
P
p
.002 w
.45704 .56752 m .45591 .56922 L p
.45091 .56276 L 1 g
F P
s
P
p
.002 w
.45591 .56922 m .45232 .57465 L p
.45091 .56276 L 1 g
F P
s
P
p
.002 w
.45091 .56276 m .45146 .56129 L p
.44632 .55682 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45091 .56276 L p
1 g
F P
s
P
p
.002 w
.45091 .56276 m .45002 .56518 L p
.45827 .56848 L 1 g
F P
s
P
p
.46872 .57265 m .45091 .56276 L .45827 .56848 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43861 .54687 L p
1 g
F P
s
P
p
.45146 .56129 m .43861 .54687 L .44632 .55682 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45232 .57465 m .448 .57166 L p
.43876 .53368 L 1 g
F P
s
P
p
.002 w
.448 .57166 m .41685 .55007 L .43475 .53668 L p
1 g
F P
s
P
p
.002 w
.43861 .54687 m .43925 .54566 L p
.43488 .53701 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43251 .52873 L p
1 g
F P
s
P
p
.41685 .55007 m .43082 .52276 L .43251 .52873 L 1 g
F
P
p
.002 w
.43475 .53668 m .43206 .5387 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43206 .5387 m .41685 .55007 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43251 .52873 m .43346 .52734 L p
.43318 .51927 L 1 g
F P
s
P
p
.002 w
.41883 .50625 m .43481 .50024 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.43266 .52529 m .42891 .52012 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.42891 .52012 m .41883 .50625 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.43404 .50922 m .43485 .50826 L p
.43834 .50011 L 1 g
F P
s
P
p
.43318 .51927 m .43266 .52529 L .43251 .52873 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.43925 .54566 m .43251 .52873 L .4348 .53687 L 1 g
F
P
p
.002 w
.43876 .53368 m .43475 .53668 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43082 .52276 m .43266 .52529 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43335 .51005 L p
1 g
F P
s
P
p
.43346 .52734 m .43335 .51005 L .43307 .51621 L 1 g
F
P
p
.002 w
.43266 .52529 m .43876 .53368 L p
.43251 .52873 L 1 g
F P
s
P
p
.002 w
.43335 .51005 m .43287 .51061 L p
.43307 .51621 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43266 .52529 m .43404 .50922 L .44947 .49473 L 1 g
F
P
p
.002 w
.43481 .50024 m .43902 .49866 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44256 .49138 L p
1 g
F P
s
P
p
.41883 .50625 m .44624 .48382 L .44256 .49138 L 1 g
F
P
p
.002 w
.43902 .49866 m .43249 .50111 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.43249 .50111 m .41883 .50625 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44256 .49138 m .44234 .49162 L p
.44101 .49457 L 1 g
F P
s
P
p
.43485 .50826 m .44256 .49138 L .44101 .49457 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .44339 .4905 L p
.45075 .48344 L 1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44716 .48694 m .45769 .4767 L .47884 .46956 L 1 g
F
P
p
.002 w
.45769 .4767 m .45826 .47608 L p
.46829 .47168 L 1 g
F P
s
P
p
.002 w
.47163 .4701 m .47884 .46956 L p
.45769 .4767 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .4673 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53378 .49614 m .52248 .50048 L .51587 .46638 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56626 .50959 L p
1 g
F P
s
P
p
.55661 .4905 m .56626 .50959 L .56567 .50835 L 1 g
F
P
p
.002 w
.56875 .50916 m .56682 .51075 L p
.56626 .50959 L 1 g
F P
s
P
p
.56612 .50818 m .56626 .50959 L .56547 .50794 L 1 g
F
P
p
.56875 .50916 m .56626 .50959 L .56612 .50818 L 1 g
F
P
p
.002 w
.56626 .50959 m .56515 .50826 L p
.56684 .5192 L 1 g
F P
s
P
p
.57358 .52576 m .56715 .52531 L .56682 .51075 L 1 g
F
P
p
.002 w
.56642 .51108 m .56682 .51075 L p
.56715 .52531 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56171 .54747 L p
1 g
F P
s
P
p
.56654 .52734 m .56171 .54747 L .56219 .54607 L 1 g
F
P
p
.002 w
.56274 .54443 m .56532 .54869 L p
.56182 .54716 L 1 g
F P
s
P
p
.56654 .52734 m .56219 .54607 L .56461 .53793 L 1 g
F
P
p
.002 w
.56532 .54869 m .5607 .55046 L p
.56171 .54747 L 1 g
F P
s
P
p
.56191 .5472 m .56171 .54747 L .56182 .54716 L 1 g
F
P
p
.56532 .54869 m .56171 .54747 L .56191 .5472 L 1 g
F
P
p
.002 w
.56171 .54747 m .56075 .54566 L p
.55549 .55519 L 1 g
F P
s
P
p
.002 w
.56532 .54869 m .56636 .55039 L p
.55706 .55337 L 1 g
F P
s
P
p
.002 w
.55901 .55111 m .56532 .54869 L p
.55706 .55337 L 1 g
F P
s
P
p
.55549 .55519 m .55901 .55111 L .56171 .54747 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56636 .55039 m .57773 .56895 L p
.54823 .56362 L 1 g
F P
s
P
p
.54823 .56362 m .54781 .56355 L .54905 .56267 L 1 g
F
P
p
.54823 .56362 m .54905 .56267 L .56636 .55039 L 1 g
F
P
p
.54905 .56267 m .55706 .55337 L .56636 .55039 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54905 .56267 L p
1 g
F P
s
P
p
.57773 .56895 m .5361 .5777 L .54823 .56362 L 1 g
F
P
p
.002 w
.54905 .56267 m .54998 .56518 L p
.55549 .55519 L 1 g
F P
s
P
p
.56075 .54566 m .54905 .56267 L .55549 .55519 L 1 g
F
P
p
.002 w
.57773 .56895 m .53721 .58451 L .5361 .5777 L p
1 g
F P
s
P
p
.002 w
.5361 .5777 m .53526 .57245 L p
.54823 .56362 L 1 g
F P
s
P
p
.54823 .56362 m .53526 .57245 L .54781 .56355 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54905 .56267 L p
1 g
F P
s
P
p
.002 w
.54905 .56267 m .54854 .56129 L p
.54141 .56808 L 1 g
F P
s
P
p
.54141 .56808 m .5322 .57686 L .54905 .56267 L 1 g
F
P
p
.002 w
.53526 .57245 m .5334 .56094 L p
.54781 .56355 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56171 .54747 m .5334 .56094 L .56182 .54716 L 1 g
F
P
p
.002 w
.5607 .55046 m .55901 .55111 L p
.56171 .54747 L 1 g
F P
s
P
p
.002 w
.55901 .55111 m .5334 .56094 L p
.56171 .54747 L 1 g
F P
s
P
p
.55409 .55773 m .54998 .56518 L .56027 .54964 L 1 g
F
P
p
.55901 .55111 m .56027 .54964 L .56171 .54747 L 1 g
F
P
p
.55409 .55773 m .56027 .54964 L .55901 .55111 L 1 g
F
P
p
.54781 .56355 m .5334 .56094 L .55706 .55337 L 1 g
F
P
p
.54781 .56355 m .55706 .55337 L .54905 .56267 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56187 .54778 L p
1 g
F P
s
P
p
.002 w
.56187 .54778 m .56171 .54747 L p
.56027 .54964 L 1 g
F P
s
P
p
.56027 .54964 m .54998 .56518 L .56187 .54778 L 1 g
F
P
p
.55549 .55519 m .55409 .55773 L .55901 .55111 L 1 g
F
P
p
.002 w
.5334 .56094 m .55901 .55111 L p
.55706 .55337 L 1 g
F P
s
P
p
.56219 .54607 m .56182 .54767 L .56274 .54443 L 1 g
F
P
p
.56219 .54607 m .56274 .54443 L .56461 .53793 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5334 .56094 m .52844 .53263 L p
.56182 .54716 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.52844 .53263 m .55051 .52417 L .56274 .54443 L p
1 g
F P
s
P
p
.56182 .54716 m .52844 .53263 L .56274 .54443 L 1 g
F
P
p
.002 w
.56171 .54747 m .56182 .54767 L p
.56219 .54607 L 1 g
F P
s
P
p
.002 w
.56532 .54869 m .56274 .54443 L p
.56675 .53045 L 1 g
F P
s
P
p
.002 w
.56182 .54767 m .56257 .5491 L p
.56461 .53793 L 1 g
F P
s
P
p
.002 w
.59172 .52701 m .56824 .54629 L p
.56732 .52847 L 1 g
F P
s
P
p
.002 w
.56732 .52847 m .56654 .52734 L p
.56461 .53793 L 1 g
F P
s
P
p
.5682 .52538 m .56732 .52847 L .56715 .52531 L 1 g
F
P
p
.59172 .52701 m .56732 .52847 L .5682 .52538 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56824 .54629 m .56532 .54869 L p
.56715 .52531 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56732 .52847 L p
1 g
F P
s
P
p
.56461 .53793 m .56257 .5491 L .56732 .52847 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56715 .52531 m .56675 .53045 L .55051 .52417 L 1 g
F
P
p
.002 w
.56274 .54443 m .55051 .52417 L p
.56675 .53045 L 1 g
F P
s
P
p
.55661 .4905 m .56567 .50835 L .56434 .5056 L 1 g
F
P
p
.55661 .4905 m .56434 .5056 L .56212 .50105 L 1 g
F
P
p
.56823 .50182 m .56434 .5056 L .55738 .49132 L 1 g
F
P
p
.002 w
.58122 .4892 m .56875 .50916 L .56434 .5056 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.53378 .49614 m .54311 .48845 L .56434 .5056 L p
1 g
F P
s
P
p
.002 w
.56434 .5056 m .56875 .50916 L p
.56547 .50794 L 1 g
F P
s
P
p
.56547 .50794 m .53378 .49614 L .56434 .5056 L 1 g
F
P
p
.002 w
.56682 .51075 m .56875 .50916 L p
.57358 .52576 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55754 .49149 L p
1 g
F P
s
P
p
.002 w
.55754 .49149 m .55661 .4905 L p
.56245 .50167 L 1 g
F P
s
P
p
.56245 .50167 m .56713 .51061 L .55754 .49149 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55738 .49132 L p
1 g
F P
s
P
p
.54174 .47608 m .55738 .49132 L .55108 .48523 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56434 .5056 m .54311 .48845 L p
.55465 .48868 L 1 g
F P
s
P
p
.55611 .48871 m .55738 .49132 L .55465 .48868 L 1 g
F
P
p
.55738 .49132 m .56434 .5056 L .55465 .48868 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5424 .4768 L p
1 g
F P
s
P
p
.002 w
.54311 .48845 m .5168 .46651 L p
.53323 .4724 L 1 g
F P
s
P
p
.54078 .47602 m .54311 .48845 L .53323 .4724 L 1 g
F
P
p
.52214 .46667 m .5424 .4768 L .53297 .47227 L 1 g
F
P
p
.002 w
.54736 .48162 m .54311 .48845 L p
.54059 .47504 L 1 g
F P
s
P
p
.002 w
.51885 .46678 m .53088 .47127 L p
.5168 .46651 L 1 g
F P
s
P
p
.52214 .46667 m .53297 .47227 L .53088 .47127 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46725 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.51572 .4656 m .51926 .4657 L p
.52249 .46725 L 1 g
F P
s
P
p
.002 w
.53088 .47127 m .51885 .46678 L p
.52249 .46725 L 1 g
F P
s
P
p
.5 .4634 m .52249 .46725 L .52239 .46723 L 1 g
F
P
p
.5 .4634 m .52249 .46725 L .52214 .46721 L 1 g
F
P
p
.5 .4634 m .5225 .46727 L .52191 .46719 L 1 g
F
P
p
.5 .4634 m .52252 .46729 L .51885 .46679 L 1 g
F
P
p
.002 w
.51885 .46678 m .51572 .4656 L p
.52249 .46725 L 1 g
F P
s
P
p
.002 w
.52249 .46725 m .52249 .46725 L p
.52239 .46723 L 1 g
F P
s
P
p
.002 w
.52249 .46725 m .52249 .46725 L p
.53088 .47127 L 1 g
F P
s
P
p
.002 w
.52249 .46725 m .52214 .46667 L p
.53088 .47127 L 1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.55216 .46655 m .54947 .47823 L .53088 .47127 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51926 .4657 m .55216 .46655 L p
.53088 .47127 L 1 g
F P
s
P
p
.002 w
.53088 .47127 m .54947 .47823 L p
.53323 .4724 L 1 g
F P
s
P
p
.53323 .4724 m .5168 .46651 L .53088 .47127 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46725 L p
1 g
F P
s
P
p
.53297 .47227 m .54302 .47747 L .52249 .46725 L 1 g
F
P
p
.002 w
.5424 .4768 m .54302 .47747 L p
.53297 .47227 L 1 g
F P
s
P
p
.54059 .47504 m .54078 .47602 L .53323 .4724 L 1 g
F
P
p
.54174 .47608 m .55108 .48523 L .54736 .48162 L 1 g
F
P
p
.002 w
.5424 .4768 m .54174 .47608 L p
.54736 .48162 L 1 g
F P
s
P
p
.002 w
.54947 .47823 m .54736 .48162 L p
.54059 .47504 L 1 g
F P
s
P
p
.002 w
.54265 .47708 m .5424 .4768 L p
.54736 .48162 L 1 g
F P
s
P
p
.002 w
.54311 .48845 m .54947 .47823 L .58122 .4892 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54265 .47708 L p
1 g
F P
s
P
p
.55108 .48523 m .55834 .49233 L .54265 .47708 L 1 g
F
P
p
.002 w
.55738 .49132 m .55834 .49233 L p
.55108 .48523 L 1 g
F P
s
P
p
.58122 .4892 m .56823 .50182 L .55611 .48871 L 1 g
F
P
p
.56823 .50182 m .55738 .49132 L .55611 .48871 L 1 g
F
P
p
.56212 .50105 m .56434 .5056 L .56245 .50167 L 1 g
F
P
p
.56245 .50167 m .56634 .50968 L .56453 .50565 L 1 g
F
P
p
.56567 .50835 m .56634 .50968 L .56245 .50167 L 1 g
F
P
p
.56626 .50959 m .55051 .52417 L .56547 .50794 L 1 g
F
P
p
.002 w
.56682 .51075 m .56642 .51108 L p
.56626 .50959 L 1 g
F P
s
P
p
.56684 .5192 m .56642 .51108 L .56626 .50959 L 1 g
F
P
p
.002 w
.56642 .51108 m .55051 .52417 L p
.56626 .50959 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56634 .50968 L p
1 g
F P
s
P
p
.002 w
.56634 .50968 m .56626 .50959 L p
.56641 .51087 L 1 g
F P
s
P
p
.56641 .51087 m .56854 .53025 L .56634 .50968 L 1 g
F
P
p
.56684 .5192 m .56804 .52704 L .56642 .51108 L 1 g
F
P
p
.002 w
.55051 .52417 m .56642 .51108 L p
.56715 .52531 L 1 g
F P
s
P
p
.56804 .52704 m .56854 .53025 L .56626 .50959 L 1 g
F
P
p
.002 w
.55051 .52417 m .53378 .49614 L p
.56547 .50794 L 1 g
F P
s
P
p
.002 w
.56626 .50959 m .56634 .50968 L p
.56567 .50835 L 1 g
F P
s
P
p
.002 w
.56634 .50968 m .56713 .51061 L p
.56453 .50565 L 1 g
F P
s
P
p
.002 w
.56875 .50916 m .59172 .52701 L p
.57358 .52576 L 1 g
F P
s
P
p
.002 w
.54311 .48845 m .53378 .49614 L .51621 .46643 L p
1 g
F P
s
P
p
.002 w
.5168 .46651 m .54311 .48845 L p
.51621 .46643 L 1 g
F P
s
P
p
.002 w
.51621 .46643 m .53378 .49614 L p
.51587 .46638 L 1 g
F P
s
P
p
.002 w
.48911 .49071 m .48218 .48101 L .51448 .46617 L p
1 g
F P
s
P
p
.5 .4634 m .51921 .46685 L .51442 .46617 L 1 g
F
P
p
.002 w
.51448 .46617 m .48218 .48101 L p
.51283 .46591 L 1 g
F P
s
P
p
.51441 .46616 m .51442 .46617 L .51441 .46616 L 1 g
F
P
p
.5 .4634 m .51442 .46617 L .51441 .46616 L 1 g
F
P
p
.002 w
.48218 .48101 m .47884 .46956 L .51283 .46591 L p
1 g
F P
s
P
p
.5 .4634 m .51441 .46616 L .51425 .46614 L 1 g
F
P
p
.002 w
.51503 .46626 m .48911 .49071 L p
.51448 .46617 L 1 g
F P
s
P
p
.002 w
.52248 .50048 m .51042 .50099 L .51561 .46635 L p
1 g
F P
s
P
p
.002 w
.51587 .46638 m .52248 .50048 L p
.51561 .46635 L 1 g
F P
s
P
p
.002 w
.47884 .46956 m .47897 .46712 L p
.51187 .46576 L 1 g
F P
s
P
p
.002 w
.51283 .46591 m .47884 .46956 L p
.51187 .46576 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51429 .46615 L 1 g
F P
s
P
p
.002 w
.50468 .46316 m .51572 .4656 L p
.47897 .46712 L 1 g
F P
s
P
p
.002 w
.51042 .50099 m .49888 .49762 L .51535 .46631 L p
1 g
F P
s
P
p
.002 w
.51535 .46631 m .51572 .4656 L .51561 .46635 L p
1 g
F P
s
P
p
.002 w
.51561 .46635 m .51042 .50099 L p
.51535 .46631 L 1 g
F P
s
P
p
.51429 .46615 m .51443 .46617 L .5 .46388 L 1 g
F
P
p
.002 w
.49888 .49762 m .48911 .49071 L .51503 .46626 L p
1 g
F P
s
P
p
.002 w
.51503 .46626 m .51572 .4656 L .51535 .46631 L p
1 g
F P
s
P
p
.002 w
.51535 .46631 m .49888 .49762 L p
.51503 .46626 L 1 g
F P
s
P
p
.51548 .46633 m .52262 .46747 L .51503 .46626 L 1 g
F
P
p
.51921 .46685 m .52042 .46707 L .51548 .46633 L 1 g
F
P
p
.52042 .46707 m .52262 .46747 L .51548 .46633 L 1 g
F
P
p
.51443 .46617 m .52282 .46778 L .50738 .46514 L 1 g
F
P
p
.51443 .46617 m .50738 .46514 L .5 .46388 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.47947 .45758 m .50468 .46316 L p
.5 .46388 L 1 g
F P
s
P
p
.47786 .46667 m .48969 .46547 L .48823 .46569 L 1 g
F
P
p
.002 w
.47748 .4673 m .47786 .46667 L p
.49694 .46487 L 1 g
F P
s
P
p
.002 w
.47897 .46712 m .47931 .4606 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.47931 .4606 m .47947 .45758 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.51283 .46591 m .51572 .4656 L .51448 .46617 L p
1 g
F P
s
P
p
.002 w
.51448 .46617 m .51572 .4656 L .51503 .46626 L p
1 g
F P
s
P
p
.51425 .46614 m .51441 .46616 L .51429 .46615 L 1 g
F
P
p
.51921 .46685 m .51503 .46626 L .51429 .46615 L 1 g
F
P
p
.002 w
.51561 .46635 m .51572 .4656 L .51587 .46638 L p
1 g
F P
s
P
p
.002 w
.5168 .46651 m .51572 .4656 L .51885 .46678 L p
1 g
F P
s
P
p
.002 w
.52249 .46725 m .5225 .46727 L p
.52214 .46721 L 1 g
F P
s
P
p
.002 w
.5225 .46727 m .52252 .46729 L p
.52191 .46719 L 1 g
F P
s
P
p
.002 w
.51621 .46643 m .51572 .4656 L .5168 .46651 L p
1 g
F P
s
P
p
.002 w
.51587 .46638 m .51572 .4656 L .51621 .46643 L p
1 g
F P
s
P
p
.002 w
.52252 .46729 m .52262 .46747 L p
.51885 .46679 L 1 g
F P
s
P
p
.002 w
.52262 .46747 m .52282 .46778 L p
.51429 .46615 L 1 g
F P
s
P
p
.002 w
.51572 .4656 m .51283 .46591 L p
.51187 .46576 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .49694 .46487 L p
.48823 .46569 L 1 g
F P
s
P
p
.48969 .46547 m .5 .46442 L .48823 .46569 L 1 g
F
P
p
.002 w
.479 .46658 m .47884 .46956 L .47163 .4701 L p
1 g
F P
s
P
p
.002 w
.49694 .46487 m .47718 .46778 L .47748 .4673 L p
1 g
F P
s
P
p
.002 w
.47947 .45758 m .479 .46658 L p
.46232 .4692 L 1 g
F P
s
P
p
.44282 .47227 m .4451 .47136 L .46232 .4692 L 1 g
F
P
p
.4451 .47136 m .47947 .45758 L .46232 .4692 L 1 g
F
P
p
.45826 .47608 m .47748 .4673 L .47632 .46786 L 1 g
F
P
p
.45826 .47608 m .47745 .46734 L .46829 .47168 L 1 g
F
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47163 .4701 m .44282 .47227 L p
.479 .46658 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47745 .46734 L p
.47632 .46786 L 1 g
F P
s
P
p
.002 w
.47745 .46734 m .47718 .46778 L p
.46829 .47168 L 1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43485 .50826 m .44234 .49162 L .43834 .50011 L 1 g
F
P
p
.002 w
.44947 .49473 m .43902 .49866 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4572 .47724 L p
1 g
F P
s
P
p
.44339 .4905 m .4572 .47724 L .45351 .48081 L 1 g
F
P
p
.45075 .48344 m .44716 .48694 L .44256 .49138 L 1 g
F
P
p
.002 w
.44624 .48382 m .44716 .48694 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44716 .48694 m .44947 .49473 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.4572 .47724 m .45698 .47747 L p
.45351 .48081 L 1 g
F P
s
P
p
.002 w
.44282 .47227 m .46388 .47068 L p
.45769 .4767 L 1 g
F P
s
P
p
.002 w
.44716 .48694 m .4458 .48234 L p
.45769 .4767 L 1 g
F P
s
P
p
.002 w
.4458 .48234 m .44282 .47227 L p
.45769 .4767 L 1 g
F P
s
P
p
.002 w
.46388 .47068 m .47163 .4701 L p
.45769 .4767 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .4767 L p
1 g
F P
s
P
p
.46829 .47168 m .47718 .46778 L .45769 .4767 L 1 g
F
P
p
.45075 .48344 m .45351 .48081 L .44716 .48694 L 1 g
F
P
p
.002 w
.44947 .49473 m .44716 .48694 L p
.47884 .46956 L 1 g
F P
s
P
p
.002 w
.44234 .49162 m .44166 .49233 L p
.43834 .50011 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.45351 .48081 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.44282 .47227 m .44624 .48382 L p
.41883 .50625 L 1 g
F P
s
P
p
.002 w
.43902 .49866 m .44947 .49473 L p
.43404 .50922 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43404 .50922 L p
1 g
F P
s
P
p
.43834 .50011 m .44166 .49233 L .43404 .50922 L 1 g
F
P
p
.43318 .51927 m .43307 .51621 L .43266 .52529 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .53368 m .43266 .52529 L p
.44947 .49473 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52873 L p
1 g
F P
s
P
p
.43307 .51621 m .43287 .51061 L .43251 .52873 L 1 g
F
P
p
.002 w
.43251 .52873 m .43146 .53025 L p
.4348 .53687 L 1 g
F P
s
P
p
.002 w
.41883 .50625 m .43082 .52276 L p
.41685 .55007 L 1 g
F P
s
P
p
.002 w
.43475 .53668 m .43876 .53368 L p
.448 .57166 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43861 .54687 L p
1 g
F P
s
P
p
.43488 .53701 m .43146 .53025 L .43861 .54687 L 1 g
F
P
p
.002 w
.43861 .54687 m .43743 .5491 L p
.44632 .55682 L 1 g
F P
s
P
p
.45091 .56276 m .43876 .53368 L .45704 .56752 L 1 g
F
P
p
.4475 .56011 m .44649 .55704 L .45091 .56276 L 1 g
F
P
p
.44649 .55704 m .43876 .53368 L .45091 .56276 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45091 .56276 L p
1 g
F P
s
P
p
.44632 .55682 m .43743 .5491 L .45091 .56276 L 1 g
F
P
p
.002 w
.43876 .53368 m .46659 .55309 L .45704 .56752 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46798 .57602 L p
1 g
F P
s
P
p
.002 w
.46798 .57602 m .46839 .57416 L p
.46083 .57046 L 1 g
F P
s
P
p
.46083 .57046 m .45002 .56518 L .46798 .57602 L 1 g
F
P
p
.002 w
.46839 .57416 m .46872 .57265 L p
.45955 .56899 L 1 g
F P
s
P
p
.45955 .56899 m .45002 .56518 L .46839 .57416 L 1 g
F
P
p
.489 .58051 m .47558 .57837 L .46659 .55309 L 1 g
F
P
p
.002 w
.45704 .56752 m .46659 .55309 L p
.47558 .57837 L 1 g
F P
s
P
p
.002 w
.4939 .58651 m .46632 .57865 L p
.489 .58051 L 1 g
F P
s
P
p
.002 w
.46632 .57865 m .45232 .57465 L p
.489 .58051 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58232 L p
1 g
F P
s
P
p
.002 w
.51106 .58232 m .5109 .58011 L p
.5006 .58146 L 1 g
F P
s
P
p
.5006 .58146 m .48889 .583 L .51106 .58232 L 1 g
F
P
p
.002 w
.46839 .57416 m .4678 .57686 L p
.48061 .57791 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58051 L p
1 g
F P
s
P
p
.48061 .57791 m .4678 .57686 L .48907 .58051 L 1 g
F
P
p
.002 w
.48907 .58051 m .48889 .583 L p
.49775 .58123 L 1 g
F P
s
P
p
.002 w
.46659 .55309 m .49929 .56248 L .49513 .58101 L p
1 g
F P
s
P
p
.002 w
.49513 .58101 m .49929 .56248 L p
.52795 .57913 L 1 g
F P
s
P
p
.50031 .58072 m .48889 .583 L .5109 .58011 L 1 g
F
P
p
.002 w
.5109 .58011 m .51111 .583 L p
.52349 .57665 L 1 g
F P
s
P
p
.53166 .5744 m .49929 .56248 L .53526 .57245 L 1 g
F
P
p
.52552 .57772 m .52361 .57661 L .53166 .5744 L 1 g
F
P
p
.52361 .57661 m .49929 .56248 L .53166 .5744 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53166 .5744 L p
1 g
F P
s
P
p
.52349 .57665 m .51111 .583 L .53166 .5744 L 1 g
F
P
p
.002 w
.49929 .56248 m .5334 .56094 L .53526 .57245 L p
1 g
F P
s
P
p
.002 w
.53166 .5744 m .53178 .57492 L p
.53392 .57317 L 1 g
F P
s
P
p
.002 w
.53178 .57492 m .5322 .57686 L p
.54141 .56808 L 1 g
F P
s
P
p
.002 w
.61128 .54145 m .57773 .56895 L .56532 .54869 L p
1 g
F P
s
P
p
.002 w
.45397 .30562 m .40835 .33236 L .39404 .31313 L p
1 g
F P
s
P
p
.002 w
.39404 .31313 m .44511 .28317 L .45397 .30562 L p
1 g
F P
s
P
p
.002 w
.50576 .29516 m .45397 .30562 L .44511 .28317 L p
1 g
F P
s
P
p
.002 w
.56532 .54869 m .59172 .52701 L .61128 .54145 L p
1 g
F P
s
P
p
.002 w
.63433 .50481 m .61128 .54145 L .59172 .52701 L p
1 g
F P
s
P
p
.002 w
.6402 .41986 m .62205 .38056 L .63992 .36259 L p
1 g
F P
s
P
p
.002 w
.60421 .32553 m .63992 .36259 L .62205 .38056 L p
1 g
F P
s
P
p
.002 w
.59172 .52701 m .60982 .49815 L .63433 .50481 L p
1 g
F P
s
P
p
.002 w
.64438 .46282 m .63433 .50481 L .60982 .49815 L p
1 g
F P
s
P
p
.002 w
.38059 .43 m .37875 .4737 L .35291 .47244 L p
1 g
F P
s
P
p
.002 w
.35291 .47244 m .35495 .42084 L .38059 .43 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.60982 .49815 m .61764 .4651 L .64438 .46282 L p
1 g
F P
s
P
p
.002 w
.6402 .41986 m .64438 .46282 L .61764 .4651 L p
1 g
F P
s
P
p
.002 w
.62205 .38056 m .59171 .34925 L .60421 .32553 L p
1 g
F P
s
P
p
.002 w
.55779 .30211 m .60421 .32553 L .59171 .34925 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41685 .55007 m .39136 .51521 L .41883 .50625 L p
1 g
F P
s
P
p
.002 w
.39688 .38896 m .38059 .43 L .35495 .42084 L p
1 g
F P
s
P
p
.002 w
.35495 .42084 m .37408 .37231 L .39688 .38896 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59171 .34925 m .55237 .32952 L .55779 .30211 L p
1 g
F P
s
P
p
.002 w
.50576 .29516 m .55779 .30211 L .55237 .32952 L p
1 g
F P
s
P
p
.002 w
.61764 .4651 m .61426 .43137 L .6402 .41986 L p
1 g
F P
s
P
p
.002 w
.62205 .38056 m .6402 .41986 L .61426 .43137 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42592 .3552 m .39688 .38896 L .37408 .37231 L p
1 g
F P
s
P
p
.002 w
.37408 .37231 m .40835 .33236 L .42592 .3552 L p
1 g
F P
s
P
p
.002 w
.40905 .47366 m .41883 .50625 L .39136 .51521 L p
1 g
F P
s
P
p
.002 w
.39136 .51521 m .37875 .4737 L .40905 .47366 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.55237 .32952 m .50833 .32371 L .50576 .29516 L p
1 g
F P
s
P
p
.002 w
.45397 .30562 m .50576 .29516 L .50833 .32371 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.50487 .53366 m .52844 .53263 L .5334 .56094 L p
1 g
F P
s
P
p
.002 w
.5334 .56094 m .49929 .56248 L .50487 .53366 L p
1 g
F P
s
P
p
.002 w
.46453 .33259 m .42592 .3552 L .40835 .33236 L p
1 g
F P
s
P
p
.002 w
.40835 .33236 m .45397 .30562 L .46453 .33259 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.60982 .49815 m .59172 .52701 L .56875 .50916 L p
1 g
F P
s
P
p
.002 w
.50833 .32371 m .46453 .33259 L .45397 .30562 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.48229 .52713 m .50487 .53366 L .49929 .56248 L p
1 g
F P
s
P
p
.002 w
.49929 .56248 m .46659 .55309 L .48229 .52713 L p
1 g
F P
s
P
p
.002 w
.61426 .43137 m .59992 .40057 L .62205 .38056 L p
1 g
F P
s
P
p
.002 w
.59171 .34925 m .62205 .38056 L .59992 .40057 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.56875 .50916 m .58122 .4892 L .60982 .49815 L p
1 g
F P
s
P
p
.002 w
.61764 .4651 m .60982 .49815 L .58122 .4892 L p
1 g
F P
s
P
p
.002 w
.4106 .43942 m .40905 .47366 L .37875 .4737 L p
1 g
F P
s
P
p
.002 w
.37875 .4737 m .38059 .43 L .4106 .43942 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46313 .51368 m .48229 .52713 L .46659 .55309 L p
1 g
F P
s
P
p
.002 w
.46659 .55309 m .43876 .53368 L .46313 .51368 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58122 .4892 m .58655 .46638 L .61764 .4651 L p
1 g
F P
s
P
p
.002 w
.61426 .43137 m .61764 .4651 L .58655 .46638 L p
1 g
F P
s
P
p
.002 w
.59992 .40057 m .57605 .37611 L .59171 .34925 L p
1 g
F P
s
P
p
.002 w
.55237 .32952 m .59171 .34925 L .57605 .37611 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.44947 .49473 m .46313 .51368 L .43876 .53368 L p
1 g
F P
s
P
p
.002 w
.42344 .40731 m .4106 .43942 L .38059 .43 L p
1 g
F P
s
P
p
.002 w
.38059 .43 m .39688 .38896 L .42344 .40731 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.58655 .46638 m .58414 .44313 L .61426 .43137 L p
1 g
F P
s
P
p
.002 w
.59992 .40057 m .61426 .43137 L .58414 .44313 L p
1 g
F P
s
P
p
.002 w
.57605 .37611 m .54519 .36074 L .55237 .32952 L p
1 g
F P
s
P
p
.002 w
.50833 .32371 m .55237 .32952 L .54519 .36074 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.44622 .38092 m .42344 .40731 L .39688 .38896 L p
1 g
F P
s
P
p
.002 w
.39688 .38896 m .42592 .3552 L .44622 .38092 L p
1 g
F P
s
P
p
.002 w
.41883 .50625 m .40905 .47366 L .44282 .47227 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54519 .36074 m .5107 .35626 L .50833 .32371 L p
1 g
F P
s
P
p
.002 w
.46453 .33259 m .50833 .32371 L .5107 .35626 L p
1 g
F P
s
P
p
.002 w
.52248 .50048 m .53378 .49614 L .55051 .52417 L p
1 g
F P
s
P
p
.002 w
.55051 .52417 m .52844 .53263 L .52248 .50048 L p
1 g
F P
s
P
p
.002 w
.51042 .50099 m .52248 .50048 L .52844 .53263 L p
1 g
F P
s
P
p
.002 w
.52844 .53263 m .50487 .53366 L .51042 .50099 L p
1 g
F P
s
P
p
.002 w
.47643 .36324 m .44622 .38092 L .42592 .3552 L p
1 g
F P
s
P
p
.002 w
.42592 .3552 m .46453 .33259 L .47643 .36324 L p
1 g
F P
s
P
p
.002 w
.58414 .44313 m .57418 .42196 L .59992 .40057 L p
1 g
F P
s
P
p
.002 w
.57605 .37611 m .59992 .40057 L .57418 .42196 L p
1 g
F P
s
P
p
.002 w
.5107 .35626 m .47643 .36324 L .46453 .33259 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49888 .49762 m .51042 .50099 L .50487 .53366 L p
1 g
F P
s
P
p
.002 w
.50487 .53366 m .48229 .52713 L .49888 .49762 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.44397 .44873 m .44282 .47227 L .40905 .47366 L p
1 g
F P
s
P
p
.002 w
.40905 .47366 m .4106 .43942 L .44397 .44873 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.58655 .46638 m .58122 .4892 L .54947 .47823 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.48911 .49071 m .49888 .49762 L .48229 .52713 L p
1 g
F P
s
P
p
.002 w
.48229 .52713 m .46313 .51368 L .48911 .49071 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54947 .47823 m .55216 .46655 L .58655 .46638 L p
1 g
F P
s
P
p
.002 w
.58414 .44313 m .58655 .46638 L .55216 .46655 L p
1 g
F P
s
P
p
.002 w
.57418 .42196 m .55771 .40519 L .57605 .37611 L p
1 g
F P
s
P
p
.002 w
.54519 .36074 m .57605 .37611 L .55771 .40519 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.48218 .48101 m .48911 .49071 L .46313 .51368 L p
1 g
F P
s
P
p
.002 w
.46313 .51368 m .44947 .49473 L .48218 .48101 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.45285 .4267 m .44397 .44873 L .4106 .43942 L p
1 g
F P
s
P
p
.002 w
.4106 .43942 m .42344 .40731 L .45285 .4267 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57418 .42196 m .58414 .44313 L .55088 .45469 L p
1 g
F P
s
P
p
.002 w
.55216 .46655 m .55088 .45469 L .58414 .44313 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.55771 .40519 m .53647 .3947 L .54519 .36074 L p
1 g
F P
s
P
p
.002 w
.5107 .35626 m .54519 .36074 L .53647 .3947 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47884 .46956 m .48218 .48101 L .44947 .49473 L p
1 g
F P
s
P
p
.002 w
.46852 .40861 m .45285 .4267 L .42344 .40731 L p
1 g
F P
s
P
p
.002 w
.42344 .40731 m .44622 .38092 L .46852 .40861 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.53647 .3947 m .51278 .39167 L .5107 .35626 L p
1 g
F P
s
P
p
.002 w
.47643 .36324 m .5107 .35626 L .51278 .39167 L p
1 g
F P
s
P
p
.002 w
.55088 .45469 m .54576 .44392 L .57418 .42196 L p
1 g
F P
s
P
p
.002 w
.55771 .40519 m .57418 .42196 L .54576 .44392 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.48926 .39648 m .46852 .40861 L .44622 .38092 L p
1 g
F P
s
P
p
.002 w
.44622 .38092 m .47643 .36324 L .48926 .39648 L p
1 g
F P
s
P
p
.002 w
.51278 .39167 m .48926 .39648 L .47643 .36324 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.44282 .47227 m .44397 .44873 L .47947 .45758 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.55088 .45469 m .55216 .46655 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.54576 .44392 m .53734 .43542 L .55771 .40519 L p
1 g
F P
s
P
p
.002 w
.53647 .3947 m .55771 .40519 L .53734 .43542 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.48402 .44639 m .47947 .45758 L .44397 .44873 L p
1 g
F P
s
P
p
.002 w
.44397 .44873 m .45285 .4267 L .48402 .44639 L p
1 g
F P
s
P
p
.002 w
.54576 .44392 m .55088 .45469 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53734 .43542 m .52652 .43011 L .53647 .3947 L p
1 g
F P
s
P
p
.002 w
.51278 .39167 m .53647 .3947 L .52652 .43011 L p
1 g
F P
s
P
p
.002 w
.53734 .43542 m .54576 .44392 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.49199 .43721 m .48402 .44639 L .45285 .4267 L p
1 g
F P
s
P
p
.002 w
.45285 .4267 m .46852 .40861 L .49199 .43721 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52652 .43011 m .51448 .4286 L .51278 .39167 L p
1 g
F P
s
P
p
.002 w
.48926 .39648 m .51278 .39167 L .51448 .4286 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.52652 .43011 m .53734 .43542 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.51448 .4286 m .52652 .43011 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.50253 .43106 m .51448 .4286 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.49199 .43721 m .50253 .43106 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50072 .43212 L
s
P
p
.002 w
.48402 .44639 m .49199 .43721 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.47947 .45758 m .48402 .44639 L .51572 .4656 L closepath p
1 g
F P
s
P
p
.002 w
.50253 .43106 m .49199 .43721 L .46852 .40861 L p
1 g
F P
s
P
p
.002 w
.46852 .40861 m .48926 .39648 L .50253 .43106 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51448 .4286 m .50253 .43106 L .48926 .39648 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.51572 .4656 m
.52548 .48738 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .77244 .50217 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .52548 .48738 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.368992)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.368992)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49715 .46886 m .51979 .45393 L .5006 .43288 L p
1 g
F P
s
P
p
.002 w
.5006 .43288 m .48517 .44303 L .49715 .46886 L p
1 g
F P
s
P
p
.002 w
.51215 .41846 m .5006 .43288 L .51979 .45393 L p
1 g
F P
s
P
p
.002 w
.48517 .44303 m .5006 .43288 L .48141 .41178 L p
1 g
F P
s
P
p
.002 w
.5006 .43288 m .51215 .41846 L .48726 .40446 L p
1 g
F P
s
P
p
.002 w
.48726 .40446 m .48141 .41178 L .5006 .43288 L p
1 g
F P
s
P
p
.002 w
.51979 .45393 m .53677 .43277 L .51215 .41846 L p
1 g
F P
s
P
p
.002 w
.51859 .40126 m .51215 .41846 L .53677 .43277 L p
1 g
F P
s
P
p
.002 w
.51215 .41846 m .51859 .40126 L .4905 .39573 L p
1 g
F P
s
P
p
.002 w
.4905 .39573 m .48726 .40446 L .51215 .41846 L p
1 g
F P
s
P
p
.002 w
.47114 .47597 m .49715 .46886 L .48517 .44303 L p
1 g
F P
s
P
p
.002 w
.48517 .44303 m .46746 .44782 L .47114 .47597 L p
1 g
F P
s
P
p
.002 w
.46746 .44782 m .48517 .44303 L .47357 .41692 L p
1 g
F P
s
P
p
.002 w
.48141 .41178 m .47357 .41692 L .48517 .44303 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .47357 .41692 L .48141 .41178 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .48141 .41178 L .48726 .40446 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .48726 .40446 L .4905 .39573 L closepath p
1 g
F P
s
P
p
.002 w
.47357 .41692 m .46458 .41932 L .46746 .44782 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .46458 .41932 L .47357 .41692 L closepath p
1 g
F P
s
P
p
.002 w
.50928 .49395 m .53864 .47456 L .51979 .45393 L p
1 g
F P
s
P
p
.002 w
.51979 .45393 m .49715 .46886 L .50928 .49395 L p
1 g
F P
s
P
p
.002 w
.53677 .43277 m .51979 .45393 L .53864 .47456 L p
1 g
F P
s
P
p
.002 w
.51923 .38309 m .51859 .40126 L .54631 .40752 L p
1 g
F P
s
P
p
.002 w
.53677 .43277 m .54631 .40752 L .51859 .40126 L p
1 g
F P
s
P
p
.002 w
.51859 .40126 m .51923 .38309 L .49079 .38652 L p
1 g
F P
s
P
p
.002 w
.49079 .38652 m .4905 .39573 L .51859 .40126 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .4905 .39573 L .49079 .38652 L closepath p
1 g
F P
s
P
p
.002 w
.53864 .47456 m .56068 .44713 L .53677 .43277 L p
1 g
F P
s
P
p
.002 w
.54631 .40752 m .53677 .43277 L .56068 .44713 L p
1 g
F P
s
P
p
.002 w
.44447 .47448 m .47114 .47597 L .46746 .44782 L p
1 g
F P
s
P
p
.002 w
.46746 .44782 m .44934 .44672 L .44447 .47448 L p
1 g
F P
s
P
p
.002 w
.44934 .44672 m .46746 .44782 L .46458 .41932 L p
1 g
F P
s
P
p
.002 w
.46458 .41932 m .4554 .41873 L .44934 .44672 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .4554 .41873 L .46458 .41932 L closepath p
1 g
F P
s
P
p
.002 w
.47556 .50328 m .50928 .49395 L .49715 .46886 L p
1 g
F P
s
P
p
.002 w
.49715 .46886 m .47114 .47597 L .47556 .50328 L p
1 g
F P
s
P
p
.002 w
.48806 .37782 m .49079 .38652 L .51923 .38309 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .49079 .38652 L .48806 .37782 L closepath p
1 g
F P
s
P
p
.002 w
.43271 .4398 m .44934 .44672 L .4554 .41873 L p
1 g
F P
s
P
p
.002 w
.4554 .41873 m .44701 .41518 L .43271 .4398 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .44701 .41518 L .4554 .41873 L closepath p
1 g
F P
s
P
p
.002 w
.54631 .40752 m .54736 .3808 L .51923 .38309 L p
1 g
F P
s
P
p
.002 w
.51394 .36586 m .51923 .38309 L .54736 .3808 L p
1 g
F P
s
P
p
.002 w
.51923 .38309 m .51394 .36586 L .48806 .37782 L p
1 g
F P
s
P
p
.002 w
.54736 .3808 m .54631 .40752 L .57314 .4144 L p
1 g
F P
s
P
p
.002 w
.56068 .44713 m .57314 .4144 L .54631 .40752 L p
1 g
F P
s
P
p
.002 w
.41993 .46443 m .44447 .47448 L .44934 .44672 L p
1 g
F P
s
P
p
.002 w
.44934 .44672 m .43271 .4398 L .41993 .46443 L p
1 g
F P
s
P
p
.002 w
.44091 .5015 m .47556 .50328 L .47114 .47597 L p
1 g
F P
s
P
p
.002 w
.47114 .47597 m .44447 .47448 L .44091 .5015 L p
1 g
F P
s
P
p
.002 w
.48261 .37057 m .48806 .37782 L .51394 .36586 L p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .48806 .37782 L .48261 .37057 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .48261 .37057 L .47501 .36556 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .47501 .36556 L .46608 .36336 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .46608 .36336 L .45678 .36421 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .45678 .36421 L .44814 .36804 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .44814 .36804 L .44112 .37443 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .44112 .37443 L .43648 .38268 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .43648 .38268 L .43474 .39187 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .43474 .39187 L .43608 .40099 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .43608 .40099 L .44033 .40905 L closepath p
1 g
F P
s
P
p
.002 w
.46255 .39101 m .44033 .40905 L .44701 .41518 L closepath p
1 g
F P
s
P
p
.002 w
.4194 .42775 m .43271 .4398 L .44701 .41518 L p
1 g
F P
s
P
p
.002 w
.44701 .41518 m .44033 .40905 L .4194 .42775 L p
1 g
F P
s
P
p
.002 w
.52135 .51783 m .55678 .49438 L .53864 .47456 L p
1 g
F P
s
P
p
.002 w
.53864 .47456 m .50928 .49395 L .52135 .51783 L p
1 g
F P
s
P
p
.002 w
.56068 .44713 m .53864 .47456 L .55678 .49438 L p
1 g
F P
s
P
p
.002 w
.51394 .36586 m .50324 .35144 L .48261 .37057 L p
1 g
F P
s
P
p
.002 w
.47501 .36556 m .48261 .37057 L .50324 .35144 L p
1 g
F P
s
P
p
.002 w
.55678 .49438 m .58342 .46127 L .56068 .44713 L p
1 g
F P
s
P
p
.002 w
.57314 .4144 m .56068 .44713 L .58342 .46127 L p
1 g
F P
s
P
p
.002 w
.41088 .41181 m .4194 .42775 L .44033 .40905 L p
1 g
F P
s
P
p
.002 w
.44033 .40905 m .43608 .40099 L .41088 .41181 L p
1 g
F P
s
P
p
.002 w
.48065 .52922 m .52135 .51783 L .50928 .49395 L p
1 g
F P
s
P
p
.002 w
.50928 .49395 m .47556 .50328 L .48065 .52922 L p
1 g
F P
s
P
p
.002 w
.54736 .3808 m .53971 .35539 L .51394 .36586 L p
1 g
F P
s
P
p
.002 w
.50324 .35144 m .51394 .36586 L .53971 .35539 L p
1 g
F P
s
P
p
.002 w
.40018 .44676 m .41993 .46443 L .43271 .4398 L p
1 g
F P
s
P
p
.002 w
.43271 .4398 m .4194 .42775 L .40018 .44676 L p
1 g
F P
s
P
p
.002 w
.57314 .4144 m .57465 .3797 L .54736 .3808 L p
1 g
F P
s
P
p
.002 w
.53971 .35539 m .54736 .3808 L .57465 .3797 L p
1 g
F P
s
P
p
.002 w
.50324 .35144 m .48822 .34143 L .47501 .36556 L p
1 g
F P
s
P
p
.002 w
.46608 .36336 m .47501 .36556 L .48822 .34143 L p
1 g
F P
s
P
p
.002 w
.40814 .39369 m .41088 .41181 L .43608 .40099 L p
1 g
F P
s
P
p
.002 w
.43608 .40099 m .43474 .39187 L .40814 .39369 L p
1 g
F P
s
P
p
.002 w
.40893 .48859 m .44091 .5015 L .44447 .47448 L p
1 g
F P
s
P
p
.002 w
.44447 .47448 m .41993 .46443 L .40893 .48859 L p
1 g
F P
s
P
p
.002 w
.57465 .3797 m .57314 .4144 L .59858 .42178 L p
1 g
F P
s
P
p
.002 w
.58342 .46127 m .59858 .42178 L .57314 .4144 L p
1 g
F P
s
P
p
.002 w
.48822 .34143 m .47049 .33696 L .46608 .36336 L p
1 g
F P
s
P
p
.002 w
.45678 .36421 m .46608 .36336 L .47049 .33696 L p
1 g
F P
s
P
p
.002 w
.41155 .37538 m .40814 .39369 L .43474 .39187 L p
1 g
F P
s
P
p
.002 w
.43474 .39187 m .43648 .38268 L .41155 .37538 L p
1 g
F P
s
P
p
.002 w
.43875 .52723 m .48065 .52922 L .47556 .50328 L p
1 g
F P
s
P
p
.002 w
.47556 .50328 m .44091 .5015 L .43875 .52723 L p
1 g
F P
s
P
p
.002 w
.53971 .35539 m .52405 .33402 L .50324 .35144 L p
1 g
F P
s
P
p
.002 w
.48822 .34143 m .50324 .35144 L .52405 .33402 L p
1 g
F P
s
P
p
.002 w
.47049 .33696 m .45198 .3386 L .45678 .36421 L p
1 g
F P
s
P
p
.002 w
.44814 .36804 m .45678 .36421 L .45198 .3386 L p
1 g
F P
s
P
p
.002 w
.42076 .35894 m .41155 .37538 L .43648 .38268 L p
1 g
F P
s
P
p
.002 w
.43648 .38268 m .44112 .37443 L .42076 .35894 L p
1 g
F P
s
P
p
.002 w
.38746 .42327 m .40018 .44676 L .4194 .42775 L p
1 g
F P
s
P
p
.002 w
.4194 .42775 m .41088 .41181 L .38746 .42327 L p
1 g
F P
s
P
p
.002 w
.45198 .3386 m .43476 .3462 L .44814 .36804 L p
1 g
F P
s
P
p
.002 w
.44112 .37443 m .44814 .36804 L .43476 .3462 L p
1 g
F P
s
P
p
.002 w
.43476 .3462 m .42076 .35894 L .44112 .37443 L p
1 g
F P
s
P
p
.002 w
.57465 .3797 m .56488 .34661 L .53971 .35539 L p
1 g
F P
s
P
p
.002 w
.52405 .33402 m .53971 .35539 L .56488 .34661 L p
1 g
F P
s
P
p
.002 w
.53313 .54002 m .57386 .513 L .55678 .49438 L p
1 g
F P
s
P
p
.002 w
.55678 .49438 m .52135 .51783 L .53313 .54002 L p
1 g
F P
s
P
p
.002 w
.58342 .46127 m .55678 .49438 L .57386 .513 L p
1 g
F P
s
P
p
.002 w
.38308 .46572 m .40893 .48859 L .41993 .46443 L p
1 g
F P
s
P
p
.002 w
.41993 .46443 m .40018 .44676 L .38308 .46572 L p
1 g
F P
s
P
p
.002 w
.57386 .513 m .60455 .47493 L .58342 .46127 L p
1 g
F P
s
P
p
.002 w
.59858 .42178 m .58342 .46127 L .60455 .47493 L p
1 g
F P
s
P
p
.002 w
.52405 .33402 m .50194 .3191 L .48822 .34143 L p
1 g
F P
s
P
p
.002 w
.47049 .33696 m .48822 .34143 L .50194 .3191 L p
1 g
F P
s
P
p
.002 w
.48633 .55325 m .53313 .54002 L .52135 .51783 L p
1 g
F P
s
P
p
.002 w
.52135 .51783 m .48065 .52922 L .48633 .55325 L p
1 g
F P
s
P
p
.002 w
.59858 .42178 m .60058 .37984 L .57465 .3797 L p
1 g
F P
s
P
p
.002 w
.56488 .34661 m .57465 .3797 L .60058 .37984 L p
1 g
F P
s
P
p
.002 w
.38329 .39646 m .38746 .42327 L .41088 .41181 L p
1 g
F P
s
P
p
.002 w
.41088 .41181 m .40814 .39369 L .38329 .39646 L p
1 g
F P
s
P
p
.002 w
.39997 .51181 m .43875 .52723 L .44091 .5015 L p
1 g
F P
s
P
p
.002 w
.44091 .5015 m .40893 .48859 L .39997 .51181 L p
1 g
F P
s
P
p
.002 w
.50194 .3191 m .47572 .31237 L .47049 .33696 L p
1 g
F P
s
P
p
.002 w
.45198 .3386 m .47049 .33696 L .47572 .31237 L p
1 g
F P
s
P
p
.002 w
.38825 .3693 m .38329 .39646 L .40814 .39369 L p
1 g
F P
s
P
p
.002 w
.40814 .39369 m .41155 .37538 L .38825 .3693 L p
1 g
F P
s
P
p
.002 w
.60058 .37984 m .59858 .42178 L .6221 .42953 L p
1 g
F P
s
P
p
.002 w
.60455 .47493 m .6221 .42953 L .59858 .42178 L p
1 g
F P
s
P
p
.002 w
.56488 .34661 m .54465 .31868 L .52405 .33402 L p
1 g
F P
s
P
p
.002 w
.50194 .3191 m .52405 .33402 L .54465 .31868 L p
1 g
F P
s
P
p
.002 w
.43808 .55114 m .48633 .55325 L .48065 .52922 L p
1 g
F P
s
P
p
.002 w
.48065 .52922 m .43875 .52723 L .43808 .55114 L p
1 g
F P
s
P
p
.002 w
.36633 .43517 m .38308 .46572 L .40018 .44676 L p
1 g
F P
s
P
p
.002 w
.40018 .44676 m .38746 .42327 L .36633 .43517 L p
1 g
F P
s
P
p
.002 w
.47572 .31237 m .44827 .31471 L .45198 .3386 L p
1 g
F P
s
P
p
.002 w
.43476 .3462 m .45198 .3386 L .44827 .31471 L p
1 g
F P
s
P
p
.002 w
.40189 .34486 m .38825 .3693 L .41155 .37538 L p
1 g
F P
s
P
p
.002 w
.41155 .37538 m .42076 .35894 L .40189 .34486 L p
1 g
F P
s
P
p
.002 w
.60058 .37984 m .58895 .33974 L .56488 .34661 L p
1 g
F P
s
P
p
.002 w
.54465 .31868 m .56488 .34661 L .58895 .33974 L p
1 g
F P
s
P
p
.002 w
.44827 .31471 m .42269 .32595 L .43476 .3462 L p
1 g
F P
s
P
p
.002 w
.42076 .35894 m .43476 .3462 L .42269 .32595 L p
1 g
F P
s
P
p
.002 w
.42269 .32595 m .40189 .34486 L .42076 .35894 L p
1 g
F P
s
P
p
.002 w
.36851 .48427 m .39997 .51181 L .40893 .48859 L p
1 g
F P
s
P
p
.002 w
.40893 .48859 m .38308 .46572 L .36851 .48427 L p
1 g
F P
s
P
p
.002 w
.54438 .56002 m .58952 .53001 L .57386 .513 L p
1 g
F P
s
P
p
.002 w
.57386 .513 m .53313 .54002 L .54438 .56002 L p
1 g
F P
s
P
p
.002 w
.60455 .47493 m .57386 .513 L .58952 .53001 L p
1 g
F P
s
P
p
.002 w
.54465 .31868 m .51592 .29906 L .50194 .3191 L p
1 g
F P
s
P
p
.002 w
.47572 .31237 m .50194 .3191 L .51592 .29906 L p
1 g
F P
s
P
p
.002 w
.6221 .42953 m .62457 .38125 L .60058 .37984 L p
1 g
F P
s
P
p
.002 w
.58895 .33974 m .60058 .37984 L .62457 .38125 L p
1 g
F P
s
P
p
.002 w
.36074 .40016 m .36633 .43517 L .38746 .42327 L p
1 g
F P
s
P
p
.002 w
.38746 .42327 m .38329 .39646 L .36074 .40016 L p
1 g
F P
s
P
p
.002 w
.58952 .53001 m .62358 .48782 L .60455 .47493 L p
1 g
F P
s
P
p
.002 w
.6221 .42953 m .60455 .47493 L .62358 .48782 L p
1 g
F P
s
P
p
.002 w
.4925 .57481 m .54438 .56002 L .53313 .54002 L p
1 g
F P
s
P
p
.002 w
.53313 .54002 m .48633 .55325 L .4925 .57481 L p
1 g
F P
s
P
p
.002 w
.39331 .53358 m .43808 .55114 L .43875 .52723 L p
1 g
F P
s
P
p
.002 w
.43875 .52723 m .39997 .51181 L .39331 .53358 L p
1 g
F P
s
P
p
.002 w
.58895 .33974 m .56461 .30578 L .54465 .31868 L p
1 g
F P
s
P
p
.002 w
.51592 .29906 m .54465 .31868 L .56461 .30578 L p
1 g
F P
s
P
p
.002 w
.51592 .29906 m .4817 .29013 L .47572 .31237 L p
1 g
F P
s
P
p
.002 w
.44827 .31471 m .47572 .31237 L .4817 .29013 L p
1 g
F P
s
P
p
.002 w
.36714 .3646 m .36074 .40016 L .38329 .39646 L p
1 g
F P
s
P
p
.002 w
.38329 .39646 m .38825 .3693 L .36714 .3646 L p
1 g
F P
s
P
p
.002 w
.62457 .38125 m .6221 .42953 L .64315 .43751 L p
1 g
F P
s
P
p
.002 w
.62358 .48782 m .64315 .43751 L .6221 .42953 L p
1 g
F P
s
P
p
.002 w
.34802 .44728 m .36851 .48427 L .38308 .46572 L p
1 g
F P
s
P
p
.002 w
.38308 .46572 m .36633 .43517 L .34802 .44728 L p
1 g
F P
s
P
p
.002 w
.43896 .57266 m .4925 .57481 L .48633 .55325 L p
1 g
F P
s
P
p
.002 w
.48633 .55325 m .43808 .55114 L .43896 .57266 L p
1 g
F P
s
P
p
.002 w
.4817 .29013 m .44577 .29309 L .44827 .31471 L p
1 g
F P
s
P
p
.002 w
.42269 .32595 m .44827 .31471 L .44577 .29309 L p
1 g
F P
s
P
p
.002 w
.62457 .38125 m .61139 .335 L .58895 .33974 L p
1 g
F P
s
P
p
.002 w
.56461 .30578 m .58895 .33974 L .61139 .335 L p
1 g
F P
s
P
p
.002 w
.38496 .33255 m .36714 .3646 L .38825 .3693 L p
1 g
F P
s
P
p
.002 w
.38825 .3693 m .40189 .34486 L .38496 .33255 L p
1 g
F P
s
P
p
.002 w
.35689 .50197 m .39331 .53358 L .39997 .51181 L p
1 g
F P
s
P
p
.002 w
.39997 .51181 m .36851 .48427 L .35689 .50197 L p
1 g
F P
s
P
p
.002 w
.44577 .29309 m .41223 .30776 L .42269 .32595 L p
1 g
F P
s
P
p
.002 w
.40189 .34486 m .42269 .32595 L .41223 .30776 L p
1 g
F P
s
P
p
.002 w
.41223 .30776 m .38496 .33255 L .40189 .34486 L p
1 g
F P
s
P
p
.002 w
.56461 .30578 m .52987 .28183 L .51592 .29906 L p
1 g
F P
s
P
p
.002 w
.4817 .29013 m .51592 .29906 L .52987 .28183 L p
1 g
F P
s
P
p
.002 w
.34107 .40476 m .34802 .44728 L .36633 .43517 L p
1 g
F P
s
P
p
.002 w
.36633 .43517 m .36074 .40016 L .34107 .40476 L p
1 g
F P
s
P
p
.002 w
.55483 .57731 m .60337 .545 L .58952 .53001 L p
1 g
F P
s
P
p
.002 w
.58952 .53001 m .54438 .56002 L .55483 .57731 L p
1 g
F P
s
P
p
.002 w
.62358 .48782 m .58952 .53001 L .60337 .545 L p
1 g
F P
s
P
p
.002 w
.64315 .43751 m .64608 .38396 L .62457 .38125 L p
1 g
F P
s
P
p
.002 w
.61139 .335 m .62457 .38125 L .64608 .38396 L p
1 g
F P
s
P
p
.002 w
.3892 .55336 m .43896 .57266 L .43808 .55114 L p
1 g
F P
s
P
p
.002 w
.43808 .55114 m .39331 .53358 L .3892 .55336 L p
1 g
F P
s
P
p
.002 w
.60337 .545 m .64003 .49963 L .62358 .48782 L p
1 g
F P
s
P
p
.002 w
.64315 .43751 m .62358 .48782 L .64003 .49963 L p
1 g
F P
s
P
p
.002 w
.49906 .59334 m .55483 .57731 L .54438 .56002 L p
1 g
F P
s
P
p
.002 w
.54438 .56002 m .4925 .57481 L .49906 .59334 L p
1 g
F P
s
P
p
.002 w
.61139 .335 m .5835 .29571 L .56461 .30578 L p
1 g
F P
s
P
p
.002 w
.52987 .28183 m .56461 .30578 L .5835 .29571 L p
1 g
F P
s
P
p
.002 w
.52987 .28183 m .48833 .27081 L .4817 .29013 L p
1 g
F P
s
P
p
.002 w
.44577 .29309 m .4817 .29013 L .48833 .27081 L p
1 g
F P
s
P
p
.002 w
.33305 .45935 m .35689 .50197 L .36851 .48427 L p
1 g
F P
s
P
p
.002 w
.36851 .48427 m .34802 .44728 L .33305 .45935 L p
1 g
F P
s
P
p
.002 w
.34876 .36144 m .34107 .40476 L .36074 .40016 L p
1 g
F P
s
P
p
.002 w
.36074 .40016 m .36714 .3646 L .34876 .36144 L p
1 g
F P
s
P
p
.002 w
.64608 .38396 m .64315 .43751 L .66119 .44555 L p
1 g
F P
s
P
p
.002 w
.64003 .49963 m .66119 .44555 L .64315 .43751 L p
1 g
F P
s
P
p
.002 w
.44146 .5912 m .49906 .59334 L .4925 .57481 L p
1 g
F P
s
P
p
.002 w
.4925 .57481 m .43896 .57266 L .44146 .5912 L p
1 g
F P
s
P
p
.002 w
.64608 .38396 m .63165 .33256 L .61139 .335 L p
1 g
F P
s
P
p
.002 w
.5835 .29571 m .61139 .335 L .63165 .33256 L p
1 g
F P
s
P
p
.002 w
.48833 .27081 m .44459 .2743 L .44577 .29309 L p
1 g
F P
s
P
p
.002 w
.41223 .30776 m .44577 .29309 L .44459 .2743 L p
1 g
F P
s
P
p
.002 w
.37044 .32236 m .34876 .36144 L .36714 .3646 L p
1 g
F P
s
P
p
.002 w
.36714 .3646 m .38496 .33255 L .37044 .32236 L p
1 g
F P
s
P
p
.002 w
.3486 .51841 m .3892 .55336 L .39331 .53358 L p
1 g
F P
s
P
p
.002 w
.39331 .53358 m .35689 .50197 L .3486 .51841 L p
1 g
F P
s
P
p
.002 w
.44459 .2743 m .40368 .29214 L .41223 .30776 L p
1 g
F P
s
P
p
.002 w
.38496 .33255 m .41223 .30776 L .40368 .29214 L p
1 g
F P
s
P
p
.002 w
.40368 .29214 m .37044 .32236 L .38496 .33255 L p
1 g
F P
s
P
p
.002 w
.5835 .29571 m .5435 .26788 L .52987 .28183 L p
1 g
F P
s
P
p
.002 w
.48833 .27081 m .52987 .28183 L .5435 .26788 L p
1 g
F P
s
P
p
.002 w
.32486 .41018 m .33305 .45935 L .34802 .44728 L p
1 g
F P
s
P
p
.002 w
.34802 .44728 m .34107 .40476 L .32486 .41018 L p
1 g
F P
s
P
p
.002 w
.66119 .44555 m .6645 .38796 L .64608 .38396 L p
1 g
F P
s
P
p
.002 w
.63165 .33256 m .64608 .38396 L .6645 .38796 L p
1 g
F P
s
P
p
.002 w
.56423 .5914 m .61502 .55754 L .60337 .545 L p
1 g
F P
s
P
p
.002 w
.60337 .545 m .55483 .57731 L .56423 .5914 L p
1 g
F P
s
P
p
.002 w
.64003 .49963 m .60337 .545 L .61502 .55754 L p
1 g
F P
s
P
p
.002 w
.38785 .57062 m .44146 .5912 L .43896 .57266 L p
1 g
F P
s
P
p
.002 w
.43896 .57266 m .3892 .55336 L .38785 .57062 L p
1 g
F P
s
P
p
.002 w
.61502 .55754 m .65342 .51007 L .64003 .49963 L p
1 g
F P
s
P
p
.002 w
.66119 .44555 m .64003 .49963 L .65342 .51007 L p
1 g
F P
s
P
p
.002 w
.50588 .60828 m .56423 .5914 L .55483 .57731 L p
1 g
F P
s
P
p
.002 w
.55483 .57731 m .49906 .59334 L .50588 .60828 L p
1 g
F P
s
P
p
.002 w
.63165 .33256 m .60085 .2888 L .5835 .29571 L p
1 g
F P
s
P
p
.002 w
.5435 .26788 m .5835 .29571 L .60085 .2888 L p
1 g
F P
s
P
p
.002 w
.32194 .4711 m .3486 .51841 L .35689 .50197 L p
1 g
F P
s
P
p
.002 w
.35689 .50197 m .33305 .45935 L .32194 .4711 L p
1 g
F P
s
P
p
.002 w
.5435 .26788 m .49549 .25499 L .48833 .27081 L p
1 g
F P
s
P
p
.002 w
.44459 .2743 m .48833 .27081 L .49549 .25499 L p
1 g
F P
s
P
p
.002 w
.33367 .35998 m .32486 .41018 L .34107 .40476 L p
1 g
F P
s
P
p
.002 w
.34107 .40476 m .34876 .36144 L .33367 .35998 L p
1 g
F P
s
P
p
.002 w
.6645 .38796 m .66119 .44555 L .67566 .4535 L p
1 g
F P
s
P
p
.002 w
.65342 .51007 m .67566 .4535 L .66119 .44555 L p
1 g
F P
s
P
p
.002 w
.4456 .60618 m .50588 .60828 L .49906 .59334 L p
1 g
F P
s
P
p
.002 w
.49906 .59334 m .44146 .5912 L .4456 .60618 L p
1 g
F P
s
P
p
.002 w
.6645 .38796 m .64916 .33261 L .63165 .33256 L p
1 g
F P
s
P
p
.002 w
.60085 .2888 m .63165 .33256 L .64916 .33261 L p
1 g
F P
s
P
p
.002 w
.34403 .53313 m .38785 .57062 L .3892 .55336 L p
1 g
F P
s
P
p
.002 w
.3892 .55336 m .3486 .51841 L .34403 .53313 L p
1 g
F P
s
P
p
.002 w
.49549 .25499 m .44481 .25893 L .44459 .2743 L p
1 g
F P
s
P
p
.002 w
.40368 .29214 m .44459 .2743 L .44481 .25893 L p
1 g
F P
s
P
p
.002 w
.35878 .31463 m .33367 .35998 L .34876 .36144 L p
1 g
F P
s
P
p
.002 w
.34876 .36144 m .37044 .32236 L .35878 .31463 L p
1 g
F P
s
P
p
.002 w
.60085 .2888 m .55647 .25771 L .5435 .26788 L p
1 g
F P
s
P
p
.002 w
.49549 .25499 m .5435 .26788 L .55647 .25771 L p
1 g
F P
s
P
p
.002 w
.44481 .25893 m .39735 .27956 L .40368 .29214 L p
1 g
F P
s
P
p
.002 w
.37044 .32236 m .40368 .29214 L .39735 .27956 L p
1 g
F P
s
P
p
.002 w
.39735 .27956 m .35878 .31463 L .37044 .32236 L p
1 g
F P
s
P
p
.002 w
.31269 .41636 m .32194 .4711 L .33305 .45935 L p
1 g
F P
s
P
p
.002 w
.33305 .45935 m .32486 .41018 L .31269 .41636 L p
1 g
F P
s
P
p
.002 w
.67566 .4535 m .67926 .39323 L .6645 .38796 L p
1 g
F P
s
P
p
.002 w
.64916 .33261 m .6645 .38796 L .67926 .39323 L p
1 g
F P
s
P
p
.002 w
.38945 .58478 m .4456 .60618 L .44146 .5912 L p
1 g
F P
s
P
p
.002 w
.44146 .5912 m .38785 .57062 L .38945 .58478 L p
1 g
F P
s
P
p
.002 w
.57229 .60177 m .62407 .5672 L .61502 .55754 L p
1 g
F P
s
P
p
.002 w
.61502 .55754 m .56423 .5914 L .57229 .60177 L p
1 g
F P
s
P
p
.002 w
.65342 .51007 m .61502 .55754 L .62407 .5672 L p
1 g
F P
s
P
p
.002 w
.62407 .5672 m .66326 .5188 L .65342 .51007 L p
1 g
F P
s
P
p
.002 w
.67566 .4535 m .65342 .51007 L .66326 .5188 L p
1 g
F P
s
P
p
.002 w
.51281 .61905 m .57229 .60177 L .56423 .5914 L p
1 g
F P
s
P
p
.002 w
.56423 .5914 m .50588 .60828 L .51281 .61905 L p
1 g
F P
s
P
p
.002 w
.64916 .33261 m .61616 .2854 L .60085 .2888 L p
1 g
F P
s
P
p
.002 w
.55647 .25771 m .60085 .2888 L .61616 .2854 L p
1 g
F P
s
P
p
.002 w
.31518 .48222 m .34403 .53313 L .3486 .51841 L p
1 g
F P
s
P
p
.002 w
.3486 .51841 m .32194 .4711 L .31518 .48222 L p
1 g
F P
s
P
p
.002 w
.55647 .25771 m .50305 .24323 L .49549 .25499 L p
1 g
F P
s
P
p
.002 w
.44481 .25893 m .49549 .25499 L .50305 .24323 L p
1 g
F P
s
P
p
.002 w
.32244 .36036 m .31269 .41636 L .32486 .41018 L p
1 g
F P
s
P
p
.002 w
.32486 .41018 m .33367 .35998 L .32244 .36036 L p
1 g
F P
s
P
p
.002 w
.67926 .39323 m .67566 .4535 L .68601 .46114 L p
1 g
F P
s
P
p
.002 w
.66326 .5188 m .68601 .46114 L .67566 .4535 L p
1 g
F P
s
P
p
.002 w
.45137 .61702 m .51281 .61905 L .50588 .60828 L p
1 g
F P
s
P
p
.002 w
.50588 .60828 m .4456 .60618 L .45137 .61702 L p
1 g
F P
s
P
p
.002 w
.67926 .39323 m .66336 .33528 L .64916 .33261 L p
1 g
F P
s
P
p
.002 w
.61616 .2854 m .64916 .33261 L .66336 .33528 L p
1 g
F P
s
P
p
.002 w
.34351 .54565 m .38945 .58478 L .38785 .57062 L p
1 g
F P
s
P
p
.002 w
.38785 .57062 m .34403 .53313 L .34351 .54565 L p
1 g
F P
s
P
p
.002 w
.50305 .24323 m .44653 .24754 L .44481 .25893 L p
1 g
F P
s
P
p
.002 w
.39735 .27956 m .44481 .25893 L .44653 .24754 L p
1 g
F P
s
P
p
.002 w
.35044 .3097 m .32244 .36036 L .33367 .35998 L p
1 g
F P
s
P
p
.002 w
.33367 .35998 m .35878 .31463 L .35044 .3097 L p
1 g
F P
s
P
p
.002 w
.61616 .2854 m .56843 .25179 L .55647 .25771 L p
1 g
F P
s
P
p
.002 w
.50305 .24323 m .55647 .25771 L .56843 .25179 L p
1 g
F P
s
P
p
.002 w
.44653 .24754 m .39353 .27054 L .39735 .27956 L p
1 g
F P
s
P
p
.002 w
.35878 .31463 m .39735 .27956 L .39353 .27054 L p
1 g
F P
s
P
p
.002 w
.30511 .42318 m .31518 .48222 L .32194 .4711 L p
1 g
F P
s
P
p
.002 w
.32194 .4711 m .31269 .41636 L .30511 .42318 L p
1 g
F P
s
P
p
.002 w
.39353 .27054 m .35044 .3097 L .35878 .31463 L p
1 g
F P
s
P
p
.002 w
.68601 .46114 m .68979 .39972 L .67926 .39323 L p
1 g
F P
s
P
p
.002 w
.66336 .33528 m .67926 .39323 L .68979 .39972 L p
1 g
F P
s
P
p
.002 w
.39413 .59532 m .45137 .61702 L .4456 .60618 L p
1 g
F P
s
P
p
.002 w
.4456 .60618 m .38945 .58478 L .39413 .59532 L p
1 g
F P
s
P
p
.002 w
.57872 .60793 m .63015 .57358 L .62407 .5672 L p
1 g
F P
s
P
p
.002 w
.62407 .5672 m .57229 .60177 L .57872 .60793 L p
1 g
F P
s
P
p
.002 w
.66326 .5188 m .62407 .5672 L .63015 .57358 L p
1 g
F P
s
P
p
.002 w
.63015 .57358 m .66909 .5255 L .66326 .5188 L p
1 g
F P
s
P
p
.002 w
.68601 .46114 m .66326 .5188 L .66909 .5255 L p
1 g
F P
s
P
p
.002 w
.66336 .33528 m .62893 .2858 L .61616 .2854 L p
1 g
F P
s
P
p
.002 w
.56843 .25179 m .61616 .2854 L .62893 .2858 L p
1 g
F P
s
P
p
.002 w
.51969 .62513 m .57872 .60793 L .57229 .60177 L p
1 g
F P
s
P
p
.002 w
.57229 .60177 m .51281 .61905 L .51969 .62513 L p
1 g
F P
s
P
p
.002 w
.31321 .49238 m .34351 .54565 L .34403 .53313 L p
1 g
F P
s
P
p
.002 w
.34403 .53313 m .31518 .48222 L .31321 .49238 L p
1 g
F P
s
P
p
.002 w
.56843 .25179 m .51084 .23608 L .50305 .24323 L p
1 g
F P
s
P
p
.002 w
.44653 .24754 m .50305 .24323 L .51084 .23608 L p
1 g
F P
s
P
p
.002 w
.31559 .36267 m .30511 .42318 L .31269 .41636 L p
1 g
F P
s
P
p
.002 w
.31269 .41636 m .32244 .36036 L .31559 .36267 L p
1 g
F P
s
P
p
.002 w
.68979 .39972 m .68601 .46114 L .69172 .46826 L p
1 g
F P
s
P
p
.002 w
.66909 .5255 m .69172 .46826 L .68601 .46114 L p
1 g
F P
s
P
p
.002 w
.45872 .62318 m .51969 .62513 L .51281 .61905 L p
1 g
F P
s
P
p
.002 w
.51281 .61905 m .45137 .61702 L .45872 .62318 L p
1 g
F P
s
P
p
.002 w
.68979 .39972 m .67368 .34065 L .66336 .33528 L p
1 g
F P
s
P
p
.002 w
.62893 .2858 m .66336 .33528 L .67368 .34065 L p
1 g
F P
s
P
p
.002 w
.34729 .55551 m .39413 .59532 L .38945 .58478 L p
1 g
F P
s
P
p
.002 w
.38945 .58478 m .34351 .54565 L .34729 .55551 L p
1 g
F P
s
P
p
.002 w
.51084 .23608 m .44978 .24067 L .44653 .24754 L p
1 g
F P
s
P
p
.002 w
.39353 .27054 m .44653 .24754 L .44978 .24067 L p
1 g
F P
s
P
p
.002 w
.34586 .30789 m .31559 .36267 L .32244 .36036 L p
1 g
F P
s
P
p
.002 w
.32244 .36036 m .35044 .3097 L .34586 .30789 L p
1 g
F P
s
P
p
.002 w
.62893 .2858 m .57901 .25053 L .56843 .25179 L p
1 g
F P
s
P
p
.002 w
.51084 .23608 m .56843 .25179 L .57901 .25053 L p
1 g
F P
s
P
p
.002 w
.30262 .4305 m .31321 .49238 L .31518 .48222 L p
1 g
F P
s
P
p
.002 w
.31518 .48222 m .30511 .42318 L .30262 .4305 L p
1 g
F P
s
P
p
.002 w
.44978 .24067 m .39247 .26552 L .39353 .27054 L p
1 g
F P
s
P
p
.002 w
.35044 .3097 m .39353 .27054 L .39247 .26552 L p
1 g
F P
s
P
p
.002 w
.39247 .26552 m .34586 .30789 L .35044 .3097 L p
1 g
F P
s
P
p
.002 w
.69172 .46826 m .69553 .40732 L .68979 .39972 L p
1 g
F P
s
P
p
.002 w
.67368 .34065 m .68979 .39972 L .69553 .40732 L p
1 g
F P
s
P
p
.002 w
.40196 .6017 m .45872 .62318 L .45137 .61702 L p
1 g
F P
s
P
p
.002 w
.45137 .61702 m .39413 .59532 L .40196 .6017 L p
1 g
F P
s
P
p
.002 w
.58326 .60944 m .6329 .57627 L .63015 .57358 L p
1 g
F P
s
P
p
.002 w
.63015 .57358 m .57872 .60793 L .58326 .60944 L p
1 g
F P
s
P
p
.002 w
.66909 .5255 m .63015 .57358 L .6329 .57627 L p
1 g
F P
s
P
p
.002 w
.67368 .34065 m .63868 .29021 L .62893 .2858 L p
1 g
F P
s
P
p
.002 w
.57901 .25053 m .62893 .2858 L .63868 .29021 L p
1 g
F P
s
P
p
.002 w
.6329 .57627 m .6705 .52987 L .66909 .5255 L p
1 g
F P
s
P
p
.002 w
.69172 .46826 m .66909 .5255 L .6705 .52987 L p
1 g
F P
s
P
p
.002 w
.52631 .62606 m .58326 .60944 L .57872 .60793 L p
1 g
F P
s
P
p
.002 w
.57872 .60793 m .51969 .62513 L .52631 .62606 L p
1 g
F P
s
P
p
.002 w
.31641 .50124 m .34729 .55551 L .34351 .54565 L p
1 g
F P
s
P
p
.002 w
.34351 .54565 m .31321 .49238 L .31641 .50124 L p
1 g
F P
s
P
p
.002 w
.57901 .25053 m .51866 .23401 L .51084 .23608 L p
1 g
F P
s
P
p
.002 w
.44978 .24067 m .51084 .23608 L .51866 .23401 L p
1 g
F P
s
P
p
.002 w
.31361 .36699 m .30262 .4305 L .30511 .42318 L p
1 g
F P
s
P
p
.002 w
.30511 .42318 m .31559 .36267 L .31361 .36699 L p
1 g
F P
s
P
p
.002 w
.6705 .52987 m .69235 .47464 L .69172 .46826 L p
1 g
F P
s
P
p
.002 w
.69553 .40732 m .69172 .46826 L .69235 .47464 L p
1 g
F P
s
P
p
.002 w
.69553 .40732 m .67961 .34875 L .67368 .34065 L p
1 g
F P
s
P
p
.002 w
.63868 .29021 m .67368 .34065 L .67961 .34875 L p
1 g
F P
s
P
p
.002 w
.46755 .62418 m .52631 .62606 L .51969 .62513 L p
1 g
F P
s
P
p
.002 w
.51969 .62513 m .45872 .62318 L .46755 .62418 L p
1 g
F P
s
P
p
.004 w
.70586 .58683 m
.73673 .61027 L
s
P
p
.002 w
.35555 .56225 m .40196 .6017 L .39413 .59532 L p
1 g
F P
s
P
p
.002 w
.39413 .59532 m .34729 .55551 L .35555 .56225 L p
1 g
F P
s
P
p
.002 w
.51866 .23401 m .45459 .23882 L .44978 .24067 L p
1 g
F P
s
P
p
.002 w
.39247 .26552 m .44978 .24067 L .45459 .23882 L p
1 g
F P
s
P
p
.002 w
.3454 .30944 m .31361 .36699 L .31559 .36267 L p
1 g
F P
s
P
p
.002 w
.31559 .36267 m .34586 .30789 L .3454 .30944 L p
1 g
F P
s
P
p
.002 w
.63868 .29021 m .58783 .25425 L .57901 .25053 L p
1 g
F P
s
P
p
.002 w
.51866 .23401 m .57901 .25053 L .58783 .25425 L p
1 g
F P
s
P
p
.002 w
.30562 .43813 m .31641 .50124 L .31321 .49238 L p
1 g
F P
s
P
p
.002 w
.31321 .49238 m .30262 .4305 L .30562 .43813 L p
1 g
F P
s
P
p
.002 w
.69235 .47464 m .69603 .41591 L .69553 .40732 L p
1 g
F P
s
P
p
.002 w
.67961 .34875 m .69553 .40732 L .69603 .41591 L p
1 g
F P
s
P
p
.002 w
.45459 .23882 m .39438 .26492 L .39247 .26552 L p
1 g
F P
s
P
p
.002 w
.34586 .30789 m .39247 .26552 L .39438 .26492 L p
1 g
F P
s
P
p
.002 w
.39438 .26492 m .3454 .30944 L .34586 .30789 L p
1 g
F P
s
P
p
.002 w
.41292 .60348 m .46755 .62418 L .45872 .62318 L p
1 g
F P
s
P
p
.002 w
.45872 .62318 m .40196 .6017 L .41292 .60348 L p
1 g
F P
s
P
p
.002 w
.58564 .60596 m .63202 .57498 L .6329 .57627 L p
1 g
F P
s
P
p
.002 w
.6329 .57627 m .58326 .60944 L .58564 .60596 L p
1 g
F P
s
P
p
.002 w
.6705 .52987 m .6329 .57627 L .63202 .57498 L p
1 g
F P
s
P
p
.002 w
.67961 .34875 m .64492 .29876 L .63868 .29021 L p
1 g
F P
s
P
p
.002 w
.58783 .25425 m .63868 .29021 L .64492 .29876 L p
1 g
F P
s
P
p
.002 w
.63202 .57498 m .66714 .53162 L .6705 .52987 L p
1 g
F P
s
P
p
.004 w
.66949 .55921 m
.70586 .58683 L
s
P
p
.002 w
.69235 .47464 m .6705 .52987 L .66714 .53162 L p
1 g
F P
s
P
p
.002 w
.32499 .50845 m .35555 .56225 L .34729 .55551 L p
1 g
F P
s
P
p
.002 w
.34729 .55551 m .31641 .50124 L .32499 .50845 L p
1 g
F P
s
P
p
.002 w
.53247 .62146 m .58564 .60596 L .58326 .60944 L p
1 g
F P
s
P
p
.002 w
.58326 .60944 m .52631 .62606 L .53247 .62146 L p
1 g
F P
s
P
p
.002 w
.58783 .25425 m .52629 .23742 L .51866 .23401 L p
1 g
F P
s
P
p
.002 w
.45459 .23882 m .51866 .23401 L .52629 .23742 L p
1 g
F P
s
P
p
.002 w
.31688 .37331 m .30562 .43813 L .30262 .4305 L p
1 g
F P
s
P
p
.002 w
.30262 .4305 m .31361 .36699 L .31688 .37331 L p
1 g
F P
s
P
p
.002 w
.66714 .53162 m .68753 .48005 L .69235 .47464 L p
1 g
F P
s
P
p
.002 w
.69603 .41591 m .69235 .47464 L .68753 .48005 L p
1 g
F P
s
P
p
.002 w
.69603 .41591 m .68068 .35951 L .67961 .34875 L p
1 g
F P
s
P
p
.002 w
.64492 .29876 m .67961 .34875 L .68068 .35951 L p
1 g
F P
s
P
p
.002 w
.47769 .61967 m .53247 .62146 L .52631 .62606 L p
1 g
F P
s
P
p
.002 w
.52631 .62606 m .46755 .62418 L .47769 .61967 L p
1 g
F P
s
P
p
.002 w
.36832 .56548 m .41292 .60348 L .40196 .6017 L p
1 g
F P
s
P
p
.002 w
.40196 .6017 m .35555 .56225 L .36832 .56548 L p
1 g
F P
s
P
p
.002 w
.52629 .23742 m .4609 .24236 L .45459 .23882 L p
1 g
F P
s
P
p
.002 w
.39438 .26492 m .45459 .23882 L .4609 .24236 L p
1 g
F P
s
P
p
.002 w
.64492 .29876 m .59451 .26317 L .58783 .25425 L p
1 g
F P
s
P
p
.002 w
.52629 .23742 m .58783 .25425 L .59451 .26317 L p
1 g
F P
s
P
p
.002 w
.34938 .31454 m .31688 .37331 L .31361 .36699 L p
1 g
F P
s
P
p
.002 w
.31361 .36699 m .3454 .30944 L .34938 .31454 L p
1 g
F P
s
P
p
.002 w
.31438 .44587 m .32499 .50845 L .31641 .50124 L p
1 g
F P
s
P
p
.002 w
.31641 .50124 m .30562 .43813 L .31438 .44587 L p
1 g
F P
s
P
p
.002 w
.68753 .48005 m .69093 .42528 L .69603 .41591 L p
1 g
F P
s
P
p
.002 w
.68068 .35951 m .69603 .41591 L .69093 .42528 L p
1 g
F P
s
P
p
.002 w
.4609 .24236 m .39941 .26905 L .39438 .26492 L p
1 g
F P
s
P
p
.002 w
.3454 .30944 m .39438 .26492 L .39941 .26905 L p
1 g
F P
s
P
p
.002 w
.42685 .60031 m .47769 .61967 L .46755 .62418 L p
1 g
F P
s
P
p
.002 w
.46755 .62418 m .41292 .60348 L .42685 .60031 L p
1 g
F P
s
P
p
.002 w
.39941 .26905 m .34938 .31454 L .3454 .30944 L p
1 g
F P
s
P
p
.002 w
.68068 .35951 m .64725 .31147 L .64492 .29876 L p
1 g
F P
s
P
p
.002 w
.59451 .26317 m .64492 .29876 L .64725 .31147 L p
1 g
F P
s
P
p
.002 w
.58565 .59726 m .62729 .56946 L .63202 .57498 L p
1 g
F P
s
P
p
.002 w
.63202 .57498 m .58564 .60596 L .58565 .59726 L p
1 g
F P
s
P
p
.002 w
.66714 .53162 m .63202 .57498 L .62729 .56946 L p
1 g
F P
s
P
p
.002 w
.33904 .51368 m .36832 .56548 L .35555 .56225 L p
1 g
F P
s
P
p
.002 w
.35555 .56225 m .32499 .50845 L .33904 .51368 L p
1 g
F P
s
P
p
.002 w
.62729 .56946 m .65882 .53052 L .66714 .53162 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.64849 .54327 L
s
P
p
.004 w
.65271 .54647 m
.65387 .54735 L
s
P
p
.004 w
.65387 .54735 m
.65961 .55171 L
s
P
p
.004 w
.65961 .55171 m
.66949 .55921 L
s
P
p
.002 w
.68753 .48005 m .66714 .53162 L .65882 .53052 L p
1 g
F P
s
P
p
.002 w
.53795 .61112 m .58565 .59726 L .58564 .60596 L p
1 g
F P
s
P
p
.002 w
.58564 .60596 m .53247 .62146 L .53795 .61112 L p
1 g
F P
s
P
p
.002 w
.59451 .26317 m .53348 .24656 L .52629 .23742 L p
1 g
F P
s
P
p
.002 w
.4609 .24236 m .52629 .23742 L .53348 .24656 L p
1 g
F P
s
P
p
.002 w
.32563 .38157 m .31438 .44587 L .30562 .43813 L p
1 g
F P
s
P
p
.002 w
.30562 .43813 m .31688 .37331 L .32563 .38157 L p
1 g
F P
s
P
p
.002 w
.69093 .42528 m .67655 .37278 L .68068 .35951 L p
1 g
F P
s
P
p
.002 w
.64725 .31147 m .68068 .35951 L .67655 .37278 L p
1 g
F P
s
P
p
.002 w
.69093 .42528 m .68753 .48005 L .67707 .48426 L p
1 g
F P
s
P
p
.002 w
.65882 .53052 m .67707 .48426 L .68753 .48005 L p
1 g
F P
s
P
p
.002 w
.4889 .60942 m .53795 .61112 L .53247 .62146 L p
1 g
F P
s
P
p
.002 w
.53247 .62146 m .47769 .61967 L .4889 .60942 L p
1 g
F P
s
P
p
.002 w
.38548 .56487 m .42685 .60031 L .41292 .60348 L p
1 g
F P
s
P
p
.002 w
.41292 .60348 m .36832 .56548 L .38548 .56487 L p
1 g
F P
s
P
p
.002 w
.64725 .31147 m .59871 .27733 L .59451 .26317 L p
1 g
F P
s
P
p
.002 w
.53348 .24656 m .59451 .26317 L .59871 .27733 L p
1 g
F P
s
P
p
.002 w
.53348 .24656 m .46862 .25155 L .4609 .24236 L p
1 g
F P
s
P
p
.002 w
.39941 .26905 m .4609 .24236 L .46862 .25155 L p
1 g
F P
s
P
p
.002 w
.35794 .32326 m .32563 .38157 L .31688 .37331 L p
1 g
F P
s
P
p
.002 w
.31688 .37331 m .34938 .31454 L .35794 .32326 L p
1 g
F P
s
P
p
.002 w
.32898 .45347 m .33904 .51368 L .32499 .50845 L p
1 g
F P
s
P
p
.002 w
.32499 .50845 m .31438 .44587 L .32898 .45347 L p
1 g
F P
s
P
p
.002 w
.67707 .48426 m .68003 .43519 L .69093 .42528 L p
1 g
F P
s
P
p
.002 w
.67655 .37278 m .69093 .42528 L .68003 .43519 L p
1 g
F P
s
P
p
.002 w
.4435 .59199 m .4889 .60942 L .47769 .61967 L p
1 g
F P
s
P
p
.002 w
.47769 .61967 m .42685 .60031 L .4435 .59199 L p
1 g
F P
s
P
p
.002 w
.46862 .25155 m .40761 .27809 L .39941 .26905 L p
1 g
F P
s
P
p
.002 w
.34938 .31454 m .39941 .26905 L .40761 .27809 L p
1 g
F P
s
P
p
.002 w
.40761 .27809 m .35794 .32326 L .34938 .31454 L p
1 g
F P
s
P
p
.002 w
.67655 .37278 m .64536 .32817 L .64725 .31147 L p
1 g
F P
s
P
p
.002 w
.59871 .27733 m .64725 .31147 L .64536 .32817 L p
1 g
F P
s
P
p
.002 w
.35842 .51664 m .38548 .56487 L .36832 .56548 L p
1 g
F P
s
P
p
.002 w
.36832 .56548 m .33904 .51368 L .35842 .51664 L p
1 g
F P
s
P
p
.002 w
.58313 .58327 m .61861 .55961 L .62729 .56946 L p
1 g
F P
s
P
p
.002 w
.62729 .56946 m .58565 .59726 L .58313 .58327 L p
1 g
F P
s
P
p
.002 w
.65882 .53052 m .62729 .56946 L .61861 .55961 L p
1 g
F P
s
P
p
.002 w
.61861 .55961 m .64545 .52644 L .65882 .53052 L p
1 g
F P
s
P
p
.002 w
.67707 .48426 m .65882 .53052 L .64545 .52644 L p
1 g
F P
s
P
p
.002 w
.54253 .595 m .58313 .58327 L .58565 .59726 L p
1 g
F P
s
P
p
.002 w
.58565 .59726 m .53795 .61112 L .54253 .595 L p
1 g
F P
s
P
p
.002 w
.59871 .27733 m .53998 .2615 L .53348 .24656 L p
1 g
F P
s
P
p
.002 w
.46862 .25155 m .53348 .24656 L .53998 .2615 L p
1 g
F P
s
P
p
.002 w
.33993 .39163 m .32898 .45347 L .31438 .44587 L p
1 g
F P
s
P
p
.002 w
.31438 .44587 m .32563 .38157 L .33993 .39163 L p
1 g
F P
s
P
p
.002 w
.68003 .43519 m .66705 .38828 L .67655 .37278 L p
1 g
F P
s
P
p
.002 w
.64536 .32817 m .67655 .37278 L .66705 .38828 L p
1 g
F P
s
P
p
.002 w
.68003 .43519 m .67707 .48426 L .66093 .48704 L p
1 g
F P
s
P
p
.002 w
.64545 .52644 m .66093 .48704 L .67707 .48426 L p
1 g
F P
s
P
p
.002 w
.40668 .56021 m .4435 .59199 L .42685 .60031 L p
1 g
F P
s
P
p
.002 w
.42685 .60031 m .38548 .56487 L .40668 .56021 L p
1 g
F P
s
P
p
.002 w
.50086 .59346 m .54253 .595 L .53795 .61112 L p
1 g
F P
s
P
p
.002 w
.53795 .61112 m .4889 .60942 L .50086 .59346 L p
1 g
F P
s
P
p
.002 w
.64536 .32817 m .60014 .2966 L .59871 .27733 L p
1 g
F P
s
P
p
.002 w
.53998 .2615 m .59871 .27733 L .60014 .2966 L p
1 g
F P
s
P
p
.002 w
.53998 .2615 m .47759 .26644 L .46862 .25155 L p
1 g
F P
s
P
p
.002 w
.40761 .27809 m .46862 .25155 L .47759 .26644 L p
1 g
F P
s
P
p
.002 w
.34926 .46066 m .35842 .51664 L .33904 .51368 L p
1 g
F P
s
P
p
.002 w
.33904 .51368 m .32898 .45347 L .34926 .46066 L p
1 g
F P
s
P
p
.002 w
.37108 .33553 m .33993 .39163 L .32563 .38157 L p
1 g
F P
s
P
p
.002 w
.32563 .38157 m .35794 .32326 L .37108 .33553 L p
1 g
F P
s
P
p
.002 w
.66093 .48704 m .66335 .44534 L .68003 .43519 L p
1 g
F P
s
P
p
.002 w
.66705 .38828 m .68003 .43519 L .66335 .44534 L p
1 g
F P
s
P
p
.002 w
.46244 .57853 m .50086 .59346 L .4889 .60942 L p
1 g
F P
s
P
p
.002 w
.4889 .60942 m .4435 .59199 L .46244 .57853 L p
1 g
F P
s
P
p
.002 w
.47759 .26644 m .4189 .29205 L .40761 .27809 L p
1 g
F P
s
P
p
.002 w
.35794 .32326 m .40761 .27809 L .4189 .29205 L p
1 g
F P
s
P
p
.002 w
.4189 .29205 m .37108 .33553 L .35794 .32326 L p
1 g
F P
s
P
p
.002 w
.66705 .38828 m .63905 .34856 L .64536 .32817 L p
1 g
F P
s
P
p
.002 w
.60014 .2966 m .64536 .32817 L .63905 .34856 L p
1 g
F P
s
P
p
.002 w
.38275 .5171 m .40668 .56021 L .38548 .56487 L p
1 g
F P
s
P
p
.002 w
.38548 .56487 m .35842 .51664 L .38275 .5171 L p
1 g
F P
s
P
p
.002 w
.57803 .56416 m .60604 .5455 L .61861 .55961 L p
1 g
F P
s
P
p
.002 w
.61861 .55961 m .58313 .58327 L .57803 .56416 L p
1 g
F P
s
P
p
.002 w
.64545 .52644 m .61861 .55961 L .60604 .5455 L p
1 g
F P
s
P
p
.002 w
.60604 .5455 m .62721 .51931 L .64545 .52644 L p
1 g
F P
s
P
p
.002 w
.66093 .48704 m .64545 .52644 L .62721 .51931 L p
1 g
F P
s
P
p
.002 w
.546 .57334 m .57803 .56416 L .58313 .58327 L p
1 g
F P
s
P
p
.002 w
.58313 .58327 m .54253 .595 L .546 .57334 L p
1 g
F P
s
P
p
.002 w
.60014 .2966 m .54553 .28208 L .53998 .2615 L p
1 g
F P
s
P
p
.002 w
.47759 .26644 m .53998 .2615 L .54553 .28208 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.3596 .40323 m .34926 .46066 L .32898 .45347 L p
1 g
F P
s
P
p
.002 w
.32898 .45347 m .33993 .39163 L .3596 .40323 L p
1 g
F P
s
P
p
.002 w
.66335 .44534 m .65219 .40561 L .66705 .38828 L p
1 g
F P
s
P
p
.002 w
.63905 .34856 m .66705 .38828 L .65219 .40561 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.43142 .55147 m .46244 .57853 L .4435 .59199 L p
1 g
F P
s
P
p
.002 w
.4435 .59199 m .40668 .56021 L .43142 .55147 L p
1 g
F P
s
P
p
.002 w
.66335 .44534 m .66093 .48704 L .63935 .48823 L p
1 g
F P
s
P
p
.002 w
.62721 .51931 m .63935 .48823 L .66093 .48704 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58054 L p
1 g
F P
s
P
p
.002 w
.546 .57334 m .54253 .595 L p
.52259 .57936 L 1 g
F P
s
P
p
.52259 .57936 m .52054 .57775 L .52806 .57645 L 1 g
F
P
p
.52259 .57936 m .52806 .57645 L .546 .57334 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57451 L p
1 g
F P
s
P
p
.54854 .56129 m .53169 .57451 L .53475 .57288 L 1 g
F
P
p
.54854 .56129 m .53475 .57288 L .54007 .56936 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.546 .57334 m .53475 .57288 L p
.54208 .56803 L 1 g
F P
s
P
p
.002 w
.54668 .56499 m .546 .57334 L p
.54208 .56803 L 1 g
F P
s
P
p
.53128 .57265 m .51093 .58054 L .52239 .57721 L 1 g
F
P
p
.002 w
.537 .57297 m .546 .57334 L p
.52054 .57775 L 1 g
F P
s
P
p
.002 w
.54253 .595 m .50086 .59346 L .50778 .58145 L p
1 g
F P
s
P
p
.54253 .595 m .50778 .58145 L .51093 .58054 L 1 g
F
P
p
.52272 .57946 m .51093 .58054 L .52054 .57775 L 1 g
F
P
p
.54253 .595 m .51093 .58054 L .52272 .57946 L 1 g
F
P
p
.002 w
.51093 .58054 m .51079 .57862 L p
.50133 .58051 L 1 g
F P
s
P
p
.002 w
.50816 .58079 m .50086 .59346 L p
.4938 .58021 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46244 .57853 m .46708 .5744 L p
.46827 .5747 L 1 g
F P
s
P
p
.48881 .57994 m .47721 .57932 L .46827 .5747 L 1 g
F
P
p
.47721 .57932 m .46244 .57853 L .46827 .5747 L 1 g
F
P
p
.46872 .57265 m .46042 .56934 L .46067 .56951 L 1 g
F
P
p
.002 w
.4673 .5742 m .46244 .57853 L p
.46171 .57024 L 1 g
F P
s
P
p
.002 w
.46827 .5747 m .46872 .57265 L p
.46067 .56951 L 1 g
F P
s
P
p
.46244 .57853 m .43368 .55043 L .45096 .56264 L 1 g
F
P
p
.46223 .57623 m .45096 .56264 L .46171 .57024 L 1 g
F
P
p
.46244 .57853 m .45096 .56264 L .46223 .57623 L 1 g
F
P
p
.002 w
.45096 .56264 m .45146 .56129 L p
.44563 .55623 L 1 g
F P
s
P
p
.46067 .56951 m .4673 .5742 L .46827 .5747 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43837 .54732 L p
1 g
F P
s
P
p
.43142 .55147 m .43441 .54118 L .43837 .54732 L 1 g
F
P
p
.002 w
.43884 .54805 m .43861 .54815 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.43861 .54815 m .43142 .55147 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.43837 .54732 m .43925 .54566 L p
.43606 .53934 L 1 g
F P
s
P
p
.45146 .56129 m .43837 .54732 L .43869 .5478 L 1 g
F
P
p
.45146 .56129 m .43832 .54741 L .44563 .55623 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43283 .52825 L p
1 g
F P
s
P
p
.43925 .54566 m .43283 .52825 L .43606 .53934 L 1 g
F
P
p
.43837 .54732 m .44345 .51008 L .43884 .54805 L 1 g
F
P
p
.43441 .54118 m .4355 .53743 L .43837 .54732 L 1 g
F
P
p
.4355 .53743 m .44345 .51008 L .43837 .54732 L 1 g
F
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43142 .55147 m .41139 .51492 L .43369 .51156 L p
1 g
F P
s
P
p
.002 w
.43283 .52825 m .43346 .52734 L p
.43323 .52062 L 1 g
F P
s
P
p
.43142 .55147 m .43369 .51156 L .43169 .55055 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43394 .50935 L p
1 g
F P
s
P
p
.41139 .51492 m .43729 .47888 L .43394 .50935 L 1 g
F
P
p
.002 w
.43369 .51156 m .43282 .51169 L p
.43394 .50935 L 1 g
F P
s
P
p
.002 w
.43282 .51169 m .41139 .51492 L p
.43394 .50935 L 1 g
F P
s
P
p
.002 w
.43394 .50935 m .43485 .50826 L p
.43818 .50048 L 1 g
F P
s
P
p
.43346 .52734 m .43394 .50935 L .4331 .51697 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44345 .51008 m .43369 .51156 L p
.43403 .50914 L 1 g
F P
s
P
p
.002 w
.43857 .47708 m .44112 .49433 L p
.43403 .50914 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44259 .49135 L p
1 g
F P
s
P
p
.002 w
.43857 .47708 m .44921 .47796 L p
.44259 .49135 L 1 g
F P
s
P
p
.002 w
.44112 .49433 m .44092 .49297 L p
.44259 .49135 L 1 g
F P
s
P
p
.002 w
.44092 .49297 m .43857 .47708 L p
.44259 .49135 L 1 g
F P
s
P
p
.002 w
.44259 .49135 m .4425 .49145 L p
.44196 .49262 L 1 g
F P
s
P
p
.43485 .50826 m .44259 .49135 L .44196 .49262 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44259 .49135 m .44339 .4905 L p
.44986 .4843 L 1 g
F P
s
P
p
.43485 .50826 m .4425 .49145 L .43818 .50048 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44112 .49433 m .44259 .49135 L .4746 .48004 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45769 .4767 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45769 .4767 m .45826 .47608 L p
.46772 .47193 L 1 g
F P
s
P
p
.002 w
.4746 .48004 m .47707 .46748 L p
.51396 .46981 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.45826 .47608 m .4775 .46727 L .47727 .46738 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.47707 .46748 m .4775 .46727 L .51396 .46981 L 1 g
F
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.48912 .46552 L 1 g
F P
s
P
p
.002 w
.49847 .46412 m .51396 .46981 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51997 .45929 m .51906 .46088 L p
.47913 .45702 L 1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56627 .5096 L p
1 g
F P
s
P
p
.56972 .51718 m .56627 .5096 L .57029 .50576 L 1 g
F
P
p
.002 w
.56586 .5087 m .5662 .50847 L p
.56627 .5096 L 1 g
F P
s
P
p
.002 w
.5662 .50847 m .57029 .50576 L p
.56627 .5096 L 1 g
F P
s
P
p
.002 w
.56627 .5096 m .56515 .50826 L p
.5669 .51962 L 1 g
F P
s
P
p
.55661 .4905 m .56627 .5096 L .56586 .5087 L 1 g
F
P
p
.002 w
.55761 .49175 m .57029 .50576 L .56586 .5087 L p
1 g
F P
s
P
p
.56235 .50148 m .56586 .5087 L .56412 .50487 L 1 g
F
P
p
.55661 .4905 m .56586 .5087 L .56235 .50148 L 1 g
F
P
p
.002 w
.54815 .48129 m .57781 .49643 L .57117 .50466 L p
1 g
F P
s
P
p
.002 w
.57117 .50466 m .57029 .50576 L .55761 .49175 L p
1 g
F P
s
P
p
.57117 .50466 m .55761 .49175 L .55743 .49137 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55743 .49137 L p
1 g
F P
s
P
p
.002 w
.55743 .49137 m .55661 .4905 L p
.56253 .50182 L 1 g
F P
s
P
p
.56253 .50182 m .56713 .51061 L .55743 .49137 L 1 g
F
P
p
.002 w
.55761 .49175 m .55615 .49013 L p
.55743 .49137 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55743 .49137 L p
1 g
F P
s
P
p
.54174 .47608 m .55743 .49137 L .55741 .49136 L 1 g
F
P
p
.54174 .47608 m .55743 .49137 L .55133 .48548 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55615 .49013 m .54815 .48129 L p
.57117 .50466 L 1 g
F P
s
P
p
.002 w
.55743 .49137 m .55743 .49137 L p
.55741 .49136 L 1 g
F P
s
P
p
.002 w
.55615 .49013 m .55761 .49175 L p
.54884 .48306 L 1 g
F P
s
P
p
.002 w
.55743 .49137 m .55834 .49233 L p
.55133 .48548 L 1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56031 .51238 m .54884 .48306 L p
.55761 .49175 L 1 g
F P
s
P
p
.002 w
.51396 .46981 m .51591 .46639 L p
.54598 .48028 L 1 g
F P
s
P
p
.002 w
.54641 .4807 m .51396 .46981 L p
.54598 .48028 L 1 g
F P
s
P
p
.002 w
.5424 .4768 m .54174 .47608 L p
.55143 .48557 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.52897 .45109 m .54815 .48129 L .54241 .47681 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5424 .4768 L p
1 g
F P
s
P
p
.002 w
.54241 .47681 m .54239 .47679 L p
.5424 .4768 L 1 g
F P
s
P
p
.55143 .48557 m .54817 .48242 L .5424 .4768 L 1 g
F
P
p
.002 w
.53733 .51499 m .52678 .51068 L .54768 .48194 L p
1 g
F P
s
P
p
.002 w
.54768 .48194 m .54815 .48129 L .54788 .48213 L p
1 g
F P
s
P
p
.002 w
.54788 .48213 m .53733 .51499 L p
.54768 .48194 L 1 g
F P
s
P
p
.002 w
.52678 .51068 m .51841 .50307 L .5475 .48176 L p
1 g
F P
s
P
p
.002 w
.5475 .48176 m .54815 .48129 L .54768 .48194 L p
1 g
F P
s
P
p
.002 w
.54768 .48194 m .52678 .51068 L p
.5475 .48176 L 1 g
F P
s
P
p
.002 w
.51841 .50307 m .51316 .49297 L .5473 .48157 L p
1 g
F P
s
P
p
.002 w
.5473 .48157 m .54815 .48129 L .5475 .48176 L p
1 g
F P
s
P
p
.002 w
.5475 .48176 m .51841 .50307 L p
.5473 .48157 L 1 g
F P
s
P
p
.54768 .48194 m .54751 .48177 L .54741 .48168 L 1 g
F
P
p
.54777 .48203 m .54771 .48197 L .54768 .48194 L 1 g
F
P
p
.54771 .48197 m .54751 .48177 L .54768 .48194 L 1 g
F
P
p
.54788 .48213 m .54781 .48207 L .54777 .48203 L 1 g
F
P
p
.54781 .48207 m .54751 .48177 L .54777 .48203 L 1 g
F
P
p
.002 w
.54817 .48242 m .54892 .51558 L p
.54788 .48213 L 1 g
F P
s
P
p
.54817 .48242 m .54801 .48226 L .54788 .48213 L 1 g
F
P
p
.54801 .48226 m .54751 .48177 L .54788 .48213 L 1 g
F
P
p
.002 w
.51161 .48146 m .51396 .46981 L .54641 .4807 L p
1 g
F P
s
P
p
.002 w
.54641 .4807 m .54815 .48129 L .54701 .48129 L p
1 g
F P
s
P
p
.002 w
.54701 .48129 m .51161 .48146 L p
.54641 .4807 L 1 g
F P
s
P
p
.002 w
.51316 .49297 m .51161 .48146 L .54701 .48129 L p
1 g
F P
s
P
p
.002 w
.54701 .48129 m .54815 .48129 L .5473 .48157 L p
1 g
F P
s
P
p
.002 w
.5473 .48157 m .51316 .49297 L p
.54701 .48129 L 1 g
F P
s
P
p
.54817 .48242 m .54759 .48185 L .5424 .4768 L 1 g
F
P
p
.54759 .48185 m .5475 .48177 L .54717 .48145 L 1 g
F
P
p
.54759 .48185 m .54717 .48145 L .5424 .4768 L 1 g
F
P
p
.5475 .48177 m .54741 .48168 L .54641 .4807 L 1 g
F
P
p
.5475 .48177 m .54641 .4807 L .5424 .4768 L 1 g
F
P
p
.002 w
.54892 .51558 m .53733 .51499 L .54788 .48213 L p
1 g
F P
s
P
p
.002 w
.54788 .48213 m .54815 .48129 L .54817 .48242 L p
1 g
F P
s
P
p
.51591 .46639 m .52249 .46724 L .54815 .48129 L 1 g
F
P
p
.002 w
.54239 .47679 m .54815 .48129 L p
.52249 .46724 L 1 g
F P
s
P
p
.52214 .46667 m .5424 .4768 L .53312 .47235 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46724 L p
1 g
F P
s
P
p
.002 w
.52249 .46724 m .52214 .46667 L p
.53291 .47224 L 1 g
F P
s
P
p
.53291 .47224 m .54302 .47747 L .52249 .46724 L 1 g
F
P
p
.002 w
.51997 .45929 m .53169 .46844 L p
.52249 .46724 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52249 .46724 L p
1 g
F P
s
P
p
.5 .4634 m .52249 .46724 L .51881 .46677 L 1 g
F
P
p
.5 .4634 m .52261 .46744 L .51386 .46606 L 1 g
F
P
p
.002 w
.51591 .46639 m .51694 .46458 L p
.52249 .46724 L 1 g
F P
s
P
p
.002 w
.51694 .46458 m .51997 .45929 L p
.52249 .46724 L 1 g
F P
s
P
p
.002 w
.53169 .46844 m .54239 .47679 L p
.52249 .46724 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54302 .47747 L p
.53312 .47235 L 1 g
F P
s
P
p
.002 w
.51997 .45929 m .52227 .4572 L p
.5424 .4768 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .51997 .45929 L p
.5424 .4768 L 1 g
F P
s
P
p
.002 w
.52227 .4572 m .52897 .45109 L p
.54241 .47681 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56031 .51238 m .54892 .51558 L .54817 .48242 L p
1 g
F P
s
P
p
.002 w
.54884 .48306 m .56031 .51238 L p
.54817 .48242 L 1 g
F P
s
P
p
.55143 .48557 m .5556 .48965 L .54751 .48177 L 1 g
F
P
p
.002 w
.54817 .48242 m .54815 .48129 L .54884 .48306 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5424 .4768 L p
1 g
F P
s
P
p
.5556 .48965 m .55834 .49233 L .5424 .4768 L 1 g
F
P
p
.002 w
.54815 .48129 m .54641 .4807 L p
.54598 .48028 L 1 g
F P
s
P
p
.002 w
.54884 .48306 m .54815 .48129 L .55615 .49013 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .5669 .51962 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56031 .51238 m .56586 .5087 L p
.56627 .5096 L 1 g
F P
s
P
p
.56972 .51718 m .56665 .51561 L .56627 .5096 L 1 g
F
P
p
.56665 .51561 m .56031 .51238 L .56627 .5096 L 1 g
F
P
p
.002 w
.58979 .5274 m .57036 .54031 L .56692 .53075 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54726 L p
1 g
F P
s
P
p
.55929 .55314 m .5616 .54726 L .57036 .54031 L 1 g
F
P
p
.002 w
.56356 .54224 m .56611 .54151 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.56611 .54151 m .57036 .54031 L p
.5616 .54726 L 1 g
F P
s
P
p
.002 w
.57036 .54031 m .57803 .56416 L p
.55929 .55314 L 1 g
F P
s
P
p
.002 w
.5616 .54726 m .56075 .54566 L p
.5558 .55463 L 1 g
F P
s
P
p
.56654 .52734 m .5616 .54726 L .56335 .54278 L 1 g
F
P
p
.56654 .52734 m .56322 .5434 L .56425 .53988 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.58979 .5274 m .56692 .53075 L .57046 .51755 L 1 g
F
P
p
.002 w
.56751 .52875 m .56654 .52734 L p
.56425 .53988 L 1 g
F P
s
P
p
.002 w
.54817 .5466 m .54892 .51558 L p
.5657 .53493 L 1 g
F P
s
P
p
.002 w
.57036 .54031 m .56356 .54224 L p
.5657 .53493 L 1 g
F P
s
P
p
.002 w
.56356 .54224 m .54817 .5466 L p
.5657 .53493 L 1 g
F P
s
P
p
.002 w
.56692 .53075 m .57036 .54031 L p
.5657 .53493 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56751 .52875 L p
1 g
F P
s
P
p
.56425 .53988 m .56257 .5491 L .56751 .52875 L 1 g
F
P
p
.56425 .53988 m .56219 .54838 L .56378 .54246 L 1 g
F
P
p
.56322 .5434 m .56219 .54838 L .56425 .53988 L 1 g
F
P
p
.002 w
.54892 .51558 m .56031 .51238 L .56692 .53075 L p
1 g
F P
s
P
p
.5657 .53493 m .54892 .51558 L .56692 .53075 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56304 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56304 L .5558 .55463 L 1 g
F
P
p
.002 w
.54817 .5466 m .56356 .54224 L p
.5616 .54726 L 1 g
F P
s
P
p
.55929 .55314 m .55771 .55221 L .5616 .54726 L 1 g
F
P
p
.55771 .55221 m .54817 .5466 L .5616 .54726 L 1 g
F
P
p
.002 w
.57803 .56416 m .546 .57334 L .54668 .56499 L p
1 g
F P
s
P
p
.54854 .56129 m .53844 .57091 L .54034 .56991 L 1 g
F
P
p
.002 w
.54919 .56304 m .54854 .56129 L p
.54034 .56991 L 1 g
F P
s
P
p
.002 w
.54668 .56499 m .54817 .5466 L p
.56082 .55404 L 1 g
F P
s
P
p
.57803 .56416 m .54668 .56499 L .56082 .55404 L 1 g
F
P
p
.002 w
.54986 .56483 m .54919 .56304 L p
.54034 .56991 L 1 g
F P
s
P
p
.002 w
.54919 .56304 m .54998 .56518 L p
.5558 .55463 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5616 .54726 L p
1 g
F P
s
P
p
.5558 .55463 m .54998 .56518 L .5616 .54726 L 1 g
F
P
p
.002 w
.5616 .54726 m .56219 .54838 L p
.56335 .54278 L 1 g
F P
s
P
p
.002 w
.56692 .53075 m .56031 .51238 L p
.57046 .51755 L 1 g
F P
s
P
p
.002 w
.56219 .54838 m .56257 .5491 L p
.56378 .54246 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.5669 .51962 L 1 g
F P
s
P
p
.002 w
.56586 .5087 m .56031 .51238 L p
.55761 .49175 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56627 .5096 L p
1 g
F P
s
P
p
.5669 .51962 m .56854 .53025 L .56627 .5096 L 1 g
F
P
p
.002 w
.56627 .5096 m .56713 .51061 L p
.56412 .50487 L 1 g
F P
s
P
p
.002 w
.57029 .50576 m .58979 .5274 L p
.56972 .51718 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52261 .46744 L p
.51881 .46677 L 1 g
F P
s
P
p
.002 w
.51591 .46639 m .51396 .46981 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.52261 .46744 m .52282 .46778 L p
.51386 .46606 L 1 g
F P
s
P
p
.002 w
.51396 .46981 m .49847 .46412 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51386 .46606 L 1 g
F P
s
P
p
.51386 .46606 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.47913 .45702 m .51906 .46088 L .5 .46388 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .49966 .46393 L 1 g
F
P
p
.47786 .46667 m .5 .46389 L .48912 .46552 L 1 g
F
P
p
.002 w
.49847 .46412 m .49616 .46327 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.49616 .46327 m .47913 .45702 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.51906 .46088 m .51591 .46639 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46389 L p
.49966 .46393 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.48912 .46552 L 1 g
F P
s
P
p
.002 w
.47913 .45702 m .49007 .46104 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.47707 .46748 m .4771 .46733 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.4771 .46733 m .47913 .45702 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.49007 .46104 m .49847 .46412 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46727 L p
1 g
F P
s
P
p
.48912 .46552 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.45826 .47608 m .47749 .46728 L .46772 .47193 L 1 g
F
P
p
.002 w
.4775 .46727 m .47749 .46728 L p
.47727 .46738 L 1 g
F P
s
P
p
.002 w
.47707 .46748 m .4746 .48004 L p
.4579 .4766 L 1 g
F P
s
P
p
.002 w
.47749 .46728 m .47718 .46778 L p
.46772 .47193 L 1 g
F P
s
P
p
.002 w
.4746 .48004 m .45584 .4785 L p
.4579 .4766 L 1 g
F P
s
P
p
.002 w
.47913 .45702 m .47707 .46748 L p
.4579 .4766 L 1 g
F P
s
P
p
.47664 .45825 m .47913 .45702 L .4579 .4766 L 1 g
F
P
p
.45769 .4767 m .4579 .4766 L .45584 .4785 L 1 g
F
P
p
.47664 .45825 m .4579 .4766 L .45769 .4767 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .4767 L p
1 g
F P
s
P
p
.46772 .47193 m .47718 .46778 L .45769 .4767 L 1 g
F
P
p
.002 w
.45769 .4767 m .45763 .47677 L p
.45686 .47751 L 1 g
F P
s
P
p
.44339 .4905 m .45769 .4767 L .45686 .47751 L 1 g
F
P
p
.44339 .4905 m .45763 .47677 L .44986 .4843 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45584 .4785 m .43857 .47708 L p
.47664 .45825 L 1 g
F P
s
P
p
.002 w
.44921 .47796 m .45584 .4785 L p
.44259 .49135 L 1 g
F P
s
P
p
.002 w
.45584 .4785 m .4746 .48004 L p
.44259 .49135 L 1 g
F P
s
P
p
.002 w
.45763 .47677 m .45698 .47747 L p
.44986 .4843 L 1 g
F P
s
P
p
.002 w
.4425 .49145 m .44166 .49233 L p
.43818 .50048 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44259 .49135 L p
1 g
F P
s
P
p
.44986 .4843 m .45698 .47747 L .44259 .49135 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44345 .51008 m .44112 .49433 L p
.4746 .48004 L 1 g
F P
s
P
p
.002 w
.44112 .49433 m .44345 .51008 L p
.43403 .50914 L 1 g
F P
s
P
p
.43729 .47888 m .43857 .47708 L .43369 .51156 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43394 .50935 L p
1 g
F P
s
P
p
.43818 .50048 m .44166 .49233 L .43394 .50935 L 1 g
F
P
p
.002 w
.43394 .50935 m .43287 .51061 L p
.4331 .51697 L 1 g
F P
s
P
p
.002 w
.43369 .51156 m .44345 .51008 L p
.43169 .55055 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43283 .52825 L p
1 g
F P
s
P
p
.43323 .52062 m .43287 .51061 L .43283 .52825 L 1 g
F
P
p
.002 w
.43283 .52825 m .43146 .53025 L p
.43606 .53934 L 1 g
F P
s
P
p
.002 w
.43368 .55043 m .43884 .54805 L p
.45096 .56264 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43837 .54732 L p
1 g
F P
s
P
p
.43606 .53934 m .43146 .53025 L .43837 .54732 L 1 g
F
P
p
.002 w
.43837 .54732 m .43832 .54741 L p
.43869 .5478 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44345 .51008 m .45893 .53878 L .43884 .54805 L p
1 g
F P
s
P
p
.46171 .57024 m .45096 .56264 L .45893 .53878 L 1 g
F
P
p
.002 w
.43884 .54805 m .45893 .53878 L p
.45096 .56264 L 1 g
F P
s
P
p
.002 w
.43832 .54741 m .43743 .5491 L p
.44563 .55623 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45096 .56264 L p
1 g
F P
s
P
p
.44563 .55623 m .43743 .5491 L .45096 .56264 L 1 g
F
P
p
.46067 .56951 m .45069 .56562 L .4673 .5742 L 1 g
F
P
p
.002 w
.46244 .57853 m .43142 .55147 L .43368 .55043 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.45893 .53878 m .48311 .56013 L .4673 .5742 L p
1 g
F P
s
P
p
.46171 .57024 m .45893 .53878 L .4673 .5742 L 1 g
F
P
p
.002 w
.45002 .56518 m .45069 .56562 L p
.46067 .56951 L 1 g
F P
s
P
p
.46042 .56934 m .45002 .56518 L .46067 .56951 L 1 g
F
P
p
.002 w
.48911 .58001 m .48921 .57862 L p
.481 .57795 L 1 g
F P
s
P
p
.002 w
.46708 .5744 m .48311 .56013 L p
.48881 .57994 L 1 g
F P
s
P
p
.002 w
.45069 .56562 m .4678 .57686 L .46827 .5747 L p
1 g
F P
s
P
p
.002 w
.50086 .59346 m .46358 .57897 L p
.4938 .58021 L 1 g
F P
s
P
p
.52054 .57775 m .51093 .58054 L .51322 .572 L 1 g
F
P
p
.002 w
.50778 .58145 m .50816 .58079 L p
.51093 .58054 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48892 .58255 L p
1 g
F P
s
P
p
.51079 .57862 m .48892 .58255 L .49297 .58218 L 1 g
F
P
p
.50133 .58051 m .50816 .58079 L .51093 .58054 L 1 g
F
P
p
.002 w
.50816 .58079 m .51322 .572 L p
.51093 .58054 L 1 g
F P
s
P
p
.002 w
.48892 .58255 m .48889 .583 L p
.49297 .58218 L 1 g
F P
s
P
p
.002 w
.46358 .57897 m .46244 .57853 L p
.4938 .58021 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48911 .58001 L p
1 g
F P
s
P
p
.481 .57795 m .4678 .57686 L .48911 .58001 L 1 g
F
P
p
.4938 .58021 m .48881 .57994 L .48311 .56013 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58091 L p
1 g
F P
s
P
p
.002 w
.51096 .58091 m .51093 .58054 L p
.50852 .58081 L 1 g
F P
s
P
p
.50852 .58081 m .48889 .583 L .51096 .58091 L 1 g
F
P
p
.50133 .58051 m .49297 .58218 L .50816 .58079 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48311 .56013 m .51322 .572 L .50816 .58079 L p
1 g
F P
s
P
p
.4938 .58021 m .48311 .56013 L .50816 .58079 L 1 g
F
P
p
.49297 .58218 m .48889 .583 L .51093 .58054 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53169 .57451 L p
1 g
F P
s
P
p
.002 w
.53169 .57451 m .53128 .57265 L p
.52239 .57721 L 1 g
F P
s
P
p
.52239 .57721 m .51111 .583 L .53169 .57451 L 1 g
F
P
p
.002 w
.51322 .572 m .53475 .57288 L p
.52054 .57775 L 1 g
F P
s
P
p
.002 w
.53475 .57288 m .537 .57297 L p
.53169 .57451 L 1 g
F P
s
P
p
.52054 .57775 m .53475 .57288 L .53169 .57451 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54986 .56483 L p
1 g
F P
s
P
p
.53844 .57091 m .5322 .57686 L .54986 .56483 L 1 g
F
P
p
.002 w
.51322 .572 m .52553 .54558 L p
.54208 .56803 L 1 g
F P
s
P
p
.002 w
.53475 .57288 m .51322 .572 L p
.54208 .56803 L 1 g
F P
s
P
p
.53844 .57091 m .53475 .57288 L .5322 .57686 L 1 g
F
P
p
.002 w
.53169 .57451 m .53176 .57486 L p
.53475 .57288 L 1 g
F P
s
P
p
.002 w
.53176 .57486 m .5322 .57686 L p
.53475 .57288 L 1 g
F P
s
P
p
.54007 .56936 m .53475 .57288 L .53844 .57091 L 1 g
F
P
p
.002 w
.52553 .54558 m .54817 .5466 L .54668 .56499 L p
1 g
F P
s
P
p
.54208 .56803 m .52553 .54558 L .54668 .56499 L 1 g
F
P
p
.002 w
.51093 .58054 m .51111 .583 L p
.52239 .57721 L 1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.63905 .34856 m .5986 .32058 L .60014 .2966 L p
1 g
F P
s
P
p
.002 w
.54553 .28208 m .60014 .2966 L .5986 .32058 L p
1 g
F P
s
P
p
.002 w
.3748 .46717 m .38275 .5171 L .35842 .51664 L p
1 g
F P
s
P
p
.002 w
.35842 .51664 m .34926 .46066 L .3748 .46717 L p
1 g
F P
s
P
p
.002 w
.54553 .28208 m .48756 .28682 L .47759 .26644 L p
1 g
F P
s
P
p
.002 w
.4189 .29205 m .47759 .26644 L .48756 .28682 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5239 .45571 L
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.38863 .35114 m .3596 .40323 L .33993 .39163 L p
1 g
F P
s
P
p
.002 w
.33993 .39163 m .37108 .33553 L .38863 .35114 L p
1 g
F P
s
P
p
.002 w
.63935 .48823 m .64114 .4554 L .66335 .44534 L p
1 g
F P
s
P
p
.002 w
.65219 .40561 m .66335 .44534 L .64114 .4554 L p
1 g
F P
s
P
p
.002 w
.65219 .40561 m .62833 .3721 L .63905 .34856 L p
1 g
F P
s
P
p
.002 w
.5986 .32058 m .63905 .34856 L .62833 .3721 L p
1 g
F P
s
P
p
.002 w
.48756 .28682 m .43306 .31072 L .4189 .29205 L p
1 g
F P
s
P
p
.002 w
.37108 .33553 m .4189 .29205 L .43306 .31072 L p
1 g
F P
s
P
p
.002 w
.43306 .31072 m .38863 .35114 L .37108 .33553 L p
1 g
F P
s
P
p
.002 w
.41139 .51492 m .43142 .55147 L .40668 .56021 L p
1 g
F P
s
P
p
.002 w
.40668 .56021 m .38275 .5171 L .41139 .51492 L p
1 g
F P
s
P
p
.002 w
.57036 .54031 m .58979 .5274 L .60604 .5455 L p
1 g
F P
s
P
p
.002 w
.60604 .5455 m .57803 .56416 L .57036 .54031 L p
1 g
F P
s
P
p
.002 w
.62721 .51931 m .60604 .5455 L .58979 .5274 L p
1 g
F P
s
P
p
.002 w
.5986 .32058 m .54986 .30785 L .54553 .28208 L p
1 g
F P
s
P
p
.002 w
.48756 .28682 m .54553 .28208 L .54986 .30785 L p
1 g
F P
s
P
p
.002 w
.58979 .5274 m .60445 .50923 L .62721 .51931 L p
1 g
F P
s
P
p
.002 w
.63935 .48823 m .62721 .51931 L .60445 .50923 L p
1 g
F P
s
P
p
.002 w
.64114 .4554 m .63223 .42424 L .65219 .40561 L p
1 g
F P
s
P
p
.002 w
.62833 .3721 m .65219 .40561 L .63223 .42424 L p
1 g
F P
s
P
p
.002 w
.38419 .41603 m .3748 .46717 L .34926 .46066 L p
1 g
F P
s
P
p
.002 w
.34926 .46066 m .3596 .40323 L .38419 .41603 L p
1 g
F P
s
P
p
.002 w
.60445 .50923 m .61281 .48769 L .63935 .48823 L p
1 g
F P
s
P
p
.002 w
.64114 .4554 m .63935 .48823 L .61281 .48769 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62833 .3721 m .594 .34864 L .5986 .32058 L p
1 g
F P
s
P
p
.002 w
.54986 .30785 m .5986 .32058 L .594 .34864 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.4049 .47273 m .41139 .51492 L .38275 .5171 L p
1 g
F P
s
P
p
.002 w
.38275 .5171 m .3748 .46717 L .4049 .47273 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.54986 .30785 m .49823 .31226 L .48756 .28682 L p
1 g
F P
s
P
p
.002 w
.43306 .31072 m .48756 .28682 L .49823 .31226 L p
1 g
F P
s
P
p
.002 w
.61281 .48769 m .61395 .46499 L .64114 .4554 L p
1 g
F P
s
P
p
.002 w
.63223 .42424 m .64114 .4554 L .61395 .46499 L p
1 g
F P
s
P
p
.002 w
.41013 .36967 m .38419 .41603 L .3596 .40323 L p
1 g
F P
s
P
p
.002 w
.3596 .40323 m .38863 .35114 L .41013 .36967 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.50481 .53727 m .52553 .54558 L .51322 .572 L p
1 g
F P
s
P
p
.002 w
.51322 .572 m .48311 .56013 L .50481 .53727 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.63223 .42424 m .61336 .39809 L .62833 .3721 L p
1 g
F P
s
P
p
.002 w
.594 .34864 m .62833 .3721 L .61336 .39809 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49823 .31226 m .44972 .33365 L .43306 .31072 L p
1 g
F P
s
P
p
.002 w
.38863 .35114 m .43306 .31072 L .44972 .33365 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.44972 .33365 m .41013 .36967 L .38863 .35114 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.594 .34864 m .55279 .33811 L .54986 .30785 L p
1 g
F P
s
P
p
.002 w
.49823 .31226 m .54986 .30785 L .55279 .33811 L p
1 g
F P
s
P
p
.002 w
.61395 .46499 m .60768 .44354 L .63223 .42424 L p
1 g
F P
s
P
p
.002 w
.61336 .39809 m .63223 .42424 L .60768 .44354 L p
1 g
F P
s
P
p
.002 w
.60445 .50923 m .58979 .5274 L .57029 .50576 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57029 .50576 m .57781 .49643 L .60445 .50923 L p
1 g
F P
s
P
p
.002 w
.61281 .48769 m .60445 .50923 L .57781 .49643 L p
1 g
F P
s
P
p
.002 w
.48829 .52247 m .50481 .53727 L .48311 .56013 L p
1 g
F P
s
P
p
.002 w
.48311 .56013 m .45893 .53878 L .48829 .52247 L p
1 g
F P
s
P
p
.002 w
.41299 .4296 m .4049 .47273 L .3748 .46717 L p
1 g
F P
s
P
p
.002 w
.3748 .46717 m .38419 .41603 L .41299 .4296 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.61395 .46499 m .61281 .48769 L .58206 .48536 L p
1 g
F P
s
P
p
.002 w
.57781 .49643 m .58206 .48536 L .61281 .48769 L p
1 g
F P
s
P
p
.002 w
.53733 .51499 m .54892 .51558 L .54817 .5466 L p
1 g
F P
s
P
p
.002 w
.54817 .5466 m .52553 .54558 L .53733 .51499 L p
1 g
F P
s
P
p
.002 w
.61336 .39809 m .58639 .37991 L .594 .34864 L p
1 g
F P
s
P
p
.002 w
.55279 .33811 m .594 .34864 L .58639 .37991 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41139 .51492 m .4049 .47273 L .43857 .47708 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58206 .48536 m .58259 .47374 L .61395 .46499 L p
1 g
F P
s
P
p
.002 w
.60768 .44354 m .61395 .46499 L .58259 .47374 L p
1 g
F P
s
P
p
.002 w
.55279 .33811 m .50922 .34202 L .49823 .31226 L p
1 g
F P
s
P
p
.002 w
.44972 .33365 m .49823 .31226 L .50922 .34202 L p
1 g
F P
s
P
p
.002 w
.60768 .44354 m .59457 .42563 L .61336 .39809 L p
1 g
F P
s
P
p
.002 w
.58639 .37991 m .61336 .39809 L .59457 .42563 L p
1 g
F P
s
P
p
.002 w
.52678 .51068 m .53733 .51499 L .52553 .54558 L p
1 g
F P
s
P
p
.002 w
.52553 .54558 m .50481 .53727 L .52678 .51068 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43496 .39053 m .41299 .4296 L .38419 .41603 L p
1 g
F P
s
P
p
.002 w
.38419 .41603 m .41013 .36967 L .43496 .39053 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.4778 .50268 m .48829 .52247 L .45893 .53878 L p
1 g
F P
s
P
p
.002 w
.45893 .53878 m .44345 .51008 L .4778 .50268 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.50922 .34202 m .46834 .36015 L .44972 .33365 L p
1 g
F P
s
P
p
.002 w
.41013 .36967 m .44972 .33365 L .46834 .36015 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.46834 .36015 m .43496 .39053 L .41013 .36967 L p
1 g
F P
s
P
p
.002 w
.58259 .47374 m .57932 .4628 L .60768 .44354 L p
1 g
F P
s
P
p
.002 w
.59457 .42563 m .60768 .44354 L .57932 .4628 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51841 .50307 m .52678 .51068 L .50481 .53727 L p
1 g
F P
s
P
p
.002 w
.50481 .53727 m .48829 .52247 L .51841 .50307 L p
1 g
F P
s
P
p
.002 w
.58639 .37991 m .55412 .37187 L .55279 .33811 L p
1 g
F P
s
P
p
.002 w
.50922 .34202 m .55279 .33811 L .55412 .37187 L p
1 g
F P
s
P
p
.002 w
.44503 .44344 m .43857 .47708 L .4049 .47273 L p
1 g
F P
s
P
p
.002 w
.4049 .47273 m .41299 .4296 L .44503 .44344 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58206 .48536 m .57781 .49643 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.59457 .42563 m .57595 .41328 L .58639 .37991 L p
1 g
F P
s
P
p
.002 w
.55412 .37187 m .58639 .37991 L .57595 .41328 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58259 .47374 m .58206 .48536 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.4746 .48004 m .4778 .50268 L .44345 .51008 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57932 .4628 m .57256 .45373 L .59457 .42563 L p
1 g
F P
s
P
p
.002 w
.57595 .41328 m .59457 .42563 L .57256 .45373 L p
1 g
F P
s
P
p
.002 w
.57932 .4628 m .58259 .47374 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.51316 .49297 m .51841 .50307 L .48829 .52247 L p
1 g
F P
s
P
p
.002 w
.48829 .52247 m .4778 .50268 L .51316 .49297 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.55412 .37187 m .52013 .37508 L .50922 .34202 L p
1 g
F P
s
P
p
.002 w
.46834 .36015 m .50922 .34202 L .52013 .37508 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.46224 .41301 m .44503 .44344 L .41299 .4296 L p
1 g
F P
s
P
p
.002 w
.41299 .4296 m .43496 .39053 L .46224 .41301 L p
1 g
F P
s
P
p
.002 w
.57256 .45373 m .57932 .4628 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57595 .41328 m .55379 .40792 L .55412 .37187 L p
1 g
F P
s
P
p
.002 w
.52013 .37508 m .55412 .37187 L .55379 .40792 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57256 .45373 m .56304 .44752 L .57595 .41328 L p
1 g
F P
s
P
p
.002 w
.55379 .40792 m .57595 .41328 L .56304 .44752 L p
1 g
F P
s
P
p
.002 w
.52013 .37508 m .48827 .38931 L .46834 .36015 L p
1 g
F P
s
P
p
.002 w
.43496 .39053 m .46834 .36015 L .48827 .38931 L p
1 g
F P
s
P
p
.002 w
.43857 .47708 m .44503 .44344 L .47913 .45702 L p
1 g
F P
s
P
p
.002 w
.48827 .38931 m .46224 .41301 L .43496 .39053 L p
1 g
F P
s
P
p
.002 w
.56304 .44752 m .57256 .45373 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51161 .48146 m .51316 .49297 L .4778 .50268 L p
1 g
F P
s
P
p
.002 w
.4778 .50268 m .4746 .48004 L .51161 .48146 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55177 .44487 m .56304 .44752 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.53998 .4461 m .55177 .44487 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.52897 .45109 m .53998 .4461 L .54815 .48129 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.56304 .44752 m .55177 .44487 L .55379 .40792 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.004 w
.54815 .48129 m
.5497 .48292 L
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55379 .40792 m .53052 .41023 L .52013 .37508 L p
1 g
F P
s
P
p
.002 w
.48827 .38931 m .52013 .37508 L .53052 .41023 L p
1 g
F P
s
P
p
.002 w
.53052 .41023 m .55379 .40792 L .55177 .44487 L p
1 g
F P
s
P
p
.002 w
.49095 .43623 m .47913 .45702 L .44503 .44344 L p
1 g
F P
s
P
p
.002 w
.44503 .44344 m .46224 .41301 L .49095 .43623 L p
1 g
F P
s
P
p
.002 w
.51396 .46981 m .51161 .48146 L .4746 .48004 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.55177 .44487 m .53998 .4461 L .53052 .41023 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53998 .4461 m .52897 .45109 L .50875 .42002 L p
1 g
F P
s
P
p
.002 w
.50875 .42002 m .53052 .41023 L .53998 .4461 L p
1 g
F P
s
P
p
.002 w
.53052 .41023 m .50875 .42002 L .48827 .38931 L p
1 g
F P
s
P
p
.002 w
.46224 .41301 m .48827 .38931 L .50875 .42002 L p
1 g
F P
s
P
p
.002 w
.50875 .42002 m .49095 .43623 L .46224 .41301 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52897 .45109 m .51997 .45929 L .49095 .43623 L p
1 g
F P
s
P
p
.002 w
.49095 .43623 m .50875 .42002 L .52897 .45109 L p
1 g
F P
s
P
p
.002 w
.47913 .45702 m .49095 .43623 L .51997 .45929 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.5497 .48292 m
.57777 .51253 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .73673 .61027 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57777 .51253 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.374419)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.374419)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48036 .47622 m .51151 .46051 L .49505 .43726 L p
1 g
F P
s
P
p
.002 w
.49505 .43726 m .47094 .44935 L .48036 .47622 L p
1 g
F P
s
P
p
.002 w
.51472 .41862 m .49505 .43726 L .51151 .46051 L p
1 g
F P
s
P
p
.002 w
.47094 .44935 m .49505 .43726 L .47872 .41386 L p
1 g
F P
s
P
p
.002 w
.49505 .43726 m .51472 .41862 L .49215 .40112 L p
1 g
F P
s
P
p
.002 w
.49215 .40112 m .47872 .41386 L .49505 .43726 L p
1 g
F P
s
P
p
.002 w
.52796 .3953 m .51472 .41862 L .53695 .43643 L p
1 g
F P
s
P
p
.002 w
.51151 .46051 m .53695 .43643 L .51472 .41862 L p
1 g
F P
s
P
p
.002 w
.51472 .41862 m .52796 .3953 L .50113 .38517 L p
1 g
F P
s
P
p
.002 w
.50113 .38517 m .49215 .40112 L .51472 .41862 L p
1 g
F P
s
P
p
.002 w
.47872 .41386 m .46224 .42208 L .47094 .44935 L p
1 g
F P
s
P
p
.002 w
.46224 .42208 m .47872 .41386 L .46281 .39073 L p
1 g
F P
s
P
p
.002 w
.47872 .41386 m .49215 .40112 L .46965 .38424 L p
1 g
F P
s
P
p
.002 w
.46965 .38424 m .46281 .39073 L .47872 .41386 L p
1 g
F P
s
P
p
.002 w
.49215 .40112 m .50113 .38517 L .47419 .37611 L p
1 g
F P
s
P
p
.002 w
.47419 .37611 m .46965 .38424 L .49215 .40112 L p
1 g
F P
s
P
p
.002 w
.49034 .50219 m .5278 .48319 L .51151 .46051 L p
1 g
F P
s
P
p
.002 w
.51151 .46051 m .48036 .47622 L .49034 .50219 L p
1 g
F P
s
P
p
.002 w
.53695 .43643 m .51151 .46051 L .5278 .48319 L p
1 g
F P
s
P
p
.002 w
.44654 .48193 m .48036 .47622 L .47094 .44935 L p
1 g
F P
s
P
p
.002 w
.47094 .44935 m .44479 .45363 L .44654 .48193 L p
1 g
F P
s
P
p
.002 w
.44479 .45363 m .47094 .44935 L .46224 .42208 L p
1 g
F P
s
P
p
.002 w
.55418 .40631 m .53695 .43643 L .55845 .45422 L p
1 g
F P
s
P
p
.002 w
.5278 .48319 m .55845 .45422 L .53695 .43643 L p
1 g
F P
s
P
p
.002 w
.53695 .43643 m .55418 .40631 L .52796 .3953 L p
1 g
F P
s
P
p
.002 w
.46224 .42208 m .44438 .42491 L .44479 .45363 L p
1 g
F P
s
P
p
.002 w
.44438 .42491 m .46224 .42208 L .45442 .39489 L p
1 g
F P
s
P
p
.002 w
.46281 .39073 m .45442 .39489 L .46224 .42208 L p
1 g
F P
s
P
p
.002 w
.53336 .36961 m .52796 .3953 L .55418 .40631 L p
1 g
F P
s
P
p
.002 w
.52796 .3953 m .53336 .36961 L .5047 .36764 L p
1 g
F P
s
P
p
.002 w
.5047 .36764 m .50113 .38517 L .52796 .3953 L p
1 g
F P
s
P
p
.002 w
.50113 .38517 m .5047 .36764 L .47595 .3672 L p
1 g
F P
s
P
p
.002 w
.47595 .3672 m .47419 .37611 L .50113 .38517 L p
1 g
F P
s
P
p
.002 w
.44962 .50927 m .49034 .50219 L .48036 .47622 L p
1 g
F P
s
P
p
.002 w
.48036 .47622 m .44654 .48193 L .44962 .50927 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .45442 .39489 L .46281 .39073 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .46281 .39073 L .46965 .38424 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .46965 .38424 L .47419 .37611 L closepath p
1 g
F P
s
P
p
.002 w
.41925 .44955 m .44479 .45363 L .44438 .42491 L p
1 g
F P
s
P
p
.002 w
.44438 .42491 m .42701 .422 L .41925 .44955 L p
1 g
F P
s
P
p
.002 w
.42701 .422 m .44438 .42491 L .44533 .39629 L p
1 g
F P
s
P
p
.002 w
.45442 .39489 m .44533 .39629 L .44438 .42491 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .44533 .39629 L .45442 .39489 L closepath p
1 g
F P
s
P
p
.002 w
.55845 .45422 m .57932 .41802 L .55418 .40631 L p
1 g
F P
s
P
p
.002 w
.56138 .37309 m .55418 .40631 L .57932 .41802 L p
1 g
F P
s
P
p
.002 w
.55418 .40631 m .56138 .37309 L .53336 .36961 L p
1 g
F P
s
P
p
.002 w
.50069 .52678 m .54363 .50489 L .5278 .48319 L p
1 g
F P
s
P
p
.002 w
.5278 .48319 m .49034 .50219 L .50069 .52678 L p
1 g
F P
s
P
p
.002 w
.55845 .45422 m .5278 .48319 L .54363 .50489 L p
1 g
F P
s
P
p
.002 w
.4134 .47688 m .44654 .48193 L .44479 .45363 L p
1 g
F P
s
P
p
.002 w
.44479 .45363 m .41925 .44955 L .4134 .47688 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .47419 .37611 L .47595 .3672 L closepath p
1 g
F P
s
P
p
.002 w
.50244 .35035 m .5047 .36764 L .53336 .36961 L p
1 g
F P
s
P
p
.002 w
.5047 .36764 m .50244 .35035 L .47473 .35844 L p
1 g
F P
s
P
p
.002 w
.47473 .35844 m .47595 .3672 L .5047 .36764 L p
1 g
F P
s
P
p
.002 w
.54363 .50489 m .57881 .47166 L .55845 .45422 L p
1 g
F P
s
P
p
.002 w
.57932 .41802 m .55845 .45422 L .57881 .47166 L p
1 g
F P
s
P
p
.002 w
.44533 .39629 m .43653 .39474 L .42701 .422 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .43653 .39474 L .44533 .39629 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .47595 .3672 L .47473 .35844 L closepath p
1 g
F P
s
P
p
.002 w
.53024 .34418 m .53336 .36961 L .56138 .37309 L p
1 g
F P
s
P
p
.002 w
.53336 .36961 m .53024 .34418 L .50244 .35035 L p
1 g
F P
s
P
p
.002 w
.454 .53512 m .50069 .52678 L .49034 .50219 L p
1 g
F P
s
P
p
.002 w
.49034 .50219 m .44962 .50927 L .454 .53512 L p
1 g
F P
s
P
p
.002 w
.41197 .41358 m .42701 .422 L .43653 .39474 L p
1 g
F P
s
P
p
.002 w
.43653 .39474 m .42895 .39041 L .41197 .41358 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .42895 .39041 L .43653 .39474 L closepath p
1 g
F P
s
P
p
.002 w
.397 .43737 m .41925 .44955 L .42701 .422 L p
1 g
F P
s
P
p
.002 w
.42701 .422 m .41197 .41358 L .397 .43737 L p
1 g
F P
s
P
p
.002 w
.40961 .50347 m .44962 .50927 L .44654 .48193 L p
1 g
F P
s
P
p
.002 w
.44654 .48193 m .4134 .47688 L .40961 .50347 L p
1 g
F P
s
P
p
.002 w
.47064 .35079 m .47473 .35844 L .50244 .35035 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .47473 .35844 L .47064 .35079 L closepath p
1 g
F P
s
P
p
.002 w
.49449 .33514 m .50244 .35035 L .53024 .34418 L p
1 g
F P
s
P
p
.002 w
.50244 .35035 m .49449 .33514 L .47064 .35079 L p
1 g
F P
s
P
p
.002 w
.57881 .47166 m .60289 .43021 L .57932 .41802 L p
1 g
F P
s
P
p
.002 w
.58824 .37803 m .57932 .41802 L .60289 .43021 L p
1 g
F P
s
P
p
.002 w
.57932 .41802 m .58824 .37803 L .56138 .37309 L p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .47064 .35079 L .46409 .34507 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .46409 .34507 L .45578 .34194 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .45578 .34194 L .44661 .34176 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .44661 .34176 L .43759 .34455 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .43759 .34455 L .42973 .35003 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .42973 .35003 L .42389 .35759 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .42389 .35759 L .42073 .36638 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .42073 .36638 L .42058 .37543 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .42058 .37543 L .42343 .38374 L closepath p
1 g
F P
s
P
p
.002 w
.44763 .3683 m .42343 .38374 L .42895 .39041 L closepath p
1 g
F P
s
P
p
.002 w
.4009 .40048 m .41197 .41358 L .42895 .39041 L p
1 g
F P
s
P
p
.002 w
.42895 .39041 m .42343 .38374 L .4009 .40048 L p
1 g
F P
s
P
p
.002 w
.38438 .46133 m .4134 .47688 L .41925 .44955 L p
1 g
F P
s
P
p
.002 w
.41925 .44955 m .397 .43737 L .38438 .46133 L p
1 g
F P
s
P
p
.002 w
.5576 .34007 m .56138 .37309 L .58824 .37803 L p
1 g
F P
s
P
p
.002 w
.56138 .37309 m .5576 .34007 L .53024 .34418 L p
1 g
F P
s
P
p
.002 w
.46409 .34507 m .47064 .35079 L .49449 .33514 L p
1 g
F P
s
P
p
.002 w
.51124 .54946 m .55868 .52515 L .54363 .50489 L p
1 g
F P
s
P
p
.002 w
.54363 .50489 m .50069 .52678 L .51124 .54946 L p
1 g
F P
s
P
p
.002 w
.57881 .47166 m .54363 .50489 L .55868 .52515 L p
1 g
F P
s
P
p
.002 w
.60289 .43021 m .57881 .47166 L .59761 .48843 L p
1 g
F P
s
P
p
.002 w
.55868 .52515 m .59761 .48843 L .57881 .47166 L p
1 g
F P
s
P
p
.002 w
.38052 .4182 m .397 .43737 L .41197 .41358 L p
1 g
F P
s
P
p
.002 w
.41197 .41358 m .4009 .40048 L .38052 .4182 L p
1 g
F P
s
P
p
.002 w
.3951 .38404 m .4009 .40048 L .42343 .38374 L p
1 g
F P
s
P
p
.002 w
.42343 .38374 m .42058 .37543 L .3951 .38404 L p
1 g
F P
s
P
p
.002 w
.51874 .32168 m .53024 .34418 L .5576 .34007 L p
1 g
F P
s
P
p
.002 w
.53024 .34418 m .51874 .32168 L .49449 .33514 L p
1 g
F P
s
P
p
.002 w
.49449 .33514 m .48162 .3237 L .46409 .34507 L p
1 g
F P
s
P
p
.002 w
.45578 .34194 m .46409 .34507 L .48162 .3237 L p
1 g
F P
s
P
p
.002 w
.40801 .52876 m .454 .53512 L .44962 .50927 L p
1 g
F P
s
P
p
.002 w
.44962 .50927 m .40961 .50347 L .40801 .52876 L p
1 g
F P
s
P
p
.002 w
.48162 .3237 m .49449 .33514 L .51874 .32168 L p
1 g
F P
s
P
p
.002 w
.45963 .55892 m .51124 .54946 L .50069 .52678 L p
1 g
F P
s
P
p
.002 w
.50069 .52678 m .454 .53512 L .45963 .55892 L p
1 g
F P
s
P
p
.002 w
.39529 .36603 m .3951 .38404 L .42058 .37543 L p
1 g
F P
s
P
p
.002 w
.42058 .37543 m .42073 .36638 L .39529 .36603 L p
1 g
F P
s
P
p
.002 w
.37443 .48497 m .40961 .50347 L .4134 .47688 L p
1 g
F P
s
P
p
.002 w
.4134 .47688 m .38438 .46133 L .37443 .48497 L p
1 g
F P
s
P
p
.002 w
.48162 .3237 m .46516 .31735 L .45578 .34194 L p
1 g
F P
s
P
p
.002 w
.44661 .34176 m .45578 .34194 L .46516 .31735 L p
1 g
F P
s
P
p
.002 w
.40152 .34847 m .39529 .36603 L .42073 .36638 L p
1 g
F P
s
P
p
.002 w
.42073 .36638 m .42389 .35759 L .40152 .34847 L p
1 g
F P
s
P
p
.002 w
.60289 .43021 m .61338 .38436 L .58824 .37803 L p
1 g
F P
s
P
p
.002 w
.58398 .33815 m .58824 .37803 L .61338 .38436 L p
1 g
F P
s
P
p
.002 w
.58824 .37803 m .58398 .33815 L .5576 .34007 L p
1 g
F P
s
P
p
.002 w
.59761 .48843 m .62438 .44266 L .60289 .43021 L p
1 g
F P
s
P
p
.002 w
.61338 .38436 m .60289 .43021 L .62438 .44266 L p
1 g
F P
s
P
p
.002 w
.36273 .43659 m .38438 .46133 L .397 .43737 L p
1 g
F P
s
P
p
.002 w
.397 .43737 m .38052 .4182 L .36273 .43659 L p
1 g
F P
s
P
p
.002 w
.37174 .39398 m .38052 .4182 L .4009 .40048 L p
1 g
F P
s
P
p
.002 w
.4009 .40048 m .3951 .38404 L .37174 .39398 L p
1 g
F P
s
P
p
.002 w
.46516 .31735 m .4469 .31688 L .44661 .34176 L p
1 g
F P
s
P
p
.002 w
.43759 .34455 m .44661 .34176 L .4469 .31688 L p
1 g
F P
s
P
p
.002 w
.41316 .33335 m .40152 .34847 L .42389 .35759 L p
1 g
F P
s
P
p
.002 w
.42389 .35759 m .42973 .35003 L .41316 .33335 L p
1 g
F P
s
P
p
.002 w
.4469 .31688 m .42888 .32241 L .43759 .34455 L p
1 g
F P
s
P
p
.002 w
.42973 .35003 m .43759 .34455 L .42888 .32241 L p
1 g
F P
s
P
p
.002 w
.42888 .32241 m .41316 .33335 L .42973 .35003 L p
1 g
F P
s
P
p
.002 w
.54293 .31072 m .5576 .34007 L .58398 .33815 L p
1 g
F P
s
P
p
.002 w
.5576 .34007 m .54293 .31072 L .51874 .32168 L p
1 g
F P
s
P
p
.002 w
.51874 .32168 m .4999 .30463 L .48162 .3237 L p
1 g
F P
s
P
p
.002 w
.46516 .31735 m .48162 .3237 L .4999 .30463 L p
1 g
F P
s
P
p
.002 w
.4999 .30463 m .51874 .32168 L .54293 .31072 L p
1 g
F P
s
P
p
.002 w
.52178 .56973 m .57263 .54355 L .55868 .52515 L p
1 g
F P
s
P
p
.002 w
.55868 .52515 m .51124 .54946 L .52178 .56973 L p
1 g
F P
s
P
p
.002 w
.59761 .48843 m .55868 .52515 L .57263 .54355 L p
1 g
F P
s
P
p
.002 w
.62438 .44266 m .59761 .48843 L .61443 .50416 L p
1 g
F P
s
P
p
.002 w
.57263 .54355 m .61443 .50416 L .59761 .48843 L p
1 g
F P
s
P
p
.002 w
.40871 .55219 m .45963 .55892 L .454 .53512 L p
1 g
F P
s
P
p
.002 w
.454 .53512 m .40801 .52876 L .40871 .55219 L p
1 g
F P
s
P
p
.002 w
.37186 .3673 m .37174 .39398 L .3951 .38404 L p
1 g
F P
s
P
p
.002 w
.3951 .38404 m .39529 .36603 L .37186 .3673 L p
1 g
F P
s
P
p
.002 w
.36742 .50782 m .40801 .52876 L .40961 .50347 L p
1 g
F P
s
P
p
.002 w
.40961 .50347 m .37443 .48497 L .36742 .50782 L p
1 g
F P
s
P
p
.002 w
.4999 .30463 m .47563 .29506 L .46516 .31735 L p
1 g
F P
s
P
p
.002 w
.4469 .31688 m .46516 .31735 L .47563 .29506 L p
1 g
F P
s
P
p
.002 w
.46644 .5801 m .52178 .56973 L .51124 .54946 L p
1 g
F P
s
P
p
.002 w
.51124 .54946 m .45963 .55892 L .46644 .5801 L p
1 g
F P
s
P
p
.002 w
.348 .45527 m .37443 .48497 L .38438 .46133 L p
1 g
F P
s
P
p
.002 w
.38438 .46133 m .36273 .43659 L .348 .45527 L p
1 g
F P
s
P
p
.002 w
.35106 .4051 m .36273 .43659 L .38052 .4182 L p
1 g
F P
s
P
p
.002 w
.38052 .4182 m .37174 .39398 L .35106 .4051 L p
1 g
F P
s
P
p
.002 w
.62438 .44266 m .63625 .392 L .61338 .38436 L p
1 g
F P
s
P
p
.002 w
.60882 .33852 m .61338 .38436 L .63625 .392 L p
1 g
F P
s
P
p
.002 w
.61338 .38436 m .60882 .33852 L .58398 .33815 L p
1 g
F P
s
P
p
.002 w
.38103 .34117 m .37186 .3673 L .39529 .36603 L p
1 g
F P
s
P
p
.002 w
.39529 .36603 m .40152 .34847 L .38103 .34117 L p
1 g
F P
s
P
p
.002 w
.56655 .30255 m .58398 .33815 L .60882 .33852 L p
1 g
F P
s
P
p
.002 w
.58398 .33815 m .56655 .30255 L .54293 .31072 L p
1 g
F P
s
P
p
.002 w
.61443 .50416 m .64329 .45513 L .62438 .44266 L p
1 g
F P
s
P
p
.002 w
.63625 .392 m .62438 .44266 L .64329 .45513 L p
1 g
F P
s
P
p
.002 w
.47563 .29506 m .44854 .29422 L .4469 .31688 L p
1 g
F P
s
P
p
.002 w
.42888 .32241 m .4469 .31688 L .44854 .29422 L p
1 g
F P
s
P
p
.002 w
.54293 .31072 m .51859 .28833 L .4999 .30463 L p
1 g
F P
s
P
p
.002 w
.47563 .29506 m .4999 .30463 L .51859 .28833 L p
1 g
F P
s
P
p
.002 w
.51859 .28833 m .54293 .31072 L .56655 .30255 L p
1 g
F P
s
P
p
.002 w
.39831 .31865 m .38103 .34117 L .40152 .34847 L p
1 g
F P
s
P
p
.002 w
.40152 .34847 m .41316 .33335 L .39831 .31865 L p
1 g
F P
s
P
p
.002 w
.44854 .29422 m .42173 .30237 L .42888 .32241 L p
1 g
F P
s
P
p
.002 w
.41316 .33335 m .42888 .32241 L .42173 .30237 L p
1 g
F P
s
P
p
.002 w
.42173 .30237 m .39831 .31865 L .41316 .33335 L p
1 g
F P
s
P
p
.002 w
.35103 .37022 m .35106 .4051 L .37174 .39398 L p
1 g
F P
s
P
p
.002 w
.37174 .39398 m .37186 .3673 L .35103 .37022 L p
1 g
F P
s
P
p
.002 w
.53208 .58706 m .58516 .55963 L .57263 .54355 L p
1 g
F P
s
P
p
.002 w
.57263 .54355 m .52178 .56973 L .53208 .58706 L p
1 g
F P
s
P
p
.002 w
.61443 .50416 m .57263 .54355 L .58516 .55963 L p
1 g
F P
s
P
p
.002 w
.36364 .52932 m .40871 .55219 L .40801 .52876 L p
1 g
F P
s
P
p
.002 w
.40801 .52876 m .36742 .50782 L .36364 .52932 L p
1 g
F P
s
P
p
.002 w
.41179 .57318 m .46644 .5801 L .45963 .55892 L p
1 g
F P
s
P
p
.002 w
.45963 .55892 m .40871 .55219 L .41179 .57318 L p
1 g
F P
s
P
p
.002 w
.64329 .45513 m .61443 .50416 L .62884 .51849 L p
1 g
F P
s
P
p
.002 w
.58516 .55963 m .62884 .51849 L .61443 .50416 L p
1 g
F P
s
P
p
.002 w
.33677 .47386 m .36742 .50782 L .37443 .48497 L p
1 g
F P
s
P
p
.002 w
.37443 .48497 m .348 .45527 L .33677 .47386 L p
1 g
F P
s
P
p
.002 w
.33361 .41721 m .348 .45527 L .36273 .43659 L p
1 g
F P
s
P
p
.002 w
.36273 .43659 m .35106 .4051 L .33361 .41721 L p
1 g
F P
s
P
p
.002 w
.51859 .28833 m .487 .27563 L .47563 .29506 L p
1 g
F P
s
P
p
.002 w
.44854 .29422 m .47563 .29506 L .487 .27563 L p
1 g
F P
s
P
p
.002 w
.47434 .59808 m .53208 .58706 L .52178 .56973 L p
1 g
F P
s
P
p
.002 w
.52178 .56973 m .46644 .5801 L .47434 .59808 L p
1 g
F P
s
P
p
.002 w
.64329 .45513 m .65627 .40084 L .63625 .392 L p
1 g
F P
s
P
p
.002 w
.63153 .34125 m .63625 .392 L .65627 .40084 L p
1 g
F P
s
P
p
.002 w
.63625 .392 m .63153 .34125 L .60882 .33852 L p
1 g
F P
s
P
p
.002 w
.58909 .29744 m .60882 .33852 L .63153 .34125 L p
1 g
F P
s
P
p
.002 w
.60882 .33852 m .58909 .29744 L .56655 .30255 L p
1 g
F P
s
P
p
.002 w
.36293 .33594 m .35103 .37022 L .37186 .3673 L p
1 g
F P
s
P
p
.002 w
.37186 .3673 m .38103 .34117 L .36293 .33594 L p
1 g
F P
s
P
p
.002 w
.56655 .30255 m .53731 .27522 L .51859 .28833 L p
1 g
F P
s
P
p
.002 w
.487 .27563 m .51859 .28833 L .53731 .27522 L p
1 g
F P
s
P
p
.002 w
.53731 .27522 m .56655 .30255 L .58909 .29744 L p
1 g
F P
s
P
p
.002 w
.62884 .51849 m .65911 .46735 L .64329 .45513 L p
1 g
F P
s
P
p
.002 w
.65627 .40084 m .64329 .45513 L .65911 .46735 L p
1 g
F P
s
P
p
.002 w
.487 .27563 m .45156 .27437 L .44854 .29422 L p
1 g
F P
s
P
p
.002 w
.42173 .30237 m .44854 .29422 L .45156 .27437 L p
1 g
F P
s
P
p
.002 w
.38558 .30633 m .36293 .33594 L .38103 .34117 L p
1 g
F P
s
P
p
.002 w
.38103 .34117 m .39831 .31865 L .38558 .30633 L p
1 g
F P
s
P
p
.002 w
.45156 .27437 m .41636 .28497 L .42173 .30237 L p
1 g
F P
s
P
p
.002 w
.39831 .31865 m .42173 .30237 L .41636 .28497 L p
1 g
F P
s
P
p
.002 w
.33338 .37482 m .33361 .41721 L .35106 .4051 L p
1 g
F P
s
P
p
.002 w
.35106 .4051 m .35103 .37022 L .33338 .37482 L p
1 g
F P
s
P
p
.002 w
.41636 .28497 m .38558 .30633 L .39831 .31865 L p
1 g
F P
s
P
p
.002 w
.36332 .54892 m .41179 .57318 L .40871 .55219 L p
1 g
F P
s
P
p
.002 w
.40871 .55219 m .36364 .52932 L .36332 .54892 L p
1 g
F P
s
P
p
.002 w
.41729 .59112 m .47434 .59808 L .46644 .5801 L p
1 g
F P
s
P
p
.002 w
.46644 .5801 m .41179 .57318 L .41729 .59112 L p
1 g
F P
s
P
p
.002 w
.32947 .49192 m .36364 .52932 L .36742 .50782 L p
1 g
F P
s
P
p
.002 w
.36742 .50782 m .33677 .47386 L .32947 .49192 L p
1 g
F P
s
P
p
.002 w
.31994 .43007 m .33677 .47386 L .348 .45527 L p
1 g
F P
s
P
p
.002 w
.348 .45527 m .33361 .41721 L .31994 .43007 L p
1 g
F P
s
P
p
.002 w
.5419 .60091 m .59591 .57291 L .58516 .55963 L p
1 g
F P
s
P
p
.002 w
.58516 .55963 m .53208 .58706 L .5419 .60091 L p
1 g
F P
s
P
p
.002 w
.62884 .51849 m .58516 .55963 L .59591 .57291 L p
1 g
F P
s
P
p
.002 w
.53731 .27522 m .49906 .2596 L .487 .27563 L p
1 g
F P
s
P
p
.002 w
.45156 .27437 m .487 .27563 L .49906 .2596 L p
1 g
F P
s
P
p
.002 w
.59591 .57291 m .6404 .53104 L .62884 .51849 L p
1 g
F P
s
P
p
.002 w
.65911 .46735 m .62884 .51849 L .6404 .53104 L p
1 g
F P
s
P
p
.002 w
.65627 .40084 m .65153 .34639 L .63153 .34125 L p
1 g
F P
s
P
p
.002 w
.60999 .29564 m .63153 .34125 L .65153 .34639 L p
1 g
F P
s
P
p
.002 w
.63153 .34125 m .60999 .29564 L .58909 .29744 L p
1 g
F P
s
P
p
.002 w
.65911 .46735 m .67288 .41074 L .65627 .40084 L p
1 g
F P
s
P
p
.002 w
.65153 .34639 m .65627 .40084 L .67288 .41074 L p
1 g
F P
s
P
p
.002 w
.58909 .29744 m .55563 .26576 L .53731 .27522 L p
1 g
F P
s
P
p
.002 w
.49906 .2596 m .53731 .27522 L .55563 .26576 L p
1 g
F P
s
P
p
.002 w
.4832 .61229 m .5419 .60091 L .53208 .58706 L p
1 g
F P
s
P
p
.002 w
.53208 .58706 m .47434 .59808 L .4832 .61229 L p
1 g
F P
s
P
p
.002 w
.55563 .26576 m .58909 .29744 L .60999 .29564 L p
1 g
F P
s
P
p
.002 w
.34778 .33301 m .33338 .37482 L .35103 .37022 L p
1 g
F P
s
P
p
.002 w
.35103 .37022 m .36293 .33594 L .34778 .33301 L p
1 g
F P
s
P
p
.002 w
.6404 .53104 m .67132 .47904 L .65911 .46735 L p
1 g
F P
s
P
p
.002 w
.67288 .41074 m .65911 .46735 L .67132 .47904 L p
1 g
F P
s
P
p
.002 w
.49906 .2596 m .45595 .25791 L .45156 .27437 L p
1 g
F P
s
P
p
.002 w
.41636 .28497 m .45156 .27437 L .45595 .25791 L p
1 g
F P
s
P
p
.002 w
.37539 .29683 m .34778 .33301 L .36293 .33594 L p
1 g
F P
s
P
p
.002 w
.36293 .33594 m .38558 .30633 L .37539 .29683 L p
1 g
F P
s
P
p
.002 w
.3195 .38107 m .31994 .43007 L .33361 .41721 L p
1 g
F P
s
P
p
.002 w
.33361 .41721 m .33338 .37482 L .3195 .38107 L p
1 g
F P
s
P
p
.002 w
.36665 .56606 m .41729 .59112 L .41179 .57318 L p
1 g
F P
s
P
p
.002 w
.41179 .57318 m .36332 .54892 L .36665 .56606 L p
1 g
F P
s
P
p
.002 w
.45595 .25791 m .41299 .27076 L .41636 .28497 L p
1 g
F P
s
P
p
.002 w
.38558 .30633 m .41636 .28497 L .41299 .27076 L p
1 g
F P
s
P
p
.002 w
.32648 .50898 m .36332 .54892 L .36364 .52932 L p
1 g
F P
s
P
p
.002 w
.36364 .52932 m .32947 .49192 L .32648 .50898 L p
1 g
F P
s
P
p
.002 w
.41299 .27076 m .37539 .29683 L .38558 .30633 L p
1 g
F P
s
P
p
.002 w
.31059 .44341 m .32947 .49192 L .33677 .47386 L p
1 g
F P
s
P
p
.002 w
.33677 .47386 m .31994 .43007 L .31059 .44341 L p
1 g
F P
s
P
p
.002 w
.42521 .60542 m .4832 .61229 L .47434 .59808 L p
1 g
F P
s
P
p
.002 w
.47434 .59808 m .41729 .59112 L .42521 .60542 L p
1 g
F P
s
P
p
.002 w
.55563 .26576 m .51158 .24752 L .49906 .2596 L p
1 g
F P
s
P
p
.002 w
.45595 .25791 m .49906 .2596 L .51158 .24752 L p
1 g
F P
s
P
p
.002 w
.551 .61077 m .60453 .58293 L .59591 .57291 L p
1 g
F P
s
P
p
.002 w
.59591 .57291 m .5419 .60091 L .551 .61077 L p
1 g
F P
s
P
p
.002 w
.6404 .53104 m .59591 .57291 L .60453 .58293 L p
1 g
F P
s
P
p
.002 w
.67132 .47904 m .6404 .53104 L .64869 .5414 L p
1 g
F P
s
P
p
.002 w
.60453 .58293 m .64869 .5414 L .6404 .53104 L p
1 g
F P
s
P
p
.002 w
.67288 .41074 m .6682 .35393 L .65153 .34639 L p
1 g
F P
s
P
p
.002 w
.6287 .29735 m .65153 .34639 L .6682 .35393 L p
1 g
F P
s
P
p
.002 w
.65153 .34639 m .6287 .29735 L .60999 .29564 L p
1 g
F P
s
P
p
.002 w
.60999 .29564 m .57311 .26033 L .55563 .26576 L p
1 g
F P
s
P
p
.002 w
.51158 .24752 m .55563 .26576 L .57311 .26033 L p
1 g
F P
s
P
p
.002 w
.67132 .47904 m .68551 .42153 L .67288 .41074 L p
1 g
F P
s
P
p
.002 w
.6682 .35393 m .67288 .41074 L .68551 .42153 L p
1 g
F P
s
P
p
.002 w
.57311 .26033 m .60999 .29564 L .6287 .29735 L p
1 g
F P
s
P
p
.002 w
.49286 .62216 m .551 .61077 L .5419 .60091 L p
1 g
F P
s
P
p
.002 w
.5419 .60091 m .4832 .61229 L .49286 .62216 L p
1 g
F P
s
P
p
.002 w
.3361 .33257 m .3195 .38107 L .33338 .37482 L p
1 g
F P
s
P
p
.002 w
.33338 .37482 m .34778 .33301 L .3361 .33257 L p
1 g
F P
s
P
p
.002 w
.64869 .5414 m .67943 .48989 L .67132 .47904 L p
1 g
F P
s
P
p
.002 w
.68551 .42153 m .67132 .47904 L .67943 .48989 L p
1 g
F P
s
P
p
.002 w
.51158 .24752 m .46169 .24542 L .45595 .25791 L p
1 g
F P
s
P
p
.002 w
.41299 .27076 m .45595 .25791 L .46169 .24542 L p
1 g
F P
s
P
p
.002 w
.30996 .38892 m .31059 .44341 L .31994 .43007 L p
1 g
F P
s
P
p
.002 w
.31994 .43007 m .3195 .38107 L .30996 .38892 L p
1 g
F P
s
P
p
.002 w
.37375 .58015 m .42521 .60542 L .41729 .59112 L p
1 g
F P
s
P
p
.002 w
.41729 .59112 m .36665 .56606 L .37375 .58015 L p
1 g
F P
s
P
p
.002 w
.36814 .29053 m .3361 .33257 L .34778 .33301 L p
1 g
F P
s
P
p
.002 w
.34778 .33301 m .37539 .29683 L .36814 .29053 L p
1 g
F P
s
P
p
.002 w
.32811 .52455 m .36665 .56606 L .36332 .54892 L p
1 g
F P
s
P
p
.002 w
.36332 .54892 m .32648 .50898 L .32811 .52455 L p
1 g
F P
s
P
p
.002 w
.30604 .45693 m .32648 .50898 L .32947 .49192 L p
1 g
F P
s
P
p
.002 w
.32947 .49192 m .31059 .44341 L .30604 .45693 L p
1 g
F P
s
P
p
.002 w
.46169 .24542 m .41182 .26026 L .41299 .27076 L p
1 g
F P
s
P
p
.002 w
.37539 .29683 m .41299 .27076 L .41182 .26026 L p
1 g
F P
s
P
p
.002 w
.43548 .6155 m .49286 .62216 L .4832 .61229 L p
1 g
F P
s
P
p
.002 w
.4832 .61229 m .42521 .60542 L .43548 .6155 L p
1 g
F P
s
P
p
.002 w
.41182 .26026 m .36814 .29053 L .37539 .29683 L p
1 g
F P
s
P
p
.002 w
.57311 .26033 m .52426 .2399 L .51158 .24752 L p
1 g
F P
s
P
p
.002 w
.46169 .24542 m .51158 .24752 L .52426 .2399 L p
1 g
F P
s
P
p
.002 w
.68551 .42153 m .68095 .36382 L .6682 .35393 L p
1 g
F P
s
P
p
.002 w
.64461 .30272 m .6682 .35393 L .68095 .36382 L p
1 g
F P
s
P
p
.002 w
.6682 .35393 m .64461 .30272 L .6287 .29735 L p
1 g
F P
s
P
p
.002 w
.55908 .61614 m .61069 .58925 L .60453 .58293 L p
1 g
F P
s
P
p
.002 w
.60453 .58293 m .551 .61077 L .55908 .61614 L p
1 g
F P
s
P
p
.002 w
.64869 .5414 m .60453 .58293 L .61069 .58925 L p
1 g
F P
s
P
p
.002 w
.58926 .2593 m .6287 .29735 L .64461 .30272 L p
1 g
F P
s
P
p
.002 w
.6287 .29735 m .58926 .2593 L .57311 .26033 L p
1 g
F P
s
P
p
.002 w
.52426 .2399 m .57311 .26033 L .58926 .2593 L p
1 g
F P
s
P
p
.002 w
.61069 .58925 m .6533 .5492 L .64869 .5414 L p
1 g
F P
s
P
p
.002 w
.67943 .48989 m .64869 .5414 L .6533 .5492 L p
1 g
F P
s
P
p
.002 w
.67943 .48989 m .6936 .43297 L .68551 .42153 L p
1 g
F P
s
P
p
.002 w
.68095 .36382 m .68551 .42153 L .6936 .43297 L p
1 g
F P
s
P
p
.002 w
.32841 .3348 m .30996 .38892 L .3195 .38107 L p
1 g
F P
s
P
p
.002 w
.3195 .38107 m .3361 .33257 L .32841 .3348 L p
1 g
F P
s
P
p
.002 w
.5031 .62717 m .55908 .61614 L .551 .61077 L p
1 g
F P
s
P
p
.002 w
.551 .61077 m .49286 .62216 L .5031 .62717 L p
1 g
F P
s
P
p
.002 w
.6533 .5492 m .68298 .49957 L .67943 .48989 L p
1 g
F P
s
P
p
.002 w
.6936 .43297 m .67943 .48989 L .68298 .49957 L p
1 g
F P
s
P
p
.002 w
.52426 .2399 m .46871 .23746 L .46169 .24542 L p
1 g
F P
s
P
p
.002 w
.41182 .26026 m .46169 .24542 L .46871 .23746 L p
1 g
F P
s
P
p
.002 w
.30529 .39824 m .30604 .45693 L .31059 .44341 L p
1 g
F P
s
P
p
.002 w
.31059 .44341 m .30996 .38892 L .30529 .39824 L p
1 g
F P
s
P
p
.002 w
.3346 .53811 m .37375 .58015 L .36665 .56606 L p
1 g
F P
s
P
p
.002 w
.36665 .56606 m .32811 .52455 L .3346 .53811 L p
1 g
F P
s
P
p
.002 w
.38463 .59063 m .43548 .6155 L .42521 .60542 L p
1 g
F P
s
P
p
.002 w
.42521 .60542 m .37375 .58015 L .38463 .59063 L p
1 g
F P
s
P
p
.002 w
.30671 .47026 m .32811 .52455 L .32648 .50898 L p
1 g
F P
s
P
p
.002 w
.32648 .50898 m .30604 .45693 L .30671 .47026 L p
1 g
F P
s
P
p
.002 w
.3642 .28782 m .32841 .3348 L .3361 .33257 L p
1 g
F P
s
P
p
.002 w
.3361 .33257 m .36814 .29053 L .3642 .28782 L p
1 g
F P
s
P
p
.002 w
.46871 .23746 m .41303 .25398 L .41182 .26026 L p
1 g
F P
s
P
p
.002 w
.36814 .29053 m .41182 .26026 L .41303 .25398 L p
1 g
F P
s
P
p
.002 w
.44797 .62083 m .5031 .62717 L .49286 .62216 L p
1 g
F P
s
P
p
.002 w
.49286 .62216 m .43548 .6155 L .44797 .62083 L p
1 g
F P
s
P
p
.002 w
.58926 .2593 m .53679 .23721 L .52426 .2399 L p
1 g
F P
s
P
p
.002 w
.46871 .23746 m .52426 .2399 L .53679 .23721 L p
1 g
F P
s
P
p
.002 w
.41303 .25398 m .3642 .28782 L .36814 .29053 L p
1 g
F P
s
P
p
.002 w
.6936 .43297 m .68922 .37594 L .68095 .36382 L p
1 g
F P
s
P
p
.002 w
.65716 .31181 m .68095 .36382 L .68922 .37594 L p
1 g
F P
s
P
p
.002 w
.68095 .36382 m .65716 .31181 L .64461 .30272 L p
1 g
F P
s
P
p
.002 w
.60359 .26294 m .64461 .30272 L .65716 .31181 L p
1 g
F P
s
P
p
.002 w
.64461 .30272 m .60359 .26294 L .58926 .2593 L p
1 g
F P
s
P
p
.002 w
.53679 .23721 m .58926 .2593 L .60359 .26294 L p
1 g
F P
s
P
p
.002 w
.56587 .61658 m .61406 .59147 L .61069 .58925 L p
1 g
F P
s
P
p
.002 w
.61069 .58925 m .55908 .61614 L .56587 .61658 L p
1 g
F P
s
P
p
.002 w
.6533 .5492 m .61069 .58925 L .61406 .59147 L p
1 g
F P
s
P
p
.002 w
.68298 .49957 m .69669 .44482 L .6936 .43297 L p
1 g
F P
s
P
p
.002 w
.68922 .37594 m .6936 .43297 L .69669 .44482 L p
1 g
F P
s
P
p
.002 w
.68298 .49957 m .6533 .5492 L .65387 .55405 L p
1 g
F P
s
P
p
.002 w
.61406 .59147 m .65387 .55405 L .6533 .5492 L p
1 g
F P
s
P
p
.002 w
.3252 .3398 m .30529 .39824 L .30996 .38892 L p
1 g
F P
s
P
p
.002 w
.30996 .38892 m .32841 .3348 L .3252 .3398 L p
1 g
F P
s
P
p
.002 w
.51369 .62689 m .56587 .61658 L .55908 .61614 L p
1 g
F P
s
P
p
.002 w
.55908 .61614 m .5031 .62717 L .51369 .62689 L p
1 g
F P
s
P
p
.002 w
.53679 .23721 m .4769 .23454 L .46871 .23746 L p
1 g
F P
s
P
p
.002 w
.41303 .25398 m .46871 .23746 L .4769 .23454 L p
1 g
F P
s
P
p
.002 w
.65387 .55405 m .68159 .50774 L .68298 .49957 L p
1 g
F P
s
P
p
.002 w
.69669 .44482 m .68298 .49957 L .68159 .50774 L p
1 g
F P
s
P
p
.004 w
.60783 .61777 m
.64925 .68971 L
s
P
p
.002 w
.30593 .40887 m .30671 .47026 L .30604 .45693 L p
1 g
F P
s
P
p
.002 w
.30604 .45693 m .30529 .39824 L .30593 .40887 L p
1 g
F P
s
P
p
.002 w
.34603 .54915 m .38463 .59063 L .37375 .58015 L p
1 g
F P
s
P
p
.002 w
.37375 .58015 m .3346 .53811 L .34603 .54915 L p
1 g
F P
s
P
p
.002 w
.39922 .59698 m .44797 .62083 L .43548 .6155 L p
1 g
F P
s
P
p
.002 w
.43548 .6155 m .38463 .59063 L .39922 .59698 L p
1 g
F P
s
P
p
.002 w
.31289 .483 m .3346 .53811 L .32811 .52455 L p
1 g
F P
s
P
p
.002 w
.32811 .52455 m .30671 .47026 L .31289 .483 L p
1 g
F P
s
P
p
.002 w
.36391 .28899 m .3252 .3398 L .32841 .3348 L p
1 g
F P
s
P
p
.002 w
.32841 .3348 m .3642 .28782 L .36391 .28899 L p
1 g
F P
s
P
p
.002 w
.46244 .62097 m .51369 .62689 L .5031 .62717 L p
1 g
F P
s
P
p
.002 w
.5031 .62717 m .44797 .62083 L .46244 .62097 L p
1 g
F P
s
P
p
.002 w
.60359 .26294 m .5488 .23983 L .53679 .23721 L p
1 g
F P
s
P
p
.002 w
.4769 .23454 m .53679 .23721 L .5488 .23983 L p
1 g
F P
s
P
p
.002 w
.4769 .23454 m .41673 .25239 L .41303 .25398 L p
1 g
F P
s
P
p
.002 w
.3642 .28782 m .41303 .25398 L .41673 .25239 L p
1 g
F P
s
P
p
.002 w
.69669 .44482 m .69252 .39006 L .68922 .37594 L p
1 g
F P
s
P
p
.002 w
.68922 .37594 m .66579 .32459 L .65716 .31181 L p
1 g
F P
s
P
p
.002 w
.66579 .32459 m .68922 .37594 L .69252 .39006 L p
1 g
F P
s
P
p
.002 w
.65716 .31181 m .61558 .27143 L .60359 .26294 L p
1 g
F P
s
P
p
.002 w
.61558 .27143 m .65716 .31181 L .66579 .32459 L p
1 g
F P
s
P
p
.002 w
.41673 .25239 m .36391 .28899 L .3642 .28782 L p
1 g
F P
s
P
p
.002 w
.5488 .23983 m .60359 .26294 L .61558 .27143 L p
1 g
F P
s
P
p
.002 w
.68159 .50774 m .69436 .45675 L .69669 .44482 L p
1 g
F P
s
P
p
.002 w
.69252 .39006 m .69669 .44482 L .69436 .45675 L p
1 g
F P
s
P
p
.002 w
.5711 .61177 m .61436 .58923 L .61406 .59147 L p
1 g
F P
s
P
p
.002 w
.61406 .59147 m .56587 .61658 L .5711 .61177 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.59669 .59844 L
s
P
p
.004 w
.59738 .59962 m
.5981 .60087 L
s
P
p
.004 w
.5981 .60087 m
.60783 .61777 L
s
P
p
.002 w
.65387 .55405 m .61406 .59147 L .61436 .58923 L p
1 g
F P
s
P
p
.002 w
.68159 .50774 m .65387 .55405 L .65011 .55562 L p
1 g
F P
s
P
p
.002 w
.61436 .58923 m .65011 .55562 L .65387 .55405 L p
1 g
F P
s
P
p
.002 w
.32684 .34762 m .30593 .40887 L .30529 .39824 L p
1 g
F P
s
P
p
.002 w
.30529 .39824 m .3252 .3398 L .32684 .34762 L p
1 g
F P
s
P
p
.002 w
.52434 .62098 m .5711 .61177 L .56587 .61658 L p
1 g
F P
s
P
p
.002 w
.56587 .61658 m .51369 .62689 L .52434 .62098 L p
1 g
F P
s
P
p
.002 w
.36236 .55719 m .39922 .59698 L .38463 .59063 L p
1 g
F P
s
P
p
.002 w
.38463 .59063 m .34603 .54915 L .36236 .55719 L p
1 g
F P
s
P
p
.002 w
.31219 .42057 m .31289 .483 L .30671 .47026 L p
1 g
F P
s
P
p
.002 w
.30671 .47026 m .30593 .40887 L .31219 .42057 L p
1 g
F P
s
P
p
.002 w
.5488 .23983 m .4861 .23706 L .4769 .23454 L p
1 g
F P
s
P
p
.002 w
.41673 .25239 m .4769 .23454 L .4861 .23706 L p
1 g
F P
s
P
p
.002 w
.65011 .55562 m .67497 .51407 L .68159 .50774 L p
1 g
F P
s
P
p
.002 w
.69436 .45675 m .68159 .50774 L .67497 .51407 L p
1 g
F P
s
P
p
.002 w
.32473 .49472 m .34603 .54915 L .3346 .53811 L p
1 g
F P
s
P
p
.002 w
.3346 .53811 m .31289 .483 L .32473 .49472 L p
1 g
F P
s
P
p
.002 w
.41729 .59876 m .46244 .62097 L .44797 .62083 L p
1 g
F P
s
P
p
.002 w
.44797 .62083 m .39922 .59698 L .41729 .59876 L p
1 g
F P
s
P
p
.002 w
.36751 .29429 m .32684 .34762 L .3252 .3398 L p
1 g
F P
s
P
p
.002 w
.3252 .3398 m .36391 .28899 L .36751 .29429 L p
1 g
F P
s
P
p
.002 w
.47856 .6156 m .52434 .62098 L .51369 .62689 L p
1 g
F P
s
P
p
.002 w
.51369 .62689 m .46244 .62097 L .47856 .6156 L p
1 g
F P
s
P
p
.002 w
.61558 .27143 m .55991 .24801 L .5488 .23983 L p
1 g
F P
s
P
p
.002 w
.4861 .23706 m .5488 .23983 L .55991 .24801 L p
1 g
F P
s
P
p
.002 w
.69252 .39006 m .67003 .3409 L .66579 .32459 L p
1 g
F P
s
P
p
.002 w
.62474 .28481 m .66579 .32459 L .67003 .3409 L p
1 g
F P
s
P
p
.002 w
.66579 .32459 m .62474 .28481 L .61558 .27143 L p
1 g
F P
s
P
p
.002 w
.69436 .45675 m .69044 .40591 L .69252 .39006 L p
1 g
F P
s
P
p
.002 w
.67003 .3409 m .69252 .39006 L .69044 .40591 L p
1 g
F P
s
P
p
.002 w
.55991 .24801 m .61558 .27143 L .62474 .28481 L p
1 g
F P
s
P
p
.002 w
.4861 .23706 m .42298 .25583 L .41673 .25239 L p
1 g
F P
s
P
p
.002 w
.36391 .28899 m .41673 .25239 L .42298 .25583 L p
1 g
F P
s
P
p
.002 w
.42298 .25583 m .36751 .29429 L .36391 .28899 L p
1 g
F P
s
P
p
.002 w
.67497 .51407 m .68635 .46842 L .69436 .45675 L p
1 g
F P
s
P
p
.002 w
.69044 .40591 m .69436 .45675 L .68635 .46842 L p
1 g
F P
s
P
p
.002 w
.57449 .60151 m .61137 .58232 L .61436 .58923 L p
1 g
F P
s
P
p
.002 w
.61436 .58923 m .5711 .61177 L .57449 .60151 L p
1 g
F P
s
P
p
.002 w
.65011 .55562 m .61436 .58923 L .61137 .58232 L p
1 g
F P
s
P
p
.002 w
.61137 .58232 m .64186 .55365 L .65011 .55562 L p
1 g
F P
s
P
p
.002 w
.67497 .51407 m .65011 .55562 L .64186 .55365 L p
1 g
F P
s
P
p
.002 w
.33361 .3582 m .31219 .42057 L .30593 .40887 L p
1 g
F P
s
P
p
.002 w
.30593 .40887 m .32684 .34762 L .33361 .3582 L p
1 g
F P
s
P
p
.002 w
.53471 .60927 m .57449 .60151 L .5711 .61177 L p
1 g
F P
s
P
p
.002 w
.5711 .61177 m .52434 .62098 L .53471 .60927 L p
1 g
F P
s
P
p
.002 w
.38333 .56179 m .41729 .59876 L .39922 .59698 L p
1 g
F P
s
P
p
.002 w
.39922 .59698 m .36236 .55719 L .38333 .56179 L p
1 g
F P
s
P
p
.002 w
.34218 .505 m .36236 .55719 L .34603 .54915 L p
1 g
F P
s
P
p
.002 w
.34603 .54915 m .32473 .49472 L .34218 .505 L p
1 g
F P
s
P
p
.002 w
.32424 .43303 m .32473 .49472 L .31289 .483 L p
1 g
F P
s
P
p
.002 w
.31289 .483 m .31219 .42057 L .32424 .43303 L p
1 g
F P
s
P
p
.002 w
.43844 .59566 m .47856 .6156 L .46244 .62097 L p
1 g
F P
s
P
p
.002 w
.46244 .62097 m .41729 .59876 L .43844 .59566 L p
1 g
F P
s
P
p
.002 w
.55991 .24801 m .49609 .24531 L .4861 .23706 L p
1 g
F P
s
P
p
.002 w
.42298 .25583 m .4861 .23706 L .49609 .24531 L p
1 g
F P
s
P
p
.002 w
.64186 .55365 m .66299 .51824 L .67497 .51407 L p
1 g
F P
s
P
p
.002 w
.68635 .46842 m .67497 .51407 L .66299 .51824 L p
1 g
F P
s
P
p
.002 w
.69044 .40591 m .66947 .36042 L .67003 .3409 L p
1 g
F P
s
P
p
.002 w
.63061 .30294 m .67003 .3409 L .66947 .36042 L p
1 g
F P
s
P
p
.002 w
.67003 .3409 m .63061 .30294 L .62474 .28481 L p
1 g
F P
s
P
p
.002 w
.62474 .28481 m .56972 .26184 L .55991 .24801 L p
1 g
F P
s
P
p
.002 w
.49609 .24531 m .55991 .24801 L .56972 .26184 L p
1 g
F P
s
P
p
.002 w
.68635 .46842 m .68273 .42307 L .69044 .40591 L p
1 g
F P
s
P
p
.002 w
.66947 .36042 m .69044 .40591 L .68273 .42307 L p
1 g
F P
s
P
p
.002 w
.49592 .60457 m .53471 .60927 L .52434 .62098 L p
1 g
F P
s
P
p
.002 w
.52434 .62098 m .47856 .6156 L .49592 .60457 L p
1 g
F P
s
P
p
.002 w
.37516 .30381 m .33361 .3582 L .32684 .34762 L p
1 g
F P
s
P
p
.002 w
.32684 .34762 m .36751 .29429 L .37516 .30381 L p
1 g
F P
s
P
p
.002 w
.56972 .26184 m .62474 .28481 L .63061 .30294 L p
1 g
F P
s
P
p
.002 w
.49609 .24531 m .43176 .26454 L .42298 .25583 L p
1 g
F P
s
P
p
.002 w
.36751 .29429 m .42298 .25583 L .43176 .26454 L p
1 g
F P
s
P
p
.002 w
.66299 .51824 m .67257 .47945 L .68635 .46842 L p
1 g
F P
s
P
p
.002 w
.68273 .42307 m .68635 .46842 L .67257 .47945 L p
1 g
F P
s
P
p
.002 w
.43176 .26454 m .37516 .30381 L .36751 .29429 L p
1 g
F P
s
P
p
.002 w
.57582 .58577 m .60498 .57064 L .61137 .58232 L p
1 g
F P
s
P
p
.002 w
.61137 .58232 m .57449 .60151 L .57582 .58577 L p
1 g
F P
s
P
p
.002 w
.64186 .55365 m .61137 .58232 L .60498 .57064 L p
1 g
F P
s
P
p
.002 w
.34561 .37134 m .32424 .43303 L .31219 .42057 L p
1 g
F P
s
P
p
.002 w
.31219 .42057 m .33361 .3582 L .34561 .37134 L p
1 g
F P
s
P
p
.002 w
.60498 .57064 m .62908 .54797 L .64186 .55365 L p
1 g
F P
s
P
p
.002 w
.66299 .51824 m .64186 .55365 L .62908 .54797 L p
1 g
F P
s
P
p
.002 w
.40848 .56262 m .43844 .59566 L .41729 .59876 L p
1 g
F P
s
P
p
.002 w
.41729 .59876 m .38333 .56179 L .40848 .56262 L p
1 g
F P
s
P
p
.002 w
.36496 .5134 m .38333 .56179 L .36236 .55719 L p
1 g
F P
s
P
p
.002 w
.36236 .55719 m .34218 .505 L .36496 .5134 L p
1 g
F P
s
P
p
.002 w
.34198 .44587 m .34218 .505 L .32473 .49472 L p
1 g
F P
s
P
p
.002 w
.32473 .49472 m .32424 .43303 L .34198 .44587 L p
1 g
F P
s
P
p
.002 w
.54444 .5918 m .57582 .58577 L .57449 .60151 L p
1 g
F P
s
P
p
.002 w
.57449 .60151 m .53471 .60927 L .54444 .5918 L p
1 g
F P
s
P
p
.002 w
.46213 .58753 m .49592 .60457 L .47856 .6156 L p
1 g
F P
s
P
p
.002 w
.47856 .6156 m .43844 .59566 L .46213 .58753 L p
1 g
F P
s
P
p
.002 w
.56972 .26184 m .50659 .25936 L .49609 .24531 L p
1 g
F P
s
P
p
.002 w
.43176 .26454 m .49609 .24531 L .50659 .25936 L p
1 g
F P
s
P
p
.002 w
.62908 .54797 m .64571 .51998 L .66299 .51824 L p
1 g
F P
s
P
p
.002 w
.67257 .47945 m .66299 .51824 L .64571 .51998 L p
1 g
F P
s
P
p
.002 w
.68273 .42307 m .66387 .38271 L .66947 .36042 L p
1 g
F P
s
P
p
.002 w
.63282 .3255 m .66947 .36042 L .66387 .38271 L p
1 g
F P
s
P
p
.002 w
.66947 .36042 m .63282 .3255 L .63061 .30294 L p
1 g
F P
s
P
p
.002 w
.67257 .47945 m .66934 .44108 L .68273 .42307 L p
1 g
F P
s
P
p
.002 w
.66387 .38271 m .68273 .42307 L .66934 .44108 L p
1 g
F P
s
P
p
.002 w
.57782 .28118 m .63061 .30294 L .63282 .3255 L p
1 g
F P
s
P
p
.002 w
.63061 .30294 m .57782 .28118 L .56972 .26184 L p
1 g
F P
s
P
p
.002 w
.50659 .25936 m .56972 .26184 L .57782 .28118 L p
1 g
F P
s
P
p
.002 w
.51399 .58796 m .54444 .5918 L .53471 .60927 L p
1 g
F P
s
P
p
.002 w
.53471 .60927 m .49592 .60457 L .51399 .58796 L p
1 g
F P
s
P
p
.002 w
.38684 .3175 m .34561 .37134 L .33361 .3582 L p
1 g
F P
s
P
p
.002 w
.33361 .3582 m .37516 .30381 L .38684 .3175 L p
1 g
F P
s
P
p
.002 w
.50659 .25936 m .44292 .27855 L .43176 .26454 L p
1 g
F P
s
P
p
.002 w
.37516 .30381 m .43176 .26454 L .44292 .27855 L p
1 g
F P
s
P
p
.002 w
.64571 .51998 m .65315 .48941 L .67257 .47945 L p
1 g
F P
s
P
p
.002 w
.66934 .44108 m .67257 .47945 L .65315 .48941 L p
1 g
F P
s
P
p
.002 w
.44292 .27855 m .38684 .3175 L .37516 .30381 L p
1 g
F P
s
P
p
.002 w
.43712 .55947 m .46213 .58753 L .43844 .59566 L p
1 g
F P
s
P
p
.002 w
.43844 .59566 m .40848 .56262 L .43712 .55947 L p
1 g
F P
s
P
p
.002 w
.3627 .38676 m .34198 .44587 L .32424 .43303 L p
1 g
F P
s
P
p
.002 w
.32424 .43303 m .34561 .37134 L .3627 .38676 L p
1 g
F P
s
P
p
.002 w
.3925 .51953 m .40848 .56262 L .38333 .56179 L p
1 g
F P
s
P
p
.002 w
.38333 .56179 m .36496 .5134 L .3925 .51953 L p
1 g
F P
s
P
p
.002 w
.57492 .56478 m .59519 .5543 L .60498 .57064 L p
1 g
F P
s
P
p
.002 w
.60498 .57064 m .57582 .58577 L .57492 .56478 L p
1 g
F P
s
P
p
.002 w
.62908 .54797 m .60498 .57064 L .59519 .5543 L p
1 g
F P
s
P
p
.002 w
.64571 .51998 m .62908 .54797 L .61192 .53854 L p
1 g
F P
s
P
p
.002 w
.59519 .5543 m .61192 .53854 L .62908 .54797 L p
1 g
F P
s
P
p
.002 w
.3651 .45866 m .36496 .5134 L .34218 .505 L p
1 g
F P
s
P
p
.002 w
.34218 .505 m .34198 .44587 L .3651 .45866 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48907 .58047 m .48921 .57862 L p
.47829 .57772 L 1 g
F P
s
P
p
.46213 .58753 m .46474 .57276 L .4684 .5741 L 1 g
F
P
p
.002 w
.47999 .57835 m .47719 .57979 L p
.4684 .5741 L 1 g
F P
s
P
p
.002 w
.47719 .57979 m .46213 .58753 L p
.4684 .5741 L 1 g
F P
s
P
p
.002 w
.4684 .5741 m .46872 .57265 L p
.46203 .56998 L 1 g
F P
s
P
p
.47829 .57772 m .47999 .57835 L .48907 .58047 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.49592 .60457 m .46213 .58753 L .47999 .57835 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46808 .57557 L p
1 g
F P
s
P
p
.48921 .57862 m .46808 .57557 L .47679 .5776 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58047 L p
1 g
F P
s
P
p
.48933 .58053 m .48907 .58047 L .48931 .58048 L 1 g
F
P
p
.49592 .60457 m .48107 .58012 L .48933 .58053 L 1 g
F
P
p
.48107 .58012 m .47999 .57835 L .48907 .58047 L 1 g
F
P
p
.48107 .58012 m .48907 .58047 L .48933 .58053 L 1 g
F
P
p
.002 w
.51399 .58796 m .49592 .60457 L p
.48933 .58053 L 1 g
F P
s
P
p
.51079 .57862 m .49936 .58091 L .50036 .58095 L 1 g
F
P
p
.002 w
.51399 .58796 m .50341 .58252 L p
.51403 .58043 L 1 g
F P
s
P
p
.002 w
.50341 .58252 m .50036 .58095 L p
.51093 .58055 L 1 g
F P
s
P
p
.50341 .58252 m .51093 .58055 L .51403 .58043 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58055 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58055 L .52105 .5779 L 1 g
F
P
p
.002 w
.51093 .58055 m .51079 .57862 L p
.50036 .58095 L 1 g
F P
s
P
p
.51079 .57862 m .48907 .58047 L .49936 .58091 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48765 .57441 m .51414 .55659 L p
.51403 .58043 L 1 g
F P
s
P
p
.002 w
.50036 .58095 m .48765 .57441 L p
.51403 .58043 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.53128 .57265 m .52105 .5779 L .52271 .57746 L 1 g
F
P
p
.54444 .5918 m .52454 .57867 L .53554 .57316 L 1 g
F
P
p
.52454 .57867 m .52271 .57746 L .53167 .57446 L 1 g
F
P
p
.52454 .57867 m .53167 .57446 L .53554 .57316 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53167 .57446 L p
1 g
F P
s
P
p
.54854 .56129 m .53167 .57446 L .53971 .56971 L 1 g
F
P
p
.002 w
.53167 .57446 m .53128 .57265 L p
.52271 .57746 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52271 .57746 m .53217 .56608 L p
.53554 .57316 L 1 g
F P
s
P
p
.002 w
.55317 .56887 m .54444 .5918 L p
.53518 .57239 L 1 g
F P
s
P
p
.54854 .56129 m .53971 .56971 L .54334 .56756 L 1 g
F
P
p
.002 w
.55317 .56887 m .54553 .56785 L p
.55226 .56095 L 1 g
F P
s
P
p
.002 w
.54553 .56785 m .54334 .56756 L p
.54924 .56318 L 1 g
F P
s
P
p
.54553 .56785 m .54924 .56318 L .55226 .56095 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54924 .56318 L p
1 g
F P
s
P
p
.56075 .54566 m .54924 .56318 L .55526 .55562 L 1 g
F
P
p
.002 w
.54924 .56318 m .54854 .56129 L p
.54334 .56756 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53217 .56608 m .54979 .53953 L p
.55226 .56095 L 1 g
F P
s
P
p
.002 w
.54334 .56756 m .53217 .56608 L p
.55226 .56095 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.56075 .54566 m .55526 .55562 L .55738 .55296 L 1 g
F
P
p
.57492 .56478 m .55909 .55411 L .56315 .54536 L 1 g
F
P
p
.55909 .55411 m .55738 .55296 L .56164 .54734 L 1 g
F
P
p
.55909 .55411 m .56164 .54734 L .56315 .54536 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56164 .54734 L p
1 g
F P
s
P
p
.56654 .52734 m .56164 .54734 L .56406 .54092 L 1 g
F
P
p
.002 w
.56164 .54734 m .56075 .54566 L p
.55738 .55296 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55738 .55296 m .56053 .54103 L p
.56315 .54536 L 1 g
F P
s
P
p
.002 w
.5717 .53899 m .57492 .56478 L p
.56268 .54459 L 1 g
F P
s
P
p
.56654 .52734 m .56406 .54092 L .56428 .54035 L 1 g
F
P
p
.002 w
.56888 .52369 m .5717 .53899 L .56816 .53964 L p
1 g
F P
s
P
p
.002 w
.56816 .53964 m .56428 .54035 L p
.56749 .52872 L 1 g
F P
s
P
p
.56816 .53964 m .56749 .52872 L .56888 .52369 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56749 .52872 L p
1 g
F P
s
P
p
.56515 .50826 m .56749 .52872 L .56695 .51991 L 1 g
F
P
p
.002 w
.56749 .52872 m .56654 .52734 L p
.56428 .54035 L 1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56515 .50826 m .56695 .51991 L .56633 .50992 L 1 g
F
P
p
.002 w
.56629 .5093 m .58215 .53361 L p
.56667 .51043 L 1 g
F P
s
P
p
.56667 .51043 m .56633 .50992 L .56632 .50965 L 1 g
F
P
p
.56667 .51043 m .56632 .50965 L .56629 .5093 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56632 .50965 L p
1 g
F P
s
P
p
.002 w
.56633 .50992 m .56619 .50914 L .56629 .5093 L p
1 g
F P
s
P
p
.55661 .4905 m .56632 .50965 L .56619 .50937 L 1 g
F
P
p
.55661 .4905 m .56619 .50937 L .56612 .50922 L 1 g
F
P
p
.002 w
.55298 .47853 m .56619 .50914 L .56598 .50892 L p
1 g
F P
s
P
p
.002 w
.55163 .47948 m .55298 .47853 L p
.55921 .49309 L 1 g
F P
s
P
p
.55742 .49137 m .55921 .49309 L .56598 .50892 L 1 g
F
P
p
.55163 .47948 m .55921 .49309 L .55742 .49137 L 1 g
F
P
p
.55661 .4905 m .56612 .50922 L .5661 .50918 L 1 g
F
P
p
.5661 .50917 m .5661 .50918 L .5661 .50917 L 1 g
F
P
p
.55661 .4905 m .5661 .50918 L .5661 .50917 L 1 g
F
P
p
.55661 .4905 m .5661 .50917 L .56609 .50915 L 1 g
F
P
p
.002 w
.56632 .50965 m .56515 .50826 L p
.56633 .50992 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53411 .52672 m .5309 .51674 L .56609 .50916 L p
1 g
F P
s
P
p
.002 w
.56609 .50916 m .56619 .50914 L .5661 .50918 L p
1 g
F P
s
P
p
.002 w
.5661 .50918 m .53411 .52672 L p
.56609 .50916 L 1 g
F P
s
P
p
.55661 .4905 m .56609 .50916 L .56608 .50914 L 1 g
F
P
p
.55661 .4905 m .56609 .50914 L .56253 .50182 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.5309 .51674 m .53142 .50574 L .56608 .50913 L p
1 g
F P
s
P
p
.002 w
.56608 .50913 m .56619 .50914 L .56609 .50916 L p
1 g
F P
s
P
p
.002 w
.56609 .50916 m .5309 .51674 L p
.56608 .50913 L 1 g
F P
s
P
p
.56609 .50915 m .5661 .50917 L .56609 .50916 L 1 g
F
P
p
.56608 .50914 m .56609 .50916 L .56609 .50914 L 1 g
F
P
p
.002 w
.53142 .50574 m .53563 .49492 L .56605 .50907 L p
1 g
F P
s
P
p
.002 w
.56605 .50907 m .56619 .50914 L .56608 .50913 L p
1 g
F P
s
P
p
.002 w
.56608 .50913 m .53142 .50574 L p
.56605 .50907 L 1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.53563 .49492 m .5431 .4855 L .56598 .50892 L p
1 g
F P
s
P
p
.002 w
.56598 .50892 m .56619 .50914 L .56605 .50907 L p
1 g
F P
s
P
p
.002 w
.56605 .50907 m .53563 .49492 L p
.56598 .50892 L 1 g
F P
s
P
p
.56253 .50182 m .56609 .50914 L .56374 .50413 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.59076 .52549 m .58215 .53361 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.59665 .51547 m .59076 .52549 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.59916 .5046 m .59665 .51547 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.59803 .49403 m .59916 .5046 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.59332 .48489 m .59803 .49403 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.58552 .47818 m .59332 .48489 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.57545 .47467 m .58552 .47818 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.56418 .47478 m .57545 .47467 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.55298 .47853 m .56418 .47478 L .56619 .50914 L closepath p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55742 .49137 L p
1 g
F P
s
P
p
.54174 .47608 m .55742 .49137 L .55128 .48542 L 1 g
F
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56598 .50892 m .5431 .4855 L .54788 .48213 L p
1 g
F P
s
P
p
.54174 .47608 m .55128 .48542 L .54788 .48213 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54788 .48213 m .5431 .4855 L p
.53667 .47404 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47677 L p
1 g
F P
s
P
p
.52214 .46667 m .54237 .47677 L .53275 .47216 L 1 g
F
P
p
.53318 .46782 m .54237 .47677 L .53667 .47404 L 1 g
F
P
p
.54237 .47677 m .54788 .48213 L .53667 .47404 L 1 g
F
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.5183 .45977 m .53318 .46782 L .53667 .47404 L 1 g
F
P
p
.002 w
.5431 .4855 m .5281 .46994 L p
.53667 .47404 L 1 g
F P
s
P
p
.52214 .46667 m .53275 .47216 L .5281 .46994 L 1 g
F
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5281 .46994 m .5431 .4855 L p
.51911 .46676 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.5 .4634 m .52247 .46722 L .5136 .46601 L 1 g
F
P
p
.51519 .46371 m .52247 .46722 L .51911 .46676 L 1 g
F
P
p
.52247 .46722 m .5281 .46994 L .51911 .46676 L 1 g
F
P
p
.002 w
.50354 .4785 m .5134 .46599 L p
.5431 .4855 L 1 g
F P
s
P
p
.5 .4634 m .5136 .46601 L .5134 .46599 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5134 .46599 m .50354 .4785 L p
.48622 .46594 L 1 g
F P
s
P
p
.47786 .46667 m .48847 .46559 L .48211 .46657 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48211 .46657 m .50354 .4785 L p
.47238 .4697 L 1 g
F P
s
P
p
.47754 .4672 m .48211 .46657 L .47238 .4697 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.46665 .47248 m .47238 .4697 L .50354 .4785 L 1 g
F
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46825 .4717 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46825 .4717 L 1 g
F
P
p
.002 w
.45932 .49201 m .46665 .47248 L p
.50354 .4785 L 1 g
F P
s
P
p
.45826 .47608 m .46825 .4717 L .46665 .47248 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46665 .47248 m .45932 .49201 L .44585 .48819 L p
1 g
F P
s
P
p
.44339 .4905 m .44978 .48438 L .44585 .48819 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43419 .50904 m .43485 .50826 L p
.4373 .50252 L 1 g
F P
s
P
p
.42427 .50902 m .44268 .49125 L .4372 .50275 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44268 .49125 L p
1 g
F P
s
P
p
.002 w
.44268 .49125 m .44166 .49233 L p
.4373 .50252 L 1 g
F P
s
P
p
.43485 .50826 m .44268 .49125 L .4373 .50252 L 1 g
F
P
p
.002 w
.42401 .52308 m .42427 .50902 L p
.4372 .50275 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43001 .5178 m .43419 .50904 L .43364 .51461 L 1 g
F
P
p
.42401 .52308 m .43439 .50708 L .43001 .5178 L 1 g
F
P
p
.43439 .50708 m .4372 .50275 L .43419 .50904 L 1 g
F
P
p
.43439 .50708 m .43419 .50904 L .43001 .5178 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43419 .50904 L p
1 g
F P
s
P
p
.43346 .52734 m .43419 .50904 L .43318 .5193 L 1 g
F
P
p
.43346 .52734 m .43318 .5193 L .43279 .52327 L 1 g
F
P
p
.002 w
.43205 .54538 m .42401 .52308 L .43087 .52323 L p
1 g
F P
s
P
p
.002 w
.43087 .52323 m .43279 .52327 L p
.43261 .52858 L 1 g
F P
s
P
p
.43205 .54538 m .43087 .52323 L .43261 .52858 L 1 g
F
P
p
.002 w
.43858 .54692 m .43925 .54566 L p
.43623 .53968 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43712 .55947 m .43205 .54538 L p
.4355 .54256 L 1 g
F P
s
P
p
.43712 .55947 m .4355 .54256 L .44186 .55155 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43858 .54692 L p
1 g
F P
s
P
p
.45146 .56129 m .43858 .54692 L .44335 .55366 L 1 g
F
P
p
.002 w
.44603 .55743 m .43712 .55947 L p
.44186 .55155 L 1 g
F P
s
P
p
.45146 .56129 m .43779 .54842 L .4422 .55324 L 1 g
F
P
p
.46213 .58753 m .44781 .56078 L .46398 .57709 L 1 g
F
P
p
.44781 .56078 m .44603 .55743 L .45091 .56278 L 1 g
F
P
p
.44781 .56078 m .45091 .56278 L .46398 .57709 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45091 .56278 L p
1 g
F P
s
P
p
.002 w
.46213 .58753 m .43712 .55947 L .44603 .55743 L p
1 g
F P
s
P
p
.46872 .57265 m .45091 .56278 L .46203 .56998 L 1 g
F
P
p
.45146 .56129 m .44444 .55519 L .44603 .55743 L 1 g
F
P
p
.002 w
.45053 .5638 m .45091 .56278 L p
.44603 .55743 L 1 g
F P
s
P
p
.002 w
.45091 .56278 m .45146 .56129 L p
.44603 .55743 L 1 g
F P
s
P
p
.002 w
.44603 .55743 m .46835 .55231 L p
.46398 .57709 L 1 g
F P
s
P
p
.002 w
.45091 .56278 m .45002 .56518 L p
.46203 .56998 L 1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45843 .52383 m .46835 .55231 L .44603 .55743 L p
1 g
F P
s
P
p
.44186 .55155 m .45843 .52383 L .44603 .55743 L 1 g
F
P
p
.002 w
.43858 .54692 m .43779 .54842 L p
.44335 .55366 L 1 g
F P
s
P
p
.002 w
.43779 .54842 m .43743 .5491 L p
.4422 .55324 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43261 .52858 L p
1 g
F P
s
P
p
.43925 .54566 m .43261 .52858 L .43623 .53968 L 1 g
F
P
p
.002 w
.43261 .52858 m .43346 .52734 L p
.43279 .52327 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43279 .52327 m .45843 .52383 L p
.43205 .54538 L 1 g
F P
s
P
p
.002 w
.43261 .52858 m .43146 .53025 L p
.43623 .53968 L 1 g
F P
s
P
p
.44186 .55155 m .43858 .54692 L .45843 .52383 L 1 g
F
P
p
.43858 .54692 m .4355 .54256 L .43682 .54149 L 1 g
F
P
p
.43858 .54692 m .43682 .54149 L .45843 .52383 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45053 .5638 L p
1 g
F P
s
P
p
.44444 .55519 m .43743 .5491 L .45053 .5638 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43858 .54692 L p
1 g
F P
s
P
p
.43623 .53968 m .43146 .53025 L .43858 .54692 L 1 g
F
P
p
.002 w
.43221 .52917 m .43261 .52858 L p
.43279 .52327 L 1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.45932 .49201 m .45843 .52383 L .42401 .52308 L p
1 g
F P
s
P
p
.002 w
.43419 .50904 m .43287 .51061 L p
.43318 .5193 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43221 .52917 L p
1 g
F P
s
P
p
.43318 .5193 m .43287 .51061 L .43221 .52917 L 1 g
F
P
p
.43364 .51461 m .4372 .50275 L .45932 .49201 L 1 g
F
P
p
.43419 .50904 m .4372 .50275 L .43364 .51461 L 1 g
F
P
p
.002 w
.44585 .48819 m .45932 .49201 L p
.4372 .50275 L 1 g
F P
s
P
p
.44268 .49125 m .44585 .48819 L .4372 .50275 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43419 .50904 L p
1 g
F P
s
P
p
.4373 .50252 m .44166 .49233 L .43419 .50904 L 1 g
F
P
p
.002 w
.44245 .4915 m .44268 .49125 L p
.44585 .48819 L 1 g
F P
s
P
p
.002 w
.44268 .49125 m .44339 .4905 L p
.44585 .48819 L 1 g
F P
s
P
p
.45776 .47663 m .46665 .47248 L .44585 .48819 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45776 .47663 L p
1 g
F P
s
P
p
.002 w
.45776 .47663 m .45698 .47747 L p
.44978 .48438 L 1 g
F P
s
P
p
.44339 .4905 m .45776 .47663 L .44978 .48438 L 1 g
F
P
p
.002 w
.43786 .48592 m .42477 .4822 L p
.46058 .47388 L 1 g
F P
s
P
p
.002 w
.45776 .47663 m .45826 .47608 L p
.46665 .47248 L 1 g
F P
s
P
p
.46058 .47388 m .46665 .47248 L .45776 .47663 L 1 g
F
P
p
.46058 .47388 m .45776 .47663 L .43786 .48592 L 1 g
F
P
p
.002 w
.42427 .50902 m .42477 .4822 L .44585 .48819 L p
1 g
F P
s
P
p
.002 w
.44585 .48819 m .43786 .48592 L p
.45776 .47663 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44245 .4915 L p
1 g
F P
s
P
p
.44978 .48438 m .45698 .47747 L .44245 .4915 L 1 g
F
P
p
.002 w
.45751 .4769 m .45776 .47663 L p
.46665 .47248 L 1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47115 .46047 m .46665 .47248 L p
.42477 .4822 L 1 g
F P
s
P
p
.002 w
.46665 .47248 m .46814 .4685 L p
.47238 .4697 L 1 g
F P
s
P
p
.46814 .4685 m .47754 .4672 L .47238 .4697 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45751 .4769 L p
1 g
F P
s
P
p
.46825 .4717 m .47718 .46778 L .45751 .4769 L 1 g
F
P
p
.002 w
.4775 .46727 m .47754 .4672 L p
.48211 .46657 L 1 g
F P
s
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.48211 .46657 L 1 g
F P
s
P
p
.5 .46382 m .5134 .46599 L .48622 .46594 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .46442 L p
.48847 .46559 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .48847 .46559 L 1 g
F
P
p
.47115 .46047 m .47853 .46036 L .48622 .46594 L 1 g
F
P
p
.002 w
.50354 .4785 m .48211 .46657 L p
.48622 .46594 L 1 g
F P
s
P
p
.002 w
.48211 .46657 m .47115 .46047 L p
.48622 .46594 L 1 g
F P
s
P
p
.002 w
.46814 .4685 m .47115 .46047 L .48211 .46657 L p
1 g
F P
s
P
p
.47853 .46036 m .5 .46382 L .48622 .46594 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46727 L p
1 g
F P
s
P
p
.48847 .46559 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.002 w
.5 .46417 m .5 .46382 L p
.5134 .46599 L 1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .4634 L p
.5134 .46599 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5183 .45977 m .5134 .46599 L p
.47853 .46036 L 1 g
F P
s
P
p
.002 w
.5134 .46599 m .51519 .46371 L p
.51911 .46676 L 1 g
F P
s
P
p
.5134 .46599 m .51911 .46676 L .5431 .4855 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46417 L p
1 g
F P
s
P
p
.5136 .46601 m .52282 .46778 L .5 .46417 L 1 g
F
P
p
.002 w
.52247 .46722 m .52282 .46778 L p
.5136 .46601 L 1 g
F P
s
P
p
.002 w
.52249 .46725 m .52247 .46722 L p
.5281 .46994 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.5281 .46994 L 1 g
F P
s
P
p
.002 w
.51519 .46371 m .5183 .45977 L .5281 .46994 L p
1 g
F P
s
P
p
.002 w
.5281 .46994 m .5183 .45977 L p
.53667 .47404 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52249 .46725 L p
1 g
F P
s
P
p
.53275 .47216 m .54302 .47747 L .52249 .46725 L 1 g
F
P
p
.002 w
.54237 .47677 m .54302 .47747 L p
.53275 .47216 L 1 g
F P
s
P
p
.002 w
.54265 .47708 m .54237 .47677 L p
.54788 .48213 L 1 g
F P
s
P
p
.002 w
.54237 .47677 m .54174 .47608 L p
.54788 .48213 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55298 .47853 m .54788 .48213 L p
.53318 .46782 L 1 g
F P
s
P
p
.002 w
.54788 .48213 m .55163 .47948 L p
.55742 .49137 L 1 g
F P
s
P
p
.54788 .48213 m .55742 .49137 L .56598 .50892 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54265 .47708 L p
1 g
F P
s
P
p
.55128 .48542 m .55834 .49233 L .54265 .47708 L 1 g
F
P
p
.002 w
.55742 .49137 m .55834 .49233 L p
.55128 .48542 L 1 g
F P
s
P
p
.56374 .50413 m .56608 .50913 L .56413 .50488 L 1 g
F
P
p
.56608 .50913 m .56612 .50922 L .56609 .50916 L 1 g
F
P
p
.56608 .50913 m .56609 .50916 L .56413 .50488 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54065 .53459 m .53411 .52672 L .5661 .50918 L p
1 g
F P
s
P
p
.002 w
.5661 .50918 m .56619 .50914 L .56612 .50921 L p
1 g
F P
s
P
p
.002 w
.56612 .50921 m .54065 .53459 L p
.5661 .50918 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54979 .53953 m .54065 .53459 L .56612 .50921 L p
1 g
F P
s
P
p
.002 w
.56612 .50921 m .56619 .50914 L .56613 .50924 L p
1 g
F P
s
P
p
.002 w
.56613 .50924 m .54979 .53953 L p
.56612 .50921 L 1 g
F P
s
P
p
.56413 .50488 m .56613 .50924 L .56427 .50515 L 1 g
F
P
p
.002 w
.56616 .5093 m .56619 .50914 L .56626 .50952 L p
1 g
F P
s
P
p
.56613 .50924 m .56619 .50937 L .56616 .5093 L 1 g
F
P
p
.56613 .50924 m .56616 .5093 L .56427 .50515 L 1 g
F
P
p
.002 w
.56053 .54103 m .54979 .53953 L .56613 .50924 L p
1 g
F P
s
P
p
.002 w
.56613 .50924 m .56619 .50914 L .56616 .5093 L p
1 g
F P
s
P
p
.002 w
.56616 .5093 m .56053 .54103 L p
.56613 .50924 L 1 g
F P
s
P
p
.002 w
.56053 .54103 m .56616 .5093 L p
.56633 .50992 L 1 g
F P
s
P
p
.002 w
.56626 .50952 m .56633 .50992 L p
.56616 .5093 L 1 g
F P
s
P
p
.56427 .50515 m .56626 .50952 L .56713 .51061 L 1 g
F
P
p
.002 w
.56632 .50965 m .56632 .50965 L p
.56626 .50952 L 1 g
F P
s
P
p
.002 w
.56632 .50965 m .56713 .51061 L p
.56626 .50952 L 1 g
F P
s
P
p
.002 w
.56632 .50965 m .56632 .50965 L p
.56633 .50992 L 1 g
F P
s
P
p
.002 w
.58215 .53361 m .5717 .53899 L .56633 .50992 L p
1 g
F P
s
P
p
.002 w
.56633 .50992 m .56888 .52369 L p
.56737 .52682 L 1 g
F P
s
P
p
.56737 .52682 m .56053 .54103 L .56633 .50992 L 1 g
F
P
p
.002 w
.56428 .54035 m .56053 .54103 L p
.56888 .52369 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56632 .50965 L p
1 g
F P
s
P
p
.56695 .51991 m .56854 .53025 L .56632 .50965 L 1 g
F
P
p
.002 w
.56749 .52872 m .56854 .53025 L p
.56695 .51991 L 1 g
F P
s
P
p
.002 w
.56824 .52982 m .56749 .52872 L p
.56428 .54035 L 1 g
F P
s
P
p
.002 w
.56053 .54103 m .56428 .54035 L p
.56268 .54459 L 1 g
F P
s
P
p
.002 w
.56428 .54035 m .5717 .53899 L p
.56268 .54459 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56824 .52982 L p
1 g
F P
s
P
p
.56406 .54092 m .56257 .5491 L .56824 .52982 L 1 g
F
P
p
.002 w
.56164 .54734 m .56257 .5491 L p
.56406 .54092 L 1 g
F P
s
P
p
.002 w
.56172 .54749 m .56164 .54734 L p
.55738 .55296 L 1 g
F P
s
P
p
.002 w
.57492 .56478 m .55317 .56887 L .55738 .55296 L p
1 g
F P
s
P
p
.002 w
.54979 .53953 m .56053 .54103 L .55738 .55296 L p
1 g
F P
s
P
p
.002 w
.55738 .55296 m .55317 .56887 L p
.5521 .55959 L 1 g
F P
s
P
p
.5521 .55959 m .54979 .53953 L .55738 .55296 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56172 .54749 L p
1 g
F P
s
P
p
.55526 .55562 m .54998 .56518 L .56172 .54749 L 1 g
F
P
p
.002 w
.54924 .56318 m .54998 .56518 L p
.55526 .55562 L 1 g
F P
s
P
p
.002 w
.54951 .56391 m .54924 .56318 L p
.54334 .56756 L 1 g
F P
s
P
p
.002 w
.53217 .56608 m .54334 .56756 L p
.53518 .57239 L 1 g
F P
s
P
p
.002 w
.54334 .56756 m .55317 .56887 L p
.53518 .57239 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54951 .56391 L p
1 g
F P
s
P
p
.53971 .56971 m .5322 .57686 L .54951 .56391 L 1 g
F
P
p
.002 w
.53167 .57446 m .5322 .57686 L p
.53971 .56971 L 1 g
F P
s
P
p
.002 w
.53181 .57508 m .53167 .57446 L p
.52271 .57746 L 1 g
F P
s
P
p
.002 w
.54444 .5918 m .51399 .58796 L .52271 .57746 L p
1 g
F P
s
P
p
.002 w
.51414 .55659 m .53217 .56608 L .52271 .57746 L p
1 g
F P
s
P
p
.002 w
.52271 .57746 m .51399 .58796 L p
.51403 .57974 L 1 g
F P
s
P
p
.51403 .57974 m .51414 .55659 L .52271 .57746 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53181 .57508 L p
1 g
F P
s
P
p
.52105 .5779 m .51111 .583 L .53181 .57508 L 1 g
F
P
p
.002 w
.51093 .58055 m .51111 .583 L p
.52105 .5779 L 1 g
F P
s
P
p
.002 w
.511 .5814 m .51093 .58055 L p
.50036 .58095 L 1 g
F P
s
P
p
.002 w
.48765 .57441 m .50801 .58488 L p
.48933 .58053 L 1 g
F P
s
P
p
.002 w
.50801 .58488 m .51399 .58796 L p
.48933 .58053 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .5814 L p
1 g
F P
s
P
p
.49936 .58091 m .48889 .583 L .511 .5814 L 1 g
F
P
p
.002 w
.48907 .58047 m .48889 .583 L p
.49936 .58091 L 1 g
F P
s
P
p
.002 w
.47999 .57835 m .48765 .57441 L p
.48931 .58048 L 1 g
F P
s
P
p
.48907 .58047 m .47999 .57835 L .48931 .58048 L 1 g
F
P
p
.002 w
.46808 .57557 m .4678 .57686 L p
.47679 .5776 L 1 g
F P
s
P
p
.46474 .57276 m .46835 .55231 L .47999 .57835 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4684 .5741 L p
1 g
F P
s
P
p
.46203 .56998 m .45002 .56518 L .4684 .5741 L 1 g
F
P
p
.47829 .57772 m .47679 .5776 L .47999 .57835 L 1 g
F
P
p
.002 w
.46835 .55231 m .48765 .57441 L .47999 .57835 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58047 L p
1 g
F P
s
P
p
.47679 .5776 m .4678 .57686 L .48907 .58047 L 1 g
F
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.55317 .56887 m .57492 .56478 L .57582 .58577 L p
1 g
F P
s
P
p
.002 w
.57582 .58577 m .54444 .5918 L .55317 .56887 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.57782 .28118 m .51728 .27907 L .50659 .25936 L p
1 g
F P
s
P
p
.002 w
.44292 .27855 m .50659 .25936 L .51728 .27907 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.61192 .53854 m .62342 .51909 L .64571 .51998 L p
1 g
F P
s
P
p
.002 w
.65315 .48941 m .64571 .51998 L .62342 .51909 L p
1 g
F P
s
P
p
.002 w
.66934 .44108 m .65319 .40713 L .66387 .38271 L p
1 g
F P
s
P
p
.002 w
.63111 .35193 m .66387 .38271 L .65319 .40713 L p
1 g
F P
s
P
p
.002 w
.66387 .38271 m .63111 .35193 L .63282 .3255 L p
1 g
F P
s
P
p
.002 w
.65315 .48941 m .65042 .45933 L .66934 .44108 L p
1 g
F P
s
P
p
.002 w
.65319 .40713 m .66934 .44108 L .65042 .45933 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.58385 .30567 m .63282 .3255 L .63111 .35193 L p
1 g
F P
s
P
p
.002 w
.63282 .3255 m .58385 .30567 L .57782 .28118 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.004 w
.5 .43051 m
.52929 .46531 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.51728 .27907 m .57782 .28118 L .58385 .30567 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.40239 .33512 m .3627 .38676 L .34561 .37134 L p
1 g
F P
s
P
p
.002 w
.34561 .37134 m .38684 .3175 L .40239 .33512 L p
1 g
F P
s
P
p
.002 w
.62342 .51909 m .62846 .49792 L .65315 .48941 L p
1 g
F P
s
P
p
.002 w
.65042 .45933 m .65315 .48941 L .62846 .49792 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.51728 .27907 m .45622 .29767 L .44292 .27855 L p
1 g
F P
s
P
p
.002 w
.38684 .3175 m .44292 .27855 L .45622 .29767 L p
1 g
F P
s
P
p
.002 w
.42401 .52308 m .43712 .55947 L .40848 .56262 L p
1 g
F P
s
P
p
.002 w
.40848 .56262 m .3925 .51953 L .42401 .52308 L p
1 g
F P
s
P
p
.002 w
.45622 .29767 m .40239 .33512 L .38684 .3175 L p
1 g
F P
s
P
p
.002 w
.38454 .40399 m .3651 .45866 L .34198 .44587 L p
1 g
F P
s
P
p
.002 w
.34198 .44587 m .3627 .38676 L .38454 .40399 L p
1 g
F P
s
P
p
.002 w
.39299 .47093 m .3925 .51953 L .36496 .5134 L p
1 g
F P
s
P
p
.002 w
.36496 .5134 m .3651 .45866 L .39299 .47093 L p
1 g
F P
s
P
p
.002 w
.5717 .53899 m .58215 .53361 L .59519 .5543 L p
1 g
F P
s
P
p
.002 w
.59519 .5543 m .57492 .56478 L .5717 .53899 L p
1 g
F P
s
P
p
.002 w
.61192 .53854 m .59519 .5543 L .58215 .53361 L p
1 g
F P
s
P
p
.002 w
.62342 .51909 m .61192 .53854 L .59076 .52549 L p
1 g
F P
s
P
p
.002 w
.58215 .53361 m .59076 .52549 L .61192 .53854 L p
1 g
F P
s
P
p
.002 w
.65042 .45933 m .63756 .43291 L .65319 .40713 L p
1 g
F P
s
P
p
.002 w
.62536 .38146 m .65319 .40713 L .63756 .43291 L p
1 g
F P
s
P
p
.002 w
.65319 .40713 m .62536 .38146 L .63111 .35193 L p
1 g
F P
s
P
p
.002 w
.62846 .49792 m .62642 .47721 L .65042 .45933 L p
1 g
F P
s
P
p
.002 w
.63756 .43291 m .65042 .45933 L .62642 .47721 L p
1 g
F P
s
P
p
.002 w
.58749 .33467 m .63111 .35193 L .62536 .38146 L p
1 g
F P
s
P
p
.002 w
.63111 .35193 m .58749 .33467 L .58385 .30567 L p
1 g
F P
s
P
p
.002 w
.58385 .30567 m .52778 .30403 L .51728 .27907 L p
1 g
F P
s
P
p
.002 w
.45622 .29767 m .51728 .27907 L .52778 .30403 L p
1 g
F P
s
P
p
.002 w
.59076 .52549 m .59665 .51547 L .62342 .51909 L p
1 g
F P
s
P
p
.002 w
.62846 .49792 m .62342 .51909 L .59665 .51547 L p
1 g
F P
s
P
p
.002 w
.52778 .30403 m .58385 .30567 L .58749 .33467 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59665 .51547 m .59916 .5046 L .62846 .49792 L p
1 g
F P
s
P
p
.002 w
.62642 .47721 m .62846 .49792 L .59916 .5046 L p
1 g
F P
s
P
p
.002 w
.50108 .54128 m .51414 .55659 L .48765 .57441 L p
1 g
F P
s
P
p
.002 w
.48765 .57441 m .46835 .55231 L .50108 .54128 L p
1 g
F P
s
P
p
.002 w
.42141 .35622 m .38454 .40399 L .3627 .38676 L p
1 g
F P
s
P
p
.002 w
.3627 .38676 m .40239 .33512 L .42141 .35622 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52778 .30403 m .47127 .32146 L .45622 .29767 L p
1 g
F P
s
P
p
.002 w
.40239 .33512 m .45622 .29767 L .47127 .32146 L p
1 g
F P
s
P
p
.002 w
.42477 .4822 m .42401 .52308 L .3925 .51953 L p
1 g
F P
s
P
p
.002 w
.3925 .51953 m .39299 .47093 L .42477 .4822 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54065 .53459 m .54979 .53953 L .53217 .56608 L p
1 g
F P
s
P
p
.002 w
.53217 .56608 m .51414 .55659 L .54065 .53459 L p
1 g
F P
s
P
p
.002 w
.41051 .42248 m .39299 .47093 L .3651 .45866 L p
1 g
F P
s
P
p
.002 w
.3651 .45866 m .38454 .40399 L .41051 .42248 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62642 .47721 m .6174 .45915 L .63756 .43291 L p
1 g
F P
s
P
p
.002 w
.61564 .41311 m .63756 .43291 L .6174 .45915 L p
1 g
F P
s
P
p
.002 w
.63756 .43291 m .61564 .41311 L .62536 .38146 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.47127 .32146 m .42141 .35622 L .40239 .33512 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.59916 .5046 m .59803 .49403 L .62642 .47721 L p
1 g
F P
s
P
p
.002 w
.6174 .45915 m .62642 .47721 L .59803 .49403 L p
1 g
F P
s
P
p
.002 w
.58852 .36727 m .62536 .38146 L .61564 .41311 L p
1 g
F P
s
P
p
.002 w
.62536 .38146 m .58852 .36727 L .58749 .33467 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5377 .33354 m .58749 .33467 L .58852 .36727 L p
1 g
F P
s
P
p
.002 w
.58749 .33467 m .5377 .33354 L .52778 .30403 L p
1 g
F P
s
P
p
.002 w
.47127 .32146 m .52778 .30403 L .5377 .33354 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.53411 .52672 m .54065 .53459 L .51414 .55659 L p
1 g
F P
s
P
p
.002 w
.51414 .55659 m .50108 .54128 L .53411 .52672 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.49452 .5217 m .50108 .54128 L .46835 .55231 L p
1 g
F P
s
P
p
.002 w
.46835 .55231 m .45843 .52383 L .49452 .5217 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59803 .49403 m .59332 .48489 L .6174 .45915 L p
1 g
F P
s
P
p
.002 w
.60221 .44576 m .6174 .45915 L .59332 .48489 L p
1 g
F P
s
P
p
.002 w
.6174 .45915 m .60221 .44576 L .61564 .41311 L p
1 g
F P
s
P
p
.002 w
.44335 .38013 m .41051 .42248 L .38454 .40399 L p
1 g
F P
s
P
p
.002 w
.38454 .40399 m .42141 .35622 L .44335 .38013 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58683 .40236 m .61564 .41311 L .60221 .44576 L p
1 g
F P
s
P
p
.002 w
.61564 .41311 m .58683 .40236 L .58852 .36727 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43974 .44155 m .42477 .4822 L .39299 .47093 L p
1 g
F P
s
P
p
.002 w
.39299 .47093 m .41051 .42248 L .43974 .44155 L p
1 g
F P
s
P
p
.002 w
.5377 .33354 m .48759 .34923 L .47127 .32146 L p
1 g
F P
s
P
p
.002 w
.42141 .35622 m .47127 .32146 L .48759 .34923 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.5309 .51674 m .53411 .52672 L .50108 .54128 L p
1 g
F P
s
P
p
.002 w
.50108 .54128 m .49452 .5217 L .5309 .51674 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.54664 .36664 m .58852 .36727 L .58683 .40236 L p
1 g
F P
s
P
p
.002 w
.58852 .36727 m .54664 .36664 L .5377 .33354 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.48759 .34923 m .44335 .38013 L .42141 .35622 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59332 .48489 m .58552 .47818 L .60221 .44576 L p
1 g
F P
s
P
p
.002 w
.48759 .34923 m .5377 .33354 L .54664 .36664 L p
1 g
F P
s
P
p
.002 w
.58242 .43862 m .60221 .44576 L .58552 .47818 L p
1 g
F P
s
P
p
.002 w
.60221 .44576 m .58242 .43862 L .58683 .40236 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.49533 .49996 m .49452 .5217 L .45843 .52383 L p
1 g
F P
s
P
p
.002 w
.45843 .52383 m .45932 .49201 L .49533 .49996 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58552 .47818 m .57545 .47467 L .58242 .43862 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.53142 .50574 m .5309 .51674 L .49452 .5217 L p
1 g
F P
s
P
p
.002 w
.49452 .5217 m .49533 .49996 L .53142 .50574 L p
1 g
F P
s
P
p
.002 w
.42477 .4822 m .43974 .44155 L .47115 .46047 L p
1 g
F P
s
P
p
.002 w
.55423 .40213 m .58683 .40236 L .58242 .43862 L p
1 g
F P
s
P
p
.002 w
.58683 .40236 m .55423 .40213 L .54664 .36664 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.46742 .40603 m .43974 .44155 L .41051 .42248 L p
1 g
F P
s
P
p
.002 w
.41051 .42248 m .44335 .38013 L .46742 .40603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.004 w
.5686 .512 m
.56869 .51211 L
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57545 .47467 m .56418 .47478 L .56015 .43865 L p
1 g
F P
s
P
p
.002 w
.56015 .43865 m .58242 .43862 L .57545 .47467 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.58242 .43862 m .56015 .43865 L .55423 .40213 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54664 .36664 m .50457 .38002 L .48759 .34923 L p
1 g
F P
s
P
p
.002 w
.44335 .38013 m .48759 .34923 L .50457 .38002 L p
1 g
F P
s
P
p
.002 w
.53563 .49492 m .53142 .50574 L .49533 .49996 L p
1 g
F P
s
P
p
.002 w
.50457 .38002 m .54664 .36664 L .55423 .40213 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56418 .47478 m .55298 .47853 L .53793 .44596 L p
1 g
F P
s
P
p
.002 w
.53793 .44596 m .56015 .43865 L .56418 .47478 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.004 w
.57059 .51436 m
.57068 .51448 L
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.50457 .38002 m .46742 .40603 L .44335 .38013 L p
1 g
F P
s
P
p
.002 w
.50354 .4785 m .49533 .49996 L .45932 .49201 L p
1 g
F P
s
P
p
.002 w
.5431 .4855 m .53563 .49492 L .50354 .4785 L p
1 g
F P
s
P
p
.002 w
.49533 .49996 m .50354 .4785 L .53563 .49492 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5183 .45977 m .53793 .44596 L .55298 .47853 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.49274 .43293 m .47115 .46047 L .43974 .44155 L p
1 g
F P
s
P
p
.002 w
.43974 .44155 m .46742 .40603 L .49274 .43293 L p
1 g
F P
s
P
p
.002 w
.52157 .41269 m .55423 .40213 L .56015 .43865 L p
1 g
F P
s
P
p
.002 w
.55423 .40213 m .52157 .41269 L .50457 .38002 L p
1 g
F P
s
P
p
.002 w
.56015 .43865 m .53793 .44596 L .52157 .41269 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.004 w
.57259 .51674 m
.57269 .51686 L
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46742 .40603 m .50457 .38002 L .52157 .41269 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.47115 .46047 m .49274 .43293 L .5183 .45977 L p
1 g
F P
s
P
p
.002 w
.53793 .44596 m .5183 .45977 L .49274 .43293 L p
1 g
F P
s
P
p
.002 w
.49274 .43293 m .52157 .41269 L .53793 .44596 L p
1 g
F P
s
P
p
.002 w
.52157 .41269 m .49274 .43293 L .46742 .40603 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.004 w
.57461 .51914 m
.57471 .51926 L
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.004 w
.57664 .52156 m
.57674 .52167 L
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.004 w
.57869 .52399 m
.57879 .5241 L
s
P
p
.004 w
.58075 .52643 m
.58082 .52652 L
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.004 w
.58082 .52652 m
.58085 .52655 L
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.004 w
.58283 .5289 m
.58292 .52902 L
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.58492 .53138 m
.58502 .5315 L
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.004 w
.58702 .53389 m
.58712 .534 L
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.58924 .53653 m
.60629 .55678 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .64925 .68971 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60629 .55678 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.379845)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.379845)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.524 .42102 m .49504 .44061 L .50783 .46602 L p
1 g
F P
s
P
p
.002 w
.46833 .47948 m .50783 .46602 L .49504 .44061 L p
1 g
F P
s
P
p
.002 w
.49504 .44061 m .46213 .45173 L .46833 .47948 L p
1 g
F P
s
P
p
.002 w
.49504 .44061 m .524 .42102 L .50484 .39979 L p
1 g
F P
s
P
p
.002 w
.50484 .39979 m .4824 .415 L .49504 .44061 L p
1 g
F P
s
P
p
.002 w
.46213 .45173 m .49504 .44061 L .4824 .415 L p
1 g
F P
s
P
p
.002 w
.4824 .415 m .50484 .39979 L .48549 .37922 L p
1 g
F P
s
P
p
.002 w
.48549 .37922 m .47012 .38965 L .4824 .415 L p
1 g
F P
s
P
p
.002 w
.4824 .415 m .45686 .42355 L .46213 .45173 L p
1 g
F P
s
P
p
.002 w
.45686 .42355 m .4824 .415 L .47012 .38965 L p
1 g
F P
s
P
p
.002 w
.50783 .46602 m .54262 .44252 L .524 .42102 L p
1 g
F P
s
P
p
.002 w
.54623 .39481 m .524 .42102 L .54262 .44252 L p
1 g
F P
s
P
p
.002 w
.524 .42102 m .54623 .39481 L .52198 .3794 L p
1 g
F P
s
P
p
.002 w
.52198 .3794 m .50484 .39979 L .524 .42102 L p
1 g
F P
s
P
p
.002 w
.50484 .39979 m .52198 .3794 L .49714 .36521 L p
1 g
F P
s
P
p
.002 w
.49714 .36521 m .48549 .37922 L .50484 .39979 L p
1 g
F P
s
P
p
.002 w
.54262 .44252 m .50783 .46602 L .52052 .49075 L p
1 g
F P
s
P
p
.002 w
.47536 .50628 m .52052 .49075 L .50783 .46602 L p
1 g
F P
s
P
p
.002 w
.50783 .46602 m .46833 .47948 L .47536 .50628 L p
1 g
F P
s
P
p
.002 w
.42779 .48152 m .46833 .47948 L .46213 .45173 L p
1 g
F P
s
P
p
.002 w
.46213 .45173 m .42839 .45322 L .42779 .48152 L p
1 g
F P
s
P
p
.002 w
.42839 .45322 m .46213 .45173 L .45686 .42355 L p
1 g
F P
s
P
p
.002 w
.45686 .42355 m .43073 .42453 L .42839 .45322 L p
1 g
F P
s
P
p
.002 w
.43073 .42453 m .45686 .42355 L .45262 .39545 L p
1 g
F P
s
P
p
.002 w
.47012 .38965 m .45262 .39545 L .45686 .42355 L p
1 g
F P
s
P
p
.002 w
.52052 .49075 m .56035 .46391 L .54262 .44252 L p
1 g
F P
s
P
p
.002 w
.56946 .41114 m .54262 .44252 L .56035 .46391 L p
1 g
F P
s
P
p
.002 w
.54262 .44252 m .56946 .41114 L .54623 .39481 L p
1 g
F P
s
P
p
.002 w
.47012 .38965 m .48549 .37922 L .46628 .35968 L p
1 g
F P
s
P
p
.002 w
.46628 .35968 m .45844 .36501 L .47012 .38965 L p
1 g
F P
s
P
p
.002 w
.45262 .39545 m .47012 .38965 L .45844 .36501 L p
1 g
F P
s
P
p
.002 w
.48549 .37922 m .49714 .36521 L .47219 .35251 L p
1 g
F P
s
P
p
.002 w
.47219 .35251 m .46628 .35968 L .48549 .37922 L p
1 g
F P
s
P
p
.002 w
.53202 .3558 m .52198 .3794 L .54623 .39481 L p
1 g
F P
s
P
p
.002 w
.52198 .3794 m .53202 .3558 L .50387 .34904 L p
1 g
F P
s
P
p
.002 w
.50387 .34904 m .49714 .36521 L .52198 .3794 L p
1 g
F P
s
P
p
.002 w
.42896 .50891 m .47536 .50628 L .46833 .47948 L p
1 g
F P
s
P
p
.002 w
.46833 .47948 m .42779 .48152 L .42896 .50891 L p
1 g
F P
s
P
p
.002 w
.55945 .3644 m .54623 .39481 L .56946 .41114 L p
1 g
F P
s
P
p
.002 w
.54623 .39481 m .55945 .3644 L .53202 .3558 L p
1 g
F P
s
P
p
.002 w
.45262 .39545 m .43475 .39601 L .43073 .42453 L p
1 g
F P
s
P
p
.002 w
.43475 .39601 m .45262 .39545 L .4495 .36794 L p
1 g
F P
s
P
p
.002 w
.45844 .36501 m .4495 .36794 L .45262 .39545 L p
1 g
F P
s
P
p
.002 w
.56035 .46391 m .52052 .49075 L .53288 .51436 L p
1 g
F P
s
P
p
.002 w
.48311 .53163 m .53288 .51436 L .52052 .49075 L p
1 g
F P
s
P
p
.002 w
.52052 .49075 m .47536 .50628 L .48311 .53163 L p
1 g
F P
s
P
p
.002 w
.49714 .36521 m .50387 .34904 L .47555 .34426 L p
1 g
F P
s
P
p
.002 w
.47555 .34426 m .47219 .35251 L .49714 .36521 L p
1 g
F P
s
P
p
.002 w
.53288 .51436 m .57686 .48478 L .56035 .46391 L p
1 g
F P
s
P
p
.002 w
.59123 .42813 m .56035 .46391 L .57686 .48478 L p
1 g
F P
s
P
p
.002 w
.56035 .46391 m .59123 .42813 L .56946 .41114 L p
1 g
F P
s
P
p
.002 w
.39713 .44471 m .42839 .45322 L .43073 .42453 L p
1 g
F P
s
P
p
.002 w
.43073 .42453 m .40663 .41772 L .39713 .44471 L p
1 g
F P
s
P
p
.002 w
.40663 .41772 m .43073 .42453 L .43475 .39601 L p
1 g
F P
s
P
p
.002 w
.58565 .37471 m .56946 .41114 L .59123 .42813 L p
1 g
F P
s
P
p
.002 w
.56946 .41114 m .58565 .37471 L .55945 .3644 L p
1 g
F P
s
P
p
.002 w
.43475 .39601 m .41836 .3912 L .40663 .41772 L p
1 g
F P
s
P
p
.002 w
.41836 .3912 m .43475 .39601 L .4404 .36817 L p
1 g
F P
s
P
p
.002 w
.4495 .36794 m .4404 .36817 L .43475 .39601 L p
1 g
F P
s
P
p
.002 w
.39008 .47164 m .42779 .48152 L .42839 .45322 L p
1 g
F P
s
P
p
.002 w
.42839 .45322 m .39713 .44471 L .39008 .47164 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .45844 .36501 L .46628 .35968 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .4495 .36794 L .45844 .36501 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .46628 .35968 L .47219 .35251 L closepath p
1 g
F P
s
P
p
.002 w
.43193 .53483 m .48311 .53163 L .47536 .50628 L p
1 g
F P
s
P
p
.002 w
.47536 .50628 m .42896 .50891 L .43193 .53483 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .4404 .36817 L .4495 .36794 L closepath p
1 g
F P
s
P
p
.002 w
.5338 .33132 m .53202 .3558 L .55945 .3644 L p
1 g
F P
s
P
p
.002 w
.53202 .3558 m .5338 .33132 L .5049 .33234 L p
1 g
F P
s
P
p
.002 w
.5049 .33234 m .50387 .34904 L .53202 .3558 L p
1 g
F P
s
P
p
.002 w
.50387 .34904 m .5049 .33234 L .47597 .33578 L p
1 g
F P
s
P
p
.002 w
.47597 .33578 m .47555 .34426 L .50387 .34904 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .47219 .35251 L .47555 .34426 L closepath p
1 g
F P
s
P
p
.002 w
.4404 .36817 m .43209 .36565 L .41836 .3912 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .43209 .36565 L .4404 .36817 L closepath p
1 g
F P
s
P
p
.002 w
.38567 .49799 m .42896 .50891 L .42779 .48152 L p
1 g
F P
s
P
p
.002 w
.42779 .48152 m .39008 .47164 L .38567 .49799 L p
1 g
F P
s
P
p
.002 w
.5621 .33274 m .55945 .3644 L .58565 .37471 L p
1 g
F P
s
P
p
.002 w
.55945 .3644 m .5621 .33274 L .5338 .33132 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .47555 .34426 L .47597 .33578 L closepath p
1 g
F P
s
P
p
.002 w
.57686 .48478 m .53288 .51436 L .54468 .53637 L p
1 g
F P
s
P
p
.002 w
.49144 .55498 m .54468 .53637 L .53288 .51436 L p
1 g
F P
s
P
p
.002 w
.53288 .51436 m .48311 .53163 L .49144 .55498 L p
1 g
F P
s
P
p
.002 w
.38711 .40363 m .40663 .41772 L .41836 .3912 L p
1 g
F P
s
P
p
.002 w
.41836 .3912 m .40519 .38145 L .38711 .40363 L p
1 g
F P
s
P
p
.002 w
.40519 .38145 m .41836 .3912 L .43209 .36565 L p
1 g
F P
s
P
p
.002 w
.57686 .48478 m .6111 .44544 L .59123 .42813 L p
1 g
F P
s
P
p
.002 w
.61009 .38655 m .59123 .42813 L .6111 .44544 L p
1 g
F P
s
P
p
.002 w
.59123 .42813 m .61009 .38655 L .58565 .37471 L p
1 g
F P
s
P
p
.002 w
.43209 .36565 m .42548 .36062 L .40519 .38145 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .42548 .36062 L .43209 .36565 L closepath p
1 g
F P
s
P
p
.002 w
.54468 .53637 m .59179 .50473 L .57686 .48478 L p
1 g
F P
s
P
p
.002 w
.6111 .44544 m .57686 .48478 L .59179 .50473 L p
1 g
F P
s
P
p
.002 w
.37163 .42676 m .39713 .44471 L .40663 .41772 L p
1 g
F P
s
P
p
.002 w
.40663 .41772 m .38711 .40363 L .37163 .42676 L p
1 g
F P
s
P
p
.002 w
.4734 .32799 m .47597 .33578 L .5049 .33234 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .47597 .33578 L .4734 .32799 L closepath p
1 g
F P
s
P
p
.002 w
.50001 .31689 m .5049 .33234 L .5338 .33132 L p
1 g
F P
s
P
p
.002 w
.5049 .33234 m .50001 .31689 L .4734 .32799 L p
1 g
F P
s
P
p
.002 w
.39672 .36769 m .40519 .38145 L .42548 .36062 L p
1 g
F P
s
P
p
.002 w
.42548 .36062 m .42129 .35361 L .39672 .36769 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .42129 .35361 L .42548 .36062 L closepath p
1 g
F P
s
P
p
.002 w
.58925 .33663 m .58565 .37471 L .61009 .38655 L p
1 g
F P
s
P
p
.002 w
.58565 .37471 m .58925 .33663 L .5621 .33274 L p
1 g
F P
s
P
p
.002 w
.43668 .55871 m .49144 .55498 L .48311 .53163 L p
1 g
F P
s
P
p
.002 w
.48311 .53163 m .43193 .53483 L .43668 .55871 L p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .4734 .32799 L .46807 .32174 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .46807 .32174 L .46053 .31772 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .46053 .31772 L .4516 .31641 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .4516 .31641 L .44227 .31797 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .44227 .31797 L .43357 .32224 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .43357 .32224 L .42648 .32874 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .42648 .32874 L .42179 .33674 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .42179 .33674 L .42 .34535 L closepath p
1 g
F P
s
P
p
.002 w
.44758 .34156 m .42 .34535 L .42129 .35361 L closepath p
1 g
F P
s
P
p
.002 w
.35912 .45037 m .39008 .47164 L .39713 .44471 L p
1 g
F P
s
P
p
.002 w
.39713 .44471 m .37163 .42676 L .35912 .45037 L p
1 g
F P
s
P
p
.002 w
.5269 .30851 m .5338 .33132 L .5621 .33274 L p
1 g
F P
s
P
p
.002 w
.5338 .33132 m .5269 .30851 L .50001 .31689 L p
1 g
F P
s
P
p
.002 w
.38407 .52318 m .43193 .53483 L .42896 .50891 L p
1 g
F P
s
P
p
.002 w
.42896 .50891 m .38567 .49799 L .38407 .52318 L p
1 g
F P
s
P
p
.002 w
.46807 .32174 m .4734 .32799 L .50001 .31689 L p
1 g
F P
s
P
p
.002 w
.37438 .38354 m .38711 .40363 L .40519 .38145 L p
1 g
F P
s
P
p
.002 w
.40519 .38145 m .39672 .36769 L .37438 .38354 L p
1 g
F P
s
P
p
.002 w
.39397 .35134 m .39672 .36769 L .42129 .35361 L p
1 g
F P
s
P
p
.002 w
.42129 .35361 m .42 .34535 L .39397 .35134 L p
1 g
F P
s
P
p
.002 w
.59179 .50473 m .62861 .46276 L .6111 .44544 L p
1 g
F P
s
P
p
.002 w
.63223 .39971 m .6111 .44544 L .62861 .46276 L p
1 g
F P
s
P
p
.002 w
.6111 .44544 m .63223 .39971 L .61009 .38655 L p
1 g
F P
s
P
p
.002 w
.50001 .31689 m .48961 .30438 L .46807 .32174 L p
1 g
F P
s
P
p
.002 w
.46053 .31772 m .46807 .32174 L .48961 .30438 L p
1 g
F P
s
P
p
.002 w
.48961 .30438 m .50001 .31689 L .5269 .30851 L p
1 g
F P
s
P
p
.002 w
.59179 .50473 m .54468 .53637 L .55567 .55628 L p
1 g
F P
s
P
p
.002 w
.50021 .57581 m .55567 .55628 L .54468 .53637 L p
1 g
F P
s
P
p
.002 w
.54468 .53637 m .49144 .55498 L .50021 .57581 L p
1 g
F P
s
P
p
.002 w
.55352 .30307 m .5621 .33274 L .58925 .33663 L p
1 g
F P
s
P
p
.002 w
.5621 .33274 m .55352 .30307 L .5269 .30851 L p
1 g
F P
s
P
p
.002 w
.35481 .40088 m .37163 .42676 L .38711 .40363 L p
1 g
F P
s
P
p
.002 w
.38711 .40363 m .37438 .38354 L .35481 .40088 L p
1 g
F P
s
P
p
.002 w
.39739 .33419 m .39397 .35134 L .42 .34535 L p
1 g
F P
s
P
p
.002 w
.42 .34535 m .42179 .33674 L .39739 .33419 L p
1 g
F P
s
P
p
.002 w
.34994 .47399 m .38567 .49799 L .39008 .47164 L p
1 g
F P
s
P
p
.002 w
.39008 .47164 m .35912 .45037 L .34994 .47399 L p
1 g
F P
s
P
p
.002 w
.55567 .55628 m .6048 .52332 L .59179 .50473 L p
1 g
F P
s
P
p
.002 w
.62861 .46276 m .59179 .50473 L .6048 .52332 L p
1 g
F P
s
P
p
.002 w
.61464 .34297 m .61009 .38655 L .63223 .39971 L p
1 g
F P
s
P
p
.002 w
.61009 .38655 m .61464 .34297 L .58925 .33663 L p
1 g
F P
s
P
p
.002 w
.48961 .30438 m .47472 .29626 L .46053 .31772 L p
1 g
F P
s
P
p
.002 w
.4516 .31641 m .46053 .31772 L .47472 .29626 L p
1 g
F P
s
P
p
.002 w
.37008 .35946 m .37438 .38354 L .39672 .36769 L p
1 g
F P
s
P
p
.002 w
.39672 .36769 m .39397 .35134 L .37008 .35946 L p
1 g
F P
s
P
p
.002 w
.40668 .31816 m .39739 .33419 L .42179 .33674 L p
1 g
F P
s
P
p
.002 w
.42179 .33674 m .42648 .32874 L .40668 .31816 L p
1 g
F P
s
P
p
.002 w
.47472 .29626 m .45695 .29352 L .4516 .31641 L p
1 g
F P
s
P
p
.002 w
.44227 .31797 m .4516 .31641 L .45695 .29352 L p
1 g
F P
s
P
p
.002 w
.3854 .54664 m .43668 .55871 L .43193 .53483 L p
1 g
F P
s
P
p
.002 w
.43193 .53483 m .38407 .52318 L .3854 .54664 L p
1 g
F P
s
P
p
.002 w
.44319 .57996 m .50021 .57581 L .49144 .55498 L p
1 g
F P
s
P
p
.002 w
.49144 .55498 m .43668 .55871 L .44319 .57996 L p
1 g
F P
s
P
p
.002 w
.51179 .2899 m .5269 .30851 L .55352 .30307 L p
1 g
F P
s
P
p
.002 w
.5269 .30851 m .51179 .2899 L .48961 .30438 L p
1 g
F P
s
P
p
.002 w
.42084 .30511 m .40668 .31816 L .42648 .32874 L p
1 g
F P
s
P
p
.002 w
.42648 .32874 m .43357 .32224 L .42084 .30511 L p
1 g
F P
s
P
p
.002 w
.45695 .29352 m .43827 .29658 L .44227 .31797 L p
1 g
F P
s
P
p
.002 w
.43357 .32224 m .44227 .31797 L .43827 .29658 L p
1 g
F P
s
P
p
.002 w
.47472 .29626 m .48961 .30438 L .51179 .2899 L p
1 g
F P
s
P
p
.002 w
.43827 .29658 m .42084 .30511 L .43357 .32224 L p
1 g
F P
s
P
p
.002 w
.3385 .4194 m .35912 .45037 L .37163 .42676 L p
1 g
F P
s
P
p
.002 w
.37163 .42676 m .35481 .40088 L .3385 .4194 L p
1 g
F P
s
P
p
.002 w
.57932 .30076 m .58925 .33663 L .61464 .34297 L p
1 g
F P
s
P
p
.002 w
.58925 .33663 m .57932 .30076 L .55352 .30307 L p
1 g
F P
s
P
p
.002 w
.37495 .33402 m .37008 .35946 L .39397 .35134 L p
1 g
F P
s
P
p
.002 w
.39397 .35134 m .39739 .33419 L .37495 .33402 L p
1 g
F P
s
P
p
.002 w
.6048 .52332 m .64332 .47973 L .62861 .46276 L p
1 g
F P
s
P
p
.002 w
.65155 .41398 m .62861 .46276 L .64332 .47973 L p
1 g
F P
s
P
p
.002 w
.62861 .46276 m .65155 .41398 L .63223 .39971 L p
1 g
F P
s
P
p
.002 w
.34441 .49709 m .38407 .52318 L .38567 .49799 L p
1 g
F P
s
P
p
.002 w
.38567 .49799 m .34994 .47399 L .34441 .49709 L p
1 g
F P
s
P
p
.002 w
.34891 .36962 m .35481 .40088 L .37438 .38354 L p
1 g
F P
s
P
p
.002 w
.37438 .38354 m .37008 .35946 L .34891 .36962 L p
1 g
F P
s
P
p
.002 w
.63769 .35169 m .63223 .39971 L .65155 .41398 L p
1 g
F P
s
P
p
.002 w
.63223 .39971 m .63769 .35169 L .61464 .34297 L p
1 g
F P
s
P
p
.002 w
.51179 .2899 m .4899 .27769 L .47472 .29626 L p
1 g
F P
s
P
p
.002 w
.45695 .29352 m .47472 .29626 L .4899 .27769 L p
1 g
F P
s
P
p
.002 w
.6048 .52332 m .55567 .55628 L .56556 .57359 L p
1 g
F P
s
P
p
.002 w
.50924 .59355 m .56556 .57359 L .55567 .55628 L p
1 g
F P
s
P
p
.002 w
.55567 .55628 m .50021 .57581 L .50924 .59355 L p
1 g
F P
s
P
p
.002 w
.53417 .27868 m .55352 .30307 L .57932 .30076 L p
1 g
F P
s
P
p
.002 w
.55352 .30307 m .53417 .27868 L .51179 .2899 L p
1 g
F P
s
P
p
.002 w
.56556 .57359 m .61553 .54012 L .6048 .52332 L p
1 g
F P
s
P
p
.002 w
.64332 .47973 m .6048 .52332 L .61553 .54012 L p
1 g
F P
s
P
p
.002 w
.38866 .31013 m .37495 .33402 L .39739 .33419 L p
1 g
F P
s
P
p
.002 w
.39739 .33419 m .40668 .31816 L .38866 .31013 L p
1 g
F P
s
P
p
.002 w
.4899 .27769 m .51179 .2899 L .53417 .27868 L p
1 g
F P
s
P
p
.002 w
.32595 .43871 m .34994 .47399 L .35912 .45037 L p
1 g
F P
s
P
p
.002 w
.35912 .45037 m .3385 .4194 L .32595 .43871 L p
1 g
F P
s
P
p
.002 w
.38976 .56777 m .44319 .57996 L .43668 .55871 L p
1 g
F P
s
P
p
.002 w
.43668 .55871 m .3854 .54664 L .38976 .56777 L p
1 g
F P
s
P
p
.002 w
.4899 .27769 m .46355 .27348 L .45695 .29352 L p
1 g
F P
s
P
p
.002 w
.43827 .29658 m .45695 .29352 L .46355 .27348 L p
1 g
F P
s
P
p
.002 w
.60369 .30174 m .61464 .34297 L .63769 .35169 L p
1 g
F P
s
P
p
.002 w
.61464 .34297 m .60369 .30174 L .57932 .30076 L p
1 g
F P
s
P
p
.002 w
.45138 .59801 m .50924 .59355 L .50021 .57581 L p
1 g
F P
s
P
p
.002 w
.50021 .57581 m .44319 .57996 L .45138 .59801 L p
1 g
F P
s
P
p
.002 w
.40974 .29065 m .38866 .31013 L .40668 .31816 L p
1 g
F P
s
P
p
.002 w
.40668 .31816 m .42084 .30511 L .40974 .29065 L p
1 g
F P
s
P
p
.002 w
.46355 .27348 m .43574 .27794 L .43827 .29658 L p
1 g
F P
s
P
p
.002 w
.42084 .30511 m .43827 .29658 L .43574 .27794 L p
1 g
F P
s
P
p
.002 w
.35505 .33636 m .34891 .36962 L .37008 .35946 L p
1 g
F P
s
P
p
.002 w
.37008 .35946 m .37495 .33402 L .35505 .33636 L p
1 g
F P
s
P
p
.002 w
.33105 .38167 m .3385 .4194 L .35481 .40088 L p
1 g
F P
s
P
p
.002 w
.35481 .40088 m .34891 .36962 L .33105 .38167 L p
1 g
F P
s
P
p
.002 w
.43574 .27794 m .40974 .29065 L .42084 .30511 L p
1 g
F P
s
P
p
.002 w
.3428 .51912 m .3854 .54664 L .38407 .52318 L p
1 g
F P
s
P
p
.002 w
.38407 .52318 m .34441 .49709 L .3428 .51912 L p
1 g
F P
s
P
p
.002 w
.61553 .54012 m .65479 .49595 L .64332 .47973 L p
1 g
F P
s
P
p
.002 w
.6675 .42909 m .64332 .47973 L .65479 .49595 L p
1 g
F P
s
P
p
.002 w
.64332 .47973 m .6675 .42909 L .65155 .41398 L p
1 g
F P
s
P
p
.002 w
.55626 .27109 m .57932 .30076 L .60369 .30174 L p
1 g
F P
s
P
p
.002 w
.57932 .30076 m .55626 .27109 L .53417 .27868 L p
1 g
F P
s
P
p
.002 w
.65781 .3627 m .65155 .41398 L .6675 .42909 L p
1 g
F P
s
P
p
.002 w
.65155 .41398 m .65781 .3627 L .63769 .35169 L p
1 g
F P
s
P
p
.002 w
.53417 .27868 m .50578 .26254 L .4899 .27769 L p
1 g
F P
s
P
p
.002 w
.46355 .27348 m .4899 .27769 L .50578 .26254 L p
1 g
F P
s
P
p
.002 w
.50578 .26254 m .53417 .27868 L .55626 .27109 L p
1 g
F P
s
P
p
.002 w
.31762 .4584 m .34441 .49709 L .34994 .47399 L p
1 g
F P
s
P
p
.002 w
.34994 .47399 m .32595 .43871 L .31762 .4584 L p
1 g
F P
s
P
p
.002 w
.61553 .54012 m .56556 .57359 L .5741 .58779 L p
1 g
F P
s
P
p
.002 w
.51835 .60764 m .5741 .58779 L .56556 .57359 L p
1 g
F P
s
P
p
.002 w
.56556 .57359 m .50924 .59355 L .51835 .60764 L p
1 g
F P
s
P
p
.002 w
.37291 .30497 m .35505 .33636 L .37495 .33402 L p
1 g
F P
s
P
p
.002 w
.37495 .33402 m .38866 .31013 L .37291 .30497 L p
1 g
F P
s
P
p
.002 w
.62605 .30611 m .63769 .35169 L .65781 .3627 L p
1 g
F P
s
P
p
.002 w
.63769 .35169 m .62605 .30611 L .60369 .30174 L p
1 g
F P
s
P
p
.002 w
.5741 .58779 m .62362 .55465 L .61553 .54012 L p
1 g
F P
s
P
p
.002 w
.65479 .49595 m .61553 .54012 L .62362 .55465 L p
1 g
F P
s
P
p
.002 w
.3972 .58596 m .45138 .59801 L .44319 .57996 L p
1 g
F P
s
P
p
.002 w
.44319 .57996 m .38976 .56777 L .3972 .58596 L p
1 g
F P
s
P
p
.002 w
.50578 .26254 m .47134 .25685 L .46355 .27348 L p
1 g
F P
s
P
p
.002 w
.43574 .27794 m .46355 .27348 L .47134 .25685 L p
1 g
F P
s
P
p
.002 w
.31709 .39542 m .32595 .43871 L .3385 .4194 L p
1 g
F P
s
P
p
.002 w
.3385 .4194 m .33105 .38167 L .31709 .39542 L p
1 g
F P
s
P
p
.002 w
.33829 .34127 m .33105 .38167 L .34891 .36962 L p
1 g
F P
s
P
p
.002 w
.34891 .36962 m .35505 .33636 L .33829 .34127 L p
1 g
F P
s
P
p
.002 w
.34534 .5395 m .38976 .56777 L .3854 .54664 L p
1 g
F P
s
P
p
.002 w
.3854 .54664 m .3428 .51912 L .34534 .5395 L p
1 g
F P
s
P
p
.002 w
.46116 .61225 m .51835 .60764 L .50924 .59355 L p
1 g
F P
s
P
p
.002 w
.50924 .59355 m .45138 .59801 L .46116 .61225 L p
1 g
F P
s
P
p
.002 w
.40059 .27932 m .37291 .30497 L .38866 .31013 L p
1 g
F P
s
P
p
.002 w
.38866 .31013 m .40974 .29065 L .40059 .27932 L p
1 g
F P
s
P
p
.002 w
.57753 .26746 m .60369 .30174 L .62605 .30611 L p
1 g
F P
s
P
p
.002 w
.60369 .30174 m .57753 .26746 L .55626 .27109 L p
1 g
F P
s
P
p
.002 w
.47134 .25685 m .4348 .26262 L .43574 .27794 L p
1 g
F P
s
P
p
.002 w
.40974 .29065 m .43574 .27794 L .4348 .26262 L p
1 g
F P
s
P
p
.002 w
.4348 .26262 m .40059 .27932 L .40974 .29065 L p
1 g
F P
s
P
p
.002 w
.65479 .49595 m .67957 .44472 L .6675 .42909 L p
1 g
F P
s
P
p
.002 w
.67438 .37584 m .6675 .42909 L .67957 .44472 L p
1 g
F P
s
P
p
.002 w
.6675 .42909 m .67438 .37584 L .65781 .3627 L p
1 g
F P
s
P
p
.002 w
.62362 .55465 m .6626 .51103 L .65479 .49595 L p
1 g
F P
s
P
p
.002 w
.67957 .44472 m .65479 .49595 L .6626 .51103 L p
1 g
F P
s
P
p
.002 w
.55626 .27109 m .52203 .25131 L .50578 .26254 L p
1 g
F P
s
P
p
.002 w
.47134 .25685 m .50578 .26254 L .52203 .25131 L p
1 g
F P
s
P
p
.002 w
.52203 .25131 m .55626 .27109 L .57753 .26746 L p
1 g
F P
s
P
p
.002 w
.31392 .47799 m .3428 .51912 L .34441 .49709 L p
1 g
F P
s
P
p
.002 w
.34441 .49709 m .31762 .4584 L .31392 .47799 L p
1 g
F P
s
P
p
.002 w
.64575 .31393 m .65781 .3627 L .67438 .37584 L p
1 g
F P
s
P
p
.002 w
.65781 .3627 m .64575 .31393 L .62605 .30611 L p
1 g
F P
s
P
p
.002 w
.35994 .30297 m .33829 .34127 L .35505 .33636 L p
1 g
F P
s
P
p
.002 w
.35505 .33636 m .37291 .30497 L .35994 .30297 L p
1 g
F P
s
P
p
.002 w
.62362 .55465 m .5741 .58779 L .58101 .59837 L p
1 g
F P
s
P
p
.002 w
.52733 .61756 m .58101 .59837 L .5741 .58779 L p
1 g
F P
s
P
p
.002 w
.5741 .58779 m .51835 .60764 L .52733 .61756 L p
1 g
F P
s
P
p
.002 w
.30757 .41061 m .31762 .4584 L .32595 .43871 L p
1 g
F P
s
P
p
.002 w
.32595 .43871 m .31709 .39542 L .30757 .41061 L p
1 g
F P
s
P
p
.002 w
.40768 .60059 m .46116 .61225 L .45138 .59801 L p
1 g
F P
s
P
p
.002 w
.45138 .59801 m .3972 .58596 L .40768 .60059 L p
1 g
F P
s
P
p
.002 w
.58101 .59837 m .62875 .56645 L .62362 .55465 L p
1 g
F P
s
P
p
.002 w
.6626 .51103 m .62362 .55465 L .62875 .56645 L p
1 g
F P
s
P
p
.002 w
.32525 .34878 m .31709 .39542 L .33105 .38167 L p
1 g
F P
s
P
p
.002 w
.33105 .38167 m .33829 .34127 L .32525 .34878 L p
1 g
F P
s
P
p
.002 w
.52203 .25131 m .48017 .24423 L .47134 .25685 L p
1 g
F P
s
P
p
.002 w
.4348 .26262 m .47134 .25685 L .48017 .24423 L p
1 g
F P
s
P
p
.002 w
.35217 .55762 m .3972 .58596 L .38976 .56777 L p
1 g
F P
s
P
p
.002 w
.38976 .56777 m .34534 .5395 L .35217 .55762 L p
1 g
F P
s
P
p
.002 w
.59744 .26807 m .62605 .30611 L .64575 .31393 L p
1 g
F P
s
P
p
.002 w
.62605 .30611 m .59744 .26807 L .57753 .26746 L p
1 g
F P
s
P
p
.002 w
.47236 .62212 m .52733 .61756 L .51835 .60764 L p
1 g
F P
s
P
p
.002 w
.51835 .60764 m .46116 .61225 L .47236 .62212 L p
1 g
F P
s
P
p
.002 w
.39373 .27159 m .35994 .30297 L .37291 .30497 L p
1 g
F P
s
P
p
.002 w
.37291 .30497 m .40059 .27932 L .39373 .27159 L p
1 g
F P
s
P
p
.002 w
.48017 .24423 m .43556 .25118 L .4348 .26262 L p
1 g
F P
s
P
p
.002 w
.40059 .27932 m .4348 .26262 L .43556 .25118 L p
1 g
F P
s
P
p
.002 w
.6626 .51103 m .68727 .46053 L .67957 .44472 L p
1 g
F P
s
P
p
.002 w
.68683 .39088 m .67957 .44472 L .68727 .46053 L p
1 g
F P
s
P
p
.002 w
.67957 .44472 m .68683 .39088 L .67438 .37584 L p
1 g
F P
s
P
p
.002 w
.31519 .49698 m .34534 .5395 L .3428 .51912 L p
1 g
F P
s
P
p
.002 w
.3428 .51912 m .31392 .47799 L .31519 .49698 L p
1 g
F P
s
P
p
.002 w
.53826 .24447 m .57753 .26746 L .59744 .26807 L p
1 g
F P
s
P
p
.002 w
.57753 .26746 m .53826 .24447 L .52203 .25131 L p
1 g
F P
s
P
p
.002 w
.48017 .24423 m .52203 .25131 L .53826 .24447 L p
1 g
F P
s
P
p
.002 w
.43556 .25118 m .39373 .27159 L .40059 .27932 L p
1 g
F P
s
P
p
.002 w
.62875 .56645 m .66634 .52453 L .6626 .51103 L p
1 g
F P
s
P
p
.002 w
.68727 .46053 m .6626 .51103 L .66634 .52453 L p
1 g
F P
s
P
p
.002 w
.66218 .32516 m .67438 .37584 L .68683 .39088 L p
1 g
F P
s
P
p
.002 w
.67438 .37584 m .66218 .32516 L .64575 .31393 L p
1 g
F P
s
P
p
.002 w
.30299 .42691 m .31392 .47799 L .31762 .4584 L p
1 g
F P
s
P
p
.002 w
.31762 .4584 m .30757 .41061 L .30299 .42691 L p
1 g
F P
s
P
p
.002 w
.35026 .30436 m .32525 .34878 L .33829 .34127 L p
1 g
F P
s
P
p
.002 w
.33829 .34127 m .35994 .30297 L .35026 .30436 L p
1 g
F P
s
P
p
.002 w
.4211 .61108 m .47236 .62212 L .46116 .61225 L p
1 g
F P
s
P
p
.002 w
.46116 .61225 m .40768 .60059 L .4211 .61108 L p
1 g
F P
s
P
p
.002 w
.3165 .35883 m .30757 .41061 L .31709 .39542 L p
1 g
F P
s
P
p
.002 w
.31709 .39542 m .32525 .34878 L .3165 .35883 L p
1 g
F P
s
P
p
.002 w
.36334 .57287 m .40768 .60059 L .3972 .58596 L p
1 g
F P
s
P
p
.002 w
.3972 .58596 m .35217 .55762 L .36334 .57287 L p
1 g
F P
s
P
p
.002 w
.62875 .56645 m .58101 .59837 L .58601 .60484 L p
1 g
F P
s
P
p
.002 w
.53594 .62279 m .58601 .60484 L .58101 .59837 L p
1 g
F P
s
P
p
.002 w
.58101 .59837 m .52733 .61756 L .53594 .62279 L p
1 g
F P
s
P
p
.002 w
.6154 .27313 m .64575 .31393 L .66218 .32516 L p
1 g
F P
s
P
p
.002 w
.64575 .31393 m .6154 .27313 L .59744 .26807 L p
1 g
F P
s
P
p
.002 w
.58601 .60484 m .63059 .57505 L .62875 .56645 L p
1 g
F P
s
P
p
.002 w
.66634 .52453 m .62875 .56645 L .63059 .57505 L p
1 g
F P
s
P
p
.002 w
.53826 .24447 m .4899 .23616 L .48017 .24423 L p
1 g
F P
s
P
p
.002 w
.43556 .25118 m .48017 .24423 L .4899 .23616 L p
1 g
F P
s
P
p
.002 w
.48477 .6271 m .53594 .62279 L .52733 .61756 L p
1 g
F P
s
P
p
.002 w
.52733 .61756 m .47236 .62212 L .48477 .6271 L p
1 g
F P
s
P
p
.002 w
.32165 .5148 m .35217 .55762 L .34534 .5395 L p
1 g
F P
s
P
p
.002 w
.34534 .5395 m .31519 .49698 L .32165 .5148 L p
1 g
F P
s
P
p
.002 w
.55406 .24246 m .59744 .26807 L .6154 .27313 L p
1 g
F P
s
P
p
.002 w
.59744 .26807 m .55406 .24246 L .53826 .24447 L p
1 g
F P
s
P
p
.002 w
.3895 .26789 m .35026 .30436 L .35994 .30297 L p
1 g
F P
s
P
p
.002 w
.35994 .30297 m .39373 .27159 L .3895 .26789 L p
1 g
F P
s
P
p
.002 w
.66634 .52453 m .69015 .47612 L .68727 .46053 L p
1 g
F P
s
P
p
.002 w
.69463 .40755 m .68727 .46053 L .69015 .47612 L p
1 g
F P
s
P
p
.002 w
.68727 .46053 m .69463 .40755 L .68683 .39088 L p
1 g
F P
s
P
p
.002 w
.4899 .23616 m .53826 .24447 L .55406 .24246 L p
1 g
F P
s
P
p
.002 w
.4899 .23616 m .43813 .24417 L .43556 .25118 L p
1 g
F P
s
P
p
.002 w
.39373 .27159 m .43556 .25118 L .43813 .24417 L p
1 g
F P
s
P
p
.002 w
.67473 .33968 m .68683 .39088 L .69463 .40755 L p
1 g
F P
s
P
p
.002 w
.68683 .39088 m .67473 .33968 L .66218 .32516 L p
1 g
F P
s
P
p
.002 w
.63059 .57505 m .66568 .53601 L .66634 .52453 L p
1 g
F P
s
P
p
.002 w
.69015 .47612 m .66634 .52453 L .66568 .53601 L p
1 g
F P
s
P
p
.002 w
.43813 .24417 m .3895 .26789 L .39373 .27159 L p
1 g
F P
s
P
p
.002 w
.30377 .44394 m .31519 .49698 L .31392 .47799 L p
1 g
F P
s
P
p
.002 w
.31392 .47799 m .30299 .42691 L .30377 .44394 L p
1 g
F P
s
P
p
.002 w
.34433 .30933 m .3165 .35883 L .32525 .34878 L p
1 g
F P
s
P
p
.002 w
.32525 .34878 m .35026 .30436 L .34433 .30933 L p
1 g
F P
s
P
p
.002 w
.63082 .28272 m .66218 .32516 L .67473 .33968 L p
1 g
F P
s
P
p
.002 w
.66218 .32516 m .63082 .28272 L .6154 .27313 L p
1 g
F P
s
P
p
.002 w
.31255 .37132 m .30299 .42691 L .30757 .41061 L p
1 g
F P
s
P
p
.002 w
.30757 .41061 m .3165 .35883 L .31255 .37132 L p
1 g
F P
s
P
p
.002 w
.37877 .58467 m .4211 .61108 L .40768 .60059 L p
1 g
F P
s
P
p
.002 w
.40768 .60059 m .36334 .57287 L .37877 .58467 L p
1 g
F P
s
P
p
.002 w
.43724 .61691 m .48477 .6271 L .47236 .62212 L p
1 g
F P
s
P
p
.002 w
.47236 .62212 m .4211 .61108 L .43724 .61691 L p
1 g
F P
s
P
p
.002 w
.63059 .57505 m .58601 .60484 L .58885 .60676 L p
1 g
F P
s
P
p
.002 w
.54391 .62288 m .58885 .60676 L .58601 .60484 L p
1 g
F P
s
P
p
.002 w
.58601 .60484 m .53594 .62279 L .54391 .62288 L p
1 g
F P
s
P
p
.002 w
.55406 .24246 m .50031 .23314 L .4899 .23616 L p
1 g
F P
s
P
p
.002 w
.43813 .24417 m .4899 .23616 L .50031 .23314 L p
1 g
F P
s
P
p
.002 w
.58885 .60676 m .62888 .58001 L .63059 .57505 L p
1 g
F P
s
P
p
.002 w
.66568 .53601 m .63059 .57505 L .62888 .58001 L p
1 g
F P
s
P
p
.002 w
.33341 .53088 m .36334 .57287 L .35217 .55762 L p
1 g
F P
s
P
p
.002 w
.35217 .55762 m .32165 .5148 L .33341 .53088 L p
1 g
F P
s
P
p
.002 w
.6154 .27313 m .56898 .24559 L .55406 .24246 L p
1 g
F P
s
P
p
.002 w
.56898 .24559 m .6154 .27313 L .63082 .28272 L p
1 g
F P
s
P
p
.002 w
.66568 .53601 m .68786 .49105 L .69015 .47612 L p
1 g
F P
s
P
p
.002 w
.69015 .47612 m .69729 .42547 L .69463 .40755 L p
1 g
F P
s
P
p
.002 w
.69729 .42547 m .69015 .47612 L .68786 .49105 L p
1 g
F P
s
P
p
.002 w
.49811 .62675 m .54391 .62288 L .53594 .62279 L p
1 g
F P
s
P
p
.002 w
.53594 .62279 m .48477 .6271 L .49811 .62675 L p
1 g
F P
s
P
p
.002 w
.50031 .23314 m .55406 .24246 L .56898 .24559 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52031 .62431 L
s
P
p
.004 w
.52037 .62487 m
.52045 .62573 L
s
P
p
.004 w
.52045 .62573 m
.53094 .72583 L
s
P
p
.002 w
.38817 .26858 m .34433 .30933 L .35026 .30436 L p
1 g
F P
s
P
p
.002 w
.35026 .30436 m .3895 .26789 L .38817 .26858 L p
1 g
F P
s
P
p
.002 w
.69463 .40755 m .68283 .35727 L .67473 .33968 L p
1 g
F P
s
P
p
.002 w
.68283 .35727 m .69463 .40755 L .69729 .42547 L p
1 g
F P
s
P
p
.002 w
.50031 .23314 m .44254 .24206 L .43813 .24417 L p
1 g
F P
s
P
p
.002 w
.3895 .26789 m .43813 .24417 L .44254 .24206 L p
1 g
F P
s
P
p
.002 w
.31018 .46122 m .32165 .5148 L .31519 .49698 L p
1 g
F P
s
P
p
.002 w
.31519 .49698 m .30377 .44394 L .31018 .46122 L p
1 g
F P
s
P
p
.002 w
.62888 .58001 m .66036 .54502 L .66568 .53601 L p
1 g
F P
s
P
p
.002 w
.68786 .49105 m .66568 .53601 L .66036 .54502 L p
1 g
F P
s
P
p
.002 w
.44254 .24206 m .38817 .26858 L .3895 .26789 L p
1 g
F P
s
P
p
.002 w
.67473 .33968 m .64312 .29685 L .63082 .28272 L p
1 g
F P
s
P
p
.002 w
.64312 .29685 m .67473 .33968 L .68283 .35727 L p
1 g
F P
s
P
p
.002 w
.34258 .31797 m .31255 .37132 L .3165 .35883 L p
1 g
F P
s
P
p
.002 w
.3165 .35883 m .34433 .30933 L .34258 .31797 L p
1 g
F P
s
P
p
.002 w
.3138 .386 m .30377 .44394 L .30299 .42691 L p
1 g
F P
s
P
p
.002 w
.30299 .42691 m .31255 .37132 L .3138 .386 L p
1 g
F P
s
P
p
.002 w
.39821 .59247 m .43724 .61691 L .4211 .61108 L p
1 g
F P
s
P
p
.002 w
.4211 .61108 m .37877 .58467 L .39821 .59247 L p
1 g
F P
s
P
p
.002 w
.45578 .61762 m .49811 .62675 L .48477 .6271 L p
1 g
F P
s
P
p
.002 w
.48477 .6271 m .43724 .61691 L .45578 .61762 L p
1 g
F P
s
P
p
.002 w
.35039 .54461 m .37877 .58467 L .36334 .57287 L p
1 g
F P
s
P
p
.002 w
.36334 .57287 m .33341 .53088 L .35039 .54461 L p
1 g
F P
s
P
p
.002 w
.58253 .25409 m .63082 .28272 L .64312 .29685 L p
1 g
F P
s
P
p
.002 w
.63082 .28272 m .58253 .25409 L .56898 .24559 L p
1 g
F P
s
P
p
.002 w
.56898 .24559 m .51115 .23557 L .50031 .23314 L p
1 g
F P
s
P
p
.002 w
.44254 .24206 m .50031 .23314 L .51115 .23557 L p
1 g
F P
s
P
p
.002 w
.62888 .58001 m .58885 .60676 L .58929 .60378 L p
1 g
F P
s
P
p
.002 w
.55098 .61751 m .58929 .60378 L .58885 .60676 L p
1 g
F P
s
P
p
.002 w
.58885 .60676 m .54391 .62288 L .55098 .61751 L p
1 g
F P
s
P
p
.002 w
.58929 .60378 m .62345 .58096 L .62888 .58001 L p
1 g
F P
s
P
p
.002 w
.66036 .54502 m .62888 .58001 L .62345 .58096 L p
1 g
F P
s
P
p
.002 w
.66036 .54502 m .68016 .50486 L .68786 .49105 L p
1 g
F P
s
P
p
.002 w
.69447 .4442 m .68786 .49105 L .68016 .50486 L p
1 g
F P
s
P
p
.002 w
.68786 .49105 m .69447 .4442 L .69729 .42547 L p
1 g
F P
s
P
p
.002 w
.51115 .23557 m .56898 .24559 L .58253 .25409 L p
1 g
F P
s
P
p
.002 w
.68602 .37757 m .69729 .42547 L .69447 .4442 L p
1 g
F P
s
P
p
.002 w
.69729 .42547 m .68602 .37757 L .68283 .35727 L p
1 g
F P
s
P
p
.002 w
.51205 .62076 m .55098 .61751 L .54391 .62288 L p
1 g
F P
s
P
p
.002 w
.54391 .62288 m .49811 .62675 L .51205 .62076 L p
1 g
F P
s
P
p
.002 w
.38999 .27395 m .34258 .31797 L .34433 .30933 L p
1 g
F P
s
P
p
.002 w
.34433 .30933 m .38817 .26858 L .38999 .27395 L p
1 g
F P
s
P
p
.002 w
.32235 .47824 m .33341 .53088 L .32165 .5148 L p
1 g
F P
s
P
p
.002 w
.32165 .5148 m .31018 .46122 L .32235 .47824 L p
1 g
F P
s
P
p
.002 w
.62345 .58096 m .65023 .55114 L .66036 .54502 L p
1 g
F P
s
P
p
.002 w
.68016 .50486 m .66036 .54502 L .65023 .55114 L p
1 g
F P
s
P
p
.002 w
.51115 .23557 m .44879 .24525 L .44254 .24206 L p
1 g
F P
s
P
p
.002 w
.38817 .26858 m .44254 .24206 L .44879 .24525 L p
1 g
F P
s
P
p
.002 w
.65175 .31532 m .68283 .35727 L .68602 .37757 L p
1 g
F P
s
P
p
.002 w
.68283 .35727 m .65175 .31532 L .64312 .29685 L p
1 g
F P
s
P
p
.002 w
.44879 .24525 m .38999 .27395 L .38817 .26858 L p
1 g
F P
s
P
p
.002 w
.32054 .40256 m .31018 .46122 L .30377 .44394 L p
1 g
F P
s
P
p
.002 w
.30377 .44394 m .3138 .386 L .32054 .40256 L p
1 g
F P
s
P
p
.002 w
.42128 .59581 m .45578 .61762 L .43724 .61691 L p
1 g
F P
s
P
p
.002 w
.43724 .61691 m .39821 .59247 L .42128 .59581 L p
1 g
F P
s
P
p
.002 w
.34534 .33024 m .3138 .386 L .31255 .37132 L p
1 g
F P
s
P
p
.002 w
.31255 .37132 m .34258 .31797 L .34534 .33024 L p
1 g
F P
s
P
p
.002 w
.47628 .61292 m .51205 .62076 L .49811 .62675 L p
1 g
F P
s
P
p
.002 w
.49811 .62675 m .45578 .61762 L .47628 .61292 L p
1 g
F P
s
P
p
.002 w
.37231 .55546 m .39821 .59247 L .37877 .58467 L p
1 g
F P
s
P
p
.002 w
.37877 .58467 m .35039 .54461 L .37231 .55546 L p
1 g
F P
s
P
p
.002 w
.59421 .26801 m .64312 .29685 L .65175 .31532 L p
1 g
F P
s
P
p
.002 w
.64312 .29685 m .59421 .26801 L .58253 .25409 L p
1 g
F P
s
P
p
.002 w
.58253 .25409 m .52212 .24374 L .51115 .23557 L p
1 g
F P
s
P
p
.002 w
.44879 .24525 m .51115 .23557 L .52212 .24374 L p
1 g
F P
s
P
p
.002 w
.68016 .50486 m .68593 .4632 L .69447 .4442 L p
1 g
F P
s
P
p
.002 w
.68393 .4001 m .69447 .4442 L .68593 .4632 L p
1 g
F P
s
P
p
.002 w
.69447 .4442 m .68393 .4001 L .68602 .37757 L p
1 g
F P
s
P
p
.002 w
.62345 .58096 m .58929 .60378 L .58717 .59565 L p
1 g
F P
s
P
p
.002 w
.55686 .60648 m .58717 .59565 L .58929 .60378 L p
1 g
F P
s
P
p
.002 w
.58929 .60378 m .55098 .61751 L .55686 .60648 L p
1 g
F P
s
P
p
.002 w
.65023 .55114 m .66697 .51705 L .68016 .50486 L p
1 g
F P
s
P
p
.002 w
.68593 .4632 m .68016 .50486 L .66697 .51705 L p
1 g
F P
s
P
p
.002 w
.52212 .24374 m .58253 .25409 L .59421 .26801 L p
1 g
F P
s
P
p
.002 w
.58717 .59565 m .6142 .57758 L .62345 .58096 L p
1 g
F P
s
P
p
.002 w
.65023 .55114 m .62345 .58096 L .6142 .57758 L p
1 g
F P
s
P
p
.002 w
.34017 .49443 m .35039 .54461 L .33341 .53088 L p
1 g
F P
s
P
p
.002 w
.33341 .53088 m .32235 .47824 L .34017 .49443 L p
1 g
F P
s
P
p
.002 w
.52618 .60896 m .55686 .60648 L .55098 .61751 L p
1 g
F P
s
P
p
.002 w
.55098 .61751 m .51205 .62076 L .52618 .60896 L p
1 g
F P
s
P
p
.002 w
.39511 .28412 m .34534 .33024 L .34258 .31797 L p
1 g
F P
s
P
p
.002 w
.34258 .31797 m .38999 .27395 L .39511 .28412 L p
1 g
F P
s
P
p
.002 w
.65626 .33779 m .68602 .37757 L .68393 .4001 L p
1 g
F P
s
P
p
.002 w
.68602 .37757 m .65626 .33779 L .65175 .31532 L p
1 g
F P
s
P
p
.002 w
.6142 .57758 m .63532 .554 L .65023 .55114 L p
1 g
F P
s
P
p
.002 w
.66697 .51705 m .65023 .55114 L .63532 .554 L p
1 g
F P
s
P
p
.002 w
.33286 .42055 m .32235 .47824 L .31018 .46122 L p
1 g
F P
s
P
p
.002 w
.31018 .46122 m .32054 .40256 L .33286 .42055 L p
1 g
F P
s
P
p
.002 w
.44738 .59437 m .47628 .61292 L .45578 .61762 L p
1 g
F P
s
P
p
.002 w
.45578 .61762 m .42128 .59581 L .44738 .59437 L p
1 g
F P
s
P
p
.002 w
.52212 .24374 m .4568 .25398 L .44879 .24525 L p
1 g
F P
s
P
p
.002 w
.38999 .27395 m .44879 .24525 L .4568 .25398 L p
1 g
F P
s
P
p
.002 w
.35278 .34598 m .32054 .40256 L .3138 .386 L p
1 g
F P
s
P
p
.002 w
.3138 .386 m .34534 .33024 L .35278 .34598 L p
1 g
F P
s
P
p
.002 w
.4568 .25398 m .39511 .28412 L .38999 .27395 L p
1 g
F P
s
P
p
.002 w
.39867 .56291 m .42128 .59581 L .39821 .59247 L p
1 g
F P
s
P
p
.002 w
.39821 .59247 m .37231 .55546 L .39867 .56291 L p
1 g
F P
s
P
p
.002 w
.49817 .60268 m .52618 .60896 L .51205 .62076 L p
1 g
F P
s
P
p
.002 w
.51205 .62076 m .47628 .61292 L .49817 .60268 L p
1 g
F P
s
P
p
.002 w
.60356 .28721 m .65175 .31532 L .65626 .33779 L p
1 g
F P
s
P
p
.002 w
.65175 .31532 m .60356 .28721 L .59421 .26801 L p
1 g
F P
s
P
p
.002 w
.66697 .51705 m .67167 .48189 L .68593 .4632 L p
1 g
F P
s
P
p
.002 w
.67637 .42424 m .68593 .4632 L .67167 .48189 L p
1 g
F P
s
P
p
.002 w
.68593 .4632 m .67637 .42424 L .68393 .4001 L p
1 g
F P
s
P
p
.002 w
.36332 .50918 m .37231 .55546 L .35039 .54461 L p
1 g
F P
s
P
p
.002 w
.35039 .54461 m .34017 .49443 L .36332 .50918 L p
1 g
F P
s
P
p
.002 w
.59421 .26801 m .53288 .25772 L .52212 .24374 L p
1 g
F P
s
P
p
.002 w
.4568 .25398 m .52212 .24374 L .53288 .25772 L p
1 g
F P
s
P
p
.002 w
.63532 .554 m .64838 .52715 L .66697 .51705 L p
1 g
F P
s
P
p
.002 w
.67167 .48189 m .66697 .51705 L .64838 .52715 L p
1 g
F P
s
P
p
.002 w
.53288 .25772 m .59421 .26801 L .60356 .28721 L p
1 g
F P
s
P
p
.002 w
.6142 .57758 m .58717 .59565 L .58239 .5823 L p
1 g
F P
s
P
p
.004 w
.59188 .58642 m
.60363 .60635 L
s
P
p
.002 w
.56131 .5898 m .58239 .5823 L .58717 .59565 L p
1 g
F P
s
P
p
.002 w
.58717 .59565 m .55686 .60648 L .56131 .5898 L p
1 g
F P
s
P
p
.002 w
.65627 .36371 m .68393 .4001 L .67637 .42424 L p
1 g
F P
s
P
p
.002 w
.68393 .4001 m .65627 .36371 L .65626 .33779 L p
1 g
F P
s
P
p
.002 w
.58239 .5823 m .60119 .56972 L .6142 .57758 L p
1 g
F P
s
P
p
.002 w
.63532 .554 m .6142 .57758 L .60119 .56972 L p
1 g
F P
s
P
p
.002 w
.54004 .59144 m .56131 .5898 L .55686 .60648 L p
1 g
F P
s
P
p
.002 w
.55686 .60648 m .52618 .60896 L .54004 .59144 L p
1 g
F P
s
P
p
.002 w
.40356 .29907 m .35278 .34598 L .34534 .33024 L p
1 g
F P
s
P
p
.002 w
.34534 .33024 m .39511 .28412 L .40356 .29907 L p
1 g
F P
s
P
p
.002 w
.35061 .43943 m .34017 .49443 L .32235 .47824 L p
1 g
F P
s
P
p
.002 w
.32235 .47824 m .33286 .42055 L .35061 .43943 L p
1 g
F P
s
P
p
.002 w
.47577 .58799 m .49817 .60268 L .47628 .61292 L p
1 g
F P
s
P
p
.002 w
.47628 .61292 m .44738 .59437 L .47577 .58799 L p
1 g
F P
s
P
p
.002 w
.60119 .56972 m .61582 .55331 L .63532 .554 L p
1 g
F P
s
P
p
.002 w
.64838 .52715 m .63532 .554 L .61582 .55331 L p
1 g
F P
s
P
p
.002 w
.42874 .56656 m .44738 .59437 L .42128 .59581 L p
1 g
F P
s
P
p
.002 w
.42128 .59581 m .39867 .56291 L .42874 .56656 L p
1 g
F P
s
P
p
.002 w
.53288 .25772 m .46642 .26832 L .4568 .25398 L p
1 g
F P
s
P
p
.002 w
.39511 .28412 m .4568 .25398 L .46642 .26832 L p
1 g
F P
s
P
p
.002 w
.61012 .31133 m .65626 .33779 L .65627 .36371 L p
1 g
F P
s
P
p
.002 w
.65626 .33779 m .61012 .31133 L .60356 .28721 L p
1 g
F P
s
P
p
.002 w
.36493 .36484 m .33286 .42055 L .32054 .40256 L p
1 g
F P
s
P
p
.002 w
.32054 .40256 m .35278 .34598 L .36493 .36484 L p
1 g
F P
s
P
p
.002 w
.52076 .58697 m .54004 .59144 L .52618 .60896 L p
1 g
F P
s
P
p
.002 w
.52618 .60896 m .49817 .60268 L .52076 .58697 L p
1 g
F P
s
P
p
.002 w
.46642 .26832 m .40356 .29907 L .39511 .28412 L p
1 g
F P
s
P
p
.002 w
.64838 .52715 m .65186 .49963 L .67167 .48189 L p
1 g
F P
s
P
p
.002 w
.66334 .44925 m .67167 .48189 L .65186 .49963 L p
1 g
F P
s
P
p
.002 w
.67167 .48189 m .66334 .44925 L .67637 .42424 L p
1 g
F P
s
P
p
.002 w
.3912 .52192 m .39867 .56291 L .37231 .55546 L p
1 g
F P
s
P
p
.002 w
.37231 .55546 m .36332 .50918 L .3912 .52192 L p
1 g
F P
s
P
p
.002 w
.61582 .55331 m .62475 .5347 L .64838 .52715 L p
1 g
F P
s
P
p
.002 w
.65186 .49963 m .64838 .52715 L .62475 .5347 L p
1 g
F P
s
P
p
.002 w
.54304 .27738 m .60356 .28721 L .61012 .31133 L p
1 g
F P
s
P
p
.002 w
.60356 .28721 m .54304 .27738 L .53288 .25772 L p
1 g
F P
s
P
p
.002 w
.6516 .39234 m .67637 .42424 L .66334 .44925 L p
1 g
F P
s
P
p
.002 w
.67637 .42424 m .6516 .39234 L .65627 .36371 L p
1 g
F P
s
P
p
.002 w
.46642 .26832 m .53288 .25772 L .54304 .27738 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.60119 .56972 m .58239 .5823 L .57495 .56387 L p
1 g
F P
s
P
p
.002 w
.56406 .56771 m .57495 .56387 L .58239 .5823 L p
1 g
F P
s
P
p
.002 w
.58239 .5823 m .56131 .5898 L .56406 .56771 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.52076 .58697 m .49817 .60268 L p
.50433 .58093 L 1 g
F P
s
P
p
.002 w
.51186 .58098 m .52076 .58697 L p
.50663 .58178 L 1 g
F P
s
P
p
.50433 .58093 m .51096 .58097 L .50663 .58178 L 1 g
F
P
p
.51096 .58097 m .51186 .58098 L .50663 .58178 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58097 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58097 L .51166 .58084 L 1 g
F
P
p
.53128 .57265 m .51166 .58084 L .521 .57792 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52076 .58697 m .51166 .58084 L p
.52696 .57606 L 1 g
F P
s
P
p
.002 w
.53541 .57342 m .52076 .58697 L p
.52585 .578 L 1 g
F P
s
P
p
.52585 .578 m .52696 .57606 L .5317 .57458 L 1 g
F
P
p
.52585 .578 m .5317 .57458 L .53541 .57342 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57458 L p
1 g
F P
s
P
p
.54854 .56129 m .5317 .57458 L .5384 .57065 L 1 g
F
P
p
.54854 .56129 m .5384 .57065 L .53927 .57013 L 1 g
F
P
p
.002 w
.54004 .59144 m .52076 .58697 L .53541 .57342 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53173 .57471 L p
1 g
F P
s
P
p
.002 w
.53173 .57471 m .53128 .57265 L p
.51769 .57962 L 1 g
F P
s
P
p
.51769 .57962 m .51111 .583 L .53173 .57471 L 1 g
F
P
p
.002 w
.53541 .57342 m .5384 .57065 L p
.53853 .57233 L 1 g
F P
s
P
p
.54004 .59144 m .53541 .57342 L .53853 .57233 L 1 g
F
P
p
.54004 .59144 m .5384 .57065 L .54308 .56781 L 1 g
F
P
p
.002 w
.55313 .5685 m .54004 .59144 L p
.54308 .56781 L 1 g
F P
s
P
p
.002 w
.54513 .56657 m .55313 .5685 L p
.54308 .56781 L 1 g
F P
s
P
p
.002 w
.55829 .5564 m .55313 .5685 L .54654 .56691 L p
1 g
F P
s
P
p
.002 w
.54654 .56691 m .54513 .56657 L p
.5493 .56334 L 1 g
F P
s
P
p
.54654 .56691 m .5493 .56334 L .55829 .5564 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5493 .56334 L p
1 g
F P
s
P
p
.56075 .54566 m .5493 .56334 L .55518 .55576 L 1 g
F
P
p
.002 w
.5493 .56334 m .54854 .56129 L p
.53388 .57526 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56167 .54739 m .56075 .54566 L p
.55518 .55576 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .54739 L p
1 g
F P
s
P
p
.002 w
.56496 .54073 m .56267 .54609 L p
.56183 .54697 L 1 g
F P
s
P
p
.002 w
.56356 .54236 m .56496 .54073 L p
.56183 .54697 L 1 g
F P
s
P
p
.002 w
.56267 .54609 m .55829 .5564 L p
.55104 .5611 L 1 g
F P
s
P
p
.56654 .52734 m .56167 .54739 L .56356 .54236 L 1 g
F
P
p
.002 w
.5639 .54145 m .56496 .54073 L .56356 .54236 L p
1 g
F P
s
P
p
.56654 .52734 m .56356 .54236 L .56398 .54123 L 1 g
F
P
p
.002 w
.56404 .54106 m .56496 .54073 L .5639 .54145 L p
1 g
F P
s
P
p
.56403 .5411 m .56398 .54123 L .56402 .54112 L 1 g
F
P
p
.56654 .52734 m .56398 .54123 L .56403 .5411 L 1 g
F
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56413 .5408 m .56496 .54073 L .56404 .54106 L p
1 g
F P
s
P
p
.002 w
.58464 .55737 m .57495 .56387 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.57495 .56387 m .56406 .56771 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.59215 .54889 m .58464 .55737 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.56406 .56771 m .55371 .56846 L p
.5629 .54579 L 1 g
F P
s
P
p
.002 w
.56496 .54073 m .56487 .54323 L p
.5629 .54579 L 1 g
F P
s
P
p
.002 w
.56487 .54323 m .56406 .56771 L p
.5629 .54579 L 1 g
F P
s
P
p
.002 w
.55815 .55671 m .56496 .54073 L p
.55371 .56846 L 1 g
F P
s
P
p
.002 w
.54513 .56657 m .5433 .56612 L p
.55829 .5564 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56167 .5474 L p
1 g
F P
s
P
p
.002 w
.56167 .5474 m .56167 .54739 L p
.56161 .54748 L 1 g
F P
s
P
p
.56161 .54748 m .54998 .56518 L .56167 .5474 L 1 g
F
P
p
.002 w
.59666 .53932 m .59215 .54889 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.59768 .52965 m .59666 .53932 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.59506 .52091 m .59768 .52965 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.58902 .51407 m .59506 .52091 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.5802 .5099 m .58902 .51407 L .56496 .54073 L closepath p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56749 .52872 L p
1 g
F P
s
P
p
.002 w
.5802 .5099 m .56786 .53486 L p
.56767 .53165 L 1 g
F P
s
P
p
.56515 .50826 m .56749 .52872 L .56725 .52476 L 1 g
F
P
p
.002 w
.5663 .50955 m .56953 .50889 L .56868 .51482 L p
1 g
F P
s
P
p
.002 w
.56868 .51482 m .56725 .52476 L p
.56631 .50964 L 1 g
F P
s
P
p
.5663 .50955 m .56868 .51482 L .56631 .50964 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56631 .50964 L p
1 g
F P
s
P
p
.55661 .4905 m .56631 .50964 L .56627 .50955 L 1 g
F
P
p
.002 w
.56953 .50889 m .56627 .50955 L p
.55738 .49132 L 1 g
F P
s
P
p
.55586 .48819 m .55888 .49277 L .55738 .49132 L 1 g
F
P
p
.55888 .49277 m .56953 .50889 L .55738 .49132 L 1 g
F
P
p
.55661 .4905 m .56627 .50955 L .56212 .50105 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55738 .49132 L p
1 g
F P
s
P
p
.54174 .47608 m .55738 .49132 L .55132 .48546 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55132 .48546 m .55819 .51119 L p
.54597 .48027 L 1 g
F P
s
P
p
.55109 .48524 m .55132 .48546 L .55112 .48527 L 1 g
F
P
p
.54174 .47608 m .55132 .48546 L .55109 .48524 L 1 g
F
P
p
.002 w
.52811 .48918 m .54597 .48027 L p
.55819 .51119 L 1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54947 .47852 m .55586 .48819 L .55604 .49003 L 1 g
F
P
p
.002 w
.55819 .51119 m .55132 .48546 L p
.55604 .49003 L 1 g
F P
s
P
p
.002 w
.55132 .48546 m .54947 .47852 L p
.55604 .49003 L 1 g
F P
s
P
p
.56515 .50826 m .56725 .52476 L .56695 .51993 L 1 g
F
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56953 .50889 m .57285 .50921 L p
.56749 .52872 L 1 g
F P
s
P
p
.002 w
.56749 .52872 m .56654 .52734 L p
.56424 .54046 L 1 g
F P
s
P
p
.002 w
.56428 .54031 m .56496 .54073 L .56421 .54057 L p
1 g
F P
s
P
p
.56424 .54046 m .56424 .54047 L .56426 .5404 L 1 g
F
P
p
.56424 .54046 m .56426 .5404 L .56749 .52872 L 1 g
F
P
p
.56424 .54047 m .56433 .54017 L .56749 .52872 L 1 g
F
P
p
.56654 .52734 m .56402 .54114 L .56419 .54061 L 1 g
F
P
p
.56654 .52734 m .56415 .54084 L .56421 .54062 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52984 .54373 m .53246 .53381 L .56421 .54057 L p
1 g
F P
s
P
p
.002 w
.56421 .54057 m .56496 .54073 L .56413 .5408 L p
1 g
F P
s
P
p
.002 w
.56413 .5408 m .52984 .54373 L p
.56421 .54057 L 1 g
F P
s
P
p
.56419 .54061 m .564 .54123 L .56415 .54084 L 1 g
F
P
p
.56402 .54114 m .564 .54123 L .56419 .54061 L 1 g
F
P
p
.56421 .54062 m .56415 .54084 L .56419 .54073 L 1 g
F
P
p
.56423 .54053 m .56455 .53938 L .56749 .52872 L 1 g
F
P
p
.002 w
.56439 .53995 m .56496 .54073 L .56428 .54031 L p
1 g
F P
s
P
p
.56421 .54062 m .56579 .5349 L .56749 .52872 L 1 g
F
P
p
.002 w
.56634 .50968 m .56515 .50826 L p
.56696 .52003 L 1 g
F P
s
P
p
.002 w
.56725 .52476 m .56579 .5349 L p
.5663 .50955 L 1 g
F P
s
P
p
.002 w
.56579 .5349 m .56496 .54073 L p
.5651 .53741 L 1 g
F P
s
P
p
.5663 .50955 m .56579 .5349 L .5651 .53741 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.53246 .53381 m .53855 .5244 L .56428 .54031 L p
1 g
F P
s
P
p
.002 w
.56421 .54057 m .53246 .53381 L p
.56428 .54031 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.53855 .5244 m .54746 .51656 L .56439 .53995 L p
1 g
F P
s
P
p
.002 w
.56428 .54031 m .53855 .5244 L p
.56439 .53995 L 1 g
F P
s
P
p
.56424 .54047 m .56423 .54053 L .56433 .54017 L 1 g
F
P
p
.56423 .54053 m .56421 .54062 L .56455 .53938 L 1 g
F
P
p
.002 w
.54746 .51656 m .55819 .51119 L .56461 .5392 L p
1 g
F P
s
P
p
.002 w
.56461 .5392 m .56496 .54073 L .56439 .53995 L p
1 g
F P
s
P
p
.002 w
.56439 .53995 m .54746 .51656 L p
.56461 .5392 L 1 g
F P
s
P
p
.002 w
.55819 .51119 m .5663 .50955 L p
.5651 .53741 L 1 g
F P
s
P
p
.002 w
.56496 .54073 m .56461 .5392 L p
.5651 .53741 L 1 g
F P
s
P
p
.002 w
.56461 .5392 m .55819 .51119 L p
.5651 .53741 L 1 g
F P
s
P
p
.56421 .54062 m .56419 .54073 L .56579 .5349 L 1 g
F
P
p
.002 w
.56579 .5349 m .56725 .52476 L p
.56749 .52872 L 1 g
F P
s
P
p
.002 w
.56725 .52476 m .56953 .50889 L p
.56749 .52872 L 1 g
F P
s
P
p
.002 w
.57285 .50921 m .5802 .5099 L p
.56579 .5349 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56634 .50968 L p
1 g
F P
s
P
p
.56696 .52003 m .56854 .53025 L .56634 .50968 L 1 g
F
P
p
.002 w
.56627 .50955 m .55819 .51119 L p
.55586 .48819 L 1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47677 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52811 .48918 m .51186 .46572 L p
.53882 .47505 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46712 L .5126 .46582 L 1 g
F
P
p
.52241 .46712 m .53882 .47505 L .51186 .46572 L 1 g
F
P
p
.002 w
.48165 .48269 m .5023 .46429 L p
.52811 .48918 L 1 g
F P
s
P
p
.002 w
.51186 .46572 m .52811 .48918 L p
.5023 .46429 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48165 .48269 m .46847 .47159 L p
.47573 .46801 L 1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5023 .46429 m .48165 .48269 L p
.47573 .46801 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47761 .46708 L p
1 g
F P
s
P
p
.45826 .47608 m .47761 .46708 L .46847 .47159 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46847 .47159 m .48165 .48269 L p
.44854 .48557 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47656 L p
1 g
F P
s
P
p
.45782 .47656 m .46847 .47159 L .44854 .48557 L 1 g
F
P
p
.002 w
.45782 .47656 m .45698 .47747 L p
.44851 .4856 L 1 g
F P
s
P
p
.44339 .4905 m .45782 .47656 L .44851 .4856 L 1 g
F
P
p
.002 w
.43128 .49475 m .43626 .48664 L p
.44854 .48557 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44271 .49123 L p
1 g
F P
s
P
p
.44163 .49227 m .44271 .49123 L .44226 .49212 L 1 g
F
P
p
.42294 .53213 m .43508 .49655 L .43415 .50877 L 1 g
F
P
p
.002 w
.43264 .52854 m .43346 .52734 L p
.43323 .52076 L 1 g
F P
s
P
p
.42294 .53213 m .43415 .50877 L .42354 .53181 L 1 g
F
P
p
.43415 .50877 m .4391 .49845 L .43412 .50913 L 1 g
F
P
p
.43415 .50877 m .43412 .50913 L .42354 .53181 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43412 .50913 L p
1 g
F P
s
P
p
.43346 .52734 m .43412 .50913 L .43323 .52076 L 1 g
F
P
p
.43485 .50826 m .44271 .49123 L .4391 .49845 L 1 g
F
P
p
.43843 .49989 m .4391 .49845 L .43871 .49923 L 1 g
F
P
p
.43485 .50826 m .4391 .49845 L .43843 .49989 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4391 .49845 m .46433 .5104 L p
.43276 .52697 L 1 g
F P
s
P
p
.42354 .53181 m .43412 .50913 L .43276 .52697 L 1 g
F
P
p
.002 w
.43508 .49655 m .4391 .49845 L p
.43415 .50877 L 1 g
F P
s
P
p
.002 w
.4391 .49845 m .43128 .49475 L p
.44226 .49212 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43326 .51015 L p
1 g
F P
s
P
p
.002 w
.43326 .51015 m .43485 .50826 L p
.43871 .49923 L 1 g
F P
s
P
p
.43871 .49923 m .44166 .49233 L .43326 .51015 L 1 g
F
P
p
.002 w
.48165 .48269 m .46433 .5104 L .4391 .49845 L p
1 g
F P
s
P
p
.44226 .49212 m .48165 .48269 L .4391 .49845 L 1 g
F
P
p
.43412 .50913 m .4391 .49845 L .43276 .52697 L 1 g
F
P
p
.002 w
.43412 .50913 m .43287 .51061 L p
.43323 .52076 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43418 .53447 m .42294 .53213 L p
.43229 .52722 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43223 .52913 L p
1 g
F P
s
P
p
.002 w
.42874 .56656 m .42294 .53213 L .43418 .53447 L p
1 g
F P
s
P
p
.42874 .56656 m .4333 .53965 L .44148 .55451 L 1 g
F
P
p
.4333 .53965 m .43418 .53447 L .43866 .54677 L 1 g
F
P
p
.4333 .53965 m .43866 .54677 L .44148 .55451 L 1 g
F
P
p
.43925 .54566 m .43223 .52913 L .43569 .53862 L 1 g
F
P
p
.002 w
.4378 .54839 m .43925 .54566 L p
.4348 .53686 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43866 .54677 L p
1 g
F P
s
P
p
.45146 .56129 m .43866 .54677 L .44602 .55657 L 1 g
F
P
p
.002 w
.43418 .53447 m .45748 .53935 L p
.44323 .55285 L 1 g
F P
s
P
p
.44148 .55451 m .43866 .54677 L .44323 .55285 L 1 g
F
P
p
.43866 .54677 m .43418 .53447 L .44323 .55285 L 1 g
F
P
p
.002 w
.45084 .56297 m .45146 .56129 L p
.44602 .55657 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45494 .56625 m .42874 .56656 L p
.44091 .55504 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45064 .56349 L p
1 g
F P
s
P
p
.46872 .57265 m .45064 .56349 L .45865 .56863 L 1 g
F
P
p
.002 w
.44738 .59437 m .42874 .56656 L .45494 .56625 L p
1 g
F P
s
P
p
.46872 .57265 m .45865 .56863 L .46641 .5736 L 1 g
F
P
p
.002 w
.47577 .58799 m .46682 .57423 L p
.48073 .58156 L 1 g
F P
s
P
p
.002 w
.46682 .57423 m .46641 .5736 L p
.46828 .57464 L 1 g
F P
s
P
p
.46682 .57423 m .46828 .57464 L .48073 .58156 L 1 g
F
P
p
.002 w
.48907 .58054 m .48921 .57862 L p
.47949 .57782 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46828 .57464 L p
1 g
F P
s
P
p
.48921 .57862 m .46828 .57464 L .47949 .57782 L 1 g
F
P
p
.002 w
.46158 .56617 m .49606 .56164 L p
.48287 .57878 L 1 g
F P
s
P
p
.48073 .58156 m .47422 .57633 L .48287 .57878 L 1 g
F
P
p
.47422 .57633 m .46158 .56617 L .48287 .57878 L 1 g
F
P
p
.002 w
.46828 .57464 m .46872 .57265 L p
.46641 .5736 L 1 g
F P
s
P
p
.002 w
.46641 .5736 m .46158 .56617 L p
.48073 .58156 L 1 g
F P
s
P
p
.002 w
.46641 .5736 m .46682 .57423 L p
.45993 .56945 L 1 g
F P
s
P
p
.002 w
.46682 .57423 m .47577 .58799 L p
.46263 .5726 L 1 g
F P
s
P
p
.45993 .56945 m .46682 .57423 L .46263 .5726 L 1 g
F
P
p
.002 w
.46828 .57464 m .46825 .57479 L p
.47949 .57782 L 1 g
F P
s
P
p
.002 w
.46825 .57479 m .4678 .57686 L p
.47517 .57747 L 1 g
F P
s
P
p
.47949 .57782 m .46825 .57479 L .47517 .57747 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49455 .58088 m .47577 .58799 L p
.48186 .58009 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58085 L p
1 g
F P
s
P
p
.002 w
.49817 .60268 m .47577 .58799 L .49455 .58088 L p
1 g
F P
s
P
p
.49817 .60268 m .49455 .58088 L .50433 .58093 L 1 g
F
P
p
.002 w
.48904 .58085 m .48889 .583 L p
.49936 .58091 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58085 L .49936 .58091 L 1 g
F
P
p
.002 w
.51096 .58097 m .51079 .57862 L p
.49936 .58091 L 1 g
F P
s
P
p
.002 w
.49455 .58088 m .50553 .57672 L p
.50433 .58093 L 1 g
F P
s
P
p
.002 w
.49606 .56164 m .50553 .57672 L .49455 .58088 L p
1 g
F P
s
P
p
.48186 .58009 m .49606 .56164 L .49455 .58088 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51103 .5819 L p
1 g
F P
s
P
p
.002 w
.51103 .5819 m .51096 .58097 L p
.50495 .58152 L 1 g
F P
s
P
p
.50495 .58152 m .48889 .583 L .51103 .5819 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58054 L p
1 g
F P
s
P
p
.47949 .57782 m .4678 .57686 L .48907 .58054 L 1 g
F
P
p
.002 w
.46825 .57479 m .46828 .57464 L p
.46641 .5736 L 1 g
F P
s
P
p
.002 w
.45494 .56625 m .46158 .56617 L p
.45993 .56945 L 1 g
F P
s
P
p
.44738 .59437 m .45494 .56625 L .45993 .56945 L 1 g
F
P
p
.002 w
.47577 .58799 m .44738 .59437 L p
.45993 .56945 L 1 g
F P
s
P
p
.002 w
.46786 .57658 m .46825 .57479 L p
.45718 .56804 L 1 g
F P
s
P
p
.45865 .56863 m .45718 .56804 L .46825 .57479 L 1 g
F
P
p
.002 w
.45064 .56349 m .45002 .56518 L p
.45865 .56863 L 1 g
F P
s
P
p
.002 w
.46158 .56617 m .46641 .5736 L p
.45993 .56945 L 1 g
F P
s
P
p
.002 w
.45748 .53935 m .46158 .56617 L .45494 .56625 L p
1 g
F P
s
P
p
.44091 .55504 m .45748 .53935 L .45494 .56625 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46786 .57658 L p
1 g
F P
s
P
p
.45718 .56804 m .45002 .56518 L .46786 .57658 L 1 g
F
P
p
.002 w
.43866 .54677 m .43743 .5491 L p
.44602 .55657 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45084 .56297 L p
1 g
F P
s
P
p
.44602 .55657 m .43743 .5491 L .45084 .56297 L 1 g
F
P
p
.002 w
.43223 .52913 m .43146 .53025 L p
.43569 .53862 L 1 g
F P
s
P
p
.002 w
.46433 .5104 m .45748 .53935 L .43418 .53447 L p
1 g
F P
s
P
p
.43229 .52722 m .46433 .5104 L .43418 .53447 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4378 .54839 L p
1 g
F P
s
P
p
.4348 .53686 m .43146 .53025 L .4378 .54839 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43264 .52854 L p
1 g
F P
s
P
p
.43323 .52076 m .43287 .51061 L .43264 .52854 L 1 g
F
P
p
.002 w
.42294 .53213 m .43128 .49475 L .43508 .49655 L p
1 g
F P
s
P
p
.43871 .49923 m .4391 .49845 L .44166 .49233 L 1 g
F
P
p
.002 w
.44271 .49123 m .44224 .49172 L p
.4391 .49845 L 1 g
F P
s
P
p
.002 w
.44224 .49172 m .44166 .49233 L p
.4391 .49845 L 1 g
F P
s
P
p
.44226 .49212 m .44854 .48557 L .48165 .48269 L 1 g
F
P
p
.44271 .49123 m .44854 .48557 L .44226 .49212 L 1 g
F
P
p
.002 w
.44271 .49123 m .44339 .4905 L p
.44851 .4856 L 1 g
F P
s
P
p
.43128 .49475 m .44854 .48557 L .44163 .49227 L 1 g
F
P
p
.43626 .48664 m .45782 .47656 L .44854 .48557 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44271 .49123 L p
1 g
F P
s
P
p
.44851 .4856 m .45698 .47747 L .44271 .49123 L 1 g
F
P
p
.46788 .47186 m .46847 .47159 L .46816 .47174 L 1 g
F
P
p
.45826 .47608 m .46847 .47159 L .46788 .47186 L 1 g
F
P
p
.002 w
.45736 .47706 m .45826 .47608 L p
.46816 .47174 L 1 g
F P
s
P
p
.002 w
.43626 .48664 m .45332 .45883 L .46847 .47159 L p
1 g
F P
s
P
p
.002 w
.47761 .46708 m .47786 .46667 L p
.4871 .46573 L 1 g
F P
s
P
p
.47761 .46708 m .5023 .46429 L .47573 .46801 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .4871 .46573 L 1 g
F
P
p
.48821 .46186 m .5 .46389 L .47761 .46708 L 1 g
F
P
p
.5 .46389 m .5023 .46429 L .47761 .46708 L 1 g
F
P
p
.002 w
.5 .46389 m .5 .46442 L p
.4871 .46573 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47761 .46708 L p
1 g
F P
s
P
p
.4871 .46573 m .5 .46442 L .47761 .46708 L 1 g
F
P
p
.47212 .45909 m .48821 .46186 L .47761 .46708 L 1 g
F
P
p
.47548 .46738 m .47761 .46708 L .47573 .46801 L 1 g
F
P
p
.47212 .45909 m .47761 .46708 L .47548 .46738 L 1 g
F
P
p
.002 w
.47761 .46708 m .47718 .46778 L p
.46816 .47174 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45736 .47706 L p
1 g
F P
s
P
p
.46816 .47174 m .47718 .46778 L .45736 .47706 L 1 g
F
P
p
.45332 .45883 m .47212 .45909 L .47573 .46801 L 1 g
F
P
p
.002 w
.46847 .47159 m .45332 .45883 L p
.47573 .46801 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .4634 L p
.5129 .46588 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.50759 .45957 m .5023 .46429 L p
.47212 .45909 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .5 .46395 L p
.51193 .46595 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .52091 .4675 L p
.51193 .46595 L 1 g
F P
s
P
p
.002 w
.52091 .4675 m .5 .46442 L p
.51193 .46595 L 1 g
F P
s
P
p
.5129 .46588 m .52282 .46778 L .5 .46395 L 1 g
F
P
p
.002 w
.5023 .46429 m .50759 .45957 L .51186 .46572 L p
1 g
F P
s
P
p
.002 w
.51186 .46572 m .508 .46016 L p
.52241 .46712 L 1 g
F P
s
P
p
.002 w
.52241 .46712 m .52282 .46778 L p
.5126 .46582 L 1 g
F P
s
P
p
.52214 .46667 m .54237 .47677 L .53147 .4715 L 1 g
F
P
p
.002 w
.54597 .48027 m .52811 .48918 L p
.53958 .47405 L 1 g
F P
s
P
p
.002 w
.54237 .47677 m .54302 .47747 L p
.53147 .4715 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.50759 .45957 m .53958 .47405 L .53882 .47505 L 1 g
F
P
p
.002 w
.508 .46016 m .50759 .45957 L p
.53882 .47505 L 1 g
F P
s
P
p
.54174 .47608 m .55112 .48527 L .54709 .48137 L 1 g
F
P
p
.002 w
.54237 .47677 m .54174 .47608 L p
.54709 .48137 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54947 .47852 m .54597 .48027 L p
.53958 .47405 L 1 g
F P
s
P
p
.002 w
.54266 .47708 m .54237 .47677 L p
.54709 .48137 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54266 .47708 L p
1 g
F P
s
P
p
.55112 .48527 m .55834 .49233 L .54266 .47708 L 1 g
F
P
p
.002 w
.54597 .48027 m .54947 .47852 L .55132 .48546 L p
1 g
F P
s
P
p
.002 w
.55738 .49132 m .55834 .49233 L p
.55112 .48527 L 1 g
F P
s
P
p
.56212 .50105 m .56627 .50955 L .56416 .50494 L 1 g
F
P
p
.002 w
.56631 .50964 m .56713 .51061 L p
.56416 .50494 L 1 g
F P
s
P
p
.56695 .51993 m .56725 .52476 L .56696 .52003 L 1 g
F
P
p
.002 w
.56749 .52872 m .56854 .53025 L p
.56696 .52003 L 1 g
F P
s
P
p
.002 w
.56496 .54073 m .56579 .5349 L p
.56767 .53165 L 1 g
F P
s
P
p
.002 w
.56786 .53486 m .56496 .54073 L p
.56767 .53165 L 1 g
F P
s
P
p
.002 w
.56829 .52989 m .56749 .52872 L p
.56419 .54073 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56829 .52989 L p
1 g
F P
s
P
p
.564 .54123 m .56257 .5491 L .56829 .52989 L 1 g
F
P
p
.002 w
.55371 .56846 m .55313 .5685 L .55815 .55671 L p
1 g
F P
s
P
p
.002 w
.53095 .55306 m .52984 .54373 L .56413 .5408 L p
1 g
F P
s
P
p
.002 w
.56404 .54106 m .53095 .55306 L p
.56413 .5408 L 1 g
F P
s
P
p
.002 w
.53562 .5608 m .53095 .55306 L .56404 .54106 L p
1 g
F P
s
P
p
.002 w
.5639 .54145 m .53562 .5608 L p
.56404 .54106 L 1 g
F P
s
P
p
.56402 .54112 m .5639 .54145 L .56402 .54116 L 1 g
F
P
p
.5639 .54145 m .56356 .54236 L .56378 .54178 L 1 g
F
P
p
.5639 .54145 m .56378 .54178 L .56402 .54116 L 1 g
F
P
p
.002 w
.5433 .56612 m .53562 .5608 L .5639 .54145 L p
1 g
F P
s
P
p
.002 w
.56356 .54236 m .5433 .56612 L p
.5639 .54145 L 1 g
F P
s
P
p
.55104 .5611 m .5433 .56612 L .56267 .54609 L 1 g
F
P
p
.002 w
.56167 .54739 m .56257 .5491 L p
.56402 .54116 L 1 g
F P
s
P
p
.002 w
.5433 .56612 m .56356 .54236 L p
.56183 .54697 L 1 g
F P
s
P
p
.55518 .55576 m .54998 .56518 L .56167 .54739 L 1 g
F
P
p
.002 w
.5493 .56334 m .54998 .56518 L p
.55518 .55576 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5493 .56334 L p
1 g
F P
s
P
p
.53388 .57526 m .5322 .57686 L .5493 .56334 L 1 g
F
P
p
.002 w
.5384 .57065 m .5433 .56612 L p
.54308 .56781 L 1 g
F P
s
P
p
.53921 .57018 m .5384 .57065 L .5322 .57686 L 1 g
F
P
p
.002 w
.53562 .5608 m .5433 .56612 L .5384 .57065 L p
1 g
F P
s
P
p
.002 w
.5384 .57065 m .53541 .57342 L p
.53543 .57239 L 1 g
F P
s
P
p
.53543 .57239 m .53562 .5608 L .5384 .57065 L 1 g
F
P
p
.52696 .57606 m .53562 .5608 L .53541 .57342 L 1 g
F
P
p
.002 w
.5317 .57458 m .53173 .57471 L p
.5384 .57065 L 1 g
F P
s
P
p
.002 w
.53173 .57471 m .5322 .57686 L p
.5384 .57065 L 1 g
F P
s
P
p
.53927 .57013 m .5384 .57065 L .53921 .57018 L 1 g
F
P
p
.002 w
.5433 .56612 m .54513 .56657 L p
.54308 .56781 L 1 g
F P
s
P
p
.002 w
.50553 .57672 m .53562 .5608 L p
.52696 .57606 L 1 g
F P
s
P
p
.002 w
.51166 .58084 m .50553 .57672 L p
.52696 .57606 L 1 g
F P
s
P
p
.002 w
.50553 .57672 m .51166 .58084 L p
.50433 .58093 L 1 g
F P
s
P
p
.002 w
.51166 .58084 m .51186 .58098 L p
.51096 .58097 L 1 g
F P
s
P
p
.50433 .58093 m .51166 .58084 L .51096 .58097 L 1 g
F
P
p
.51739 .57978 m .51166 .58084 L .51111 .583 L 1 g
F
P
p
.002 w
.51096 .58097 m .51097 .58106 L p
.51166 .58084 L 1 g
F P
s
P
p
.002 w
.51097 .58106 m .51111 .583 L p
.51166 .58084 L 1 g
F P
s
P
p
.521 .57792 m .51166 .58084 L .51739 .57978 L 1 g
F
P
p
.49936 .58091 m .48889 .583 L .51096 .58097 L 1 g
F
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51802 .46108 L
s
P
p
.004 w
.53948 .49751 m
.54997 .51531 L
s
P
p
.002 w
.37341 .45856 m .36332 .50918 L .34017 .49443 L p
1 g
F P
s
P
p
.002 w
.34017 .49443 m .35061 .43943 L .37341 .45856 L p
1 g
F P
s
P
p
.002 w
.57495 .56387 m .58464 .55737 L .60119 .56972 L p
1 g
F P
s
P
p
.002 w
.61582 .55331 m .60119 .56972 L .58464 .55737 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.55313 .5685 m .56406 .56771 L .56131 .5898 L p
1 g
F P
s
P
p
.002 w
.56131 .5898 m .54004 .59144 L .55313 .5685 L p
1 g
F P
s
P
p
.002 w
.61354 .33974 m .65627 .36371 L .6516 .39234 L p
1 g
F P
s
P
p
.002 w
.65627 .36371 m .61354 .33974 L .61012 .31133 L p
1 g
F P
s
P
p
.002 w
.41525 .31856 m .36493 .36484 L .35278 .34598 L p
1 g
F P
s
P
p
.002 w
.35278 .34598 m .40356 .29907 L .41525 .31856 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.58464 .55737 m .59215 .54889 L .61582 .55331 L p
1 g
F P
s
P
p
.002 w
.62475 .5347 m .61582 .55331 L .59215 .54889 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.3816 .3863 m .35061 .43943 L .33286 .42055 L p
1 g
F P
s
P
p
.002 w
.33286 .42055 m .36493 .36484 L .3816 .3863 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.62475 .5347 m .62697 .51576 L .65186 .49963 L p
1 g
F P
s
P
p
.002 w
.64508 .4743 m .65186 .49963 L .62697 .51576 L p
1 g
F P
s
P
p
.002 w
.65186 .49963 m .64508 .4743 L .66334 .44925 L p
1 g
F P
s
P
p
.002 w
.42294 .53213 m .42874 .56656 L .39867 .56291 L p
1 g
F P
s
P
p
.002 w
.39867 .56291 m .3912 .52192 L .42294 .53213 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.54304 .27738 m .4774 .28809 L .46642 .26832 L p
1 g
F P
s
P
p
.002 w
.40356 .29907 m .46642 .26832 L .4774 .28809 L p
1 g
F P
s
P
p
.002 w
.64223 .42278 m .66334 .44925 L .64508 .4743 L p
1 g
F P
s
P
p
.002 w
.66334 .44925 m .64223 .42278 L .6516 .39234 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.4774 .28809 m .41525 .31856 L .40356 .29907 L p
1 g
F P
s
P
p
.002 w
.59215 .54889 m .59666 .53932 L .62475 .5347 L p
1 g
F P
s
P
p
.002 w
.62697 .51576 m .62475 .5347 L .59666 .53932 L p
1 g
F P
s
P
p
.002 w
.55222 .30233 m .61012 .31133 L .61354 .33974 L p
1 g
F P
s
P
p
.002 w
.61012 .31133 m .55222 .30233 L .54304 .27738 L p
1 g
F P
s
P
p
.002 w
.4774 .28809 m .54304 .27738 L .55222 .30233 L p
1 g
F P
s
P
p
.002 w
.4006 .47724 m .3912 .52192 L .36332 .50918 L p
1 g
F P
s
P
p
.002 w
.36332 .50918 m .37341 .45856 L .4006 .47724 L p
1 g
F P
s
P
p
.002 w
.61358 .37159 m .6516 .39234 L .64223 .42278 L p
1 g
F P
s
P
p
.002 w
.6516 .39234 m .61358 .37159 L .61354 .33974 L p
1 g
F P
s
P
p
.002 w
.59666 .53932 m .59768 .52965 L .62697 .51576 L p
1 g
F P
s
P
p
.002 w
.62208 .49849 m .62697 .51576 L .59768 .52965 L p
1 g
F P
s
P
p
.002 w
.62697 .51576 m .62208 .49849 L .64508 .4743 L p
1 g
F P
s
P
p
.002 w
.62837 .45398 m .64508 .4743 L .62208 .49849 L p
1 g
F P
s
P
p
.002 w
.64508 .4743 m .62837 .45398 L .64223 .42278 L p
1 g
F P
s
P
p
.002 w
.42991 .3421 m .3816 .3863 L .36493 .36484 L p
1 g
F P
s
P
p
.002 w
.36493 .36484 m .41525 .31856 L .42991 .3421 L p
1 g
F P
s
P
p
.002 w
.40236 .40969 m .37341 .45856 L .35061 .43943 L p
1 g
F P
s
P
p
.002 w
.35061 .43943 m .3816 .3863 L .40236 .40969 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.53095 .55306 m .53562 .5608 L .50553 .57672 L p
1 g
F P
s
P
p
.002 w
.50553 .57672 m .49606 .56164 L .53095 .55306 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.56005 .33188 m .61354 .33974 L .61358 .37159 L p
1 g
F P
s
P
p
.002 w
.61354 .33974 m .56005 .33188 L .55222 .30233 L p
1 g
F P
s
P
p
.002 w
.55222 .30233 m .48943 .31285 L .4774 .28809 L p
1 g
F P
s
P
p
.002 w
.41525 .31856 m .4774 .28809 L .48943 .31285 L p
1 g
F P
s
P
p
.002 w
.61012 .4058 m .64223 .42278 L .62837 .45398 L p
1 g
F P
s
P
p
.002 w
.64223 .42278 m .61012 .4058 L .61358 .37159 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.43128 .49475 m .42294 .53213 L .3912 .52192 L p
1 g
F P
s
P
p
.002 w
.3912 .52192 m .4006 .47724 L .43128 .49475 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.49357 .54327 m .49606 .56164 L .46158 .56617 L p
1 g
F P
s
P
p
.002 w
.46158 .56617 m .45748 .53935 L .49357 .54327 L p
1 g
F P
s
P
p
.002 w
.48943 .31285 m .42991 .3421 L .41525 .31856 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59768 .52965 m .59506 .52091 L .62208 .49849 L p
1 g
F P
s
P
p
.002 w
.61043 .48479 m .62208 .49849 L .59506 .52091 L p
1 g
F P
s
P
p
.002 w
.62208 .49849 m .61043 .48479 L .62837 .45398 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.48943 .31285 m .55222 .30233 L .56005 .33188 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.52984 .54373 m .53095 .55306 L .49606 .56164 L p
1 g
F P
s
P
p
.002 w
.49606 .56164 m .49357 .54327 L .52984 .54373 L p
1 g
F P
s
P
p
.002 w
.59506 .52091 m .58902 .51407 L .61043 .48479 L p
1 g
F P
s
P
p
.002 w
.60323 .44115 m .62837 .45398 L .61043 .48479 L p
1 g
F P
s
P
p
.002 w
.62837 .45398 m .60323 .44115 L .61012 .4058 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42655 .43418 m .4006 .47724 L .37341 .45856 L p
1 g
F P
s
P
p
.002 w
.37341 .45856 m .40236 .40969 L .42655 .43418 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.56617 .36508 m .61358 .37159 L .61012 .4058 L p
1 g
F P
s
P
p
.002 w
.61358 .37159 m .56617 .36508 L .56005 .33188 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.44712 .36898 m .40236 .40969 L .3816 .3863 L p
1 g
F P
s
P
p
.002 w
.3816 .3863 m .42991 .3421 L .44712 .36898 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59313 .47629 m .61043 .48479 L .58902 .51407 L p
1 g
F P
s
P
p
.002 w
.61043 .48479 m .59313 .47629 L .60323 .44115 L p
1 g
F P
s
P
p
.002 w
.58902 .51407 m .5802 .5099 L .59313 .47629 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56005 .33188 m .50209 .34189 L .48943 .31285 L p
1 g
F P
s
P
p
.002 w
.42991 .3421 m .48943 .31285 L .50209 .34189 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53246 .53381 m .52984 .54373 L .49357 .54327 L p
1 g
F P
s
P
p
.002 w
.49849 .52358 m .49357 .54327 L .45748 .53935 L p
1 g
F P
s
P
p
.002 w
.45748 .53935 m .46433 .5104 L .49849 .52358 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.50209 .34189 m .56005 .33188 L .56617 .36508 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49357 .54327 m .49849 .52358 L .53246 .53381 L p
1 g
F P
s
P
p
.002 w
.57031 .40076 m .61012 .4058 L .60323 .44115 L p
1 g
F P
s
P
p
.002 w
.61012 .4058 m .57031 .40076 L .56617 .36508 L p
1 g
F P
s
P
p
.002 w
.5802 .5099 m .56953 .50889 L .57202 .47408 L p
1 g
F P
s
P
p
.002 w
.57202 .47408 m .59313 .47629 L .5802 .5099 L p
1 g
F P
s
P
p
.002 w
.50209 .34189 m .44712 .36898 L .42991 .3421 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45332 .45883 m .43128 .49475 L .4006 .47724 L p
1 g
F P
s
P
p
.002 w
.4006 .47724 m .42655 .43418 L .45332 .45883 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.53855 .5244 m .53246 .53381 L .49849 .52358 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54947 .47852 m .57202 .47408 L .56953 .50889 L p
1 g
F P
s
P
p
.002 w
.57229 .43757 m .60323 .44115 L .59313 .47629 L p
1 g
F P
s
P
p
.002 w
.60323 .44115 m .57229 .43757 L .57031 .40076 L p
1 g
F P
s
P
p
.002 w
.59313 .47629 m .57202 .47408 L .57229 .43757 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.54746 .51656 m .53855 .5244 L .51044 .50482 L p
1 g
F P
s
P
p
.002 w
.49849 .52358 m .51044 .50482 L .53855 .5244 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46629 .39827 m .42655 .43418 L .40236 .40969 L p
1 g
F P
s
P
p
.002 w
.40236 .40969 m .44712 .36898 L .46629 .39827 L p
1 g
F P
s
P
p
.002 w
.55819 .51119 m .54746 .51656 L .52811 .48918 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51044 .50482 m .52811 .48918 L .54746 .51656 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.51044 .50482 m .49849 .52358 L .46433 .5104 L p
1 g
F P
s
P
p
.002 w
.51492 .37423 m .56617 .36508 L .57031 .40076 L p
1 g
F P
s
P
p
.002 w
.56617 .36508 m .51492 .37423 L .50209 .34189 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.44712 .36898 m .50209 .34189 L .51492 .37423 L p
1 g
F P
s
P
p
.002 w
.46433 .5104 m .48165 .48269 L .51044 .50482 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57202 .47408 m .54947 .47852 L .53908 .44391 L p
1 g
F P
s
P
p
.002 w
.53908 .44391 m .57229 .43757 L .57202 .47408 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.51492 .37423 m .46629 .39827 L .44712 .36898 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52741 .40868 m .57031 .40076 L .57229 .43757 L p
1 g
F P
s
P
p
.002 w
.57031 .40076 m .52741 .40868 L .51492 .37423 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52811 .48918 m .51044 .50482 L .48165 .48269 L p
1 g
F P
s
P
p
.002 w
.48671 .42886 m .45332 .45883 L .42655 .43418 L p
1 g
F P
s
P
p
.002 w
.42655 .43418 m .46629 .39827 L .48671 .42886 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.57229 .43757 m .53908 .44391 L .52741 .40868 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50759 .45957 m .53908 .44391 L .54947 .47852 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.46629 .39827 m .51492 .37423 L .52741 .40868 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.45332 .45883 m .48671 .42886 L .50759 .45957 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52741 .40868 m .48671 .42886 L .46629 .39827 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53908 .44391 m .50759 .45957 L .48671 .42886 L p
1 g
F P
s
P
p
.002 w
.48671 .42886 m .52741 .40868 L .53908 .44391 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.5868 .5778 m
.59188 .58642 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .53094 .72583 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60363 .60635 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.385271)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.385271)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45773 .45584 m .49888 .44935 L .49098 .42189 L p
1 g
F P
s
P
p
.002 w
.49098 .42189 m .45664 .42721 L .45773 .45584 L p
1 g
F P
s
P
p
.002 w
.5231 .40816 m .49098 .42189 L .49888 .44935 L p
1 g
F P
s
P
p
.002 w
.45664 .42721 m .49098 .42189 L .48327 .39458 L p
1 g
F P
s
P
p
.002 w
.49098 .42189 m .5231 .40816 L .50821 .38387 L p
1 g
F P
s
P
p
.002 w
.50821 .38387 m .48327 .39458 L .49098 .42189 L p
1 g
F P
s
P
p
.002 w
.45986 .484 m .50684 .47646 L .49888 .44935 L p
1 g
F P
s
P
p
.002 w
.49888 .44935 m .45773 .45584 L .45986 .484 L p
1 g
F P
s
P
p
.002 w
.5374 .43294 m .49888 .44935 L .50684 .47646 L p
1 g
F P
s
P
p
.002 w
.49888 .44935 m .5374 .43294 L .5231 .40816 L p
1 g
F P
s
P
p
.002 w
.54996 .38725 m .5231 .40816 L .5374 .43294 L p
1 g
F P
s
P
p
.002 w
.5231 .40816 m .54996 .38725 L .52897 .36753 L p
1 g
F P
s
P
p
.002 w
.52897 .36753 m .50821 .38387 L .5231 .40816 L p
1 g
F P
s
P
p
.002 w
.50684 .47646 m .55086 .45778 L .5374 .43294 L p
1 g
F P
s
P
p
.002 w
.56976 .40804 m .5374 .43294 L .55086 .45778 L p
1 g
F P
s
P
p
.002 w
.5374 .43294 m .56976 .40804 L .54996 .38725 L p
1 g
F P
s
P
p
.002 w
.48327 .39458 m .45659 .39864 L .45664 .42721 L p
1 g
F P
s
P
p
.002 w
.45659 .39864 m .48327 .39458 L .47591 .3679 L p
1 g
F P
s
P
p
.002 w
.48327 .39458 m .50821 .38387 L .49301 .36054 L p
1 g
F P
s
P
p
.002 w
.49301 .36054 m .47591 .3679 L .48327 .39458 L p
1 g
F P
s
P
p
.002 w
.4177 .45169 m .45773 .45584 L .45664 .42721 L p
1 g
F P
s
P
p
.002 w
.45664 .42721 m .42329 .42352 L .4177 .45169 L p
1 g
F P
s
P
p
.002 w
.42329 .42352 m .45664 .42721 L .45659 .39864 L p
1 g
F P
s
P
p
.002 w
.463 .51117 m .51472 .50272 L .50684 .47646 L p
1 g
F P
s
P
p
.002 w
.50684 .47646 m .45986 .484 L .463 .51117 L p
1 g
F P
s
P
p
.002 w
.55086 .45778 m .50684 .47646 L .51472 .50272 L p
1 g
F P
s
P
p
.002 w
.50821 .38387 m .52897 .36753 L .50717 .34926 L p
1 g
F P
s
P
p
.002 w
.50717 .34926 m .49301 .36054 L .50821 .38387 L p
1 g
F P
s
P
p
.002 w
.41408 .47958 m .45986 .484 L .45773 .45584 L p
1 g
F P
s
P
p
.002 w
.45773 .45584 m .4177 .45169 L .41408 .47958 L p
1 g
F P
s
P
p
.002 w
.45659 .39864 m .43075 .3956 L .42329 .42352 L p
1 g
F P
s
P
p
.002 w
.47591 .3679 m .4576 .37064 L .45659 .39864 L p
1 g
F P
s
P
p
.002 w
.43075 .3956 m .45659 .39864 L .4576 .37064 L p
1 g
F P
s
P
p
.002 w
.51472 .50272 m .56322 .48221 L .55086 .45778 L p
1 g
F P
s
P
p
.002 w
.58799 .42953 m .55086 .45778 L .56322 .48221 L p
1 g
F P
s
P
p
.002 w
.55086 .45778 m .58799 .42953 L .56976 .40804 L p
1 g
F P
s
P
p
.002 w
.5689 .36104 m .54996 .38725 L .56976 .40804 L p
1 g
F P
s
P
p
.002 w
.54996 .38725 m .5689 .36104 L .54344 .34708 L p
1 g
F P
s
P
p
.002 w
.54344 .34708 m .52897 .36753 L .54996 .38725 L p
1 g
F P
s
P
p
.002 w
.41254 .50663 m .463 .51117 L .45986 .484 L p
1 g
F P
s
P
p
.002 w
.45986 .484 m .41408 .47958 L .41254 .50663 L p
1 g
F P
s
P
p
.002 w
.4576 .37064 m .47591 .3679 L .46903 .34237 L p
1 g
F P
s
P
p
.002 w
.47591 .3679 m .49301 .36054 L .47777 .33859 L p
1 g
F P
s
P
p
.002 w
.47777 .33859 m .46903 .34237 L .47591 .3679 L p
1 g
F P
s
P
p
.002 w
.52897 .36753 m .54344 .34708 L .51693 .33519 L p
1 g
F P
s
P
p
.002 w
.51693 .33519 m .50717 .34926 L .52897 .36753 L p
1 g
F P
s
P
p
.002 w
.49301 .36054 m .50717 .34926 L .48497 .33279 L p
1 g
F P
s
P
p
.002 w
.48497 .33279 m .47777 .33859 L .49301 .36054 L p
1 g
F P
s
P
p
.002 w
.5928 .37679 m .56976 .40804 L .58799 .42953 L p
1 g
F P
s
P
p
.002 w
.56976 .40804 m .5928 .37679 L .5689 .36104 L p
1 g
F P
s
P
p
.002 w
.4576 .37064 m .43992 .36843 L .43075 .3956 L p
1 g
F P
s
P
p
.002 w
.46903 .34237 m .45967 .34374 L .4576 .37064 L p
1 g
F P
s
P
p
.002 w
.43992 .36843 m .4576 .37064 L .45967 .34374 L p
1 g
F P
s
P
p
.002 w
.46711 .53681 m .52236 .52764 L .51472 .50272 L p
1 g
F P
s
P
p
.002 w
.51472 .50272 m .463 .51117 L .46711 .53681 L p
1 g
F P
s
P
p
.002 w
.56322 .48221 m .51472 .50272 L .52236 .52764 L p
1 g
F P
s
P
p
.002 w
.38259 .437 m .4177 .45169 L .42329 .42352 L p
1 g
F P
s
P
p
.002 w
.42329 .42352 m .39421 .41097 L .38259 .437 L p
1 g
F P
s
P
p
.002 w
.39421 .41097 m .42329 .42352 L .43075 .3956 L p
1 g
F P
s
P
p
.002 w
.43075 .3956 m .40834 .38563 L .39421 .41097 L p
1 g
F P
s
P
p
.002 w
.40834 .38563 m .43075 .3956 L .43992 .36843 L p
1 g
F P
s
P
p
.002 w
.50717 .34926 m .51693 .33519 L .48987 .32558 L p
1 g
F P
s
P
p
.002 w
.48987 .32558 m .48497 .33279 L .50717 .34926 L p
1 g
F P
s
P
p
.002 w
.52236 .52764 m .57423 .50579 L .56322 .48221 L p
1 g
F P
s
P
p
.002 w
.60428 .45133 m .56322 .48221 L .57423 .50579 L p
1 g
F P
s
P
p
.002 w
.56322 .48221 m .60428 .45133 L .58799 .42953 L p
1 g
F P
s
P
p
.002 w
.37376 .4632 m .41408 .47958 L .4177 .45169 L p
1 g
F P
s
P
p
.002 w
.4177 .45169 m .38259 .437 L .37376 .4632 L p
1 g
F P
s
P
p
.002 w
.43992 .36843 m .42469 .36146 L .40834 .38563 L p
1 g
F P
s
P
p
.002 w
.42469 .36146 m .43992 .36843 L .45066 .34256 L p
1 g
F P
s
P
p
.002 w
.45967 .34374 m .45066 .34256 L .43992 .36843 L p
1 g
F P
s
P
p
.002 w
.61467 .39405 m .58799 .42953 L .60428 .45133 L p
1 g
F P
s
P
p
.002 w
.58799 .42953 m .61467 .39405 L .5928 .37679 L p
1 g
F P
s
P
p
.002 w
.41317 .5323 m .46711 .53681 L .463 .51117 L p
1 g
F P
s
P
p
.002 w
.463 .51117 m .41254 .50663 L .41317 .5323 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .45967 .34374 L .46903 .34237 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .46903 .34237 L .47777 .33859 L closepath p
1 g
F P
s
P
p
.002 w
.55 .3245 m .54344 .34708 L .5689 .36104 L p
1 g
F P
s
P
p
.002 w
.54344 .34708 m .55 .3245 L .52119 .31973 L p
1 g
F P
s
P
p
.002 w
.52119 .31973 m .51693 .33519 L .54344 .34708 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .47777 .33859 L .48497 .33279 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .45066 .34256 L .45967 .34374 L closepath p
1 g
F P
s
P
p
.002 w
.51693 .33519 m .52119 .31973 L .49192 .31771 L p
1 g
F P
s
P
p
.002 w
.49192 .31771 m .48987 .32558 L .51693 .33519 L p
1 g
F P
s
P
p
.002 w
.57777 .33195 m .5689 .36104 L .5928 .37679 L p
1 g
F P
s
P
p
.002 w
.5689 .36104 m .57777 .33195 L .55 .3245 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .48497 .33279 L .48987 .32558 L closepath p
1 g
F P
s
P
p
.002 w
.36797 .48904 m .41254 .50663 L .41408 .47958 L p
1 g
F P
s
P
p
.002 w
.41408 .47958 m .37376 .4632 L .36797 .48904 L p
1 g
F P
s
P
p
.002 w
.47214 .56037 m .52961 .5507 L .52236 .52764 L p
1 g
F P
s
P
p
.002 w
.52236 .52764 m .46711 .53681 L .47214 .56037 L p
1 g
F P
s
P
p
.002 w
.57423 .50579 m .52236 .52764 L .52961 .5507 L p
1 g
F P
s
P
p
.002 w
.45066 .34256 m .44295 .33892 L .42469 .36146 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .44295 .33892 L .45066 .34256 L closepath p
1 g
F P
s
P
p
.002 w
.37246 .3905 m .39421 .41097 L .40834 .38563 L p
1 g
F P
s
P
p
.002 w
.40834 .38563 m .39175 .36956 L .37246 .3905 L p
1 g
F P
s
P
p
.002 w
.39175 .36956 m .40834 .38563 L .42469 .36146 L p
1 g
F P
s
P
p
.002 w
.42469 .36146 m .41355 .35034 L .39175 .36956 L p
1 g
F P
s
P
p
.002 w
.41355 .35034 m .42469 .36146 L .44295 .33892 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .48987 .32558 L .49192 .31771 L closepath p
1 g
F P
s
P
p
.002 w
.52961 .5507 m .58363 .52801 L .57423 .50579 L p
1 g
F P
s
P
p
.002 w
.61828 .473 m .57423 .50579 L .58363 .52801 L p
1 g
F P
s
P
p
.002 w
.57423 .50579 m .61828 .473 L .60428 .45133 L p
1 g
F P
s
P
p
.002 w
.63402 .41251 m .60428 .45133 L .61828 .473 L p
1 g
F P
s
P
p
.002 w
.60428 .45133 m .63402 .41251 L .61467 .39405 L p
1 g
F P
s
P
p
.002 w
.60392 .34197 m .5928 .37679 L .61467 .39405 L p
1 g
F P
s
P
p
.002 w
.5928 .37679 m .60392 .34197 L .57777 .33195 L p
1 g
F P
s
P
p
.002 w
.35611 .41274 m .38259 .437 L .39421 .41097 L p
1 g
F P
s
P
p
.002 w
.39421 .41097 m .37246 .3905 L .35611 .41274 L p
1 g
F P
s
P
p
.002 w
.44295 .33892 m .43738 .33321 L .41355 .35034 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .43738 .33321 L .44295 .33892 L closepath p
1 g
F P
s
P
p
.002 w
.41601 .556 m .47214 .56037 L .46711 .53681 L p
1 g
F P
s
P
p
.002 w
.46711 .53681 m .41317 .5323 L .41601 .556 L p
1 g
F P
s
P
p
.002 w
.51938 .30448 m .52119 .31973 L .55 .3245 L p
1 g
F P
s
P
p
.002 w
.52119 .31973 m .51938 .30448 L .49089 .31 L p
1 g
F P
s
P
p
.002 w
.49089 .31 m .49192 .31771 L .52119 .31973 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .49192 .31771 L .49089 .31 L closepath p
1 g
F P
s
P
p
.002 w
.40777 .33619 m .41355 .35034 L .43738 .33321 L p
1 g
F P
s
P
p
.002 w
.43738 .33321 m .43457 .32599 L .40777 .33619 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .43457 .32599 L .43738 .33321 L closepath p
1 g
F P
s
P
p
.002 w
.36542 .51397 m .41317 .5323 L .41254 .50663 L p
1 g
F P
s
P
p
.002 w
.41254 .50663 m .36797 .48904 L .36542 .51397 L p
1 g
F P
s
P
p
.002 w
.54769 .30207 m .55 .3245 L .57777 .33195 L p
1 g
F P
s
P
p
.002 w
.55 .3245 m .54769 .30207 L .51938 .30448 L p
1 g
F P
s
P
p
.002 w
.34313 .43587 m .37376 .4632 L .38259 .437 L p
1 g
F P
s
P
p
.002 w
.38259 .437 m .35611 .41274 L .34313 .43587 L p
1 g
F P
s
P
p
.002 w
.38295 .34889 m .39175 .36956 L .41355 .35034 L p
1 g
F P
s
P
p
.002 w
.41355 .35034 m .40777 .33619 L .38295 .34889 L p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .49089 .31 L .48683 .30331 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .48683 .30331 L .48016 .29837 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .48016 .29837 L .4716 .29576 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .4716 .29576 L .46208 .29578 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .46208 .29578 L .45266 .29845 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .45266 .29845 L .44442 .30346 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .44442 .30346 L .43826 .31025 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .43826 .31025 L .43486 .31805 L closepath p
1 g
F P
s
P
p
.002 w
.46277 .31848 m .43486 .31805 L .43457 .32599 L closepath p
1 g
F P
s
P
p
.002 w
.62787 .3544 m .61467 .39405 L .63402 .41251 L p
1 g
F P
s
P
p
.002 w
.61467 .39405 m .62787 .3544 L .60392 .34197 L p
1 g
F P
s
P
p
.002 w
.48683 .30331 m .49089 .31 L .51938 .30448 L p
1 g
F P
s
P
p
.002 w
.40813 .32046 m .40777 .33619 L .43457 .32599 L p
1 g
F P
s
P
p
.002 w
.43457 .32599 m .43486 .31805 L .40813 .32046 L p
1 g
F P
s
P
p
.002 w
.47801 .5813 m .53632 .57135 L .52961 .5507 L p
1 g
F P
s
P
p
.002 w
.52961 .5507 m .47214 .56037 L .47801 .5813 L p
1 g
F P
s
P
p
.002 w
.58363 .52801 m .52961 .5507 L .53632 .57135 L p
1 g
F P
s
P
p
.002 w
.36067 .3639 m .37246 .3905 L .39175 .36956 L p
1 g
F P
s
P
p
.002 w
.39175 .36956 m .38295 .34889 L .36067 .3639 L p
1 g
F P
s
P
p
.002 w
.57522 .30288 m .57777 .33195 L .60392 .34197 L p
1 g
F P
s
P
p
.002 w
.57777 .33195 m .57522 .30288 L .54769 .30207 L p
1 g
F P
s
P
p
.002 w
.58363 .52801 m .62961 .49412 L .61828 .473 L p
1 g
F P
s
P
p
.002 w
.65038 .43183 m .61828 .473 L .62961 .49412 L p
1 g
F P
s
P
p
.002 w
.61828 .473 m .65038 .43183 L .63402 .41251 L p
1 g
F P
s
P
p
.002 w
.51156 .29112 m .51938 .30448 L .54769 .30207 L p
1 g
F P
s
P
p
.002 w
.51938 .30448 m .51156 .29112 L .48683 .30331 L p
1 g
F P
s
P
p
.002 w
.48016 .29837 m .48683 .30331 L .51156 .29112 L p
1 g
F P
s
P
p
.002 w
.53632 .57135 m .59118 .54839 L .58363 .52801 L p
1 g
F P
s
P
p
.002 w
.62961 .49412 m .58363 .52801 L .59118 .54839 L p
1 g
F P
s
P
p
.002 w
.41473 .30488 m .40813 .32046 L .43486 .31805 L p
1 g
F P
s
P
p
.002 w
.43486 .31805 m .43826 .31025 L .41473 .30488 L p
1 g
F P
s
P
p
.002 w
.33391 .45938 m .36797 .48904 L .37376 .4632 L p
1 g
F P
s
P
p
.002 w
.37376 .4632 m .34313 .43587 L .33391 .45938 L p
1 g
F P
s
P
p
.002 w
.38318 .32572 m .38295 .34889 L .40777 .33619 L p
1 g
F P
s
P
p
.002 w
.40777 .33619 m .40813 .32046 L .38318 .32572 L p
1 g
F P
s
P
p
.002 w
.42111 .57715 m .47801 .5813 L .47214 .56037 L p
1 g
F P
s
P
p
.002 w
.47214 .56037 m .41601 .556 L .42111 .57715 L p
1 g
F P
s
P
p
.002 w
.51156 .29112 m .49844 .28117 L .48016 .29837 L p
1 g
F P
s
P
p
.002 w
.4716 .29576 m .48016 .29837 L .49844 .28117 L p
1 g
F P
s
P
p
.002 w
.34149 .38096 m .35611 .41274 L .37246 .3905 L p
1 g
F P
s
P
p
.002 w
.37246 .3905 m .36067 .3639 L .34149 .38096 L p
1 g
F P
s
P
p
.002 w
.36629 .53739 m .41601 .556 L .41317 .5323 L p
1 g
F P
s
P
p
.002 w
.41317 .5323 m .36542 .51397 L .36629 .53739 L p
1 g
F P
s
P
p
.002 w
.42695 .29125 m .41473 .30488 L .43826 .31025 L p
1 g
F P
s
P
p
.002 w
.43826 .31025 m .44442 .30346 L .42695 .29125 L p
1 g
F P
s
P
p
.002 w
.64905 .36904 m .63402 .41251 L .65038 .43183 L p
1 g
F P
s
P
p
.002 w
.63402 .41251 m .64905 .36904 L .62787 .3544 L p
1 g
F P
s
P
p
.002 w
.60134 .30698 m .60392 .34197 L .62787 .3544 L p
1 g
F P
s
P
p
.002 w
.60392 .34197 m .60134 .30698 L .57522 .30288 L p
1 g
F P
s
P
p
.002 w
.53646 .28225 m .54769 .30207 L .57522 .30288 L p
1 g
F P
s
P
p
.002 w
.54769 .30207 m .53646 .28225 L .51156 .29112 L p
1 g
F P
s
P
p
.002 w
.49844 .28117 m .48139 .27584 L .4716 .29576 L p
1 g
F P
s
P
p
.002 w
.46208 .29578 m .4716 .29576 L .48139 .27584 L p
1 g
F P
s
P
p
.002 w
.44345 .28116 m .42695 .29125 L .44442 .30346 L p
1 g
F P
s
P
p
.002 w
.44442 .30346 m .45266 .29845 L .44345 .28116 L p
1 g
F P
s
P
p
.002 w
.49844 .28117 m .51156 .29112 L .53646 .28225 L p
1 g
F P
s
P
p
.002 w
.48139 .27584 m .46233 .27582 L .46208 .29578 L p
1 g
F P
s
P
p
.002 w
.45266 .29845 m .46208 .29578 L .46233 .27582 L p
1 g
F P
s
P
p
.002 w
.46233 .27582 m .44345 .28116 L .45266 .29845 L p
1 g
F P
s
P
p
.002 w
.36061 .33384 m .36067 .3639 L .38295 .34889 L p
1 g
F P
s
P
p
.002 w
.38295 .34889 m .38318 .32572 L .36061 .33384 L p
1 g
F P
s
P
p
.002 w
.39274 .3026 m .38318 .32572 L .40813 .32046 L p
1 g
F P
s
P
p
.002 w
.40813 .32046 m .41473 .30488 L .39274 .3026 L p
1 g
F P
s
P
p
.002 w
.59118 .54839 m .63795 .51421 L .62961 .49412 L p
1 g
F P
s
P
p
.002 w
.66328 .4516 m .62961 .49412 L .63795 .51421 L p
1 g
F P
s
P
p
.002 w
.62961 .49412 m .66328 .4516 L .65038 .43183 L p
1 g
F P
s
P
p
.002 w
.3288 .48275 m .36542 .51397 L .36797 .48904 L p
1 g
F P
s
P
p
.002 w
.36797 .48904 m .33391 .45938 L .3288 .48275 L p
1 g
F P
s
P
p
.002 w
.32597 .39974 m .34313 .43587 L .35611 .41274 L p
1 g
F P
s
P
p
.002 w
.35611 .41274 m .34149 .38096 L .32597 .39974 L p
1 g
F P
s
P
p
.002 w
.48465 .599 m .54232 .58906 L .53632 .57135 L p
1 g
F P
s
P
p
.002 w
.53632 .57135 m .47801 .5813 L .48465 .599 L p
1 g
F P
s
P
p
.002 w
.59118 .54839 m .53632 .57135 L .54232 .58906 L p
1 g
F P
s
P
p
.002 w
.56099 .277 m .57522 .30288 L .60134 .30698 L p
1 g
F P
s
P
p
.002 w
.57522 .30288 m .56099 .277 L .53646 .28225 L p
1 g
F P
s
P
p
.002 w
.62545 .31437 m .62787 .3544 L .64905 .36904 L p
1 g
F P
s
P
p
.002 w
.62787 .3544 m .62545 .31437 L .60134 .30698 L p
1 g
F P
s
P
p
.002 w
.54232 .58906 m .59662 .56639 L .59118 .54839 L p
1 g
F P
s
P
p
.002 w
.63795 .51421 m .59118 .54839 L .59662 .56639 L p
1 g
F P
s
P
p
.002 w
.53646 .28225 m .51723 .26736 L .49844 .28117 L p
1 g
F P
s
P
p
.002 w
.48139 .27584 m .49844 .28117 L .51723 .26736 L p
1 g
F P
s
P
p
.002 w
.66689 .38565 m .65038 .43183 L .66328 .4516 L p
1 g
F P
s
P
p
.002 w
.65038 .43183 m .66689 .38565 L .64905 .36904 L p
1 g
F P
s
P
p
.002 w
.37072 .5587 m .42111 .57715 L .41601 .556 L p
1 g
F P
s
P
p
.002 w
.41601 .556 m .36629 .53739 L .37072 .5587 L p
1 g
F P
s
P
p
.002 w
.4108 .28225 m .39274 .3026 L .41473 .30488 L p
1 g
F P
s
P
p
.002 w
.41473 .30488 m .42695 .29125 L .4108 .28225 L p
1 g
F P
s
P
p
.002 w
.42844 .59515 m .48465 .599 L .47801 .5813 L p
1 g
F P
s
P
p
.002 w
.47801 .5813 m .42111 .57715 L .42844 .59515 L p
1 g
F P
s
P
p
.002 w
.51723 .26736 m .53646 .28225 L .56099 .277 L p
1 g
F P
s
P
p
.002 w
.34105 .34472 m .34149 .38096 L .36067 .3639 L p
1 g
F P
s
P
p
.002 w
.36067 .3639 m .36061 .33384 L .34105 .34472 L p
1 g
F P
s
P
p
.002 w
.51723 .26736 m .49198 .2593 L .48139 .27584 L p
1 g
F P
s
P
p
.002 w
.46233 .27582 m .48139 .27584 L .49198 .2593 L p
1 g
F P
s
P
p
.002 w
.37285 .30361 m .36061 .33384 L .38318 .32572 L p
1 g
F P
s
P
p
.002 w
.38318 .32572 m .39274 .3026 L .37285 .30361 L p
1 g
F P
s
P
p
.002 w
.31463 .41988 m .33391 .45938 L .34313 .43587 L p
1 g
F P
s
P
p
.002 w
.34313 .43587 m .32597 .39974 L .31463 .41988 L p
1 g
F P
s
P
p
.002 w
.43538 .26715 m .4108 .28225 L .42695 .29125 L p
1 g
F P
s
P
p
.002 w
.42695 .29125 m .44345 .28116 L .43538 .26715 L p
1 g
F P
s
P
p
.002 w
.3281 .50542 m .36629 .53739 L .36542 .51397 L p
1 g
F P
s
P
p
.002 w
.36542 .51397 m .3288 .48275 L .3281 .50542 L p
1 g
F P
s
P
p
.002 w
.49198 .2593 m .46357 .25919 L .46233 .27582 L p
1 g
F P
s
P
p
.002 w
.44345 .28116 m .46233 .27582 L .46357 .25919 L p
1 g
F P
s
P
p
.002 w
.46357 .25919 m .43538 .26715 L .44345 .28116 L p
1 g
F P
s
P
p
.002 w
.58458 .27562 m .60134 .30698 L .62545 .31437 L p
1 g
F P
s
P
p
.002 w
.60134 .30698 m .58458 .27562 L .56099 .277 L p
1 g
F P
s
P
p
.002 w
.6469 .32501 m .64905 .36904 L .66689 .38565 L p
1 g
F P
s
P
p
.002 w
.64905 .36904 m .6469 .32501 L .62545 .31437 L p
1 g
F P
s
P
p
.002 w
.59662 .56639 m .64296 .53277 L .63795 .51421 L p
1 g
F P
s
P
p
.002 w
.6723 .47141 m .63795 .51421 L .64296 .53277 L p
1 g
F P
s
P
p
.002 w
.63795 .51421 m .6723 .47141 L .66328 .4516 L p
1 g
F P
s
P
p
.002 w
.56099 .277 m .53614 .25741 L .51723 .26736 L p
1 g
F P
s
P
p
.002 w
.49198 .2593 m .51723 .26736 L .53614 .25741 L p
1 g
F P
s
P
p
.002 w
.49193 .61292 m .54742 .60327 L .54232 .58906 L p
1 g
F P
s
P
p
.002 w
.54232 .58906 m .48465 .599 L .49193 .61292 L p
1 g
F P
s
P
p
.002 w
.59662 .56639 m .54232 .58906 L .54742 .60327 L p
1 g
F P
s
P
p
.002 w
.68083 .40392 m .66328 .4516 L .6723 .47141 L p
1 g
F P
s
P
p
.002 w
.66328 .4516 m .68083 .40392 L .66689 .38565 L p
1 g
F P
s
P
p
.002 w
.53614 .25741 m .56099 .277 L .58458 .27562 L p
1 g
F P
s
P
p
.002 w
.32512 .35825 m .32597 .39974 L .34149 .38096 L p
1 g
F P
s
P
p
.002 w
.34149 .38096 m .34105 .34472 L .32512 .35825 L p
1 g
F P
s
P
p
.002 w
.37875 .57728 m .42844 .59515 L .42111 .57715 L p
1 g
F P
s
P
p
.002 w
.42111 .57715 m .37072 .5587 L .37875 .57728 L p
1 g
F P
s
P
p
.002 w
.54742 .60327 m .59972 .58148 L .59662 .56639 L p
1 g
F P
s
P
p
.002 w
.64296 .53277 m .59662 .56639 L .59972 .58148 L p
1 g
F P
s
P
p
.002 w
.39641 .27684 m .37285 .30361 L .39274 .3026 L p
1 g
F P
s
P
p
.002 w
.39274 .3026 m .4108 .28225 L .39641 .27684 L p
1 g
F P
s
P
p
.002 w
.30793 .44092 m .3288 .48275 L .33391 .45938 L p
1 g
F P
s
P
p
.002 w
.33391 .45938 m .31463 .41988 L .30793 .44092 L p
1 g
F P
s
P
p
.002 w
.43795 .6094 m .49193 .61292 L .48465 .599 L p
1 g
F P
s
P
p
.002 w
.48465 .599 m .42844 .59515 L .43795 .6094 L p
1 g
F P
s
P
p
.002 w
.35566 .30804 m .34105 .34472 L .36061 .33384 L p
1 g
F P
s
P
p
.002 w
.36061 .33384 m .37285 .30361 L .35566 .30804 L p
1 g
F P
s
P
p
.002 w
.60663 .2783 m .62545 .31437 L .6469 .32501 L p
1 g
F P
s
P
p
.002 w
.62545 .31437 m .60663 .2783 L .58458 .27562 L p
1 g
F P
s
P
p
.002 w
.33202 .52678 m .37072 .5587 L .36629 .53739 L p
1 g
F P
s
P
p
.002 w
.36629 .53739 m .3281 .50542 L .33202 .52678 L p
1 g
F P
s
P
p
.002 w
.53614 .25741 m .50316 .24669 L .49198 .2593 L p
1 g
F P
s
P
p
.002 w
.46357 .25919 m .49198 .2593 L .50316 .24669 L p
1 g
F P
s
P
p
.002 w
.66506 .33879 m .66689 .38565 L .68083 .40392 L p
1 g
F P
s
P
p
.002 w
.66689 .38565 m .66506 .33879 L .6469 .32501 L p
1 g
F P
s
P
p
.002 w
.42871 .25694 m .39641 .27684 L .4108 .28225 L p
1 g
F P
s
P
p
.002 w
.4108 .28225 m .43538 .26715 L .42871 .25694 L p
1 g
F P
s
P
p
.002 w
.50316 .24669 m .46584 .24646 L .46357 .25919 L p
1 g
F P
s
P
p
.002 w
.43538 .26715 m .46357 .25919 L .46584 .24646 L p
1 g
F P
s
P
p
.002 w
.46584 .24646 m .42871 .25694 L .43538 .26715 L p
1 g
F P
s
P
p
.002 w
.59972 .58148 m .64435 .54929 L .64296 .53277 L p
1 g
F P
s
P
p
.002 w
.67704 .49078 m .64296 .53277 L .64435 .54929 L p
1 g
F P
s
P
p
.002 w
.64296 .53277 m .67704 .49078 L .6723 .47141 L p
1 g
F P
s
P
p
.002 w
.55472 .25172 m .58458 .27562 L .60663 .2783 L p
1 g
F P
s
P
p
.002 w
.58458 .27562 m .55472 .25172 L .53614 .25741 L p
1 g
F P
s
P
p
.002 w
.31339 .37421 m .31463 .41988 L .32597 .39974 L p
1 g
F P
s
P
p
.002 w
.32597 .39974 m .32512 .35825 L .31339 .37421 L p
1 g
F P
s
P
p
.002 w
.50316 .24669 m .53614 .25741 L .55472 .25172 L p
1 g
F P
s
P
p
.002 w
.69035 .42346 m .6723 .47141 L .67704 .49078 L p
1 g
F P
s
P
p
.002 w
.6723 .47141 m .69035 .42346 L .68083 .40392 L p
1 g
F P
s
P
p
.002 w
.30626 .46236 m .3281 .50542 L .3288 .48275 L p
1 g
F P
s
P
p
.002 w
.3288 .48275 m .30793 .44092 L .30626 .46236 L p
1 g
F P
s
P
p
.002 w
.49973 .62248 m .55146 .61342 L .54742 .60327 L p
1 g
F P
s
P
p
.002 w
.54742 .60327 m .49193 .61292 L .49973 .62248 L p
1 g
F P
s
P
p
.002 w
.59972 .58148 m .54742 .60327 L .55146 .61342 L p
1 g
F P
s
P
p
.002 w
.39037 .5925 m .43795 .6094 L .42844 .59515 L p
1 g
F P
s
P
p
.002 w
.42844 .59515 m .37875 .57728 L .39037 .5925 L p
1 g
F P
s
P
p
.002 w
.38425 .27538 m .35566 .30804 L .37285 .30361 L p
1 g
F P
s
P
p
.002 w
.37285 .30361 m .39641 .27684 L .38425 .27538 L p
1 g
F P
s
P
p
.002 w
.34175 .31597 m .32512 .35825 L .34105 .34472 L p
1 g
F P
s
P
p
.002 w
.34105 .34472 m .35566 .30804 L .34175 .31597 L p
1 g
F P
s
P
p
.002 w
.62652 .28518 m .6469 .32501 L .66506 .33879 L p
1 g
F P
s
P
p
.002 w
.6469 .32501 m .62652 .28518 L .60663 .2783 L p
1 g
F P
s
P
p
.002 w
.55146 .61342 m .60026 .59312 L .59972 .58148 L p
1 g
F P
s
P
p
.002 w
.64435 .54929 m .59972 .58148 L .60026 .59312 L p
1 g
F P
s
P
p
.002 w
.34069 .5462 m .37875 .57728 L .37072 .5587 L p
1 g
F P
s
P
p
.002 w
.37072 .5587 m .33202 .52678 L .34069 .5462 L p
1 g
F P
s
P
p
.002 w
.44952 .61932 m .49973 .62248 L .49193 .61292 L p
1 g
F P
s
P
p
.002 w
.49193 .61292 m .43795 .6094 L .44952 .61932 L p
1 g
F P
s
P
p
.002 w
.67931 .35548 m .68083 .40392 L .69035 .42346 L p
1 g
F P
s
P
p
.002 w
.68083 .40392 m .67931 .35548 L .66506 .33879 L p
1 g
F P
s
P
p
.002 w
.55472 .25172 m .51469 .23855 L .50316 .24669 L p
1 g
F P
s
P
p
.002 w
.46584 .24646 m .50316 .24669 L .51469 .23855 L p
1 g
F P
s
P
p
.002 w
.4237 .25101 m .38425 .27538 L .39641 .27684 L p
1 g
F P
s
P
p
.002 w
.39641 .27684 m .42871 .25694 L .4237 .25101 L p
1 g
F P
s
P
p
.002 w
.30641 .39229 m .30793 .44092 L .31463 .41988 L p
1 g
F P
s
P
p
.002 w
.31463 .41988 m .31339 .37421 L .30641 .39229 L p
1 g
F P
s
P
p
.002 w
.57248 .25066 m .60663 .2783 L .62652 .28518 L p
1 g
F P
s
P
p
.002 w
.60663 .2783 m .57248 .25066 L .55472 .25172 L p
1 g
F P
s
P
p
.002 w
.60026 .59312 m .64188 .56323 L .64435 .54929 L p
1 g
F P
s
P
p
.002 w
.67715 .50921 m .64435 .54929 L .64188 .56323 L p
1 g
F P
s
P
p
.002 w
.64435 .54929 m .67715 .50921 L .67704 .49078 L p
1 g
F P
s
P
p
.002 w
.51469 .23855 m .55472 .25172 L .57248 .25066 L p
1 g
F P
s
P
p
.002 w
.69501 .44384 m .67704 .49078 L .67715 .50921 L p
1 g
F P
s
P
p
.002 w
.67704 .49078 m .69501 .44384 L .69035 .42346 L p
1 g
F P
s
P
p
.002 w
.51469 .23855 m .46912 .2382 L .46584 .24646 L p
1 g
F P
s
P
p
.002 w
.42871 .25694 m .46584 .24646 L .46912 .2382 L p
1 g
F P
s
P
p
.002 w
.30994 .48363 m .33202 .52678 L .3281 .50542 L p
1 g
F P
s
P
p
.002 w
.3281 .50542 m .30626 .46236 L .30994 .48363 L p
1 g
F P
s
P
p
.002 w
.46912 .2382 m .4237 .25101 L .42871 .25694 L p
1 g
F P
s
P
p
.002 w
.64361 .29627 m .66506 .33879 L .67931 .35548 L p
1 g
F P
s
P
p
.002 w
.66506 .33879 m .64361 .29627 L .62652 .28518 L p
1 g
F P
s
P
p
.002 w
.33169 .3274 m .31339 .37421 L .32512 .35825 L p
1 g
F P
s
P
p
.002 w
.32512 .35825 m .34175 .31597 L .33169 .3274 L p
1 g
F P
s
P
p
.002 w
.37478 .27813 m .34175 .31597 L .35566 .30804 L p
1 g
F P
s
P
p
.002 w
.35566 .30804 m .38425 .27538 L .37478 .27813 L p
1 g
F P
s
P
p
.002 w
.40545 .60378 m .44952 .61932 L .43795 .6094 L p
1 g
F P
s
P
p
.002 w
.43795 .6094 m .39037 .5925 L .40545 .60378 L p
1 g
F P
s
P
p
.002 w
.50785 .62716 m .55427 .61901 L .55146 .61342 L p
1 g
F P
s
P
p
.002 w
.55146 .61342 m .49973 .62248 L .50785 .62716 L p
1 g
F P
s
P
p
.002 w
.60026 .59312 m .55146 .61342 L .55427 .61901 L p
1 g
F P
s
P
p
.002 w
.35411 .56304 m .39037 .5925 L .37875 .57728 L p
1 g
F P
s
P
p
.002 w
.37875 .57728 m .34069 .5462 L .35411 .56304 L p
1 g
F P
s
P
p
.002 w
.68908 .37479 m .69035 .42346 L .69501 .44384 L p
1 g
F P
s
P
p
.002 w
.69035 .42346 m .68908 .37479 L .67931 .35548 L p
1 g
F P
s
P
p
.002 w
.55427 .61901 m .59809 .6008 L .60026 .59312 L p
1 g
F P
s
P
p
.002 w
.64188 .56323 m .60026 .59312 L .59809 .6008 L p
1 g
F P
s
P
p
.002 w
.46294 .62438 m .50785 .62716 L .49973 .62248 L p
1 g
F P
s
P
p
.002 w
.49973 .62248 m .44952 .61932 L .46294 .62438 L p
1 g
F P
s
P
p
.002 w
.30464 .41208 m .30626 .46236 L .30793 .44092 L p
1 g
F P
s
P
p
.002 w
.30793 .44092 m .30641 .39229 L .30464 .41208 L p
1 g
F P
s
P
p
.002 w
.57248 .25066 m .52629 .23536 L .51469 .23855 L p
1 g
F P
s
P
p
.002 w
.46912 .2382 m .51469 .23855 L .52629 .23536 L p
1 g
F P
s
P
p
.002 w
.58892 .25453 m .62652 .28518 L .64361 .29627 L p
1 g
F P
s
P
p
.002 w
.62652 .28518 m .58892 .25453 L .57248 .25066 L p
1 g
F P
s
P
p
.002 w
.42059 .24981 m .37478 .27813 L .38425 .27538 L p
1 g
F P
s
P
p
.002 w
.38425 .27538 m .4237 .25101 L .42059 .24981 L p
1 g
F P
s
P
p
.002 w
.31912 .5041 m .34069 .5462 L .33202 .52678 L p
1 g
F P
s
P
p
.002 w
.33202 .52678 m .30994 .48363 L .31912 .5041 L p
1 g
F P
s
P
p
.002 w
.64188 .56323 m .67238 .52615 L .67715 .50921 L p
1 g
F P
s
P
p
.002 w
.69442 .46455 m .67715 .50921 L .67238 .52615 L p
1 g
F P
s
P
p
.002 w
.67715 .50921 m .69442 .46455 L .69501 .44384 L p
1 g
F P
s
P
p
.002 w
.52629 .23536 m .57248 .25066 L .58892 .25453 L p
1 g
F P
s
P
p
.002 w
.59809 .6008 m .63538 .57407 L .64188 .56323 L p
1 g
F P
s
P
p
.002 w
.67238 .52615 m .64188 .56323 L .63538 .57407 L p
1 g
F P
s
P
p
.002 w
.65729 .3115 m .67931 .35548 L .68908 .37479 L p
1 g
F P
s
P
p
.002 w
.67931 .35548 m .65729 .3115 L .64361 .29627 L p
1 g
F P
s
P
p
.002 w
.52629 .23536 m .47341 .23492 L .46912 .2382 L p
1 g
F P
s
P
p
.002 w
.4237 .25101 m .46912 .2382 L .47341 .23492 L p
1 g
F P
s
P
p
.002 w
.326 .34219 m .30641 .39229 L .31339 .37421 L p
1 g
F P
s
P
p
.002 w
.31339 .37421 m .33169 .3274 L .326 .34219 L p
1 g
F P
s
P
p
.002 w
.47341 .23492 m .42059 .24981 L .4237 .25101 L p
1 g
F P
s
P
p
.002 w
.36843 .2853 m .33169 .3274 L .34175 .31597 L p
1 g
F P
s
P
p
.002 w
.34175 .31597 m .37478 .27813 L .36843 .2853 L p
1 g
F P
s
P
p
.002 w
.42375 .61057 m .46294 .62438 L .44952 .61932 L p
1 g
F P
s
P
p
.002 w
.44952 .61932 m .40545 .60378 L .42375 .61057 L p
1 g
F P
s
P
p
.002 w
.69501 .44384 m .69388 .39629 L .68908 .37479 L p
1 g
F P
s
P
p
.002 w
.69388 .39629 m .69501 .44384 L .69442 .46455 L p
1 g
F P
s
P
p
.002 w
.37212 .57667 m .40545 .60378 L .39037 .5925 L p
1 g
F P
s
P
p
.002 w
.39037 .5925 m .35411 .56304 L .37212 .57667 L p
1 g
F P
s
P
p
.004 w
.43786 .61529 m
.5 .43051 L
s
P
p
.004 w
.4374 .61665 m
.43778 .61552 L
s
P
p
.004 w
.40524 .71227 m
.4374 .61665 L
s
P
p
.002 w
.51611 .62653 m .55569 .61958 L .55427 .61901 L p
1 g
F P
s
P
p
.002 w
.55427 .61901 m .50785 .62716 L .51611 .62653 L p
1 g
F P
s
P
p
.002 w
.59809 .6008 m .55427 .61901 L .55569 .61958 L p
1 g
F P
s
P
p
.002 w
.30839 .4331 m .30994 .48363 L .30626 .46236 L p
1 g
F P
s
P
p
.002 w
.30626 .46236 m .30464 .41208 L .30839 .4331 L p
1 g
F P
s
P
p
.002 w
.55569 .61958 m .59306 .60404 L .59809 .6008 L p
1 g
F P
s
P
p
.002 w
.63538 .57407 m .59809 .6008 L .59306 .60404 L p
1 g
F P
s
P
p
.002 w
.64361 .29627 m .60348 .26349 L .58892 .25453 L p
1 g
F P
s
P
p
.002 w
.60348 .26349 m .64361 .29627 L .65729 .3115 L p
1 g
F P
s
P
p
.002 w
.47796 .62416 m .51611 .62653 L .50785 .62716 L p
1 g
F P
s
P
p
.002 w
.50785 .62716 m .46294 .62438 L .47796 .62416 L p
1 g
F P
s
P
p
.002 w
.33378 .52312 m .35411 .56304 L .34069 .5462 L p
1 g
F P
s
P
p
.002 w
.34069 .5462 m .31912 .5041 L .33378 .52312 L p
1 g
F P
s
P
p
.002 w
.58892 .25453 m .53763 .23751 L .52629 .23536 L p
1 g
F P
s
P
p
.002 w
.47341 .23492 m .52629 .23536 L .53763 .23751 L p
1 g
F P
s
P
p
.002 w
.68908 .37479 m .66697 .33063 L .65729 .3115 L p
1 g
F P
s
P
p
.002 w
.66697 .33063 m .68908 .37479 L .69388 .39629 L p
1 g
F P
s
P
p
.002 w
.63538 .57407 m .66259 .54103 L .67238 .52615 L p
1 g
F P
s
P
p
.002 w
.67238 .52615 m .68832 .48501 L .69442 .46455 L p
1 g
F P
s
P
p
.002 w
.68832 .48501 m .67238 .52615 L .66259 .54103 L p
1 g
F P
s
P
p
.002 w
.53763 .23751 m .58892 .25453 L .60348 .26349 L p
1 g
F P
s
P
p
.002 w
.41959 .2537 m .36843 .2853 L .37478 .27813 L p
1 g
F P
s
P
p
.002 w
.37478 .27813 m .42059 .24981 L .41959 .2537 L p
1 g
F P
s
P
p
.002 w
.3251 .3601 m .30464 .41208 L .30641 .39229 L p
1 g
F P
s
P
p
.002 w
.30641 .39229 m .326 .34219 L .3251 .3601 L p
1 g
F P
s
P
p
.002 w
.59306 .60404 m .6248 .5813 L .63538 .57407 L p
1 g
F P
s
P
p
.002 w
.66259 .54103 m .63538 .57407 L .6248 .5813 L p
1 g
F P
s
P
p
.002 w
.69332 .41948 m .69442 .46455 L .68832 .48501 L p
1 g
F P
s
P
p
.002 w
.69442 .46455 m .69332 .41948 L .69388 .39629 L p
1 g
F P
s
P
p
.002 w
.53763 .23751 m .47863 .23705 L .47341 .23492 L p
1 g
F P
s
P
p
.002 w
.42059 .24981 m .47341 .23492 L .47863 .23705 L p
1 g
F P
s
P
p
.002 w
.39439 .58652 m .42375 .61057 L .40545 .60378 L p
1 g
F P
s
P
p
.002 w
.40545 .60378 m .37212 .57667 L .39439 .58652 L p
1 g
F P
s
P
p
.002 w
.3656 .29696 m .326 .34219 L .33169 .3274 L p
1 g
F P
s
P
p
.002 w
.33169 .3274 m .36843 .2853 L .3656 .29696 L p
1 g
F P
s
P
p
.002 w
.44489 .61243 m .47796 .62416 L .46294 .62438 L p
1 g
F P
s
P
p
.002 w
.46294 .62438 m .42375 .61057 L .44489 .61243 L p
1 g
F P
s
P
p
.002 w
.47863 .23705 m .41959 .2537 L .42059 .24981 L p
1 g
F P
s
P
p
.002 w
.31784 .45475 m .31912 .5041 L .30994 .48363 L p
1 g
F P
s
P
p
.002 w
.30994 .48363 m .30839 .4331 L .31784 .45475 L p
1 g
F P
s
P
p
.002 w
.61563 .27757 m .65729 .3115 L .66697 .33063 L p
1 g
F P
s
P
p
.002 w
.65729 .3115 m .61563 .27757 L .60348 .26349 L p
1 g
F P
s
P
p
.002 w
.35373 .54 m .37212 .57667 L .35411 .56304 L p
1 g
F P
s
P
p
.002 w
.35411 .56304 m .33378 .52312 L .35373 .54 L p
1 g
F P
s
P
p
.002 w
.52426 .62025 m .55558 .61477 L .55569 .61958 L p
1 g
F P
s
P
p
.002 w
.55569 .61958 m .51611 .62653 L .52426 .62025 L p
1 g
F P
s
P
p
.002 w
.59306 .60404 m .55569 .61958 L .55558 .61477 L p
1 g
F P
s
P
p
.002 w
.55558 .61477 m .58516 .60246 L .59306 .60404 L p
1 g
F P
s
P
p
.002 w
.6248 .5813 m .59306 .60404 L .58516 .60246 L p
1 g
F P
s
P
p
.002 w
.67217 .35327 m .69388 .39629 L .69332 .41948 L p
1 g
F P
s
P
p
.002 w
.69388 .39629 m .67217 .35327 L .66697 .33063 L p
1 g
F P
s
P
p
.002 w
.49419 .61833 m .52426 .62025 L .51611 .62653 L p
1 g
F P
s
P
p
.002 w
.51611 .62653 m .47796 .62416 L .49419 .61833 L p
1 g
F P
s
P
p
.002 w
.60348 .26349 m .54836 .24528 L .53763 .23751 L p
1 g
F P
s
P
p
.002 w
.47863 .23705 m .53763 .23751 L .54836 .24528 L p
1 g
F P
s
P
p
.002 w
.6248 .5813 m .64779 .55331 L .66259 .54103 L p
1 g
F P
s
P
p
.002 w
.67664 .50458 m .66259 .54103 L .64779 .55331 L p
1 g
F P
s
P
p
.002 w
.66259 .54103 m .67664 .50458 L .68832 .48501 L p
1 g
F P
s
P
p
.002 w
.54836 .24528 m .60348 .26349 L .61563 .27757 L p
1 g
F P
s
P
p
.002 w
.32931 .38073 m .30839 .4331 L .30464 .41208 L p
1 g
F P
s
P
p
.002 w
.30464 .41208 m .3251 .3601 L .32931 .38073 L p
1 g
F P
s
P
p
.002 w
.68715 .4437 m .68832 .48501 L .67664 .50458 L p
1 g
F P
s
P
p
.002 w
.68832 .48501 m .68715 .4437 L .69332 .41948 L p
1 g
F P
s
P
p
.002 w
.42089 .26288 m .3656 .29696 L .36843 .2853 L p
1 g
F P
s
P
p
.002 w
.36843 .2853 m .41959 .2537 L .42089 .26288 L p
1 g
F P
s
P
p
.002 w
.58516 .60246 m .61019 .58448 L .6248 .5813 L p
1 g
F P
s
P
p
.002 w
.64779 .55331 m .6248 .5813 L .61019 .58448 L p
1 g
F P
s
P
p
.002 w
.42041 .5921 m .44489 .61243 L .42375 .61057 L p
1 g
F P
s
P
p
.002 w
.42375 .61057 m .39439 .58652 L .42041 .5921 L p
1 g
F P
s
P
p
.002 w
.33296 .47634 m .33378 .52312 L .31912 .5041 L p
1 g
F P
s
P
p
.002 w
.31912 .5041 m .31784 .45475 L .33296 .47634 L p
1 g
F P
s
P
p
.002 w
.36659 .313 m .3251 .3601 L .326 .34219 L p
1 g
F P
s
P
p
.002 w
.326 .34219 m .3656 .29696 L .36659 .313 L p
1 g
F P
s
P
p
.002 w
.46834 .60903 m .49419 .61833 L .47796 .62416 L p
1 g
F P
s
P
p
.002 w
.47796 .62416 m .44489 .61243 L .46834 .60903 L p
1 g
F P
s
P
p
.002 w
.54836 .24528 m .48471 .24487 L .47863 .23705 L p
1 g
F P
s
P
p
.002 w
.41959 .2537 m .47863 .23705 L .48471 .24487 L p
1 g
F P
s
P
p
.002 w
.62485 .29662 m .66697 .33063 L .67217 .35327 L p
1 g
F P
s
P
p
.002 w
.66697 .33063 m .62485 .29662 L .61563 .27757 L p
1 g
F P
s
P
p
.002 w
.48471 .24487 m .42089 .26288 L .41959 .2537 L p
1 g
F P
s
P
p
.002 w
.37854 .55412 m .39439 .58652 L .37212 .57667 L p
1 g
F P
s
P
p
.002 w
.37212 .57667 m .35373 .54 L .37854 .55412 L p
1 g
F P
s
P
p
.002 w
.67249 .37888 m .69332 .41948 L .68715 .4437 L p
1 g
F P
s
P
p
.002 w
.69332 .41948 m .67249 .37888 L .67217 .35327 L p
1 g
F P
s
P
p
.002 w
.53204 .60817 m .55384 .60437 L .55558 .61477 L p
1 g
F P
s
P
p
.002 w
.55558 .61477 m .52426 .62025 L .53204 .60817 L p
1 g
F P
s
P
p
.002 w
.58516 .60246 m .55558 .61477 L .55384 .60437 L p
1 g
F P
s
P
p
.002 w
.61019 .58448 m .62816 .56245 L .64779 .55331 L p
1 g
F P
s
P
p
.002 w
.65944 .52263 m .64779 .55331 L .62816 .56245 L p
1 g
F P
s
P
p
.002 w
.64779 .55331 m .65944 .52263 L .67664 .50458 L p
1 g
F P
s
P
p
.002 w
.55384 .60437 m .57443 .59579 L .58516 .60246 L p
1 g
F P
s
P
p
.002 w
.61019 .58448 m .58516 .60246 L .57443 .59579 L p
1 g
F P
s
P
p
.002 w
.55811 .25877 m .61563 .27757 L .62485 .29662 L p
1 g
F P
s
P
p
.002 w
.61563 .27757 m .55811 .25877 L .54836 .24528 L p
1 g
F P
s
P
p
.002 w
.33874 .40353 m .31784 .45475 L .30839 .4331 L p
1 g
F P
s
P
p
.002 w
.30839 .4331 m .32931 .38073 L .33874 .40353 L p
1 g
F P
s
P
p
.002 w
.67533 .46823 m .67664 .50458 L .65944 .52263 L p
1 g
F P
s
P
p
.002 w
.67664 .50458 m .67533 .46823 L .68715 .4437 L p
1 g
F P
s
P
p
.002 w
.48471 .24487 m .54836 .24528 L .55811 .25877 L p
1 g
F P
s
P
p
.002 w
.51121 .60677 m .53204 .60817 L .52426 .62025 L p
1 g
F P
s
P
p
.002 w
.52426 .62025 m .49419 .61833 L .51121 .60677 L p
1 g
F P
s
P
p
.002 w
.35347 .49714 m .35373 .54 L .33378 .52312 L p
1 g
F P
s
P
p
.002 w
.33378 .52312 m .33296 .47634 L .35347 .49714 L p
1 g
F P
s
P
p
.002 w
.44947 .59304 m .46834 .60903 L .44489 .61243 L p
1 g
F P
s
P
p
.002 w
.44489 .61243 m .42041 .5921 L .44947 .59304 L p
1 g
F P
s
P
p
.002 w
.42458 .27741 m .36659 .313 L .3656 .29696 L p
1 g
F P
s
P
p
.002 w
.3656 .29696 m .42089 .26288 L .42458 .27741 L p
1 g
F P
s
P
p
.002 w
.57443 .59579 m .59178 .58327 L .61019 .58448 L p
1 g
F P
s
P
p
.002 w
.62816 .56245 m .61019 .58448 L .59178 .58327 L p
1 g
F P
s
P
p
.002 w
.63068 .32026 m .67217 .35327 L .67249 .37888 L p
1 g
F P
s
P
p
.002 w
.67217 .35327 m .63068 .32026 L .62485 .29662 L p
1 g
F P
s
P
p
.002 w
.37161 .33316 m .32931 .38073 L .3251 .3601 L p
1 g
F P
s
P
p
.002 w
.3251 .3601 m .36659 .313 L .37161 .33316 L p
1 g
F P
s
P
p
.002 w
.40754 .56487 m .42041 .5921 L .39439 .58652 L p
1 g
F P
s
P
p
.002 w
.39439 .58652 m .37854 .55412 L .40754 .56487 L p
1 g
F P
s
P
p
.002 w
.49345 .60025 m .51121 .60677 L .49419 .61833 L p
1 g
F P
s
P
p
.002 w
.49419 .61833 m .46834 .60903 L .49345 .60025 L p
1 g
F P
s
P
p
.002 w
.66771 .40673 m .68715 .4437 L .67533 .46823 L p
1 g
F P
s
P
p
.002 w
.68715 .4437 m .66771 .40673 L .67249 .37888 L p
1 g
F P
s
P
p
.002 w
.55811 .25877 m .49149 .2585 L .48471 .24487 L p
1 g
F P
s
P
p
.002 w
.42089 .26288 m .48471 .24487 L .49149 .2585 L p
1 g
F P
s
P
p
.002 w
.49149 .2585 m .42458 .27741 L .42089 .26288 L p
1 g
F P
s
P
p
.002 w
.62816 .56245 m .63706 .53848 L .65944 .52263 L p
1 g
F P
s
P
p
.002 w
.65801 .49227 m .65944 .52263 L .63706 .53848 L p
1 g
F P
s
P
p
.002 w
.65944 .52263 m .65801 .49227 L .67533 .46823 L p
1 g
F P
s
P
p
.002 w
.59178 .58327 m .6041 .568 L .62816 .56245 L p
1 g
F P
s
P
p
.002 w
.63706 .53848 m .62816 .56245 L .6041 .568 L p
1 g
F P
s
P
p
.002 w
.35332 .42782 m .33296 .47634 L .31784 .45475 L p
1 g
F P
s
P
p
.002 w
.31784 .45475 m .33874 .40353 L .35332 .42782 L p
1 g
F P
s
P
p
.002 w
.5665 .27787 m .62485 .29662 L .63068 .32026 L p
1 g
F P
s
P
p
.002 w
.62485 .29662 m .5665 .27787 L .55811 .25877 L p
1 g
F P
s
P
p
.002 w
.37886 .5164 m .37854 .55412 L .35373 .54 L p
1 g
F P
s
P
p
.002 w
.35373 .54 m .35347 .49714 L .37886 .5164 L p
1 g
F P
s
P
p
.002 w
.53917 .59032 m .55043 .58838 L .55384 .60437 L p
1 g
F P
s
P
p
.002 w
.55384 .60437 m .53204 .60817 L .53917 .59032 L p
1 g
F P
s
P
p
.002 w
.57443 .59579 m .55384 .60437 L .55043 .58838 L p
1 g
F P
s
P
p
.002 w
.49149 .2585 m .55811 .25877 L .5665 .27787 L p
1 g
F P
s
P
p
.002 w
.48069 .58915 m .49345 .60025 L .46834 .60903 L p
1 g
F P
s
P
p
.002 w
.46834 .60903 m .44947 .59304 L .48069 .58915 L p
1 g
F P
s
P
p
.002 w
.55043 .58838 m .56106 .58394 L .57443 .59579 L p
1 g
F P
s
P
p
.002 w
.59178 .58327 m .57443 .59579 L .56106 .58394 L p
1 g
F P
s
P
p
.002 w
.52846 .58956 m .53917 .59032 L .53204 .60817 L p
1 g
F P
s
P
p
.002 w
.53204 .60817 m .51121 .60677 L .52846 .58956 L p
1 g
F P
s
P
p
.002 w
.43985 .57179 m .44947 .59304 L .42041 .5921 L p
1 g
F P
s
P
p
.002 w
.42041 .5921 m .40754 .56487 L .43985 .57179 L p
1 g
F P
s
P
p
.002 w
.63277 .3479 m .67249 .37888 L .66771 .40673 L p
1 g
F P
s
P
p
.002 w
.67249 .37888 m .63277 .3479 L .63068 .32026 L p
1 g
F P
s
P
p
.002 w
.65779 .43595 m .67533 .46823 L .65801 .49227 L p
1 g
F P
s
P
p
.002 w
.67533 .46823 m .65779 .43595 L .66771 .40673 L p
1 g
F P
s
P
p
.002 w
.56106 .58394 m .56998 .57746 L .59178 .58327 L p
1 g
F P
s
P
p
.002 w
.6041 .568 m .59178 .58327 L .56998 .57746 L p
1 g
F P
s
P
p
.002 w
.38069 .35695 m .33874 .40353 L .32931 .38073 L p
1 g
F P
s
P
p
.002 w
.32931 .38073 m .37161 .33316 L .38069 .35695 L p
1 g
F P
s
P
p
.002 w
.43069 .2971 m .37161 .33316 L .36659 .313 L p
1 g
F P
s
P
p
.002 w
.36659 .313 m .42458 .27741 L .43069 .2971 L p
1 g
F P
s
P
p
.002 w
.51942 .58614 m .52846 .58956 L .51121 .60677 L p
1 g
F P
s
P
p
.002 w
.51121 .60677 m .49345 .60025 L .51942 .58614 L p
1 g
F P
s
P
p
.002 w
.6041 .568 m .61002 .55151 L .63706 .53848 L p
1 g
F P
s
P
p
.002 w
.63561 .51497 m .63706 .53848 L .61002 .55151 L p
1 g
F P
s
P
p
.002 w
.63706 .53848 m .63561 .51497 L .65801 .49227 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.40835 .53336 m .40754 .56487 L .37854 .55412 L p
1 g
F P
s
P
p
.002 w
.37854 .55412 m .37886 .5164 L .40835 .53336 L p
1 g
F P
s
P
p
.002 w
.37272 .45277 m .35347 .49714 L .33296 .47634 L p
1 g
F P
s
P
p
.002 w
.33296 .47634 m .35332 .42782 L .37272 .45277 L p
1 g
F P
s
P
p
.002 w
.56998 .57746 m .57623 .56959 L .6041 .568 L p
1 g
F P
s
P
p
.002 w
.61002 .55151 m .6041 .568 L .57623 .56959 L p
1 g
F P
s
P
p
.002 w
.5665 .27787 m .49878 .27782 L .49149 .2585 L p
1 g
F P
s
P
p
.002 w
.42458 .27741 m .49149 .2585 L .49878 .27782 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53536 .5369 L
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.57317 .30222 m .63068 .32026 L .63277 .3479 L p
1 g
F P
s
P
p
.002 w
.63068 .32026 m .57317 .30222 L .5665 .27787 L p
1 g
F P
s
P
p
.002 w
.49878 .27782 m .43069 .2971 L .42458 .27741 L p
1 g
F P
s
P
p
.002 w
.48069 .58915 m .44947 .59304 L p
.47219 .57618 L 1 g
F P
s
P
p
.002 w
.47565 .5774 m .48069 .58915 L p
.47219 .57618 L 1 g
F P
s
P
p
.002 w
.44947 .59304 m .43985 .57179 L .46551 .57382 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46825 .57479 L p
1 g
F P
s
P
p
.48921 .57862 m .46825 .57479 L .47565 .5774 L 1 g
F
P
p
.002 w
.48069 .58915 m .47688 .58027 L p
.49406 .58175 L 1 g
F P
s
P
p
.002 w
.47688 .58027 m .47565 .5774 L p
.48906 .58057 L 1 g
F P
s
P
p
.47688 .58027 m .48906 .58057 L .49406 .58175 L 1 g
F
P
p
.002 w
.51942 .58614 m .49345 .60025 L p
.51267 .58077 L 1 g
F P
s
P
p
.53128 .57265 m .51097 .5811 L .5133 .58065 L 1 g
F
P
p
.002 w
.53773 .57265 m .51942 .58614 L .51661 .58362 L p
1 g
F P
s
P
p
.002 w
.51661 .58362 m .5133 .58065 L p
.53171 .57462 L 1 g
F P
s
P
p
.51661 .58362 m .53171 .57462 L .53773 .57265 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57462 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57462 L .53931 .57009 L 1 g
F
P
p
.53128 .57265 m .5133 .58065 L .51992 .57848 L 1 g
F
P
p
.002 w
.5133 .58065 m .51942 .58614 L p
.51267 .58077 L 1 g
F P
s
P
p
.002 w
.52846 .58956 m .51942 .58614 L .53773 .57265 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57467 L p
1 g
F P
s
P
p
.002 w
.53172 .57467 m .53128 .57265 L p
.51891 .57899 L 1 g
F P
s
P
p
.51891 .57899 m .51111 .583 L .53172 .57467 L 1 g
F
P
p
.002 w
.53773 .57265 m .54536 .56702 L .5423 .5711 L p
1 g
F P
s
P
p
.002 w
.5423 .5711 m .52846 .58956 L p
.53773 .57265 L 1 g
F P
s
P
p
.002 w
.54536 .56702 m .53773 .57265 L p
.532 .57445 L 1 g
F P
s
P
p
.54854 .56129 m .53931 .57009 L .5424 .56825 L 1 g
F
P
p
.002 w
.57384 .54618 m .57832 .55306 L .54698 .56634 L p
1 g
F P
s
P
p
.002 w
.54698 .56634 m .54536 .56702 L .5479 .56516 L p
1 g
F P
s
P
p
.002 w
.5479 .56516 m .57384 .54618 L p
.54698 .56634 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54931 .56335 L p
1 g
F P
s
P
p
.56075 .54566 m .54931 .56335 L .54941 .56322 L 1 g
F
P
p
.002 w
.57384 .54618 m .5479 .56516 L p
.54931 .56335 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56167 .5474 L p
1 g
F P
s
P
p
.002 w
.56632 .5414 m .57251 .54533 L p
.55826 .5564 L 1 g
F P
s
P
p
.56632 .5414 m .55826 .5564 L .56167 .5474 L 1 g
F
P
p
.56654 .52734 m .56167 .5474 L .56211 .54625 L 1 g
F
P
p
.002 w
.56413 .54082 m .56612 .54128 L .56211 .54625 L p
1 g
F P
s
P
p
.56403 .54111 m .56211 .54625 L .564 .54127 L 1 g
F
P
p
.56654 .52734 m .56211 .54625 L .56403 .54111 L 1 g
F
P
p
.54854 .56129 m .5424 .56825 L .54408 .56723 L 1 g
F
P
p
.54854 .56129 m .54408 .56723 L .54436 .56706 L 1 g
F
P
p
.54854 .56129 m .54435 .56707 L .54454 .56695 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51001 .57293 m .51075 .56451 L .54453 .56696 L p
1 g
F P
s
P
p
.002 w
.54453 .56696 m .54536 .56702 L .54408 .56723 L p
1 g
F P
s
P
p
.002 w
.54408 .56723 m .51001 .57293 L p
.54453 .56696 L 1 g
F P
s
P
p
.54436 .56706 m .54408 .56723 L .54435 .56707 L 1 g
F
P
p
.54454 .56695 m .54435 .56707 L .54453 .56696 L 1 g
F
P
p
.54854 .56129 m .54453 .56696 L .54495 .56668 L 1 g
F
P
p
.002 w
.54513 .56656 m .54536 .56702 L .54495 .56668 L p
1 g
F P
s
P
p
.545 .56665 m .54495 .56668 L .54499 .56666 L 1 g
F
P
p
.54854 .56129 m .54495 .56668 L .545 .56665 L 1 g
F
P
p
.002 w
.54931 .56335 m .54854 .56129 L p
.54668 .56539 L 1 g
F P
s
P
p
.56167 .5474 m .55826 .5564 L .54931 .56335 L 1 g
F
P
p
.002 w
.57251 .54533 m .57384 .54618 L p
.54931 .56335 L 1 g
F P
s
P
p
.55516 .5558 m .54931 .56336 L .55493 .55622 L 1 g
F
P
p
.56075 .54566 m .54941 .56322 L .55516 .5558 L 1 g
F
P
p
.54941 .56322 m .54931 .56336 L .55516 .5558 L 1 g
F
P
p
.002 w
.57832 .55306 m .57913 .56117 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56612 .54128 m .56632 .5414 L p
.56189 .54681 L 1 g
F P
s
P
p
.56612 .54128 m .56189 .54681 L .5621 .54626 L 1 g
F
P
p
.002 w
.54668 .56539 m .56612 .54128 L p
.54673 .56534 L 1 g
F P
s
P
p
.002 w
.5479 .56516 m .54536 .56702 L p
.54673 .56534 L 1 g
F P
s
P
p
.56632 .5414 m .54931 .56335 L .54673 .56534 L 1 g
F
P
p
.54931 .56335 m .5479 .56516 L .54673 .56534 L 1 g
F
P
p
.002 w
.54953 .56396 m .54931 .56337 L p
.54668 .56539 L 1 g
F P
s
P
p
.56654 .52734 m .564 .54127 L .56405 .54114 L 1 g
F
P
p
.002 w
.56612 .54128 m .56413 .54082 L p
.56591 .53427 L 1 g
F P
s
P
p
.002 w
.56744 .52865 m .56654 .52734 L p
.56405 .54114 L 1 g
F P
s
P
p
.002 w
.58514 .51177 m .56612 .54128 L p
.56591 .53427 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52865 L p
1 g
F P
s
P
p
.002 w
.56608 .50714 m .57284 .50878 L p
.57024 .51833 L 1 g
F P
s
P
p
.56624 .50955 m .57024 .51833 L .56744 .52865 L 1 g
F
P
p
.56608 .50714 m .57024 .51833 L .56624 .50955 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56624 .50955 L p
1 g
F P
s
P
p
.55661 .4905 m .56624 .50955 L .56507 .50701 L 1 g
F
P
p
.55661 .4905 m .56507 .50701 L .56503 .50691 L 1 g
F
P
p
.002 w
.57233 .47204 m .5651 .50691 L p
.5649 .50665 L 1 g
F P
s
P
p
.002 w
.54822 .47285 m .57233 .47204 L p
.56633 .49998 L 1 g
F P
s
P
p
.55729 .49122 m .56633 .49998 L .5649 .50665 L 1 g
F
P
p
.54822 .47285 m .56633 .49998 L .55729 .49122 L 1 g
F
P
p
.55661 .4905 m .56503 .50691 L .56234 .50147 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5651 .50691 m .56608 .50714 L p
.56607 .50919 L 1 g
F P
s
P
p
.56515 .50826 m .56744 .52865 L .56685 .51928 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.57284 .50878 m .58514 .51177 L p
.56767 .53222 L 1 g
F P
s
P
p
.57284 .50878 m .56767 .53222 L .56744 .52865 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56624 .50955 L p
1 g
F P
s
P
p
.002 w
.56624 .50955 m .56515 .50826 L p
.56685 .51928 L 1 g
F P
s
P
p
.56685 .51928 m .56854 .53025 L .56624 .50955 L 1 g
F
P
p
.56744 .52865 m .56767 .53222 L .56591 .53427 L 1 g
F
P
p
.56511 .50708 m .56607 .50919 L .56591 .53427 L 1 g
F
P
p
.5651 .50691 m .56607 .50919 L .56511 .50708 L 1 g
F
P
p
.002 w
.55834 .49233 m .55661 .4905 L p
.56393 .50451 L 1 g
F P
s
P
p
.56608 .50714 m .56744 .52865 L .56591 .53427 L 1 g
F
P
p
.002 w
.58514 .51177 m .5651 .50691 L .57233 .47204 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55908 .49388 L p
.56393 .50451 L 1 g
F P
s
P
p
.002 w
.55908 .49388 m .55834 .49233 L p
.56393 .50451 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55729 .49122 L p
1 g
F P
s
P
p
.54174 .47608 m .55729 .49122 L .54932 .4835 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.53875 .47316 m .54822 .47285 L p
.55729 .49122 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.54114 .47621 m .55729 .49122 L .5649 .50665 L 1 g
F
P
p
.54239 .47679 m .55729 .49122 L .54114 .47621 L 1 g
F
P
p
.52214 .46667 m .54239 .47679 L .53896 .47522 L 1 g
F
P
p
.002 w
.50502 .48289 m .5362 .4739 L p
.54233 .5078 L 1 g
F P
s
P
p
.002 w
.53896 .47522 m .54233 .5078 L p
.5362 .4739 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5362 .4739 m .50502 .48289 L .49685 .46437 L p
1 g
F P
s
P
p
.5 .46383 m .5362 .4739 L .49685 .46437 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52238 .46707 L p
1 g
F P
s
P
p
.5 .4634 m .52238 .46707 L .50911 .46515 L 1 g
F
P
p
.52238 .46707 m .5362 .4739 L .5 .46383 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46383 L p
1 g
F P
s
P
p
.002 w
.5 .46383 m .5 .4634 L p
.50911 .46515 L 1 g
F P
s
P
p
.50911 .46515 m .52282 .46778 L .5 .46383 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46383 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.46308 .47412 m .46538 .473 L .50502 .48289 L 1 g
F
P
p
.002 w
.45763 .47677 m .45826 .47608 L p
.46627 .47257 L 1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.49685 .46437 m .50502 .48289 L p
.46538 .473 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47764 .46704 L p
1 g
F P
s
P
p
.45826 .47608 m .47764 .46704 L .46627 .47257 L 1 g
F
P
p
.45443 .47027 m .47764 .46704 L .46538 .473 L 1 g
F
P
p
.47764 .46704 m .49685 .46437 L .46538 .473 L 1 g
F
P
p
.002 w
.47764 .46704 m .47718 .46778 L p
.46627 .47257 L 1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.50502 .48289 m .47529 .50006 L .45672 .47765 L p
1 g
F P
s
P
p
.46083 .47365 m .50502 .48289 L .45672 .47765 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45758 .47683 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.43275 .50085 m .4428 .49112 L .4381 .50075 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4428 .49112 L p
1 g
F P
s
P
p
.43485 .50826 m .4428 .49112 L .43774 .5015 L 1 g
F
P
p
.43485 .50826 m .43774 .5015 L .43419 .50877 L 1 g
F
P
p
.40835 .53336 m .43395 .509 L .42486 .52935 L 1 g
F
P
p
.43395 .509 m .43419 .50877 L .43393 .50936 L 1 g
F
P
p
.43395 .509 m .43393 .50936 L .42486 .52935 L 1 g
F
P
p
.002 w
.43282 .52828 m .43346 .52734 L p
.43324 .52103 L 1 g
F P
s
P
p
.002 w
.43393 .50936 m .43485 .50826 L p
.43419 .50877 L 1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43393 .50936 L p
1 g
F P
s
P
p
.43346 .52734 m .43393 .50936 L .43324 .52103 L 1 g
F
P
p
.002 w
.43419 .50877 m .45312 .52249 L p
.43287 .52741 L 1 g
F P
s
P
p
.42486 .52935 m .43393 .50936 L .43287 .52741 L 1 g
F
P
p
.43393 .50936 m .43419 .50877 L .43287 .52741 L 1 g
F
P
p
.002 w
.43393 .50936 m .43287 .51061 L p
.43324 .52103 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43827 .54751 L p
1 g
F P
s
P
p
.002 w
.43985 .57179 m .40754 .56487 L p
.43895 .54843 L 1 g
F P
s
P
p
.002 w
.4408 .55095 m .43985 .57179 L p
.43895 .54843 L 1 g
F P
s
P
p
.45146 .56129 m .43827 .54751 L .43913 .54867 L 1 g
F
P
p
.002 w
.40754 .56487 m .40835 .53336 L .43689 .54563 L p
1 g
F P
s
P
p
.002 w
.43689 .54563 m .4377 .54598 L p
.43827 .54751 L 1 g
F P
s
P
p
.40754 .56487 m .43689 .54563 L .43895 .54843 L 1 g
F
P
p
.002 w
.4377 .54598 m .43689 .54563 L p
.4374 .54491 L 1 g
F P
s
P
p
.002 w
.43827 .54751 m .43925 .54566 L p
.43564 .53852 L 1 g
F P
s
P
p
.42656 .52894 m .43259 .52748 L .43689 .54563 L 1 g
F
P
p
.43259 .52748 m .4374 .54491 L .43689 .54563 L 1 g
F
P
p
.43564 .53852 m .43278 .53287 L .4377 .54598 L 1 g
F
P
p
.43564 .53852 m .4377 .54598 L .43827 .54751 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.43259 .52748 m .45312 .52249 L .4374 .54491 L 1 g
F
P
p
.002 w
.45312 .52249 m .44096 .54738 L .4377 .54598 L p
1 g
F P
s
P
p
.4374 .54491 m .45312 .52249 L .4377 .54598 L 1 g
F
P
p
.002 w
.43689 .54563 m .40835 .53336 L p
.42656 .52894 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43817 .5477 L p
1 g
F P
s
P
p
.002 w
.43817 .5477 m .43827 .54751 L p
.43777 .54623 L 1 g
F P
s
P
p
.43777 .54623 m .43146 .53025 L .43817 .5477 L 1 g
F
P
p
.43278 .53287 m .43146 .53025 L .43827 .54751 L 1 g
F
P
p
.43895 .54843 m .43827 .54751 L .44096 .54738 L 1 g
F
P
p
.002 w
.4377 .54598 m .44096 .54738 L p
.43827 .54751 L 1 g
F P
s
P
p
.002 w
.43985 .57179 m .44058 .55564 L p
.45387 .56633 L 1 g
F P
s
P
p
.002 w
.44058 .55564 m .4408 .55095 L p
.45089 .56282 L 1 g
F P
s
P
p
.44058 .55564 m .45089 .56282 L .45387 .56633 L 1 g
F
P
p
.47219 .57618 m .46825 .57479 L .47441 .57453 L 1 g
F
P
p
.002 w
.46551 .57382 m .46682 .57393 L p
.46825 .57479 L 1 g
F P
s
P
p
.002 w
.46825 .57479 m .46872 .57265 L p
.46682 .57393 L 1 g
F P
s
P
p
.002 w
.46682 .57393 m .47441 .57453 L p
.46825 .57479 L 1 g
F P
s
P
p
.46872 .57265 m .45997 .56915 L .46682 .57393 L 1 g
F
P
p
.44947 .59304 m .46551 .57382 L .46825 .57479 L 1 g
F
P
p
.47146 .57672 m .46825 .57479 L .47219 .57618 L 1 g
F
P
p
.44947 .59304 m .46825 .57479 L .47146 .57672 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45089 .56282 L p
1 g
F P
s
P
p
.46872 .57265 m .45089 .56282 L .45997 .56915 L 1 g
F
P
p
.002 w
.47551 .55789 m .47441 .57453 L .46682 .57393 L p
1 g
F P
s
P
p
.002 w
.46682 .57393 m .43985 .57179 L p
.45518 .56582 L 1 g
F P
s
P
p
.45518 .56582 m .47551 .55789 L .46682 .57393 L 1 g
F
P
p
.45146 .56129 m .43913 .54867 L .4408 .55095 L 1 g
F
P
p
.4443 .55507 m .4408 .55095 L .44299 .55393 L 1 g
F
P
p
.45146 .56129 m .4408 .55095 L .4443 .55507 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44096 .54738 m .47551 .55789 L p
.45387 .56633 L 1 g
F P
s
P
p
.002 w
.4408 .55095 m .44096 .54738 L p
.45387 .56633 L 1 g
F P
s
P
p
.002 w
.45089 .56282 m .45002 .56518 L p
.45997 .56915 L 1 g
F P
s
P
p
.46682 .57393 m .45002 .56518 L .46823 .57491 L 1 g
F
P
p
.45997 .56915 m .45672 .56786 L .46682 .57393 L 1 g
F
P
p
.45672 .56786 m .45002 .56518 L .46682 .57393 L 1 g
F
P
p
.002 w
.46823 .57491 m .46825 .57479 L p
.46682 .57393 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46823 .57491 L p
1 g
F P
s
P
p
.44299 .55393 m .43954 .54947 L .44092 .55213 L 1 g
F
P
p
.43954 .54947 m .43817 .5477 L .43854 .54829 L 1 g
F
P
p
.43954 .54947 m .43854 .54829 L .44092 .55213 L 1 g
F
P
p
.43913 .54867 m .43817 .5477 L .44299 .55393 L 1 g
F
P
p
.002 w
.43827 .54751 m .43817 .5477 L p
.43913 .54867 L 1 g
F P
s
P
p
.002 w
.44096 .54738 m .4408 .55095 L p
.43895 .54843 L 1 g
F P
s
P
p
.002 w
.43817 .5477 m .43743 .5491 L p
.44092 .55213 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43282 .52828 L p
1 g
F P
s
P
p
.43324 .52103 m .43287 .51061 L .43282 .52828 L 1 g
F
P
p
.002 w
.43388 .50942 m .43393 .50936 L p
.43419 .50877 L 1 g
F P
s
P
p
.002 w
.40835 .53336 m .42352 .50103 L .43419 .50877 L p
1 g
F P
s
P
p
.002 w
.47529 .50006 m .45312 .52249 L .42352 .50103 L p
1 g
F P
s
P
p
.002 w
.4428 .49112 m .44166 .49233 L p
.43774 .5015 L 1 g
F P
s
P
p
.42352 .50103 m .44553 .48553 L .43275 .50085 L 1 g
F
P
p
.44339 .4905 m .45758 .47683 L .44914 .48499 L 1 g
F
P
p
.44553 .48553 m .45672 .47765 L .4428 .49112 L 1 g
F
P
p
.44553 .48553 m .4428 .49112 L .43275 .50085 L 1 g
F
P
p
.002 w
.45672 .47765 m .47529 .50006 L p
.4381 .50075 L 1 g
F P
s
P
p
.4428 .49112 m .45672 .47765 L .4381 .50075 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43388 .50942 L p
1 g
F P
s
P
p
.43774 .5015 m .44166 .49233 L .43388 .50942 L 1 g
F
P
p
.002 w
.45758 .47683 m .45698 .47747 L p
.44914 .48499 L 1 g
F P
s
P
p
.002 w
.42352 .50103 m .45185 .47177 L .45672 .47765 L p
1 g
F P
s
P
p
.002 w
.45672 .47765 m .45185 .47177 L p
.46083 .47365 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44339 .4905 L p
.45238 .48188 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44186 .49214 L p
.45238 .48188 L 1 g
F P
s
P
p
.002 w
.44186 .49214 m .44166 .49233 L p
.45238 .48188 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45763 .47677 L p
1 g
F P
s
P
p
.46627 .47257 m .47718 .46778 L .45763 .47677 L 1 g
F
P
p
.002 w
.45185 .47177 m .45443 .47027 L p
.46538 .473 L 1 g
F P
s
P
p
.45185 .47177 m .46538 .473 L .46308 .47412 L 1 g
F
P
p
.47786 .46667 m .5 .46383 L .49142 .46529 L 1 g
F
P
p
.002 w
.47724 .4677 m .47786 .46667 L p
.49142 .46529 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.45443 .47027 m .49023 .44938 L .49685 .46437 L p
1 g
F P
s
P
p
.49142 .46529 m .49685 .46437 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46383 m .5 .46393 L p
.49685 .46437 L 1 g
F P
s
P
p
.002 w
.5 .46393 m .5 .46442 L p
.49685 .46437 L 1 g
F P
s
P
p
.49125 .45169 m .51178 .46184 L .5 .46383 L 1 g
F
P
p
.002 w
.49685 .46437 m .49638 .46331 L p
.5 .46383 L 1 g
F P
s
P
p
.002 w
.49638 .46331 m .49125 .45169 L p
.5 .46383 L 1 g
F P
s
P
p
.51178 .46184 m .52238 .46707 L .5 .46383 L 1 g
F
P
p
.002 w
.52238 .46707 m .52282 .46778 L p
.50911 .46515 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47724 .4677 L p
1 g
F P
s
P
p
.49142 .46529 m .5 .46442 L .47724 .4677 L 1 g
F
P
p
.52214 .46667 m .53896 .47522 L .53496 .47331 L 1 g
F
P
p
.002 w
.53875 .47316 m .5362 .4739 L p
.49023 .44938 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.54233 .5078 m .53896 .47522 L p
.5649 .50665 L 1 g
F P
s
P
p
.002 w
.53896 .47522 m .53875 .47316 L p
.54114 .47621 L 1 g
F P
s
P
p
.54114 .47621 m .5649 .50665 L .53896 .47522 L 1 g
F
P
p
.002 w
.52282 .46778 m .52214 .46667 L p
.53617 .47393 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52346 .46809 L p
.53617 .47393 L 1 g
F P
s
P
p
.002 w
.52346 .46809 m .52282 .46778 L p
.53617 .47393 L 1 g
F P
s
P
p
.002 w
.49125 .45169 m .49023 .44938 L p
.5362 .4739 L 1 g
F P
s
P
p
.53496 .47331 m .5362 .4739 L .53617 .47393 L 1 g
F
P
p
.5362 .4739 m .53896 .47522 L .5376 .47459 L 1 g
F
P
p
.5362 .4739 m .5376 .47459 L .53617 .47393 L 1 g
F
P
p
.002 w
.5362 .4739 m .53875 .47316 L .53896 .47522 L p
1 g
F P
s
P
p
.002 w
.54239 .47679 m .54302 .47747 L p
.53617 .47393 L 1 g
F P
s
P
p
.53909 .47359 m .54239 .47679 L .54114 .47621 L 1 g
F
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.54932 .4835 L 1 g
F P
s
P
p
.53875 .47316 m .55729 .49122 L .53909 .47359 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54239 .47679 L p
1 g
F P
s
P
p
.54932 .4835 m .55834 .49233 L .54239 .47679 L 1 g
F
P
p
.002 w
.55729 .49122 m .55834 .49233 L p
.54932 .4835 L 1 g
F P
s
P
p
.56234 .50147 m .56503 .50691 L .5637 .50407 L 1 g
F
P
p
.002 w
.5651 .50691 m .56503 .50691 L p
.5649 .50665 L 1 g
F P
s
P
p
.002 w
.56503 .50691 m .54233 .5078 L p
.5649 .50665 L 1 g
F P
s
P
p
.5637 .50407 m .56503 .50691 L .56393 .50451 L 1 g
F
P
p
.002 w
.56503 .50691 m .5651 .50691 L .56507 .50701 L p
1 g
F P
s
P
p
.56503 .50691 m .56507 .50701 L .56504 .50694 L 1 g
F
P
p
.56503 .50691 m .56504 .50694 L .56393 .50451 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54233 .5078 m .56503 .50691 L p
.55598 .53894 L 1 g
F P
s
P
p
.002 w
.56507 .50701 m .55598 .53894 L p
.56503 .50691 L 1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55598 .53894 m .5651 .50691 L p
.56591 .53427 L 1 g
F P
s
P
p
.002 w
.56624 .50955 m .56713 .51061 L p
.56393 .50451 L 1 g
F P
s
P
p
.002 w
.56744 .52865 m .56854 .53025 L p
.56685 .51928 L 1 g
F P
s
P
p
.56405 .54114 m .56257 .5491 L .56831 .52991 L 1 g
F
P
p
.564 .54127 m .56397 .54143 L .56405 .54114 L 1 g
F
P
p
.56397 .54143 m .56257 .5491 L .56405 .54114 L 1 g
F
P
p
.002 w
.56831 .52991 m .56744 .52865 L p
.56405 .54114 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56413 .54082 m .55598 .53894 L p
.56591 .53427 L 1 g
F P
s
P
p
.54854 .56129 m .54499 .56666 L .54668 .56539 L 1 g
F
P
p
.54499 .56666 m .54524 .56648 L .54668 .56539 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.5331 .54277 m .54455 .53945 L .54535 .5664 L p
1 g
F P
s
P
p
.002 w
.54535 .5664 m .54536 .56702 L .54513 .56656 L p
1 g
F P
s
P
p
.002 w
.54513 .56656 m .5331 .54277 L p
.54535 .5664 L 1 g
F P
s
P
p
.54499 .56666 m .54498 .56668 L .54524 .56648 L 1 g
F
P
p
.54498 .56668 m .54496 .5667 L .5457 .56614 L 1 g
F
P
p
.54498 .56668 m .5457 .56614 L .54668 .56539 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54455 .53945 m .55598 .53894 L .5457 .56614 L p
1 g
F P
s
P
p
.002 w
.5457 .56614 m .54536 .56702 L .54535 .5664 L p
1 g
F P
s
P
p
.002 w
.54535 .5664 m .54455 .53945 L p
.5457 .56614 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56211 .54625 m .54668 .56539 L p
.56413 .54082 L 1 g
F P
s
P
p
.002 w
.54668 .56539 m .54536 .56702 L p
.54635 .56564 L 1 g
F P
s
P
p
.56413 .54082 m .54668 .56539 L .54635 .56564 L 1 g
F
P
p
.002 w
.54536 .56702 m .54668 .56539 L p
.54673 .56534 L 1 g
F P
s
P
p
.002 w
.54477 .5668 m .54536 .56702 L .54453 .56696 L p
1 g
F P
s
P
p
.002 w
.54495 .56668 m .54536 .56702 L .54477 .5668 L p
1 g
F P
s
P
p
.002 w
.54536 .56702 m .5457 .56614 L p
.54635 .56564 L 1 g
F P
s
P
p
.002 w
.54408 .56723 m .54536 .56702 L .5424 .56825 L p
1 g
F P
s
P
p
.002 w
.5424 .56825 m .54536 .56702 L p
.532 .57445 L 1 g
F P
s
P
p
.002 w
.5133 .58065 m .51303 .5804 L p
.53773 .57265 L 1 g
F P
s
P
p
.002 w
.55043 .58838 m .53917 .59032 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.002 w
.56106 .58394 m .55043 .58838 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.002 w
.56998 .57746 m .56106 .58394 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.002 w
.53917 .59032 m .52846 .58956 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.002 w
.57623 .56959 m .56998 .57746 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.002 w
.57913 .56117 m .57623 .56959 L .54536 .56702 L closepath p
1 g
F P
s
P
p
.54488 .56677 m .5322 .57686 L .54954 .56399 L 1 g
F
P
p
.53931 .57009 m .53417 .57498 L .54488 .56677 L 1 g
F
P
p
.53417 .57498 m .5322 .57686 L .54488 .56677 L 1 g
F
P
p
.54668 .56539 m .54496 .5667 L .54505 .56665 L 1 g
F
P
p
.54668 .56539 m .54505 .56665 L .54953 .56396 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56831 .52991 L p
1 g
F P
s
P
p
.5621 .54626 m .56189 .54681 L .54673 .56534 L 1 g
F
P
p
.002 w
.54931 .56337 m .54931 .56335 L p
.54668 .56539 L 1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52294 .54853 m .5331 .54277 L .54513 .56656 L p
1 g
F P
s
P
p
.002 w
.54495 .56668 m .52294 .54853 L p
.54513 .56656 L 1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.51075 .56451 m .51521 .55606 L .54477 .5668 L p
1 g
F P
s
P
p
.002 w
.54453 .56696 m .51075 .56451 L p
.54477 .5668 L 1 g
F P
s
P
p
.002 w
.51521 .55606 m .52294 .54853 L .54495 .56668 L p
1 g
F P
s
P
p
.002 w
.54477 .5668 m .51521 .55606 L p
.54495 .56668 L 1 g
F P
s
P
p
.54499 .56666 m .54453 .56696 L .54496 .5667 L 1 g
F
P
p
.002 w
.55598 .53894 m .56413 .54082 L p
.54635 .56564 L 1 g
F P
s
P
p
.002 w
.5457 .56614 m .55598 .53894 L p
.54635 .56564 L 1 g
F P
s
P
p
.002 w
.56167 .5474 m .56257 .5491 L p
.564 .54127 L 1 g
F P
s
P
p
.002 w
.54954 .56399 m .54953 .56396 L p
.54505 .56665 L 1 g
F P
s
P
p
.54505 .56665 m .5424 .56825 L .54497 .56672 L 1 g
F
P
p
.54505 .56665 m .54497 .56672 L .54954 .56399 L 1 g
F
P
p
.002 w
.54931 .56335 m .54931 .56336 L p
.54941 .56322 L 1 g
F P
s
P
p
.002 w
.54931 .56336 m .54998 .56518 L p
.55493 .55622 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .5811 L p
1 g
F P
s
P
p
.002 w
.51303 .5804 m .51001 .57293 L .54408 .56723 L p
1 g
F P
s
P
p
.002 w
.5424 .56825 m .51303 .5804 L p
.54408 .56723 L 1 g
F P
s
P
p
.002 w
.51303 .5804 m .5424 .56825 L p
.532 .57445 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54954 .56399 L p
1 g
F P
s
P
p
.002 w
.53171 .57462 m .5322 .57686 L p
.53931 .57009 L 1 g
F P
s
P
p
.51992 .57848 m .5133 .58065 L .51715 .5799 L 1 g
F
P
p
.002 w
.51303 .5804 m .5133 .58065 L p
.51267 .58077 L 1 g
F P
s
P
p
.002 w
.49345 .60025 m .48069 .58915 L .51046 .5811 L p
1 g
F P
s
P
p
.002 w
.51097 .5811 m .51079 .57862 L p
.51046 .5811 L 1 g
F P
s
P
p
.002 w
.51046 .5811 m .51303 .5804 L p
.51235 .5811 L 1 g
F P
s
P
p
.49345 .60025 m .51046 .5811 L .51235 .5811 L 1 g
F
P
p
.51079 .57862 m .49971 .58083 L .51046 .5811 L 1 g
F
P
p
.002 w
.51097 .58111 m .51097 .5811 L p
.51046 .5811 L 1 g
F P
s
P
p
.002 w
.51097 .5811 m .51111 .583 L p
.51715 .5799 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58057 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58057 L .49971 .58083 L 1 g
F
P
p
.002 w
.51001 .57293 m .51303 .5804 L .51046 .5811 L p
1 g
F P
s
P
p
.002 w
.51046 .5811 m .48069 .58915 L p
.49589 .58074 L 1 g
F P
s
P
p
.49589 .58074 m .51001 .57293 L .51046 .5811 L 1 g
F
P
p
.48921 .57862 m .47565 .5774 L .47632 .57756 L 1 g
F
P
p
.002 w
.48895 .5821 m .48921 .57862 L p
.47603 .57754 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.47441 .57453 m .51001 .57293 L p
.49406 .58175 L 1 g
F P
s
P
p
.002 w
.47565 .5774 m .47441 .57453 L p
.49406 .58175 L 1 g
F P
s
P
p
.002 w
.48906 .58057 m .48889 .583 L p
.49971 .58083 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51097 .58111 L p
1 g
F P
s
P
p
.49971 .58083 m .48889 .583 L .51097 .58111 L 1 g
F
P
p
.47632 .57756 m .47565 .5774 L .47603 .57754 L 1 g
F
P
p
.002 w
.46825 .57479 m .4678 .57686 L p
.47603 .57754 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48895 .5821 L p
1 g
F P
s
P
p
.47603 .57754 m .4678 .57686 L .48895 .5821 L 1 g
F
P
p
.002 w
.47441 .57453 m .47565 .5774 L p
.47219 .57618 L 1 g
F P
s
P
p
.002 w
.64292 .46556 m .65801 .49227 L .63561 .51497 L p
1 g
F P
s
P
p
.002 w
.65801 .49227 m .64292 .46556 L .65779 .43595 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.63089 .37874 m .66771 .40673 L .65779 .43595 L p
1 g
F P
s
P
p
.002 w
.66771 .40673 m .63089 .37874 L .63277 .3479 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.49878 .27782 m .5665 .27787 L .57317 .30222 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.57623 .56959 m .57913 .56117 L .61002 .55151 L p
1 g
F P
s
P
p
.002 w
.60875 .53549 m .61002 .55151 L .57913 .56117 L p
1 g
F P
s
P
p
.002 w
.61002 .55151 m .60875 .53549 L .63561 .51497 L p
1 g
F P
s
P
p
.002 w
.39369 .38367 m .35332 .42782 L .33874 .40353 L p
1 g
F P
s
P
p
.002 w
.33874 .40353 m .38069 .35695 L .39369 .38367 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.43911 .32154 m .38069 .35695 L .37161 .33316 L p
1 g
F P
s
P
p
.002 w
.37161 .33316 m .43069 .2971 L .43911 .32154 L p
1 g
F P
s
P
p
.002 w
.39639 .47749 m .37886 .5164 L .35347 .49714 L p
1 g
F P
s
P
p
.002 w
.35347 .49714 m .37272 .45277 L .39639 .47749 L p
1 g
F P
s
P
p
.002 w
.62352 .4945 m .63561 .51497 L .60875 .53549 L p
1 g
F P
s
P
p
.002 w
.63561 .51497 m .62352 .4945 L .64292 .46556 L p
1 g
F P
s
P
p
.002 w
.62496 .41176 m .65779 .43595 L .64292 .46556 L p
1 g
F P
s
P
p
.002 w
.65779 .43595 m .62496 .41176 L .63089 .37874 L p
1 g
F P
s
P
p
.002 w
.57778 .33118 m .63277 .3479 L .63089 .37874 L p
1 g
F P
s
P
p
.002 w
.63277 .3479 m .57778 .33118 L .57317 .30222 L p
1 g
F P
s
P
p
.002 w
.57913 .56117 m .57832 .55306 L .60875 .53549 L p
1 g
F P
s
P
p
.002 w
.57317 .30222 m .50636 .30245 L .49878 .27782 L p
1 g
F P
s
P
p
.002 w
.43069 .2971 m .49878 .27782 L .50636 .30245 L p
1 g
F P
s
P
p
.002 w
.60021 .52171 m .60875 .53549 L .57832 .55306 L p
1 g
F P
s
P
p
.002 w
.60875 .53549 m .60021 .52171 L .62352 .4945 L p
1 g
F P
s
P
p
.002 w
.50636 .30245 m .43911 .32154 L .43069 .2971 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42352 .50103 m .40835 .53336 L .37886 .5164 L p
1 g
F P
s
P
p
.002 w
.37886 .5164 m .39639 .47749 L .42352 .50103 L p
1 g
F P
s
P
p
.002 w
.50636 .30245 m .57317 .30222 L .57778 .33118 L p
1 g
F P
s
P
p
.002 w
.61513 .44577 m .64292 .46556 L .62352 .4945 L p
1 g
F P
s
P
p
.002 w
.64292 .46556 m .61513 .44577 L .62496 .41176 L p
1 g
F P
s
P
p
.002 w
.41027 .41243 m .37272 .45277 L .35332 .42782 L p
1 g
F P
s
P
p
.002 w
.35332 .42782 m .39369 .38367 L .41027 .41243 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.51075 .56451 m .51001 .57293 L .47441 .57453 L p
1 g
F P
s
P
p
.002 w
.47441 .57453 m .47551 .55789 L .51075 .56451 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.57832 .55306 m .57384 .54618 L .60021 .52171 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.5801 .36386 m .63089 .37874 L .62496 .41176 L p
1 g
F P
s
P
p
.002 w
.63089 .37874 m .5801 .36386 L .57778 .33118 L p
1 g
F P
s
P
p
.002 w
.44966 .35003 m .39369 .38367 L .38069 .35695 L p
1 g
F P
s
P
p
.002 w
.38069 .35695 m .43911 .32154 L .44966 .35003 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.60169 .47953 m .62352 .4945 L .60021 .52171 L p
1 g
F P
s
P
p
.002 w
.62352 .4945 m .60169 .47953 L .61513 .44577 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57384 .54618 m .56612 .54128 L .58514 .51177 L p
1 g
F P
s
P
p
.002 w
.58514 .51177 m .60021 .52171 L .57384 .54618 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60021 .52171 m .58514 .51177 L .60169 .47953 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51521 .55606 m .51075 .56451 L .47551 .55789 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.48407 .54106 m .47551 .55789 L .44096 .54738 L p
1 g
F P
s
P
p
.002 w
.44096 .54738 m .45312 .52249 L .48407 .54106 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.47551 .55789 m .48407 .54106 L .51521 .55606 L p
1 g
F P
s
P
p
.002 w
.4299 .44217 m .39639 .47749 L .37272 .45277 L p
1 g
F P
s
P
p
.002 w
.37272 .45277 m .41027 .41243 L .4299 .44217 L p
1 g
F P
s
P
p
.002 w
.57778 .33118 m .51395 .33173 L .50636 .30245 L p
1 g
F P
s
P
p
.002 w
.43911 .32154 m .50636 .30245 L .51395 .33173 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.52294 .54853 m .51521 .55606 L .48407 .54106 L p
1 g
F P
s
P
p
.002 w
.57997 .39912 m .62496 .41176 L .61513 .44577 L p
1 g
F P
s
P
p
.002 w
.62496 .41176 m .57997 .39912 L .5801 .36386 L p
1 g
F P
s
P
p
.002 w
.51395 .33173 m .57778 .33118 L .5801 .36386 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51395 .33173 m .44966 .35003 L .43911 .32154 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55598 .53894 m .54455 .53945 L .54233 .5078 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5331 .54277 m .52294 .54853 L .49929 .52596 L p
1 g
F P
s
P
p
.002 w
.48407 .54106 m .49929 .52596 L .52294 .54853 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.54455 .53945 m .5331 .54277 L .51949 .51441 L p
1 g
F P
s
P
p
.002 w
.51949 .51441 m .54233 .5078 L .54455 .53945 L p
1 g
F P
s
P
p
.002 w
.57233 .47204 m .60169 .47953 L .58514 .51177 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.49929 .52596 m .51949 .51441 L .5331 .54277 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.462 .38162 m .41027 .41243 L .39369 .38367 L p
1 g
F P
s
P
p
.002 w
.39369 .38367 m .44966 .35003 L .462 .38162 L p
1 g
F P
s
P
p
.002 w
.57735 .43565 m .61513 .44577 L .60169 .47953 L p
1 g
F P
s
P
p
.002 w
.61513 .44577 m .57735 .43565 L .57997 .39912 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45185 .47177 m .42352 .50103 L .39639 .47749 L p
1 g
F P
s
P
p
.002 w
.39639 .47749 m .4299 .44217 L .45185 .47177 L p
1 g
F P
s
P
p
.002 w
.60169 .47953 m .57233 .47204 L .57735 .43565 L p
1 g
F P
s
P
p
.002 w
.49929 .52596 m .48407 .54106 L .45312 .52249 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.52126 .3647 m .5801 .36386 L .57997 .39912 L p
1 g
F P
s
P
p
.002 w
.5801 .36386 m .52126 .3647 L .51395 .33173 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.45312 .52249 m .47529 .50006 L .49929 .52596 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44966 .35003 m .51395 .33173 L .52126 .3647 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51949 .51441 m .49929 .52596 L .47529 .50006 L p
1 g
F P
s
P
p
.002 w
.52126 .3647 m .462 .38162 L .44966 .35003 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.4757 .41517 m .4299 .44217 L .41027 .41243 L p
1 g
F P
s
P
p
.002 w
.41027 .41243 m .462 .38162 L .4757 .41517 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54233 .5078 m .51949 .51441 L .50502 .48289 L p
1 g
F P
s
P
p
.002 w
.47529 .50006 m .50502 .48289 L .51949 .51441 L p
1 g
F P
s
P
p
.002 w
.52801 .40018 m .57997 .39912 L .57735 .43565 L p
1 g
F P
s
P
p
.002 w
.57997 .39912 m .52801 .40018 L .52126 .3647 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57233 .47204 m .53875 .47316 L .53392 .43682 L p
1 g
F P
s
P
p
.002 w
.53392 .43682 m .57735 .43565 L .57233 .47204 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57735 .43565 m .53392 .43682 L .52801 .40018 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.5607 .61318 m
.56392 .62287 L
s
P
p
.004 w
.56392 .62287 m
.57198 .64711 L
s
P
p
.002 w
.49023 .44938 m .45185 .47177 L .4299 .44217 L p
1 g
F P
s
P
p
.002 w
.4299 .44217 m .4757 .41517 L .49023 .44938 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.462 .38162 m .52126 .3647 L .52801 .40018 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.52801 .40018 m .4757 .41517 L .462 .38162 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49023 .44938 m .53392 .43682 L .53875 .47316 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.4757 .41517 m .52801 .40018 L .53392 .43682 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.53392 .43682 m .49023 .44938 L .4757 .41517 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .40524 .71227 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57198 .64711 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.390698)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.390698)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45337 .46622 m .50092 .4681 L .49872 .43979 L p
1 g
F P
s
P
p
.002 w
.49872 .43979 m .45705 .43804 L .45337 .46622 L p
1 g
F P
s
P
p
.002 w
.53971 .43172 m .49872 .43979 L .50092 .4681 L p
1 g
F P
s
P
p
.002 w
.45705 .43804 m .49872 .43979 L .49655 .41131 L p
1 g
F P
s
P
p
.002 w
.49872 .43979 m .53971 .43172 L .53077 .4045 L p
1 g
F P
s
P
p
.002 w
.53077 .4045 m .49655 .41131 L .49872 .43979 L p
1 g
F P
s
P
p
.002 w
.49655 .41131 m .46176 .40976 L .45705 .43804 L p
1 g
F P
s
P
p
.002 w
.46176 .40976 m .49655 .41131 L .49446 .38317 L p
1 g
F P
s
P
p
.002 w
.49655 .41131 m .53077 .4045 L .52105 .37782 L p
1 g
F P
s
P
p
.002 w
.52105 .37782 m .49446 .38317 L .49655 .41131 L p
1 g
F P
s
P
p
.002 w
.45079 .4938 m .50312 .49574 L .50092 .4681 L p
1 g
F P
s
P
p
.002 w
.50092 .4681 m .45337 .46622 L .45079 .4938 L p
1 g
F P
s
P
p
.002 w
.54771 .45899 m .50092 .4681 L .50312 .49574 L p
1 g
F P
s
P
p
.002 w
.50092 .4681 m .54771 .45899 L .53971 .43172 L p
1 g
F P
s
P
p
.002 w
.57631 .41449 m .53971 .43172 L .54771 .45899 L p
1 g
F P
s
P
p
.002 w
.53971 .43172 m .57631 .41449 L .56121 .38993 L p
1 g
F P
s
P
p
.002 w
.56121 .38993 m .53077 .4045 L .53971 .43172 L p
1 g
F P
s
P
p
.002 w
.53077 .4045 m .56121 .38993 L .54462 .36636 L p
1 g
F P
s
P
p
.002 w
.54462 .36636 m .52105 .37782 L .53077 .4045 L p
1 g
F P
s
P
p
.002 w
.41847 .42653 m .45705 .43804 L .46176 .40976 L p
1 g
F P
s
P
p
.002 w
.46176 .40976 m .42964 .39994 L .41847 .42653 L p
1 g
F P
s
P
p
.002 w
.42964 .39994 m .46176 .40976 L .46741 .3819 L p
1 g
F P
s
P
p
.002 w
.49446 .38317 m .46741 .3819 L .46176 .40976 L p
1 g
F P
s
P
p
.002 w
.40923 .45339 m .45337 .46622 L .45705 .43804 L p
1 g
F P
s
P
p
.002 w
.45705 .43804 m .41847 .42653 L .40923 .45339 L p
1 g
F P
s
P
p
.002 w
.46741 .3819 m .49446 .38317 L .49248 .35588 L p
1 g
F P
s
P
p
.002 w
.49446 .38317 m .52105 .37782 L .51073 .35218 L p
1 g
F P
s
P
p
.002 w
.51073 .35218 m .49248 .35588 L .49446 .38317 L p
1 g
F P
s
P
p
.002 w
.50312 .49574 m .55462 .48582 L .54771 .45899 L p
1 g
F P
s
P
p
.002 w
.58962 .43959 m .54771 .45899 L .55462 .48582 L p
1 g
F P
s
P
p
.002 w
.54771 .45899 m .58962 .43959 L .57631 .41449 L p
1 g
F P
s
P
p
.002 w
.52105 .37782 m .54462 .36636 L .52684 .34422 L p
1 g
F P
s
P
p
.002 w
.52684 .34422 m .51073 .35218 L .52105 .37782 L p
1 g
F P
s
P
p
.002 w
.46741 .3819 m .44252 .37411 L .42964 .39994 L p
1 g
F P
s
P
p
.002 w
.44252 .37411 m .46741 .3819 L .47391 .35497 L p
1 g
F P
s
P
p
.002 w
.49248 .35588 m .47391 .35497 L .46741 .3819 L p
1 g
F P
s
P
p
.002 w
.40212 .47999 m .45079 .4938 L .45337 .46622 L p
1 g
F P
s
P
p
.002 w
.45337 .46622 m .40923 .45339 L .40212 .47999 L p
1 g
F P
s
P
p
.002 w
.44939 .52023 m .50527 .52218 L .50312 .49574 L p
1 g
F P
s
P
p
.002 w
.50312 .49574 m .45079 .4938 L .44939 .52023 L p
1 g
F P
s
P
p
.002 w
.55462 .48582 m .50312 .49574 L .50527 .52218 L p
1 g
F P
s
P
p
.002 w
.58489 .3688 m .56121 .38993 L .57631 .41449 L p
1 g
F P
s
P
p
.002 w
.56121 .38993 m .58489 .3688 L .56279 .34978 L p
1 g
F P
s
P
p
.002 w
.56279 .34978 m .54462 .36636 L .56121 .38993 L p
1 g
F P
s
P
p
.002 w
.47391 .35497 m .49248 .35588 L .49065 .32998 L p
1 g
F P
s
P
p
.002 w
.49248 .35588 m .51073 .35218 L .49999 .32807 L p
1 g
F P
s
P
p
.002 w
.49999 .32807 m .49065 .32998 L .49248 .35588 L p
1 g
F P
s
P
p
.002 w
.38666 .40607 m .41847 .42653 L .42964 .39994 L p
1 g
F P
s
P
p
.002 w
.42964 .39994 m .40334 .38259 L .38666 .40607 L p
1 g
F P
s
P
p
.002 w
.40334 .38259 m .42964 .39994 L .44252 .37411 L p
1 g
F P
s
P
p
.002 w
.50527 .52218 m .56029 .51168 L .55462 .48582 L p
1 g
F P
s
P
p
.002 w
.60088 .46475 m .55462 .48582 L .56029 .51168 L p
1 g
F P
s
P
p
.002 w
.55462 .48582 m .60088 .46475 L .58962 .43959 L p
1 g
F P
s
P
p
.002 w
.60501 .38945 m .57631 .41449 L .58962 .43959 L p
1 g
F P
s
P
p
.002 w
.57631 .41449 m .60501 .38945 L .58489 .3688 L p
1 g
F P
s
P
p
.002 w
.54462 .36636 m .56279 .34978 L .53914 .33275 L p
1 g
F P
s
P
p
.002 w
.53914 .33275 m .52684 .34422 L .54462 .36636 L p
1 g
F P
s
P
p
.002 w
.51073 .35218 m .52684 .34422 L .50819 .32395 L p
1 g
F P
s
P
p
.002 w
.50819 .32395 m .49999 .32807 L .51073 .35218 L p
1 g
F P
s
P
p
.002 w
.47391 .35497 m .45689 .34951 L .44252 .37411 L p
1 g
F P
s
P
p
.002 w
.45689 .34951 m .47391 .35497 L .48115 .32949 L p
1 g
F P
s
P
p
.002 w
.49065 .32998 m .48115 .32949 L .47391 .35497 L p
1 g
F P
s
P
p
.002 w
.39734 .50582 m .44939 .52023 L .45079 .4938 L p
1 g
F P
s
P
p
.002 w
.45079 .4938 m .40212 .47999 L .39734 .50582 L p
1 g
F P
s
P
p
.002 w
.44252 .37411 m .4223 .36043 L .40334 .38259 L p
1 g
F P
s
P
p
.002 w
.4223 .36043 m .44252 .37411 L .45689 .34951 L p
1 g
F P
s
P
p
.002 w
.37264 .43041 m .40923 .45339 L .41847 .42653 L p
1 g
F P
s
P
p
.002 w
.41847 .42653 m .38666 .40607 L .37264 .43041 L p
1 g
F P
s
P
p
.002 w
.62271 .41133 m .58962 .43959 L .60088 .46475 L p
1 g
F P
s
P
p
.002 w
.58962 .43959 m .62271 .41133 L .60501 .38945 L p
1 g
F P
s
P
p
.002 w
.52684 .34422 m .53914 .33275 L .51439 .31805 L p
1 g
F P
s
P
p
.002 w
.51439 .31805 m .50819 .32395 L .52684 .34422 L p
1 g
F P
s
P
p
.002 w
.45689 .34951 m .44317 .34001 L .4223 .36043 L p
1 g
F P
s
P
p
.002 w
.48115 .32949 m .47248 .32665 L .45689 .34951 L p
1 g
F P
s
P
p
.002 w
.44317 .34001 m .45689 .34951 L .47248 .32665 L p
1 g
F P
s
P
p
.002 w
.44922 .54498 m .50734 .54689 L .50527 .52218 L p
1 g
F P
s
P
p
.002 w
.50527 .52218 m .44939 .52023 L .44922 .54498 L p
1 g
F P
s
P
p
.002 w
.56029 .51168 m .50527 .52218 L .50734 .54689 L p
1 g
F P
s
P
p
.002 w
.3616 .45514 m .40212 .47999 L .40923 .45339 L p
1 g
F P
s
P
p
.002 w
.40923 .45339 m .37264 .43041 L .3616 .45514 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .48115 .32949 L .49065 .32998 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .49065 .32998 L .49999 .32807 L closepath p
1 g
F P
s
P
p
.002 w
.50734 .54689 m .56458 .53607 L .56029 .51168 L p
1 g
F P
s
P
p
.002 w
.60981 .48948 m .56029 .51168 L .56458 .53607 L p
1 g
F P
s
P
p
.002 w
.56029 .51168 m .60981 .48948 L .60088 .46475 L p
1 g
F P
s
P
p
.002 w
.57357 .32964 m .56279 .34978 L .58489 .3688 L p
1 g
F P
s
P
p
.002 w
.56279 .34978 m .57357 .32964 L .54628 .31891 L p
1 g
F P
s
P
p
.002 w
.54628 .31891 m .53914 .33275 L .56279 .34978 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .49999 .32807 L .50819 .32395 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .47248 .32665 L .48115 .32949 L closepath p
1 g
F P
s
P
p
.002 w
.39504 .53033 m .44922 .54498 L .44939 .52023 L p
1 g
F P
s
P
p
.002 w
.44939 .52023 m .39734 .50582 L .39504 .53033 L p
1 g
F P
s
P
p
.002 w
.38569 .35916 m .40334 .38259 L .4223 .36043 L p
1 g
F P
s
P
p
.002 w
.4223 .36043 m .40893 .3421 L .38569 .35916 L p
1 g
F P
s
P
p
.002 w
.40893 .3421 m .4223 .36043 L .44317 .34001 L p
1 g
F P
s
P
p
.002 w
.59922 .34298 m .58489 .3688 L .60501 .38945 L p
1 g
F P
s
P
p
.002 w
.58489 .3688 m .59922 .34298 L .57357 .32964 L p
1 g
F P
s
P
p
.002 w
.53914 .33275 m .54628 .31891 L .51791 .31097 L p
1 g
F P
s
P
p
.002 w
.51791 .31097 m .51439 .31805 L .53914 .33275 L p
1 g
F P
s
P
p
.002 w
.6376 .43402 m .60088 .46475 L .60981 .48948 L p
1 g
F P
s
P
p
.002 w
.60088 .46475 m .6376 .43402 L .62271 .41133 L p
1 g
F P
s
P
p
.002 w
.44317 .34001 m .43425 .32737 L .40893 .3421 L p
1 g
F P
s
P
p
.002 w
.43425 .32737 m .44317 .34001 L .46555 .32174 L p
1 g
F P
s
P
p
.002 w
.47248 .32665 m .46555 .32174 L .44317 .34001 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .50819 .32395 L .51439 .31805 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .46555 .32174 L .47248 .32665 L closepath p
1 g
F P
s
P
p
.002 w
.36505 .37824 m .38666 .40607 L .40334 .38259 L p
1 g
F P
s
P
p
.002 w
.40334 .38259 m .38569 .35916 L .36505 .37824 L p
1 g
F P
s
P
p
.002 w
.35386 .47974 m .39734 .50582 L .40212 .47999 L p
1 g
F P
s
P
p
.002 w
.40212 .47999 m .3616 .45514 L .35386 .47974 L p
1 g
F P
s
P
p
.002 w
.62266 .35869 m .60501 .38945 L .62271 .41133 L p
1 g
F P
s
P
p
.002 w
.60501 .38945 m .62266 .35869 L .59922 .34298 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .51439 .31805 L .51791 .31097 L closepath p
1 g
F P
s
P
p
.002 w
.46555 .32174 m .46112 .31526 L .43425 .32737 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .46112 .31526 L .46555 .32174 L closepath p
1 g
F P
s
P
p
.002 w
.34751 .39898 m .37264 .43041 L .38666 .40607 L p
1 g
F P
s
P
p
.002 w
.38666 .40607 m .36505 .37824 L .34751 .39898 L p
1 g
F P
s
P
p
.002 w
.45032 .5675 m .50927 .56932 L .50734 .54689 L p
1 g
F P
s
P
p
.002 w
.50734 .54689 m .44922 .54498 L .45032 .5675 L p
1 g
F P
s
P
p
.002 w
.56458 .53607 m .50734 .54689 L .50927 .56932 L p
1 g
F P
s
P
p
.002 w
.54739 .3041 m .54628 .31891 L .57357 .32964 L p
1 g
F P
s
P
p
.002 w
.54628 .31891 m .54739 .3041 L .51834 .30346 L p
1 g
F P
s
P
p
.002 w
.51834 .30346 m .51791 .31097 L .54628 .31891 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .51791 .31097 L .51834 .30346 L closepath p
1 g
F P
s
P
p
.002 w
.43118 .31286 m .43425 .32737 L .46112 .31526 L p
1 g
F P
s
P
p
.002 w
.46112 .31526 m .4597 .30788 L .43118 .31286 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .4597 .30788 L .46112 .31526 L closepath p
1 g
F P
s
P
p
.002 w
.40406 .32088 m .40893 .3421 L .43425 .32737 L p
1 g
F P
s
P
p
.002 w
.43425 .32737 m .43118 .31286 L .40406 .32088 L p
1 g
F P
s
P
p
.002 w
.50927 .56932 m .56735 .55844 L .56458 .53607 L p
1 g
F P
s
P
p
.002 w
.61617 .51328 m .56458 .53607 L .56735 .55844 L p
1 g
F P
s
P
p
.002 w
.56458 .53607 m .61617 .51328 L .60981 .48948 L p
1 g
F P
s
P
p
.002 w
.64336 .37648 m .62271 .41133 L .6376 .43402 L p
1 g
F P
s
P
p
.002 w
.62271 .41133 m .64336 .37648 L .62266 .35869 L p
1 g
F P
s
P
p
.002 w
.64929 .45709 m .60981 .48948 L .61617 .51328 L p
1 g
F P
s
P
p
.002 w
.60981 .48948 m .64929 .45709 L .6376 .43402 L p
1 g
F P
s
P
p
.002 w
.57557 .30793 m .57357 .32964 L .59922 .34298 L p
1 g
F P
s
P
p
.002 w
.57357 .32964 m .57557 .30793 L .54739 .3041 L p
1 g
F P
s
P
p
.002 w
.48901 .306 m .51834 .30346 L .51559 .29633 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .46628 .29365 L .46147 .30041 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .46147 .30041 L .4597 .30788 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .51559 .29633 L .50993 .29036 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .50993 .29036 L .50195 .28624 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .50195 .28624 L .49253 .28444 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .49253 .28444 L .48273 .28518 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .48273 .28518 L .47364 .28837 L closepath p
1 g
F P
s
P
p
.002 w
.48901 .306 m .47364 .28837 L .46628 .29365 L closepath p
1 g
F P
s
P
p
.002 w
.39538 .55294 m .45032 .5675 L .44922 .54498 L p
1 g
F P
s
P
p
.002 w
.44922 .54498 m .39504 .53033 L .39538 .55294 L p
1 g
F P
s
P
p
.002 w
.37894 .33182 m .38569 .35916 L .40893 .3421 L p
1 g
F P
s
P
p
.002 w
.40893 .3421 m .40406 .32088 L .37894 .33182 L p
1 g
F P
s
P
p
.002 w
.3497 .50368 m .39504 .53033 L .39734 .50582 L p
1 g
F P
s
P
p
.002 w
.39734 .50582 m .35386 .47974 L .3497 .50368 L p
1 g
F P
s
P
p
.002 w
.33353 .42096 m .3616 .45514 L .37264 .43041 L p
1 g
F P
s
P
p
.002 w
.37264 .43041 m .34751 .39898 L .33353 .42096 L p
1 g
F P
s
P
p
.002 w
.51559 .29633 m .51834 .30346 L .54739 .3041 L p
1 g
F P
s
P
p
.002 w
.43445 .29802 m .43118 .31286 L .4597 .30788 L p
1 g
F P
s
P
p
.002 w
.4597 .30788 m .46147 .30041 L .43445 .29802 L p
1 g
F P
s
P
p
.002 w
.60226 .31495 m .59922 .34298 L .62266 .35869 L p
1 g
F P
s
P
p
.002 w
.59922 .34298 m .60226 .31495 L .57557 .30793 L p
1 g
F P
s
P
p
.002 w
.35645 .34553 m .36505 .37824 L .38569 .35916 L p
1 g
F P
s
P
p
.002 w
.38569 .35916 m .37894 .33182 L .35645 .34553 L p
1 g
F P
s
P
p
.002 w
.54219 .2899 m .54739 .3041 L .57557 .30793 L p
1 g
F P
s
P
p
.002 w
.54739 .3041 m .54219 .2899 L .51559 .29633 L p
1 g
F P
s
P
p
.002 w
.50993 .29036 m .51559 .29633 L .54219 .2899 L p
1 g
F P
s
P
p
.002 w
.44387 .2845 m .43445 .29802 L .46147 .30041 L p
1 g
F P
s
P
p
.002 w
.46147 .30041 m .46628 .29365 L .44387 .2845 L p
1 g
F P
s
P
p
.002 w
.40856 .29898 m .40406 .32088 L .43118 .31286 L p
1 g
F P
s
P
p
.002 w
.43118 .31286 m .43445 .29802 L .40856 .29898 L p
1 g
F P
s
P
p
.002 w
.66079 .39602 m .6376 .43402 L .64929 .45709 L p
1 g
F P
s
P
p
.002 w
.6376 .43402 m .66079 .39602 L .64336 .37648 L p
1 g
F P
s
P
p
.002 w
.45275 .58719 m .51103 .58889 L .50927 .56932 L p
1 g
F P
s
P
p
.002 w
.50927 .56932 m .45032 .5675 L .45275 .58719 L p
1 g
F P
s
P
p
.002 w
.56735 .55844 m .50927 .56932 L .51103 .58889 L p
1 g
F P
s
P
p
.002 w
.54219 .2899 m .53109 .27794 L .50993 .29036 L p
1 g
F P
s
P
p
.002 w
.50195 .28624 m .50993 .29036 L .53109 .27794 L p
1 g
F P
s
P
p
.002 w
.32356 .44374 m .35386 .47974 L .3616 .45514 L p
1 g
F P
s
P
p
.002 w
.3616 .45514 m .33353 .42096 L .32356 .44374 L p
1 g
F P
s
P
p
.002 w
.45848 .27387 m .44387 .2845 L .46628 .29365 L p
1 g
F P
s
P
p
.002 w
.46628 .29365 m .47364 .28837 L .45848 .27387 L p
1 g
F P
s
P
p
.002 w
.62684 .32508 m .62266 .35869 L .64336 .37648 L p
1 g
F P
s
P
p
.002 w
.62266 .35869 m .62684 .32508 L .60226 .31495 L p
1 g
F P
s
P
p
.002 w
.56735 .55844 m .61972 .5356 L .61617 .51328 L p
1 g
F P
s
P
p
.002 w
.65742 .48003 m .61617 .51328 L .61972 .5356 L p
1 g
F P
s
P
p
.002 w
.61617 .51328 m .65742 .48003 L .64929 .45709 L p
1 g
F P
s
P
p
.002 w
.56823 .28695 m .57557 .30793 L .60226 .31495 L p
1 g
F P
s
P
p
.002 w
.57557 .30793 m .56823 .28695 L .54219 .2899 L p
1 g
F P
s
P
p
.002 w
.53109 .27794 m .51523 .26961 L .50195 .28624 L p
1 g
F P
s
P
p
.002 w
.49253 .28444 m .50195 .28624 L .51523 .26961 L p
1 g
F P
s
P
p
.002 w
.47668 .26743 m .45848 .27387 L .47364 .28837 L p
1 g
F P
s
P
p
.002 w
.47364 .28837 m .48273 .28518 L .47668 .26743 L p
1 g
F P
s
P
p
.002 w
.51103 .58889 m .56847 .57822 L .56735 .55844 L p
1 g
F P
s
P
p
.002 w
.61972 .5356 m .56735 .55844 L .56847 .57822 L p
1 g
F P
s
P
p
.002 w
.33717 .36179 m .34751 .39898 L .36505 .37824 L p
1 g
F P
s
P
p
.002 w
.36505 .37824 m .35645 .34553 L .33717 .36179 L p
1 g
F P
s
P
p
.002 w
.34937 .52639 m .39538 .55294 L .39504 .53033 L p
1 g
F P
s
P
p
.002 w
.39504 .53033 m .3497 .50368 L .34937 .52639 L p
1 g
F P
s
P
p
.002 w
.3844 .30338 m .37894 .33182 L .40406 .32088 L p
1 g
F P
s
P
p
.002 w
.40406 .32088 m .40856 .29898 L .3844 .30338 L p
1 g
F P
s
P
p
.002 w
.39845 .57307 m .45275 .58719 L .45032 .5675 L p
1 g
F P
s
P
p
.002 w
.45032 .5675 m .39538 .55294 L .39845 .57307 L p
1 g
F P
s
P
p
.002 w
.51523 .26961 m .49636 .26595 L .49253 .28444 L p
1 g
F P
s
P
p
.002 w
.48273 .28518 m .49253 .28444 L .49636 .26595 L p
1 g
F P
s
P
p
.002 w
.49636 .26595 m .47668 .26743 L .48273 .28518 L p
1 g
F P
s
P
p
.002 w
.53109 .27794 m .54219 .2899 L .56823 .28695 L p
1 g
F P
s
P
p
.002 w
.42227 .27887 m .40856 .29898 L .43445 .29802 L p
1 g
F P
s
P
p
.002 w
.43445 .29802 m .44387 .2845 L .42227 .27887 L p
1 g
F P
s
P
p
.002 w
.67445 .41693 m .64929 .45709 L .65742 .48003 L p
1 g
F P
s
P
p
.002 w
.64929 .45709 m .67445 .41693 L .66079 .39602 L p
1 g
F P
s
P
p
.002 w
.64867 .33819 m .64336 .37648 L .66079 .39602 L p
1 g
F P
s
P
p
.002 w
.64336 .37648 m .64867 .33819 L .62684 .32508 L p
1 g
F P
s
P
p
.002 w
.318 .46678 m .3497 .50368 L .35386 .47974 L p
1 g
F P
s
P
p
.002 w
.35386 .47974 m .32356 .44374 L .318 .46678 L p
1 g
F P
s
P
p
.002 w
.59313 .28765 m .60226 .31495 L .62684 .32508 L p
1 g
F P
s
P
p
.002 w
.60226 .31495 m .59313 .28765 L .56823 .28695 L p
1 g
F P
s
P
p
.002 w
.56823 .28695 m .55202 .26912 L .53109 .27794 L p
1 g
F P
s
P
p
.002 w
.51523 .26961 m .53109 .27794 L .55202 .26912 L p
1 g
F P
s
P
p
.002 w
.32169 .38031 m .33353 .42096 L .34751 .39898 L p
1 g
F P
s
P
p
.002 w
.34751 .39898 m .33717 .36179 L .32169 .38031 L p
1 g
F P
s
P
p
.002 w
.36261 .31125 m .35645 .34553 L .37894 .33182 L p
1 g
F P
s
P
p
.002 w
.37894 .33182 m .3844 .30338 L .36261 .31125 L p
1 g
F P
s
P
p
.002 w
.44389 .26297 m .42227 .27887 L .44387 .2845 L p
1 g
F P
s
P
p
.002 w
.44387 .2845 m .45848 .27387 L .44389 .26297 L p
1 g
F P
s
P
p
.002 w
.45649 .60348 m .51257 .60504 L .51103 .58889 L p
1 g
F P
s
P
p
.002 w
.51103 .58889 m .45275 .58719 L .45649 .60348 L p
1 g
F P
s
P
p
.002 w
.56847 .57822 m .51103 .58889 L .51257 .60504 L p
1 g
F P
s
P
p
.002 w
.55202 .26912 m .56823 .28695 L .59313 .28765 L p
1 g
F P
s
P
p
.002 w
.56847 .57822 m .62028 .55589 L .61972 .5356 L p
1 g
F P
s
P
p
.002 w
.66167 .50233 m .61972 .5356 L .62028 .55589 L p
1 g
F P
s
P
p
.002 w
.61972 .5356 m .66167 .50233 L .65742 .48003 L p
1 g
F P
s
P
p
.002 w
.40203 .27706 m .3844 .30338 L .40856 .29898 L p
1 g
F P
s
P
p
.002 w
.40856 .29898 m .42227 .27887 L .40203 .27706 L p
1 g
F P
s
P
p
.002 w
.35303 .54725 m .39845 .57307 L .39538 .55294 L p
1 g
F P
s
P
p
.002 w
.39538 .55294 m .34937 .52639 L .35303 .54725 L p
1 g
F P
s
P
p
.002 w
.55202 .26912 m .52854 .25662 L .51523 .26961 L p
1 g
F P
s
P
p
.002 w
.49636 .26595 m .51523 .26961 L .52854 .25662 L p
1 g
F P
s
P
p
.002 w
.47102 .25329 m .44389 .26297 L .45848 .27387 L p
1 g
F P
s
P
p
.002 w
.45848 .27387 m .47668 .26743 L .47102 .25329 L p
1 g
F P
s
P
p
.002 w
.51257 .60504 m .56785 .59483 L .56847 .57822 L p
1 g
F P
s
P
p
.002 w
.62028 .55589 m .56847 .57822 L .56785 .59483 L p
1 g
F P
s
P
p
.002 w
.40432 .59012 m .45649 .60348 L .45275 .58719 L p
1 g
F P
s
P
p
.002 w
.45275 .58719 m .39845 .57307 L .40432 .59012 L p
1 g
F P
s
P
p
.002 w
.66715 .35409 m .66079 .39602 L .67445 .41693 L p
1 g
F P
s
P
p
.002 w
.66079 .39602 m .66715 .35409 L .64867 .33819 L p
1 g
F P
s
P
p
.002 w
.52854 .25662 m .50043 .25109 L .49636 .26595 L p
1 g
F P
s
P
p
.002 w
.47668 .26743 m .49636 .26595 L .50043 .25109 L p
1 g
F P
s
P
p
.002 w
.50043 .25109 m .47102 .25329 L .47668 .26743 L p
1 g
F P
s
P
p
.002 w
.61625 .29213 m .62684 .32508 L .64867 .33819 L p
1 g
F P
s
P
p
.002 w
.62684 .32508 m .61625 .29213 L .59313 .28765 L p
1 g
F P
s
P
p
.002 w
.68388 .43877 m .65742 .48003 L .66167 .50233 L p
1 g
F P
s
P
p
.002 w
.65742 .48003 m .68388 .43877 L .67445 .41693 L p
1 g
F P
s
P
p
.002 w
.31055 .40071 m .32356 .44374 L .33353 .42096 L p
1 g
F P
s
P
p
.002 w
.33353 .42096 m .32169 .38031 L .31055 .40071 L p
1 g
F P
s
P
p
.002 w
.34383 .32255 m .33717 .36179 L .35645 .34553 L p
1 g
F P
s
P
p
.002 w
.35645 .34553 m .36261 .31125 L .34383 .32255 L p
1 g
F P
s
P
p
.002 w
.31716 .48955 m .34937 .52639 L .3497 .50368 L p
1 g
F P
s
P
p
.002 w
.3497 .50368 m .318 .46678 L .31716 .48955 L p
1 g
F P
s
P
p
.002 w
.59313 .28765 m .57224 .26427 L .55202 .26912 L p
1 g
F P
s
P
p
.002 w
.52854 .25662 m .55202 .26912 L .57224 .26427 L p
1 g
F P
s
P
p
.002 w
.43026 .25613 m .40203 .27706 L .42227 .27887 L p
1 g
F P
s
P
p
.002 w
.42227 .27887 m .44389 .26297 L .43026 .25613 L p
1 g
F P
s
P
p
.002 w
.57224 .26427 m .59313 .28765 L .61625 .29213 L p
1 g
F P
s
P
p
.002 w
.38372 .2793 m .36261 .31125 L .3844 .30338 L p
1 g
F P
s
P
p
.002 w
.3844 .30338 m .40203 .27706 L .38372 .2793 L p
1 g
F P
s
P
p
.002 w
.56785 .59483 m .61766 .57357 L .62028 .55589 L p
1 g
F P
s
P
p
.002 w
.66175 .52342 m .62028 .55589 L .61766 .57357 L p
1 g
F P
s
P
p
.002 w
.62028 .55589 m .66175 .52342 L .66167 .50233 L p
1 g
F P
s
P
p
.002 w
.68167 .37249 m .67445 .41693 L .68388 .43877 L p
1 g
F P
s
P
p
.002 w
.67445 .41693 m .68167 .37249 L .66715 .35409 L p
1 g
F P
s
P
p
.002 w
.46155 .61579 m .51383 .61719 L .51257 .60504 L p
1 g
F P
s
P
p
.002 w
.51257 .60504 m .45649 .60348 L .46155 .61579 L p
1 g
F P
s
P
p
.002 w
.56785 .59483 m .51257 .60504 L .51383 .61719 L p
1 g
F P
s
P
p
.002 w
.63696 .30043 m .64867 .33819 L .66715 .35409 L p
1 g
F P
s
P
p
.002 w
.64867 .33819 m .63696 .30043 L .61625 .29213 L p
1 g
F P
s
P
p
.002 w
.3608 .56566 m .40432 .59012 L .39845 .57307 L p
1 g
F P
s
P
p
.002 w
.39845 .57307 m .35303 .54725 L .3608 .56566 L p
1 g
F P
s
P
p
.002 w
.57224 .26427 m .54159 .24778 L .52854 .25662 L p
1 g
F P
s
P
p
.002 w
.50043 .25109 m .52854 .25662 L .54159 .24778 L p
1 g
F P
s
P
p
.002 w
.46591 .24334 m .43026 .25613 L .44389 .26297 L p
1 g
F P
s
P
p
.002 w
.44389 .26297 m .47102 .25329 L .46591 .24334 L p
1 g
F P
s
P
p
.002 w
.32868 .33716 m .32169 .38031 L .33717 .36179 L p
1 g
F P
s
P
p
.002 w
.33717 .36179 m .34383 .32255 L .32868 .33716 L p
1 g
F P
s
P
p
.002 w
.68864 .46104 m .66167 .50233 L .66175 .52342 L p
1 g
F P
s
P
p
.002 w
.66167 .50233 m .68864 .46104 L .68388 .43877 L p
1 g
F P
s
P
p
.002 w
.30424 .42256 m .318 .46678 L .32356 .44374 L p
1 g
F P
s
P
p
.002 w
.32356 .44374 m .31055 .40071 L .30424 .42256 L p
1 g
F P
s
P
p
.002 w
.51383 .61719 m .56538 .60771 L .56785 .59483 L p
1 g
F P
s
P
p
.002 w
.61766 .57357 m .56785 .59483 L .56538 .60771 L p
1 g
F P
s
P
p
.002 w
.413 .60349 m .46155 .61579 L .45649 .60348 L p
1 g
F P
s
P
p
.002 w
.45649 .60348 m .40432 .59012 L .413 .60349 L p
1 g
F P
s
P
p
.002 w
.32131 .51141 m .35303 .54725 L .34937 .52639 L p
1 g
F P
s
P
p
.002 w
.34937 .52639 m .31716 .48955 L .32131 .51141 L p
1 g
F P
s
P
p
.002 w
.54159 .24778 m .50464 .24044 L .50043 .25109 L p
1 g
F P
s
P
p
.002 w
.47102 .25329 m .50043 .25109 L .50464 .24044 L p
1 g
F P
s
P
p
.002 w
.50464 .24044 m .46591 .24334 L .47102 .25329 L p
1 g
F P
s
P
p
.002 w
.59122 .26371 m .61625 .29213 L .63696 .30043 L p
1 g
F P
s
P
p
.002 w
.61625 .29213 m .59122 .26371 L .57224 .26427 L p
1 g
F P
s
P
p
.002 w
.54159 .24778 m .57224 .26427 L .59122 .26371 L p
1 g
F P
s
P
p
.002 w
.3679 .28576 m .34383 .32255 L .36261 .31125 L p
1 g
F P
s
P
p
.002 w
.36261 .31125 m .38372 .2793 L .3679 .28576 L p
1 g
F P
s
P
p
.002 w
.41797 .25375 m .38372 .2793 L .40203 .27706 L p
1 g
F P
s
P
p
.002 w
.40203 .27706 m .43026 .25613 L .41797 .25375 L p
1 g
F P
s
P
p
.002 w
.65463 .31253 m .66715 .35409 L .68167 .37249 L p
1 g
F P
s
P
p
.002 w
.66715 .35409 m .65463 .31253 L .63696 .30043 L p
1 g
F P
s
P
p
.002 w
.69169 .39303 m .68388 .43877 L .68864 .46104 L p
1 g
F P
s
P
p
.002 w
.68388 .43877 m .69169 .39303 L .68167 .37249 L p
1 g
F P
s
P
p
.002 w
.56538 .60771 m .61177 .58805 L .61766 .57357 L p
1 g
F P
s
P
p
.002 w
.65747 .54271 m .61766 .57357 L .61177 .58805 L p
1 g
F P
s
P
p
.002 w
.61766 .57357 m .65747 .54271 L .66175 .52342 L p
1 g
F P
s
P
p
.002 w
.31776 .35485 m .31055 .40071 L .32169 .38031 L p
1 g
F P
s
P
p
.002 w
.32169 .38031 m .32868 .33716 L .31776 .35485 L p
1 g
F P
s
P
p
.002 w
.30317 .44532 m .31716 .48955 L .318 .46678 L p
1 g
F P
s
P
p
.002 w
.318 .46678 m .30424 .42256 L .30317 .44532 L p
1 g
F P
s
P
p
.002 w
.37268 .58099 m .413 .60349 L .40432 .59012 L p
1 g
F P
s
P
p
.002 w
.40432 .59012 m .3608 .56566 L .37268 .58099 L p
1 g
F P
s
P
p
.002 w
.68841 .48318 m .66175 .52342 L .65747 .54271 L p
1 g
F P
s
P
p
.002 w
.66175 .52342 m .68841 .48318 L .68864 .46104 L p
1 g
F P
s
P
p
.002 w
.46786 .62355 m .51477 .62478 L .51383 .61719 L p
1 g
F P
s
P
p
.002 w
.51383 .61719 m .46155 .61579 L .46786 .62355 L p
1 g
F P
s
P
p
.002 w
.56538 .60771 m .51383 .61719 L .51477 .62478 L p
1 g
F P
s
P
p
.002 w
.59122 .26371 m .55403 .24355 L .54159 .24778 L p
1 g
F P
s
P
p
.002 w
.50464 .24044 m .54159 .24778 L .55403 .24355 L p
1 g
F P
s
P
p
.002 w
.33055 .53173 m .3608 .56566 L .35303 .54725 L p
1 g
F P
s
P
p
.002 w
.35303 .54725 m .32131 .51141 L .33055 .53173 L p
1 g
F P
s
P
p
.002 w
.46151 .23808 m .41797 .25375 L .43026 .25613 L p
1 g
F P
s
P
p
.002 w
.43026 .25613 m .46591 .24334 L .46151 .23808 L p
1 g
F P
s
P
p
.002 w
.51477 .62478 m .56104 .61629 L .56538 .60771 L p
1 g
F P
s
P
p
.002 w
.61177 .58805 m .56538 .60771 L .56104 .61629 L p
1 g
F P
s
P
p
.002 w
.6084 .26767 m .63696 .30043 L .65463 .31253 L p
1 g
F P
s
P
p
.002 w
.63696 .30043 m .6084 .26767 L .59122 .26371 L p
1 g
F P
s
P
p
.002 w
.42443 .61261 m .46786 .62355 L .46155 .61579 L p
1 g
F P
s
P
p
.002 w
.46155 .61579 m .413 .60349 L .42443 .61261 L p
1 g
F P
s
P
p
.002 w
.35516 .29649 m .32868 .33716 L .34383 .32255 L p
1 g
F P
s
P
p
.002 w
.34383 .32255 m .3679 .28576 L .35516 .29649 L p
1 g
F P
s
P
p
.002 w
.55403 .24355 m .59122 .26371 L .6084 .26767 L p
1 g
F P
s
P
p
.002 w
.55403 .24355 m .50891 .23453 L .50464 .24044 L p
1 g
F P
s
P
p
.002 w
.46591 .24334 m .50464 .24044 L .50891 .23453 L p
1 g
F P
s
P
p
.002 w
.50891 .23453 m .46151 .23808 L .46591 .24334 L p
1 g
F P
s
P
p
.002 w
.66862 .32829 m .68167 .37249 L .69169 .39303 L p
1 g
F P
s
P
p
.002 w
.68167 .37249 m .66862 .32829 L .65463 .31253 L p
1 g
F P
s
P
p
.002 w
.40744 .25617 m .3679 .28576 L .38372 .2793 L p
1 g
F P
s
P
p
.002 w
.38372 .2793 m .41797 .25375 L .40744 .25617 L p
1 g
F P
s
P
p
.002 w
.69673 .41525 m .68864 .46104 L .68841 .48318 L p
1 g
F P
s
P
p
.002 w
.68864 .46104 m .69673 .41525 L .69169 .39303 L p
1 g
F P
s
P
p
.002 w
.31159 .37527 m .30424 .42256 L .31055 .40071 L p
1 g
F P
s
P
p
.002 w
.31055 .40071 m .31776 .35485 L .31159 .37527 L p
1 g
F P
s
P
p
.002 w
.30761 .46838 m .32131 .51141 L .31716 .48955 L p
1 g
F P
s
P
p
.002 w
.31716 .48955 m .30317 .44532 L .30761 .46838 L p
1 g
F P
s
P
p
.002 w
.56104 .61629 m .60257 .59876 L .61177 .58805 L p
1 g
F P
s
P
p
.002 w
.6487 .5596 m .61177 .58805 L .60257 .59876 L p
1 g
F P
s
P
p
.002 w
.61177 .58805 m .6487 .5596 L .65747 .54271 L p
1 g
F P
s
P
p
.002 w
.68295 .50457 m .65747 .54271 L .6487 .5596 L p
1 g
F P
s
P
p
.002 w
.65747 .54271 m .68295 .50457 L .68841 .48318 L p
1 g
F P
s
P
p
.002 w
.38856 .59264 m .42443 .61261 L .413 .60349 L p
1 g
F P
s
P
p
.002 w
.413 .60349 m .37268 .58099 L .38856 .59264 L p
1 g
F P
s
P
p
.002 w
.34487 .54985 m .37268 .58099 L .3608 .56566 L p
1 g
F P
s
P
p
.002 w
.3608 .56566 m .33055 .53173 L .34487 .54985 L p
1 g
F P
s
P
p
.002 w
.62322 .27631 m .65463 .31253 L .66862 .32829 L p
1 g
F P
s
P
p
.002 w
.65463 .31253 m .62322 .27631 L .6084 .26767 L p
1 g
F P
s
P
p
.002 w
.6084 .26767 m .56549 .24432 L .55403 .24355 L p
1 g
F P
s
P
p
.002 w
.50891 .23453 m .55403 .24355 L .56549 .24432 L p
1 g
F P
s
P
p
.002 w
.47534 .62626 m .51534 .6273 L .51477 .62478 L p
1 g
F P
s
P
p
.002 w
.51477 .62478 m .46786 .62355 L .47534 .62626 L p
1 g
F P
s
P
p
.002 w
.56104 .61629 m .51477 .62478 L .51534 .6273 L p
1 g
F P
s
P
p
.002 w
.458 .23798 m .40744 .25617 L .41797 .25375 L p
1 g
F P
s
P
p
.002 w
.41797 .25375 m .46151 .23808 L .458 .23798 L p
1 g
F P
s
P
p
.002 w
.34604 .31143 m .31776 .35485 L .32868 .33716 L p
1 g
F P
s
P
p
.002 w
.32868 .33716 m .35516 .29649 L .34604 .31143 L p
1 g
F P
s
P
p
.002 w
.69169 .39303 m .67835 .34745 L .66862 .32829 L p
1 g
F P
s
P
p
.002 w
.67835 .34745 m .69169 .39303 L .69673 .41525 L p
1 g
F P
s
P
p
.002 w
.51534 .6273 m .5548 .62007 L .56104 .61629 L p
1 g
F P
s
P
p
.002 w
.60257 .59876 m .56104 .61629 L .5548 .62007 L p
1 g
F P
s
P
p
.002 w
.56549 .24432 m .6084 .26767 L .62322 .27631 L p
1 g
F P
s
P
p
.002 w
.68841 .48318 m .69639 .43861 L .69673 .41525 L p
1 g
F P
s
P
p
.002 w
.69639 .43861 m .68841 .48318 L .68295 .50457 L p
1 g
F P
s
P
p
.004 w
.51866 .64199 m
.52099 .66843 L
s
P
p
.004 w
.2963 .64984 m
.35186 .59001 L
s
P
p
.002 w
.43843 .61698 m .47534 .62626 L .46786 .62355 L p
1 g
F P
s
P
p
.002 w
.46786 .62355 m .42443 .61261 L .43843 .61698 L p
1 g
F P
s
P
p
.002 w
.3106 .39795 m .30317 .44532 L .30424 .42256 L p
1 g
F P
s
P
p
.002 w
.30424 .42256 m .31159 .37527 L .3106 .39795 L p
1 g
F P
s
P
p
.002 w
.39909 .26364 m .35516 .29649 L .3679 .28576 L p
1 g
F P
s
P
p
.002 w
.3679 .28576 m .40744 .25617 L .39909 .26364 L p
1 g
F P
s
P
p
.002 w
.31768 .49106 m .33055 .53173 L .32131 .51141 L p
1 g
F P
s
P
p
.002 w
.32131 .51141 m .30761 .46838 L .31768 .49106 L p
1 g
F P
s
P
p
.002 w
.56549 .24432 m .51312 .23385 L .50891 .23453 L p
1 g
F P
s
P
p
.002 w
.46151 .23808 m .50891 .23453 L .51312 .23385 L p
1 g
F P
s
P
p
.002 w
.51312 .23385 m .458 .23798 L .46151 .23808 L p
1 g
F P
s
P
p
.002 w
.60257 .59876 m .63546 .57349 L .6487 .5596 L p
1 g
F P
s
P
p
.002 w
.6487 .5596 m .67216 .52458 L .68295 .50457 L p
1 g
F P
s
P
p
.002 w
.67216 .52458 m .6487 .5596 L .63546 .57349 L p
1 g
F P
s
P
p
.002 w
.5548 .62007 m .59012 .60518 L .60257 .59876 L p
1 g
F P
s
P
p
.002 w
.63546 .57349 m .60257 .59876 L .59012 .60518 L p
1 g
F P
s
P
p
.002 w
.36409 .56512 m .38856 .59264 L .37268 .58099 L p
1 g
F P
s
P
p
.002 w
.37268 .58099 m .34487 .54985 L .36409 .56512 L p
1 g
F P
s
P
p
.004 w
.36942 .57111 m
.5 .43051 L
s
P
p
.004 w
.36633 .57443 m
.36732 .57337 L
s
P
p
.004 w
.36239 .57868 m
.36633 .57443 L
s
P
p
.004 w
.35186 .59001 m
.36239 .57868 L
s
P
p
.002 w
.40817 .60008 m .43843 .61698 L .42443 .61261 L p
1 g
F P
s
P
p
.002 w
.42443 .61261 m .38856 .59264 L .40817 .60008 L p
1 g
F P
s
P
p
.002 w
.66862 .32829 m .63511 .28964 L .62322 .27631 L p
1 g
F P
s
P
p
.002 w
.63511 .28964 m .66862 .32829 L .67835 .34745 L p
1 g
F P
s
P
p
.002 w
.68332 .36962 m .69673 .41525 L .69639 .43861 L p
1 g
F P
s
P
p
.002 w
.69673 .41525 m .68332 .36962 L .67835 .34745 L p
1 g
F P
s
P
p
.002 w
.34102 .33037 m .31159 .37527 L .31776 .35485 L p
1 g
F P
s
P
p
.002 w
.31776 .35485 m .34604 .31143 L .34102 .33037 L p
1 g
F P
s
P
p
.002 w
.62322 .27631 m .57557 .25039 L .56549 .24432 L p
1 g
F P
s
P
p
.002 w
.51312 .23385 m .56549 .24432 L .57557 .25039 L p
1 g
F P
s
P
p
.002 w
.69045 .46246 m .68295 .50457 L .67216 .52458 L p
1 g
F P
s
P
p
.002 w
.68295 .50457 m .69045 .46246 L .69639 .43861 L p
1 g
F P
s
P
p
.002 w
.45553 .24336 m .39909 .26364 L .40744 .25617 L p
1 g
F P
s
P
p
.002 w
.40744 .25617 m .458 .23798 L .45553 .24336 L p
1 g
F P
s
P
p
.002 w
.31508 .4223 m .30761 .46838 L .30317 .44532 L p
1 g
F P
s
P
p
.002 w
.30317 .44532 m .3106 .39795 L .31508 .4223 L p
1 g
F P
s
P
p
.002 w
.48384 .62353 m .5155 .62435 L .51534 .6273 L p
1 g
F P
s
P
p
.002 w
.51534 .6273 m .47534 .62626 L .48384 .62353 L p
1 g
F P
s
P
p
.002 w
.5548 .62007 m .51534 .6273 L .5155 .62435 L p
1 g
F P
s
P
p
.002 w
.57557 .25039 m .62322 .27631 L .63511 .28964 L p
1 g
F P
s
P
p
.002 w
.33333 .51265 m .34487 .54985 L .33055 .53173 L p
1 g
F P
s
P
p
.002 w
.33055 .53173 m .31768 .49106 L .33333 .51265 L p
1 g
F P
s
P
p
.002 w
.39332 .27623 m .34604 .31143 L .35516 .29649 L p
1 g
F P
s
P
p
.002 w
.35516 .29649 m .39909 .26364 L .39332 .27623 L p
1 g
F P
s
P
p
.002 w
.5155 .62435 m .54674 .61863 L .5548 .62007 L p
1 g
F P
s
P
p
.002 w
.59012 .60518 m .5548 .62007 L .54674 .61863 L p
1 g
F P
s
P
p
.002 w
.45475 .61617 m .48384 .62353 L .47534 .62626 L p
1 g
F P
s
P
p
.002 w
.47534 .62626 m .43843 .61698 L .45475 .61617 L p
1 g
F P
s
P
p
.002 w
.57557 .25039 m .51714 .23875 L .51312 .23385 L p
1 g
F P
s
P
p
.002 w
.458 .23798 m .51312 .23385 L .51714 .23875 L p
1 g
F P
s
P
p
.002 w
.51714 .23875 m .45553 .24336 L .458 .23798 L p
1 g
F P
s
P
p
.002 w
.59012 .60518 m .61788 .5838 L .63546 .57349 L p
1 g
F P
s
P
p
.002 w
.65611 .54253 m .63546 .57349 L .61788 .5838 L p
1 g
F P
s
P
p
.002 w
.63546 .57349 m .65611 .54253 L .67216 .52458 L p
1 g
F P
s
P
p
.002 w
.64355 .30752 m .67835 .34745 L .68332 .36962 L p
1 g
F P
s
P
p
.002 w
.67835 .34745 m .64355 .30752 L .63511 .28964 L p
1 g
F P
s
P
p
.002 w
.38782 .57692 m .40817 .60008 L .38856 .59264 L p
1 g
F P
s
P
p
.002 w
.38856 .59264 m .36409 .56512 L .38782 .57692 L p
1 g
F P
s
P
p
.002 w
.68314 .39425 m .69639 .43861 L .69045 .46246 L p
1 g
F P
s
P
p
.002 w
.69639 .43861 m .68314 .39425 L .68332 .36962 L p
1 g
F P
s
P
p
.002 w
.54674 .61863 m .57458 .60685 L .59012 .60518 L p
1 g
F P
s
P
p
.002 w
.61788 .5838 m .59012 .60518 L .57458 .60685 L p
1 g
F P
s
P
p
.002 w
.43111 .60286 m .45475 .61617 L .43843 .61698 L p
1 g
F P
s
P
p
.002 w
.43843 .61698 m .40817 .60008 L .43111 .60286 L p
1 g
F P
s
P
p
.002 w
.3405 .35291 m .3106 .39795 L .31159 .37527 L p
1 g
F P
s
P
p
.002 w
.31159 .37527 m .34102 .33037 L .3405 .35291 L p
1 g
F P
s
P
p
.002 w
.67882 .48607 m .67216 .52458 L .65611 .54253 L p
1 g
F P
s
P
p
.002 w
.67216 .52458 m .67882 .48607 L .69045 .46246 L p
1 g
F P
s
P
p
.002 w
.32513 .4476 m .31768 .49106 L .30761 .46838 L p
1 g
F P
s
P
p
.002 w
.30761 .46838 m .31508 .4223 L .32513 .4476 L p
1 g
F P
s
P
p
.002 w
.35429 .53239 m .36409 .56512 L .34487 .54985 L p
1 g
F P
s
P
p
.002 w
.34487 .54985 m .33333 .51265 L .35429 .53239 L p
1 g
F P
s
P
p
.002 w
.63511 .28964 m .58389 .26192 L .57557 .25039 L p
1 g
F P
s
P
p
.002 w
.51714 .23875 m .57557 .25039 L .58389 .26192 L p
1 g
F P
s
P
p
.002 w
.58389 .26192 m .63511 .28964 L .64355 .30752 L p
1 g
F P
s
P
p
.002 w
.45425 .25445 m .39332 .27623 L .39909 .26364 L p
1 g
F P
s
P
p
.002 w
.39909 .26364 m .45553 .24336 L .45425 .25445 L p
1 g
F P
s
P
p
.002 w
.39045 .29387 m .34102 .33037 L .34604 .31143 L p
1 g
F P
s
P
p
.002 w
.34604 .31143 m .39332 .27623 L .39045 .29387 L p
1 g
F P
s
P
p
.002 w
.49318 .61506 m .51522 .61566 L .5155 .62435 L p
1 g
F P
s
P
p
.002 w
.5155 .62435 m .48384 .62353 L .49318 .61506 L p
1 g
F P
s
P
p
.002 w
.54674 .61863 m .5155 .62435 L .51522 .61566 L p
1 g
F P
s
P
p
.002 w
.51522 .61566 m .53697 .61166 L .54674 .61863 L p
1 g
F P
s
P
p
.002 w
.57458 .60685 m .54674 .61863 L .53697 .61166 L p
1 g
F P
s
P
p
.002 w
.47302 .60991 m .49318 .61506 L .48384 .62353 L p
1 g
F P
s
P
p
.002 w
.48384 .62353 m .45475 .61617 L .47302 .60991 L p
1 g
F P
s
P
p
.002 w
.57458 .60685 m .59628 .59003 L .61788 .5838 L p
1 g
F P
s
P
p
.002 w
.63505 .55777 m .61788 .5838 L .59628 .59003 L p
1 g
F P
s
P
p
.002 w
.61788 .5838 m .63505 .55777 L .65611 .54253 L p
1 g
F P
s
P
p
.002 w
.64807 .32963 m .68332 .36962 L .68314 .39425 L p
1 g
F P
s
P
p
.002 w
.68332 .36962 m .64807 .32963 L .64355 .30752 L p
1 g
F P
s
P
p
.002 w
.67759 .42066 m .69045 .46246 L .67882 .48607 L p
1 g
F P
s
P
p
.002 w
.69045 .46246 m .67759 .42066 L .68314 .39425 L p
1 g
F P
s
P
p
.002 w
.41548 .58473 m .43111 .60286 L .40817 .60008 L p
1 g
F P
s
P
p
.002 w
.40817 .60008 m .38782 .57692 L .41548 .58473 L p
1 g
F P
s
P
p
.002 w
.58389 .26192 m .52083 .24945 L .51714 .23875 L p
1 g
F P
s
P
p
.002 w
.45553 .24336 m .51714 .23875 L .52083 .24945 L p
1 g
F P
s
P
p
.002 w
.52083 .24945 m .45425 .25445 L .45553 .24336 L p
1 g
F P
s
P
p
.002 w
.34472 .37848 m .31508 .4223 L .3106 .39795 L p
1 g
F P
s
P
p
.002 w
.3106 .39795 m .3405 .35291 L .34472 .37848 L p
1 g
F P
s
P
p
.002 w
.66166 .5087 m .65611 .54253 L .63505 .55777 L p
1 g
F P
s
P
p
.002 w
.65611 .54253 m .66166 .5087 L .67882 .48607 L p
1 g
F P
s
P
p
.002 w
.34064 .47303 m .33333 .51265 L .31768 .49106 L p
1 g
F P
s
P
p
.002 w
.31768 .49106 m .32513 .4476 L .34064 .47303 L p
1 g
F P
s
P
p
.002 w
.53697 .61166 m .55627 .60344 L .57458 .60685 L p
1 g
F P
s
P
p
.002 w
.59628 .59003 m .57458 .60685 L .55627 .60344 L p
1 g
F P
s
P
p
.002 w
.38003 .54955 m .38782 .57692 L .36409 .56512 L p
1 g
F P
s
P
p
.002 w
.36409 .56512 m .35429 .53239 L .38003 .54955 L p
1 g
F P
s
P
p
.002 w
.4568 .60064 m .47302 .60991 L .45475 .61617 L p
1 g
F P
s
P
p
.002 w
.45475 .61617 m .43111 .60286 L .4568 .60064 L p
1 g
F P
s
P
p
.002 w
.59007 .27884 m .64355 .30752 L .64807 .32963 L p
1 g
F P
s
P
p
.002 w
.64355 .30752 m .59007 .27884 L .58389 .26192 L p
1 g
F P
s
P
p
.002 w
.52083 .24945 m .58389 .26192 L .59007 .27884 L p
1 g
F P
s
P
p
.002 w
.39076 .31624 m .3405 .35291 L .34102 .33037 L p
1 g
F P
s
P
p
.002 w
.34102 .33037 m .39045 .29387 L .39076 .31624 L p
1 g
F P
s
P
p
.002 w
.45428 .27122 m .39045 .29387 L .39332 .27623 L p
1 g
F P
s
P
p
.002 w
.39332 .27623 m .45425 .25445 L .45428 .27122 L p
1 g
F P
s
P
p
.002 w
.66662 .44805 m .67882 .48607 L .66166 .5087 L p
1 g
F P
s
P
p
.002 w
.67882 .48607 m .66662 .44805 L .67759 .42066 L p
1 g
F P
s
P
p
.002 w
.64834 .35544 m .68314 .39425 L .67759 .42066 L p
1 g
F P
s
P
p
.002 w
.68314 .39425 m .64834 .35544 L .64807 .32963 L p
1 g
F P
s
P
p
.002 w
.55627 .60344 m .57116 .59176 L .59628 .59003 L p
1 g
F P
s
P
p
.002 w
.60945 .56969 m .59628 .59003 L .57116 .59176 L p
1 g
F P
s
P
p
.002 w
.59628 .59003 m .60945 .56969 L .63505 .55777 L p
1 g
F P
s
P
p
.002 w
.36126 .49771 m .35429 .53239 L .33333 .51265 L p
1 g
F P
s
P
p
.002 w
.33333 .51265 m .34064 .47303 L .36126 .49771 L p
1 g
F P
s
P
p
.002 w
.50309 .6008 m .51448 .60112 L .51522 .61566 L p
1 g
F P
s
P
p
.002 w
.51522 .61566 m .49318 .61506 L .50309 .6008 L p
1 g
F P
s
P
p
.002 w
.53697 .61166 m .51522 .61566 L .51448 .60112 L p
1 g
F P
s
P
p
.002 w
.44627 .58813 m .4568 .60064 L .43111 .60286 L p
1 g
F P
s
P
p
.002 w
.43111 .60286 m .41548 .58473 L .44627 .58813 L p
1 g
F P
s
P
p
.002 w
.63931 .52953 m .63505 .55777 L .60945 .56969 L p
1 g
F P
s
P
p
.002 w
.63505 .55777 m .63931 .52953 L .66166 .5087 L p
1 g
F P
s
P
p
.002 w
.35373 .40633 m .32513 .4476 L .31508 .4223 L p
1 g
F P
s
P
p
.002 w
.31508 .4223 m .34472 .37848 L .35373 .40633 L p
1 g
F P
s
P
p
.002 w
.51448 .60112 m .52571 .59904 L .53697 .61166 L p
1 g
F P
s
P
p
.002 w
.55627 .60344 m .53697 .61166 L .52571 .59904 L p
1 g
F P
s
P
p
.002 w
.49273 .59811 m .50309 .6008 L .49318 .61506 L p
1 g
F P
s
P
p
.002 w
.49318 .61506 m .47302 .60991 L .49273 .59811 L p
1 g
F P
s
P
p
.002 w
.40983 .56348 m .41548 .58473 L .38782 .57692 L p
1 g
F P
s
P
p
.002 w
.38782 .57692 m .38003 .54955 L .40983 .56348 L p
1 g
F P
s
P
p
.002 w
.59007 .27884 m .52405 .26597 L .52083 .24945 L p
1 g
F P
s
P
p
.002 w
.45425 .25445 m .52083 .24945 L .52405 .26597 L p
1 g
F P
s
P
p
.002 w
.52405 .26597 m .45428 .27122 L .45425 .25445 L p
1 g
F P
s
P
p
.002 w
.52571 .59904 m .53564 .59477 L .55627 .60344 L p
1 g
F P
s
P
p
.002 w
.57116 .59176 m .55627 .60344 L .53564 .59477 L p
1 g
F P
s
P
p
.002 w
.48448 .5933 m .49273 .59811 L .47302 .60991 L p
1 g
F P
s
P
p
.002 w
.47302 .60991 m .4568 .60064 L .48448 .5933 L p
1 g
F P
s
P
p
.002 w
.65042 .4755 m .66166 .5087 L .63931 .52953 L p
1 g
F P
s
P
p
.002 w
.66166 .5087 m .65042 .4755 L .66662 .44805 L p
1 g
F P
s
P
p
.002 w
.59378 .30092 m .64807 .32963 L .64834 .35544 L p
1 g
F P
s
P
p
.002 w
.64807 .32963 m .59378 .30092 L .59007 .27884 L p
1 g
F P
s
P
p
.002 w
.64415 .38422 m .67759 .42066 L .66662 .44805 L p
1 g
F P
s
P
p
.002 w
.67759 .42066 m .64415 .38422 L .64834 .35544 L p
1 g
F P
s
P
p
.002 w
.3864 .52076 m .38003 .54955 L .35429 .53239 L p
1 g
F P
s
P
p
.002 w
.35429 .53239 m .36126 .49771 L .3864 .52076 L p
1 g
F P
s
P
p
.002 w
.3944 .34279 m .34472 .37848 L .3405 .35291 L p
1 g
F P
s
P
p
.002 w
.3405 .35291 m .39076 .31624 L .3944 .34279 L p
1 g
F P
s
P
p
.002 w
.57116 .59176 m .58 .57775 L .60945 .56969 L p
1 g
F P
s
P
p
.002 w
.61237 .54781 m .60945 .56969 L .58 .57775 L p
1 g
F P
s
P
p
.002 w
.60945 .56969 m .61237 .54781 L .63931 .52953 L p
1 g
F P
s
P
p
.002 w
.52405 .26597 m .59007 .27884 L .59378 .30092 L p
1 g
F P
s
P
p
.002 w
.53564 .59477 m .5432 .58874 L .57116 .59176 L p
1 g
F P
s
P
p
.002 w
.58 .57775 m .57116 .59176 L .5432 .58874 L p
1 g
F P
s
P
p
.002 w
.44273 .57359 m .44627 .58813 L .41548 .58473 L p
1 g
F P
s
P
p
.002 w
.41548 .58473 m .40983 .56348 L .44273 .57359 L p
1 g
F P
s
P
p
.002 w
.3674 .43553 m .34064 .47303 L .32513 .4476 L p
1 g
F P
s
P
p
.002 w
.32513 .4476 m .35373 .40633 L .3674 .43553 L p
1 g
F P
s
P
p
.002 w
.47924 .58687 m .48448 .5933 L .4568 .60064 L p
1 g
F P
s
P
p
.002 w
.4568 .60064 m .44627 .58813 L .47924 .58687 L p
1 g
F P
s
P
p
.002 w
.4557 .29342 m .39076 .31624 L .39045 .29387 L p
1 g
F P
s
P
p
.002 w
.39045 .29387 m .45428 .27122 L .4557 .29342 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51038 .54813 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.51448 .60112 m .50309 .6008 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.52571 .59904 m .51448 .60112 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.62941 .50204 m .63931 .52953 L .61237 .54781 L p
1 g
F P
s
P
p
.002 w
.63931 .52953 m .62941 .50204 L .65042 .4755 L p
1 g
F P
s
P
p
.002 w
.53564 .59477 m .52571 .59904 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.50309 .6008 m .49273 .59811 L .51298 .58113 L p
1 g
F P
s
P
p
.002 w
.49273 .59811 m .48448 .5933 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.51327 .58089 m .48448 .5933 L .47942 .58709 L p
1 g
F P
s
P
p
.002 w
.47942 .58709 m .47924 .58687 L .49794 .58358 L p
1 g
F P
s
P
p
.002 w
.49794 .58358 m .51327 .58089 L p
.47942 .58709 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .5811 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .5811 L .511 .5811 L 1 g
F
P
p
.002 w
.51232 .58085 m .51327 .58089 L .51194 .58112 L p
1 g
F P
s
P
p
.002 w
.51194 .58112 m .49794 .58358 L p
.51097 .5811 L 1 g
F P
s
P
p
.51097 .5811 m .51232 .58085 L .51194 .58112 L 1 g
F
P
p
.002 w
.51097 .5811 m .51079 .57862 L p
.49934 .58091 L 1 g
F P
s
P
p
.002 w
.54826 .574 m .51327 .58089 L .51528 .58 L p
1 g
F P
s
P
p
.002 w
.54641 .5698 m .54826 .574 L p
.52593 .57806 L 1 g
F P
s
P
p
.53171 .57462 m .52593 .57806 L .51528 .58 L 1 g
F
P
p
.54641 .5698 m .52593 .57806 L .53171 .57462 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57462 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57462 L .5393 .57009 L 1 g
F
P
p
.53128 .57265 m .511 .5811 L .51232 .58085 L 1 g
F
P
p
.002 w
.51279 .58076 m .51327 .58089 L .51232 .58085 L p
1 g
F P
s
P
p
.51263 .58079 m .51232 .58085 L .51262 .58079 L 1 g
F
P
p
.53128 .57265 m .51232 .58085 L .51263 .58079 L 1 g
F
P
p
.53128 .57265 m .51262 .58079 L .5128 .58075 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47762 .57947 m .47799 .57822 L p
.48453 .57972 L 1 g
F P
s
P
p
.44273 .57359 m .46296 .57267 L .47103 .57641 L 1 g
F
P
p
.002 w
.47509 .57905 m .44273 .57359 L p
.47103 .57641 L 1 g
F P
s
P
p
.002 w
.46829 .57464 m .46872 .57265 L p
.4596 .56901 L 1 g
F P
s
P
p
.48921 .57862 m .47618 .57755 L .48465 .57975 L 1 g
F
P
p
.47618 .57755 m .47799 .57822 L .48465 .57975 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47762 .57947 m .47509 .57905 L p
.47103 .57641 L 1 g
F P
s
P
p
.002 w
.47799 .57822 m .47762 .57947 L p
.46296 .57267 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.47985 .5719 m .47799 .57822 L p
.46829 .57464 L 1 g
F P
s
P
p
.46296 .57267 m .4651 .57257 L .46829 .57464 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45073 .56326 L p
1 g
F P
s
P
p
.46872 .57265 m .45073 .56326 L .4596 .56901 L 1 g
F
P
p
.4651 .57257 m .47985 .5719 L .46829 .57464 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45073 .56326 m .45146 .56129 L p
.44362 .55448 L 1 g
F P
s
P
p
.44362 .55448 m .44474 .5561 L .45073 .56326 L 1 g
F
P
p
.41524 .5413 m .43562 .54292 L .4385 .54708 L 1 g
F
P
p
.002 w
.44625 .55827 m .44123 .55552 L p
.4385 .54708 L 1 g
F P
s
P
p
.002 w
.44123 .55552 m .41524 .5413 L p
.4385 .54708 L 1 g
F P
s
P
p
.002 w
.4385 .54708 m .43925 .54566 L p
.43588 .539 L 1 g
F P
s
P
p
.44474 .5561 m .4467 .55885 L .45073 .56326 L 1 g
F
P
p
.44277 .55374 m .44625 .55827 L .44474 .5561 L 1 g
F
P
p
.44625 .55827 m .4467 .55885 L .44474 .5561 L 1 g
F
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43254 .52868 L p
1 g
F P
s
P
p
.43925 .54566 m .43254 .52868 L .43588 .539 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.41524 .5413 m .43161 .5207 L .43275 .52173 L p
1 g
F P
s
P
p
.40702 .49381 m .43514 .4996 L .43325 .5109 L 1 g
F
P
p
.002 w
.43407 .50919 m .43485 .50826 L p
.43747 .50212 L 1 g
F P
s
P
p
.002 w
.43254 .52868 m .43346 .52734 L p
.43312 .51769 L 1 g
F P
s
P
p
.43312 .51769 m .433 .51876 L .43254 .52868 L 1 g
F
P
p
.002 w
.43288 .51988 m .43161 .5207 L p
.43514 .4996 L 1 g
F P
s
P
p
.43309 .51684 m .43275 .52173 L .43254 .52868 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43161 .5207 m .42959 .51849 L p
.43325 .5109 L 1 g
F P
s
P
p
.002 w
.42959 .51849 m .40702 .49381 L p
.43325 .5109 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43359 .50976 L p
1 g
F P
s
P
p
.002 w
.43359 .50976 m .43287 .51061 L p
.43309 .51684 L 1 g
F P
s
P
p
.43346 .52734 m .43359 .50976 L .43309 .51684 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.4574 .50419 m .47583 .53369 L p
.4328 .52105 L 1 g
F P
s
P
p
.002 w
.43161 .5207 m .43288 .51988 L p
.4328 .52105 L 1 g
F P
s
P
p
.002 w
.43288 .51988 m .4574 .50419 L p
.4328 .52105 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.4574 .50419 m .43288 .51988 L p
.43407 .50919 L 1 g
F P
s
P
p
.43514 .4996 m .43837 .50027 L .43407 .50919 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44275 .49119 L p
1 g
F P
s
P
p
.43485 .50826 m .44275 .49119 L .43747 .50212 L 1 g
F
P
p
.43837 .50027 m .4574 .50419 L .43407 .50919 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44275 .49119 m .44339 .4905 L p
.44989 .48427 L 1 g
F P
s
P
p
.45547 .47885 m .48973 .49391 L .44777 .48633 L 1 g
F
P
p
.44989 .48427 m .45199 .48226 L .44777 .48633 L 1 g
F
P
p
.44989 .48427 m .44777 .48633 L .44275 .49119 L 1 g
F
P
p
.002 w
.48973 .49391 m .4574 .50419 L .44777 .48633 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47656 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45547 .47885 m .45948 .47577 L .48973 .49391 L 1 g
F
P
p
.002 w
.45782 .47656 m .45826 .47608 L p
.46539 .47295 L 1 g
F P
s
P
p
.45948 .47577 m .47757 .46715 L .48973 .49391 L 1 g
F
P
p
.002 w
.47757 .46715 m .47786 .46667 L p
.48867 .46557 L 1 g
F P
s
P
p
.49068 .46525 m .52469 .49122 L .48363 .46637 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.4819 .45855 m .52724 .45508 L .52693 .45946 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55797 .49645 m .52469 .49122 L .52625 .46904 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54215 .47653 L p
1 g
F P
s
P
p
.52214 .46667 m .54215 .47653 L .53269 .47207 L 1 g
F
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54215 .47653 m .55797 .49645 L .52625 .46904 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.002 w
.58552 .50884 m .57295 .52422 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.56054 .49761 m .5652 .4997 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.5652 .4997 m .58552 .50884 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56665 .51798 L 1 g
F P
s
P
p
.55661 .4905 m .56595 .50921 L .5623 .50138 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56159 .54724 L p
1 g
F P
s
P
p
.002 w
.57582 .54858 m .55695 .5598 L p
.56159 .54724 L 1 g
F P
s
P
p
.002 w
.56483 .53848 m .56686 .54035 L p
.56159 .54724 L 1 g
F P
s
P
p
.002 w
.56686 .54035 m .57582 .54858 L p
.56159 .54724 L 1 g
F P
s
P
p
.002 w
.56159 .54724 m .56075 .54566 L p
.55544 .55529 L 1 g
F P
s
P
p
.56654 .52734 m .56159 .54724 L .56419 .54019 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5493 .56333 L p
1 g
F P
s
P
p
.002 w
.55695 .5598 m .54785 .56522 L p
.54819 .56477 L 1 g
F P
s
P
p
.56075 .54566 m .5493 .56333 L .55544 .55529 L 1 g
F
P
p
.002 w
.54511 .56685 m .54641 .5698 L p
.53171 .57462 L 1 g
F P
s
P
p
.002 w
.5493 .56333 m .54854 .56129 L p
.5393 .57009 L 1 g
F P
s
P
p
.5393 .57009 m .5395 .56997 L .5493 .56333 L 1 g
F
P
p
.002 w
.54372 .56746 m .54511 .56685 L p
.53171 .57462 L 1 g
F P
s
P
p
.53924 .57015 m .54496 .56672 L .5493 .56333 L 1 g
F
P
p
.53128 .57265 m .5132 .58068 L .51991 .57848 L 1 g
F
P
p
.002 w
.51315 .58112 m .50309 .6008 L p
.51298 .58113 L 1 g
F P
s
P
p
.002 w
.5432 .58874 m .53564 .59477 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.54758 .58157 m .5432 .58874 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.54826 .574 m .54758 .58157 L .51327 .58089 L closepath p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51528 .58 m .54372 .56746 L p
.53171 .57462 L 1 g
F P
s
P
p
.5393 .57009 m .53924 .57015 L .5395 .56997 L 1 g
F
P
p
.002 w
.54496 .56672 m .54511 .56685 L .54372 .56746 L p
1 g
F P
s
P
p
.53924 .57015 m .53316 .57594 L .54496 .56672 L 1 g
F
P
p
.53128 .57265 m .51279 .58076 L .51292 .58073 L 1 g
F
P
p
.53128 .57265 m .51289 .58074 L .513 .58071 L 1 g
F
P
p
.53128 .57265 m .51298 .58072 L .51308 .5807 L 1 g
F
P
p
.53128 .57265 m .51304 .58071 L .51314 .58068 L 1 g
F
P
p
.53128 .57265 m .5131 .5807 L .5132 .58067 L 1 g
F
P
p
.53128 .57265 m .51315 .58069 L .51326 .58065 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53842 .56092 m .54496 .56672 L p
.51528 .58 L 1 g
F P
s
P
p
.002 w
.54372 .56746 m .51528 .58 L p
.54496 .56672 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5675 .52874 L p
1 g
F P
s
P
p
.56595 .50921 m .57015 .51822 L .56725 .52551 L 1 g
F
P
p
.002 w
.57295 .52422 m .56672 .53185 L p
.57015 .51822 L 1 g
F P
s
P
p
.56515 .50826 m .5675 .52874 L .56665 .51798 L 1 g
F
P
p
.002 w
.5675 .52874 m .56654 .52734 L p
.56394 .54157 L 1 g
F P
s
P
p
.002 w
.57582 .54858 m .56483 .53848 L p
.58552 .50884 L 1 g
F P
s
P
p
.002 w
.56672 .53185 m .56766 .5307 L p
.56483 .53848 L 1 g
F P
s
P
p
.002 w
.56766 .5307 m .58552 .50884 L p
.56781 .5342 L 1 g
F P
s
P
p
.56781 .5342 m .56483 .53848 L .56766 .5307 L 1 g
F
P
p
.56394 .54157 m .56672 .53185 L .5675 .52874 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56672 .53185 m .56281 .53663 L p
.56725 .52551 L 1 g
F P
s
P
p
.57015 .51822 m .5675 .52874 L .56725 .52551 L 1 g
F
P
p
.5675 .52874 m .56672 .53185 L .56725 .52551 L 1 g
F
P
p
.002 w
.5675 .52874 m .56758 .52885 L p
.56665 .51798 L 1 g
F P
s
P
p
.002 w
.56758 .52885 m .56854 .53025 L p
.56728 .52208 L 1 g
F P
s
P
p
.56665 .51798 m .56758 .52885 L .56728 .52208 L 1 g
F
P
p
.56394 .54157 m .56308 .54632 L .56672 .53185 L 1 g
F
P
p
.002 w
.56483 .53848 m .56281 .53663 L .56672 .53185 L p
1 g
F P
s
P
p
.002 w
.58552 .50884 m .56054 .49761 L p
.57028 .46211 L 1 g
F P
s
P
p
.002 w
.55882 .49407 m .55918 .49308 L p
.56054 .49761 L 1 g
F P
s
P
p
.002 w
.55918 .49308 m .57028 .46211 L p
.56124 .49506 L 1 g
F P
s
P
p
.56124 .49506 m .56054 .49761 L .55918 .49308 L 1 g
F
P
p
.002 w
.54013 .45718 m .57028 .46211 L .55918 .49308 L p
1 g
F P
s
P
p
.002 w
.55918 .49308 m .55882 .49407 L p
.55749 .49143 L 1 g
F P
s
P
p
.54013 .45718 m .55918 .49308 L .55749 .49143 L 1 g
F
P
p
.002 w
.55834 .49233 m .55761 .49156 L p
.56147 .49928 L 1 g
F P
s
P
p
.002 w
.54215 .47653 m .54174 .47608 L p
.54833 .48254 L 1 g
F P
s
P
p
.002 w
.55761 .49156 m .55661 .4905 L p
.56321 .50313 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55749 .49143 L p
1 g
F P
s
P
p
.54174 .47608 m .55749 .49143 L .54833 .48254 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52724 .45508 m .54013 .45718 L p
.55426 .4883 L 1 g
F P
s
P
p
.54581 .48009 m .55426 .4883 L .55797 .49645 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.52724 .45508 m .55426 .4883 L .54581 .48009 L 1 g
F
P
p
.002 w
.55882 .49407 m .55797 .49645 L p
.54013 .45718 L 1 g
F P
s
P
p
.56321 .50313 m .56713 .51061 L .55761 .49156 L 1 g
F
P
p
.54581 .48009 m .55797 .49645 L .54215 .47653 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54215 .47653 L p
1 g
F P
s
P
p
.54833 .48254 m .55834 .49233 L .54215 .47653 L 1 g
F
P
p
.002 w
.56713 .51061 m .5656 .50745 L p
.56147 .49928 L 1 g
F P
s
P
p
.002 w
.5656 .50745 m .55834 .49233 L p
.56147 .49928 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56007 .49417 L p
.5434 .47785 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .54411 .47854 L p
.5434 .47785 L 1 g
F P
s
P
p
.002 w
.54411 .47854 m .55834 .49233 L p
.5434 .47785 L 1 g
F P
s
P
p
.002 w
.56054 .49761 m .55797 .49645 L .55882 .49407 L p
1 g
F P
s
P
p
.56054 .49761 m .56595 .50921 L .56281 .53663 L 1 g
F
P
p
.56595 .50921 m .56725 .52551 L .56281 .53663 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5675 .52874 L p
1 g
F P
s
P
p
.56308 .54632 m .56257 .5491 L .5675 .52874 L 1 g
F
P
p
.56483 .53848 m .55823 .55634 L .54549 .5663 L 1 g
F
P
p
.55823 .55634 m .55695 .5598 L .54549 .5663 L 1 g
F
P
p
.002 w
.54826 .574 m .54562 .56799 L p
.57582 .54858 L 1 g
F P
s
P
p
.002 w
.54562 .56799 m .54511 .56685 L .54785 .56522 L p
1 g
F P
s
P
p
.002 w
.54785 .56522 m .57582 .54858 L p
.54562 .56799 L 1 g
F P
s
P
p
.002 w
.5493 .56333 m .54932 .56339 L p
.55544 .55529 L 1 g
F P
s
P
p
.002 w
.54932 .56339 m .54998 .56518 L p
.55453 .55693 L 1 g
F P
s
P
p
.55544 .55529 m .54932 .56339 L .55453 .55693 L 1 g
F
P
p
.54549 .5663 m .54819 .56477 L .54511 .56685 L 1 g
F
P
p
.002 w
.54785 .56522 m .54511 .56685 L p
.54819 .56477 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56281 .53663 m .56483 .53848 L p
.54511 .56685 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54511 .56685 m .53842 .56092 L .56281 .53663 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5493 .56333 L p
1 g
F P
s
P
p
.53316 .57594 m .5322 .57686 L .5493 .56333 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56159 .54724 L p
1 g
F P
s
P
p
.55544 .55529 m .54998 .56518 L .56159 .54724 L 1 g
F
P
p
.002 w
.56159 .54724 m .56257 .5491 L p
.56419 .54019 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56665 .51798 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.5623 .50138 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55797 .49645 m .56054 .49761 L p
.56281 .53663 L 1 g
F P
s
P
p
.54372 .47726 m .54581 .48009 L .54215 .47653 L 1 g
F
P
p
.002 w
.55749 .49143 m .55834 .49233 L p
.54833 .48254 L 1 g
F P
s
P
p
.52214 .46667 m .54282 .47726 L .53758 .47466 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52625 .46904 m .52469 .49122 L p
.51352 .4658 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46715 L p
1 g
F P
s
P
p
.5 .4634 m .52243 .46715 L .50871 .46508 L 1 g
F
P
p
.5118 .46188 m .52243 .46715 L .51352 .4658 L 1 g
F
P
p
.52243 .46715 m .52625 .46904 L .51352 .4658 L 1 g
F
P
p
.49068 .46525 m .5 .46376 L .52469 .49122 L 1 g
F
P
p
.002 w
.5 .46376 m .5 .4634 L p
.50871 .46508 L 1 g
F P
s
P
p
.5 .46376 m .5118 .46188 L .51352 .4658 L 1 g
F
P
p
.5 .46376 m .51352 .4658 L .52469 .49122 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46376 L p
1 g
F P
s
P
p
.50871 .46508 m .52282 .46778 L .5 .46376 L 1 g
F
P
p
.002 w
.52243 .46715 m .52282 .46778 L p
.50871 .46508 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52625 .46904 m .52724 .45508 L p
.54372 .47726 L 1 g
F P
s
P
p
.002 w
.54215 .47653 m .54282 .47726 L p
.53269 .47207 L 1 g
F P
s
P
p
.002 w
.54282 .47726 m .54302 .47747 L p
.53758 .47466 L 1 g
F P
s
P
p
.002 w
.52693 .45946 m .52625 .46904 L p
.5118 .46188 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46428 L p
1 g
F P
s
P
p
.002 w
.5 .46428 m .5 .46442 L p
.49482 .46494 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46428 L .49482 .46494 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47757 .46715 L p
1 g
F P
s
P
p
.002 w
.47757 .46715 m .47718 .46778 L p
.46539 .47295 L 1 g
F P
s
P
p
.45826 .47608 m .47757 .46715 L .46539 .47295 L 1 g
F
P
p
.002 w
.4819 .45855 m .48321 .46446 L p
.47757 .46715 L 1 g
F P
s
P
p
.45948 .47577 m .46933 .4682 L .47757 .46715 L 1 g
F
P
p
.46933 .4682 m .4819 .45855 L .47757 .46715 L 1 g
F
P
p
.4819 .45855 m .52693 .45946 L .49068 .46525 L 1 g
F
P
p
.002 w
.52469 .49122 m .48973 .49391 L .48363 .46637 L p
1 g
F P
s
P
p
.002 w
.48363 .46637 m .48973 .49391 L p
.47757 .46715 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47744 .46736 L p
1 g
F P
s
P
p
.002 w
.47744 .46736 m .47757 .46715 L p
.48267 .46653 L 1 g
F P
s
P
p
.48267 .46653 m .5 .46442 L .47744 .46736 L 1 g
F
P
p
.48867 .46557 m .49482 .46494 L .48363 .46637 L 1 g
F
P
p
.48867 .46557 m .48363 .46637 L .47757 .46715 L 1 g
F
P
p
.002 w
.48363 .46637 m .4819 .45855 L p
.49068 .46525 L 1 g
F P
s
P
p
.002 w
.48321 .46446 m .48363 .46637 L p
.47757 .46715 L 1 g
F P
s
P
p
.49482 .46494 m .5 .46442 L .47757 .46715 L 1 g
F
P
p
.002 w
.47356 .46125 m .4819 .45855 L p
.45547 .47885 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45782 .47656 L p
1 g
F P
s
P
p
.46539 .47295 m .47718 .46778 L .45782 .47656 L 1 g
F
P
p
.002 w
.45782 .47656 m .45698 .47747 L p
.44989 .48427 L 1 g
F P
s
P
p
.44339 .4905 m .45782 .47656 L .44989 .48427 L 1 g
F
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.4401 .47209 m .47356 .46125 L p
.45547 .47885 L 1 g
F P
s
P
p
.002 w
.44777 .48633 m .4401 .47209 L p
.45547 .47885 L 1 g
F P
s
P
p
.002 w
.40702 .49381 m .4401 .47209 L .44777 .48633 L p
1 g
F P
s
P
p
.002 w
.44777 .48633 m .4574 .50419 L p
.43422 .49941 L 1 g
F P
s
P
p
.40702 .49381 m .44777 .48633 L .43422 .49941 L 1 g
F
P
p
.002 w
.44275 .49119 m .44166 .49233 L p
.43747 .50212 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44275 .49119 L p
1 g
F P
s
P
p
.45199 .48226 m .45698 .47747 L .44275 .49119 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43407 .50919 L p
1 g
F P
s
P
p
.43747 .50212 m .44166 .49233 L .43407 .50919 L 1 g
F
P
p
.43312 .51769 m .43309 .51684 L .433 .51876 L 1 g
F
P
p
.002 w
.43275 .52173 m .43161 .5207 L p
.4328 .52105 L 1 g
F P
s
P
p
.43309 .51684 m .43299 .51377 L .43275 .52173 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.47583 .53369 m .45818 .54471 L .43275 .52173 L p
1 g
F P
s
P
p
.4328 .52105 m .47583 .53369 L .43275 .52173 L 1 g
F
P
p
.002 w
.43275 .52173 m .45818 .54471 L p
.43213 .54264 L 1 g
F P
s
P
p
.41524 .5413 m .43275 .52173 L .43213 .54264 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43254 .52868 L p
1 g
F P
s
P
p
.43299 .51377 m .43287 .51061 L .43254 .52868 L 1 g
F
P
p
.002 w
.43254 .52868 m .43146 .53025 L p
.43588 .539 L 1 g
F P
s
P
p
.4385 .54708 m .45818 .54471 L .44625 .55827 L 1 g
F
P
p
.43562 .54292 m .43719 .54304 L .4385 .54708 L 1 g
F
P
p
.43719 .54304 m .45818 .54471 L .4385 .54708 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4385 .54708 L p
1 g
F P
s
P
p
.43588 .539 m .43146 .53025 L .4385 .54708 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45818 .54471 m .44678 .55856 L .44625 .55827 L p
1 g
F P
s
P
p
.44362 .55448 m .44277 .55374 L .44474 .5561 L 1 g
F
P
p
.002 w
.44273 .57359 m .40983 .56348 L p
.4465 .55859 L 1 g
F P
s
P
p
.002 w
.4467 .55885 m .44273 .57359 L p
.4465 .55859 L 1 g
F P
s
P
p
.002 w
.40983 .56348 m .41524 .5413 L .44625 .55827 L p
1 g
F P
s
P
p
.002 w
.44625 .55827 m .44678 .55856 L p
.4465 .55859 L 1 g
F P
s
P
p
.40983 .56348 m .44625 .55827 L .4465 .55859 L 1 g
F
P
p
.002 w
.44273 .57359 m .4467 .55885 L p
.45949 .57283 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45052 .56383 L p
1 g
F P
s
P
p
.002 w
.45052 .56383 m .45073 .56326 L p
.44716 .55945 L 1 g
F P
s
P
p
.44716 .55945 m .43743 .5491 L .45052 .56383 L 1 g
F
P
p
.44277 .55374 m .43906 .55051 L .4467 .55885 L 1 g
F
P
p
.002 w
.44678 .55856 m .4467 .55885 L p
.4465 .55859 L 1 g
F P
s
P
p
.002 w
.44678 .55856 m .47985 .5719 L p
.45949 .57283 L 1 g
F P
s
P
p
.002 w
.4467 .55885 m .44678 .55856 L p
.45949 .57283 L 1 g
F P
s
P
p
.43906 .55051 m .43743 .5491 L .45073 .56326 L 1 g
F
P
p
.002 w
.45073 .56326 m .45002 .56518 L p
.4596 .56901 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57464 L p
1 g
F P
s
P
p
.4596 .56901 m .45002 .56518 L .46829 .57464 L 1 g
F
P
p
.47618 .57755 m .47447 .57741 L .47799 .57822 L 1 g
F
P
p
.47924 .58687 m .48396 .58065 L .49976 .58313 L 1 g
F
P
p
.48396 .58065 m .48465 .57975 L .48905 .58074 L 1 g
F
P
p
.48396 .58065 m .48905 .58074 L .49976 .58313 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58074 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58074 L .49934 .58091 L 1 g
F
P
p
.002 w
.48905 .58074 m .48921 .57862 L p
.48465 .57975 L 1 g
F P
s
P
p
.002 w
.48465 .57975 m .51232 .58085 L p
.49976 .58313 L 1 g
F P
s
P
p
.002 w
.48905 .58074 m .48889 .583 L p
.49934 .58091 L 1 g
F P
s
P
p
.002 w
.48905 .58076 m .48905 .58074 L p
.48465 .57975 L 1 g
F P
s
P
p
.002 w
.47924 .58687 m .47762 .57947 L .48465 .57975 L p
1 g
F P
s
P
p
.002 w
.51232 .58085 m .47762 .57947 L p
.51279 .58076 L 1 g
F P
s
P
p
.002 w
.47762 .57947 m .47924 .58687 L .44627 .58813 L p
1 g
F P
s
P
p
.002 w
.44627 .58813 m .44273 .57359 L .47762 .57947 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58076 L p
1 g
F P
s
P
p
.47447 .57741 m .4678 .57686 L .48905 .58076 L 1 g
F
P
p
.002 w
.47985 .5719 m .51279 .58076 L p
.48453 .57972 L 1 g
F P
s
P
p
.002 w
.47799 .57822 m .47985 .5719 L p
.48453 .57972 L 1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.47985 .5719 m .48575 .565 L .51297 .58072 L p
1 g
F P
s
P
p
.002 w
.51297 .58072 m .51327 .58089 L .51279 .58076 L p
1 g
F P
s
P
p
.002 w
.51279 .58076 m .47985 .5719 L p
.51297 .58072 L 1 g
F P
s
P
p
.5128 .58075 m .51262 .58079 L .51279 .58076 L 1 g
F
P
p
.51292 .58073 m .51279 .58076 L .51289 .58074 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48575 .565 m .49469 .55953 L .5131 .58069 L p
1 g
F P
s
P
p
.002 w
.5131 .58069 m .51327 .58089 L .51297 .58072 L p
1 g
F P
s
P
p
.002 w
.51297 .58072 m .48575 .565 L p
.5131 .58069 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.49469 .55953 m .50571 .55615 L .5132 .58066 L p
1 g
F P
s
P
p
.002 w
.5132 .58066 m .51327 .58089 L .5131 .58069 L p
1 g
F P
s
P
p
.002 w
.5131 .58069 m .49469 .55953 L p
.5132 .58066 L 1 g
F P
s
P
p
.513 .58071 m .51289 .58074 L .51298 .58072 L 1 g
F
P
p
.51308 .5807 m .51298 .58072 L .51304 .58071 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.50571 .55615 m .51756 .55523 L .51331 .58063 L p
1 g
F P
s
P
p
.002 w
.51331 .58063 m .51327 .58089 L .5132 .58066 L p
1 g
F P
s
P
p
.002 w
.5132 .58066 m .50571 .55615 L p
.51331 .58063 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.51756 .55523 m .52889 .55689 L .51347 .58058 L p
1 g
F P
s
P
p
.002 w
.51347 .58058 m .51327 .58089 L .51331 .58063 L p
1 g
F P
s
P
p
.002 w
.51331 .58063 m .51756 .55523 L p
.51347 .58058 L 1 g
F P
s
P
p
.51314 .58068 m .51304 .58071 L .5131 .5807 L 1 g
F
P
p
.5132 .58067 m .5131 .5807 L .51315 .58069 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52889 .55689 m .53842 .56092 L .51377 .58049 L p
1 g
F P
s
P
p
.002 w
.51377 .58049 m .51327 .58089 L .51347 .58058 L p
1 g
F P
s
P
p
.002 w
.51347 .58058 m .52889 .55689 L p
.51377 .58049 L 1 g
F P
s
P
p
.002 w
.51528 .58 m .51327 .58089 L .51377 .58049 L p
1 g
F P
s
P
p
.002 w
.51377 .58049 m .53842 .56092 L p
.51528 .58 L 1 g
F P
s
P
p
.51326 .58065 m .51315 .58069 L .5132 .58068 L 1 g
F
P
p
.51991 .57848 m .5132 .58068 L .51706 .57995 L 1 g
F
P
p
.002 w
.53171 .57462 m .5322 .57686 L p
.5393 .57009 L 1 g
F P
s
P
p
.51706 .57995 m .51317 .58069 L .51703 .57996 L 1 g
F
P
p
.51317 .58069 m .51097 .58111 L .51315 .5807 L 1 g
F
P
p
.51317 .58069 m .51315 .5807 L .51703 .57996 L 1 g
F
P
p
.511 .5811 m .51097 .58111 L .51706 .57995 L 1 g
F
P
p
.002 w
.49794 .58358 m .47924 .58687 L p
.51232 .58085 L 1 g
F P
s
P
p
.002 w
.51098 .58117 m .51097 .5811 L p
.49667 .58144 L 1 g
F P
s
P
p
.49934 .58091 m .49667 .58144 L .51097 .5811 L 1 g
F
P
p
.002 w
.51097 .5811 m .51097 .58111 L p
.511 .5811 L 1 g
F P
s
P
p
.002 w
.51298 .58113 m .51327 .58089 L .51315 .58112 L p
1 g
F P
s
P
p
.002 w
.51097 .58111 m .51111 .583 L p
.51703 .57996 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58117 L p
1 g
F P
s
P
p
.49667 .58144 m .48889 .583 L .51098 .58117 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.41524 .5413 m .40983 .56348 L .38003 .54955 L p
1 g
F P
s
P
p
.002 w
.38003 .54955 m .3864 .52076 L .41524 .5413 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.5432 .58874 m .54758 .58157 L .58 .57775 L p
1 g
F P
s
P
p
.002 w
.58169 .56282 m .58 .57775 L .54758 .58157 L p
1 g
F P
s
P
p
.002 w
.58 .57775 m .58169 .56282 L .61237 .54781 L p
1 g
F P
s
P
p
.002 w
.63549 .41506 m .66662 .44805 L .65042 .4755 L p
1 g
F P
s
P
p
.002 w
.66662 .44805 m .63549 .41506 L .64415 .38422 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.59378 .30092 m .52667 .28808 L .52405 .26597 L p
1 g
F P
s
P
p
.002 w
.45428 .27122 m .52405 .26597 L .52667 .28808 L p
1 g
F P
s
P
p
.002 w
.59476 .32763 m .64834 .35544 L .64415 .38422 L p
1 g
F P
s
P
p
.002 w
.64834 .35544 m .59476 .32763 L .59378 .30092 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.52667 .28808 m .4557 .29342 L .45428 .27122 L p
1 g
F P
s
P
p
.002 w
.38536 .46506 m .36126 .49771 L .34064 .47303 L p
1 g
F P
s
P
p
.002 w
.34064 .47303 m .3674 .43553 L .38536 .46506 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.40138 .37274 m .35373 .40633 L .34472 .37848 L p
1 g
F P
s
P
p
.002 w
.34472 .37848 m .3944 .34279 L .40138 .37274 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.60426 .52671 m .61237 .54781 L .58169 .56282 L p
1 g
F P
s
P
p
.002 w
.61237 .54781 m .60426 .52671 L .62941 .50204 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52667 .28808 m .59378 .30092 L .59476 .32763 L p
1 g
F P
s
P
p
.002 w
.54758 .58157 m .54826 .574 L .58169 .56282 L p
1 g
F P
s
P
p
.002 w
.45852 .32055 m .3944 .34279 L .39076 .31624 L p
1 g
F P
s
P
p
.002 w
.39076 .31624 m .4557 .29342 L .45852 .32055 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.62253 .44689 m .65042 .4755 L .62941 .50204 L p
1 g
F P
s
P
p
.002 w
.65042 .4755 m .62253 .44689 L .63549 .41506 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.57582 .54858 m .58169 .56282 L .54826 .574 L p
1 g
F P
s
P
p
.002 w
.58169 .56282 m .57582 .54858 L .60426 .52671 L p
1 g
F P
s
P
p
.002 w
.40702 .49381 m .3864 .52076 L .36126 .49771 L p
1 g
F P
s
P
p
.002 w
.36126 .49771 m .38536 .46506 L .40702 .49381 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.59286 .35821 m .64415 .38422 L .63549 .41506 L p
1 g
F P
s
P
p
.002 w
.64415 .38422 m .59286 .35821 L .59476 .32763 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.41156 .40508 m .3674 .43553 L .35373 .40633 L p
1 g
F P
s
P
p
.002 w
.35373 .40633 m .40138 .37274 L .41156 .40508 L p
1 g
F P
s
P
p
.002 w
.60568 .47855 m .62941 .50204 L .60426 .52671 L p
1 g
F P
s
P
p
.002 w
.62941 .50204 m .60568 .47855 L .62253 .44689 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.43161 .5207 m .41524 .5413 L .3864 .52076 L p
1 g
F P
s
P
p
.002 w
.3864 .52076 m .40702 .49381 L .43161 .5207 L p
1 g
F P
s
P
p
.002 w
.59476 .32763 m .52855 .31526 L .52667 .28808 L p
1 g
F P
s
P
p
.002 w
.4557 .29342 m .52667 .28808 L .52855 .31526 L p
1 g
F P
s
P
p
.002 w
.52855 .31526 m .45852 .32055 L .4557 .29342 L p
1 g
F P
s
P
p
.002 w
.48575 .565 m .47985 .5719 L .44678 .55856 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.58552 .50884 m .60426 .52671 L .57582 .54858 L p
1 g
F P
s
P
p
.002 w
.60426 .52671 m .58552 .50884 L .60568 .47855 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52855 .31526 m .59476 .32763 L .59286 .35821 L p
1 g
F P
s
P
p
.002 w
.44678 .55856 m .45818 .54471 L .48575 .565 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.4627 .35179 m .40138 .37274 L .3944 .34279 L p
1 g
F P
s
P
p
.002 w
.3944 .34279 m .45852 .32055 L .4627 .35179 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.58805 .39164 m .63549 .41506 L .62253 .44689 L p
1 g
F P
s
P
p
.002 w
.63549 .41506 m .58805 .39164 L .59286 .35821 L p
1 g
F P
s
P
p
.002 w
.53842 .56092 m .52889 .55689 L .54398 .52843 L p
1 g
F P
s
P
p
.002 w
.54398 .52843 m .56281 .53663 L .53842 .56092 L p
1 g
F P
s
P
p
.002 w
.49469 .55953 m .48575 .565 L .45818 .54471 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.42462 .43862 m .38536 .46506 L .3674 .43553 L p
1 g
F P
s
P
p
.002 w
.3674 .43553 m .41156 .40508 L .42462 .43862 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52889 .55689 m .51756 .55523 L .52142 .52501 L p
1 g
F P
s
P
p
.002 w
.52142 .52501 m .54398 .52843 L .52889 .55689 L p
1 g
F P
s
P
p
.002 w
.50571 .55615 m .49469 .55953 L .47583 .53369 L p
1 g
F P
s
P
p
.002 w
.45818 .54471 m .47583 .53369 L .49469 .55953 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51756 .55523 m .50571 .55615 L .49777 .52684 L p
1 g
F P
s
P
p
.002 w
.49777 .52684 m .52142 .52501 L .51756 .55523 L p
1 g
F P
s
P
p
.002 w
.47583 .53369 m .49777 .52684 L .50571 .55615 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58044 .42672 m .62253 .44689 L .60568 .47855 L p
1 g
F P
s
P
p
.002 w
.62253 .44689 m .58044 .42672 L .58805 .39164 L p
1 g
F P
s
P
p
.002 w
.56281 .53663 m .54398 .52843 L .55797 .49645 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.004 w
.5161 .61301 m
.51611 .61313 L
s
P
p
.002 w
.4401 .47209 m .40702 .49381 L .38536 .46506 L p
1 g
F P
s
P
p
.002 w
.38536 .46506 m .42462 .43862 L .4401 .47209 L p
1 g
F P
s
P
p
.002 w
.59286 .35821 m .52959 .34672 L .52855 .31526 L p
1 g
F P
s
P
p
.002 w
.45852 .32055 m .52855 .31526 L .52959 .34672 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.52959 .34672 m .59286 .35821 L .58805 .39164 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.52959 .34672 m .4627 .35179 L .45852 .32055 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57028 .46211 m .60568 .47855 L .58552 .50884 L p
1 g
F P
s
P
p
.002 w
.60568 .47855 m .57028 .46211 L .58044 .42672 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.46812 .38607 m .41156 .40508 L .40138 .37274 L p
1 g
F P
s
P
p
.002 w
.40138 .37274 m .4627 .35179 L .46812 .38607 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54398 .52843 m .52142 .52501 L .52469 .49122 L p
1 g
F P
s
P
p
.002 w
.52469 .49122 m .55797 .49645 L .54398 .52843 L p
1 g
F P
s
P
p
.002 w
.49777 .52684 m .47583 .53369 L .4574 .50419 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.52142 .52501 m .49777 .52684 L .48973 .49391 L p
1 g
F P
s
P
p
.002 w
.48973 .49391 m .52469 .49122 L .52142 .52501 L p
1 g
F P
s
P
p
.002 w
.4574 .50419 m .48973 .49391 L .49777 .52684 L p
1 g
F P
s
P
p
.002 w
.52973 .38139 m .58805 .39164 L .58044 .42672 L p
1 g
F P
s
P
p
.002 w
.58805 .39164 m .52973 .38139 L .52959 .34672 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.4746 .42213 m .42462 .43862 L .41156 .40508 L p
1 g
F P
s
P
p
.002 w
.41156 .40508 m .46812 .38607 L .4746 .42213 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.4627 .35179 m .52959 .34672 L .52973 .38139 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.52973 .38139 m .46812 .38607 L .4627 .35179 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.51777 .63189 m
.51866 .64199 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52894 .41798 m .58044 .42672 L .57028 .46211 L p
1 g
F P
s
P
p
.002 w
.58044 .42672 m .52894 .41798 L .52973 .38139 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57028 .46211 m .52724 .45508 L .52894 .41798 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.4819 .45855 m .4401 .47209 L .42462 .43862 L p
1 g
F P
s
P
p
.002 w
.42462 .43862 m .4746 .42213 L .4819 .45855 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.46812 .38607 m .52973 .38139 L .52894 .41798 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.52894 .41798 m .4746 .42213 L .46812 .38607 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.52724 .45508 m .4819 .45855 L .4746 .42213 L p
1 g
F P
s
P
p
.002 w
.4746 .42213 m .52894 .41798 L .52724 .45508 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .2963 .64984 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .52099 .66843 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.396124)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.396124)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45124 .45753 m .49744 .46937 L .50129 .44125 L p
1 g
F P
s
P
p
.002 w
.50129 .44125 m .46082 .4308 L .45124 .45753 L p
1 g
F P
s
P
p
.002 w
.54298 .44187 m .50129 .44125 L .49744 .46937 L p
1 g
F P
s
P
p
.002 w
.46082 .4308 m .50129 .44125 L .50509 .41293 L p
1 g
F P
s
P
p
.002 w
.50129 .44125 m .54298 .44187 L .5399 .41337 L p
1 g
F P
s
P
p
.002 w
.5399 .41337 m .50509 .41293 L .50129 .44125 L p
1 g
F P
s
P
p
.002 w
.50509 .41293 m .47132 .40415 L .46082 .4308 L p
1 g
F P
s
P
p
.002 w
.47132 .40415 m .50509 .41293 L .50879 .38493 L p
1 g
F P
s
P
p
.002 w
.50509 .41293 m .5399 .41337 L .53585 .3852 L p
1 g
F P
s
P
p
.002 w
.53585 .3852 m .50879 .38493 L .50509 .41293 L p
1 g
F P
s
P
p
.002 w
.44276 .48385 m .49362 .49678 L .49744 .46937 L p
1 g
F P
s
P
p
.002 w
.49744 .46937 m .45124 .45753 L .44276 .48385 L p
1 g
F P
s
P
p
.002 w
.54502 .4702 m .49744 .46937 L .49362 .49678 L p
1 g
F P
s
P
p
.002 w
.49744 .46937 m .54502 .4702 L .54298 .44187 L p
1 g
F P
s
P
p
.002 w
.42525 .41139 m .46082 .4308 L .47132 .40415 L p
1 g
F P
s
P
p
.002 w
.47132 .40415 m .44175 .38777 L .42525 .41139 L p
1 g
F P
s
P
p
.002 w
.44175 .38777 m .47132 .40415 L .48255 .37805 L p
1 g
F P
s
P
p
.002 w
.50879 .38493 m .48255 .37805 L .47132 .40415 L p
1 g
F P
s
P
p
.002 w
.41049 .43562 m .45124 .45753 L .46082 .4308 L p
1 g
F P
s
P
p
.002 w
.46082 .4308 m .42525 .41139 L .41049 .43562 L p
1 g
F P
s
P
p
.002 w
.5725 .40533 m .5399 .41337 L .54298 .44187 L p
1 g
F P
s
P
p
.002 w
.5399 .41337 m .5725 .40533 L .56111 .37879 L p
1 g
F P
s
P
p
.002 w
.56111 .37879 m .53585 .3852 L .5399 .41337 L p
1 g
F P
s
P
p
.002 w
.58213 .43251 m .54298 .44187 L .54502 .4702 L p
1 g
F P
s
P
p
.002 w
.54298 .44187 m .58213 .43251 L .5725 .40533 L p
1 g
F P
s
P
p
.002 w
.48255 .37805 m .50879 .38493 L .51231 .35775 L p
1 g
F P
s
P
p
.002 w
.50879 .38493 m .53585 .3852 L .53089 .3579 L p
1 g
F P
s
P
p
.002 w
.53089 .3579 m .51231 .35775 L .50879 .38493 L p
1 g
F P
s
P
p
.002 w
.48255 .37805 m .45967 .36519 L .44175 .38777 L p
1 g
F P
s
P
p
.002 w
.45967 .36519 m .48255 .37805 L .4943 .353 L p
1 g
F P
s
P
p
.002 w
.51231 .35775 m .4943 .353 L .48255 .37805 L p
1 g
F P
s
P
p
.002 w
.39776 .46001 m .44276 .48385 L .45124 .45753 L p
1 g
F P
s
P
p
.002 w
.45124 .45753 m .41049 .43562 L .39776 .46001 L p
1 g
F P
s
P
p
.002 w
.53585 .3852 m .56111 .37879 L .54817 .35338 L p
1 g
F P
s
P
p
.002 w
.54817 .35338 m .53089 .3579 L .53585 .3852 L p
1 g
F P
s
P
p
.002 w
.49362 .49678 m .54598 .49782 L .54502 .4702 L p
1 g
F P
s
P
p
.002 w
.5898 .45981 m .54502 .4702 L .54598 .49782 L p
1 g
F P
s
P
p
.002 w
.54502 .4702 m .5898 .45981 L .58213 .43251 L p
1 g
F P
s
P
p
.002 w
.43556 .50926 m .48991 .52298 L .49362 .49678 L p
1 g
F P
s
P
p
.002 w
.49362 .49678 m .44276 .48385 L .43556 .50926 L p
1 g
F P
s
P
p
.002 w
.54598 .49782 m .49362 .49678 L .48991 .52298 L p
1 g
F P
s
P
p
.002 w
.39802 .38459 m .42525 .41139 L .44175 .38777 L p
1 g
F P
s
P
p
.002 w
.44175 .38777 m .4193 .3652 L .39802 .38459 L p
1 g
F P
s
P
p
.002 w
.4193 .3652 m .44175 .38777 L .45967 .36519 L p
1 g
F P
s
P
p
.002 w
.4943 .353 m .51231 .35775 L .51559 .33192 L p
1 g
F P
s
P
p
.002 w
.51231 .35775 m .53089 .3579 L .52509 .33197 L p
1 g
F P
s
P
p
.002 w
.52509 .33197 m .51559 .33192 L .51231 .35775 L p
1 g
F P
s
P
p
.002 w
.59971 .3894 m .5725 .40533 L .58213 .43251 L p
1 g
F P
s
P
p
.002 w
.5725 .40533 m .59971 .3894 L .58205 .36621 L p
1 g
F P
s
P
p
.002 w
.58205 .36621 m .56111 .37879 L .5725 .40533 L p
1 g
F P
s
P
p
.002 w
.45967 .36519 m .44246 .34751 L .4193 .3652 L p
1 g
F P
s
P
p
.002 w
.44246 .34751 m .45967 .36519 L .47867 .34408 L p
1 g
F P
s
P
p
.002 w
.4943 .353 m .47867 .34408 L .45967 .36519 L p
1 g
F P
s
P
p
.002 w
.37905 .40533 m .41049 .43562 L .42525 .41139 L p
1 g
F P
s
P
p
.002 w
.42525 .41139 m .39802 .38459 L .37905 .40533 L p
1 g
F P
s
P
p
.002 w
.47867 .34408 m .4943 .353 L .50638 .32947 L p
1 g
F P
s
P
p
.002 w
.51559 .33192 m .50638 .32947 L .4943 .353 L p
1 g
F P
s
P
p
.002 w
.38736 .48409 m .43556 .50926 L .44276 .48385 L p
1 g
F P
s
P
p
.002 w
.44276 .48385 m .39776 .46001 L .38736 .48409 L p
1 g
F P
s
P
p
.002 w
.53089 .3579 m .54817 .35338 L .5339 .32961 L p
1 g
F P
s
P
p
.002 w
.5339 .32961 m .52509 .33197 L .53089 .3579 L p
1 g
F P
s
P
p
.002 w
.56111 .37879 m .58205 .36621 L .56238 .34462 L p
1 g
F P
s
P
p
.002 w
.56238 .34462 m .54817 .35338 L .56111 .37879 L p
1 g
F P
s
P
p
.002 w
.48991 .52298 m .54582 .52422 L .54598 .49782 L p
1 g
F P
s
P
p
.002 w
.59534 .48672 m .54598 .49782 L .54582 .52422 L p
1 g
F P
s
P
p
.002 w
.54598 .49782 m .59534 .48672 L .5898 .45981 L p
1 g
F P
s
P
p
.002 w
.615 .41375 m .58213 .43251 L .5898 .45981 L p
1 g
F P
s
P
p
.002 w
.58213 .43251 m .615 .41375 L .59971 .3894 L p
1 g
F P
s
P
p
.002 w
.47867 .34408 m .46704 .33187 L .44246 .34751 L p
1 g
F P
s
P
p
.002 w
.46704 .33187 m .47867 .34408 L .49842 .32487 L p
1 g
F P
s
P
p
.002 w
.50638 .32947 m .49842 .32487 L .47867 .34408 L p
1 g
F P
s
P
p
.002 w
.36284 .42702 m .39776 .46001 L .41049 .43562 L p
1 g
F P
s
P
p
.002 w
.41049 .43562 m .37905 .40533 L .36284 .42702 L p
1 g
F P
s
P
p
.002 w
.54817 .35338 m .56238 .34462 L .54108 .32507 L p
1 g
F P
s
P
p
.002 w
.54108 .32507 m .5339 .32961 L .54817 .35338 L p
1 g
F P
s
P
p
.002 w
.42981 .53325 m .48636 .54743 L .48991 .52298 L p
1 g
F P
s
P
p
.002 w
.48991 .52298 m .43556 .50926 L .42981 .53325 L p
1 g
F P
s
P
p
.002 w
.54582 .52422 m .48991 .52298 L .48636 .54743 L p
1 g
F P
s
P
p
.002 w
.62759 .43879 m .5898 .45981 L .59534 .48672 L p
1 g
F P
s
P
p
.002 w
.5898 .45981 m .62759 .43879 L .615 .41375 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .50638 .32947 L .51559 .33192 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .51559 .33192 L .52509 .33197 L closepath p
1 g
F P
s
P
p
.002 w
.40645 .33846 m .4193 .3652 L .44246 .34751 L p
1 g
F P
s
P
p
.002 w
.44246 .34751 m .43282 .32668 L .40645 .33846 L p
1 g
F P
s
P
p
.002 w
.43282 .32668 m .44246 .34751 L .46704 .33187 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .49842 .32487 L .50638 .32947 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .52509 .33197 L .5339 .32961 L closepath p
1 g
F P
s
P
p
.002 w
.37957 .50735 m .42981 .53325 L .43556 .50926 L p
1 g
F P
s
P
p
.002 w
.43556 .50926 m .38736 .48409 L .37957 .50735 L p
1 g
F P
s
P
p
.002 w
.38213 .35269 m .39802 .38459 L .4193 .3652 L p
1 g
F P
s
P
p
.002 w
.4193 .3652 m .40645 .33846 L .38213 .35269 L p
1 g
F P
s
P
p
.002 w
.46704 .33187 m .46068 .31757 L .43282 .32668 L p
1 g
F P
s
P
p
.002 w
.49842 .32487 m .49257 .31859 L .46704 .33187 L p
1 g
F P
s
P
p
.002 w
.46068 .31757 m .46704 .33187 L .49257 .31859 L p
1 g
F P
s
P
p
.002 w
.5964 .34855 m .58205 .36621 L .59971 .3894 L p
1 g
F P
s
P
p
.002 w
.58205 .36621 m .5964 .34855 L .57198 .33244 L p
1 g
F P
s
P
p
.002 w
.57198 .33244 m .56238 .34462 L .58205 .36621 L p
1 g
F P
s
P
p
.002 w
.48636 .54743 m .54452 .54885 L .54582 .52422 L p
1 g
F P
s
P
p
.002 w
.5986 .5127 m .54582 .52422 L .54452 .54885 L p
1 g
F P
s
P
p
.002 w
.54582 .52422 m .5986 .5127 L .59534 .48672 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .49257 .31859 L .49842 .32487 L closepath p
1 g
F P
s
P
p
.002 w
.56238 .34462 m .57198 .33244 L .54585 .31882 L p
1 g
F P
s
P
p
.002 w
.54585 .31882 m .54108 .32507 L .56238 .34462 L p
1 g
F P
s
P
p
.002 w
.34977 .44924 m .38736 .48409 L .39776 .46001 L p
1 g
F P
s
P
p
.002 w
.39776 .46001 m .36284 .42702 L .34977 .44924 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .5339 .32961 L .54108 .32507 L closepath p
1 g
F P
s
P
p
.002 w
.6186 .36686 m .59971 .3894 L .615 .41375 L p
1 g
F P
s
P
p
.002 w
.59971 .3894 m .6186 .36686 L .5964 .34855 L p
1 g
F P
s
P
p
.002 w
.63717 .46402 m .59534 .48672 L .5986 .5127 L p
1 g
F P
s
P
p
.002 w
.59534 .48672 m .63717 .46402 L .62759 .43879 L p
1 g
F P
s
P
p
.002 w
.3604 .36914 m .37905 .40533 L .39802 .38459 L p
1 g
F P
s
P
p
.002 w
.39802 .38459 m .38213 .35269 L .3604 .36914 L p
1 g
F P
s
P
p
.002 w
.49257 .31859 m .48945 .31129 L .46068 .31757 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .48945 .31129 L .49257 .31859 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .54108 .32507 L .54585 .31882 L closepath p
1 g
F P
s
P
p
.002 w
.63809 .38701 m .615 .41375 L .62759 .43879 L p
1 g
F P
s
P
p
.002 w
.615 .41375 m .63809 .38701 L .6186 .36686 L p
1 g
F P
s
P
p
.002 w
.42568 .55528 m .48307 .56958 L .48636 .54743 L p
1 g
F P
s
P
p
.002 w
.48636 .54743 m .42981 .53325 L .42568 .55528 L p
1 g
F P
s
P
p
.002 w
.54452 .54885 m .48636 .54743 L .48307 .56958 L p
1 g
F P
s
P
p
.002 w
.43203 .30477 m .43282 .32668 L .46068 .31757 L p
1 g
F P
s
P
p
.002 w
.46068 .31757 m .46039 .30264 L .43203 .30477 L p
1 g
F P
s
P
p
.002 w
.46039 .30264 m .46068 .31757 L .48945 .31129 L p
1 g
F P
s
P
p
.002 w
.48945 .31129 m .48943 .30372 L .46039 .30264 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .48943 .30372 L .48945 .31129 L closepath p
1 g
F P
s
P
p
.002 w
.54768 .31149 m .54585 .31882 L .57198 .33244 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .54585 .31882 L .54768 .31149 L closepath p
1 g
F P
s
P
p
.002 w
.57584 .31804 m .57198 .33244 L .5964 .34855 L p
1 g
F P
s
P
p
.002 w
.57198 .33244 m .57584 .31804 L .54768 .31149 L p
1 g
F P
s
P
p
.002 w
.34182 .3875 m .36284 .42702 L .37905 .40533 L p
1 g
F P
s
P
p
.002 w
.37905 .40533 m .3604 .36914 L .34182 .3875 L p
1 g
F P
s
P
p
.002 w
.40497 .31014 m .40645 .33846 L .43282 .32668 L p
1 g
F P
s
P
p
.002 w
.43282 .32668 m .43203 .30477 L .40497 .31014 L p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .54768 .31149 L .54633 .30389 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .54633 .30389 L .54189 .29683 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .54189 .29683 L .53485 .29112 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .53485 .29112 L .52596 .2874 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .52596 .2874 L .51621 .2861 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .51621 .2861 L .50672 .28737 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .50672 .28737 L .49854 .29106 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .49854 .29106 L .49256 .29672 L closepath p
1 g
F P
s
P
p
.002 w
.51855 .30796 m .49256 .29672 L .48943 .30372 L closepath p
1 g
F P
s
P
p
.002 w
.37466 .52928 m .42568 .55528 L .42981 .53325 L p
1 g
F P
s
P
p
.002 w
.42981 .53325 m .37957 .50735 L .37466 .52928 L p
1 g
F P
s
P
p
.002 w
.34026 .47153 m .37957 .50735 L .38736 .48409 L p
1 g
F P
s
P
p
.002 w
.38736 .48409 m .34977 .44924 L .34026 .47153 L p
1 g
F P
s
P
p
.002 w
.48307 .56958 m .54205 .57113 L .54452 .54885 L p
1 g
F P
s
P
p
.002 w
.59943 .53719 m .54452 .54885 L .54205 .57113 L p
1 g
F P
s
P
p
.002 w
.54452 .54885 m .59943 .53719 L .5986 .5127 L p
1 g
F P
s
P
p
.002 w
.60242 .32752 m .5964 .34855 L .6186 .36686 L p
1 g
F P
s
P
p
.002 w
.5964 .34855 m .60242 .32752 L .57584 .31804 L p
1 g
F P
s
P
p
.002 w
.46637 .2887 m .46039 .30264 L .48943 .30372 L p
1 g
F P
s
P
p
.002 w
.48943 .30372 m .49256 .29672 L .46637 .2887 L p
1 g
F P
s
P
p
.002 w
.65439 .40861 m .62759 .43879 L .63717 .46402 L p
1 g
F P
s
P
p
.002 w
.62759 .43879 m .65439 .40861 L .63809 .38701 L p
1 g
F P
s
P
p
.002 w
.54633 .30389 m .54768 .31149 L .57584 .31804 L p
1 g
F P
s
P
p
.002 w
.64345 .48893 m .5986 .5127 L .59943 .53719 L p
1 g
F P
s
P
p
.002 w
.5986 .5127 m .64345 .48893 L .63717 .46402 L p
1 g
F P
s
P
p
.002 w
.37983 .31871 m .38213 .35269 L .40645 .33846 L p
1 g
F P
s
P
p
.002 w
.40645 .33846 m .40497 .31014 L .37983 .31871 L p
1 g
F P
s
P
p
.002 w
.44052 .28414 m .43203 .30477 L .46039 .30264 L p
1 g
F P
s
P
p
.002 w
.46039 .30264 m .46637 .2887 L .44052 .28414 L p
1 g
F P
s
P
p
.002 w
.4781 .27732 m .46637 .2887 L .49256 .29672 L p
1 g
F P
s
P
p
.002 w
.49256 .29672 m .49854 .29106 L .4781 .27732 L p
1 g
F P
s
P
p
.002 w
.62682 .33977 m .6186 .36686 L .63809 .38701 L p
1 g
F P
s
P
p
.002 w
.6186 .36686 m .62682 .33977 L .60242 .32752 L p
1 g
F P
s
P
p
.002 w
.57584 .31804 m .57338 .30296 L .54633 .30389 L p
1 g
F P
s
P
p
.002 w
.54189 .29683 m .54633 .30389 L .57338 .30296 L p
1 g
F P
s
P
p
.002 w
.57338 .30296 m .57584 .31804 L .60242 .32752 L p
1 g
F P
s
P
p
.002 w
.32691 .40743 m .34977 .44924 L .36284 .42702 L p
1 g
F P
s
P
p
.002 w
.36284 .42702 m .34182 .3875 L .32691 .40743 L p
1 g
F P
s
P
p
.002 w
.49437 .26986 m .4781 .27732 L .49854 .29106 L p
1 g
F P
s
P
p
.002 w
.49854 .29106 m .50672 .28737 L .49437 .26986 L p
1 g
F P
s
P
p
.002 w
.57338 .30296 m .56473 .28885 L .54189 .29683 L p
1 g
F P
s
P
p
.002 w
.53485 .29112 m .54189 .29683 L .56473 .28885 L p
1 g
F P
s
P
p
.002 w
.42333 .5748 m .48011 .58887 L .48307 .56958 L p
1 g
F P
s
P
p
.002 w
.48307 .56958 m .42568 .55528 L .42333 .5748 L p
1 g
F P
s
P
p
.002 w
.54205 .57113 m .48307 .56958 L .48011 .58887 L p
1 g
F P
s
P
p
.002 w
.66705 .43124 m .63717 .46402 L .64345 .48893 L p
1 g
F P
s
P
p
.002 w
.63717 .46402 m .66705 .43124 L .65439 .40861 L p
1 g
F P
s
P
p
.002 w
.35724 .33039 m .3604 .36914 L .38213 .35269 L p
1 g
F P
s
P
p
.002 w
.38213 .35269 m .37983 .31871 L .35724 .33039 L p
1 g
F P
s
P
p
.002 w
.33465 .49338 m .37466 .52928 L .37957 .50735 L p
1 g
F P
s
P
p
.002 w
.37957 .50735 m .34026 .47153 L .33465 .49338 L p
1 g
F P
s
P
p
.002 w
.4156 .28327 m .40497 .31014 L .43203 .30477 L p
1 g
F P
s
P
p
.002 w
.43203 .30477 m .44052 .28414 L .4156 .28327 L p
1 g
F P
s
P
p
.002 w
.51339 .26726 m .49437 .26986 L .50672 .28737 L p
1 g
F P
s
P
p
.002 w
.50672 .28737 m .51621 .2861 L .51339 .26726 L p
1 g
F P
s
P
p
.002 w
.56473 .28885 m .55073 .27736 L .53485 .29112 L p
1 g
F P
s
P
p
.002 w
.52596 .2874 m .53485 .29112 L .55073 .27736 L p
1 g
F P
s
P
p
.002 w
.64846 .35462 m .63809 .38701 L .65439 .40861 L p
1 g
F P
s
P
p
.002 w
.63809 .38701 m .64846 .35462 L .62682 .33977 L p
1 g
F P
s
P
p
.002 w
.37285 .54934 m .42333 .5748 L .42568 .55528 L p
1 g
F P
s
P
p
.002 w
.42568 .55528 m .37466 .52928 L .37285 .54934 L p
1 g
F P
s
P
p
.002 w
.59912 .30527 m .60242 .32752 L .62682 .33977 L p
1 g
F P
s
P
p
.002 w
.60242 .32752 m .59912 .30527 L .57338 .30296 L p
1 g
F P
s
P
p
.002 w
.53294 .26986 m .51339 .26726 L .51621 .2861 L p
1 g
F P
s
P
p
.002 w
.51621 .2861 m .52596 .2874 L .53294 .26986 L p
1 g
F P
s
P
p
.002 w
.55073 .27736 m .53294 .26986 L .52596 .2874 L p
1 g
F P
s
P
p
.002 w
.45767 .26716 m .44052 .28414 L .46637 .2887 L p
1 g
F P
s
P
p
.002 w
.46637 .2887 m .4781 .27732 L .45767 .26716 L p
1 g
F P
s
P
p
.002 w
.54205 .57113 m .59774 .55961 L .59943 .53719 L p
1 g
F P
s
P
p
.002 w
.64618 .51295 m .59943 .53719 L .59774 .55961 L p
1 g
F P
s
P
p
.002 w
.59943 .53719 m .64618 .51295 L .64345 .48893 L p
1 g
F P
s
P
p
.002 w
.48011 .58887 m .53843 .5905 L .54205 .57113 L p
1 g
F P
s
P
p
.002 w
.59774 .55961 m .54205 .57113 L .53843 .5905 L p
1 g
F P
s
P
p
.002 w
.56473 .28885 m .57338 .30296 L .59912 .30527 L p
1 g
F P
s
P
p
.002 w
.31617 .42852 m .34026 .47153 L .34977 .44924 L p
1 g
F P
s
P
p
.002 w
.34977 .44924 m .32691 .40743 L .31617 .42852 L p
1 g
F P
s
P
p
.002 w
.33782 .34501 m .34182 .3875 L .3604 .36914 L p
1 g
F P
s
P
p
.002 w
.3604 .36914 m .35724 .33039 L .33782 .34501 L p
1 g
F P
s
P
p
.002 w
.39222 .28624 m .37983 .31871 L .40497 .31014 L p
1 g
F P
s
P
p
.002 w
.40497 .31014 m .4156 .28327 L .39222 .28624 L p
1 g
F P
s
P
p
.002 w
.48177 .25596 m .45767 .26716 L .4781 .27732 L p
1 g
F P
s
P
p
.002 w
.4781 .27732 m .49437 .26986 L .48177 .25596 L p
1 g
F P
s
P
p
.002 w
.67566 .45442 m .64345 .48893 L .64618 .51295 L p
1 g
F P
s
P
p
.002 w
.64345 .48893 m .67566 .45442 L .66705 .43124 L p
1 g
F P
s
P
p
.002 w
.59912 .30527 m .58654 .28431 L .56473 .28885 L p
1 g
F P
s
P
p
.002 w
.55073 .27736 m .56473 .28885 L .58654 .28431 L p
1 g
F P
s
P
p
.002 w
.66673 .37181 m .65439 .40861 L .66705 .43124 L p
1 g
F P
s
P
p
.002 w
.65439 .40861 m .66673 .37181 L .64846 .35462 L p
1 g
F P
s
P
p
.002 w
.62293 .3109 m .62682 .33977 L .64846 .35462 L p
1 g
F P
s
P
p
.002 w
.62682 .33977 m .62293 .3109 L .59912 .30527 L p
1 g
F P
s
P
p
.002 w
.43771 .26099 m .4156 .28327 L .44052 .28414 L p
1 g
F P
s
P
p
.002 w
.44052 .28414 m .45767 .26716 L .43771 .26099 L p
1 g
F P
s
P
p
.002 w
.33326 .51425 m .37285 .54934 L .37466 .52928 L p
1 g
F P
s
P
p
.002 w
.37466 .52928 m .33465 .49338 L .33326 .51425 L p
1 g
F P
s
P
p
.002 w
.42291 .59124 m .47756 .60471 L .48011 .58887 L p
1 g
F P
s
P
p
.002 w
.48011 .58887 m .42333 .5748 L .42291 .59124 L p
1 g
F P
s
P
p
.002 w
.53843 .5905 m .48011 .58887 L .47756 .60471 L p
1 g
F P
s
P
p
.002 w
.58654 .28431 m .59912 .30527 L .62293 .3109 L p
1 g
F P
s
P
p
.002 w
.51011 .252 m .48177 .25596 L .49437 .26986 L p
1 g
F P
s
P
p
.002 w
.49437 .26986 m .51339 .26726 L .51011 .252 L p
1 g
F P
s
P
p
.002 w
.58654 .28431 m .56584 .26713 L .55073 .27736 L p
1 g
F P
s
P
p
.002 w
.53294 .26986 m .55073 .27736 L .56584 .26713 L p
1 g
F P
s
P
p
.002 w
.53843 .5905 m .59345 .57937 L .59774 .55961 L p
1 g
F P
s
P
p
.002 w
.64515 .53549 m .59774 .55961 L .59345 .57937 L p
1 g
F P
s
P
p
.002 w
.59774 .55961 m .64515 .53549 L .64618 .51295 L p
1 g
F P
s
P
p
.002 w
.37434 .56694 m .42291 .59124 L .42333 .5748 L p
1 g
F P
s
P
p
.002 w
.42333 .5748 m .37285 .54934 L .37434 .56694 L p
1 g
F P
s
P
p
.002 w
.53931 .25588 m .51011 .252 L .51339 .26726 L p
1 g
F P
s
P
p
.002 w
.51339 .26726 m .53294 .26986 L .53931 .25588 L p
1 g
F P
s
P
p
.002 w
.32219 .36235 m .32691 .40743 L .34182 .3875 L p
1 g
F P
s
P
p
.002 w
.34182 .3875 m .33782 .34501 L .32219 .36235 L p
1 g
F P
s
P
p
.002 w
.56584 .26713 m .53931 .25588 L .53294 .26986 L p
1 g
F P
s
P
p
.002 w
.37101 .29314 m .35724 .33039 L .37983 .31871 L p
1 g
F P
s
P
p
.002 w
.37983 .31871 m .39222 .28624 L .37101 .29314 L p
1 g
F P
s
P
p
.002 w
.47756 .60471 m .53366 .60636 L .53843 .5905 L p
1 g
F P
s
P
p
.002 w
.59345 .57937 m .53843 .5905 L .53366 .60636 L p
1 g
F P
s
P
p
.002 w
.31004 .45028 m .33465 .49338 L .34026 .47153 L p
1 g
F P
s
P
p
.002 w
.34026 .47153 m .31617 .42852 L .31004 .45028 L p
1 g
F P
s
P
p
.002 w
.64417 .31983 m .64846 .35462 L .66673 .37181 L p
1 g
F P
s
P
p
.002 w
.64846 .35462 m .64417 .31983 L .62293 .3109 L p
1 g
F P
s
P
p
.002 w
.68108 .39102 m .66705 .43124 L .67566 .45442 L p
1 g
F P
s
P
p
.002 w
.66705 .43124 m .68108 .39102 L .66673 .37181 L p
1 g
F P
s
P
p
.002 w
.67985 .4776 m .64618 .51295 L .64515 .53549 L p
1 g
F P
s
P
p
.002 w
.64618 .51295 m .67985 .4776 L .67566 .45442 L p
1 g
F P
s
P
p
.002 w
.46918 .24618 m .43771 .26099 L .45767 .26716 L p
1 g
F P
s
P
p
.002 w
.45767 .26716 m .48177 .25596 L .46918 .24618 L p
1 g
F P
s
P
p
.002 w
.41874 .25914 m .39222 .28624 L .4156 .28327 L p
1 g
F P
s
P
p
.002 w
.4156 .28327 m .43771 .26099 L .41874 .25914 L p
1 g
F P
s
P
p
.002 w
.62293 .3109 m .60676 .28347 L .58654 .28431 L p
1 g
F P
s
P
p
.002 w
.56584 .26713 m .58654 .28431 L .60676 .28347 L p
1 g
F P
s
P
p
.002 w
.60676 .28347 m .62293 .3109 L .64417 .31983 L p
1 g
F P
s
P
p
.002 w
.33632 .53356 m .37434 .56694 L .37285 .54934 L p
1 g
F P
s
P
p
.002 w
.37285 .54934 m .33326 .51425 L .33632 .53356 L p
1 g
F P
s
P
p
.002 w
.35262 .30399 m .33782 .34501 L .35724 .33039 L p
1 g
F P
s
P
p
.002 w
.35724 .33039 m .37101 .29314 L .35262 .30399 L p
1 g
F P
s
P
p
.002 w
.31093 .38208 m .31617 .42852 L .32691 .40743 L p
1 g
F P
s
P
p
.002 w
.32691 .40743 m .32219 .36235 L .31093 .38208 L p
1 g
F P
s
P
p
.002 w
.50642 .24091 m .46918 .24618 L .48177 .25596 L p
1 g
F P
s
P
p
.002 w
.48177 .25596 m .51011 .252 L .50642 .24091 L p
1 g
F P
s
P
p
.002 w
.42453 .60403 m .4755 .61655 L .47756 .60471 L p
1 g
F P
s
P
p
.002 w
.47756 .60471 m .42291 .59124 L .42453 .60403 L p
1 g
F P
s
P
p
.002 w
.53366 .60636 m .47756 .60471 L .4755 .61655 L p
1 g
F P
s
P
p
.002 w
.53366 .60636 m .58652 .59587 L .59345 .57937 L p
1 g
F P
s
P
p
.002 w
.64023 .55595 m .59345 .57937 L .58652 .59587 L p
1 g
F P
s
P
p
.002 w
.59345 .57937 m .64023 .55595 L .64515 .53549 L p
1 g
F P
s
P
p
.002 w
.60676 .28347 m .57975 .26086 L .56584 .26713 L p
1 g
F P
s
P
p
.002 w
.53931 .25588 m .56584 .26713 L .57975 .26086 L p
1 g
F P
s
P
p
.002 w
.6622 .332 m .66673 .37181 L .68108 .39102 L p
1 g
F P
s
P
p
.002 w
.66673 .37181 m .6622 .332 L .64417 .31983 L p
1 g
F P
s
P
p
.002 w
.3089 .4722 m .33326 .51425 L .33465 .49338 L p
1 g
F P
s
P
p
.002 w
.33465 .49338 m .31004 .45028 L .3089 .4722 L p
1 g
F P
s
P
p
.002 w
.69098 .41186 m .67566 .45442 L .67985 .4776 L p
1 g
F P
s
P
p
.002 w
.67566 .45442 m .69098 .41186 L .68108 .39102 L p
1 g
F P
s
P
p
.002 w
.37929 .58153 m .42453 .60403 L .42291 .59124 L p
1 g
F P
s
P
p
.002 w
.42291 .59124 m .37434 .56694 L .37929 .58153 L p
1 g
F P
s
P
p
.002 w
.54489 .24601 m .50642 .24091 L .51011 .252 L p
1 g
F P
s
P
p
.002 w
.51011 .252 m .53931 .25588 L .54489 .24601 L p
1 g
F P
s
P
p
.002 w
.57975 .26086 m .54489 .24601 L .53931 .25588 L p
1 g
F P
s
P
p
.002 w
.4755 .61655 m .52781 .61814 L .53366 .60636 L p
1 g
F P
s
P
p
.002 w
.58652 .59587 m .53366 .60636 L .52781 .61814 L p
1 g
F P
s
P
p
.002 w
.67932 .50021 m .64515 .53549 L .64023 .55595 L p
1 g
F P
s
P
p
.002 w
.64515 .53549 m .67932 .50021 L .67985 .4776 L p
1 g
F P
s
P
p
.002 w
.4013 .26189 m .37101 .29314 L .39222 .28624 L p
1 g
F P
s
P
p
.002 w
.39222 .28624 m .41874 .25914 L .4013 .26189 L p
1 g
F P
s
P
p
.002 w
.45693 .24102 m .41874 .25914 L .43771 .26099 L p
1 g
F P
s
P
p
.002 w
.43771 .26099 m .46918 .24618 L .45693 .24102 L p
1 g
F P
s
P
p
.002 w
.64417 .31983 m .62484 .28655 L .60676 .28347 L p
1 g
F P
s
P
p
.002 w
.57975 .26086 m .60676 .28347 L .62484 .28655 L p
1 g
F P
s
P
p
.002 w
.62484 .28655 m .64417 .31983 L .6622 .332 L p
1 g
F P
s
P
p
.002 w
.33767 .3187 m .32219 .36235 L .33782 .34501 L p
1 g
F P
s
P
p
.002 w
.33782 .34501 m .35262 .30399 L .33767 .3187 L p
1 g
F P
s
P
p
.002 w
.30453 .40377 m .31004 .45028 L .31617 .42852 L p
1 g
F P
s
P
p
.002 w
.31617 .42852 m .31093 .38208 L .30453 .40377 L p
1 g
F P
s
P
p
.002 w
.67642 .34725 m .68108 .39102 L .69098 .41186 L p
1 g
F P
s
P
p
.002 w
.68108 .39102 m .67642 .34725 L .6622 .332 L p
1 g
F P
s
P
p
.002 w
.344 .55074 m .37929 .58153 L .37434 .56694 L p
1 g
F P
s
P
p
.002 w
.37434 .56694 m .33632 .53356 L .344 .55074 L p
1 g
F P
s
P
p
.002 w
.69597 .43386 m .67985 .4776 L .67932 .50021 L p
1 g
F P
s
P
p
.002 w
.67985 .4776 m .69597 .43386 L .69098 .41186 L p
1 g
F P
s
P
p
.002 w
.31301 .49369 m .33632 .53356 L .33326 .51425 L p
1 g
F P
s
P
p
.002 w
.33326 .51425 m .3089 .4722 L .31301 .49369 L p
1 g
F P
s
P
p
.002 w
.52781 .61814 m .57699 .60852 L .58652 .59587 L p
1 g
F P
s
P
p
.002 w
.63133 .5737 m .58652 .59587 L .57699 .60852 L p
1 g
F P
s
P
p
.002 w
.58652 .59587 m .63133 .5737 L .64023 .55595 L p
1 g
F P
s
P
p
.002 w
.50241 .23453 m .45693 .24102 L .46918 .24618 L p
1 g
F P
s
P
p
.002 w
.46918 .24618 m .50642 .24091 L .50241 .23453 L p
1 g
F P
s
P
p
.002 w
.62484 .28655 m .59206 .25896 L .57975 .26086 L p
1 g
F P
s
P
p
.002 w
.54489 .24601 m .57975 .26086 L .59206 .25896 L p
1 g
F P
s
P
p
.002 w
.42828 .61262 m .47402 .62383 L .4755 .61655 L p
1 g
F P
s
P
p
.002 w
.4755 .61655 m .42453 .60403 L .42828 .61262 L p
1 g
F P
s
P
p
.002 w
.52781 .61814 m .4755 .61655 L .47402 .62383 L p
1 g
F P
s
P
p
.002 w
.67386 .52163 m .64023 .55595 L .63133 .5737 L p
1 g
F P
s
P
p
.002 w
.64023 .55595 m .67386 .52163 L .67932 .50021 L p
1 g
F P
s
P
p
.002 w
.38593 .26942 m .35262 .30399 L .37101 .29314 L p
1 g
F P
s
P
p
.002 w
.37101 .29314 m .4013 .26189 L .38593 .26942 L p
1 g
F P
s
P
p
.002 w
.38776 .59254 m .42828 .61262 L .42453 .60403 L p
1 g
F P
s
P
p
.002 w
.42453 .60403 m .37929 .58153 L .38776 .59254 L p
1 g
F P
s
P
p
.002 w
.44536 .24088 m .4013 .26189 L .41874 .25914 L p
1 g
F P
s
P
p
.002 w
.41874 .25914 m .45693 .24102 L .44536 .24088 L p
1 g
F P
s
P
p
.002 w
.47402 .62383 m .52096 .62529 L .52781 .61814 L p
1 g
F P
s
P
p
.002 w
.57699 .60852 m .52781 .61814 L .52096 .62529 L p
1 g
F P
s
P
p
.002 w
.54947 .24077 m .50241 .23453 L .50642 .24091 L p
1 g
F P
s
P
p
.002 w
.50642 .24091 m .54489 .24601 L .54947 .24077 L p
1 g
F P
s
P
p
.002 w
.64017 .29367 m .6622 .332 L .67642 .34725 L p
1 g
F P
s
P
p
.002 w
.6622 .332 m .64017 .29367 L .62484 .28655 L p
1 g
F P
s
P
p
.002 w
.59206 .25896 m .54947 .24077 L .54489 .24601 L p
1 g
F P
s
P
p
.002 w
.32677 .33703 m .31093 .38208 L .32219 .36235 L p
1 g
F P
s
P
p
.002 w
.32219 .36235 m .33767 .3187 L .32677 .33703 L p
1 g
F P
s
P
p
.002 w
.59206 .25896 m .62484 .28655 L .64017 .29367 L p
1 g
F P
s
P
p
.002 w
.30341 .4269 m .3089 .4722 L .31004 .45028 L p
1 g
F P
s
P
p
.002 w
.31004 .45028 m .30453 .40377 L .30341 .4269 L p
1 g
F P
s
P
p
.002 w
.68625 .36532 m .69098 .41186 L .69597 .43386 L p
1 g
F P
s
P
p
.002 w
.69098 .41186 m .68625 .36532 L .67642 .34725 L p
1 g
F P
s
P
p
.002 w
.69567 .45646 m .67932 .50021 L .67386 .52163 L p
1 g
F P
s
P
p
.002 w
.67932 .50021 m .69567 .45646 L .69597 .43386 L p
1 g
F P
s
P
p
.002 w
.35633 .56516 m .38776 .59254 L .37929 .58153 L p
1 g
F P
s
P
p
.002 w
.37929 .58153 m .344 .55074 L .35633 .56516 L p
1 g
F P
s
P
p
.002 w
.32252 .5141 m .344 .55074 L .33632 .53356 L p
1 g
F P
s
P
p
.002 w
.33632 .53356 m .31301 .49369 L .32252 .5141 L p
1 g
F P
s
P
p
.002 w
.52096 .62529 m .56495 .61674 L .57699 .60852 L p
1 g
F P
s
P
p
.002 w
.6185 .58813 m .57699 .60852 L .56495 .61674 L p
1 g
F P
s
P
p
.002 w
.57699 .60852 m .6185 .58813 L .63133 .5737 L p
1 g
F P
s
P
p
.002 w
.37322 .28179 m .33767 .3187 L .35262 .30399 L p
1 g
F P
s
P
p
.002 w
.35262 .30399 m .38593 .26942 L .37322 .28179 L p
1 g
F P
s
P
p
.002 w
.66339 .54122 m .63133 .5737 L .6185 .58813 L p
1 g
F P
s
P
p
.002 w
.63133 .5737 m .66339 .54122 L .67386 .52163 L p
1 g
F P
s
P
p
.002 w
.49815 .23334 m .44536 .24088 L .45693 .24102 L p
1 g
F P
s
P
p
.002 w
.45693 .24102 m .50241 .23453 L .49815 .23334 L p
1 g
F P
s
P
p
.002 w
.64017 .29367 m .60232 .26172 L .59206 .25896 L p
1 g
F P
s
P
p
.002 w
.54947 .24077 m .59206 .25896 L .60232 .26172 L p
1 g
F P
s
P
p
.002 w
.43419 .6165 m .47321 .62606 L .47402 .62383 L p
1 g
F P
s
P
p
.002 w
.47402 .62383 m .42828 .61262 L .43419 .6165 L p
1 g
F P
s
P
p
.002 w
.52096 .62529 m .47402 .62383 L .47321 .62606 L p
1 g
F P
s
P
p
.002 w
.67642 .34725 m .65219 .30487 L .64017 .29367 L p
1 g
F P
s
P
p
.002 w
.65219 .30487 m .67642 .34725 L .68625 .36532 L p
1 g
F P
s
P
p
.002 w
.32043 .35865 m .30453 .40377 L .31093 .38208 L p
1 g
F P
s
P
p
.002 w
.31093 .38208 m .32677 .33703 L .32043 .35865 L p
1 g
F P
s
P
p
.002 w
.43486 .2461 m .38593 .26942 L .4013 .26189 L p
1 g
F P
s
P
p
.002 w
.4013 .26189 m .44536 .24088 L .43486 .2461 L p
1 g
F P
s
P
p
.002 w
.30787 .45085 m .31301 .49369 L .3089 .4722 L p
1 g
F P
s
P
p
.002 w
.3089 .4722 m .30341 .4269 L .30787 .45085 L p
1 g
F P
s
P
p
.004 w
.46449 .66511 m
.46844 .63901 L
s
P
p
.004 w
.28237 .52385 m
.31078 .51166 L
s
P
p
.004 w
.228 .54717 m
.28237 .52385 L
s
P
p
.002 w
.39974 .59943 m .43419 .6165 L .42828 .61262 L p
1 g
F P
s
P
p
.002 w
.42828 .61262 m .38776 .59254 L .39974 .59943 L p
1 g
F P
s
P
p
.002 w
.60232 .26172 m .64017 .29367 L .65219 .30487 L p
1 g
F P
s
P
p
.002 w
.47321 .62606 m .51323 .62731 L .52096 .62529 L p
1 g
F P
s
P
p
.002 w
.56495 .61674 m .52096 .62529 L .51323 .62731 L p
1 g
F P
s
P
p
.002 w
.69597 .43386 m .69117 .38585 L .68625 .36532 L p
1 g
F P
s
P
p
.002 w
.69117 .38585 m .69597 .43386 L .69567 .45646 L p
1 g
F P
s
P
p
.002 w
.55288 .2406 m .49815 .23334 L .50241 .23453 L p
1 g
F P
s
P
p
.002 w
.50241 .23453 m .54947 .24077 L .55288 .2406 L p
1 g
F P
s
P
p
.002 w
.60232 .26172 m .55288 .2406 L .54947 .24077 L p
1 g
F P
s
P
p
.002 w
.67386 .52163 m .68986 .47905 L .69567 .45646 L p
1 g
F P
s
P
p
.002 w
.68986 .47905 m .67386 .52163 L .66339 .54122 L p
1 g
F P
s
P
p
.002 w
.33742 .53277 m .35633 .56516 L .344 .55074 L p
1 g
F P
s
P
p
.002 w
.344 .55074 m .32252 .5141 L .33742 .53277 L p
1 g
F P
s
P
p
.002 w
.37319 .57627 m .39974 .59943 L .38776 .59254 L p
1 g
F P
s
P
p
.002 w
.38776 .59254 m .35633 .56516 L .37319 .57627 L p
1 g
F P
s
P
p
.002 w
.36367 .2989 m .32677 .33703 L .33767 .3187 L p
1 g
F P
s
P
p
.002 w
.33767 .3187 m .37322 .28179 L .36367 .2989 L p
1 g
F P
s
P
p
.002 w
.56495 .61674 m .60188 .59865 L .6185 .58813 L p
1 g
F P
s
P
p
.002 w
.6185 .58813 m .64796 .55831 L .66339 .54122 L p
1 g
F P
s
P
p
.002 w
.64796 .55831 m .6185 .58813 L .60188 .59865 L p
1 g
F P
s
P
p
.002 w
.51323 .62731 m .55061 .62005 L .56495 .61674 L p
1 g
F P
s
P
p
.002 w
.60188 .59865 m .56495 .61674 L .55061 .62005 L p
1 g
F P
s
P
p
.002 w
.31909 .38303 m .30341 .4269 L .30453 .40377 L p
1 g
F P
s
P
p
.002 w
.30453 .40377 m .32043 .35865 L .31909 .38303 L p
1 g
F P
s
P
p
.002 w
.66036 .32007 m .68625 .36532 L .69117 .38585 L p
1 g
F P
s
P
p
.002 w
.68625 .36532 m .66036 .32007 L .65219 .30487 L p
1 g
F P
s
P
p
.002 w
.49375 .23772 m .43486 .2461 L .44536 .24088 L p
1 g
F P
s
P
p
.002 w
.44536 .24088 m .49815 .23334 L .49375 .23772 L p
1 g
F P
s
P
p
.002 w
.31801 .47493 m .32252 .5141 L .31301 .49369 L p
1 g
F P
s
P
p
.002 w
.31301 .49369 m .30787 .45085 L .31801 .47493 L p
1 g
F P
s
P
p
.002 w
.65219 .30487 m .61013 .26939 L .60232 .26172 L p
1 g
F P
s
P
p
.002 w
.55288 .2406 m .60232 .26172 L .61013 .26939 L p
1 g
F P
s
P
p
.002 w
.4258 .25685 m .37322 .28179 L .38593 .26942 L p
1 g
F P
s
P
p
.002 w
.38593 .26942 m .43486 .2461 L .4258 .25685 L p
1 g
F P
s
P
p
.002 w
.69079 .40835 m .69567 .45646 L .68986 .47905 L p
1 g
F P
s
P
p
.002 w
.69567 .45646 m .69079 .40835 L .69117 .38585 L p
1 g
F P
s
P
p
.002 w
.44223 .61526 m .47311 .62283 L .47321 .62606 L p
1 g
F P
s
P
p
.002 w
.47321 .62606 m .43419 .6165 L .44223 .61526 L p
1 g
F P
s
P
p
.002 w
.51323 .62731 m .47321 .62606 L .47311 .62283 L p
1 g
F P
s
P
p
.002 w
.67843 .50096 m .66339 .54122 L .64796 .55831 L p
1 g
F P
s
P
p
.002 w
.66339 .54122 m .67843 .50096 L .68986 .47905 L p
1 g
F P
s
P
p
.002 w
.61013 .26939 m .65219 .30487 L .66036 .32007 L p
1 g
F P
s
P
p
.002 w
.41506 .60176 m .44223 .61526 L .43419 .6165 L p
1 g
F P
s
P
p
.002 w
.43419 .6165 m .39974 .59943 L .41506 .60176 L p
1 g
F P
s
P
p
.002 w
.47311 .62283 m .50478 .62381 L .51323 .62731 L p
1 g
F P
s
P
p
.002 w
.55061 .62005 m .51323 .62731 L .50478 .62381 L p
1 g
F P
s
P
p
.002 w
.55493 .24584 m .49375 .23772 L .49815 .23334 L p
1 g
F P
s
P
p
.002 w
.49815 .23334 m .55288 .2406 L .55493 .24584 L p
1 g
F P
s
P
p
.002 w
.61013 .26939 m .55493 .24584 L .55288 .2406 L p
1 g
F P
s
P
p
.002 w
.35748 .54903 m .37319 .57627 L .35633 .56516 L p
1 g
F P
s
P
p
.002 w
.35633 .56516 m .33742 .53277 L .35748 .54903 L p
1 g
F P
s
P
p
.002 w
.35779 .32046 m .32043 .35865 L .32677 .33703 L p
1 g
F P
s
P
p
.002 w
.32677 .33703 m .36367 .2989 L .35779 .32046 L p
1 g
F P
s
P
p
.002 w
.32301 .40952 m .30787 .45085 L .30341 .4269 L p
1 g
F P
s
P
p
.002 w
.30341 .4269 m .31909 .38303 L .32301 .40952 L p
1 g
F P
s
P
p
.002 w
.55061 .62005 m .58176 .60473 L .60188 .59865 L p
1 g
F P
s
P
p
.002 w
.6278 .57227 m .60188 .59865 L .58176 .60473 L p
1 g
F P
s
P
p
.002 w
.60188 .59865 m .6278 .57227 L .64796 .55831 L p
1 g
F P
s
P
p
.002 w
.39432 .58354 m .41506 .60176 L .39974 .59943 L p
1 g
F P
s
P
p
.002 w
.39974 .59943 m .37319 .57627 L .39432 .58354 L p
1 g
F P
s
P
p
.002 w
.6642 .33902 m .69117 .38585 L .69079 .40835 L p
1 g
F P
s
P
p
.002 w
.69117 .38585 m .6642 .33902 L .66036 .32007 L p
1 g
F P
s
P
p
.002 w
.50478 .62381 m .53425 .61805 L .55061 .62005 L p
1 g
F P
s
P
p
.002 w
.58176 .60473 m .55061 .62005 L .53425 .61805 L p
1 g
F P
s
P
p
.002 w
.33375 .49835 m .33742 .53277 L .32252 .5141 L p
1 g
F P
s
P
p
.004 w
.33411 .50166 m
.5 .43051 L
s
P
p
.002 w
.32252 .5141 m .31801 .47493 L .33375 .49835 L p
1 g
F P
s
P
p
.004 w
.31826 .50846 m
.32358 .50618 L
s
P
p
.004 w
.32358 .50618 m
.32491 .50561 L
s
P
p
.004 w
.31078 .51166 m
.31826 .50846 L
s
P
p
.002 w
.68486 .43222 m .68986 .47905 L .67843 .50096 L p
1 g
F P
s
P
p
.002 w
.68986 .47905 m .68486 .43222 L .69079 .40835 L p
1 g
F P
s
P
p
.002 w
.48935 .24791 m .4258 .25685 L .43486 .2461 L p
1 g
F P
s
P
p
.002 w
.43486 .2461 m .49375 .23772 L .48935 .24791 L p
1 g
F P
s
P
p
.002 w
.66149 .52145 m .64796 .55831 L .6278 .57227 L p
1 g
F P
s
P
p
.002 w
.64796 .55831 m .66149 .52145 L .67843 .50096 L p
1 g
F P
s
P
p
.002 w
.41857 .27313 m .36367 .2989 L .37322 .28179 L p
1 g
F P
s
P
p
.002 w
.37322 .28179 m .4258 .25685 L .41857 .27313 L p
1 g
F P
s
P
p
.002 w
.66036 .32007 m .61508 .28202 L .61013 .26939 L p
1 g
F P
s
P
p
.002 w
.55493 .24584 m .61013 .26939 L .61508 .28202 L p
1 g
F P
s
P
p
.002 w
.61508 .28202 m .66036 .32007 L .6642 .33902 L p
1 g
F P
s
P
p
.002 w
.45229 .60859 m .47379 .61388 L .47311 .62283 L p
1 g
F P
s
P
p
.002 w
.47311 .62283 m .44223 .61526 L .45229 .60859 L p
1 g
F P
s
P
p
.002 w
.50478 .62381 m .47311 .62283 L .47379 .61388 L p
1 g
F P
s
P
p
.002 w
.43346 .59918 m .45229 .60859 L .44223 .61526 L p
1 g
F P
s
P
p
.002 w
.44223 .61526 m .41506 .60176 L .43346 .59918 L p
1 g
F P
s
P
p
.002 w
.35593 .34598 m .31909 .38303 L .32043 .35865 L p
1 g
F P
s
P
p
.002 w
.32043 .35865 m .35779 .32046 L .35593 .34598 L p
1 g
F P
s
P
p
.002 w
.47379 .61388 m .49585 .61454 L .50478 .62381 L p
1 g
F P
s
P
p
.002 w
.53425 .61805 m .50478 .62381 L .49585 .61454 L p
1 g
F P
s
P
p
.002 w
.33229 .43733 m .31801 .47493 L .30787 .45085 L p
1 g
F P
s
P
p
.002 w
.30787 .45085 m .32301 .40952 L .33229 .43733 L p
1 g
F P
s
P
p
.002 w
.38228 .56227 m .39432 .58354 L .37319 .57627 L p
1 g
F P
s
P
p
.002 w
.37319 .57627 m .35748 .54903 L .38228 .56227 L p
1 g
F P
s
P
p
.002 w
.55547 .25669 m .48935 .24791 L .49375 .23772 L p
1 g
F P
s
P
p
.002 w
.49375 .23772 m .55493 .24584 L .55547 .25669 L p
1 g
F P
s
P
p
.002 w
.61508 .28202 m .55547 .25669 L .55493 .24584 L p
1 g
F P
s
P
p
.002 w
.53425 .61805 m .55859 .60597 L .58176 .60473 L p
1 g
F P
s
P
p
.002 w
.60334 .58252 m .58176 .60473 L .55859 .60597 L p
1 g
F P
s
P
p
.002 w
.58176 .60473 m .60334 .58252 L .6278 .57227 L p
1 g
F P
s
P
p
.002 w
.66335 .36133 m .69079 .40835 L .68486 .43222 L p
1 g
F P
s
P
p
.002 w
.69079 .40835 m .66335 .36133 L .6642 .33902 L p
1 g
F P
s
P
p
.002 w
.35479 .52031 m .35748 .54903 L .33742 .53277 L p
1 g
F P
s
P
p
.002 w
.33742 .53277 m .33375 .49835 L .35479 .52031 L p
1 g
F P
s
P
p
.002 w
.67331 .45673 m .67843 .50096 L .66149 .52145 L p
1 g
F P
s
P
p
.002 w
.67843 .50096 m .67331 .45673 L .68486 .43222 L p
1 g
F P
s
P
p
.002 w
.41923 .58654 m .43346 .59918 L .41506 .60176 L p
1 g
F P
s
P
p
.002 w
.41506 .60176 m .39432 .58354 L .41923 .58654 L p
1 g
F P
s
P
p
.002 w
.63936 .53981 m .6278 .57227 L .60334 .58252 L p
1 g
F P
s
P
p
.002 w
.6278 .57227 m .63936 .53981 L .66149 .52145 L p
1 g
F P
s
P
p
.002 w
.49585 .61454 m .51626 .6105 L .53425 .61805 L p
1 g
F P
s
P
p
.002 w
.55859 .60597 m .53425 .61805 L .51626 .6105 L p
1 g
F P
s
P
p
.002 w
.4135 .29469 m .35779 .32046 L .36367 .2989 L p
1 g
F P
s
P
p
.002 w
.36367 .2989 m .41857 .27313 L .4135 .29469 L p
1 g
F P
s
P
p
.002 w
.48509 .26394 m .41857 .27313 L .4258 .25685 L p
1 g
F P
s
P
p
.002 w
.4258 .25685 m .48935 .24791 L .48509 .26394 L p
1 g
F P
s
P
p
.002 w
.61684 .29953 m .6642 .33902 L .66335 .36133 L p
1 g
F P
s
P
p
.002 w
.6642 .33902 m .61684 .29953 L .61508 .28202 L p
1 g
F P
s
P
p
.002 w
.55547 .25669 m .61508 .28202 L .61684 .29953 L p
1 g
F P
s
P
p
.002 w
.3468 .46554 m .33375 .49835 L .31801 .47493 L p
1 g
F P
s
P
p
.002 w
.31801 .47493 m .33229 .43733 L .3468 .46554 L p
1 g
F P
s
P
p
.002 w
.35836 .37476 m .32301 .40952 L .31909 .38303 L p
1 g
F P
s
P
p
.002 w
.31909 .38303 m .35593 .34598 L .35836 .37476 L p
1 g
F P
s
P
p
.002 w
.41117 .5719 m .41923 .58654 L .39432 .58354 L p
1 g
F P
s
P
p
.002 w
.39432 .58354 m .38228 .56227 L .41117 .5719 L p
1 g
F P
s
P
p
.002 w
.38056 .54003 m .38228 .56227 L .35748 .54903 L p
1 g
F P
s
P
p
.002 w
.35748 .54903 m .35479 .52031 L .38056 .54003 L p
1 g
F P
s
P
p
.002 w
.65631 .48109 m .66149 .52145 L .63936 .53981 L p
1 g
F P
s
P
p
.002 w
.66149 .52145 m .65631 .48109 L .67331 .45673 L p
1 g
F P
s
P
p
.002 w
.46417 .59638 m .47528 .59912 L .47379 .61388 L p
1 g
F P
s
P
p
.002 w
.47379 .61388 m .45229 .60859 L .46417 .59638 L p
1 g
F P
s
P
p
.002 w
.49585 .61454 m .47379 .61388 L .47528 .59912 L p
1 g
F P
s
P
p
.002 w
.51626 .6105 m .53297 .60207 L .55859 .60597 L p
1 g
F P
s
P
p
.002 w
.57519 .58856 m .55859 .60597 L .53297 .60207 L p
1 g
F P
s
P
p
.002 w
.55859 .60597 m .57519 .58856 L .60334 .58252 L p
1 g
F P
s
P
p
.002 w
.65761 .38642 m .68486 .43222 L .67331 .45673 L p
1 g
F P
s
P
p
.002 w
.68486 .43222 m .65761 .38642 L .66335 .36133 L p
1 g
F P
s
P
p
.002 w
.45449 .5915 m .46417 .59638 L .45229 .60859 L p
1 g
F P
s
P
p
.002 w
.45229 .60859 m .43346 .59918 L .45449 .5915 L p
1 g
F P
s
P
p
.002 w
.47528 .59912 m .48667 .59945 L .49585 .61454 L p
1 g
F P
s
P
p
.002 w
.51626 .6105 m .49585 .61454 L .48667 .59945 L p
1 g
F P
s
P
p
.002 w
.61259 .55535 m .60334 .58252 L .57519 .58856 L p
1 g
F P
s
P
p
.002 w
.60334 .58252 m .61259 .55535 L .63936 .53981 L p
1 g
F P
s
P
p
.002 w
.55438 .27315 m .48509 .26394 L .48935 .24791 L p
1 g
F P
s
P
p
.002 w
.48935 .24791 m .55547 .25669 L .55438 .27315 L p
1 g
F P
s
P
p
.002 w
.61684 .29953 m .55438 .27315 L .55547 .25669 L p
1 g
F P
s
P
p
.002 w
.44727 .58498 m .45449 .5915 L .43346 .59918 L p
1 g
F P
s
P
p
.002 w
.43346 .59918 m .41923 .58654 L .44727 .58498 L p
1 g
F P
s
P
p
.002 w
.48667 .59945 m .49717 .59733 L .51626 .6105 L p
1 g
F P
s
P
p
.002 w
.53297 .60207 m .51626 .6105 L .49717 .59733 L p
1 g
F P
s
P
p
.002 w
.41089 .32107 m .35593 .34598 L .35779 .32046 L p
1 g
F P
s
P
p
.002 w
.35779 .32046 m .4135 .29469 L .41089 .32107 L p
1 g
F P
s
P
p
.002 w
.36617 .49317 m .35479 .52031 L .33375 .49835 L p
1 g
F P
s
P
p
.002 w
.33375 .49835 m .3468 .46554 L .36617 .49317 L p
1 g
F P
s
P
p
.002 w
.36515 .4059 m .33229 .43733 L .32301 .40952 L p
1 g
F P
s
P
p
.002 w
.32301 .40952 m .35836 .37476 L .36515 .4059 L p
1 g
F P
s
P
p
.002 w
.61516 .32159 m .66335 .36133 L .65761 .38642 L p
1 g
F P
s
P
p
.002 w
.66335 .36133 m .61516 .32159 L .61684 .29953 L p
1 g
F P
s
P
p
.002 w
.48111 .28559 m .4135 .29469 L .41857 .27313 L p
1 g
F P
s
P
p
.002 w
.41857 .27313 m .48509 .26394 L .48111 .28559 L p
1 g
F P
s
P
p
.002 w
.63425 .50444 m .63936 .53981 L .61259 .55535 L p
1 g
F P
s
P
p
.002 w
.63936 .53981 m .63425 .50444 L .65631 .48109 L p
1 g
F P
s
P
p
.002 w
.4103 .55674 m .41117 .5719 L .38228 .56227 L p
1 g
F P
s
P
p
.002 w
.38228 .56227 m .38056 .54003 L .4103 .55674 L p
1 g
F P
s
P
p
.002 w
.44328 .57749 m .44727 .58498 L .41923 .58654 L p
1 g
F P
s
P
p
.002 w
.41923 .58654 m .41117 .5719 L .44328 .57749 L p
1 g
F P
s
P
p
.002 w
.55438 .27315 m .61684 .29953 L .61516 .32159 L p
1 g
F P
s
P
p
.002 w
.64696 .41353 m .67331 .45673 L .65631 .48109 L p
1 g
F P
s
P
p
.002 w
.67331 .45673 m .64696 .41353 L .65761 .38642 L p
1 g
F P
s
P
p
.002 w
.53297 .60207 m .54416 .59003 L .57519 .58856 L p
1 g
F P
s
P
p
.002 w
.58197 .56743 m .57519 .58856 L .54416 .59003 L p
1 g
F P
s
P
p
.002 w
.57519 .58856 m .58197 .56743 L .61259 .55535 L p
1 g
F P
s
P
p
.002 w
.49717 .59733 m .50567 .59295 L .53297 .60207 L p
1 g
F P
s
P
p
.002 w
.54416 .59003 m .53297 .60207 L .50567 .59295 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.48252 .54603 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.38982 .51921 m .38056 .54003 L .35479 .52031 L p
1 g
F P
s
P
p
.002 w
.35479 .52031 m .36617 .49317 L .38982 .51921 L p
1 g
F P
s
P
p
.002 w
.47528 .59912 m .46417 .59638 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.48667 .59945 m .47528 .59912 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.46417 .59638 m .45449 .5915 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.49717 .59733 m .48667 .59945 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.60777 .52593 m .61259 .55535 L .58197 .56743 L p
1 g
F P
s
P
p
.002 w
.61259 .55535 m .60777 .52593 L .63425 .50444 L p
1 g
F P
s
P
p
.002 w
.37619 .43832 m .3468 .46554 L .33229 .43733 L p
1 g
F P
s
P
p
.002 w
.33229 .43733 m .36515 .4059 L .37619 .43832 L p
1 g
F P
s
P
p
.002 w
.45449 .5915 m .44727 .58498 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.55161 .29498 m .48111 .28559 L .48509 .26394 L p
1 g
F P
s
P
p
.002 w
.48509 .26394 m .55438 .27315 L .55161 .29498 L p
1 g
F P
s
P
p
.002 w
.41094 .35151 m .35836 .37476 L .35593 .34598 L p
1 g
F P
s
P
p
.002 w
.35593 .34598 m .41089 .32107 L .41094 .35151 L p
1 g
F P
s
P
p
.002 w
.44301 .56981 m .44328 .57749 L .41117 .5719 L p
1 g
F P
s
P
p
.002 w
.41117 .5719 m .4103 .55674 L .44301 .56981 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.50567 .59295 m .49717 .59733 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.61516 .32159 m .55161 .29498 L .55438 .27315 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50567 .59295 m .51125 .58675 L .54416 .59003 L p
1 g
F P
s
P
p
.002 w
.54848 .57556 m .54416 .59003 L .51125 .58675 L p
1 g
F P
s
P
p
.002 w
.54416 .59003 m .54848 .57556 L .58197 .56743 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.63159 .44177 m .65631 .48109 L .63425 .50444 L p
1 g
F P
s
P
p
.002 w
.65631 .48109 m .63159 .44177 L .64696 .41353 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.60994 .34768 m .65761 .38642 L .64696 .41353 L p
1 g
F P
s
P
p
.002 w
.65761 .38642 m .60994 .34768 L .61516 .32159 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.44727 .58498 m .44328 .57749 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51125 .58675 m .50567 .59295 L .48122 .58057 L p
1 g
F P
s
P
p
.002 w
.48577 .58068 m .51125 .58675 L p
.48122 .58057 L 1 g
F P
s
P
p
.002 w
.51097 .58109 m .51079 .57862 L p
.49937 .5809 L 1 g
F P
s
P
p
.002 w
.47757 .57872 m .48038 .57878 L p
.48127 .57898 L 1 g
F P
s
P
p
.002 w
.51279 .58112 m .51125 .58675 L .49798 .58359 L p
1 g
F P
s
P
p
.002 w
.49798 .58359 m .48577 .58068 L p
.51097 .58109 L 1 g
F P
s
P
p
.51279 .58112 m .49798 .58359 L .51097 .58109 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58109 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .58109 L .5129 .58072 L 1 g
F
P
p
.002 w
.51921 .57873 m .54848 .57556 L p
.5129 .58072 L 1 g
F P
s
P
p
.002 w
.54717 .56932 m .54848 .57556 L .52606 .57799 L p
1 g
F P
s
P
p
.002 w
.52606 .57799 m .51921 .57873 L p
.53169 .57453 L 1 g
F P
s
P
p
.54717 .56932 m .52606 .57799 L .53169 .57453 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57453 L p
1 g
F P
s
P
p
.54854 .56129 m .53169 .57453 L .54001 .56942 L 1 g
F
P
p
.53128 .57265 m .5129 .58072 L .51921 .57873 L 1 g
F
P
p
.51982 .57853 m .51921 .57873 L .51976 .57856 L 1 g
F
P
p
.53128 .57265 m .51921 .57873 L .51982 .57853 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51125 .58675 m .5129 .58072 L p
.54848 .57556 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54637 .56551 m .54717 .56932 L p
.53364 .57334 L 1 g
F P
s
P
p
.002 w
.51921 .57873 m .51326 .57938 L p
.54717 .56932 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54927 .56326 L p
1 g
F P
s
P
p
.002 w
.54848 .57556 m .5466 .56661 L p
.57775 .54474 L 1 g
F P
s
P
p
.57775 .54474 m .5466 .56661 L .54871 .56396 L 1 g
F
P
p
.56075 .54566 m .54927 .56326 L .55501 .55607 L 1 g
F
P
p
.54854 .56129 m .54001 .56942 L .54637 .56551 L 1 g
F
P
p
.002 w
.54927 .56326 m .54854 .56129 L p
.54637 .56551 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56075 .54566 m .55501 .55607 L .55571 .5552 L 1 g
F
P
p
.002 w
.57053 .53444 m .57775 .54474 L .55939 .55345 L p
1 g
F P
s
P
p
.002 w
.55939 .55345 m .55571 .5552 L p
.5615 .54708 L 1 g
F P
s
P
p
.57053 .53444 m .55939 .55345 L .5615 .54708 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5615 .54708 L p
1 g
F P
s
P
p
.56654 .52734 m .5615 .54708 L .56468 .53752 L 1 g
F
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56654 .52734 m .56468 .53752 L .56726 .52977 L 1 g
F
P
p
.002 w
.57131 .51444 m .58862 .49757 L p
.56755 .52932 L 1 g
F P
s
P
p
.56755 .52932 m .56726 .52977 L .56752 .52877 L 1 g
F
P
p
.56755 .52932 m .56752 .52877 L .57131 .51444 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56752 .52877 L p
1 g
F P
s
P
p
.002 w
.57775 .54474 m .56761 .53027 L p
.58862 .49757 L 1 g
F P
s
P
p
.002 w
.56761 .53027 m .56726 .52977 L p
.56755 .52932 L 1 g
F P
s
P
p
.58862 .49757 m .56761 .53027 L .56755 .52932 L 1 g
F
P
p
.56515 .50826 m .56705 .5206 L .56694 .5187 L 1 g
F
P
p
.002 w
.56249 .47806 m .58862 .49757 L .56937 .51634 L p
1 g
F P
s
P
p
.002 w
.56937 .51634 m .56694 .5187 L p
.5659 .50915 L 1 g
F P
s
P
p
.56249 .47806 m .56937 .51634 L .5659 .50915 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5659 .50915 L p
1 g
F P
s
P
p
.55661 .4905 m .5659 .50915 L .56043 .4978 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55676 .47378 m .56249 .47806 L p
.56251 .50212 L 1 g
F P
s
P
p
.002 w
.55722 .49115 m .55661 .4905 L p
.56043 .4978 L 1 g
F P
s
P
p
.5593 .49546 m .56251 .50212 L .56252 .52301 L 1 g
F
P
p
.55676 .47378 m .56251 .50212 L .5593 .49546 L 1 g
F
P
p
.002 w
.5659 .50915 m .56515 .50826 L p
.56694 .5187 L 1 g
F P
s
P
p
.56515 .50826 m .56752 .52877 L .56705 .5206 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56694 .5187 m .56252 .52301 L p
.56249 .47806 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.56252 .52301 m .53765 .50489 L .55024 .4844 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55722 .49115 L p
1 g
F P
s
P
p
.54174 .47608 m .55722 .49115 L .55048 .48464 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55899 .49286 m .56252 .52301 L .55024 .4844 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55722 .49115 L p
1 g
F P
s
P
p
.56043 .4978 m .56713 .51061 L .55722 .49115 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55024 .4844 m .53765 .50489 L p
.52953 .47053 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54221 .4766 L p
1 g
F P
s
P
p
.52214 .46667 m .54221 .4766 L .53033 .47091 L 1 g
F
P
p
.54221 .4766 m .55024 .4844 L .52953 .47053 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.51996 .4668 m .52953 .47053 L .53765 .50489 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46712 L .51345 .46595 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51345 .46595 m .50593 .49267 L p
.48324 .46626 L 1 g
F P
s
P
p
.002 w
.4776 .4671 m .47786 .46667 L p
.48615 .46583 L 1 g
F P
s
P
p
.5 .46376 m .51345 .46595 L .48324 .46626 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46376 L p
1 g
F P
s
P
p
.002 w
.5 .46376 m .5 .46442 L p
.48615 .46583 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46376 L .48615 .46583 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.4707 .45166 m .50478 .46305 L .47802 .4602 L 1 g
F
P
p
.5 .4634 m .51345 .46595 L .51222 .46575 L 1 g
F
P
p
.52241 .46712 m .52953 .47053 L .51996 .4668 L 1 g
F
P
p
.002 w
.53765 .50489 m .50593 .49267 L .51345 .46595 L p
1 g
F P
s
P
p
.51996 .4668 m .53765 .50489 L .51345 .46595 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46419 L p
1 g
F P
s
P
p
.002 w
.5 .46419 m .5 .4634 L p
.51285 .46587 L 1 g
F P
s
P
p
.51285 .46587 m .52282 .46778 L .5 .46419 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51345 .46595 m .51576 .45775 L p
.51996 .4668 L 1 g
F P
s
P
p
.50478 .46305 m .51345 .46595 L .5 .46376 L 1 g
F
P
p
.50478 .46305 m .5 .46376 L .47802 .4602 L 1 g
F
P
p
.47802 .4602 m .5 .46376 L .48324 .46626 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.50593 .49267 m .47117 .48797 L .47094 .4704 L p
1 g
F P
s
P
p
.48206 .46489 m .50593 .49267 L .47094 .4704 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47746 .46733 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47094 .4704 m .47117 .48797 L p
.45678 .47757 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45781 .47657 L p
1 g
F P
s
P
p
.44339 .4905 m .45781 .47657 L .44961 .48454 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43767 .49134 m .42735 .4563 L p
.45148 .47374 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44247 .49148 L p
1 g
F P
s
P
p
.43485 .50826 m .44247 .49148 L .44222 .49199 L 1 g
F
P
p
.43485 .50826 m .44222 .49199 L .43977 .49703 L 1 g
F
P
p
.40949 .50226 m .43506 .49785 L .43167 .51432 L 1 g
F
P
p
.43506 .49785 m .43977 .49703 L .43408 .50918 L 1 g
F
P
p
.43506 .49785 m .43408 .50918 L .43167 .51432 L 1 g
F
P
p
.43485 .50826 m .43977 .49703 L .43842 .49992 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43408 .50918 L p
1 g
F P
s
P
p
.43346 .52734 m .43408 .50918 L .43319 .51947 L 1 g
F
P
p
.002 w
.43977 .49703 m .44981 .52419 L p
.43354 .51534 L 1 g
F P
s
P
p
.43167 .51432 m .43408 .50918 L .43354 .51534 L 1 g
F
P
p
.002 w
.40949 .50226 m .43767 .49134 L .43977 .49703 L p
1 g
F P
s
P
p
.002 w
.43767 .49134 m .44278 .49083 L p
.44247 .49148 L 1 g
F P
s
P
p
.44026 .49362 m .44247 .49148 L .44108 .49434 L 1 g
F
P
p
.43767 .49134 m .44247 .49148 L .44026 .49362 L 1 g
F
P
p
.44339 .4905 m .44961 .48454 L .44318 .49079 L 1 g
F
P
p
.002 w
.44318 .49079 m .47117 .48797 L p
.44247 .49148 L 1 g
F P
s
P
p
.002 w
.44244 .49151 m .44247 .49148 L p
.44318 .49079 L 1 g
F P
s
P
p
.002 w
.44247 .49148 m .44339 .4905 L p
.44318 .49079 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.44247 .49148 m .47117 .48797 L .44108 .49434 L 1 g
F
P
p
.002 w
.44278 .49083 m .44318 .49079 L p
.44247 .49148 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47117 .48797 m .44278 .49083 L p
.45148 .47374 L 1 g
F P
s
P
p
.44318 .49079 m .45698 .47747 L .44244 .49151 L 1 g
F
P
p
.44961 .48454 m .45228 .48198 L .44318 .49079 L 1 g
F
P
p
.45228 .48198 m .45698 .47747 L .44318 .49079 L 1 g
F
P
p
.002 w
.43977 .49703 m .43767 .49134 L p
.44108 .49434 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.43408 .50918 m .43977 .49703 L .43354 .51534 L 1 g
F
P
p
.002 w
.43237 .52893 m .43346 .52734 L p
.43319 .51947 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43057 .53139 m .40949 .50226 L p
.42849 .5126 L 1 g
F P
s
P
p
.002 w
.43276 .53057 m .43057 .53139 L p
.42849 .5126 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43227 .52908 L p
1 g
F P
s
P
p
.43925 .54566 m .43227 .52908 L .43277 .53061 L 1 g
F
P
p
.002 w
.43445 .53575 m .43057 .53139 L p
.43373 .53354 L 1 g
F P
s
P
p
.43925 .54566 m .43277 .53061 L .43493 .53711 L 1 g
F
P
p
.002 w
.43057 .53139 m .43276 .53057 L p
.43373 .53354 L 1 g
F P
s
P
p
.43277 .53061 m .43217 .52922 L .43445 .53575 L 1 g
F
P
p
.43277 .53061 m .43445 .53575 L .43493 .53711 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44981 .52419 m .46329 .55365 L p
.43373 .53354 L 1 g
F P
s
P
p
.002 w
.43276 .53057 m .44981 .52419 L p
.43373 .53354 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46329 .55365 m .45355 .55717 L .43445 .53575 L p
1 g
F P
s
P
p
.43373 .53354 m .46329 .55365 L .43445 .53575 L 1 g
F
P
p
.002 w
.43227 .52908 m .43217 .52922 L p
.43277 .53061 L 1 g
F P
s
P
p
.002 w
.41694 .5427 m .43057 .53139 L .43445 .53575 L p
1 g
F P
s
P
p
.41694 .5427 m .43111 .53707 L .44008 .55185 L 1 g
F
P
p
.43111 .53707 m .43445 .53575 L .43845 .54718 L 1 g
F
P
p
.43111 .53707 m .43845 .54718 L .44008 .55185 L 1 g
F
P
p
.002 w
.44301 .56981 m .44484 .56617 L p
.46998 .57581 L 1 g
F P
s
P
p
.002 w
.47247 .57741 m .44301 .56981 L p
.46998 .57581 L 1 g
F P
s
P
p
.002 w
.46827 .57472 m .46872 .57265 L p
.45895 .56875 L 1 g
F P
s
P
p
.002 w
.44655 .56277 m .44794 .56166 L p
.45067 .56342 L 1 g
F P
s
P
p
.002 w
.46207 .57075 m .45321 .5662 L p
.45067 .56342 L 1 g
F P
s
P
p
.002 w
.45321 .5662 m .44655 .56277 L p
.45067 .56342 L 1 g
F P
s
P
p
.45146 .56129 m .44397 .55478 L .44859 .56114 L 1 g
F
P
p
.002 w
.45067 .56342 m .45146 .56129 L p
.44859 .56114 L 1 g
F P
s
P
p
.45895 .56875 m .46207 .57075 L .46827 .57472 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44484 .56617 m .44655 .56277 L .46207 .57075 L p
1 g
F P
s
P
p
.002 w
.47347 .57662 m .47757 .57872 L p
.44484 .56617 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46826 .57474 L p
1 g
F P
s
P
p
.002 w
.47639 .57767 m .47757 .57872 L .47347 .57662 L p
1 g
F P
s
P
p
.002 w
.47757 .57872 m .47247 .57741 L p
.46998 .57581 L 1 g
F P
s
P
p
.002 w
.44328 .57749 m .44301 .56981 L .47757 .57872 L closepath p
1 g
F P
s
P
p
.002 w
.46826 .57474 m .4678 .57686 L p
.47602 .57754 L 1 g
F P
s
P
p
.48921 .57862 m .46826 .57474 L .47602 .57754 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45066 .56345 L p
1 g
F P
s
P
p
.46872 .57265 m .45066 .56345 L .4589 .56873 L 1 g
F
P
p
.002 w
.48905 .58073 m .48921 .57862 L p
.47601 .57754 L 1 g
F P
s
P
p
.47601 .57754 m .47593 .57753 L .47613 .57758 L 1 g
F
P
p
.47601 .57754 m .47613 .57758 L .48905 .58073 L 1 g
F
P
p
.47593 .57753 m .47619 .57762 L .48905 .58073 L 1 g
F
P
p
.002 w
.47711 .57792 m .47757 .57872 L .47639 .57767 L p
1 g
F P
s
P
p
.47578 .57752 m .47628 .57767 L .48905 .58073 L 1 g
F
P
p
.47556 .5775 m .47647 .57776 L .48905 .58073 L 1 g
F
P
p
.002 w
.47749 .57805 m .47757 .57872 L .47711 .57792 L p
1 g
F P
s
P
p
.47526 .57747 m .4769 .57791 L .48905 .58073 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45355 .55717 m .46329 .55365 L .47711 .57792 L p
1 g
F P
s
P
p
.002 w
.47639 .57767 m .45355 .55717 L p
.47711 .57792 L 1 g
F P
s
P
p
.4749 .57744 m .4779 .57818 L .48905 .58073 L 1 g
F
P
p
.002 w
.46329 .55365 m .47469 .55262 L .47749 .57805 L p
1 g
F P
s
P
p
.002 w
.47711 .57792 m .46329 .55365 L p
.47749 .57805 L 1 g
F P
s
P
p
.47593 .57753 m .47578 .57752 L .47619 .57762 L 1 g
F
P
p
.47578 .57752 m .47556 .5775 L .47628 .57767 L 1 g
F
P
p
.002 w
.47469 .55262 m .48647 .55423 L .47778 .57814 L p
1 g
F P
s
P
p
.002 w
.47778 .57814 m .47757 .57872 L .47749 .57805 L p
1 g
F P
s
P
p
.002 w
.47749 .57805 m .47469 .55262 L p
.47778 .57814 L 1 g
F P
s
P
p
.002 w
.48647 .55423 m .49729 .55828 L .47806 .57822 L p
1 g
F P
s
P
p
.002 w
.47806 .57822 m .47757 .57872 L .47778 .57814 L p
1 g
F P
s
P
p
.002 w
.47778 .57814 m .48647 .55423 L p
.47806 .57822 L 1 g
F P
s
P
p
.47556 .5775 m .47526 .57747 L .47647 .57776 L 1 g
F
P
p
.47526 .57747 m .4749 .57744 L .4769 .57791 L 1 g
F
P
p
.47453 .57741 m .48038 .57878 L .48905 .58073 L 1 g
F
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49729 .55828 m .50593 .5643 L .47839 .5783 L p
1 g
F P
s
P
p
.002 w
.47839 .5783 m .47757 .57872 L .47806 .57822 L p
1 g
F P
s
P
p
.002 w
.47806 .57822 m .49729 .55828 L p
.47839 .5783 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50593 .5643 m .51144 .57161 L .47893 .57844 L p
1 g
F P
s
P
p
.002 w
.47893 .57844 m .47757 .57872 L .47839 .5783 L p
1 g
F P
s
P
p
.002 w
.47839 .5783 m .50593 .5643 L p
.47893 .57844 L 1 g
F P
s
P
p
.4749 .57744 m .47453 .57741 L .4779 .57818 L 1 g
F
P
p
.47453 .57741 m .47425 .57739 L .48038 .57878 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.51144 .57161 m .51326 .57938 L .48038 .57878 L p
1 g
F P
s
P
p
.002 w
.48038 .57878 m .47757 .57872 L .47893 .57844 L p
1 g
F P
s
P
p
.002 w
.47893 .57844 m .51144 .57161 L p
.48038 .57878 L 1 g
F P
s
P
p
.002 w
.45355 .55717 m .47639 .57767 L p
.46207 .57075 L 1 g
F P
s
P
p
.002 w
.47347 .57662 m .46207 .57075 L p
.47639 .57767 L 1 g
F P
s
P
p
.002 w
.46207 .57075 m .47347 .57662 L p
.46827 .57472 L 1 g
F P
s
P
p
.44484 .56617 m .46207 .57075 L .46827 .57472 L 1 g
F
P
p
.002 w
.45066 .56345 m .45002 .56518 L p
.4589 .56873 L 1 g
F P
s
P
p
.45067 .56342 m .45355 .55717 L .46207 .57075 L 1 g
F
P
p
.002 w
.44794 .56166 m .44859 .56114 L p
.45067 .56342 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43845 .54718 L p
1 g
F P
s
P
p
.44008 .55185 m .43845 .54718 L .44255 .55282 L 1 g
F
P
p
.45146 .56129 m .43845 .54718 L .44397 .55478 L 1 g
F
P
p
.002 w
.45355 .55717 m .44655 .56277 L .41694 .5427 L p
1 g
F P
s
P
p
.002 w
.43845 .54718 m .43743 .5491 L p
.44397 .55478 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .43925 .54566 L p
.43376 .53479 L 1 g
F P
s
P
p
.002 w
.43445 .53575 m .45355 .55717 L p
.44255 .55282 L 1 g
F P
s
P
p
.43845 .54718 m .43445 .53575 L .44255 .55282 L 1 g
F
P
p
.002 w
.44859 .56114 m .45355 .55717 L p
.45067 .56342 L 1 g
F P
s
P
p
.44859 .56114 m .43743 .5491 L .45052 .56381 L 1 g
F
P
p
.44397 .55478 m .4382 .54976 L .44859 .56114 L 1 g
F
P
p
.4382 .54976 m .43743 .5491 L .44859 .56114 L 1 g
F
P
p
.002 w
.45052 .56381 m .45067 .56342 L p
.44859 .56114 L 1 g
F P
s
P
p
.45895 .56875 m .4589 .56873 L .46207 .57075 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57472 L p
1 g
F P
s
P
p
.4589 .56873 m .45002 .56518 L .46827 .57472 L 1 g
F
P
p
.002 w
.48122 .58057 m .47757 .57872 L .48577 .58068 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48894 .58226 L p
1 g
F P
s
P
p
.002 w
.48577 .58068 m .47757 .57872 L p
.51279 .58112 L 1 g
F P
s
P
p
.002 w
.48894 .58226 m .48905 .58073 L p
.48046 .57917 L 1 g
F P
s
P
p
.48046 .57917 m .4678 .57686 L .48894 .58226 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45052 .56381 L p
1 g
F P
s
P
p
.002 w
.43217 .52922 m .43146 .53025 L p
.43493 .53711 L 1 g
F P
s
P
p
.002 w
.44981 .52419 m .43276 .53057 L p
.42849 .5126 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43631 .54556 L p
.43376 .53479 L 1 g
F P
s
P
p
.002 w
.43631 .54556 m .43743 .5491 L p
.43376 .53479 L 1 g
F P
s
P
p
.002 w
.43408 .50918 m .43287 .51061 L p
.43319 .51947 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43237 .52893 L p
1 g
F P
s
P
p
.43319 .51947 m .43287 .51061 L .43237 .52893 L 1 g
F
P
p
.43842 .49992 m .43977 .49703 L .43878 .49907 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.47117 .48797 m .47252 .52203 L p
.44108 .49434 L 1 g
F P
s
P
p
.43878 .49907 m .44244 .49151 L .43978 .49674 L 1 g
F
P
p
.44222 .49199 m .44244 .49151 L .43878 .49907 L 1 g
F
P
p
.002 w
.44247 .49148 m .44244 .49151 L p
.44222 .49199 L 1 g
F P
s
P
p
.002 w
.47252 .52203 m .44981 .52419 L .43977 .49703 L p
1 g
F P
s
P
p
.44108 .49434 m .47252 .52203 L .43977 .49703 L 1 g
F
P
p
.002 w
.44278 .49083 m .43767 .49134 L p
.45148 .47374 L 1 g
F P
s
P
p
.002 w
.44244 .49151 m .44166 .49233 L p
.43978 .49674 L 1 g
F P
s
P
p
.002 w
.45781 .47657 m .45698 .47747 L p
.44961 .48454 L 1 g
F P
s
P
p
.42735 .4563 m .46585 .46875 L .45635 .47726 L 1 g
F
P
p
.45826 .47608 m .47746 .46733 L .46704 .47223 L 1 g
F
P
p
.45781 .47657 m .47094 .4704 L .45678 .47757 L 1 g
F
P
p
.002 w
.45727 .47716 m .45826 .47608 L p
.46874 .47148 L 1 g
F P
s
P
p
.46585 .46875 m .47094 .4704 L .45781 .47657 L 1 g
F
P
p
.46585 .46875 m .45781 .47657 L .45635 .47726 L 1 g
F
P
p
.45635 .47726 m .45781 .47657 L .45678 .47757 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44244 .49151 L p
1 g
F P
s
P
p
.002 w
.47746 .46733 m .47718 .46778 L p
.46704 .47223 L 1 g
F P
s
P
p
.002 w
.42735 .4563 m .4707 .45166 L .47094 .4704 L p
1 g
F P
s
P
p
.002 w
.47094 .4704 m .4707 .45166 L p
.48206 .46489 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45727 .47716 L p
1 g
F P
s
P
p
.46874 .47148 m .47718 .46778 L .45727 .47716 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .4671 L p
1 g
F P
s
P
p
.48615 .46583 m .5 .46442 L .4776 .4671 L 1 g
F
P
p
.51222 .46575 m .51345 .46595 L .51285 .46587 L 1 g
F
P
p
.002 w
.4707 .45166 m .51576 .45775 L .51345 .46595 L p
1 g
F P
s
P
p
.51945 .4657 m .52241 .46712 L .51996 .4668 L 1 g
F
P
p
.002 w
.52241 .46712 m .52282 .46778 L p
.51285 .46587 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52241 .46712 L p
1 g
F P
s
P
p
.002 w
.52241 .46712 m .52214 .46667 L p
.53033 .47091 L 1 g
F P
s
P
p
.53033 .47091 m .54302 .47747 L .52241 .46712 L 1 g
F
P
p
.002 w
.51576 .45775 m .5276 .46238 L p
.52953 .47053 L 1 g
F P
s
P
p
.51576 .45775 m .52953 .47053 L .51945 .4657 L 1 g
F
P
p
.5276 .46238 m .54221 .4766 L .52953 .47053 L 1 g
F
P
p
.002 w
.54221 .4766 m .54302 .47747 L p
.53033 .47091 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54221 .4766 L p
1 g
F P
s
P
p
.002 w
.54221 .4766 m .54174 .47608 L p
.55075 .4849 L 1 g
F P
s
P
p
.55075 .4849 m .55834 .49233 L .54221 .4766 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5276 .46238 m .55676 .47378 L .55024 .4844 L p
1 g
F P
s
P
p
.002 w
.55024 .4844 m .55676 .47378 L p
.55899 .49286 L 1 g
F P
s
P
p
.002 w
.55722 .49115 m .55834 .49233 L p
.55048 .48464 L 1 g
F P
s
P
p
.002 w
.5659 .50915 m .56713 .51061 L p
.56043 .4978 L 1 g
F P
s
P
p
.002 w
.56643 .50979 m .5659 .50915 L p
.56694 .5187 L 1 g
F P
s
P
p
.002 w
.56752 .52877 m .56654 .52734 L p
.56726 .52977 L 1 g
F P
s
P
p
.002 w
.56726 .52977 m .56252 .52301 L .57131 .51444 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56643 .50979 L p
1 g
F P
s
P
p
.56705 .5206 m .56854 .53025 L .56643 .50979 L 1 g
F
P
p
.002 w
.56752 .52877 m .56854 .53025 L p
.56705 .5206 L 1 g
F P
s
P
p
.002 w
.56757 .52884 m .56752 .52877 L p
.56726 .52977 L 1 g
F P
s
P
p
.002 w
.56252 .52301 m .56726 .52977 L p
.54525 .56015 L 1 g
F P
s
P
p
.002 w
.56726 .52977 m .57053 .53444 L p
.56324 .54186 L 1 g
F P
s
P
p
.56726 .52977 m .56324 .54186 L .54525 .56015 L 1 g
F
P
p
.002 w
.5615 .54708 m .56075 .54566 L p
.55571 .5552 L 1 g
F P
s
P
p
.002 w
.55571 .5552 m .54525 .56015 L p
.57053 .53444 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56757 .52884 L p
1 g
F P
s
P
p
.56468 .53752 m .56257 .5491 L .56757 .52884 L 1 g
F
P
p
.002 w
.5615 .54708 m .56257 .5491 L p
.56468 .53752 L 1 g
F P
s
P
p
.002 w
.56177 .54759 m .5615 .54708 L p
.55571 .5552 L 1 g
F P
s
P
p
.002 w
.54637 .56551 m .54525 .56015 L .55571 .5552 L p
1 g
F P
s
P
p
.002 w
.55571 .5552 m .5659 .55036 L p
.54927 .56326 L 1 g
F P
s
P
p
.54927 .56326 m .54637 .56551 L .55571 .5552 L 1 g
F
P
p
.002 w
.5659 .55036 m .57775 .54474 L p
.54637 .56551 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56177 .54759 L p
1 g
F P
s
P
p
.55501 .55607 m .54998 .56518 L .56177 .54759 L 1 g
F
P
p
.002 w
.54927 .56326 m .54998 .56518 L p
.55501 .55607 L 1 g
F P
s
P
p
.002 w
.5466 .56661 m .54637 .56551 L p
.54871 .56396 L 1 g
F P
s
P
p
.002 w
.54941 .56364 m .54927 .56326 L p
.54637 .56551 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54941 .56364 L p
1 g
F P
s
P
p
.54001 .56942 m .5322 .57686 L .54941 .56364 L 1 g
F
P
p
.002 w
.54525 .56015 m .54637 .56551 L p
.51326 .57938 L 1 g
F P
s
P
p
.54637 .56551 m .53364 .57334 L .51326 .57938 L 1 g
F
P
p
.002 w
.53169 .57453 m .5322 .57686 L p
.54001 .56942 L 1 g
F P
s
P
p
.51976 .57856 m .51921 .57873 L .51713 .57991 L 1 g
F
P
p
.51921 .57873 m .5129 .58072 L .51384 .58054 L 1 g
F
P
p
.51921 .57873 m .51384 .58054 L .51713 .57991 L 1 g
F
P
p
.002 w
.5129 .58072 m .51326 .57938 L .51921 .57873 L p
1 g
F P
s
P
p
.002 w
.51326 .57938 m .51279 .58112 L p
.48127 .57898 L 1 g
F P
s
P
p
.002 w
.51097 .58109 m .51111 .583 L p
.51713 .57991 L 1 g
F P
s
P
p
.47425 .57739 m .4678 .57686 L .48905 .58073 L 1 g
F
P
p
.002 w
.48038 .57878 m .51326 .57938 L p
.48127 .57898 L 1 g
F P
s
P
p
.002 w
.51099 .58127 m .51097 .58109 L p
.49895 .58099 L 1 g
F P
s
P
p
.49937 .5809 m .49895 .58099 L .51097 .58109 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51099 .58127 L p
1 g
F P
s
P
p
.49895 .58099 m .48889 .583 L .51099 .58127 L 1 g
F
P
p
.002 w
.41694 .5427 m .4103 .55674 L .38056 .54003 L p
1 g
F P
s
P
p
.002 w
.38056 .54003 m .38982 .51921 L .41694 .5427 L p
1 g
F P
s
P
p
.002 w
.47759 .31239 m .41089 .32107 L .4135 .29469 L p
1 g
F P
s
P
p
.002 w
.4135 .29469 m .48111 .28559 L .47759 .31239 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.57775 .54474 m .58197 .56743 L .54848 .57556 L p
1 g
F P
s
P
p
.002 w
.58197 .56743 m .57775 .54474 L .60777 .52593 L p
1 g
F P
s
P
p
.002 w
.55161 .29498 m .61516 .32159 L .60994 .34768 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.39114 .47085 m .36617 .49317 L .3468 .46554 L p
1 g
F P
s
P
p
.002 w
.3468 .46554 m .37619 .43832 L .39114 .47085 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.44655 .56277 m .44301 .56981 L .4103 .55674 L p
1 g
F P
s
P
p
.002 w
.4103 .55674 m .41694 .5427 L .44655 .56277 L p
1 g
F P
s
P
p
.002 w
.61193 .47014 m .63425 .50444 L .60777 .52593 L p
1 g
F P
s
P
p
.002 w
.63425 .50444 m .61193 .47014 L .63159 .44177 L p
1 g
F P
s
P
p
.002 w
.41375 .38502 m .36515 .4059 L .35836 .37476 L p
1 g
F P
s
P
p
.002 w
.35836 .37476 m .41094 .35151 L .41375 .38502 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51326 .57938 m .51144 .57161 L .54525 .56015 L p
1 g
F P
s
P
p
.002 w
.60119 .37701 m .64696 .41353 L .63159 .44177 L p
1 g
F P
s
P
p
.002 w
.64696 .41353 m .60119 .37701 L .60994 .34768 L p
1 g
F P
s
P
p
.002 w
.40949 .50226 m .38982 .51921 L .36617 .49317 L p
1 g
F P
s
P
p
.002 w
.36617 .49317 m .39114 .47085 L .40949 .50226 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.54716 .32168 m .47759 .31239 L .48111 .28559 L p
1 g
F P
s
P
p
.002 w
.48111 .28559 m .55161 .29498 L .54716 .32168 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60994 .34768 m .54716 .32168 L .55161 .29498 L p
1 g
F P
s
P
p
.002 w
.58862 .49757 m .60777 .52593 L .57775 .54474 L p
1 g
F P
s
P
p
.002 w
.60777 .52593 m .58862 .49757 L .61193 .47014 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.51144 .57161 m .50593 .5643 L .5346 .54553 L p
1 g
F P
s
P
p
.002 w
.5346 .54553 m .54525 .56015 L .51144 .57161 L p
1 g
F P
s
P
p
.002 w
.43057 .53139 m .41694 .5427 L .38982 .51921 L p
1 g
F P
s
P
p
.002 w
.38982 .51921 m .40949 .50226 L .43057 .53139 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.47467 .34354 m .41094 .35151 L .41089 .32107 L p
1 g
F P
s
P
p
.002 w
.41089 .32107 m .47759 .31239 L .47467 .34354 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.54716 .32168 m .60994 .34768 L .60119 .37701 L p
1 g
F P
s
P
p
.002 w
.54525 .56015 m .5346 .54553 L .56252 .52301 L p
1 g
F P
s
P
p
.002 w
.41928 .4204 m .37619 .43832 L .36515 .4059 L p
1 g
F P
s
P
p
.002 w
.36515 .4059 m .41375 .38502 L .41928 .4204 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50593 .5643 m .49729 .55828 L .51757 .53339 L p
1 g
F P
s
P
p
.002 w
.51757 .53339 m .5346 .54553 L .50593 .5643 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.58914 .40858 m .63159 .44177 L .61193 .47014 L p
1 g
F P
s
P
p
.002 w
.63159 .44177 m .58914 .40858 L .60119 .37701 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.47469 .55262 m .46329 .55365 L .44981 .52419 L p
1 g
F P
s
P
p
.002 w
.49729 .55828 m .48647 .55423 L .49604 .52523 L p
1 g
F P
s
P
p
.002 w
.49604 .52523 m .51757 .53339 L .49729 .55828 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48647 .55423 m .47469 .55262 L .47252 .52203 L p
1 g
F P
s
P
p
.002 w
.44981 .52419 m .47252 .52203 L .47469 .55262 L p
1 g
F P
s
P
p
.002 w
.47252 .52203 m .49604 .52523 L .48647 .55423 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42735 .4563 m .39114 .47085 L .37619 .43832 L p
1 g
F P
s
P
p
.002 w
.37619 .43832 m .41928 .4204 L .42735 .4563 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.54114 .35244 m .47467 .34354 L .47759 .31239 L p
1 g
F P
s
P
p
.002 w
.47759 .31239 m .54716 .32168 L .54114 .35244 L p
1 g
F P
s
P
p
.002 w
.5346 .54553 m .51757 .53339 L .53765 .50489 L p
1 g
F P
s
P
p
.002 w
.53765 .50489 m .56252 .52301 L .5346 .54553 L p
1 g
F P
s
P
p
.002 w
.47249 .37802 m .41375 .38502 L .41094 .35151 L p
1 g
F P
s
P
p
.002 w
.41094 .35151 m .47467 .34354 L .47249 .37802 L p
1 g
F P
s
P
p
.002 w
.57415 .44126 m .61193 .47014 L .58862 .49757 L p
1 g
F P
s
P
p
.002 w
.61193 .47014 m .57415 .44126 L .58914 .40858 L p
1 g
F P
s
P
p
.002 w
.60119 .37701 m .54114 .35244 L .54716 .32168 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43767 .49134 m .40949 .50226 L .39114 .47085 L p
1 g
F P
s
P
p
.002 w
.39114 .47085 m .42735 .4563 L .43767 .49134 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54114 .35244 m .60119 .37701 L .58914 .40858 L p
1 g
F P
s
P
p
.002 w
.58862 .49757 m .55676 .47378 L .57415 .44126 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51757 .53339 m .49604 .52523 L .50593 .49267 L p
1 g
F P
s
P
p
.002 w
.50593 .49267 m .53765 .50489 L .51757 .53339 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.47114 .41453 m .41928 .4204 L .41375 .38502 L p
1 g
F P
s
P
p
.002 w
.41375 .38502 m .47249 .37802 L .47114 .41453 L p
1 g
F P
s
P
p
.002 w
.49604 .52523 m .47252 .52203 L .47117 .48797 L p
1 g
F P
s
P
p
.002 w
.47117 .48797 m .50593 .49267 L .49604 .52523 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.004 w
.46844 .63901 m
.47005 .62841 L
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.53371 .38623 m .58914 .40858 L .57415 .44126 L p
1 g
F P
s
P
p
.002 w
.58914 .40858 m .53371 .38623 L .54114 .35244 L p
1 g
F P
s
P
p
.002 w
.53371 .38623 m .47249 .37802 L .47467 .34354 L p
1 g
F P
s
P
p
.002 w
.47467 .34354 m .54114 .35244 L .53371 .38623 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.4707 .45166 m .42735 .4563 L .41928 .4204 L p
1 g
F P
s
P
p
.002 w
.41928 .4204 m .47114 .41453 L .4707 .45166 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52514 .42179 m .57415 .44126 L .55676 .47378 L p
1 g
F P
s
P
p
.002 w
.57415 .44126 m .52514 .42179 L .53371 .38623 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.55676 .47378 m .51576 .45775 L .52514 .42179 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52514 .42179 m .47114 .41453 L .47249 .37802 L p
1 g
F P
s
P
p
.002 w
.47249 .37802 m .53371 .38623 L .52514 .42179 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51576 .45775 m .4707 .45166 L .47114 .41453 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47114 .41453 m .52514 .42179 L .51576 .45775 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .228 .54717 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .46449 .66511 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.40155)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.40155)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46174 .43458 m .4993 .45311 L .50867 .42613 L p
1 g
F P
s
P
p
.002 w
.50867 .42613 m .47736 .41064 L .46174 .43458 L p
1 g
F P
s
P
p
.002 w
.54269 .4332 m .50867 .42613 L .4993 .45311 L p
1 g
F P
s
P
p
.002 w
.47736 .41064 m .50867 .42613 L .51785 .39922 L p
1 g
F P
s
P
p
.002 w
.50867 .42613 m .54269 .4332 L .54428 .40463 L p
1 g
F P
s
P
p
.002 w
.54428 .40463 m .51785 .39922 L .50867 .42613 L p
1 g
F P
s
P
p
.002 w
.44696 .45855 m .48991 .47967 L .4993 .45311 L p
1 g
F P
s
P
p
.002 w
.4993 .45311 m .46174 .43458 L .44696 .45855 L p
1 g
F P
s
P
p
.002 w
.54008 .4617 m .4993 .45311 L .48991 .47967 L p
1 g
F P
s
P
p
.002 w
.4993 .45311 m .54008 .4617 L .54269 .4332 L p
1 g
F P
s
P
p
.002 w
.43083 .40775 m .46174 .43458 L .47736 .41064 L p
1 g
F P
s
P
p
.002 w
.47736 .41064 m .45172 .38814 L .43083 .40775 L p
1 g
F P
s
P
p
.002 w
.45172 .38814 m .47736 .41064 L .49355 .38715 L p
1 g
F P
s
P
p
.002 w
.51785 .39922 m .49355 .38715 L .47736 .41064 L p
1 g
F P
s
P
p
.002 w
.49355 .38715 m .51785 .39922 L .52666 .37285 L p
1 g
F P
s
P
p
.002 w
.51785 .39922 m .54428 .40463 L .54479 .37652 L p
1 g
F P
s
P
p
.002 w
.54479 .37652 m .52666 .37285 L .51785 .39922 L p
1 g
F P
s
P
p
.002 w
.41147 .42807 m .44696 .45855 L .46174 .43458 L p
1 g
F P
s
P
p
.002 w
.46174 .43458 m .43083 .40775 L .41147 .42807 L p
1 g
F P
s
P
p
.002 w
.57622 .43109 m .54269 .4332 L .54008 .4617 L p
1 g
F P
s
P
p
.002 w
.54269 .4332 m .57622 .43109 L .57026 .40282 L p
1 g
F P
s
P
p
.002 w
.57026 .40282 m .54428 .40463 L .54269 .4332 L p
1 g
F P
s
P
p
.002 w
.49355 .38715 m .47375 .36959 L .45172 .38814 L p
1 g
F P
s
P
p
.002 w
.47375 .36959 m .49355 .38715 L .51001 .36456 L p
1 g
F P
s
P
p
.002 w
.52666 .37285 m .51001 .36456 L .49355 .38715 L p
1 g
F P
s
P
p
.002 w
.4333 .48211 m .48065 .50532 L .48991 .47967 L p
1 g
F P
s
P
p
.002 w
.48991 .47967 m .44696 .45855 L .4333 .48211 L p
1 g
F P
s
P
p
.002 w
.53647 .48961 m .48991 .47967 L .48065 .50532 L p
1 g
F P
s
P
p
.002 w
.48991 .47967 m .53647 .48961 L .54008 .4617 L p
1 g
F P
s
P
p
.002 w
.58034 .45944 m .54008 .4617 L .53647 .48961 L p
1 g
F P
s
P
p
.002 w
.54008 .4617 m .58034 .45944 L .57622 .43109 L p
1 g
F P
s
P
p
.002 w
.54428 .40463 m .57026 .40282 L .56257 .37515 L p
1 g
F P
s
P
p
.002 w
.56257 .37515 m .54479 .37652 L .54428 .40463 L p
1 g
F P
s
P
p
.002 w
.39403 .44873 m .4333 .48211 L .44696 .45855 L p
1 g
F P
s
P
p
.002 w
.44696 .45855 m .41147 .42807 L .39403 .44873 L p
1 g
F P
s
P
p
.002 w
.51001 .36456 m .52666 .37285 L .53495 .34753 L p
1 g
F P
s
P
p
.002 w
.52666 .37285 m .54479 .37652 L .54422 .34938 L p
1 g
F P
s
P
p
.002 w
.54422 .34938 m .53495 .34753 L .52666 .37285 L p
1 g
F P
s
P
p
.002 w
.40963 .37494 m .43083 .40775 L .45172 .38814 L p
1 g
F P
s
P
p
.002 w
.45172 .38814 m .43433 .36066 L .40963 .37494 L p
1 g
F P
s
P
p
.002 w
.43433 .36066 m .45172 .38814 L .47375 .36959 L p
1 g
F P
s
P
p
.002 w
.47375 .36959 m .46048 .34819 L .43433 .36066 L p
1 g
F P
s
P
p
.002 w
.46048 .34819 m .47375 .36959 L .49651 .35246 L p
1 g
F P
s
P
p
.002 w
.51001 .36456 m .49651 .35246 L .47375 .36959 L p
1 g
F P
s
P
p
.002 w
.49651 .35246 m .51001 .36456 L .52644 .34328 L p
1 g
F P
s
P
p
.002 w
.53495 .34753 m .52644 .34328 L .51001 .36456 L p
1 g
F P
s
P
p
.002 w
.48065 .50532 m .53192 .51641 L .53647 .48961 L p
1 g
F P
s
P
p
.002 w
.58251 .48733 m .53647 .48961 L .53192 .51641 L p
1 g
F P
s
P
p
.002 w
.53647 .48961 m .58251 .48733 L .58034 .45944 L p
1 g
F P
s
P
p
.002 w
.54479 .37652 m .56257 .37515 L .55328 .34863 L p
1 g
F P
s
P
p
.002 w
.55328 .34863 m .54422 .34938 L .54479 .37652 L p
1 g
F P
s
P
p
.002 w
.38688 .39077 m .41147 .42807 L .43083 .40775 L p
1 g
F P
s
P
p
.002 w
.43083 .40775 m .40963 .37494 L .38688 .39077 L p
1 g
F P
s
P
p
.002 w
.5932 .39382 m .57026 .40282 L .57622 .43109 L p
1 g
F P
s
P
p
.002 w
.57026 .40282 m .5932 .39382 L .57817 .36884 L p
1 g
F P
s
P
p
.002 w
.57817 .36884 m .56257 .37515 L .57026 .40282 L p
1 g
F P
s
P
p
.002 w
.60598 .41978 m .57622 .43109 L .58034 .45944 L p
1 g
F P
s
P
p
.002 w
.57622 .43109 m .60598 .41978 L .5932 .39382 L p
1 g
F P
s
P
p
.002 w
.42106 .50482 m .47171 .52957 L .48065 .50532 L p
1 g
F P
s
P
p
.002 w
.48065 .50532 m .4333 .48211 L .42106 .50482 L p
1 g
F P
s
P
p
.002 w
.53192 .51641 m .48065 .50532 L .47171 .52957 L p
1 g
F P
s
P
p
.002 w
.49651 .35246 m .48758 .33775 L .46048 .34819 L p
1 g
F P
s
P
p
.002 w
.48758 .33775 m .49651 .35246 L .51958 .33707 L p
1 g
F P
s
P
p
.002 w
.52644 .34328 m .51958 .33707 L .49651 .35246 L p
1 g
F P
s
P
p
.002 w
.56257 .37515 m .57817 .36884 L .56117 .34533 L p
1 g
F P
s
P
p
.002 w
.56117 .34533 m .55328 .34863 L .56257 .37515 L p
1 g
F P
s
P
p
.002 w
.3789 .46933 m .42106 .50482 L .4333 .48211 L p
1 g
F P
s
P
p
.002 w
.4333 .48211 m .39403 .44873 L .3789 .46933 L p
1 g
F P
s
P
p
.002 w
.61625 .44623 m .58034 .45944 L .58251 .48733 L p
1 g
F P
s
P
p
.002 w
.58034 .45944 m .61625 .44623 L .60598 .41978 L p
1 g
F P
s
P
p
.002 w
.36659 .40787 m .39403 .44873 L .41147 .42807 L p
1 g
F P
s
P
p
.002 w
.41147 .42807 m .38688 .39077 L .36659 .40787 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .52644 .34328 L .53495 .34753 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .53495 .34753 L .54422 .34938 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .51958 .33707 L .52644 .34328 L closepath p
1 g
F P
s
P
p
.002 w
.42717 .33079 m .43433 .36066 L .46048 .34819 L p
1 g
F P
s
P
p
.002 w
.46048 .34819 m .45524 .32503 L .42717 .33079 L p
1 g
F P
s
P
p
.002 w
.45524 .32503 m .46048 .34819 L .48758 .33775 L p
1 g
F P
s
P
p
.002 w
.47171 .52957 m .5265 .54157 L .53192 .51641 L p
1 g
F P
s
P
p
.002 w
.58267 .51423 m .53192 .51641 L .5265 .54157 L p
1 g
F P
s
P
p
.002 w
.53192 .51641 m .58267 .51423 L .58251 .48733 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .54422 .34938 L .55328 .34863 L closepath p
1 g
F P
s
P
p
.002 w
.48758 .33775 m .48421 .32191 L .45524 .32503 L p
1 g
F P
s
P
p
.002 w
.48421 .32191 m .48758 .33775 L .5151 .32954 L p
1 g
F P
s
P
p
.002 w
.51958 .33707 m .5151 .32954 L .48758 .33775 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .5151 .32954 L .51958 .33707 L closepath p
1 g
F P
s
P
p
.002 w
.40058 .33914 m .40963 .37494 L .43433 .36066 L p
1 g
F P
s
P
p
.002 w
.43433 .36066 m .42717 .33079 L .40058 .33914 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .55328 .34863 L .56117 .34533 L closepath p
1 g
F P
s
P
p
.002 w
.58991 .35814 m .57817 .36884 L .5932 .39382 L p
1 g
F P
s
P
p
.002 w
.57817 .36884 m .58991 .35814 L .56705 .33982 L p
1 g
F P
s
P
p
.002 w
.56705 .33982 m .56117 .34533 L .57817 .36884 L p
1 g
F P
s
P
p
.002 w
.61066 .37836 m .5932 .39382 L .60598 .41978 L p
1 g
F P
s
P
p
.002 w
.5932 .39382 m .61066 .37836 L .58991 .35814 L p
1 g
F P
s
P
p
.002 w
.62374 .47265 m .58251 .48733 L .58267 .51423 L p
1 g
F P
s
P
p
.002 w
.58251 .48733 m .62374 .47265 L .61625 .44623 L p
1 g
F P
s
P
p
.002 w
.5151 .32954 m .5135 .32148 L .48421 .32191 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .5135 .32148 L .5151 .32954 L closepath p
1 g
F P
s
P
p
.002 w
.4105 .52619 m .46327 .55191 L .47171 .52957 L p
1 g
F P
s
P
p
.002 w
.47171 .52957 m .42106 .50482 L .4105 .52619 L p
1 g
F P
s
P
p
.002 w
.5265 .54157 m .47171 .52957 L .46327 .55191 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .56117 .34533 L .56705 .33982 L closepath p
1 g
F P
s
P
p
.002 w
.37604 .34994 m .38688 .39077 L .40963 .37494 L p
1 g
F P
s
P
p
.002 w
.40963 .37494 m .40058 .33914 L .37604 .34994 L p
1 g
F P
s
P
p
.002 w
.62884 .40009 m .60598 .41978 L .61625 .44623 L p
1 g
F P
s
P
p
.002 w
.60598 .41978 m .62884 .40009 L .61066 .37836 L p
1 g
F P
s
P
p
.002 w
.34924 .42591 m .3789 .46933 L .39403 .44873 L p
1 g
F P
s
P
p
.002 w
.39403 .44873 m .36659 .40787 L .34924 .42591 L p
1 g
F P
s
P
p
.002 w
.36647 .48945 m .4105 .52619 L .42106 .50482 L p
1 g
F P
s
P
p
.002 w
.42106 .50482 m .3789 .46933 L .36647 .48945 L p
1 g
F P
s
P
p
.002 w
.45884 .30247 m .45524 .32503 L .48421 .32191 L p
1 g
F P
s
P
p
.002 w
.48421 .32191 m .48689 .30659 L .45884 .30247 L p
1 g
F P
s
P
p
.002 w
.48689 .30659 m .48421 .32191 L .5135 .32148 L p
1 g
F P
s
P
p
.002 w
.5135 .32148 m .51497 .31375 L .48689 .30659 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .51497 .31375 L .5135 .32148 L closepath p
1 g
F P
s
P
p
.002 w
.57026 .33267 m .56705 .33982 L .58991 .35814 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .56705 .33982 L .57026 .33267 L closepath p
1 g
F P
s
P
p
.002 w
.46327 .55191 m .52029 .56453 L .5265 .54157 L p
1 g
F P
s
P
p
.002 w
.58076 .53956 m .5265 .54157 L .52029 .56453 L p
1 g
F P
s
P
p
.002 w
.5265 .54157 m .58076 .53956 L .58267 .51423 L p
1 g
F P
s
P
p
.002 w
.43141 .30153 m .42717 .33079 L .45524 .32503 L p
1 g
F P
s
P
p
.002 w
.45524 .32503 m .45884 .30247 L .43141 .30153 L p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .57026 .33267 L .57041 .32463 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .57041 .32463 L .56746 .31659 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .56746 .31659 L .5617 .30942 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .5617 .30942 L .55376 .30395 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .55376 .30395 L .54452 .3008 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .54452 .3008 L .53503 .30031 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .53503 .30031 L .52633 .30252 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .52633 .30252 L .5194 .30718 L closepath p
1 g
F P
s
P
p
.002 w
.54253 .32376 m .5194 .30718 L .51497 .31375 L closepath p
1 g
F P
s
P
p
.002 w
.59647 .34411 m .58991 .35814 L .61066 .37836 L p
1 g
F P
s
P
p
.002 w
.58991 .35814 m .59647 .34411 L .57026 .33267 L p
1 g
F P
s
P
p
.002 w
.64405 .42292 m .61625 .44623 L .62374 .47265 L p
1 g
F P
s
P
p
.002 w
.61625 .44623 m .64405 .42292 L .62884 .40009 L p
1 g
F P
s
P
p
.002 w
.62824 .49849 m .58267 .51423 L .58076 .53956 L p
1 g
F P
s
P
p
.002 w
.58267 .51423 m .62824 .49849 L .62374 .47265 L p
1 g
F P
s
P
p
.002 w
.49546 .29348 m .48689 .30659 L .51497 .31375 L p
1 g
F P
s
P
p
.002 w
.51497 .31375 m .5194 .30718 L .49546 .29348 L p
1 g
F P
s
P
p
.002 w
.35415 .36304 m .36659 .40787 L .38688 .39077 L p
1 g
F P
s
P
p
.002 w
.38688 .39077 m .37604 .34994 L .35415 .36304 L p
1 g
F P
s
P
p
.002 w
.57041 .32463 m .57026 .33267 L .59647 .34411 L p
1 g
F P
s
P
p
.002 w
.6206 .35788 m .61066 .37836 L .62884 .40009 L p
1 g
F P
s
P
p
.002 w
.61066 .37836 m .6206 .35788 L .59647 .34411 L p
1 g
F P
s
P
p
.002 w
.4052 .30387 m .40058 .33914 L .42717 .33079 L p
1 g
F P
s
P
p
.002 w
.42717 .33079 m .43141 .30153 L .4052 .30387 L p
1 g
F P
s
P
p
.002 w
.4712 .283 m .45884 .30247 L .48689 .30659 L p
1 g
F P
s
P
p
.002 w
.48689 .30659 m .49546 .29348 L .4712 .283 L p
1 g
F P
s
P
p
.002 w
.50912 .28408 m .49546 .29348 L .5194 .30718 L p
1 g
F P
s
P
p
.002 w
.5194 .30718 m .52633 .30252 L .50912 .28408 L p
1 g
F P
s
P
p
.002 w
.40192 .54574 m .45553 .5718 L .46327 .55191 L p
1 g
F P
s
P
p
.002 w
.46327 .55191 m .4105 .52619 L .40192 .54574 L p
1 g
F P
s
P
p
.002 w
.52029 .56453 m .46327 .55191 L .45553 .5718 L p
1 g
F P
s
P
p
.002 w
.59647 .34411 m .59699 .32819 L .57041 .32463 L p
1 g
F P
s
P
p
.002 w
.56746 .31659 m .57041 .32463 L .59699 .32819 L p
1 g
F P
s
P
p
.002 w
.33531 .44455 m .36647 .48945 L .3789 .46933 L p
1 g
F P
s
P
p
.002 w
.3789 .46933 m .34924 .42591 L .33531 .44455 L p
1 g
F P
s
P
p
.002 w
.59699 .32819 m .59647 .34411 L .6206 .35788 L p
1 g
F P
s
P
p
.002 w
.52643 .27954 m .50912 .28408 L .52633 .30252 L p
1 g
F P
s
P
p
.002 w
.52633 .30252 m .53503 .30031 L .52643 .27954 L p
1 g
F P
s
P
p
.002 w
.65587 .44638 m .62374 .47265 L .62824 .49849 L p
1 g
F P
s
P
p
.002 w
.62374 .47265 m .65587 .44638 L .64405 .42292 L p
1 g
F P
s
P
p
.002 w
.3571 .50864 m .40192 .54574 L .4105 .52619 L p
1 g
F P
s
P
p
.002 w
.4105 .52619 m .36647 .48945 L .3571 .50864 L p
1 g
F P
s
P
p
.002 w
.64209 .37374 m .62884 .40009 L .64405 .42292 L p
1 g
F P
s
P
p
.002 w
.62884 .40009 m .64209 .37374 L .6206 .35788 L p
1 g
F P
s
P
p
.002 w
.59699 .32819 m .59127 .31214 L .56746 .31659 L p
1 g
F P
s
P
p
.002 w
.5617 .30942 m .56746 .31659 L .59127 .31214 L p
1 g
F P
s
P
p
.002 w
.44712 .27608 m .43141 .30153 L .45884 .30247 L p
1 g
F P
s
P
p
.002 w
.45884 .30247 m .4712 .283 L .44712 .27608 L p
1 g
F P
s
P
p
.002 w
.54544 .28045 m .52643 .27954 L .53503 .30031 L p
1 g
F P
s
P
p
.002 w
.53503 .30031 m .54452 .3008 L .54544 .28045 L p
1 g
F P
s
P
p
.002 w
.38083 .30954 m .37604 .34994 L .40058 .33914 L p
1 g
F P
s
P
p
.002 w
.40058 .33914 m .4052 .30387 L .38083 .30954 L p
1 g
F P
s
P
p
.002 w
.3355 .37823 m .34924 .42591 L .36659 .40787 L p
1 g
F P
s
P
p
.002 w
.36659 .40787 m .35415 .36304 L .3355 .37823 L p
1 g
F P
s
P
p
.002 w
.45553 .5718 m .51338 .58474 L .52029 .56453 L p
1 g
F P
s
P
p
.002 w
.57674 .56276 m .52029 .56453 L .51338 .58474 L p
1 g
F P
s
P
p
.002 w
.52029 .56453 m .57674 .56276 L .58076 .53956 L p
1 g
F P
s
P
p
.002 w
.62957 .5232 m .58076 .53956 L .57674 .56276 L p
1 g
F P
s
P
p
.002 w
.58076 .53956 m .62957 .5232 L .62824 .49849 L p
1 g
F P
s
P
p
.002 w
.59127 .31214 m .57985 .29777 L .5617 .30942 L p
1 g
F P
s
P
p
.002 w
.55376 .30395 m .5617 .30942 L .57985 .29777 L p
1 g
F P
s
P
p
.002 w
.49123 .26892 m .4712 .283 L .49546 .29348 L p
1 g
F P
s
P
p
.002 w
.49546 .29348 m .50912 .28408 L .49123 .26892 L p
1 g
F P
s
P
p
.002 w
.56396 .28677 m .54544 .28045 L .54452 .3008 L p
1 g
F P
s
P
p
.002 w
.54452 .3008 m .55376 .30395 L .56396 .28677 L p
1 g
F P
s
P
p
.002 w
.57985 .29777 m .56396 .28677 L .55376 .30395 L p
1 g
F P
s
P
p
.002 w
.62165 .33444 m .6206 .35788 L .64209 .37374 L p
1 g
F P
s
P
p
.002 w
.6206 .35788 m .62165 .33444 L .59699 .32819 L p
1 g
F P
s
P
p
.002 w
.59127 .31214 m .59699 .32819 L .62165 .33444 L p
1 g
F P
s
P
p
.002 w
.6604 .39142 m .64405 .42292 L .65587 .44638 L p
1 g
F P
s
P
p
.002 w
.64405 .42292 m .6604 .39142 L .64209 .37374 L p
1 g
F P
s
P
p
.002 w
.66394 .46999 m .62824 .49849 L .62957 .5232 L p
1 g
F P
s
P
p
.002 w
.62824 .49849 m .66394 .46999 L .65587 .44638 L p
1 g
F P
s
P
p
.002 w
.32528 .46339 m .3571 .50864 L .36647 .48945 L p
1 g
F P
s
P
p
.002 w
.36647 .48945 m .33531 .44455 L .32528 .46339 L p
1 g
F P
s
P
p
.002 w
.42378 .273 m .4052 .30387 L .43141 .30153 L p
1 g
F P
s
P
p
.002 w
.43141 .30153 m .44712 .27608 L .42378 .273 L p
1 g
F P
s
P
p
.002 w
.51687 .26202 m .49123 .26892 L .50912 .28408 L p
1 g
F P
s
P
p
.002 w
.50912 .28408 m .52643 .27954 L .51687 .26202 L p
1 g
F P
s
P
p
.002 w
.35893 .31854 m .35415 .36304 L .37604 .34994 L p
1 g
F P
s
P
p
.002 w
.37604 .34994 m .38083 .30954 L .35893 .31854 L p
1 g
F P
s
P
p
.002 w
.39558 .56297 m .44867 .58872 L .45553 .5718 L p
1 g
F P
s
P
p
.002 w
.45553 .5718 m .40192 .54574 L .39558 .56297 L p
1 g
F P
s
P
p
.002 w
.51338 .58474 m .45553 .5718 L .44867 .58872 L p
1 g
F P
s
P
p
.002 w
.62165 .33444 m .6134 .31061 L .59127 .31214 L p
1 g
F P
s
P
p
.002 w
.57985 .29777 m .59127 .31214 L .6134 .31061 L p
1 g
F P
s
P
p
.002 w
.47304 .25752 m .44712 .27608 L .4712 .283 L p
1 g
F P
s
P
p
.002 w
.4712 .283 m .49123 .26892 L .47304 .25752 L p
1 g
F P
s
P
p
.002 w
.32064 .39524 m .33531 .44455 L .34924 .42591 L p
1 g
F P
s
P
p
.002 w
.34924 .42591 m .3355 .37823 L .32064 .39524 L p
1 g
F P
s
P
p
.002 w
.35116 .52644 m .39558 .56297 L .40192 .54574 L p
1 g
F P
s
P
p
.002 w
.40192 .54574 m .3571 .50864 L .35116 .52644 L p
1 g
F P
s
P
p
.002 w
.51338 .58474 m .57062 .58322 L .57674 .56276 L p
1 g
F P
s
P
p
.002 w
.62756 .54617 m .57674 .56276 L .57062 .58322 L p
1 g
F P
s
P
p
.002 w
.57674 .56276 m .62756 .54617 L .62957 .5232 L p
1 g
F P
s
P
p
.002 w
.6438 .34333 m .64209 .37374 L .6604 .39142 L p
1 g
F P
s
P
p
.002 w
.64209 .37374 m .6438 .34333 L .62165 .33444 L p
1 g
F P
s
P
p
.002 w
.5452 .2633 m .51687 .26202 L .52643 .27954 L p
1 g
F P
s
P
p
.002 w
.52643 .27954 m .54544 .28045 L .5452 .2633 L p
1 g
F P
s
P
p
.002 w
.44867 .58872 m .50589 .60162 L .51338 .58474 L p
1 g
F P
s
P
p
.002 w
.57062 .58322 m .51338 .58474 L .50589 .60162 L p
1 g
F P
s
P
p
.002 w
.6134 .31061 m .59652 .28917 L .57985 .29777 L p
1 g
F P
s
P
p
.002 w
.56396 .28677 m .57985 .29777 L .59652 .28917 L p
1 g
F P
s
P
p
.002 w
.6134 .31061 m .62165 .33444 L .6438 .34333 L p
1 g
F P
s
P
p
.002 w
.67499 .41058 m .65587 .44638 L .66394 .46999 L p
1 g
F P
s
P
p
.002 w
.65587 .44638 m .67499 .41058 L .6604 .39142 L p
1 g
F P
s
P
p
.002 w
.57286 .27272 m .5452 .2633 L .54544 .28045 L p
1 g
F P
s
P
p
.002 w
.54544 .28045 m .56396 .28677 L .57286 .27272 L p
1 g
F P
s
P
p
.002 w
.59652 .28917 m .57286 .27272 L .56396 .28677 L p
1 g
F P
s
P
p
.002 w
.40175 .27399 m .38083 .30954 L .4052 .30387 L p
1 g
F P
s
P
p
.002 w
.4052 .30387 m .42378 .273 L .40175 .27399 L p
1 g
F P
s
P
p
.002 w
.66792 .4932 m .62957 .5232 L .62756 .54617 L p
1 g
F P
s
P
p
.002 w
.62957 .5232 m .66792 .4932 L .66394 .46999 L p
1 g
F P
s
P
p
.002 w
.34015 .3308 m .3355 .37823 L .35415 .36304 L p
1 g
F P
s
P
p
.002 w
.35415 .36304 m .35893 .31854 L .34015 .3308 L p
1 g
F P
s
P
p
.002 w
.50653 .24832 m .47304 .25752 L .49123 .26892 L p
1 g
F P
s
P
p
.002 w
.49123 .26892 m .51687 .26202 L .50653 .24832 L p
1 g
F P
s
P
p
.002 w
.31956 .48199 m .35116 .52644 L .3571 .50864 L p
1 g
F P
s
P
p
.002 w
.3571 .50864 m .32528 .46339 L .31956 .48199 L p
1 g
F P
s
P
p
.002 w
.45496 .25032 m .42378 .273 L .44712 .27608 L p
1 g
F P
s
P
p
.002 w
.44712 .27608 m .47304 .25752 L .45496 .25032 L p
1 g
F P
s
P
p
.002 w
.6438 .34333 m .63326 .31217 L .6134 .31061 L p
1 g
F P
s
P
p
.002 w
.59652 .28917 m .6134 .31061 L .63326 .31217 L p
1 g
F P
s
P
p
.002 w
.66283 .35476 m .6604 .39142 L .67499 .41058 L p
1 g
F P
s
P
p
.002 w
.6604 .39142 m .66283 .35476 L .6438 .34333 L p
1 g
F P
s
P
p
.002 w
.31012 .41374 m .32528 .46339 L .33531 .44455 L p
1 g
F P
s
P
p
.002 w
.33531 .44455 m .32064 .39524 L .31012 .41374 L p
1 g
F P
s
P
p
.002 w
.39176 .57734 m .4429 .60211 L .44867 .58872 L p
1 g
F P
s
P
p
.002 w
.44867 .58872 m .39558 .56297 L .39176 .57734 L p
1 g
F P
s
P
p
.002 w
.50589 .60162 m .44867 .58872 L .4429 .60211 L p
1 g
F P
s
P
p
.002 w
.63326 .31217 m .6438 .34333 L .66283 .35476 L p
1 g
F P
s
P
p
.002 w
.50589 .60162 m .56244 .60035 L .57062 .58322 L p
1 g
F P
s
P
p
.002 w
.62213 .56679 m .57062 .58322 L .56244 .60035 L p
1 g
F P
s
P
p
.002 w
.57062 .58322 m .62213 .56679 L .62756 .54617 L p
1 g
F P
s
P
p
.002 w
.68537 .43081 m .66394 .46999 L .66792 .4932 L p
1 g
F P
s
P
p
.002 w
.66394 .46999 m .68537 .43081 L .67499 .41058 L p
1 g
F P
s
P
p
.002 w
.34896 .54233 m .39176 .57734 L .39558 .56297 L p
1 g
F P
s
P
p
.002 w
.39558 .56297 m .35116 .52644 L .34896 .54233 L p
1 g
F P
s
P
p
.002 w
.54376 .24992 m .50653 .24832 L .51687 .26202 L p
1 g
F P
s
P
p
.002 w
.51687 .26202 m .5452 .2633 L .54376 .24992 L p
1 g
F P
s
P
p
.002 w
.38166 .27923 m .35893 .31854 L .38083 .30954 L p
1 g
F P
s
P
p
.002 w
.38083 .30954 m .40175 .27399 L .38166 .27923 L p
1 g
F P
s
P
p
.002 w
.63326 .31217 m .61126 .28399 L .59652 .28917 L p
1 g
F P
s
P
p
.002 w
.57286 .27272 m .59652 .28917 L .61126 .28399 L p
1 g
F P
s
P
p
.002 w
.4429 .60211 m .49797 .61461 L .50589 .60162 L p
1 g
F P
s
P
p
.002 w
.56244 .60035 m .50589 .60162 L .49797 .61461 L p
1 g
F P
s
P
p
.002 w
.66756 .51543 m .62756 .54617 L .62213 .56679 L p
1 g
F P
s
P
p
.002 w
.62756 .54617 m .66756 .51543 L .66792 .4932 L p
1 g
F P
s
P
p
.002 w
.32509 .34615 m .32064 .39524 L .3355 .37823 L p
1 g
F P
s
P
p
.002 w
.3355 .37823 m .34015 .3308 L .32509 .34615 L p
1 g
F P
s
P
p
.002 w
.58018 .26231 m .54376 .24992 L .5452 .2633 L p
1 g
F P
s
P
p
.002 w
.5452 .2633 m .57286 .27272 L .58018 .26231 L p
1 g
F P
s
P
p
.002 w
.61126 .28399 m .58018 .26231 L .57286 .27272 L p
1 g
F P
s
P
p
.002 w
.43744 .24774 m .40175 .27399 L .42378 .273 L p
1 g
F P
s
P
p
.002 w
.42378 .273 m .45496 .25032 L .43744 .24774 L p
1 g
F P
s
P
p
.002 w
.49562 .239 m .45496 .25032 L .47304 .25752 L p
1 g
F P
s
P
p
.002 w
.47304 .25752 m .50653 .24832 L .49562 .239 L p
1 g
F P
s
P
p
.002 w
.67812 .36859 m .67499 .41058 L .68537 .43081 L p
1 g
F P
s
P
p
.002 w
.67499 .41058 m .67812 .36859 L .66283 .35476 L p
1 g
F P
s
P
p
.002 w
.31852 .49985 m .34896 .54233 L .35116 .52644 L p
1 g
F P
s
P
p
.002 w
.35116 .52644 m .31956 .48199 L .31852 .49985 L p
1 g
F P
s
P
p
.002 w
.30442 .43331 m .31956 .48199 L .32528 .46339 L p
1 g
F P
s
P
p
.002 w
.32528 .46339 m .31012 .41374 L .30442 .43331 L p
1 g
F P
s
P
p
.002 w
.66283 .35476 m .65028 .31695 L .63326 .31217 L p
1 g
F P
s
P
p
.002 w
.61126 .28399 m .63326 .31217 L .65028 .31695 L p
1 g
F P
s
P
p
.002 w
.69109 .45168 m .66792 .4932 L .66756 .51543 L p
1 g
F P
s
P
p
.002 w
.66792 .4932 m .69109 .45168 L .68537 .43081 L p
1 g
F P
s
P
p
.002 w
.65028 .31695 m .66283 .35476 L .67812 .36859 L p
1 g
F P
s
P
p
.002 w
.36411 .28879 m .34015 .3308 L .35893 .31854 L p
1 g
F P
s
P
p
.002 w
.35893 .31854 m .38166 .27923 L .36411 .28879 L p
1 g
F P
s
P
p
.002 w
.39071 .58835 m .43843 .61144 L .4429 .60211 L p
1 g
F P
s
P
p
.002 w
.4429 .60211 m .39176 .57734 L .39071 .58835 L p
1 g
F P
s
P
p
.002 w
.49797 .61461 m .4429 .60211 L .43843 .61144 L p
1 g
F P
s
P
p
.002 w
.49797 .61461 m .55229 .61356 L .56244 .60035 L p
1 g
F P
s
P
p
.002 w
.61324 .58445 m .56244 .60035 L .55229 .61356 L p
1 g
F P
s
P
p
.002 w
.56244 .60035 m .61324 .58445 L .62213 .56679 L p
1 g
F P
s
P
p
.002 w
.54107 .24088 m .49562 .239 L .50653 .24832 L p
1 g
F P
s
P
p
.002 w
.50653 .24832 m .54376 .24992 L .54107 .24088 L p
1 g
F P
s
P
p
.002 w
.35078 .55581 m .39071 .58835 L .39176 .57734 L p
1 g
F P
s
P
p
.002 w
.39176 .57734 m .34896 .54233 L .35078 .55581 L p
1 g
F P
s
P
p
.002 w
.31435 .36434 m .31012 .41374 L .32064 .39524 L p
1 g
F P
s
P
p
.002 w
.32064 .39524 m .32509 .34615 L .31435 .36434 L p
1 g
F P
s
P
p
.002 w
.66264 .53609 m .62213 .56679 L .61324 .58445 L p
1 g
F P
s
P
p
.002 w
.62213 .56679 m .66264 .53609 L .66756 .51543 L p
1 g
F P
s
P
p
.002 w
.65028 .31695 m .62358 .28256 L .61126 .28399 L p
1 g
F P
s
P
p
.002 w
.58018 .26231 m .61126 .28399 L .62358 .28256 L p
1 g
F P
s
P
p
.002 w
.43843 .61144 m .48978 .62315 L .49797 .61461 L p
1 g
F P
s
P
p
.002 w
.55229 .61356 m .49797 .61461 L .48978 .62315 L p
1 g
F P
s
P
p
.002 w
.42098 .25008 m .38166 .27923 L .40175 .27399 L p
1 g
F P
s
P
p
.002 w
.40175 .27399 m .43744 .24774 L .42098 .25008 L p
1 g
F P
s
P
p
.002 w
.68911 .38457 m .68537 .43081 L .69109 .45168 L p
1 g
F P
s
P
p
.002 w
.68537 .43081 m .68911 .38457 L .67812 .36859 L p
1 g
F P
s
P
p
.002 w
.48439 .23455 m .43744 .24774 L .45496 .25032 L p
1 g
F P
s
P
p
.002 w
.45496 .25032 m .49562 .239 L .48439 .23455 L p
1 g
F P
s
P
p
.002 w
.58562 .25603 m .54107 .24088 L .54376 .24992 L p
1 g
F P
s
P
p
.002 w
.54376 .24992 m .58018 .26231 L .58562 .25603 L p
1 g
F P
s
P
p
.002 w
.62358 .28256 m .58562 .25603 L .58018 .26231 L p
1 g
F P
s
P
p
.002 w
.30396 .45348 m .31852 .49985 L .31956 .48199 L p
1 g
F P
s
P
p
.002 w
.31956 .48199 m .30442 .43331 L .30396 .45348 L p
1 g
F P
s
P
p
.002 w
.69176 .47266 m .66756 .51543 L .66264 .53609 L p
1 g
F P
s
P
p
.002 w
.66756 .51543 m .69176 .47266 L .69109 .45168 L p
1 g
F P
s
P
p
.002 w
.32247 .51647 m .35078 .55581 L .34896 .54233 L p
1 g
F P
s
P
p
.002 w
.34896 .54233 m .31852 .49985 L .32247 .51647 L p
1 g
F P
s
P
p
.002 w
.67812 .36859 m .66386 .32499 L .65028 .31695 L p
1 g
F P
s
P
p
.002 w
.62358 .28256 m .65028 .31695 L .66386 .32499 L p
1 g
F P
s
P
p
.002 w
.34974 .30264 m .32509 .34615 L .34015 .3308 L p
1 g
F P
s
P
p
.002 w
.34015 .3308 m .36411 .28879 L .34974 .30264 L p
1 g
F P
s
P
p
.002 w
.66386 .32499 m .67812 .36859 L .68911 .38457 L p
1 g
F P
s
P
p
.002 w
.48978 .62315 m .54031 .62227 L .55229 .61356 L p
1 g
F P
s
P
p
.002 w
.60094 .59853 m .55229 .61356 L .54031 .62227 L p
1 g
F P
s
P
p
.002 w
.55229 .61356 m .60094 .59853 L .61324 .58445 L p
1 g
F P
s
P
p
.002 w
.30845 .38499 m .30442 .43331 L .31012 .41374 L p
1 g
F P
s
P
p
.002 w
.31012 .41374 m .31435 .36434 L .30845 .38499 L p
1 g
F P
s
P
p
.002 w
.65308 .55453 m .61324 .58445 L .60094 .59853 L p
1 g
F P
s
P
p
.002 w
.61324 .58445 m .65308 .55453 L .66264 .53609 L p
1 g
F P
s
P
p
.002 w
.39261 .59549 m .43546 .61621 L .43843 .61144 L p
1 g
F P
s
P
p
.002 w
.43843 .61144 m .39071 .58835 L .39261 .59549 L p
1 g
F P
s
P
p
.002 w
.48978 .62315 m .43843 .61144 L .43546 .61621 L p
1 g
F P
s
P
p
.002 w
.53713 .2367 m .48439 .23455 L .49562 .239 L p
1 g
F P
s
P
p
.002 w
.49562 .239 m .54107 .24088 L .53713 .2367 L p
1 g
F P
s
P
p
.002 w
.35681 .56637 m .39261 .59549 L .39071 .58835 L p
1 g
F P
s
P
p
.002 w
.39071 .58835 m .35078 .55581 L .35681 .56637 L p
1 g
F P
s
P
p
.002 w
.40611 .25758 m .36411 .28879 L .38166 .27923 L p
1 g
F P
s
P
p
.002 w
.38166 .27923 m .42098 .25008 L .40611 .25758 L p
1 g
F P
s
P
p
.002 w
.69526 .40239 m .69109 .45168 L .69176 .47266 L p
1 g
F P
s
P
p
.002 w
.69109 .45168 m .69526 .40239 L .68911 .38457 L p
1 g
F P
s
P
p
.002 w
.66386 .32499 m .63301 .28514 L .62358 .28256 L p
1 g
F P
s
P
p
.002 w
.58562 .25603 m .62358 .28256 L .63301 .28514 L p
1 g
F P
s
P
p
.002 w
.43546 .61621 m .48154 .62674 L .48978 .62315 L p
1 g
F P
s
P
p
.002 w
.54031 .62227 m .48978 .62315 L .48154 .62674 L p
1 g
F P
s
P
p
.002 w
.47312 .2354 m .42098 .25008 L .43744 .24774 L p
1 g
F P
s
P
p
.002 w
.43744 .24774 m .48439 .23455 L .47312 .2354 L p
1 g
F P
s
P
p
.002 w
.68712 .49318 m .66264 .53609 L .65308 .55453 L p
1 g
F P
s
P
p
.002 w
.66264 .53609 m .68712 .49318 L .69176 .47266 L p
1 g
F P
s
P
p
.002 w
.58893 .25431 m .53713 .2367 L .54107 .24088 L p
1 g
F P
s
P
p
.002 w
.54107 .24088 m .58562 .25603 L .58893 .25431 L p
1 g
F P
s
P
p
.002 w
.33912 .32059 m .31435 .36434 L .32509 .34615 L p
1 g
F P
s
P
p
.002 w
.32509 .34615 m .34974 .30264 L .33912 .32059 L p
1 g
F P
s
P
p
.002 w
.309 .47371 m .32247 .51647 L .31852 .49985 L p
1 g
F P
s
P
p
.002 w
.31852 .49985 m .30396 .45348 L .309 .47371 L p
1 g
F P
s
P
p
.002 w
.63301 .28514 m .58893 .25431 L .58562 .25603 L p
1 g
F P
s
P
p
.002 w
.67342 .33628 m .68911 .38457 L .69526 .40239 L p
1 g
F P
s
P
p
.002 w
.68911 .38457 m .67342 .33628 L .66386 .32499 L p
1 g
F P
s
P
p
.002 w
.33155 .5313 m .35681 .56637 L .35078 .55581 L p
1 g
F P
s
P
p
.002 w
.35078 .55581 m .32247 .51647 L .33155 .5313 L p
1 g
F P
s
P
p
.002 w
.63301 .28514 m .66386 .32499 L .67342 .33628 L p
1 g
F P
s
P
p
.002 w
.30781 .40763 m .30396 .45348 L .30442 .43331 L p
1 g
F P
s
P
p
.002 w
.30442 .43331 m .30845 .38499 L .30781 .40763 L p
1 g
F P
s
P
p
.004 w
.22096 .42274 m
.29343 .42476 L
s
P
p
.002 w
.48154 .62674 m .52674 .626 L .54031 .62227 L p
1 g
F P
s
P
p
.002 w
.54031 .62227 m .58538 .60844 L .60094 .59853 L p
1 g
F P
s
P
p
.002 w
.58538 .60844 m .54031 .62227 L .52674 .626 L p
1 g
F P
s
P
p
.002 w
.60094 .59853 m .63891 .57013 L .65308 .55453 L p
1 g
F P
s
P
p
.002 w
.63891 .57013 m .60094 .59853 L .58538 .60844 L p
1 g
F P
s
P
p
.002 w
.69176 .47266 m .69615 .42166 L .69526 .40239 L p
1 g
F P
s
P
p
.002 w
.69615 .42166 m .69176 .47266 L .68712 .49318 L p
1 g
F P
s
P
p
.002 w
.39335 .27031 m .34974 .30264 L .36411 .28879 L p
1 g
F P
s
P
p
.002 w
.36411 .28879 m .40611 .25758 L .39335 .27031 L p
1 g
F P
s
P
p
.002 w
.53196 .23781 m .47312 .2354 L .48439 .23455 L p
1 g
F P
s
P
p
.002 w
.48439 .23455 m .53713 .2367 L .53196 .23781 L p
1 g
F P
s
P
p
.002 w
.3976 .59831 m .43416 .61598 L .43546 .61621 L p
1 g
F P
s
P
p
.002 w
.43546 .61621 m .39261 .59549 L .3976 .59831 L p
1 g
F P
s
P
p
.002 w
.48154 .62674 m .43546 .61621 L .43416 .61598 L p
1 g
F P
s
P
p
.002 w
.36715 .57352 m .3976 .59831 L .39261 .59549 L p
1 g
F P
s
P
p
.002 w
.39261 .59549 m .35681 .56637 L .36715 .57352 L p
1 g
F P
s
P
p
.002 w
.46216 .24186 m .40611 .25758 L .42098 .25008 L p
1 g
F P
s
P
p
.002 w
.42098 .25008 m .47312 .2354 L .46216 .24186 L p
1 g
F P
s
P
p
.002 w
.65308 .55453 m .67702 .51262 L .68712 .49318 L p
1 g
F P
s
P
p
.002 w
.67702 .51262 m .65308 .55453 L .63891 .57013 L p
1 g
F P
s
P
p
.002 w
.67342 .33628 m .63911 .29192 L .63301 .28514 L p
1 g
F P
s
P
p
.002 w
.58893 .25431 m .63301 .28514 L .63911 .29192 L p
1 g
F P
s
P
p
.002 w
.33277 .34232 m .30845 .38499 L .31435 .36434 L p
1 g
F P
s
P
p
.002 w
.31435 .36434 m .33912 .32059 L .33277 .34232 L p
1 g
F P
s
P
p
.002 w
.43416 .61598 m .47345 .62496 L .48154 .62674 L p
1 g
F P
s
P
p
.002 w
.52674 .626 m .48154 .62674 L .47345 .62496 L p
1 g
F P
s
P
p
.002 w
.3197 .49339 m .33155 .5313 L .32247 .51647 L p
1 g
F P
s
P
p
.002 w
.32247 .51647 m .309 .47371 L .3197 .49339 L p
1 g
F P
s
P
p
.002 w
.69526 .40239 m .67847 .35067 L .67342 .33628 L p
1 g
F P
s
P
p
.002 w
.67847 .35067 m .69526 .40239 L .69615 .42166 L p
1 g
F P
s
P
p
.002 w
.58987 .2575 m .53196 .23781 L .53713 .2367 L p
1 g
F P
s
P
p
.002 w
.53713 .2367 m .58893 .25431 L .58987 .2575 L p
1 g
F P
s
P
p
.002 w
.63911 .29192 m .67342 .33628 L .67847 .35067 L p
1 g
F P
s
P
p
.002 w
.63911 .29192 m .58987 .2575 L .58893 .25431 L p
1 g
F P
s
P
p
.002 w
.3458 .5438 m .36715 .57352 L .35681 .56637 L p
1 g
F P
s
P
p
.002 w
.35681 .56637 m .33155 .5313 L .3458 .5438 L p
1 g
F P
s
P
p
.002 w
.3127 .43165 m .309 .47371 L .30396 .45348 L p
1 g
F P
s
P
p
.002 w
.30396 .45348 m .30781 .40763 L .3127 .43165 L p
1 g
F P
s
P
p
.002 w
.52674 .626 m .56683 .61368 L .58538 .60844 L p
1 g
F P
s
P
p
.002 w
.62031 .58228 m .58538 .60844 L .56683 .61368 L p
1 g
F P
s
P
p
.002 w
.58538 .60844 m .62031 .58228 L .63891 .57013 L p
1 g
F P
s
P
p
.002 w
.69145 .44186 m .68712 .49318 L .67702 .51262 L p
1 g
F P
s
P
p
.002 w
.68712 .49318 m .69145 .44186 L .69615 .42166 L p
1 g
F P
s
P
p
.002 w
.38323 .28815 m .33912 .32059 L .34974 .30264 L p
1 g
F P
s
P
p
.002 w
.34974 .30264 m .39335 .27031 L .38323 .28815 L p
1 g
F P
s
P
p
.002 w
.47345 .62496 m .51186 .62431 L .52674 .626 L p
1 g
F P
s
P
p
.002 w
.56683 .61368 m .52674 .626 L .51186 .62431 L p
1 g
F P
s
P
p
.002 w
.52565 .24453 m .46216 .24186 L .47312 .2354 L p
1 g
F P
s
P
p
.002 w
.47312 .2354 m .53196 .23781 L .52565 .24453 L p
1 g
F P
s
P
p
.002 w
.6615 .53033 m .63891 .57013 L .62031 .58228 L p
1 g
F P
s
P
p
.002 w
.63891 .57013 m .6615 .53033 L .67702 .51262 L p
1 g
F P
s
P
p
.002 w
.33112 .36732 m .30781 .40763 L .30845 .38499 L p
1 g
F P
s
P
p
.002 w
.30845 .38499 m .33277 .34232 L .33112 .36732 L p
1 g
F P
s
P
p
.002 w
.40576 .59644 m .4347 .61043 L .43416 .61598 L p
1 g
F P
s
P
p
.002 w
.43416 .61598 m .3976 .59831 L .40576 .59644 L p
1 g
F P
s
P
p
.004 w
.41736 .63795 m
.42663 .61467 L
s
P
p
.002 w
.47345 .62496 m .43416 .61598 L .4347 .61043 L p
1 g
F P
s
P
p
.002 w
.45185 .25407 m .39335 .27031 L .40611 .25758 L p
1 g
F P
s
P
p
.002 w
.40611 .25758 m .46216 .24186 L .45185 .25407 L p
1 g
F P
s
P
p
.002 w
.38174 .57684 m .40576 .59644 L .3976 .59831 L p
1 g
F P
s
P
p
.002 w
.3976 .59831 m .36715 .57352 L .38174 .57684 L p
1 g
F P
s
P
p
.002 w
.67847 .35067 m .64148 .30297 L .63911 .29192 L p
1 g
F P
s
P
p
.002 w
.58987 .2575 m .63911 .29192 L .64148 .30297 L p
1 g
F P
s
P
p
.002 w
.67858 .36793 m .69615 .42166 L .69145 .44186 L p
1 g
F P
s
P
p
.002 w
.69615 .42166 m .67858 .36793 L .67847 .35067 L p
1 g
F P
s
P
p
.002 w
.33599 .51187 m .3458 .5438 L .33155 .5313 L p
1 g
F P
s
P
p
.002 w
.33155 .5313 m .3197 .49339 L .33599 .51187 L p
1 g
F P
s
P
p
.002 w
.4347 .61043 m .46578 .61752 L .47345 .62496 L p
1 g
F P
s
P
p
.002 w
.51186 .62431 m .47345 .62496 L .46578 .61752 L p
1 g
F P
s
P
p
.002 w
.32323 .45634 m .3197 .49339 L .309 .47371 L p
1 g
F P
s
P
p
.002 w
.309 .47371 m .3127 .43165 L .32323 .45634 L p
1 g
F P
s
P
p
.002 w
.64148 .30297 m .67847 .35067 L .67858 .36793 L p
1 g
F P
s
P
p
.002 w
.58825 .26583 m .52565 .24453 L .53196 .23781 L p
1 g
F P
s
P
p
.002 w
.53196 .23781 m .58987 .2575 L .58825 .26583 L p
1 g
F P
s
P
p
.002 w
.36506 .55344 m .38174 .57684 L .36715 .57352 L p
1 g
F P
s
P
p
.002 w
.36715 .57352 m .3458 .5438 L .36506 .55344 L p
1 g
F P
s
P
p
.002 w
.68102 .46242 m .67702 .51262 L .6615 .53033 L p
1 g
F P
s
P
p
.002 w
.67702 .51262 m .68102 .46242 L .69145 .44186 L p
1 g
F P
s
P
p
.002 w
.51186 .62431 m .54569 .61383 L .56683 .61368 L p
1 g
F P
s
P
p
.002 w
.59762 .59044 m .56683 .61368 L .54569 .61383 L p
1 g
F P
s
P
p
.002 w
.56683 .61368 m .59762 .59044 L .62031 .58228 L p
1 g
F P
s
P
p
.002 w
.64148 .30297 m .58825 .26583 L .58987 .2575 L p
1 g
F P
s
P
p
.002 w
.37621 .31082 m .33277 .34232 L .33912 .32059 L p
1 g
F P
s
P
p
.002 w
.33912 .32059 m .38323 .28815 L .37621 .31082 L p
1 g
F P
s
P
p
.002 w
.46578 .61752 m .49605 .61695 L .51186 .62431 L p
1 g
F P
s
P
p
.002 w
.54569 .61383 m .51186 .62431 L .49605 .61695 L p
1 g
F P
s
P
p
.002 w
.64079 .54568 m .62031 .58228 L .59762 .59044 L p
1 g
F P
s
P
p
.002 w
.62031 .58228 m .64079 .54568 L .6615 .53033 L p
1 g
F P
s
P
p
.002 w
.33442 .39491 m .3127 .43165 L .30781 .40763 L p
1 g
F P
s
P
p
.004 w
.29343 .42476 m
.30824 .42517 L
s
P
p
.002 w
.30781 .40763 m .33112 .36732 L .33442 .39491 L p
1 g
F P
s
P
p
.002 w
.44258 .27199 m .38323 .28815 L .39335 .27031 L p
1 g
F P
s
P
p
.002 w
.39335 .27031 m .45185 .25407 L .44258 .27199 L p
1 g
F P
s
P
p
.002 w
.51831 .25702 m .45185 .25407 L .46216 .24186 L p
1 g
F P
s
P
p
.002 w
.46216 .24186 m .52565 .24453 L .51831 .25702 L p
1 g
F P
s
P
p
.002 w
.67345 .38766 m .69145 .44186 L .68102 .46242 L p
1 g
F P
s
P
p
.002 w
.69145 .44186 m .67345 .38766 L .67858 .36793 L p
1 g
F P
s
P
p
.002 w
.41702 .58963 m .43716 .59938 L .4347 .61043 L p
1 g
F P
s
P
p
.002 w
.4347 .61043 m .40576 .59644 L .41702 .58963 L p
1 g
F P
s
P
p
.002 w
.46578 .61752 m .4347 .61043 L .43716 .59938 L p
1 g
F P
s
P
p
.002 w
.3576 .52848 m .36506 .55344 L .3458 .5438 L p
1 g
F P
s
P
p
.002 w
.3458 .5438 m .33599 .51187 L .3576 .52848 L p
1 g
F P
s
P
p
.002 w
.33928 .48091 m .33599 .51187 L .3197 .49339 L p
1 g
F P
s
P
p
.002 w
.3197 .49339 m .32323 .45634 L .33928 .48091 L p
1 g
F P
s
P
p
.002 w
.40038 .57598 m .41702 .58963 L .40576 .59644 L p
1 g
F P
s
P
p
.002 w
.40576 .59644 m .38174 .57684 L .40038 .57598 L p
1 g
F P
s
P
p
.002 w
.67858 .36793 m .63979 .31821 L .64148 .30297 L p
1 g
F P
s
P
p
.002 w
.58825 .26583 m .64148 .30297 L .63979 .31821 L p
1 g
F P
s
P
p
.002 w
.43716 .59938 m .4588 .60429 L .46578 .61752 L p
1 g
F P
s
P
p
.002 w
.49605 .61695 m .46578 .61752 L .4588 .60429 L p
1 g
F P
s
P
p
.002 w
.66493 .48268 m .6615 .53033 L .64079 .54568 L p
1 g
F P
s
P
p
.002 w
.6615 .53033 m .66493 .48268 L .68102 .46242 L p
1 g
F P
s
P
p
.002 w
.63979 .31821 m .67858 .36793 L .67345 .38766 L p
1 g
F P
s
P
p
.002 w
.37269 .33775 m .33112 .36732 L .33277 .34232 L p
1 g
F P
s
P
p
.002 w
.33277 .34232 m .37621 .31082 L .37269 .33775 L p
1 g
F P
s
P
p
.002 w
.49605 .61695 m .52251 .60862 L .54569 .61383 L p
1 g
F P
s
P
p
.002 w
.5714 .59416 m .54569 .61383 L .52251 .60862 L p
1 g
F P
s
P
p
.002 w
.54569 .61383 m .5714 .59416 L .59762 .59044 L p
1 g
F P
s
P
p
.002 w
.38895 .55976 m .40038 .57598 L .38174 .57684 L p
1 g
F P
s
P
p
.002 w
.38174 .57684 m .36506 .55344 L .38895 .55976 L p
1 g
F P
s
P
p
.002 w
.58396 .27938 m .51831 .25702 L .52565 .24453 L p
1 g
F P
s
P
p
.002 w
.52565 .24453 m .58825 .26583 L .58396 .27938 L p
1 g
F P
s
P
p
.002 w
.61535 .55804 m .59762 .59044 L .5714 .59416 L p
1 g
F P
s
P
p
.002 w
.59762 .59044 m .61535 .55804 L .64079 .54568 L p
1 g
F P
s
P
p
.002 w
.34276 .42425 m .32323 .45634 L .3127 .43165 L p
1 g
F P
s
P
p
.002 w
.3127 .43165 m .33442 .39491 L .34276 .42425 L p
1 g
F P
s
P
p
.004 w
.31602 .42539 m
.32154 .42554 L
s
P
p
.004 w
.34163 .4261 m
.5 .43051 L
s
P
p
.004 w
.32154 .42554 m
.32292 .42558 L
s
P
p
.004 w
.30824 .42517 m
.31602 .42539 L
s
P
p
.002 w
.63979 .31821 m .58396 .27938 L .58825 .26583 L p
1 g
F P
s
P
p
.002 w
.4588 .60429 m .47977 .60383 L .49605 .61695 L p
1 g
F P
s
P
p
.002 w
.52251 .60862 m .49605 .61695 L .47977 .60383 L p
1 g
F P
s
P
p
.002 w
.43472 .29529 m .37621 .31082 L .38323 .28815 L p
1 g
F P
s
P
p
.002 w
.38323 .28815 m .44258 .27199 L .43472 .29529 L p
1 g
F P
s
P
p
.002 w
.66299 .40934 m .68102 .46242 L .66493 .48268 L p
1 g
F P
s
P
p
.002 w
.68102 .46242 m .66299 .40934 L .67345 .38766 L p
1 g
F P
s
P
p
.002 w
.36048 .5045 m .3576 .52848 L .33599 .51187 L p
1 g
F P
s
P
p
.002 w
.33599 .51187 m .33928 .48091 L .36048 .5045 L p
1 g
F P
s
P
p
.002 w
.51015 .2752 m .44258 .27199 L .45185 .25407 L p
1 g
F P
s
P
p
.002 w
.45185 .25407 m .51831 .25702 L .51015 .2752 L p
1 g
F P
s
P
p
.002 w
.38401 .5426 m .38895 .55976 L .36506 .55344 L p
1 g
F P
s
P
p
.002 w
.36506 .55344 m .3576 .52848 L .38401 .5426 L p
1 g
F P
s
P
p
.002 w
.64346 .50194 m .64079 .54568 L .61535 .55804 L p
1 g
F P
s
P
p
.002 w
.64079 .54568 m .64346 .50194 L .66493 .48268 L p
1 g
F P
s
P
p
.002 w
.37293 .36819 m .33442 .39491 L .33112 .36732 L p
1 g
F P
s
P
p
.002 w
.33112 .36732 m .37269 .33775 L .37293 .36819 L p
1 g
F P
s
P
p
.002 w
.4312 .5778 m .4416 .58285 L .43716 .59938 L p
1 g
F P
s
P
p
.002 w
.43716 .59938 m .41702 .58963 L .4312 .5778 L p
1 g
F P
s
P
p
.002 w
.4588 .60429 m .43716 .59938 L .4416 .58285 L p
1 g
F P
s
P
p
.002 w
.47977 .60383 m .49796 .59796 L .52251 .60862 L p
1 g
F P
s
P
p
.002 w
.54236 .59312 m .52251 .60862 L .49796 .59796 L p
1 g
F P
s
P
p
.002 w
.52251 .60862 m .54236 .59312 L .5714 .59416 L p
1 g
F P
s
P
p
.002 w
.42266 .57074 m .4312 .5778 L .41702 .58963 L p
1 g
F P
s
P
p
.002 w
.41702 .58963 m .40038 .57598 L .42266 .57074 L p
1 g
F P
s
P
p
.002 w
.67345 .38766 m .63388 .33738 L .63979 .31821 L p
1 g
F P
s
P
p
.002 w
.58396 .27938 m .63979 .31821 L .63388 .33738 L p
1 g
F P
s
P
p
.002 w
.63388 .33738 m .67345 .38766 L .66299 .40934 L p
1 g
F P
s
P
p
.002 w
.35602 .45435 m .33928 .48091 L .32323 .45634 L p
1 g
F P
s
P
p
.002 w
.32323 .45634 m .34276 .42425 L .35602 .45435 L p
1 g
F P
s
P
p
.002 w
.4416 .58285 m .45277 .58536 L .4588 .60429 L p
1 g
F P
s
P
p
.002 w
.47977 .60383 m .4588 .60429 L .45277 .58536 L p
1 g
F P
s
P
p
.002 w
.58586 .56689 m .5714 .59416 L .54236 .59312 L p
1 g
F P
s
P
p
.002 w
.5714 .59416 m .58586 .56689 L .61535 .55804 L p
1 g
F P
s
P
p
.002 w
.41686 .56239 m .42266 .57074 L .40038 .57598 L p
1 g
F P
s
P
p
.002 w
.40038 .57598 m .38895 .55976 L .41686 .56239 L p
1 g
F P
s
P
p
.002 w
.45277 .58536 m .46356 .58507 L .47977 .60383 L p
1 g
F P
s
P
p
.002 w
.49796 .59796 m .47977 .60383 L .46356 .58507 L p
1 g
F P
s
P
p
.002 w
.57697 .298 m .51015 .2752 L .51831 .25702 L p
1 g
F P
s
P
p
.002 w
.51831 .25702 m .58396 .27938 L .57697 .298 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.64729 .43231 m .66493 .48268 L .64346 .50194 L p
1 g
F P
s
P
p
.002 w
.66493 .48268 m .64729 .43231 L .66299 .40934 L p
1 g
F P
s
P
p
.002 w
.63388 .33738 m .57697 .298 L .58396 .27938 L p
1 g
F P
s
P
p
.002 w
.38625 .52626 m .38401 .5426 L .3576 .52848 L p
1 g
F P
s
P
p
.002 w
.3576 .52848 m .36048 .5045 L .38625 .52626 L p
1 g
F P
s
P
p
.002 w
.42862 .3234 m .37269 .33775 L .37621 .31082 L p
1 g
F P
s
P
p
.002 w
.37621 .31082 m .43472 .29529 L .42862 .3234 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.61717 .51948 m .61535 .55804 L .58586 .56689 L p
1 g
F P
s
P
p
.002 w
.61535 .55804 m .61717 .51948 L .64346 .50194 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.41446 .55362 m .41686 .56239 L .38895 .55976 L p
1 g
F P
s
P
p
.002 w
.38895 .55976 m .38401 .5426 L .41446 .55362 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.37707 .40115 m .34276 .42425 L .33442 .39491 L p
1 g
F P
s
P
p
.002 w
.33442 .39491 m .37293 .36819 L .37707 .40115 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45946 .53227 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50139 .29873 m .43472 .29529 L .44258 .27199 L p
1 g
F P
s
P
p
.002 w
.44258 .27199 m .51015 .2752 L .50139 .29873 L p
1 g
F P
s
P
p
.002 w
.37384 .48415 m .36048 .5045 L .33928 .48091 L p
1 g
F P
s
P
p
.002 w
.33928 .48091 m .35602 .45435 L .37384 .48415 L p
1 g
F P
s
P
p
.002 w
.49796 .59796 m .51141 .58718 L .54236 .59312 L p
1 g
F P
s
P
p
.002 w
.55323 .5718 m .54236 .59312 L .51141 .58718 L p
1 g
F P
s
P
p
.002 w
.54236 .59312 m .55323 .5718 L .58586 .56689 L p
1 g
F P
s
P
p
.002 w
.46356 .58507 m .47282 .58199 L .49796 .59796 L p
1 g
F P
s
P
p
.002 w
.51141 .58718 m .49796 .59796 L .47282 .58199 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.6237 .36003 m .66299 .40934 L .64729 .43231 L p
1 g
F P
s
P
p
.002 w
.66299 .40934 m .6237 .36003 L .63388 .33738 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.4416 .58285 m .4312 .5778 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.45277 .58536 m .4416 .58285 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.57697 .298 m .63388 .33738 L .6237 .36003 L p
1 g
F P
s
P
p
.002 w
.4312 .5778 m .42266 .57074 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.46356 .58507 m .45277 .58536 L .44811 .56176 L p
1 g
F P
s
P
p
.002 w
.44865 .56212 m .46356 .58507 L p
.44811 .56176 L 1 g
F P
s
P
p
.002 w
.42066 .53852 m .42863 .5339 L p
.43863 .54795 L 1 g
F P
s
P
p
.002 w
.44132 .55559 m .42066 .53852 L p
.43863 .54795 L 1 g
F P
s
P
p
.002 w
.43147 .53778 m .44798 .56109 L p
.42863 .5339 L 1 g
F P
s
P
p
.002 w
.4384 .54727 m .43925 .54566 L p
.43476 .53677 L 1 g
F P
s
P
p
.002 w
.44761 .55989 m .44798 .56109 L p
.4386 .54755 L 1 g
F P
s
P
p
.44379 .55466 m .4437 .55455 L .44377 .55464 L 1 g
F
P
p
.45146 .56129 m .44372 .55457 L .44379 .55466 L 1 g
F
P
p
.44372 .55457 m .4437 .55455 L .44379 .55466 L 1 g
F
P
p
.002 w
.44798 .56109 m .43859 .54784 L p
.4386 .54755 L 1 g
F P
s
P
p
.002 w
.44798 .56109 m .44132 .55559 L p
.43863 .54795 L 1 g
F P
s
P
p
.002 w
.44852 .56107 m .44798 .56109 L .44841 .56095 L p
1 g
F P
s
P
p
.002 w
.44866 .56124 m .44798 .56109 L .44852 .56107 L p
1 g
F P
s
P
p
.002 w
.45067 .56342 m .45146 .56129 L p
.44365 .55454 L 1 g
F P
s
P
p
.44365 .55454 m .4448 .5561 L .45067 .56342 L 1 g
F
P
p
.44334 .55427 m .44523 .55676 L .45067 .56342 L 1 g
F
P
p
.44285 .55384 m .44568 .55746 L .45067 .56342 L 1 g
F
P
p
.002 w
.44803 .56046 m .44798 .56109 L .44761 .55989 L p
1 g
F P
s
P
p
.44213 .55323 m .44827 .56078 L .45067 .56342 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4384 .54727 L p
1 g
F P
s
P
p
.002 w
.43859 .54784 m .43147 .53778 L p
.4384 .54727 L 1 g
F P
s
P
p
.45146 .56129 m .4384 .54727 L .44372 .55457 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.42869 .53386 m .43344 .53298 L p
.4384 .54727 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43241 .52886 L p
1 g
F P
s
P
p
.43113 .52375 m .43241 .52886 L .42869 .53386 L 1 g
F
P
p
.002 w
.43344 .53298 m .43208 .53323 L p
.43241 .52886 L 1 g
F P
s
P
p
.002 w
.43208 .53323 m .42869 .53386 L p
.43241 .52886 L 1 g
F P
s
P
p
.002 w
.43241 .52886 m .43346 .52734 L p
.43317 .51892 L 1 g
F P
s
P
p
.43925 .54566 m .43241 .52886 L .43403 .53534 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43899 .53194 m .43344 .53298 L p
.43241 .52886 L 1 g
F P
s
P
p
.43113 .52375 m .43268 .52536 L .43241 .52886 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43389 .5094 L p
1 g
F P
s
P
p
.43346 .52734 m .43389 .5094 L .43317 .51892 L 1 g
F
P
p
.43268 .52536 m .43899 .53194 L .43241 .52886 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.41134 .50309 m .4317 .49906 L .43396 .50925 L p
1 g
F P
s
P
p
.002 w
.4317 .49906 m .42644 .46361 L p
.44445 .48767 L 1 g
F P
s
P
p
.002 w
.43389 .5094 m .43485 .50826 L p
.43884 .49892 L 1 g
F P
s
P
p
.43884 .49892 m .43848 .49965 L .43389 .5094 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.44445 .48767 m .44264 .4913 L .4317 .49906 L 1 g
F
P
p
.002 w
.43848 .49965 m .43439 .4993 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.43439 .4993 m .4317 .49906 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.44325 .49079 m .44215 .49186 L p
.43485 .50826 L 1 g
F P
s
P
p
.43485 .50826 m .44215 .49186 L .43904 .49847 L 1 g
F
P
p
.43904 .49847 m .43396 .50925 L .43389 .5094 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.45445 .50104 m .45041 .533 L p
.43551 .50597 L 1 g
F P
s
P
p
.002 w
.4317 .49906 m .43848 .49965 L p
.43551 .50597 L 1 g
F P
s
P
p
.002 w
.43848 .49965 m .45445 .50104 L p
.43551 .50597 L 1 g
F P
s
P
p
.002 w
.44215 .49186 m .44166 .49233 L p
.43904 .49847 L 1 g
F P
s
P
p
.002 w
.44333 .49064 m .44339 .4905 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.44264 .4913 m .44339 .4905 L p
.44957 .48457 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45445 .50104 m .43848 .49965 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45765 .47675 L p
1 g
F P
s
P
p
.44339 .4905 m .45765 .47675 L .44957 .48457 L 1 g
F
P
p
.44445 .48767 m .44526 .48876 L .44264 .4913 L 1 g
F
P
p
.44526 .48876 m .45445 .50104 L .44264 .4913 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45765 .47675 m .45826 .47608 L p
.46823 .47171 L 1 g
F P
s
P
p
.4631 .47416 m .47693 .50887 L .45837 .47642 L 1 g
F
P
p
.46823 .47171 m .45837 .47642 L .45765 .47675 L 1 g
F
P
p
.002 w
.49317 .47785 m .47693 .50887 L p
.4631 .47416 L 1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47128 .47025 m .49317 .47785 L p
.4631 .47416 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47758 .46713 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49317 .47785 m .47128 .47025 L p
.47758 .46713 L 1 g
F P
s
P
p
.002 w
.47758 .46713 m .47786 .46667 L p
.48753 .46569 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.52192 .49678 m .49317 .47785 L .50022 .46392 L p
1 g
F P
s
P
p
.50031 .46393 m .52192 .49678 L .50022 .46392 L 1 g
F
P
p
.5 .4634 m .50936 .4652 L .50022 .46392 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .48753 .46569 L 1 g
F
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50022 .46392 m .49317 .47785 L p
.48393 .46114 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46388 L p
.50022 .46392 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.50022 .46392 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52235 .46703 L p
1 g
F P
s
P
p
.5 .4634 m .52235 .46703 L .50936 .4652 L 1 g
F
P
p
.51366 .46155 m .51469 .46595 L .50026 .46384 L 1 g
F
P
p
.51469 .46595 m .52192 .49678 L .50031 .46393 L 1 g
F
P
p
.51469 .46595 m .50031 .46393 L .50026 .46384 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54236 .47676 L p
1 g
F P
s
P
p
.54236 .47676 m .54281 .52074 L .54095 .47611 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56602 .50929 L p
1 g
F P
s
P
p
.57353 .50087 m .56799 .51361 L .56602 .50929 L 1 g
F
P
p
.002 w
.56476 .50654 m .56581 .50587 L p
.56602 .50929 L 1 g
F P
s
P
p
.002 w
.56581 .50587 m .57353 .50087 L p
.56602 .50929 L 1 g
F P
s
P
p
.002 w
.56602 .50929 m .56515 .50826 L p
.56648 .51691 L 1 g
F P
s
P
p
.55661 .4905 m .56602 .50929 L .56476 .50654 L 1 g
F
P
p
.002 w
.54687 .46967 m .57353 .50087 L .56977 .5033 L p
1 g
F P
s
P
p
.002 w
.56977 .5033 m .56476 .50654 L p
.55736 .49128 L 1 g
F P
s
P
p
.54687 .46967 m .56977 .5033 L .55736 .49128 L 1 g
F
P
p
.55661 .4905 m .56476 .50654 L .56126 .49939 L 1 g
F
P
p
.002 w
.54236 .47676 m .54174 .47608 L p
.54883 .48302 L 1 g
F P
s
P
p
.54687 .46967 m .56476 .50654 L .54684 .47 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55721 .49114 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56476 .50654 m .54281 .52074 L p
.54602 .48031 L 1 g
F P
s
P
p
.54174 .47608 m .55721 .49114 L .54883 .48302 L 1 g
F
P
p
.54684 .47 m .55721 .49114 L .54602 .48031 L 1 g
F
P
p
.55721 .49114 m .56476 .50654 L .54602 .48031 L 1 g
F
P
p
.54602 .48031 m .54281 .52074 L .54236 .47676 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54236 .47676 L p
1 g
F P
s
P
p
.54883 .48302 m .55834 .49233 L .54236 .47676 L 1 g
F
P
p
.56126 .49939 m .56476 .50654 L .56317 .50306 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56718 .52827 L p
1 g
F P
s
P
p
.56515 .50826 m .56718 .52827 L .56648 .51691 L 1 g
F
P
p
.56602 .50929 m .55354 .54676 L .56476 .50654 L 1 g
F
P
p
.56799 .51361 m .56649 .51703 L .56602 .50929 L 1 g
F
P
p
.56649 .51703 m .55354 .54676 L .56602 .50929 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.57353 .50087 m .57424 .50267 L p
.55354 .54676 L 1 g
F P
s
P
p
.002 w
.57424 .50267 m .58685 .53463 L .56303 .54331 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56156 .54719 L p
1 g
F P
s
P
p
.58685 .53463 m .55327 .56916 L .56156 .54719 L 1 g
F
P
p
.002 w
.56303 .54331 m .56501 .54259 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.56501 .54259 m .58685 .53463 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.56156 .54719 m .56075 .54566 L p
.55526 .55561 L 1 g
F P
s
P
p
.56654 .52734 m .56156 .54719 L .56253 .54463 L 1 g
F
P
p
.56654 .52734 m .56182 .54768 L .56479 .53694 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56301 L p
1 g
F P
s
P
p
.002 w
.55323 .5718 m .54144 .57204 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.5534 .5581 m .55338 .56016 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.55338 .56016 m .55323 .5718 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.54918 .56301 m .54854 .56129 L p
.54065 .56881 L 1 g
F P
s
P
p
.56075 .54566 m .54918 .56301 L .55109 .5608 L 1 g
F
P
p
.56075 .54566 m .54936 .5635 L .55526 .55561 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53168 .5745 L p
1 g
F P
s
P
p
.55323 .5718 m .51203 .58589 L .53168 .5745 L 1 g
F
P
p
.002 w
.53573 .57215 m .53905 .57208 L p
.53168 .5745 L 1 g
F P
s
P
p
.002 w
.53905 .57208 m .55323 .5718 L p
.53168 .5745 L 1 g
F P
s
P
p
.002 w
.53168 .5745 m .53128 .57265 L p
.5206 .57813 L 1 g
F P
s
P
p
.54854 .56129 m .53168 .5745 L .53349 .57345 L 1 g
F
P
p
.54854 .56129 m .53176 .57485 L .54065 .56881 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58084 L p
1 g
F P
s
P
p
.002 w
.51141 .58718 m .49978 .58325 L p
.51096 .58084 L 1 g
F P
s
P
p
.002 w
.5149 .58 m .51449 .58085 L p
.51096 .58084 L 1 g
F P
s
P
p
.002 w
.51449 .58085 m .51141 .58718 L p
.51096 .58084 L 1 g
F P
s
P
p
.002 w
.51096 .58084 m .51079 .57862 L p
.49977 .58082 L 1 g
F P
s
P
p
.53128 .57265 m .51096 .58084 L .51308 .58039 L 1 g
F
P
p
.53128 .57265 m .51099 .58128 L .5206 .57813 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47282 .58199 m .47489 .58028 L p
.51141 .58718 L 1 g
F P
s
P
p
.51141 .58718 m .47489 .58028 L .48712 .58065 L 1 g
F
P
p
.48921 .57862 m .47609 .57754 L .48459 .57968 L 1 g
F
P
p
.002 w
.48905 .58071 m .48921 .57862 L p
.48459 .57968 L 1 g
F P
s
P
p
.002 w
.47489 .58028 m .47756 .57807 L p
.48712 .58065 L 1 g
F P
s
P
p
.002 w
.49899 .58298 m .51141 .58718 L p
.48712 .58065 L 1 g
F P
s
P
p
.48712 .58065 m .47756 .57807 L .48905 .58071 L 1 g
F
P
p
.48712 .58065 m .48905 .58071 L .49899 .58298 L 1 g
F
P
p
.002 w
.47282 .58199 m .46109 .57212 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.47756 .57807 m .47579 .57954 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.47579 .57954 m .47282 .58199 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.46827 .57471 m .46872 .57265 L p
.45899 .56876 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46827 .57471 L p
1 g
F P
s
P
p
.002 w
.46827 .57471 m .4678 .57686 L p
.47609 .57754 L 1 g
F P
s
P
p
.48921 .57862 m .46827 .57471 L .47609 .57754 L 1 g
F
P
p
.47609 .57754 m .4791 .57863 L .48905 .58081 L 1 g
F
P
p
.002 w
.4482 .56069 m .44798 .56109 L .44803 .56046 L p
1 g
F P
s
P
p
.002 w
.44832 .56083 m .44798 .56109 L .4482 .56069 L p
1 g
F P
s
P
p
.002 w
.44841 .56095 m .44798 .56109 L .44832 .56083 L p
1 g
F P
s
P
p
.4389 .55043 m .44887 .56147 L .45067 .56342 L 1 g
F
P
p
.43796 .54962 m .45037 .5631 L .45067 .56342 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45067 .56342 L p
1 g
F P
s
P
p
.002 w
.46109 .57212 m .45104 .56366 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.46356 .58507 m .44865 .56212 L p
.45204 .56491 L 1 g
F P
s
P
p
.002 w
.47282 .58199 m .46903 .58325 L p
.45204 .56491 L 1 g
F P
s
P
p
.002 w
.46903 .58325 m .46356 .58507 L p
.45204 .56491 L 1 g
F P
s
P
p
.002 w
.45104 .56366 m .47282 .58199 L p
.44865 .56212 L 1 g
F P
s
P
p
.45884 .5687 m .45104 .56366 L .45002 .56518 L 1 g
F
P
p
.002 w
.45067 .56342 m .45067 .56342 L p
.45104 .56366 L 1 g
F P
s
P
p
.002 w
.45067 .56342 m .45002 .56518 L p
.45104 .56366 L 1 g
F P
s
P
p
.46872 .57265 m .45067 .56342 L .45884 .5687 L 1 g
F
P
p
.47756 .57807 m .46827 .57471 L .45037 .5631 L 1 g
F
P
p
.002 w
.45104 .56366 m .45037 .5631 L p
.46827 .57471 L 1 g
F P
s
P
p
.002 w
.4682 .57502 m .46827 .57471 L p
.45829 .56849 L 1 g
F P
s
P
p
.45899 .56876 m .45829 .56849 L .46827 .57471 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58071 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58071 L .48982 .58073 L 1 g
F
P
p
.002 w
.49258 .58081 m .49899 .58298 L p
.48905 .58071 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58081 L .49977 .58082 L 1 g
F
P
p
.002 w
.47756 .57807 m .47957 .57641 L .49258 .58081 L p
1 g
F P
s
P
p
.48905 .58071 m .47756 .57807 L .49258 .58081 L 1 g
F
P
p
.002 w
.48905 .58071 m .48905 .58081 L p
.48982 .58073 L 1 g
F P
s
P
p
.5149 .58 m .51096 .58084 L .47957 .57641 L 1 g
F
P
p
.51096 .58084 m .5 .5832 L .49282 .58081 L 1 g
F
P
p
.51096 .58084 m .49282 .58081 L .47957 .57641 L 1 g
F
P
p
.002 w
.49899 .58298 m .47957 .57641 L p
.5 .5832 L 1 g
F P
s
P
p
.002 w
.48905 .58081 m .48889 .583 L p
.49977 .58082 L 1 g
F P
s
P
p
.49977 .58082 m .49888 .581 L .51096 .58084 L 1 g
F
P
p
.49888 .581 m .48889 .583 L .50686 .58124 L 1 g
F
P
p
.49888 .581 m .50686 .58124 L .51096 .58084 L 1 g
F
P
p
.002 w
.49978 .58325 m .49899 .58298 L p
.5 .5832 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51099 .58137 L p
1 g
F P
s
P
p
.002 w
.51099 .58137 m .51096 .58084 L p
.50686 .58124 L 1 g
F P
s
P
p
.50686 .58124 m .48889 .583 L .51099 .58137 L 1 g
F
P
p
.002 w
.48905 .58081 m .48905 .58071 L p
.48459 .57968 L 1 g
F P
s
P
p
.47609 .57754 m .47293 .57728 L .4791 .57863 L 1 g
F
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47957 .57641 m .47756 .57807 L p
.45037 .5631 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58081 L p
1 g
F P
s
P
p
.47293 .57728 m .4678 .57686 L .48905 .58081 L 1 g
F
P
p
.002 w
.51096 .58084 m .51099 .58128 L p
.51308 .58039 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51855 .5725 m .5149 .58 L p
.47957 .57641 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51855 .5725 m .53573 .57215 L p
.53168 .5745 L 1 g
F P
s
P
p
.002 w
.51203 .58589 m .5149 .58 L p
.53168 .5745 L 1 g
F P
s
P
p
.002 w
.5149 .58 m .51855 .5725 L p
.53168 .5745 L 1 g
F P
s
P
p
.002 w
.51099 .58128 m .51111 .583 L p
.5206 .57813 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53168 .5745 L p
1 g
F P
s
P
p
.5206 .57813 m .51111 .583 L .53168 .5745 L 1 g
F
P
p
.002 w
.53168 .5745 m .53176 .57485 L p
.53349 .57345 L 1 g
F P
s
P
p
.002 w
.51141 .58718 m .51203 .58589 L p
.55323 .5718 L 1 g
F P
s
P
p
.5534 .5581 m .54918 .56301 L .51855 .5725 L 1 g
F
P
p
.002 w
.54144 .57204 m .53573 .57215 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.53573 .57215 m .51855 .5725 L p
.54918 .56301 L 1 g
F P
s
P
p
.002 w
.53176 .57485 m .5322 .57686 L p
.54065 .56881 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56301 L p
1 g
F P
s
P
p
.54065 .56881 m .5322 .57686 L .54918 .56301 L 1 g
F
P
p
.002 w
.54918 .56301 m .54936 .5635 L p
.55109 .5608 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55354 .54676 m .5534 .5581 L p
.51855 .5725 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55354 .54676 m .56303 .54331 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.55327 .56916 m .5534 .5581 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.5534 .5581 m .55354 .54676 L p
.56156 .54719 L 1 g
F P
s
P
p
.002 w
.54936 .5635 m .54998 .56518 L p
.55526 .55561 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56156 .54719 L p
1 g
F P
s
P
p
.55526 .55561 m .54998 .56518 L .56156 .54719 L 1 g
F
P
p
.002 w
.56156 .54719 m .56182 .54768 L p
.56253 .54463 L 1 g
F P
s
P
p
.002 w
.55323 .5718 m .55327 .56916 L p
.58685 .53463 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56303 .54331 m .55354 .54676 L p
.57424 .50267 L 1 g
F P
s
P
p
.002 w
.56182 .54768 m .56257 .5491 L p
.56479 .53694 L 1 g
F P
s
P
p
.002 w
.56718 .52827 m .56854 .53025 L p
.56648 .51691 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56602 .50929 L p
1 g
F P
s
P
p
.56648 .51691 m .56854 .53025 L .56602 .50929 L 1 g
F
P
p
.002 w
.56602 .50929 m .56713 .51061 L p
.56317 .50306 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55354 .54676 m .54281 .52074 L .56476 .50654 L p
1 g
F P
s
P
p
.54617 .47851 m .54602 .48031 L .54236 .47676 L 1 g
F
P
p
.002 w
.55721 .49114 m .55834 .49233 L p
.54883 .48302 L 1 g
F P
s
P
p
.002 w
.54236 .47676 m .54242 .47682 L p
.54141 .47632 L 1 g
F P
s
P
p
.52214 .46667 m .54236 .47676 L .54141 .47632 L 1 g
F
P
p
.002 w
.54281 .52074 m .52192 .49678 L .54095 .47611 L p
1 g
F P
s
P
p
.52214 .46667 m .54242 .47682 L .53068 .47109 L 1 g
F
P
p
.002 w
.54095 .47611 m .54687 .46967 L p
.54617 .47851 L 1 g
F P
s
P
p
.002 w
.50978 .44503 m .54687 .46967 L .54095 .47611 L p
1 g
F P
s
P
p
.002 w
.54095 .47611 m .52192 .49678 L p
.51398 .46294 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.50978 .44503 m .54095 .47611 L .51398 .46294 L 1 g
F
P
p
.002 w
.54242 .47682 m .54302 .47747 L p
.53068 .47109 L 1 g
F P
s
P
p
.002 w
.52235 .46703 m .52282 .46778 L p
.50936 .4652 L 1 g
F P
s
P
p
.002 w
.46682 .43016 m .50978 .44503 L .50022 .46392 L p
1 g
F P
s
P
p
.46682 .43016 m .50022 .46392 L .48393 .46114 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.50936 .4652 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.50022 .46392 m .50026 .46384 L p
.50031 .46393 L 1 g
F P
s
P
p
.002 w
.50026 .46384 m .50978 .44503 L p
.51366 .46155 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46389 L p
.48753 .46569 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.49228 .4652 L 1 g
F P
s
P
p
.48753 .46569 m .5 .46389 L .49228 .4652 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.48517 .46337 m .47758 .46713 L .45998 .46633 L 1 g
F
P
p
.45826 .47608 m .47758 .46713 L .46918 .47129 L 1 g
F
P
p
.002 w
.47128 .47025 m .46679 .46869 L p
.47758 .46713 L 1 g
F P
s
P
p
.002 w
.46679 .46869 m .45998 .46633 L p
.47758 .46713 L 1 g
F P
s
P
p
.48517 .46337 m .48653 .46583 L .47758 .46713 L 1 g
F
P
p
.48653 .46583 m .49317 .47785 L .47758 .46713 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47758 .46713 L p
1 g
F P
s
P
p
.48753 .46569 m .5 .46442 L .47758 .46713 L 1 g
F
P
p
.002 w
.47758 .46713 m .47718 .46778 L p
.46918 .47129 L 1 g
F P
s
P
p
.002 w
.45998 .46633 m .46682 .43016 L p
.48517 .46337 L 1 g
F P
s
P
p
.002 w
.45998 .46633 m .47128 .47025 L p
.4631 .47416 L 1 g
F P
s
P
p
.002 w
.47693 .50887 m .45445 .50104 L .45837 .47642 L p
1 g
F P
s
P
p
.002 w
.45837 .47642 m .45445 .50104 L p
.44175 .48407 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45763 .47677 L p
1 g
F P
s
P
p
.002 w
.45763 .47677 m .45765 .47675 L p
.4583 .47645 L 1 g
F P
s
P
p
.4583 .47645 m .47718 .46778 L .45763 .47677 L 1 g
F
P
p
.46823 .47171 m .47563 .46846 L .45837 .47642 L 1 g
F
P
p
.002 w
.45837 .47642 m .45998 .46633 L p
.4631 .47416 L 1 g
F P
s
P
p
.002 w
.42644 .46361 m .45998 .46633 L .45837 .47642 L p
1 g
F P
s
P
p
.42644 .46361 m .45837 .47642 L .44175 .48407 L 1 g
F
P
p
.47563 .46846 m .47718 .46778 L .45765 .47675 L 1 g
F
P
p
.002 w
.45765 .47675 m .45698 .47747 L p
.44957 .48457 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44264 .4913 L p
1 g
F P
s
P
p
.44957 .48457 m .45698 .47747 L .44264 .4913 L 1 g
F
P
p
.43884 .49892 m .43904 .49847 L .43848 .49965 L 1 g
F
P
p
.002 w
.43396 .50925 m .4317 .49906 L p
.43551 .50597 L 1 g
F P
s
P
p
.43904 .49847 m .44027 .49559 L .43396 .50925 L 1 g
F
P
p
.002 w
.45041 .533 m .43899 .53194 L .43396 .50925 L p
1 g
F P
s
P
p
.43551 .50597 m .45041 .533 L .43396 .50925 L 1 g
F
P
p
.002 w
.43396 .50925 m .43899 .53194 L p
.42852 .52102 L 1 g
F P
s
P
p
.41134 .50309 m .43396 .50925 L .42852 .52102 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43389 .5094 L p
1 g
F P
s
P
p
.44027 .49559 m .44166 .49233 L .43389 .5094 L 1 g
F
P
p
.002 w
.43389 .5094 m .43287 .51061 L p
.43317 .51892 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43241 .52886 L p
1 g
F P
s
P
p
.43317 .51892 m .43287 .51061 L .43241 .52886 L 1 g
F
P
p
.002 w
.43241 .52886 m .43146 .53025 L p
.43403 .53534 L 1 g
F P
s
P
p
.002 w
.42869 .53386 m .41134 .50309 L p
.43113 .52375 L 1 g
F P
s
P
p
.002 w
.43344 .53298 m .43899 .53194 L p
.43859 .54784 L 1 g
F P
s
P
p
.002 w
.4384 .54727 m .43743 .5491 L p
.44372 .55457 L 1 g
F P
s
P
p
.002 w
.43147 .53778 m .42869 .53386 L p
.4384 .54727 L 1 g
F P
s
P
p
.002 w
.43899 .53194 m .45041 .533 L .44803 .56046 L p
1 g
F P
s
P
p
.002 w
.44761 .55989 m .43899 .53194 L p
.44803 .56046 L 1 g
F P
s
P
p
.44365 .55454 m .44334 .55427 L .4448 .5561 L 1 g
F
P
p
.44334 .55427 m .44285 .55384 L .44523 .55676 L 1 g
F
P
p
.002 w
.45041 .533 m .46169 .53693 L .4482 .56069 L p
1 g
F P
s
P
p
.002 w
.44803 .56046 m .45041 .533 L p
.4482 .56069 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46169 .53693 m .47152 .5433 L .44832 .56083 L p
1 g
F P
s
P
p
.002 w
.4482 .56069 m .46169 .53693 L p
.44832 .56083 L 1 g
F P
s
P
p
.44285 .55384 m .44213 .55323 L .44568 .55746 L 1 g
F
P
p
.44213 .55323 m .4389 .55043 L .44827 .56078 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47152 .5433 m .47883 .55137 L .44841 .56095 L p
1 g
F P
s
P
p
.002 w
.44832 .56083 m .47152 .5433 L p
.44841 .56095 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48304 .56889 m .47957 .57641 L .44895 .56156 L p
1 g
F P
s
P
p
.002 w
.44895 .56156 m .44798 .56109 L .44866 .56124 L p
1 g
F P
s
P
p
.002 w
.44866 .56124 m .48304 .56889 L p
.44895 .56156 L 1 g
F P
s
P
p
.4389 .55043 m .43796 .54962 L .44887 .56147 L 1 g
F
P
p
.43796 .54962 m .43758 .54929 L .45037 .5631 L 1 g
F
P
p
.002 w
.45037 .5631 m .44798 .56109 L .44895 .56156 L p
1 g
F P
s
P
p
.002 w
.44895 .56156 m .47957 .57641 L p
.45037 .5631 L 1 g
F P
s
P
p
.002 w
.43899 .53194 m .44761 .55989 L p
.4386 .54755 L 1 g
F P
s
P
p
.002 w
.43839 .54727 m .4384 .54727 L p
.43456 .53639 L 1 g
F P
s
P
p
.43476 .53677 m .43456 .53639 L .4384 .54727 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43839 .54727 L p
1 g
F P
s
P
p
.43456 .53639 m .43146 .53025 L .43839 .54727 L 1 g
F
P
p
.002 w
.42863 .5339 m .42869 .53386 L .43147 .53778 L p
1 g
F P
s
P
p
.44377 .55464 m .44105 .55224 L .4412 .55242 L 1 g
F
P
p
.4437 .55455 m .44105 .55224 L .44377 .55464 L 1 g
F
P
p
.4412 .55242 m .43989 .55123 L .44007 .55145 L 1 g
F
P
p
.44105 .55224 m .43989 .55123 L .4412 .55242 L 1 g
F
P
p
.002 w
.47883 .55137 m .4828 .56023 L .44852 .56107 L p
1 g
F P
s
P
p
.002 w
.44841 .56095 m .47883 .55137 L p
.44852 .56107 L 1 g
F P
s
P
p
.002 w
.4828 .56023 m .48304 .56889 L .44866 .56124 L p
1 g
F P
s
P
p
.002 w
.44852 .56107 m .4828 .56023 L p
.44866 .56124 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .43758 .54929 L p
.44007 .55145 L 1 g
F P
s
P
p
.43989 .55123 m .43743 .5491 L .44007 .55145 L 1 g
F
P
p
.002 w
.44865 .56212 m .44798 .56109 L .45104 .56366 L p
1 g
F P
s
P
p
.002 w
.44811 .56176 m .44798 .56109 L .44865 .56212 L p
1 g
F P
s
P
p
.002 w
.42266 .57074 m .41686 .56239 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.41686 .56239 m .41446 .55362 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.41446 .55362 m .41576 .54536 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.41576 .54536 m .42066 .53852 L .44798 .56109 L closepath p
1 g
F P
s
P
p
.002 w
.43758 .54929 m .45002 .56518 L .45067 .56342 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4682 .57502 L p
1 g
F P
s
P
p
.45829 .56849 m .45002 .56518 L .4682 .57502 L 1 g
F
P
p
.002 w
.41576 .54536 m .41446 .55362 L .38401 .5426 L p
1 g
F P
s
P
p
.002 w
.38401 .5426 m .38625 .52626 L .41576 .54536 L p
1 g
F P
s
P
p
.002 w
.58685 .53463 m .58586 .56689 L .55323 .5718 L p
1 g
F P
s
P
p
.002 w
.58586 .56689 m .58685 .53463 L .61717 .51948 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.62671 .45579 m .64346 .50194 L .61717 .51948 L p
1 g
F P
s
P
p
.002 w
.64346 .50194 m .62671 .45579 L .64729 .43231 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.39564 .51256 m .38625 .52626 L .36048 .5045 L p
1 g
F P
s
P
p
.002 w
.36048 .5045 m .37384 .48415 L .39564 .51256 L p
1 g
F P
s
P
p
.002 w
.42458 .35547 m .37293 .36819 L .37269 .33775 L p
1 g
F P
s
P
p
.002 w
.37269 .33775 m .42862 .3234 L .42458 .35547 L p
1 g
F P
s
P
p
.002 w
.38503 .43547 m .35602 .45435 L .34276 .42425 L p
1 g
F P
s
P
p
.002 w
.34276 .42425 m .37707 .40115 L .38503 .43547 L p
1 g
F P
s
P
p
.002 w
.5674 .32131 m .50139 .29873 L .51015 .2752 L p
1 g
F P
s
P
p
.002 w
.51015 .2752 m .57697 .298 L .5674 .32131 L p
1 g
F P
s
P
p
.002 w
.6237 .36003 m .5674 .32131 L .57697 .298 L p
1 g
F P
s
P
p
.002 w
.49234 .327 m .42862 .3234 L .43472 .29529 L p
1 g
F P
s
P
p
.002 w
.43472 .29529 m .50139 .29873 L .49234 .327 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42066 .53852 m .41576 .54536 L .38625 .52626 L p
1 g
F P
s
P
p
.002 w
.38625 .52626 m .39564 .51256 L .42066 .53852 L p
1 g
F P
s
P
p
.002 w
.47957 .57641 m .48304 .56889 L .51855 .5725 L p
1 g
F P
s
P
p
.002 w
.60944 .38549 m .64729 .43231 L .62671 .45579 L p
1 g
F P
s
P
p
.002 w
.64729 .43231 m .60944 .38549 L .6237 .36003 L p
1 g
F P
s
P
p
.002 w
.60184 .47894 m .61717 .51948 L .58685 .53463 L p
1 g
F P
s
P
p
.002 w
.61717 .51948 m .60184 .47894 L .62671 .45579 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.39659 .46988 m .37384 .48415 L .35602 .45435 L p
1 g
F P
s
P
p
.002 w
.35602 .45435 m .38503 .43547 L .39659 .46988 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51842 .55541 m .51855 .5725 L .48304 .56889 L p
1 g
F P
s
P
p
.002 w
.51855 .5725 m .51842 .55541 L .55354 .54676 L p
1 g
F P
s
P
p
.002 w
.5674 .32131 m .6237 .36003 L .60944 .38549 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.42282 .39041 m .37707 .40115 L .37293 .36819 L p
1 g
F P
s
P
p
.002 w
.37293 .36819 m .42458 .35547 L .42282 .39041 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48304 .56889 m .4828 .56023 L .51842 .55541 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41134 .50309 m .39564 .51256 L .37384 .48415 L p
1 g
F P
s
P
p
.002 w
.37384 .48415 m .39659 .46988 L .41134 .50309 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.58685 .53463 m .57353 .50087 L .60184 .47894 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42869 .53386 m .42066 .53852 L .39564 .51256 L p
1 g
F P
s
P
p
.002 w
.39564 .51256 m .41134 .50309 L .42869 .53386 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.55547 .34865 m .49234 .327 L .50139 .29873 L p
1 g
F P
s
P
p
.002 w
.50139 .29873 m .5674 .32131 L .55547 .34865 L p
1 g
F P
s
P
p
.002 w
.4828 .56023 m .47883 .55137 L .51083 .53778 L p
1 g
F P
s
P
p
.002 w
.51083 .53778 m .51842 .55541 L .4828 .56023 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59146 .41294 m .62671 .45579 L .60184 .47894 L p
1 g
F P
s
P
p
.002 w
.62671 .45579 m .59146 .41294 L .60944 .38549 L p
1 g
F P
s
P
p
.002 w
.48333 .35913 m .42458 .35547 L .42862 .3234 L p
1 g
F P
s
P
p
.002 w
.42862 .3234 m .49234 .327 L .48333 .35913 L p
1 g
F P
s
P
p
.002 w
.60944 .38549 m .55547 .34865 L .5674 .32131 L p
1 g
F P
s
P
p
.002 w
.54281 .52074 m .55354 .54676 L .51842 .55541 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42344 .42692 m .38503 .43547 L .37707 .40115 L p
1 g
F P
s
P
p
.002 w
.37707 .40115 m .42282 .39041 L .42344 .42692 L p
1 g
F P
s
P
p
.002 w
.51842 .55541 m .51083 .53778 L .54281 .52074 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.47883 .55137 m .47152 .5433 L .49648 .52162 L p
1 g
F P
s
P
p
.002 w
.49648 .52162 m .51083 .53778 L .47883 .55137 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55547 .34865 m .60944 .38549 L .59146 .41294 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47152 .5433 m .46169 .53693 L .47693 .50887 L p
1 g
F P
s
P
p
.002 w
.47693 .50887 m .49648 .52162 L .47152 .5433 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.42644 .46361 m .39659 .46988 L .38503 .43547 L p
1 g
F P
s
P
p
.002 w
.38503 .43547 m .42344 .42692 L .42644 .46361 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.4317 .49906 m .41134 .50309 L .39659 .46988 L p
1 g
F P
s
P
p
.002 w
.46169 .53693 m .45041 .533 L .45445 .50104 L p
1 g
F P
s
P
p
.002 w
.45445 .50104 m .47693 .50887 L .46169 .53693 L p
1 g
F P
s
P
p
.002 w
.57035 .44136 m .60184 .47894 L .57353 .50087 L p
1 g
F P
s
P
p
.002 w
.60184 .47894 m .57035 .44136 L .59146 .41294 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.39659 .46988 m .42644 .46361 L .4317 .49906 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51083 .53778 m .49648 .52162 L .52192 .49678 L p
1 g
F P
s
P
p
.002 w
.52192 .49678 m .54281 .52074 L .51083 .53778 L p
1 g
F P
s
P
p
.002 w
.4747 .39395 m .42282 .39041 L .42458 .35547 L p
1 g
F P
s
P
p
.002 w
.42458 .35547 m .48333 .35913 L .4747 .39395 L p
1 g
F P
s
P
p
.002 w
.54155 .37915 m .48333 .35913 L .49234 .327 L p
1 g
F P
s
P
p
.002 w
.49234 .327 m .55547 .34865 L .54155 .37915 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57353 .50087 m .54687 .46967 L .57035 .44136 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.59146 .41294 m .54155 .37915 L .55547 .34865 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54155 .37915 m .59146 .41294 L .57035 .44136 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.49648 .52162 m .47693 .50887 L .49317 .47785 L p
1 g
F P
s
P
p
.002 w
.49317 .47785 m .52192 .49678 L .49648 .52162 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.46682 .43016 m .42344 .42692 L .42282 .39041 L p
1 g
F P
s
P
p
.002 w
.42282 .39041 m .4747 .39395 L .46682 .43016 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45998 .46633 m .42644 .46361 L .42344 .42692 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.42344 .42692 m .46682 .43016 L .45998 .46633 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52612 .41169 m .4747 .39395 L .48333 .35913 L p
1 g
F P
s
P
p
.002 w
.48333 .35913 m .54155 .37915 L .52612 .41169 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.52612 .41169 m .57035 .44136 L .54687 .46967 L p
1 g
F P
s
P
p
.002 w
.57035 .44136 m .52612 .41169 L .54155 .37915 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54687 .46967 m .50978 .44503 L .52612 .41169 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.004 w
.42663 .61467 m
.43031 .60543 L
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50978 .44503 m .46682 .43016 L .4747 .39395 L p
1 g
F P
s
P
p
.002 w
.4747 .39395 m .52612 .41169 L .50978 .44503 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .22096 .42274 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .41736 .63795 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.406977)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.406977)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4539 .44531 m .48753 .47051 L .50146 .44582 L p
1 g
F P
s
P
p
.002 w
.50146 .44582 m .47349 .42482 L .4539 .44531 L p
1 g
F P
s
P
p
.002 w
.53389 .45836 m .50146 .44582 L .48753 .47051 L p
1 g
F P
s
P
p
.002 w
.47349 .42482 m .50146 .44582 L .51532 .42082 L p
1 g
F P
s
P
p
.002 w
.50146 .44582 m .53389 .45836 L .54046 .43047 L p
1 g
F P
s
P
p
.002 w
.54046 .43047 m .51532 .42082 L .50146 .44582 L p
1 g
F P
s
P
p
.002 w
.51532 .42082 m .49365 .40454 L .47349 .42482 L p
1 g
F P
s
P
p
.002 w
.49365 .40454 m .51532 .42082 L .52885 .39598 L p
1 g
F P
s
P
p
.002 w
.51532 .42082 m .54046 .43047 L .54607 .40253 L p
1 g
F P
s
P
p
.002 w
.54607 .40253 m .52885 .39598 L .51532 .42082 L p
1 g
F P
s
P
p
.002 w
.45267 .39738 m .47349 .42482 L .49365 .40454 L p
1 g
F P
s
P
p
.002 w
.49365 .40454 m .47762 .38322 L .45267 .39738 L p
1 g
F P
s
P
p
.002 w
.47762 .38322 m .49365 .40454 L .51403 .38482 L p
1 g
F P
s
P
p
.002 w
.52885 .39598 m .51403 .38482 L .49365 .40454 L p
1 g
F P
s
P
p
.002 w
.42874 .41243 m .4539 .44531 L .47349 .42482 L p
1 g
F P
s
P
p
.002 w
.47349 .42482 m .45267 .39738 L .42874 .41243 L p
1 g
F P
s
P
p
.002 w
.56662 .43248 m .54046 .43047 L .53389 .45836 L p
1 g
F P
s
P
p
.002 w
.54046 .43047 m .56662 .43248 L .56395 .4038 L p
1 g
F P
s
P
p
.002 w
.56395 .4038 m .54607 .40253 L .54046 .43047 L p
1 g
F P
s
P
p
.002 w
.43525 .46563 m .47378 .49445 L .48753 .47051 L p
1 g
F P
s
P
p
.002 w
.48753 .47051 m .4539 .44531 L .43525 .46563 L p
1 g
F P
s
P
p
.002 w
.52646 .48569 m .48753 .47051 L .47378 .49445 L p
1 g
F P
s
P
p
.002 w
.48753 .47051 m .52646 .48569 L .53389 .45836 L p
1 g
F P
s
P
p
.002 w
.56767 .46116 m .53389 .45836 L .52646 .48569 L p
1 g
F P
s
P
p
.002 w
.53389 .45836 m .56767 .46116 L .56662 .43248 L p
1 g
F P
s
P
p
.002 w
.51403 .38482 m .52885 .39598 L .54181 .37173 L p
1 g
F P
s
P
p
.002 w
.52885 .39598 m .54607 .40253 L .5506 .37505 L p
1 g
F P
s
P
p
.002 w
.5506 .37505 m .54181 .37173 L .52885 .39598 L p
1 g
F P
s
P
p
.002 w
.51403 .38482 m .50313 .37019 L .47762 .38322 L p
1 g
F P
s
P
p
.002 w
.50313 .37019 m .51403 .38482 L .53425 .36603 L p
1 g
F P
s
P
p
.002 w
.54181 .37173 m .53425 .36603 L .51403 .38482 L p
1 g
F P
s
P
p
.002 w
.40628 .42809 m .43525 .46563 L .4539 .44531 L p
1 g
F P
s
P
p
.002 w
.4539 .44531 m .42874 .41243 L .40628 .42809 L p
1 g
F P
s
P
p
.002 w
.44115 .36607 m .45267 .39738 L .47762 .38322 L p
1 g
F P
s
P
p
.002 w
.47762 .38322 m .46889 .35893 L .44115 .36607 L p
1 g
F P
s
P
p
.002 w
.46889 .35893 m .47762 .38322 L .50313 .37019 L p
1 g
F P
s
P
p
.002 w
.54607 .40253 m .56395 .4038 L .55971 .37564 L p
1 g
F P
s
P
p
.002 w
.55971 .37564 m .5506 .37505 L .54607 .40253 L p
1 g
F P
s
P
p
.002 w
.4146 .37486 m .42874 .41243 L .45267 .39738 L p
1 g
F P
s
P
p
.002 w
.45267 .39738 m .44115 .36607 L .4146 .37486 L p
1 g
F P
s
P
p
.002 w
.50313 .37019 m .4973 .35357 L .46889 .35893 L p
1 g
F P
s
P
p
.002 w
.4973 .35357 m .50313 .37019 L .52873 .35855 L p
1 g
F P
s
P
p
.002 w
.53425 .36603 m .52873 .35855 L .50313 .37019 L p
1 g
F P
s
P
p
.002 w
.47378 .49445 m .51831 .51195 L .52646 .48569 L p
1 g
F P
s
P
p
.002 w
.56707 .4893 m .52646 .48569 L .51831 .51195 L p
1 g
F P
s
P
p
.002 w
.52646 .48569 m .56707 .4893 L .56767 .46116 L p
1 g
F P
s
P
p
.002 w
.59116 .42652 m .56662 .43248 L .56767 .46116 L p
1 g
F P
s
P
p
.002 w
.56662 .43248 m .59116 .42652 L .58064 .39957 L p
1 g
F P
s
P
p
.002 w
.58064 .39957 m .56395 .4038 L .56662 .43248 L p
1 g
F P
s
P
p
.002 w
.41791 .48541 m .46046 .51719 L .47378 .49445 L p
1 g
F P
s
P
p
.002 w
.47378 .49445 m .43525 .46563 L .41791 .48541 L p
1 g
F P
s
P
p
.002 w
.51831 .51195 m .47378 .49445 L .46046 .51719 L p
1 g
F P
s
P
p
.002 w
.56395 .4038 m .58064 .39957 L .56817 .37342 L p
1 g
F P
s
P
p
.002 w
.56817 .37342 m .55971 .37564 L .56395 .4038 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .53425 .36603 L .54181 .37173 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .54181 .37173 L .5506 .37505 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .52873 .35855 L .53425 .36603 L closepath p
1 g
F P
s
P
p
.002 w
.38978 .38516 m .40628 .42809 L .42874 .41243 L p
1 g
F P
s
P
p
.002 w
.42874 .41243 m .4146 .37486 L .38978 .38516 L p
1 g
F P
s
P
p
.002 w
.38576 .44409 m .41791 .48541 L .43525 .46563 L p
1 g
F P
s
P
p
.002 w
.43525 .46563 m .40628 .42809 L .38576 .44409 L p
1 g
F P
s
P
p
.002 w
.59949 .45373 m .56767 .46116 L .56707 .4893 L p
1 g
F P
s
P
p
.002 w
.56767 .46116 m .59949 .45373 L .59116 .42652 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .5506 .37505 L .55971 .37564 L closepath p
1 g
F P
s
P
p
.002 w
.46852 .33411 m .46889 .35893 L .4973 .35357 L p
1 g
F P
s
P
p
.002 w
.4973 .35357 m .49721 .33666 L .46852 .33411 L p
1 g
F P
s
P
p
.002 w
.49721 .33666 m .4973 .35357 L .52583 .35008 L p
1 g
F P
s
P
p
.002 w
.52873 .35855 m .52583 .35008 L .4973 .35357 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .52583 .35008 L .52873 .35855 L closepath p
1 g
F P
s
P
p
.002 w
.44033 .33393 m .44115 .36607 L .46889 .35893 L p
1 g
F P
s
P
p
.002 w
.46889 .35893 m .46852 .33411 L .44033 .33393 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .55971 .37564 L .56817 .37342 L closepath p
1 g
F P
s
P
p
.002 w
.46046 .51719 m .50958 .53663 L .51831 .51195 L p
1 g
F P
s
P
p
.002 w
.56481 .51636 m .51831 .51195 L .50958 .53663 L p
1 g
F P
s
P
p
.002 w
.51831 .51195 m .56481 .51636 L .56707 .4893 L p
1 g
F P
s
P
p
.002 w
.52583 .35008 m .52588 .3415 L .49721 .33666 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .52588 .3415 L .52583 .35008 L closepath p
1 g
F P
s
P
p
.002 w
.59437 .39022 m .58064 .39957 L .59116 .42652 L p
1 g
F P
s
P
p
.002 w
.58064 .39957 m .59437 .39022 L .57507 .3686 L p
1 g
F P
s
P
p
.002 w
.57507 .3686 m .56817 .37342 L .58064 .39957 L p
1 g
F P
s
P
p
.002 w
.41323 .33616 m .4146 .37486 L .44115 .36607 L p
1 g
F P
s
P
p
.002 w
.44115 .36607 m .44033 .33393 L .41323 .33616 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .56817 .37342 L .57507 .3686 L closepath p
1 g
F P
s
P
p
.002 w
.60546 .4807 m .56707 .4893 L .56481 .51636 L p
1 g
F P
s
P
p
.002 w
.56707 .4893 m .60546 .4807 L .59949 .45373 L p
1 g
F P
s
P
p
.002 w
.61148 .41301 m .59116 .42652 L .59949 .45373 L p
1 g
F P
s
P
p
.002 w
.59116 .42652 m .61148 .41301 L .59437 .39022 L p
1 g
F P
s
P
p
.002 w
.50299 .32125 m .49721 .33666 L .52588 .3415 L p
1 g
F P
s
P
p
.002 w
.52588 .3415 m .52889 .33374 L .50299 .32125 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .52889 .33374 L .52588 .3415 L closepath p
1 g
F P
s
P
p
.002 w
.36722 .39681 m .38576 .44409 L .40628 .42809 L p
1 g
F P
s
P
p
.002 w
.40628 .42809 m .38978 .38516 L .36722 .39681 L p
1 g
F P
s
P
p
.002 w
.47674 .31135 m .46852 .33411 L .49721 .33666 L p
1 g
F P
s
P
p
.002 w
.49721 .33666 m .50299 .32125 L .47674 .31135 L p
1 g
F P
s
P
p
.002 w
.40223 .50424 m .44784 .53826 L .46046 .51719 L p
1 g
F P
s
P
p
.002 w
.46046 .51719 m .41791 .48541 L .40223 .50424 L p
1 g
F P
s
P
p
.002 w
.50958 .53663 m .46046 .51719 L .44784 .53826 L p
1 g
F P
s
P
p
.002 w
.57965 .36168 m .57507 .3686 L .59437 .39022 L p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .57507 .3686 L .57965 .36168 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .57965 .36168 L .58139 .35339 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .58139 .35339 L .58008 .34463 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .58008 .34463 L .57583 .33636 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .53459 .32764 L .52889 .33374 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .57583 .33636 L .56909 .32952 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .56909 .32952 L .56062 .32486 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .56062 .32486 L .55136 .32292 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .55136 .32292 L .54236 .32388 L closepath p
1 g
F P
s
P
p
.002 w
.55395 .34854 m .54236 .32388 L .53459 .32764 L closepath p
1 g
F P
s
P
p
.002 w
.36764 .4601 m .40223 .50424 L .41791 .48541 L p
1 g
F P
s
P
p
.002 w
.41791 .48541 m .38576 .44409 L .36764 .4601 L p
1 g
F P
s
P
p
.002 w
.51412 .30904 m .50299 .32125 L .52889 .33374 L p
1 g
F P
s
P
p
.002 w
.52889 .33374 m .53459 .32764 L .51412 .30904 L p
1 g
F P
s
P
p
.002 w
.45067 .30429 m .44033 .33393 L .46852 .33411 L p
1 g
F P
s
P
p
.002 w
.46852 .33411 m .47674 .31135 L .45067 .30429 L p
1 g
F P
s
P
p
.002 w
.3878 .34082 m .38978 .38516 L .4146 .37486 L p
1 g
F P
s
P
p
.002 w
.4146 .37486 m .41323 .33616 L .3878 .34082 L p
1 g
F P
s
P
p
.002 w
.62603 .43651 m .59949 .45373 L .60546 .4807 L p
1 g
F P
s
P
p
.002 w
.59949 .45373 m .62603 .43651 L .61148 .41301 L p
1 g
F P
s
P
p
.002 w
.60361 .37665 m .59437 .39022 L .61148 .41301 L p
1 g
F P
s
P
p
.002 w
.59437 .39022 m .60361 .37665 L .57965 .36168 L p
1 g
F P
s
P
p
.002 w
.58139 .35339 m .57965 .36168 L .60361 .37665 L p
1 g
F P
s
P
p
.002 w
.44784 .53826 m .50041 .55921 L .50958 .53663 L p
1 g
F P
s
P
p
.002 w
.56088 .54178 m .50958 .53663 L .50041 .55921 L p
1 g
F P
s
P
p
.002 w
.50958 .53663 m .56088 .54178 L .56481 .51636 L p
1 g
F P
s
P
p
.002 w
.60888 .50687 m .56481 .51636 L .56088 .54178 L p
1 g
F P
s
P
p
.002 w
.56481 .51636 m .60888 .50687 L .60546 .4807 L p
1 g
F P
s
P
p
.002 w
.52948 .30144 m .51412 .30904 L .53459 .32764 L p
1 g
F P
s
P
p
.002 w
.53459 .32764 m .54236 .32388 L .52948 .30144 L p
1 g
F P
s
P
p
.002 w
.49294 .29317 m .47674 .31135 L .50299 .32125 L p
1 g
F P
s
P
p
.002 w
.50299 .32125 m .51412 .30904 L .49294 .29317 L p
1 g
F P
s
P
p
.002 w
.60361 .37665 m .60724 .36024 L .58139 .35339 L p
1 g
F P
s
P
p
.002 w
.58008 .34463 m .58139 .35339 L .60724 .36024 L p
1 g
F P
s
P
p
.002 w
.62531 .39318 m .61148 .41301 L .62603 .43651 L p
1 g
F P
s
P
p
.002 w
.61148 .41301 m .62531 .39318 L .60361 .37665 L p
1 g
F P
s
P
p
.002 w
.42531 .30029 m .41323 .33616 L .44033 .33393 L p
1 g
F P
s
P
p
.002 w
.44033 .33393 m .45067 .30429 L .42531 .30029 L p
1 g
F P
s
P
p
.002 w
.54742 .2994 m .52948 .30144 L .54236 .32388 L p
1 g
F P
s
P
p
.002 w
.54236 .32388 m .55136 .32292 L .54742 .2994 L p
1 g
F P
s
P
p
.002 w
.34748 .40961 m .36764 .4601 L .38576 .44409 L p
1 g
F P
s
P
p
.002 w
.38576 .44409 m .36722 .39681 L .34748 .40961 L p
1 g
F P
s
P
p
.002 w
.60724 .36024 m .60361 .37665 L .62531 .39318 L p
1 g
F P
s
P
p
.002 w
.63766 .46028 m .60546 .4807 L .60888 .50687 L p
1 g
F P
s
P
p
.002 w
.60546 .4807 m .63766 .46028 L .62603 .43651 L p
1 g
F P
s
P
p
.002 w
.60724 .36024 m .60476 .34279 L .58008 .34463 L p
1 g
F P
s
P
p
.002 w
.57583 .33636 m .58008 .34463 L .60476 .34279 L p
1 g
F P
s
P
p
.002 w
.36462 .34788 m .36722 .39681 L .38978 .38516 L p
1 g
F P
s
P
p
.002 w
.38978 .38516 m .3878 .34082 L .36462 .34788 L p
1 g
F P
s
P
p
.002 w
.56594 .30323 m .54742 .2994 L .55136 .32292 L p
1 g
F P
s
P
p
.002 w
.55136 .32292 m .56062 .32486 L .56594 .30323 L p
1 g
F P
s
P
p
.002 w
.3886 .52172 m .4362 .55718 L .44784 .53826 L p
1 g
F P
s
P
p
.002 w
.44784 .53826 m .40223 .50424 L .3886 .52172 L p
1 g
F P
s
P
p
.002 w
.50041 .55921 m .44784 .53826 L .4362 .55718 L p
1 g
F P
s
P
p
.002 w
.60476 .34279 m .59635 .32625 L .57583 .33636 L p
1 g
F P
s
P
p
.002 w
.56909 .32952 m .57583 .33636 L .59635 .32625 L p
1 g
F P
s
P
p
.002 w
.47147 .28045 m .45067 .30429 L .47674 .31135 L p
1 g
F P
s
P
p
.002 w
.47674 .31135 m .49294 .29317 L .47147 .28045 L p
1 g
F P
s
P
p
.002 w
.5829 .31253 m .56594 .30323 L .56062 .32486 L p
1 g
F P
s
P
p
.002 w
.56062 .32486 m .56909 .32952 L .5829 .31253 L p
1 g
F P
s
P
p
.002 w
.51555 .28174 m .49294 .29317 L .51412 .30904 L p
1 g
F P
s
P
p
.002 w
.51412 .30904 m .52948 .30144 L .51555 .28174 L p
1 g
F P
s
P
p
.002 w
.59635 .32625 m .5829 .31253 L .56909 .32952 L p
1 g
F P
s
P
p
.002 w
.35238 .47582 m .3886 .52172 L .40223 .50424 L p
1 g
F P
s
P
p
.002 w
.40223 .50424 m .36764 .4601 L .35238 .47582 L p
1 g
F P
s
P
p
.002 w
.64427 .41097 m .62603 .43651 L .63766 .46028 L p
1 g
F P
s
P
p
.002 w
.62603 .43651 m .64427 .41097 L .62531 .39318 L p
1 g
F P
s
P
p
.002 w
.50041 .55921 m .55532 .565 L .56088 .54178 L p
1 g
F P
s
P
p
.002 w
.60962 .53169 m .56088 .54178 L .55532 .565 L p
1 g
F P
s
P
p
.002 w
.56088 .54178 m .60962 .53169 L .60888 .50687 L p
1 g
F P
s
P
p
.002 w
.40125 .29954 m .3878 .34082 L .41323 .33616 L p
1 g
F P
s
P
p
.002 w
.41323 .33616 m .42531 .30029 L .40125 .29954 L p
1 g
F P
s
P
p
.002 w
.62531 .39318 m .63092 .36902 L .60724 .36024 L p
1 g
F P
s
P
p
.002 w
.60476 .34279 m .60724 .36024 L .63092 .36902 L p
1 g
F P
s
P
p
.002 w
.4362 .55718 m .49098 .57914 L .50041 .55921 L p
1 g
F P
s
P
p
.002 w
.55532 .565 m .50041 .55921 L .49098 .57914 L p
1 g
F P
s
P
p
.002 w
.63092 .36902 m .62531 .39318 L .64427 .41097 L p
1 g
F P
s
P
p
.002 w
.54216 .27856 m .51555 .28174 L .52948 .30144 L p
1 g
F P
s
P
p
.002 w
.52948 .30144 m .54742 .2994 L .54216 .27856 L p
1 g
F P
s
P
p
.002 w
.64603 .48383 m .60888 .50687 L .60962 .53169 L p
1 g
F P
s
P
p
.002 w
.60888 .50687 m .64603 .48383 L .63766 .46028 L p
1 g
F P
s
P
p
.002 w
.45017 .27125 m .42531 .30029 L .45067 .30429 L p
1 g
F P
s
P
p
.002 w
.45067 .30429 m .47147 .28045 L .45017 .27125 L p
1 g
F P
s
P
p
.002 w
.3311 .42333 m .35238 .47582 L .36764 .4601 L p
1 g
F P
s
P
p
.002 w
.36764 .4601 m .34748 .40961 L .3311 .42333 L p
1 g
F P
s
P
p
.002 w
.63092 .36902 m .62743 .34314 L .60476 .34279 L p
1 g
F P
s
P
p
.002 w
.59635 .32625 m .60476 .34279 L .62743 .34314 L p
1 g
F P
s
P
p
.002 w
.3443 .35729 m .34748 .40961 L .36722 .39681 L p
1 g
F P
s
P
p
.002 w
.36722 .39681 m .36462 .34788 L .3443 .35729 L p
1 g
F P
s
P
p
.002 w
.50083 .26532 m .47147 .28045 L .49294 .29317 L p
1 g
F P
s
P
p
.002 w
.49294 .29317 m .51555 .28174 L .50083 .26532 L p
1 g
F P
s
P
p
.002 w
.56973 .28417 m .54216 .27856 L .54742 .2994 L p
1 g
F P
s
P
p
.002 w
.54742 .2994 m .56594 .30323 L .56973 .28417 L p
1 g
F P
s
P
p
.002 w
.65998 .42969 m .63766 .46028 L .64603 .48383 L p
1 g
F P
s
P
p
.002 w
.63766 .46028 m .65998 .42969 L .64427 .41097 L p
1 g
F P
s
P
p
.002 w
.3774 .53742 m .42583 .57345 L .4362 .55718 L p
1 g
F P
s
P
p
.002 w
.4362 .55718 m .3886 .52172 L .3774 .53742 L p
1 g
F P
s
P
p
.002 w
.49098 .57914 m .4362 .55718 L .42583 .57345 L p
1 g
F P
s
P
p
.002 w
.62743 .34314 m .61503 .3185 L .59635 .32625 L p
1 g
F P
s
P
p
.002 w
.5829 .31253 m .59635 .32625 L .61503 .3185 L p
1 g
F P
s
P
p
.002 w
.59502 .29802 m .56973 .28417 L .56594 .30323 L p
1 g
F P
s
P
p
.002 w
.56594 .30323 m .5829 .31253 L .59502 .29802 L p
1 g
F P
s
P
p
.002 w
.37907 .30219 m .36462 .34788 L .3878 .34082 L p
1 g
F P
s
P
p
.002 w
.3878 .34082 m .40125 .29954 L .37907 .30219 L p
1 g
F P
s
P
p
.002 w
.34046 .49087 m .3774 .53742 L .3886 .52172 L p
1 g
F P
s
P
p
.002 w
.3886 .52172 m .35238 .47582 L .34046 .49087 L p
1 g
F P
s
P
p
.002 w
.61503 .3185 m .59502 .29802 L .5829 .31253 L p
1 g
F P
s
P
p
.002 w
.64427 .41097 m .65185 .37959 L .63092 .36902 L p
1 g
F P
s
P
p
.002 w
.62743 .34314 m .63092 .36902 L .65185 .37959 L p
1 g
F P
s
P
p
.002 w
.49098 .57914 m .54818 .58544 L .55532 .565 L p
1 g
F P
s
P
p
.002 w
.60756 .55457 m .55532 .565 L .54818 .58544 L p
1 g
F P
s
P
p
.002 w
.55532 .565 m .60756 .55457 L .60962 .53169 L p
1 g
F P
s
P
p
.002 w
.65185 .37959 m .64427 .41097 L .65998 .42969 L p
1 g
F P
s
P
p
.002 w
.42583 .57345 m .48148 .59588 L .49098 .57914 L p
1 g
F P
s
P
p
.002 w
.54818 .58544 m .49098 .57914 L .48148 .59588 L p
1 g
F P
s
P
p
.002 w
.65085 .50662 m .60962 .53169 L .60756 .55457 L p
1 g
F P
s
P
p
.002 w
.60962 .53169 m .65085 .50662 L .64603 .48383 L p
1 g
F P
s
P
p
.002 w
.53562 .26098 m .50083 .26532 L .51555 .28174 L p
1 g
F P
s
P
p
.002 w
.51555 .28174 m .54216 .27856 L .53562 .26098 L p
1 g
F P
s
P
p
.002 w
.42953 .26596 m .40125 .29954 L .42531 .30029 L p
1 g
F P
s
P
p
.002 w
.42531 .30029 m .45017 .27125 L .42953 .26596 L p
1 g
F P
s
P
p
.002 w
.48561 .25269 m .45017 .27125 L .47147 .28045 L p
1 g
F P
s
P
p
.002 w
.47147 .28045 m .50083 .26532 L .48561 .25269 L p
1 g
F P
s
P
p
.002 w
.32744 .36893 m .3311 .42333 L .34748 .40961 L p
1 g
F P
s
P
p
.002 w
.34748 .40961 m .3443 .35729 L .32744 .36893 L p
1 g
F P
s
P
p
.002 w
.31862 .4377 m .34046 .49087 L .35238 .47582 L p
1 g
F P
s
P
p
.002 w
.35238 .47582 m .3311 .42333 L .31862 .4377 L p
1 g
F P
s
P
p
.002 w
.65185 .37959 m .64751 .34576 L .62743 .34314 L p
1 g
F P
s
P
p
.002 w
.61503 .3185 m .62743 .34314 L .64751 .34576 L p
1 g
F P
s
P
p
.002 w
.67197 .44895 m .64603 .48383 L .65085 .50662 L p
1 g
F P
s
P
p
.002 w
.64603 .48383 m .67197 .44895 L .65998 .42969 L p
1 g
F P
s
P
p
.002 w
.57184 .26825 m .53562 .26098 L .54216 .27856 L p
1 g
F P
s
P
p
.002 w
.54216 .27856 m .56973 .28417 L .57184 .26825 L p
1 g
F P
s
P
p
.002 w
.3594 .30833 m .3443 .35729 L .36462 .34788 L p
1 g
F P
s
P
p
.002 w
.36462 .34788 m .37907 .30219 L .3594 .30833 L p
1 g
F P
s
P
p
.002 w
.66946 .39181 m .65998 .42969 L .67197 .44895 L p
1 g
F P
s
P
p
.002 w
.65998 .42969 m .66946 .39181 L .65185 .37959 L p
1 g
F P
s
P
p
.002 w
.64751 .34576 m .65185 .37959 L .66946 .39181 L p
1 g
F P
s
P
p
.002 w
.64751 .34576 m .63136 .3134 L .61503 .3185 L p
1 g
F P
s
P
p
.002 w
.59502 .29802 m .61503 .3185 L .63136 .3134 L p
1 g
F P
s
P
p
.002 w
.369 .55088 m .41701 .58657 L .42583 .57345 L p
1 g
F P
s
P
p
.002 w
.42583 .57345 m .3774 .53742 L .369 .55088 L p
1 g
F P
s
P
p
.002 w
.48148 .59588 m .42583 .57345 L .41701 .58657 L p
1 g
F P
s
P
p
.002 w
.6051 .28645 m .57184 .26825 L .56973 .28417 L p
1 g
F P
s
P
p
.002 w
.56973 .28417 m .59502 .29802 L .6051 .28645 L p
1 g
F P
s
P
p
.002 w
.48148 .59588 m .53955 .6025 L .54818 .58544 L p
1 g
F P
s
P
p
.002 w
.60263 .57491 m .54818 .58544 L .53955 .6025 L p
1 g
F P
s
P
p
.002 w
.54818 .58544 m .60263 .57491 L .60756 .55457 L p
1 g
F P
s
P
p
.002 w
.33231 .50487 m .369 .55088 L .3774 .53742 L p
1 g
F P
s
P
p
.002 w
.3774 .53742 m .34046 .49087 L .33231 .50487 L p
1 g
F P
s
P
p
.002 w
.63136 .3134 m .6051 .28645 L .59502 .29802 L p
1 g
F P
s
P
p
.002 w
.41007 .26487 m .37907 .30219 L .40125 .29954 L p
1 g
F P
s
P
p
.002 w
.40125 .29954 m .42953 .26596 L .41007 .26487 L p
1 g
F P
s
P
p
.002 w
.65186 .5281 m .60756 .55457 L .60263 .57491 L p
1 g
F P
s
P
p
.002 w
.60756 .55457 m .65186 .5281 L .65085 .50662 L p
1 g
F P
s
P
p
.002 w
.5279 .24724 m .48561 .25269 L .50083 .26532 L p
1 g
F P
s
P
p
.002 w
.50083 .26532 m .53562 .26098 L .5279 .24724 L p
1 g
F P
s
P
p
.002 w
.41701 .58657 m .47212 .60888 L .48148 .59588 L p
1 g
F P
s
P
p
.002 w
.53955 .6025 m .48148 .59588 L .47212 .60888 L p
1 g
F P
s
P
p
.002 w
.47023 .24435 m .42953 .26596 L .45017 .27125 L p
1 g
F P
s
P
p
.002 w
.45017 .27125 m .48561 .25269 L .47023 .24435 L p
1 g
F P
s
P
p
.002 w
.67979 .46833 m .65085 .50662 L .65186 .5281 L p
1 g
F P
s
P
p
.002 w
.65085 .50662 m .67979 .46833 L .67197 .44895 L p
1 g
F P
s
P
p
.002 w
.31464 .38262 m .31862 .4377 L .3311 .42333 L p
1 g
F P
s
P
p
.002 w
.3311 .42333 m .32744 .36893 L .31464 .38262 L p
1 g
F P
s
P
p
.002 w
.66946 .39181 m .6644 .35071 L .64751 .34576 L p
1 g
F P
s
P
p
.002 w
.63136 .3134 m .64751 .34576 L .6644 .35071 L p
1 g
F P
s
P
p
.002 w
.31054 .4524 m .33231 .50487 L .34046 .49087 L p
1 g
F P
s
P
p
.002 w
.34046 .49087 m .31862 .4377 L .31054 .4524 L p
1 g
F P
s
P
p
.002 w
.34285 .31798 m .32744 .36893 L .3443 .35729 L p
1 g
F P
s
P
p
.002 w
.3443 .35729 m .3594 .30833 L .34285 .31798 L p
1 g
F P
s
P
p
.002 w
.68316 .40546 m .67197 .44895 L .67979 .46833 L p
1 g
F P
s
P
p
.002 w
.67197 .44895 m .68316 .40546 L .66946 .39181 L p
1 g
F P
s
P
p
.002 w
.57211 .25604 m .5279 .24724 L .53562 .26098 L p
1 g
F P
s
P
p
.002 w
.53562 .26098 m .57184 .26825 L .57211 .25604 L p
1 g
F P
s
P
p
.002 w
.6644 .35071 m .66946 .39181 L .68316 .40546 L p
1 g
F P
s
P
p
.002 w
.6644 .35071 m .64483 .31122 L .63136 .3134 L p
1 g
F P
s
P
p
.002 w
.6051 .28645 m .63136 .3134 L .64483 .31122 L p
1 g
F P
s
P
p
.002 w
.39235 .26825 m .3594 .30833 L .37907 .30219 L p
1 g
F P
s
P
p
.002 w
.37907 .30219 m .41007 .26487 L .39235 .26825 L p
1 g
F P
s
P
p
.002 w
.47212 .60888 m .52955 .6156 L .53955 .6025 L p
1 g
F P
s
P
p
.002 w
.59479 .5921 m .53955 .6025 L .52955 .6156 L p
1 g
F P
s
P
p
.002 w
.53955 .6025 m .59479 .5921 L .60263 .57491 L p
1 g
F P
s
P
p
.002 w
.36376 .56167 m .41006 .59606 L .41701 .58657 L p
1 g
F P
s
P
p
.002 w
.41701 .58657 m .369 .55088 L .36376 .56167 L p
1 g
F P
s
P
p
.002 w
.47212 .60888 m .41701 .58657 L .41006 .59606 L p
1 g
F P
s
P
p
.002 w
.64883 .54769 m .60263 .57491 L .59479 .5921 L p
1 g
F P
s
P
p
.002 w
.60263 .57491 m .64883 .54769 L .65186 .5281 L p
1 g
F P
s
P
p
.002 w
.61278 .27827 m .57211 .25604 L .57184 .26825 L p
1 g
F P
s
P
p
.002 w
.57184 .26825 m .6051 .28645 L .61278 .27827 L p
1 g
F P
s
P
p
.002 w
.32836 .51742 m .36376 .56167 L .369 .55088 L p
1 g
F P
s
P
p
.002 w
.369 .55088 m .33231 .50487 L .32836 .51742 L p
1 g
F P
s
P
p
.002 w
.64483 .31122 m .61278 .27827 L .6051 .28645 L p
1 g
F P
s
P
p
.002 w
.51911 .23792 m .47023 .24435 L .48561 .25269 L p
1 g
F P
s
P
p
.002 w
.48561 .25269 m .5279 .24724 L .51911 .23792 L p
1 g
F P
s
P
p
.002 w
.45507 .24076 m .41007 .26487 L .42953 .26596 L p
1 g
F P
s
P
p
.002 w
.42953 .26596 m .47023 .24435 L .45507 .24076 L p
1 g
F P
s
P
p
.002 w
.68305 .48735 m .65186 .5281 L .64883 .54769 L p
1 g
F P
s
P
p
.002 w
.65186 .5281 m .68305 .48735 L .67979 .46833 L p
1 g
F P
s
P
p
.002 w
.41006 .59606 m .46314 .61761 L .47212 .60888 L p
1 g
F P
s
P
p
.002 w
.52955 .6156 m .47212 .60888 L .46314 .61761 L p
1 g
F P
s
P
p
.002 w
.30644 .39813 m .31054 .4524 L .31862 .4377 L p
1 g
F P
s
P
p
.002 w
.31862 .4377 m .31464 .38262 L .30644 .39813 L p
1 g
F P
s
P
p
.002 w
.68316 .40546 m .6775 .358 L .6644 .35071 L p
1 g
F P
s
P
p
.002 w
.64483 .31122 m .6644 .35071 L .6775 .358 L p
1 g
F P
s
P
p
.002 w
.33002 .33108 m .31464 .38262 L .32744 .36893 L p
1 g
F P
s
P
p
.002 w
.32744 .36893 m .34285 .31798 L .33002 .33108 L p
1 g
F P
s
P
p
.002 w
.30734 .46707 m .32836 .51742 L .33231 .50487 L p
1 g
F P
s
P
p
.002 w
.33231 .50487 m .31054 .4524 L .30734 .46707 L p
1 g
F P
s
P
p
.002 w
.69243 .42028 m .67979 .46833 L .68305 .48735 L p
1 g
F P
s
P
p
.002 w
.67979 .46833 m .69243 .42028 L .68316 .40546 L p
1 g
F P
s
P
p
.002 w
.6775 .358 m .68316 .40546 L .69243 .42028 L p
1 g
F P
s
P
p
.002 w
.57042 .24806 m .51911 .23792 L .5279 .24724 L p
1 g
F P
s
P
p
.002 w
.5279 .24724 m .57211 .25604 L .57042 .24806 L p
1 g
F P
s
P
p
.002 w
.37696 .27624 m .34285 .31798 L .3594 .30833 L p
1 g
F P
s
P
p
.002 w
.3594 .30833 m .39235 .26825 L .37696 .27624 L p
1 g
F P
s
P
p
.002 w
.52955 .6156 m .5841 .60555 L .59479 .5921 L p
1 g
F P
s
P
p
.002 w
.64165 .56478 m .59479 .5921 L .5841 .60555 L p
1 g
F P
s
P
p
.002 w
.59479 .5921 m .64165 .56478 L .64883 .54769 L p
1 g
F P
s
P
p
.002 w
.46314 .61761 m .51836 .62419 L .52955 .6156 L p
1 g
F P
s
P
p
.002 w
.5841 .60555 m .52955 .6156 L .51836 .62419 L p
1 g
F P
s
P
p
.002 w
.6775 .358 m .65491 .3122 L .64483 .31122 L p
1 g
F P
s
P
p
.002 w
.61278 .27827 m .64483 .31122 L .65491 .3122 L p
1 g
F P
s
P
p
.002 w
.36202 .56933 m .40526 .60144 L .41006 .59606 L p
1 g
F P
s
P
p
.002 w
.41006 .59606 m .36376 .56167 L .36202 .56933 L p
1 g
F P
s
P
p
.002 w
.46314 .61761 m .41006 .59606 L .40526 .60144 L p
1 g
F P
s
P
p
.002 w
.44057 .24229 m .39235 .26825 L .41007 .26487 L p
1 g
F P
s
P
p
.002 w
.41007 .26487 m .45507 .24076 L .44057 .24229 L p
1 g
F P
s
P
p
.002 w
.50944 .23352 m .45507 .24076 L .47023 .24435 L p
1 g
F P
s
P
p
.002 w
.47023 .24435 m .51911 .23792 L .50944 .23352 L p
1 g
F P
s
P
p
.002 w
.61771 .27389 m .57042 .24806 L .57211 .25604 L p
1 g
F P
s
P
p
.002 w
.57211 .25604 m .61278 .27827 L .61771 .27389 L p
1 g
F P
s
P
p
.002 w
.32897 .5281 m .36202 .56933 L .36376 .56167 L p
1 g
F P
s
P
p
.002 w
.36376 .56167 m .32836 .51742 L .32897 .5281 L p
1 g
F P
s
P
p
.002 w
.68141 .50551 m .64883 .54769 L .64165 .56478 L p
1 g
F P
s
P
p
.002 w
.64883 .54769 m .68141 .50551 L .68305 .48735 L p
1 g
F P
s
P
p
.002 w
.65491 .3122 m .61771 .27389 L .61278 .27827 L p
1 g
F P
s
P
p
.002 w
.40526 .60144 m .45479 .62158 L .46314 .61761 L p
1 g
F P
s
P
p
.002 w
.51836 .62419 m .46314 .61761 L .45479 .62158 L p
1 g
F P
s
P
p
.002 w
.30332 .41513 m .30734 .46707 L .31054 .4524 L p
1 g
F P
s
P
p
.002 w
.31054 .4524 m .30644 .39813 L .30332 .41513 L p
1 g
F P
s
P
p
.002 w
.32147 .34744 m .30644 .39813 L .31464 .38262 L p
1 g
F P
s
P
p
.002 w
.31464 .38262 m .33002 .33108 L .32147 .34744 L p
1 g
F P
s
P
p
.002 w
.69675 .43593 m .68305 .48735 L .68141 .50551 L p
1 g
F P
s
P
p
.002 w
.68305 .48735 m .69675 .43593 L .69243 .42028 L p
1 g
F P
s
P
p
.002 w
.69243 .42028 m .68627 .36756 L .6775 .358 L p
1 g
F P
s
P
p
.002 w
.65491 .3122 m .6775 .358 L .68627 .36756 L p
1 g
F P
s
P
p
.002 w
.30938 .4813 m .32897 .5281 L .32836 .51742 L p
1 g
F P
s
P
p
.002 w
.32836 .51742 m .30734 .46707 L .30938 .4813 L p
1 g
F P
s
P
p
.002 w
.68627 .36756 m .69243 .42028 L .69675 .43593 L p
1 g
F P
s
P
p
.002 w
.36445 .28888 m .33002 .33108 L .34285 .31798 L p
1 g
F P
s
P
p
.002 w
.34285 .31798 m .37696 .27624 L .36445 .28888 L p
1 g
F P
s
P
p
.002 w
.56671 .24482 m .50944 .23352 L .51911 .23792 L p
1 g
F P
s
P
p
.002 w
.51911 .23792 m .57042 .24806 L .56671 .24482 L p
1 g
F P
s
P
p
.002 w
.51836 .62419 m .57068 .61467 L .5841 .60555 L p
1 g
F P
s
P
p
.002 w
.63028 .57878 m .5841 .60555 L .57068 .61467 L p
1 g
F P
s
P
p
.002 w
.5841 .60555 m .63028 .57878 L .64165 .56478 L p
1 g
F P
s
P
p
.002 w
.45479 .62158 m .5062 .62777 L .51836 .62419 L p
1 g
F P
s
P
p
.002 w
.57068 .61467 m .51836 .62419 L .5062 .62777 L p
1 g
F P
s
P
p
.002 w
.42716 .2492 m .37696 .27624 L .39235 .26825 L p
1 g
F P
s
P
p
.002 w
.39235 .26825 m .44057 .24229 L .42716 .2492 L p
1 g
F P
s
P
p
.002 w
.68627 .36756 m .66113 .3165 L .65491 .3122 L p
1 g
F P
s
P
p
.002 w
.61771 .27389 m .65491 .3122 L .66113 .3165 L p
1 g
F P
s
P
p
.002 w
.49908 .23449 m .44057 .24229 L .45507 .24076 L p
1 g
F P
s
P
p
.002 w
.45507 .24076 m .50944 .23352 L .49908 .23449 L p
1 g
F P
s
P
p
.002 w
.64165 .56478 m .67465 .52224 L .68141 .50551 L p
1 g
F P
s
P
p
.002 w
.67465 .52224 m .64165 .56478 L .63028 .57878 L p
1 g
F P
s
P
p
.002 w
.36406 .57346 m .40289 .60229 L .40526 .60144 L p
1 g
F P
s
P
p
.002 w
.40526 .60144 m .36202 .56933 L .36406 .57346 L p
1 g
F P
s
P
p
.002 w
.45479 .62158 m .40526 .60144 L .40289 .60229 L p
1 g
F P
s
P
p
.002 w
.61956 .27369 m .56671 .24482 L .57042 .24806 L p
1 g
F P
s
P
p
.002 w
.57042 .24806 m .61771 .27389 L .61956 .27369 L p
1 g
F P
s
P
p
.004 w
.29095 .30883 m
.31531 .32301 L
s
P
p
.004 w
.28747 .30681 m
.29095 .30883 L
s
P
p
.004 w
.28528 .30553 m
.28747 .30681 L
s
P
p
.002 w
.33441 .53649 m .36406 .57346 L .36202 .56933 L p
1 g
F P
s
P
p
.002 w
.36202 .56933 m .32897 .5281 L .33441 .53649 L p
1 g
F P
s
P
p
.002 w
.66113 .3165 m .61956 .27369 L .61771 .27389 L p
1 g
F P
s
P
p
.002 w
.30568 .43321 m .30938 .4813 L .30734 .46707 L p
1 g
F P
s
P
p
.002 w
.30734 .46707 m .30332 .41513 L .30568 .43321 L p
1 g
F P
s
P
p
.002 w
.31771 .36677 m .30332 .41513 L .30644 .39813 L p
1 g
F P
s
P
p
.002 w
.30644 .39813 m .32147 .34744 L .31771 .36677 L p
1 g
F P
s
P
p
.002 w
.68141 .50551 m .69573 .45205 L .69675 .43593 L p
1 g
F P
s
P
p
.002 w
.69573 .45205 m .68141 .50551 L .67465 .52224 L p
1 g
F P
s
P
p
.002 w
.40289 .60229 m .44734 .62039 L .45479 .62158 L p
1 g
F P
s
P
p
.002 w
.5062 .62777 m .45479 .62158 L .44734 .62039 L p
1 g
F P
s
P
p
.002 w
.69675 .43593 m .69018 .37929 L .68627 .36756 L p
1 g
F P
s
P
p
.002 w
.66113 .3165 m .68627 .36756 L .69018 .37929 L p
1 g
F P
s
P
p
.002 w
.69018 .37929 m .69675 .43593 L .69573 .45205 L p
1 g
F P
s
P
p
.002 w
.31692 .49466 m .33441 .53649 L .32897 .5281 L p
1 g
F P
s
P
p
.002 w
.32897 .5281 m .30938 .4813 L .31692 .49466 L p
1 g
F P
s
P
p
.002 w
.35537 .30605 m .32147 .34744 L .33002 .33108 L p
1 g
F P
s
P
p
.002 w
.33002 .33108 m .36445 .28888 L .35537 .30605 L p
1 g
F P
s
P
p
.002 w
.56092 .24672 m .49908 .23449 L .50944 .23352 L p
1 g
F P
s
P
p
.002 w
.50944 .23352 m .56671 .24482 L .56092 .24672 L p
1 g
F P
s
P
p
.002 w
.5062 .62777 m .55475 .61895 L .57068 .61467 L p
1 g
F P
s
P
p
.002 w
.57068 .61467 m .61481 .58911 L .63028 .57878 L p
1 g
F P
s
P
p
.002 w
.61481 .58911 m .57068 .61467 L .55475 .61895 L p
1 g
F P
s
P
p
.002 w
.41533 .26161 m .36445 .28888 L .37696 .27624 L p
1 g
F P
s
P
p
.002 w
.37696 .27624 m .42716 .2492 L .41533 .26161 L p
1 g
F P
s
P
p
.002 w
.44734 .62039 m .49337 .62592 L .5062 .62777 L p
1 g
F P
s
P
p
.002 w
.55475 .61895 m .5062 .62777 L .49337 .62592 L p
1 g
F P
s
P
p
.002 w
.66269 .53699 m .63028 .57878 L .61481 .58911 L p
1 g
F P
s
P
p
.002 w
.63028 .57878 m .66269 .53699 L .67465 .52224 L p
1 g
F P
s
P
p
.002 w
.48832 .24114 m .42716 .2492 L .44057 .24229 L p
1 g
F P
s
P
p
.002 w
.44057 .24229 m .49908 .23449 L .48832 .24114 L p
1 g
F P
s
P
p
.002 w
.69018 .37929 m .66305 .32423 L .66113 .3165 L p
1 g
F P
s
P
p
.002 w
.61956 .27369 m .66113 .3165 L .66305 .32423 L p
1 g
F P
s
P
p
.002 w
.37005 .5737 m .40318 .5983 L .40289 .60229 L p
1 g
F P
s
P
p
.002 w
.40289 .60229 m .36406 .57346 L .37005 .5737 L p
1 g
F P
s
P
p
.002 w
.44734 .62039 m .40289 .60229 L .40318 .5983 L p
1 g
F P
s
P
p
.002 w
.61809 .27796 m .56092 .24672 L .56671 .24482 L p
1 g
F P
s
P
p
.002 w
.56671 .24482 m .61956 .27369 L .61809 .27796 L p
1 g
F P
s
P
p
.002 w
.68908 .46817 m .67465 .52224 L .66269 .53699 L p
1 g
F P
s
P
p
.002 w
.67465 .52224 m .68908 .46817 L .69573 .45205 L p
1 g
F P
s
P
p
.002 w
.3191 .38863 m .30568 .43321 L .30332 .41513 L p
1 g
F P
s
P
p
.002 w
.30332 .41513 m .31771 .36677 L .3191 .38863 L p
1 g
F P
s
P
p
.002 w
.34482 .5422 m .37005 .5737 L .36406 .57346 L p
1 g
F P
s
P
p
.002 w
.36406 .57346 m .33441 .53649 L .34482 .5422 L p
1 g
F P
s
P
p
.002 w
.31373 .45186 m .31692 .49466 L .30938 .4813 L p
1 g
F P
s
P
p
.002 w
.30938 .4813 m .30568 .43321 L .31373 .45186 L p
1 g
F P
s
P
p
.002 w
.66305 .32423 m .61809 .27796 L .61956 .27369 L p
1 g
F P
s
P
p
.002 w
.40318 .5983 m .44108 .61371 L .44734 .62039 L p
1 g
F P
s
P
p
.002 w
.49337 .62592 m .44734 .62039 L .44108 .61371 L p
1 g
F P
s
P
p
.002 w
.69573 .45205 m .68882 .39295 L .69018 .37929 L p
1 g
F P
s
P
p
.002 w
.66305 .32423 m .69018 .37929 L .68882 .39295 L p
1 g
F P
s
P
p
.002 w
.68882 .39295 m .69573 .45205 L .68908 .46817 L p
1 g
F P
s
P
p
.002 w
.35019 .32746 m .31771 .36677 L .32147 .34744 L p
1 g
F P
s
P
p
.002 w
.32147 .34744 m .35537 .30605 L .35019 .32746 L p
1 g
F P
s
P
p
.002 w
.33006 .50668 m .34482 .5422 L .33441 .53649 L p
1 g
F P
s
P
p
.002 w
.33441 .53649 m .31692 .49466 L .33006 .50668 L p
1 g
F P
s
P
p
.002 w
.49337 .62592 m .53664 .618 L .55475 .61895 L p
1 g
F P
s
P
p
.002 w
.59549 .59527 m .55475 .61895 L .53664 .618 L p
1 g
F P
s
P
p
.002 w
.55475 .61895 m .59549 .59527 L .61481 .58911 L p
1 g
F P
s
P
p
.002 w
.40555 .27943 m .35537 .30605 L .36445 .28888 L p
1 g
F P
s
P
p
.002 w
.36445 .28888 m .41533 .26161 L .40555 .27943 L p
1 g
F P
s
P
p
.002 w
.55312 .25405 m .48832 .24114 L .49908 .23449 L p
1 g
F P
s
P
p
.002 w
.49908 .23449 m .56092 .24672 L .55312 .25405 L p
1 g
F P
s
P
p
.002 w
.6456 .54919 m .61481 .58911 L .59549 .59527 L p
1 g
F P
s
P
p
.002 w
.61481 .58911 m .6456 .54919 L .66269 .53699 L p
1 g
F P
s
P
p
.002 w
.44108 .61371 m .48021 .61837 L .49337 .62592 L p
1 g
F P
s
P
p
.002 w
.53664 .618 m .49337 .62592 L .48021 .61837 L p
1 g
F P
s
P
p
.002 w
.47747 .25361 m .41533 .26161 L .42716 .2492 L p
1 g
F P
s
P
p
.002 w
.42716 .2492 m .48832 .24114 L .47747 .25361 L p
1 g
F P
s
P
p
.002 w
.68882 .39295 m .66033 .33536 L .66305 .32423 L p
1 g
F P
s
P
p
.002 w
.61809 .27796 m .66305 .32423 L .66033 .33536 L p
1 g
F P
s
P
p
.002 w
.6767 .4838 m .66269 .53699 L .6456 .54919 L p
1 g
F P
s
P
p
.002 w
.66269 .53699 m .6767 .4838 L .68908 .46817 L p
1 g
F P
s
P
p
.002 w
.32587 .41244 m .31373 .45186 L .30568 .43321 L p
1 g
F P
s
P
p
.002 w
.30568 .43321 m .3191 .38863 L .32587 .41244 L p
1 g
F P
s
P
p
.002 w
.32754 .47053 m .33006 .50668 L .31692 .49466 L p
1 g
F P
s
P
p
.002 w
.31692 .49466 m .31373 .45186 L .32754 .47053 L p
1 g
F P
s
P
p
.002 w
.38008 .56979 m .40629 .58926 L .40318 .5983 L p
1 g
F P
s
P
p
.002 w
.40318 .5983 m .37005 .5737 L .38008 .56979 L p
1 g
F P
s
P
p
.002 w
.44108 .61371 m .40318 .5983 L .40629 .58926 L p
1 g
F P
s
P
p
.002 w
.61312 .28686 m .55312 .25405 L .56092 .24672 L p
1 g
F P
s
P
p
.002 w
.56092 .24672 m .61809 .27796 L .61312 .28686 L p
1 g
F P
s
P
p
.002 w
.3602 .54487 m .38008 .56979 L .37005 .5737 L p
1 g
F P
s
P
p
.002 w
.37005 .5737 m .34482 .5422 L .3602 .54487 L p
1 g
F P
s
P
p
.002 w
.34927 .35262 m .3191 .38863 L .31771 .36677 L p
1 g
F P
s
P
p
.002 w
.31771 .36677 m .35019 .32746 L .34927 .35262 L p
1 g
F P
s
P
p
.004 w
.32313 .32756 m
.34252 .33885 L
s
P
p
.004 w
.31531 .32301 m
.32313 .32756 L
s
P
p
.002 w
.66033 .33536 m .61312 .28686 L .61809 .27796 L p
1 g
F P
s
P
p
.002 w
.68191 .40826 m .68908 .46817 L .6767 .4838 L p
1 g
F P
s
P
p
.002 w
.68908 .46817 m .68191 .40826 L .68882 .39295 L p
1 g
F P
s
P
p
.002 w
.66033 .33536 m .68882 .39295 L .68191 .40826 L p
1 g
F P
s
P
p
.002 w
.40629 .58926 m .43627 .60141 L .44108 .61371 L p
1 g
F P
s
P
p
.002 w
.48021 .61837 m .44108 .61371 L .43627 .60141 L p
1 g
F P
s
P
p
.002 w
.34869 .51689 m .3602 .54487 L .34482 .5422 L p
1 g
F P
s
P
p
.002 w
.34482 .5422 m .33006 .50668 L .34869 .51689 L p
1 g
F P
s
P
p
.002 w
.48021 .61837 m .51681 .61154 L .53664 .618 L p
1 g
F P
s
P
p
.002 w
.57271 .59682 m .53664 .618 L .51681 .61154 L p
1 g
F P
s
P
p
.002 w
.53664 .618 m .57271 .59682 L .59549 .59527 L p
1 g
F P
s
P
p
.002 w
.39824 .30237 m .35019 .32746 L .35537 .30605 L p
1 g
F P
s
P
p
.002 w
.35537 .30605 m .40555 .27943 L .39824 .30237 L p
1 g
F P
s
P
p
.002 w
.62366 .55832 m .59549 .59527 L .57271 .59682 L p
1 g
F P
s
P
p
.002 w
.59549 .59527 m .62366 .55832 L .6456 .54919 L p
1 g
F P
s
P
p
.002 w
.54342 .2669 m .47747 .25361 L .48832 .24114 L p
1 g
F P
s
P
p
.002 w
.48832 .24114 m .55312 .25405 L .54342 .2669 L p
1 g
F P
s
P
p
.002 w
.46688 .27182 m .40555 .27943 L .41533 .26161 L p
1 g
F P
s
P
p
.002 w
.41533 .26161 m .47747 .25361 L .46688 .27182 L p
1 g
F P
s
P
p
.002 w
.43627 .60141 m .46713 .605 L .48021 .61837 L p
1 g
F P
s
P
p
.002 w
.51681 .61154 m .48021 .61837 L .46713 .605 L p
1 g
F P
s
P
p
.002 w
.65866 .49839 m .6456 .54919 L .62366 .55832 L p
1 g
F P
s
P
p
.002 w
.6456 .54919 m .65866 .49839 L .6767 .4838 L p
1 g
F P
s
P
p
.002 w
.33802 .43747 m .32754 .47053 L .31373 .45186 L p
1 g
F P
s
P
p
.002 w
.31373 .45186 m .32587 .41244 L .33802 .43747 L p
1 g
F P
s
P
p
.002 w
.68191 .40826 m .65276 .34975 L .66033 .33536 L p
1 g
F P
s
P
p
.002 w
.61312 .28686 m .66033 .33536 L .65276 .34975 L p
1 g
F P
s
P
p
.002 w
.34691 .48859 m .34869 .51689 L .33006 .50668 L p
1 g
F P
s
P
p
.002 w
.33006 .50668 m .32754 .47053 L .34691 .48859 L p
1 g
F P
s
P
p
.002 w
.35286 .38083 m .32587 .41244 L .3191 .38863 L p
1 g
F P
s
P
p
.002 w
.3191 .38863 m .34927 .35262 L .35286 .38083 L p
1 g
F P
s
P
p
.002 w
.66935 .4248 m .6767 .4838 L .65866 .49839 L p
1 g
F P
s
P
p
.002 w
.6767 .4838 m .66935 .4248 L .68191 .40826 L p
1 g
F P
s
P
p
.002 w
.39409 .56158 m .41231 .57513 L .40629 .58926 L p
1 g
F P
s
P
p
.002 w
.40629 .58926 m .38008 .56979 L .39409 .56158 L p
1 g
F P
s
P
p
.002 w
.43627 .60141 m .40629 .58926 L .41231 .57513 L p
1 g
F P
s
P
p
.002 w
.60458 .30039 m .54342 .2669 L .55312 .25405 L p
1 g
F P
s
P
p
.002 w
.55312 .25405 m .61312 .28686 L .60458 .30039 L p
1 g
F P
s
P
p
.002 w
.38032 .54425 m .39409 .56158 L .38008 .56979 L p
1 g
F P
s
P
p
.002 w
.38008 .56979 m .3602 .54487 L .38032 .54425 L p
1 g
F P
s
P
p
.002 w
.65276 .34975 m .68191 .40826 L .66935 .4248 L p
1 g
F P
s
P
p
.002 w
.65276 .34975 m .60458 .30039 L .61312 .28686 L p
1 g
F P
s
P
p
.002 w
.41231 .57513 m .43316 .58355 L .43627 .60141 L p
1 g
F P
s
P
p
.002 w
.46713 .605 m .43627 .60141 L .43316 .58355 L p
1 g
F P
s
P
p
.002 w
.39378 .32986 m .34927 .35262 L .35019 .32746 L p
1 g
F P
s
P
p
.002 w
.35019 .32746 m .39824 .30237 L .39378 .32986 L p
1 g
F P
s
P
p
.002 w
.46713 .605 m .4958 .5995 L .51681 .61154 L p
1 g
F P
s
P
p
.002 w
.54706 .5935 m .51681 .61154 L .4958 .5995 L p
1 g
F P
s
P
p
.002 w
.51681 .61154 m .54706 .5935 L .57271 .59682 L p
1 g
F P
s
P
p
.002 w
.59738 .56393 m .57271 .59682 L .54706 .5935 L p
1 g
F P
s
P
p
.002 w
.57271 .59682 m .59738 .56393 L .62366 .55832 L p
1 g
F P
s
P
p
.002 w
.37246 .52486 m .38032 .54425 L .3602 .54487 L p
1 g
F P
s
P
p
.002 w
.3602 .54487 m .34869 .51689 L .37246 .52486 L p
1 g
F P
s
P
p
.002 w
.53205 .28517 m .46688 .27182 L .47747 .25361 L p
1 g
F P
s
P
p
.002 w
.47747 .25361 m .54342 .2669 L .53205 .28517 L p
1 g
F P
s
P
p
.002 w
.45695 .29545 m .39824 .30237 L .40555 .27943 L p
1 g
F P
s
P
p
.002 w
.40555 .27943 m .46688 .27182 L .45695 .29545 L p
1 g
F P
s
P
p
.002 w
.63532 .5114 m .62366 .55832 L .59738 .56393 L p
1 g
F P
s
P
p
.002 w
.62366 .55832 m .63532 .5114 L .65866 .49839 L p
1 g
F P
s
P
p
.002 w
.43316 .58355 m .45455 .58596 L .46713 .605 L p
1 g
F P
s
P
p
.002 w
.4958 .5995 m .46713 .605 L .45455 .58596 L p
1 g
F P
s
P
p
.002 w
.35537 .46292 m .34691 .48859 L .32754 .47053 L p
1 g
F P
s
P
p
.002 w
.32754 .47053 m .33802 .43747 L .35537 .46292 L p
1 g
F P
s
P
p
.002 w
.36099 .41122 m .33802 .43747 L .32587 .41244 L p
1 g
F P
s
P
p
.002 w
.32587 .41244 m .35286 .38083 L .36099 .41122 L p
1 g
F P
s
P
p
.002 w
.37142 .50538 m .37246 .52486 L .34869 .51689 L p
1 g
F P
s
P
p
.002 w
.34869 .51689 m .34691 .48859 L .37142 .50538 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.66935 .4248 m .64032 .36712 L .65276 .34975 L p
1 g
F P
s
P
p
.002 w
.60458 .30039 m .65276 .34975 L .64032 .36712 L p
1 g
F P
s
P
p
.002 w
.65127 .44206 m .65866 .49839 L .63532 .5114 L p
1 g
F P
s
P
p
.002 w
.65866 .49839 m .65127 .44206 L .66935 .4248 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.39246 .36111 m .35286 .38083 L .34927 .35262 L p
1 g
F P
s
P
p
.004 w
.38616 .36425 m
.5 .43051 L
s
P
p
.002 w
.34927 .35262 m .39378 .32986 L .39246 .36111 L p
1 g
F P
s
P
p
.004 w
.36444 .35161 m
.36551 .35223 L
s
P
p
.004 w
.35409 .34558 m
.36444 .35161 L
s
P
p
.004 w
.34252 .33885 m
.35409 .34558 L
s
P
p
.002 w
.4958 .5995 m .51928 .5852 L .54706 .5935 L p
1 g
F P
s
P
p
.002 w
.56748 .56566 m .54706 .5935 L .51928 .5852 L p
1 g
F P
s
P
p
.002 w
.54706 .5935 m .56748 .56566 L .59738 .56393 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.64032 .36712 m .66935 .4248 L .65127 .44206 L p
1 g
F P
s
P
p
.002 w
.59255 .31836 m .53205 .28517 L .54342 .2669 L p
1 g
F P
s
P
p
.002 w
.54342 .2669 m .60458 .30039 L .59255 .31836 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.41181 .54911 m .4212 .55611 L .41231 .57513 L p
1 g
F P
s
P
p
.002 w
.41231 .57513 m .39409 .56158 L .41181 .54911 L p
1 g
F P
s
P
p
.004 w
.39262 .59366 m
.40484 .57509 L
s
P
p
.002 w
.43316 .58355 m .41231 .57513 L .4212 .55611 L p
1 g
F P
s
P
p
.002 w
.45455 .58596 m .4743 .58202 L .4958 .5995 L p
1 g
F P
s
P
p
.002 w
.51928 .5852 m .4958 .5995 L .4743 .58202 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.40475 .54016 m .41181 .54911 L .39409 .56158 L p
1 g
F P
s
P
p
.002 w
.39409 .56158 m .38032 .54425 L .40475 .54016 L p
1 g
F P
s
P
p
.002 w
.4212 .55611 m .43196 .56043 L .43316 .58355 L p
1 g
F P
s
P
p
.002 w
.45455 .58596 m .43316 .58355 L .43196 .56043 L p
1 g
F P
s
P
p
.002 w
.64032 .36712 m .59255 .31836 L .60458 .30039 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.60726 .52231 m .59738 .56393 L .56748 .56566 L p
1 g
F P
s
P
p
.002 w
.59738 .56393 m .60726 .52231 L .63532 .5114 L p
1 g
F P
s
P
p
.002 w
.40079 .5302 m .40475 .54016 L .38032 .54425 L p
1 g
F P
s
P
p
.002 w
.38032 .54425 m .37246 .52486 L .40079 .5302 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.004 w
.44784 .50977 m
.5 .43051 L
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.37744 .48787 m .37142 .50538 L .34691 .48859 L p
1 g
F P
s
P
p
.002 w
.34691 .48859 m .35537 .46292 L .37744 .48787 L p
1 g
F P
s
P
p
.002 w
.44806 .32389 m .39378 .32986 L .39824 .30237 L p
1 g
F P
s
P
p
.002 w
.39824 .30237 m .45695 .29545 L .44806 .32389 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.37352 .44274 m .35537 .46292 L .33802 .43747 L p
1 g
F P
s
P
p
.002 w
.33802 .43747 m .36099 .41122 L .37352 .44274 L p
1 g
F P
s
P
p
.002 w
.51933 .30849 m .45695 .29545 L .46688 .27182 L p
1 g
F P
s
P
p
.002 w
.46688 .27182 m .53205 .28517 L .51933 .30849 L p
1 g
F P
s
P
p
.002 w
.43196 .56043 m .44296 .56161 L .45455 .58596 L p
1 g
F P
s
P
p
.002 w
.4743 .58202 m .45455 .58596 L .44296 .56161 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.40036 .52025 m .40079 .5302 L .37246 .52486 L p
1 g
F P
s
P
p
.002 w
.37246 .52486 m .37142 .50538 L .40036 .52025 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.62806 .45947 m .63532 .5114 L .60726 .52231 L p
1 g
F P
s
P
p
.002 w
.63532 .5114 m .62806 .45947 L .65127 .44206 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.4743 .58202 m .47693 .58037 L p
.50699 .58433 L 1 g
F P
s
P
p
.002 w
.47693 .58037 m .47983 .57857 L p
.48907 .58053 L 1 g
F P
s
P
p
.50699 .58433 m .47693 .58037 L .48907 .58053 L 1 g
F
P
p
.51079 .57862 m .50053 .58067 L .50957 .58079 L 1 g
F
P
p
.002 w
.52289 .58015 m .51928 .5852 L .51 .58098 L p
1 g
F P
s
P
p
.002 w
.51 .58098 m .50957 .58079 L p
.51095 .58072 L 1 g
F P
s
P
p
.52289 .58015 m .51 .58098 L .51095 .58072 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58072 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58072 L .52088 .57798 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.53128 .57265 m .52088 .57798 L .52531 .57677 L 1 g
F
P
p
.002 w
.55699 .56491 m .56748 .56566 L p
.52976 .57559 L 1 g
F P
s
P
p
.52976 .57559 m .52531 .57677 L .53166 .57439 L 1 g
F
P
p
.52976 .57559 m .53166 .57439 L .55699 .56491 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .57439 L p
1 g
F P
s
P
p
.002 w
.51928 .5852 m .52531 .57677 L p
.56748 .56566 L 1 g
F P
s
P
p
.54854 .56129 m .53166 .57439 L .54103 .56845 L 1 g
F
P
p
.002 w
.53166 .57439 m .53128 .57265 L p
.52531 .57677 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54854 .56129 m .54103 .56845 L .54767 .56424 L 1 g
F
P
p
.002 w
.57218 .54469 m .56748 .56566 L .54825 .56428 L p
1 g
F P
s
P
p
.002 w
.54825 .56428 m .54767 .56424 L p
.54919 .56303 L 1 g
F P
s
P
p
.57218 .54469 m .54825 .56428 L .54919 .56303 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56303 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56303 L .55677 .55288 L 1 g
F
P
p
.002 w
.54919 .56303 m .54854 .56129 L p
.54767 .56424 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56134 .54676 m .56075 .54566 L p
.55677 .55288 L 1 g
F P
s
P
p
.002 w
.54767 .56424 m .5349 .56332 L p
.55735 .5521 L 1 g
F P
s
P
p
.57218 .54469 m .54919 .56303 L .55735 .5521 L 1 g
F
P
p
.54919 .56303 m .54767 .56424 L .55735 .5521 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.57533 .53064 m .57218 .54469 L p
.55988 .55084 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56134 .54676 L p
1 g
F P
s
P
p
.56654 .52734 m .56134 .54676 L .56473 .53727 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56375 .53999 m .55988 .55084 L .5349 .56332 L 1 g
F
P
p
.57533 .53064 m .55988 .55084 L .56375 .53999 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.56654 .52734 m .56473 .53727 L .56661 .53198 L 1 g
F
P
p
.002 w
.57207 .51042 m .57533 .53064 L .56771 .53181 L p
1 g
F P
s
P
p
.002 w
.56771 .53181 m .56661 .53198 L p
.56745 .52867 L 1 g
F P
s
P
p
.57207 .51042 m .56771 .53181 L .56745 .52867 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56745 .52867 L p
1 g
F P
s
P
p
.56515 .50826 m .56745 .52867 L .5665 .517 L 1 g
F
P
p
.002 w
.56745 .52867 m .56654 .52734 L p
.56661 .53198 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56585 .50909 m .56515 .50826 L p
.5665 .517 L 1 g
F P
s
P
p
.002 w
.56661 .53198 m .54062 .536 L p
.56634 .51508 L 1 g
F P
s
P
p
.57207 .51042 m .56745 .52867 L .56634 .51508 L 1 g
F
P
p
.56745 .52867 m .56661 .53198 L .56634 .51508 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56912 .49217 m .57207 .51042 L p
.56802 .51372 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56585 .50909 L p
1 g
F P
s
P
p
.55661 .4905 m .56585 .50909 L .56164 .50012 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56261 .50218 m .56802 .51372 L .54062 .536 L 1 g
F
P
p
.56912 .49217 m .56802 .51372 L .56261 .50218 L 1 g
F
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.55661 .4905 m .56164 .50012 L .55974 .49607 L 1 g
F
P
p
.54907 .45475 m .55889 .49278 L .54559 .46786 L 1 g
F
P
p
.55889 .49278 m .55974 .49607 L .55733 .49126 L 1 g
F
P
p
.55889 .49278 m .55733 .49126 L .54559 .46786 L 1 g
F
P
p
.002 w
.55733 .49126 m .55661 .4905 L p
.55974 .49607 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55733 .49126 L p
1 g
F P
s
P
p
.002 w
.55763 .49159 m .55733 .49126 L p
.55974 .49607 L 1 g
F P
s
P
p
.54174 .47608 m .55733 .49126 L .54773 .48195 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55974 .49607 m .53544 .50617 L p
.54306 .47741 L 1 g
F P
s
P
p
.002 w
.54216 .47654 m .54174 .47608 L p
.54773 .48195 L 1 g
F P
s
P
p
.54559 .46786 m .55733 .49126 L .54306 .47741 L 1 g
F
P
p
.55733 .49126 m .55974 .49607 L .54306 .47741 L 1 g
F
P
p
.002 w
.54907 .45475 m .56912 .49217 L .55974 .49607 L p
1 g
F P
s
P
p
.002 w
.55974 .49607 m .56912 .49217 L p
.56261 .50218 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55763 .49159 L p
1 g
F P
s
P
p
.56164 .50012 m .56713 .51061 L .55763 .49159 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53544 .50617 m .51965 .47725 L .52877 .47027 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54216 .47654 L p
1 g
F P
s
P
p
.52214 .46667 m .54216 .47654 L .53216 .47186 L 1 g
F
P
p
.54317 .47701 m .53544 .50617 L .52877 .47027 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52877 .47027 m .51965 .47725 L p
.51919 .46669 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46714 L p
1 g
F P
s
P
p
.5 .4634 m .52243 .46714 L .51138 .46559 L 1 g
F
P
p
.51913 .46552 m .52243 .46714 L .51919 .46669 L 1 g
F
P
p
.52243 .46714 m .52877 .47027 L .51919 .46669 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.49492 .45275 m .51726 .42302 L p
.51919 .46669 L 1 g
F P
s
P
p
.002 w
.51965 .47725 m .5073 .46501 L p
.51919 .46669 L 1 g
F P
s
P
p
.5 .4634 m .51138 .46559 L .5073 .46501 L 1 g
F
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5073 .46501 m .51965 .47725 L p
.49649 .46439 L 1 g
F P
s
P
p
.5073 .46501 m .49649 .46439 L .5 .46386 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.51965 .47725 m .4897 .49824 L p
.49353 .46484 L 1 g
F P
s
P
p
.49649 .46439 m .51965 .47725 L .49353 .46484 L 1 g
F
P
p
.47786 .46667 m .5 .46386 L .48882 .46555 L 1 g
F
P
p
.47786 .46667 m .48882 .46555 L .48465 .46619 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48465 .46619 m .47284 .48164 L p
.47073 .47048 L 1 g
F P
s
P
p
.47757 .46715 m .48465 .46619 L .47073 .47048 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47757 .46715 L p
1 g
F P
s
P
p
.45826 .47608 m .47757 .46715 L .46797 .47182 L 1 g
F
P
p
.45826 .47608 m .46797 .47182 L .46117 .47513 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46117 .47513 m .47284 .48164 L p
.45459 .47971 L 1 g
F P
s
P
p
.46117 .47513 m .45459 .47971 L .45761 .47679 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45761 .47679 L p
1 g
F P
s
P
p
.002 w
.47284 .48164 m .45188 .50859 L p
.45193 .4823 L 1 g
F P
s
P
p
.45459 .47971 m .47284 .48164 L .45193 .4823 L 1 g
F
P
p
.44339 .4905 m .45761 .47679 L .45028 .4839 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43008 .49997 m .42949 .46466 L p
.43967 .49724 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .43974 .49711 L 1 g
F
P
p
.002 w
.43744 .50176 m .43008 .49997 L p
.43967 .49724 L 1 g
F P
s
P
p
.44339 .4905 m .45028 .4839 L .44618 .48788 L 1 g
F
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.44618 .48788 L 1 g
F P
s
P
p
.43485 .50826 m .43974 .49711 L .43886 .49889 L 1 g
F
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.43967 .49724 m .44258 .49136 L .44138 .50272 L 1 g
F
P
p
.002 w
.44972 .47691 m .44618 .48788 L p
.44258 .49136 L 1 g
F P
s
P
p
.002 w
.44618 .48788 m .44138 .50272 L p
.44258 .49136 L 1 g
F P
s
P
p
.43894 .49489 m .44258 .49136 L .43967 .49724 L 1 g
F
P
p
.002 w
.44258 .49136 m .44198 .492 L p
.43974 .49711 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45188 .50859 m .44138 .50272 L .44618 .48788 L p
1 g
F P
s
P
p
.002 w
.44618 .48788 m .45196 .47 L p
.45193 .4823 L 1 g
F P
s
P
p
.45193 .4823 m .45188 .50859 L .44618 .48788 L 1 g
F
P
p
.44618 .48788 m .45698 .47747 L .44252 .49143 L 1 g
F
P
p
.45028 .4839 m .45088 .48332 L .44618 .48788 L 1 g
F
P
p
.45088 .48332 m .45698 .47747 L .44618 .48788 L 1 g
F
P
p
.002 w
.44252 .49143 m .44258 .49136 L p
.44618 .48788 L 1 g
F P
s
P
p
.42949 .46466 m .44972 .47691 L .44258 .49136 L 1 g
F
P
p
.42949 .46466 m .44258 .49136 L .43894 .49489 L 1 g
F
P
p
.43886 .49889 m .44198 .492 L .43982 .49663 L 1 g
F
P
p
.43974 .49711 m .44198 .492 L .43886 .49889 L 1 g
F
P
p
.002 w
.42949 .46466 m .45196 .47 L .44972 .47691 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43133 .5149 m .43008 .49997 L .43453 .50105 L p
1 g
F P
s
P
p
.002 w
.43453 .50105 m .43744 .50176 L p
.43388 .50942 L 1 g
F P
s
P
p
.43453 .50105 m .43388 .50942 L .43133 .5149 L 1 g
F
P
p
.43346 .52734 m .43316 .5187 L .43243 .5281 L 1 g
F
P
p
.002 w
.4322 .53117 m .41925 .50063 L p
.43186 .52691 L 1 g
F P
s
P
p
.43186 .52691 m .43243 .5281 L .43237 .52893 L 1 g
F
P
p
.43186 .52691 m .43237 .52893 L .4322 .53117 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43237 .52893 L p
1 g
F P
s
P
p
.43925 .54566 m .43237 .52893 L .43257 .52972 L 1 g
F
P
p
.43925 .54566 m .43257 .52972 L .43307 .5317 L 1 g
F
P
p
.43925 .54566 m .43307 .5317 L .43314 .53198 L 1 g
F
P
p
.43925 .54566 m .43313 .53197 L .43319 .53215 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44138 .50272 m .45188 .50859 L .43318 .53213 L p
1 g
F P
s
P
p
.002 w
.43318 .53213 m .43281 .5326 L .43307 .5317 L p
1 g
F P
s
P
p
.002 w
.43307 .5317 m .44138 .50272 L p
.43318 .53213 L 1 g
F P
s
P
p
.43314 .53198 m .43307 .5317 L .43313 .53197 L 1 g
F
P
p
.43319 .53215 m .43313 .53197 L .43318 .53214 L 1 g
F
P
p
.43925 .54566 m .43318 .53214 L .43322 .53229 L 1 g
F
P
p
.43925 .54566 m .43321 .53226 L .43325 .5324 L 1 g
F
P
p
.002 w
.45188 .50859 m .46039 .51691 L .43324 .53236 L p
1 g
F P
s
P
p
.002 w
.43324 .53236 m .43281 .5326 L .43318 .53213 L p
1 g
F P
s
P
p
.002 w
.43318 .53213 m .45188 .50859 L p
.43324 .53236 L 1 g
F P
s
P
p
.43925 .54566 m .43324 .53236 L .43328 .53249 L 1 g
F
P
p
.43925 .54566 m .43326 .53245 L .4333 .53258 L 1 g
F
P
p
.002 w
.46039 .51691 m .46596 .52676 L .43329 .53252 L p
1 g
F P
s
P
p
.002 w
.43329 .53252 m .43281 .5326 L .43324 .53236 L p
1 g
F P
s
P
p
.002 w
.43324 .53236 m .46039 .51691 L p
.43329 .53252 L 1 g
F P
s
P
p
.43322 .53229 m .43318 .53214 L .43321 .53226 L 1 g
F
P
p
.43325 .5324 m .43321 .53226 L .43324 .53236 L 1 g
F
P
p
.43925 .54566 m .43328 .53253 L .43333 .53267 L 1 g
F
P
p
.002 w
.46596 .52676 m .46799 .53701 L .43333 .53267 L p
1 g
F P
s
P
p
.002 w
.43333 .53267 m .43281 .5326 L .43329 .53252 L p
1 g
F P
s
P
p
.002 w
.43329 .53252 m .46596 .52676 L p
.43333 .53267 L 1 g
F P
s
P
p
.43925 .54566 m .4333 .53261 L .43472 .5367 L 1 g
F
P
p
.002 w
.46799 .53701 m .4663 .54654 L .43339 .53285 L p
1 g
F P
s
P
p
.002 w
.43339 .53285 m .43281 .5326 L .43333 .53267 L p
1 g
F P
s
P
p
.002 w
.43333 .53267 m .46799 .53701 L p
.43339 .53285 L 1 g
F P
s
P
p
.43328 .53249 m .43324 .53236 L .43326 .53245 L 1 g
F
P
p
.4333 .53258 m .43326 .53245 L .43328 .53253 L 1 g
F
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.4663 .54654 m .46112 .55431 L .43348 .53312 L p
1 g
F P
s
P
p
.002 w
.43348 .53312 m .43281 .5326 L .43339 .53285 L p
1 g
F P
s
P
p
.002 w
.43339 .53285 m .4663 .54654 L p
.43348 .53312 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46112 .55431 m .45304 .5595 L .43372 .53381 L p
1 g
F P
s
P
p
.002 w
.43372 .53381 m .43281 .5326 L .43348 .53312 L p
1 g
F P
s
P
p
.002 w
.43348 .53312 m .46112 .55431 L p
.43372 .53381 L 1 g
F P
s
P
p
.43333 .53267 m .43328 .53253 L .4333 .53261 L 1 g
F
P
p
.002 w
.43281 .5326 m .43372 .53381 L p
.43802 .54675 L 1 g
F P
s
P
p
.002 w
.44296 .56161 m .43752 .54607 L p
.43802 .54675 L 1 g
F P
s
P
p
.002 w
.43752 .54607 m .43281 .5326 L p
.43802 .54675 L 1 g
F P
s
P
p
.45146 .56129 m .44376 .5546 L .4481 .56053 L 1 g
F
P
p
.002 w
.44296 .56161 m .4468 .5608 L p
.45846 .57171 L 1 g
F P
s
P
p
.002 w
.4468 .5608 m .4481 .56053 L p
.4507 .56333 L 1 g
F P
s
P
p
.45846 .57171 m .4468 .5608 L .4507 .56333 L 1 g
F
P
p
.46872 .57265 m .4592 .56885 L .46606 .57329 L 1 g
F
P
p
.002 w
.47718 .58022 m .4743 .58202 L .46694 .57423 L p
1 g
F P
s
P
p
.002 w
.46694 .57423 m .46606 .57329 L p
.46828 .57468 L 1 g
F P
s
P
p
.47718 .58022 m .46694 .57423 L .46828 .57468 L 1 g
F
P
p
.002 w
.46828 .57468 m .46872 .57265 L p
.46606 .57329 L 1 g
F P
s
P
p
.002 w
.48907 .58053 m .48921 .57862 L p
.47701 .57762 L 1 g
F P
s
P
p
.47701 .57762 m .47983 .57857 L .48907 .58053 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47983 .57857 m .47718 .58022 L p
.47229 .57603 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46828 .57468 L p
1 g
F P
s
P
p
.47718 .58022 m .46828 .57468 L .47229 .57603 L 1 g
F
P
p
.4743 .58202 m .45846 .57171 L .4581 .5709 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .4507 .56333 L p
1 g
F P
s
P
p
.46694 .57423 m .4581 .5709 L .45638 .56702 L 1 g
F
P
p
.002 w
.46606 .57329 m .46694 .57423 L p
.45638 .56702 L 1 g
F P
s
P
p
.46872 .57265 m .4507 .56333 L .4592 .56885 L 1 g
F
P
p
.002 w
.4507 .56333 m .45146 .56129 L p
.4481 .56053 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4384 .54727 L p
1 g
F P
s
P
p
.45146 .56129 m .4384 .54727 L .44376 .5546 L 1 g
F
P
p
.002 w
.43372 .53381 m .45304 .5595 L .4481 .56053 L p
1 g
F P
s
P
p
.002 w
.4481 .56053 m .44335 .56152 L p
.4384 .54727 L 1 g
F P
s
P
p
.002 w
.44335 .56152 m .44296 .56161 L p
.43372 .53381 L 1 g
F P
s
P
p
.002 w
.4212 .55611 m .41181 .54911 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.43196 .56043 m .4212 .55611 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.41181 .54911 m .40475 .54016 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.44296 .56161 m .43196 .56043 L .4326 .53927 L p
1 g
F P
s
P
p
.002 w
.4326 .53927 m .43281 .5326 L .43752 .54607 L p
1 g
F P
s
P
p
.002 w
.43752 .54607 m .44296 .56161 L p
.4326 .53927 L 1 g
F P
s
P
p
.002 w
.4384 .54727 m .43839 .54728 L p
.44376 .5546 L 1 g
F P
s
P
p
.002 w
.43839 .54728 m .43743 .5491 L p
.44356 .55443 L 1 g
F P
s
P
p
.44376 .5546 m .43839 .54728 L .44356 .55443 L 1 g
F
P
p
.002 w
.40475 .54016 m .40079 .5302 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.40079 .5302 m .40036 .52025 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.40036 .52025 m .40356 .51139 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.40356 .51139 m .41008 .50459 L .43281 .5326 L closepath p
1 g
F P
s
P
p
.002 w
.41008 .50459 m .41925 .50063 L .4322 .53117 L p
1 g
F P
s
P
p
.002 w
.4322 .53117 m .43281 .5326 L .43215 .5318 L p
1 g
F P
s
P
p
.002 w
.43215 .5318 m .41008 .50459 L p
.4322 .53117 L 1 g
F P
s
P
p
.002 w
.43237 .52893 m .43346 .52734 L p
.43243 .5281 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50942 L p
1 g
F P
s
P
p
.43346 .52734 m .43388 .50942 L .43316 .5187 L 1 g
F
P
p
.002 w
.44138 .50272 m .43307 .5317 L p
.43254 .52664 L 1 g
F P
s
P
p
.43133 .5149 m .43367 .51206 L .43254 .52664 L 1 g
F
P
p
.43367 .51206 m .44138 .50272 L .43254 .52664 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43388 .50942 L p
1 g
F P
s
P
p
.002 w
.43388 .50942 m .43485 .50826 L p
.43982 .49663 L 1 g
F P
s
P
p
.43982 .49663 m .44166 .49233 L .43388 .50942 L 1 g
F
P
p
.002 w
.43744 .50176 m .44138 .50272 L p
.43133 .5149 L 1 g
F P
s
P
p
.002 w
.43388 .50942 m .43287 .51061 L p
.43316 .5187 L 1 g
F P
s
P
p
.002 w
.43257 .52972 m .43133 .5149 L p
.43307 .5317 L 1 g
F P
s
P
p
.002 w
.41925 .50063 m .43008 .49997 L .43243 .5281 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43236 .52895 L p
1 g
F P
s
P
p
.002 w
.43236 .52895 m .43237 .52893 L p
.43237 .52873 L 1 g
F P
s
P
p
.43237 .52873 m .43287 .51061 L .43236 .52895 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43925 .54566 L p
1 g
F P
s
P
p
.4481 .56053 m .4384 .54727 L .43372 .53381 L 1 g
F
P
p
.002 w
.4481 .56053 m .45304 .5595 L p
.45846 .57171 L 1 g
F P
s
P
p
.002 w
.4507 .56333 m .45002 .56518 L p
.4592 .56885 L 1 g
F P
s
P
p
.002 w
.45304 .5595 m .46606 .57329 L p
.45638 .56702 L 1 g
F P
s
P
p
.002 w
.46694 .57423 m .4743 .58202 L p
.4581 .5709 L 1 g
F P
s
P
p
.002 w
.46828 .57468 m .46827 .57473 L p
.47701 .57762 L 1 g
F P
s
P
p
.002 w
.46827 .57473 m .4678 .57686 L p
.47564 .5775 L 1 g
F P
s
P
p
.47701 .57762 m .46827 .57473 L .47564 .5775 L 1 g
F
P
p
.48921 .57862 m .46828 .57468 L .47701 .57762 L 1 g
F
P
p
.002 w
.46606 .57329 m .45304 .5595 L p
.47229 .57603 L 1 g
F P
s
P
p
.46828 .57468 m .46606 .57329 L .47229 .57603 L 1 g
F
P
p
.002 w
.4903 .57202 m .47983 .57857 L p
.45304 .5595 L 1 g
F P
s
P
p
.47983 .57857 m .47229 .57603 L .45304 .5595 L 1 g
F
P
p
.47701 .57762 m .47433 .5774 L .47983 .57857 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58165 L p
1 g
F P
s
P
p
.002 w
.48899 .58165 m .48907 .58053 L p
.48207 .57932 L 1 g
F P
s
P
p
.48207 .57932 m .4678 .57686 L .48899 .58165 L 1 g
F
P
p
.002 w
.46827 .57473 m .46828 .57468 L p
.46606 .57329 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57473 L p
1 g
F P
s
P
p
.4592 .56885 m .45002 .56518 L .46827 .57473 L 1 g
F
P
p
.002 w
.45051 .56383 m .4507 .56333 L p
.4481 .56053 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45051 .56383 L p
1 g
F P
s
P
p
.44376 .5546 m .43743 .5491 L .45051 .56383 L 1 g
F
P
p
.43472 .5367 m .4333 .53261 L .43394 .53517 L 1 g
F
P
p
.002 w
.43307 .5317 m .43281 .5326 L .43257 .52972 L p
1 g
F P
s
P
p
.43394 .53517 m .43257 .52972 L .43392 .53512 L 1 g
F
P
p
.002 w
.43243 .5281 m .43281 .5326 L .4322 .53117 L p
1 g
F P
s
P
p
.002 w
.43237 .52893 m .43146 .53025 L p
.43392 .53512 L 1 g
F P
s
P
p
.002 w
.43237 .52893 m .43237 .52893 L p
.43243 .5281 L 1 g
F P
s
P
p
.43316 .5187 m .43287 .51061 L .43237 .52893 L 1 g
F
P
p
.002 w
.44138 .50272 m .43744 .50176 L p
.43967 .49724 L 1 g
F P
s
P
p
.002 w
.44198 .492 m .44166 .49233 L p
.43982 .49663 L 1 g
F P
s
P
p
.002 w
.45761 .47679 m .45698 .47747 L p
.45028 .4839 L 1 g
F P
s
P
p
.45194 .47943 m .45459 .47971 L .45193 .4823 L 1 g
F
P
p
.45761 .47679 m .45459 .47971 L .45194 .47943 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44252 .49143 L p
1 g
F P
s
P
p
.002 w
.45748 .47693 m .45761 .47679 L p
.46117 .47513 L 1 g
F P
s
P
p
.002 w
.45761 .47679 m .45826 .47608 L p
.46117 .47513 L 1 g
F P
s
P
p
.002 w
.45196 .47 m .46117 .47513 L p
.45194 .47943 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47284 .48164 m .45196 .47 L .46416 .43565 L p
1 g
F P
s
P
p
.002 w
.47757 .46715 m .47718 .46778 L p
.46797 .47182 L 1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.46416 .43565 m .48339 .46431 L .47029 .46813 L 1 g
F
P
p
.002 w
.47757 .46715 m .47786 .46667 L p
.48465 .46619 L 1 g
F P
s
P
p
.48339 .46431 m .48465 .46619 L .47757 .46715 L 1 g
F
P
p
.48339 .46431 m .47757 .46715 L .47029 .46813 L 1 g
F
P
p
.47029 .46813 m .47757 .46715 L .47073 .47048 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45748 .47693 L p
1 g
F P
s
P
p
.46797 .47182 m .47718 .46778 L .45748 .47693 L 1 g
F
P
p
.002 w
.4775 .46727 m .47757 .46715 L p
.48465 .46619 L 1 g
F P
s
P
p
.002 w
.46416 .43565 m .49492 .45275 L .48465 .46619 L p
1 g
F P
s
P
p
.002 w
.4897 .49824 m .47284 .48164 L .49492 .45275 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .46442 L p
.48882 .46555 L 1 g
F P
s
P
p
.49376 .46287 m .49649 .46439 L .49353 .46484 L 1 g
F
P
p
.5 .46386 m .49649 .46439 L .49376 .46287 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46727 L p
1 g
F P
s
P
p
.48882 .46555 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.002 w
.5 .46398 m .5 .46386 L p
.5073 .46501 L 1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.5073 .46501 L 1 g
F P
s
P
p
.002 w
.49492 .45275 m .5073 .46501 L p
.49376 .46287 L 1 g
F P
s
P
p
.002 w
.5073 .46501 m .49492 .45275 L p
.51919 .46669 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46398 L p
1 g
F P
s
P
p
.51138 .46559 m .52282 .46778 L .5 .46398 L 1 g
F
P
p
.002 w
.52243 .46714 m .52282 .46778 L p
.51138 .46559 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46714 L p
1 g
F P
s
P
p
.002 w
.52243 .46714 m .52214 .46667 L p
.53558 .47363 L 1 g
F P
s
P
p
.53558 .47363 m .54302 .47747 L .52243 .46714 L 1 g
F
P
p
.002 w
.51726 .42302 m .54907 .45475 L .52877 .47027 L p
1 g
F P
s
P
p
.51726 .42302 m .52877 .47027 L .51913 .46552 L 1 g
F
P
p
.002 w
.52877 .47027 m .54907 .45475 L p
.54317 .47701 L 1 g
F P
s
P
p
.002 w
.54216 .47654 m .54302 .47747 L p
.53216 .47186 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54216 .47654 L p
1 g
F P
s
P
p
.54773 .48195 m .55834 .49233 L .54216 .47654 L 1 g
F
P
p
.002 w
.55733 .49126 m .55834 .49233 L p
.54773 .48195 L 1 g
F P
s
P
p
.002 w
.54062 .536 m .53544 .50617 L .55974 .49607 L p
1 g
F P
s
P
p
.56261 .50218 m .54062 .536 L .55974 .49607 L 1 g
F
P
p
.002 w
.56585 .50909 m .56713 .51061 L p
.56164 .50012 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56585 .50909 L p
1 g
F P
s
P
p
.5665 .517 m .56854 .53025 L .56585 .50909 L 1 g
F
P
p
.002 w
.56745 .52867 m .56854 .53025 L p
.5665 .517 L 1 g
F P
s
P
p
.002 w
.56768 .529 m .56745 .52867 L p
.56661 .53198 L 1 g
F P
s
P
p
.002 w
.5349 .56332 m .54062 .536 L .56661 .53198 L p
1 g
F P
s
P
p
.002 w
.56661 .53198 m .57533 .53064 L p
.56375 .53999 L 1 g
F P
s
P
p
.56375 .53999 m .5349 .56332 L .56661 .53198 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56768 .529 L p
1 g
F P
s
P
p
.56473 .53727 m .56257 .5491 L .56768 .529 L 1 g
F
P
p
.002 w
.56134 .54676 m .56257 .5491 L p
.56473 .53727 L 1 g
F P
s
P
p
.002 w
.54767 .56424 m .55699 .56491 L p
.53166 .57439 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56134 .54676 L p
1 g
F P
s
P
p
.55677 .55288 m .54998 .56518 L .56134 .54676 L 1 g
F
P
p
.002 w
.54919 .56303 m .54998 .56518 L p
.55677 .55288 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54919 .56303 L p
.54767 .56424 L 1 g
F P
s
P
p
.002 w
.52531 .57677 m .5349 .56332 L .54767 .56424 L p
1 g
F P
s
P
p
.53166 .57439 m .52531 .57677 L .54767 .56424 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54926 .56323 L p
1 g
F P
s
P
p
.54103 .56845 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.002 w
.53166 .57439 m .5322 .57686 L p
.54103 .56845 L 1 g
F P
s
P
p
.002 w
.53179 .57498 m .53166 .57439 L p
.52531 .57677 L 1 g
F P
s
P
p
.002 w
.5349 .56332 m .52531 .57677 L p
.4903 .57202 L 1 g
F P
s
P
p
.002 w
.52531 .57677 m .52289 .58015 L p
.5177 .57886 L 1 g
F P
s
P
p
.52531 .57677 m .5177 .57886 L .4903 .57202 L 1 g
F
P
p
.002 w
.51095 .58072 m .51079 .57862 L p
.50957 .58079 L 1 g
F P
s
P
p
.51928 .5852 m .50699 .58433 L .50205 .58069 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58053 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58053 L .50053 .58067 L 1 g
F
P
p
.002 w
.4903 .57202 m .50957 .58079 L p
.50205 .58069 L 1 g
F P
s
P
p
.002 w
.50957 .58079 m .4903 .57202 L p
.5177 .57886 L 1 g
F P
s
P
p
.52289 .58015 m .51095 .58072 L .5177 .57886 L 1 g
F
P
p
.51095 .58072 m .50957 .58079 L .5177 .57886 L 1 g
F
P
p
.002 w
.51095 .58072 m .51095 .5808 L p
.52088 .57798 L 1 g
F P
s
P
p
.002 w
.51 .58098 m .51928 .5852 L p
.50601 .58173 L 1 g
F P
s
P
p
.002 w
.51095 .5808 m .51111 .583 L p
.51792 .5795 L 1 g
F P
s
P
p
.52088 .57798 m .51095 .5808 L .51792 .5795 L 1 g
F
P
p
.002 w
.50957 .58079 m .51 .58098 L p
.50205 .58069 L 1 g
F P
s
P
p
.50601 .58173 m .50205 .58069 L .51 .58098 L 1 g
F
P
p
.002 w
.47983 .57857 m .4903 .57202 L p
.50699 .58433 L 1 g
F P
s
P
p
.002 w
.48907 .58053 m .48889 .583 L p
.50053 .58067 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53179 .57498 L p
1 g
F P
s
P
p
.52088 .57798 m .51111 .583 L .53179 .57498 L 1 g
F
P
p
.002 w
.51095 .5808 m .51095 .58072 L p
.50957 .58079 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .5808 L p
1 g
F P
s
P
p
.50053 .58067 m .48889 .583 L .51095 .5808 L 1 g
F
P
p
.47433 .5774 m .4678 .57686 L .48907 .58053 L 1 g
F
P
p
.002 w
.39443 .39507 m .36099 .41122 L .35286 .38083 L p
1 g
F P
s
P
p
.002 w
.35286 .38083 m .39246 .36111 L .39443 .39507 L p
1 g
F P
s
P
p
.002 w
.65127 .44206 m .6232 .38698 L .64032 .36712 L p
1 g
F P
s
P
p
.002 w
.59255 .31836 m .64032 .36712 L .6232 .38698 L p
1 g
F P
s
P
p
.002 w
.6232 .38698 m .65127 .44206 L .62806 .45947 L p
1 g
F P
s
P
p
.002 w
.56748 .56566 m .57533 .53064 L .60726 .52231 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.5773 .34036 m .51933 .30849 L .53205 .28517 L p
1 g
F P
s
P
p
.002 w
.53205 .28517 m .59255 .31836 L .5773 .34036 L p
1 g
F P
s
P
p
.002 w
.40356 .51139 m .40036 .52025 L .37142 .50538 L p
1 g
F P
s
P
p
.002 w
.37142 .50538 m .37744 .48787 L .40356 .51139 L p
1 g
F P
s
P
p
.002 w
.39007 .47426 m .37744 .48787 L .35537 .46292 L p
1 g
F P
s
P
p
.002 w
.35537 .46292 m .37352 .44274 L .39007 .47426 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.44058 .35624 m .39246 .36111 L .39378 .32986 L p
1 g
F P
s
P
p
.002 w
.39378 .32986 m .44806 .32389 L .44058 .35624 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.6232 .38698 m .5773 .34036 L .59255 .31836 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.45304 .5595 m .46112 .55431 L .4903 .57202 L p
1 g
F P
s
P
p
.002 w
.50076 .5569 m .4903 .57202 L .46112 .55431 L p
1 g
F P
s
P
p
.002 w
.4903 .57202 m .50076 .5569 L .5349 .56332 L p
1 g
F P
s
P
p
.002 w
.50567 .33621 m .44806 .32389 L .45695 .29545 L p
1 g
F P
s
P
p
.002 w
.45695 .29545 m .51933 .30849 L .50567 .33621 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60037 .47639 m .60726 .52231 L .57533 .53064 L p
1 g
F P
s
P
p
.002 w
.60726 .52231 m .60037 .47639 L .62806 .45947 L p
1 g
F P
s
P
p
.002 w
.39968 .43054 m .37352 .44274 L .36099 .41122 L p
1 g
F P
s
P
p
.002 w
.36099 .41122 m .39443 .39507 L .39968 .43054 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.54062 .536 m .5349 .56332 L .50076 .5569 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41008 .50459 m .40356 .51139 L .37744 .48787 L p
1 g
F P
s
P
p
.002 w
.37744 .48787 m .39007 .47426 L .41008 .50459 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.6018 .40873 m .62806 .45947 L .60037 .47639 L p
1 g
F P
s
P
p
.002 w
.62806 .45947 m .6018 .40873 L .6232 .38698 L p
1 g
F P
s
P
p
.002 w
.5773 .34036 m .6232 .38698 L .6018 .40873 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.46112 .55431 m .4663 .54654 L .50076 .5569 L p
1 g
F P
s
P
p
.002 w
.43484 .39138 m .39443 .39507 L .39246 .36111 L p
1 g
F P
s
P
p
.002 w
.39246 .36111 m .44058 .35624 L .43484 .39138 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.40806 .46618 m .39007 .47426 L .37352 .44274 L p
1 g
F P
s
P
p
.002 w
.37352 .44274 m .39968 .43054 L .40806 .46618 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.50439 .53816 m .50076 .5569 L .4663 .54654 L p
1 g
F P
s
P
p
.002 w
.50076 .5569 m .50439 .53816 L .54062 .536 L p
1 g
F P
s
P
p
.002 w
.57533 .53064 m .56912 .49217 L .60037 .47639 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55925 .36574 m .50567 .33621 L .51933 .30849 L p
1 g
F P
s
P
p
.002 w
.51933 .30849 m .5773 .34036 L .55925 .36574 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4663 .54654 m .46799 .53701 L .50439 .53816 L p
1 g
F P
s
P
p
.002 w
.6018 .40873 m .55925 .36574 L .5773 .34036 L p
1 g
F P
s
P
p
.002 w
.49156 .36743 m .44058 .35624 L .44806 .32389 L p
1 g
F P
s
P
p
.002 w
.44806 .32389 m .50567 .33621 L .49156 .36743 L p
1 g
F P
s
P
p
.002 w
.41925 .50063 m .41008 .50459 L .39007 .47426 L p
1 g
F P
s
P
p
.002 w
.39007 .47426 m .40806 .46618 L .41925 .50063 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53544 .50617 m .54062 .536 L .50439 .53816 L p
1 g
F P
s
P
p
.002 w
.43109 .42799 m .39968 .43054 L .39443 .39507 L p
1 g
F P
s
P
p
.002 w
.39443 .39507 m .43484 .39138 L .43109 .42799 L p
1 g
F P
s
P
p
.002 w
.46799 .53701 m .46596 .52676 L .50061 .51785 L p
1 g
F P
s
P
p
.002 w
.50061 .51785 m .50439 .53816 L .46799 .53701 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.5768 .43161 m .60037 .47639 L .56912 .49217 L p
1 g
F P
s
P
p
.002 w
.60037 .47639 m .5768 .43161 L .6018 .40873 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.50439 .53816 m .50061 .51785 L .53544 .50617 L p
1 g
F P
s
P
p
.002 w
.43008 .49997 m .41925 .50063 L .40806 .46618 L p
1 g
F P
s
P
p
.002 w
.55925 .36574 m .6018 .40873 L .5768 .43161 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.46596 .52676 m .46039 .51691 L .4897 .49824 L p
1 g
F P
s
P
p
.002 w
.4897 .49824 m .50061 .51785 L .46596 .52676 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42949 .46466 m .40806 .46618 L .39968 .43054 L p
1 g
F P
s
P
p
.002 w
.39968 .43054 m .43109 .42799 L .42949 .46466 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.40806 .46618 m .42949 .46466 L .43008 .49997 L p
1 g
F P
s
P
p
.002 w
.47754 .401 m .43484 .39138 L .44058 .35624 L p
1 g
F P
s
P
p
.002 w
.44058 .35624 m .49156 .36743 L .47754 .401 L p
1 g
F P
s
P
p
.002 w
.46039 .51691 m .45188 .50859 L .47284 .48164 L p
1 g
F P
s
P
p
.002 w
.47284 .48164 m .4897 .49824 L .46039 .51691 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.53898 .39364 m .49156 .36743 L .50567 .33621 L p
1 g
F P
s
P
p
.002 w
.50567 .33621 m .55925 .36574 L .53898 .39364 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.56912 .49217 m .54907 .45475 L .5768 .43161 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.5768 .43161 m .53898 .39364 L .55925 .36574 L p
1 g
F P
s
P
p
.002 w
.50061 .51785 m .4897 .49824 L .51965 .47725 L p
1 g
F P
s
P
p
.002 w
.51965 .47725 m .53544 .50617 L .50061 .51785 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.45196 .47 m .42949 .46466 L .43109 .42799 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.53898 .39364 m .5768 .43161 L .54907 .45475 L p
1 g
F P
s
P
p
.002 w
.46416 .43565 m .43109 .42799 L .43484 .39138 L p
1 g
F P
s
P
p
.002 w
.43484 .39138 m .47754 .401 L .46416 .43565 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.43109 .42799 m .46416 .43565 L .45196 .47 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.51726 .42302 m .47754 .401 L .49156 .36743 L p
1 g
F P
s
P
p
.002 w
.49156 .36743 m .53898 .39364 L .51726 .42302 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54907 .45475 m .51726 .42302 L .53898 .39364 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.49492 .45275 m .46416 .43565 L .47754 .401 L p
1 g
F P
s
P
p
.002 w
.47754 .401 m .51726 .42302 L .49492 .45275 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.004 w
.40484 .57509 m
.40982 .56752 L
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28528 .30553 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39262 .59366 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.412403)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.412403)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45746 .4396 m .4819 .46475 L .49921 .44224 L p
1 g
F P
s
P
p
.002 w
.49921 .44224 m .48033 .4228 L .45746 .4396 L p
1 g
F P
s
P
p
.002 w
.52289 .45522 m .49921 .44224 L .4819 .46475 L p
1 g
F P
s
P
p
.002 w
.48033 .4228 m .49921 .44224 L .5165 .4195 L p
1 g
F P
s
P
p
.002 w
.49921 .44224 m .52289 .45522 L .53268 .42832 L p
1 g
F P
s
P
p
.002 w
.53268 .42832 m .5165 .4195 L .49921 .44224 L p
1 g
F P
s
P
p
.002 w
.5165 .4195 m .50362 .40622 L .48033 .4228 L p
1 g
F P
s
P
p
.002 w
.50362 .40622 m .5165 .4195 L .53346 .39693 L p
1 g
F P
s
P
p
.002 w
.5165 .4195 m .53268 .42832 L .5417 .4014 L p
1 g
F P
s
P
p
.002 w
.5417 .4014 m .53346 .39693 L .5165 .4195 L p
1 g
F P
s
P
p
.002 w
.44164 .40864 m .45746 .4396 L .48033 .4228 L p
1 g
F P
s
P
p
.002 w
.48033 .4228 m .46819 .39884 L .44164 .40864 L p
1 g
F P
s
P
p
.002 w
.46819 .39884 m .48033 .4228 L .50362 .40622 L p
1 g
F P
s
P
p
.002 w
.50362 .40622 m .49539 .38985 L .46819 .39884 L p
1 g
F P
s
P
p
.002 w
.49539 .38985 m .50362 .40622 L .52691 .39017 L p
1 g
F P
s
P
p
.002 w
.53346 .39693 m .52691 .39017 L .50362 .40622 L p
1 g
F P
s
P
p
.002 w
.5505 .43175 m .53268 .42832 L .52289 .45522 L p
1 g
F P
s
P
p
.002 w
.53268 .42832 m .5505 .43175 L .55076 .4031 L p
1 g
F P
s
P
p
.002 w
.55076 .4031 m .5417 .4014 L .53268 .42832 L p
1 g
F P
s
P
p
.002 w
.4819 .46475 m .51252 .48161 L .52289 .45522 L p
1 g
F P
s
P
p
.002 w
.54901 .46037 m .52289 .45522 L .51252 .48161 L p
1 g
F P
s
P
p
.002 w
.52289 .45522 m .54901 .46037 L .5505 .43175 L p
1 g
F P
s
P
p
.002 w
.43542 .45634 m .46489 .48662 L .4819 .46475 L p
1 g
F P
s
P
p
.002 w
.4819 .46475 m .45746 .4396 L .43542 .45634 L p
1 g
F P
s
P
p
.002 w
.51252 .48161 m .4819 .46475 L .46489 .48662 L p
1 g
F P
s
P
p
.002 w
.46407 .37278 m .46819 .39884 L .49539 .38985 L p
1 g
F P
s
P
p
.002 w
.49539 .38985 m .49269 .37208 L .46407 .37278 L p
1 g
F P
s
P
p
.002 w
.49269 .37208 m .49539 .38985 L .52276 .38183 L p
1 g
F P
s
P
p
.002 w
.52691 .39017 m .52276 .38183 L .49539 .38985 L p
1 g
F P
s
P
p
.002 w
.41623 .41908 m .43542 .45634 L .45746 .4396 L p
1 g
F P
s
P
p
.002 w
.45746 .4396 m .44164 .40864 L .41623 .41908 L p
1 g
F P
s
P
p
.002 w
.43612 .3749 m .44164 .40864 L .46819 .39884 L p
1 g
F P
s
P
p
.002 w
.46819 .39884 m .46407 .37278 L .43612 .3749 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .52691 .39017 L .53346 .39693 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .53346 .39693 L .5417 .4014 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .52276 .38183 L .52691 .39017 L closepath p
1 g
F P
s
P
p
.002 w
.56811 .42939 m .5505 .43175 L .54901 .46037 L p
1 g
F P
s
P
p
.002 w
.5505 .43175 m .56811 .42939 L .55968 .40184 L p
1 g
F P
s
P
p
.002 w
.55968 .40184 m .55076 .4031 L .5505 .43175 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .5417 .4014 L .55076 .4031 L closepath p
1 g
F P
s
P
p
.002 w
.46489 .48662 m .50175 .507 L .51252 .48161 L p
1 g
F P
s
P
p
.002 w
.54632 .48844 m .51252 .48161 L .50175 .507 L p
1 g
F P
s
P
p
.002 w
.51252 .48161 m .54632 .48844 L .54901 .46037 L p
1 g
F P
s
P
p
.002 w
.52276 .38183 m .52143 .37281 L .49269 .37208 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .52143 .37281 L .52276 .38183 L closepath p
1 g
F P
s
P
p
.002 w
.57491 .45708 m .54901 .46037 L .54632 .48844 L p
1 g
F P
s
P
p
.002 w
.54901 .46037 m .57491 .45708 L .56811 .42939 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .55076 .4031 L .55968 .40184 L closepath p
1 g
F P
s
P
p
.002 w
.46854 .34729 m .46407 .37278 L .49269 .37208 L p
1 g
F P
s
P
p
.002 w
.49269 .37208 m .49586 .35477 L .46854 .34729 L p
1 g
F P
s
P
p
.002 w
.49586 .35477 m .49269 .37208 L .52143 .37281 L p
1 g
F P
s
P
p
.002 w
.52143 .37281 m .52311 .36404 L .49586 .35477 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .52311 .36404 L .52143 .37281 L closepath p
1 g
F P
s
P
p
.002 w
.40935 .37841 m .41623 .41908 L .44164 .40864 L p
1 g
F P
s
P
p
.002 w
.44164 .40864 m .43612 .3749 L .40935 .37841 L p
1 g
F P
s
P
p
.002 w
.41464 .47269 m .44848 .50743 L .46489 .48662 L p
1 g
F P
s
P
p
.002 w
.46489 .48662 m .43542 .45634 L .41464 .47269 L p
1 g
F P
s
P
p
.002 w
.50175 .507 m .46489 .48662 L .44848 .50743 L p
1 g
F P
s
P
p
.002 w
.56751 .39774 m .55968 .40184 L .56811 .42939 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .55968 .40184 L .56751 .39774 L closepath p
1 g
F P
s
P
p
.002 w
.44167 .34177 m .43612 .3749 L .46407 .37278 L p
1 g
F P
s
P
p
.002 w
.46407 .37278 m .46854 .34729 L .44167 .34177 L p
1 g
F P
s
P
p
.002 w
.58364 .42142 m .56811 .42939 L .57491 .45708 L p
1 g
F P
s
P
p
.002 w
.56811 .42939 m .58364 .42142 L .56751 .39774 L p
1 g
F P
s
P
p
.002 w
.39247 .42997 m .41464 .47269 L .43542 .45634 L p
1 g
F P
s
P
p
.002 w
.43542 .45634 m .41623 .41908 L .39247 .42997 L p
1 g
F P
s
P
p
.002 w
.50463 .33975 m .49586 .35477 L .52311 .36404 L p
1 g
F P
s
P
p
.002 w
.52311 .36404 m .52761 .35649 L .50463 .33975 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .52761 .35649 L .52311 .36404 L closepath p
1 g
F P
s
P
p
.002 w
.50175 .507 m .54247 .51542 L .54632 .48844 L p
1 g
F P
s
P
p
.002 w
.57993 .48439 m .54632 .48844 L .54247 .51542 L p
1 g
F P
s
P
p
.002 w
.54632 .48844 m .57993 .48439 L .57491 .45708 L p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .53448 .35098 L .52761 .35649 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .56751 .39774 L .57339 .39122 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .57339 .39122 L .57667 .38296 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .57667 .38296 L .57696 .37386 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .57696 .37386 L .57422 .36493 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .57422 .36493 L .56874 .35714 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .56874 .35714 L .56112 .35136 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .56112 .35136 L .55221 .34825 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .55221 .34825 L .54299 .34812 L closepath p
1 g
F P
s
P
p
.002 w
.54978 .37494 m .54299 .34812 L .53448 .35098 L closepath p
1 g
F P
s
P
p
.002 w
.57339 .39122 m .56751 .39774 L .58364 .42142 L p
1 g
F P
s
P
p
.002 w
.48128 .32507 m .46854 .34729 L .49586 .35477 L p
1 g
F P
s
P
p
.002 w
.49586 .35477 m .50463 .33975 L .48128 .32507 L p
1 g
F P
s
P
p
.002 w
.44848 .50743 m .49076 .53092 L .50175 .507 L p
1 g
F P
s
P
p
.002 w
.54247 .51542 m .50175 .507 L .49076 .53092 L p
1 g
F P
s
P
p
.002 w
.51816 .32871 m .50463 .33975 L .52761 .35649 L p
1 g
F P
s
P
p
.002 w
.52761 .35649 m .53448 .35098 L .51816 .32871 L p
1 g
F P
s
P
p
.002 w
.59786 .44553 m .57491 .45708 L .57993 .48439 L p
1 g
F P
s
P
p
.002 w
.57491 .45708 m .59786 .44553 L .58364 .42142 L p
1 g
F P
s
P
p
.002 w
.58364 .42142 m .5954 .4086 L .57339 .39122 L p
1 g
F P
s
P
p
.002 w
.57667 .38296 m .57339 .39122 L .5954 .4086 L p
1 g
F P
s
P
p
.002 w
.5954 .4086 m .58364 .42142 L .59786 .44553 L p
1 g
F P
s
P
p
.002 w
.38434 .38329 m .39247 .42997 L .41623 .41908 L p
1 g
F P
s
P
p
.002 w
.41623 .41908 m .40935 .37841 L .38434 .38329 L p
1 g
F P
s
P
p
.002 w
.41578 .33837 m .40935 .37841 L .43612 .3749 L p
1 g
F P
s
P
p
.002 w
.43612 .3749 m .44167 .34177 L .41578 .33837 L p
1 g
F P
s
P
p
.002 w
.53502 .32291 m .51816 .32871 L .53448 .35098 L p
1 g
F P
s
P
p
.002 w
.53448 .35098 m .54299 .34812 L .53502 .32291 L p
1 g
F P
s
P
p
.002 w
.458 .31276 m .44167 .34177 L .46854 .34729 L p
1 g
F P
s
P
p
.002 w
.46854 .34729 m .48128 .32507 L .458 .31276 L p
1 g
F P
s
P
p
.002 w
.5954 .4086 m .60203 .39227 L .57667 .38296 L p
1 g
F P
s
P
p
.002 w
.57696 .37386 m .57667 .38296 L .60203 .39227 L p
1 g
F P
s
P
p
.002 w
.50112 .3086 m .48128 .32507 L .50463 .33975 L p
1 g
F P
s
P
p
.002 w
.50463 .33975 m .51816 .32871 L .50112 .3086 L p
1 g
F P
s
P
p
.002 w
.39554 .48833 m .43302 .52676 L .44848 .50743 L p
1 g
F P
s
P
p
.002 w
.44848 .50743 m .41464 .47269 L .39554 .48833 L p
1 g
F P
s
P
p
.002 w
.49076 .53092 m .44848 .50743 L .43302 .52676 L p
1 g
F P
s
P
p
.002 w
.55338 .32307 m .53502 .32291 L .54299 .34812 L p
1 g
F P
s
P
p
.002 w
.54299 .34812 m .55221 .34825 L .55338 .32307 L p
1 g
F P
s
P
p
.002 w
.49076 .53092 m .53749 .54078 L .54247 .51542 L p
1 g
F P
s
P
p
.002 w
.58306 .51079 m .54247 .51542 L .53749 .54078 L p
1 g
F P
s
P
p
.002 w
.54247 .51542 m .58306 .51079 L .57993 .48439 L p
1 g
F P
s
P
p
.002 w
.37088 .44112 m .39554 .48833 L .41464 .47269 L p
1 g
F P
s
P
p
.002 w
.41464 .47269 m .39247 .42997 L .37088 .44112 L p
1 g
F P
s
P
p
.002 w
.60203 .39227 m .60272 .37418 L .57696 .37386 L p
1 g
F P
s
P
p
.002 w
.57422 .36493 m .57696 .37386 L .60272 .37418 L p
1 g
F P
s
P
p
.002 w
.60986 .46962 m .57993 .48439 L .58306 .51079 L p
1 g
F P
s
P
p
.002 w
.57993 .48439 m .60986 .46962 L .59786 .44553 L p
1 g
F P
s
P
p
.002 w
.57118 .32924 m .55338 .32307 L .55221 .34825 L p
1 g
F P
s
P
p
.002 w
.55221 .34825 m .56112 .35136 L .57118 .32924 L p
1 g
F P
s
P
p
.002 w
.59786 .44553 m .61535 .42678 L .5954 .4086 L p
1 g
F P
s
P
p
.002 w
.60203 .39227 m .5954 .4086 L .61535 .42678 L p
1 g
F P
s
P
p
.002 w
.61535 .42678 m .59786 .44553 L .60986 .46962 L p
1 g
F P
s
P
p
.002 w
.60272 .37418 m .59733 .35634 L .57422 .36493 L p
1 g
F P
s
P
p
.002 w
.56874 .35714 m .57422 .36493 L .59733 .35634 L p
1 g
F P
s
P
p
.002 w
.58641 .34077 m .57118 .32924 L .56112 .35136 L p
1 g
F P
s
P
p
.002 w
.56112 .35136 m .56874 .35714 L .58641 .34077 L p
1 g
F P
s
P
p
.002 w
.59733 .35634 m .58641 .34077 L .56874 .35714 L p
1 g
F P
s
P
p
.002 w
.43302 .52676 m .47977 .55284 L .49076 .53092 L p
1 g
F P
s
P
p
.002 w
.53749 .54078 m .49076 .53092 L .47977 .55284 L p
1 g
F P
s
P
p
.002 w
.52601 .29985 m .50112 .3086 L .51816 .32871 L p
1 g
F P
s
P
p
.002 w
.51816 .32871 m .53502 .32291 L .52601 .29985 L p
1 g
F P
s
P
p
.002 w
.39143 .33722 m .38434 .38329 L .40935 .37841 L p
1 g
F P
s
P
p
.002 w
.40935 .37841 m .41578 .33837 L .39143 .33722 L p
1 g
F P
s
P
p
.002 w
.43526 .30315 m .41578 .33837 L .44167 .34177 L p
1 g
F P
s
P
p
.002 w
.44167 .34177 m .458 .31276 L .43526 .30315 L p
1 g
F P
s
P
p
.002 w
.48367 .29113 m .458 .31276 L .48128 .32507 L p
1 g
F P
s
P
p
.002 w
.48128 .32507 m .50112 .3086 L .48367 .29113 L p
1 g
F P
s
P
p
.002 w
.36162 .38949 m .37088 .44112 L .39247 .42997 L p
1 g
F P
s
P
p
.002 w
.39247 .42997 m .38434 .38329 L .36162 .38949 L p
1 g
F P
s
P
p
.002 w
.61535 .42678 m .62533 .40271 L .60203 .39227 L p
1 g
F P
s
P
p
.002 w
.60272 .37418 m .60203 .39227 L .62533 .40271 L p
1 g
F P
s
P
p
.002 w
.55324 .29997 m .52601 .29985 L .53502 .32291 L p
1 g
F P
s
P
p
.002 w
.53502 .32291 m .55338 .32307 L .55324 .29997 L p
1 g
F P
s
P
p
.002 w
.60986 .46962 m .63281 .4454 L .61535 .42678 L p
1 g
F P
s
P
p
.002 w
.62533 .40271 m .61535 .42678 L .63281 .4454 L p
1 g
F P
s
P
p
.002 w
.53749 .54078 m .58416 .53573 L .58306 .51079 L p
1 g
F P
s
P
p
.002 w
.61934 .49321 m .58306 .51079 L .58416 .53573 L p
1 g
F P
s
P
p
.002 w
.58306 .51079 m .61934 .49321 L .60986 .46962 L p
1 g
F P
s
P
p
.002 w
.47977 .55284 m .53145 .56396 L .53749 .54078 L p
1 g
F P
s
P
p
.002 w
.58416 .53573 m .53749 .54078 L .53145 .56396 L p
1 g
F P
s
P
p
.002 w
.63281 .4454 m .60986 .46962 L .61934 .49321 L p
1 g
F P
s
P
p
.002 w
.62533 .40271 m .62651 .37591 L .60272 .37418 L p
1 g
F P
s
P
p
.002 w
.59733 .35634 m .60272 .37418 L .62651 .37591 L p
1 g
F P
s
P
p
.002 w
.37857 .50293 m .41884 .54418 L .43302 .52676 L p
1 g
F P
s
P
p
.002 w
.43302 .52676 m .39554 .48833 L .37857 .50293 L p
1 g
F P
s
P
p
.002 w
.47977 .55284 m .43302 .52676 L .41884 .54418 L p
1 g
F P
s
P
p
.002 w
.35196 .4523 m .37857 .50293 L .39554 .48833 L p
1 g
F P
s
P
p
.002 w
.39554 .48833 m .37088 .44112 L .35196 .4523 L p
1 g
F P
s
P
p
.002 w
.57973 .30908 m .55324 .29997 L .55338 .32307 L p
1 g
F P
s
P
p
.002 w
.55338 .32307 m .57118 .32924 L .57973 .30908 L p
1 g
F P
s
P
p
.002 w
.51609 .27951 m .48367 .29113 L .50112 .3086 L p
1 g
F P
s
P
p
.002 w
.50112 .3086 m .52601 .29985 L .51609 .27951 L p
1 g
F P
s
P
p
.002 w
.62651 .37591 m .6186 .34939 L .59733 .35634 L p
1 g
F P
s
P
p
.002 w
.58641 .34077 m .59733 .35634 L .6186 .34939 L p
1 g
F P
s
P
p
.002 w
.60239 .32621 m .57973 .30908 L .57118 .32924 L p
1 g
F P
s
P
p
.002 w
.57118 .32924 m .58641 .34077 L .60239 .32621 L p
1 g
F P
s
P
p
.002 w
.41884 .54418 m .46899 .57226 L .47977 .55284 L p
1 g
F P
s
P
p
.002 w
.53145 .56396 m .47977 .55284 L .46899 .57226 L p
1 g
F P
s
P
p
.002 w
.6186 .34939 m .60239 .32621 L .58641 .34077 L p
1 g
F P
s
P
p
.002 w
.41357 .29654 m .39143 .33722 L .41578 .33837 L p
1 g
F P
s
P
p
.002 w
.41578 .33837 m .43526 .30315 L .41357 .29654 L p
1 g
F P
s
P
p
.002 w
.36918 .33842 m .36162 .38949 L .38434 .38329 L p
1 g
F P
s
P
p
.002 w
.38434 .38329 m .39143 .33722 L .36918 .33842 L p
1 g
F P
s
P
p
.002 w
.46617 .27674 m .43526 .30315 L .458 .31276 L p
1 g
F P
s
P
p
.002 w
.458 .31276 m .48367 .29113 L .46617 .27674 L p
1 g
F P
s
P
p
.002 w
.63281 .4454 m .64603 .41411 L .62533 .40271 L p
1 g
F P
s
P
p
.002 w
.62651 .37591 m .62533 .40271 L .64603 .41411 L p
1 g
F P
s
P
p
.002 w
.3418 .39692 m .35196 .4523 L .37088 .44112 L p
1 g
F P
s
P
p
.002 w
.37088 .44112 m .36162 .38949 L .3418 .39692 L p
1 g
F P
s
P
p
.002 w
.55173 .27951 m .51609 .27951 L .52601 .29985 L p
1 g
F P
s
P
p
.002 w
.52601 .29985 m .55324 .29997 L .55173 .27951 L p
1 g
F P
s
P
p
.002 w
.61934 .49321 m .64732 .46411 L .63281 .4454 L p
1 g
F P
s
P
p
.002 w
.64603 .41411 m .63281 .4454 L .64732 .46411 L p
1 g
F P
s
P
p
.002 w
.53145 .56396 m .58315 .55865 L .58416 .53573 L p
1 g
F P
s
P
p
.002 w
.62603 .5158 m .58416 .53573 L .58315 .55865 L p
1 g
F P
s
P
p
.002 w
.58416 .53573 m .62603 .5158 L .61934 .49321 L p
1 g
F P
s
P
p
.002 w
.64732 .46411 m .61934 .49321 L .62603 .5158 L p
1 g
F P
s
P
p
.002 w
.46899 .57226 m .52443 .58439 L .53145 .56396 L p
1 g
F P
s
P
p
.002 w
.58315 .55865 m .53145 .56396 L .52443 .58439 L p
1 g
F P
s
P
p
.002 w
.64603 .41411 m .64775 .37909 L .62651 .37591 L p
1 g
F P
s
P
p
.002 w
.6186 .34939 m .62651 .37591 L .64775 .37909 L p
1 g
F P
s
P
p
.002 w
.36418 .51614 m .40629 .55924 L .41884 .54418 L p
1 g
F P
s
P
p
.002 w
.41884 .54418 m .37857 .50293 L .36418 .51614 L p
1 g
F P
s
P
p
.002 w
.46899 .57226 m .41884 .54418 L .40629 .55924 L p
1 g
F P
s
P
p
.002 w
.50545 .26243 m .46617 .27674 L .48367 .29113 L p
1 g
F P
s
P
p
.002 w
.48367 .29113 m .51609 .27951 L .50545 .26243 L p
1 g
F P
s
P
p
.002 w
.5865 .29138 m .55173 .27951 L .55324 .29997 L p
1 g
F P
s
P
p
.002 w
.55324 .29997 m .57973 .30908 L .5865 .29138 L p
1 g
F P
s
P
p
.002 w
.33625 .46329 m .36418 .51614 L .37857 .50293 L p
1 g
F P
s
P
p
.002 w
.37857 .50293 m .35196 .4523 L .33625 .46329 L p
1 g
F P
s
P
p
.002 w
.449 .2659 m .41357 .29654 L .43526 .30315 L p
1 g
F P
s
P
p
.002 w
.43526 .30315 m .46617 .27674 L .449 .2659 L p
1 g
F P
s
P
p
.002 w
.39345 .29321 m .36918 .33842 L .39143 .33722 L p
1 g
F P
s
P
p
.002 w
.39143 .33722 m .41357 .29654 L .39345 .29321 L p
1 g
F P
s
P
p
.002 w
.64775 .37909 m .63749 .34431 L .6186 .34939 L p
1 g
F P
s
P
p
.002 w
.60239 .32621 m .6186 .34939 L .63749 .34431 L p
1 g
F P
s
P
p
.002 w
.34963 .34207 m .3418 .39692 L .36162 .38949 L p
1 g
F P
s
P
p
.002 w
.36162 .38949 m .36918 .33842 L .34963 .34207 L p
1 g
F P
s
P
p
.002 w
.40629 .55924 m .45866 .58866 L .46899 .57226 L p
1 g
F P
s
P
p
.002 w
.52443 .58439 m .46899 .57226 L .45866 .58866 L p
1 g
F P
s
P
p
.002 w
.61626 .31386 m .5865 .29138 L .57973 .30908 L p
1 g
F P
s
P
p
.002 w
.57973 .30908 m .60239 .32621 L .61626 .31386 L p
1 g
F P
s
P
p
.002 w
.63749 .34431 m .61626 .31386 L .60239 .32621 L p
1 g
F P
s
P
p
.002 w
.64732 .46411 m .66358 .42627 L .64603 .41411 L p
1 g
F P
s
P
p
.002 w
.64775 .37909 m .64603 .41411 L .66358 .42627 L p
1 g
F P
s
P
p
.002 w
.32543 .40548 m .33625 .46329 L .35196 .4523 L p
1 g
F P
s
P
p
.002 w
.35196 .4523 m .3418 .39692 L .32543 .40548 L p
1 g
F P
s
P
p
.002 w
.62603 .5158 m .65845 .4825 L .64732 .46411 L p
1 g
F P
s
P
p
.002 w
.66358 .42627 m .64732 .46411 L .65845 .4825 L p
1 g
F P
s
P
p
.002 w
.54882 .26228 m .50545 .26243 L .51609 .27951 L p
1 g
F P
s
P
p
.002 w
.51609 .27951 m .55173 .27951 L .54882 .26228 L p
1 g
F P
s
P
p
.002 w
.58315 .55865 m .62966 .53685 L .62603 .5158 L p
1 g
F P
s
P
p
.002 w
.65845 .4825 m .62603 .5158 L .62966 .53685 L p
1 g
F P
s
P
p
.002 w
.52443 .58439 m .57996 .57895 L .58315 .55865 L p
1 g
F P
s
P
p
.002 w
.62966 .53685 m .58315 .55865 L .57996 .57895 L p
1 g
F P
s
P
p
.002 w
.45866 .58866 m .51655 .6015 L .52443 .58439 L p
1 g
F P
s
P
p
.002 w
.57996 .57895 m .52443 .58439 L .51655 .6015 L p
1 g
F P
s
P
p
.002 w
.66358 .42627 m .66586 .38371 L .64775 .37909 L p
1 g
F P
s
P
p
.002 w
.63749 .34431 m .64775 .37909 L .66586 .38371 L p
1 g
F P
s
P
p
.002 w
.49429 .24918 m .449 .2659 L .46617 .27674 L p
1 g
F P
s
P
p
.002 w
.46617 .27674 m .50545 .26243 L .49429 .24918 L p
1 g
F P
s
P
p
.002 w
.35281 .52758 m .39573 .57147 L .40629 .55924 L p
1 g
F P
s
P
p
.002 w
.40629 .55924 m .36418 .51614 L .35281 .52758 L p
1 g
F P
s
P
p
.002 w
.45866 .58866 m .40629 .55924 L .39573 .57147 L p
1 g
F P
s
P
p
.002 w
.43258 .25903 m .39345 .29321 L .41357 .29654 L p
1 g
F P
s
P
p
.002 w
.41357 .29654 m .449 .2659 L .43258 .25903 L p
1 g
F P
s
P
p
.002 w
.59124 .27668 m .54882 .26228 L .55173 .27951 L p
1 g
F P
s
P
p
.002 w
.55173 .27951 m .5865 .29138 L .59124 .27668 L p
1 g
F P
s
P
p
.002 w
.37545 .29341 m .34963 .34207 L .36918 .33842 L p
1 g
F P
s
P
p
.002 w
.36918 .33842 m .39345 .29321 L .37545 .29341 L p
1 g
F P
s
P
p
.002 w
.32428 .47381 m .35281 .52758 L .36418 .51614 L p
1 g
F P
s
P
p
.002 w
.36418 .51614 m .33625 .46329 L .32428 .47381 L p
1 g
F P
s
P
p
.002 w
.33338 .34818 m .32543 .40548 L .3418 .39692 L p
1 g
F P
s
P
p
.002 w
.3418 .39692 m .34963 .34207 L .33338 .34818 L p
1 g
F P
s
P
p
.002 w
.66586 .38371 m .65347 .3413 L .63749 .34431 L p
1 g
F P
s
P
p
.002 w
.61626 .31386 m .63749 .34431 L .65347 .3413 L p
1 g
F P
s
P
p
.002 w
.39573 .57147 m .44905 .60151 L .45866 .58866 L p
1 g
F P
s
P
p
.002 w
.51655 .6015 m .45866 .58866 L .44905 .60151 L p
1 g
F P
s
P
p
.002 w
.65845 .4825 m .67744 .43895 L .66358 .42627 L p
1 g
F P
s
P
p
.002 w
.66586 .38371 m .66358 .42627 L .67744 .43895 L p
1 g
F P
s
P
p
.002 w
.6276 .30411 m .59124 .27668 L .5865 .29138 L p
1 g
F P
s
P
p
.002 w
.5865 .29138 m .61626 .31386 L .6276 .30411 L p
1 g
F P
s
P
p
.002 w
.65347 .3413 m .6276 .30411 L .61626 .31386 L p
1 g
F P
s
P
p
.002 w
.62966 .53685 m .6658 .50013 L .65845 .4825 L p
1 g
F P
s
P
p
.002 w
.67744 .43895 m .65845 .4825 L .6658 .50013 L p
1 g
F P
s
P
p
.002 w
.31311 .41502 m .32428 .47381 L .33625 .46329 L p
1 g
F P
s
P
p
.002 w
.33625 .46329 m .32543 .40548 L .31311 .41502 L p
1 g
F P
s
P
p
.002 w
.57996 .57895 m .63 .55581 L .62966 .53685 L p
1 g
F P
s
P
p
.002 w
.6658 .50013 m .62966 .53685 L .63 .55581 L p
1 g
F P
s
P
p
.002 w
.5445 .24887 m .49429 .24918 L .50545 .26243 L p
1 g
F P
s
P
p
.002 w
.50545 .26243 m .54882 .26228 L .5445 .24887 L p
1 g
F P
s
P
p
.002 w
.51655 .6015 m .57456 .59605 L .57996 .57895 L p
1 g
F P
s
P
p
.002 w
.63 .55581 m .57996 .57895 L .57456 .59605 L p
1 g
F P
s
P
p
.002 w
.44905 .60151 m .50795 .61472 L .51655 .6015 L p
1 g
F P
s
P
p
.002 w
.57456 .59605 m .51655 .6015 L .50795 .61472 L p
1 g
F P
s
P
p
.002 w
.48285 .24028 m .43258 .25903 L .449 .2659 L p
1 g
F P
s
P
p
.002 w
.449 .2659 m .49429 .24918 L .48285 .24028 L p
1 g
F P
s
P
p
.002 w
.67744 .43895 m .68024 .38975 L .66586 .38371 L p
1 g
F P
s
P
p
.002 w
.65347 .3413 m .66586 .38371 L .68024 .38975 L p
1 g
F P
s
P
p
.002 w
.41736 .25653 m .37545 .29341 L .39345 .29321 L p
1 g
F P
s
P
p
.002 w
.39345 .29321 m .43258 .25903 L .41736 .25653 L p
1 g
F P
s
P
p
.002 w
.36014 .29731 m .33338 .34818 L .34963 .34207 L p
1 g
F P
s
P
p
.002 w
.34963 .34207 m .37545 .29341 L .36014 .29731 L p
1 g
F P
s
P
p
.002 w
.59374 .26551 m .5445 .24887 L .54882 .26228 L p
1 g
F P
s
P
p
.002 w
.54882 .26228 m .59124 .27668 L .59374 .26551 L p
1 g
F P
s
P
p
.002 w
.34492 .53689 m .38753 .58044 L .39573 .57147 L p
1 g
F P
s
P
p
.002 w
.39573 .57147 m .35281 .52758 L .34492 .53689 L p
1 g
F P
s
P
p
.002 w
.44905 .60151 m .39573 .57147 L .38753 .58044 L p
1 g
F P
s
P
p
.002 w
.31655 .48359 m .34492 .53689 L .35281 .52758 L p
1 g
F P
s
P
p
.002 w
.35281 .52758 m .32428 .47381 L .31655 .48359 L p
1 g
F P
s
P
p
.002 w
.32101 .35676 m .31311 .41502 L .32543 .40548 L p
1 g
F P
s
P
p
.002 w
.32543 .40548 m .33338 .34818 L .32101 .35676 L p
1 g
F P
s
P
p
.002 w
.68024 .38975 m .66598 .34055 L .65347 .3413 L p
1 g
F P
s
P
p
.002 w
.6276 .30411 m .65347 .3413 L .66598 .34055 L p
1 g
F P
s
P
p
.002 w
.6658 .50013 m .68707 .45187 L .67744 .43895 L p
1 g
F P
s
P
p
.002 w
.68024 .38975 m .67744 .43895 L .68707 .45187 L p
1 g
F P
s
P
p
.002 w
.38753 .58044 m .44041 .61029 L .44905 .60151 L p
1 g
F P
s
P
p
.002 w
.50795 .61472 m .44905 .60151 L .44041 .61029 L p
1 g
F P
s
P
p
.002 w
.63597 .29735 m .59374 .26551 L .59124 .27668 L p
1 g
F P
s
P
p
.002 w
.59124 .27668 m .6276 .30411 L .63597 .29735 L p
1 g
F P
s
P
p
.002 w
.66598 .34055 m .63597 .29735 L .6276 .30411 L p
1 g
F P
s
P
p
.002 w
.63 .55581 m .66898 .51655 L .6658 .50013 L p
1 g
F P
s
P
p
.002 w
.68707 .45187 m .6658 .50013 L .66898 .51655 L p
1 g
F P
s
P
p
.002 w
.57456 .59605 m .62687 .5721 L .63 .55581 L p
1 g
F P
s
P
p
.002 w
.66898 .51655 m .63 .55581 L .62687 .5721 L p
1 g
F P
s
P
p
.002 w
.30537 .42536 m .31655 .48359 L .32428 .47381 L p
1 g
F P
s
P
p
.002 w
.32428 .47381 m .31311 .41502 L .30537 .42536 L p
1 g
F P
s
P
p
.002 w
.5388 .23984 m .48285 .24028 L .49429 .24918 L p
1 g
F P
s
P
p
.002 w
.49429 .24918 m .5445 .24887 L .5388 .23984 L p
1 g
F P
s
P
p
.002 w
.50795 .61472 m .56695 .60936 L .57456 .59605 L p
1 g
F P
s
P
p
.002 w
.62687 .5721 m .57456 .59605 L .56695 .60936 L p
1 g
F P
s
P
p
.002 w
.47143 .23624 m .41736 .25653 L .43258 .25903 L p
1 g
F P
s
P
p
.002 w
.43258 .25903 m .48285 .24028 L .47143 .23624 L p
1 g
F P
s
P
p
.002 w
.44041 .61029 m .49878 .62349 L .50795 .61472 L p
1 g
F P
s
P
p
.002 w
.56695 .60936 m .50795 .61472 L .49878 .62349 L p
1 g
F P
s
P
p
.002 w
.68707 .45187 m .69033 .39712 L .68024 .38975 L p
1 g
F P
s
P
p
.002 w
.66598 .34055 m .68024 .38975 L .69033 .39712 L p
1 g
F P
s
P
p
.002 w
.40381 .25872 m .36014 .29731 L .37545 .29341 L p
1 g
F P
s
P
p
.002 w
.37545 .29341 m .41736 .25653 L .40381 .25872 L p
1 g
F P
s
P
p
.002 w
.34808 .30504 m .32101 .35676 L .33338 .34818 L p
1 g
F P
s
P
p
.002 w
.33338 .34818 m .36014 .29731 L .34808 .30504 L p
1 g
F P
s
P
p
.002 w
.59379 .25836 m .5388 .23984 L .5445 .24887 L p
1 g
F P
s
P
p
.002 w
.5445 .24887 m .59374 .26551 L .59379 .25836 L p
1 g
F P
s
P
p
.002 w
.34092 .5437 m .38204 .58572 L .38753 .58044 L p
1 g
F P
s
P
p
.002 w
.38753 .58044 m .34492 .53689 L .34092 .5437 L p
1 g
F P
s
P
p
.002 w
.44041 .61029 m .38753 .58044 L .38204 .58572 L p
1 g
F P
s
P
p
.002 w
.31309 .36772 m .30537 .42536 L .31311 .41502 L p
1 g
F P
s
P
p
.002 w
.31311 .41502 m .32101 .35676 L .31309 .36772 L p
1 g
F P
s
P
p
.002 w
.31352 .49233 m .34092 .5437 L .34492 .53689 L p
1 g
F P
s
P
p
.002 w
.34492 .53689 m .31655 .48359 L .31352 .49233 L p
1 g
F P
s
P
p
.002 w
.66898 .51655 m .692 .46471 L .68707 .45187 L p
1 g
F P
s
P
p
.002 w
.69033 .39712 m .68707 .45187 L .692 .46471 L p
1 g
F P
s
P
p
.002 w
.69033 .39712 m .67449 .34222 L .66598 .34055 L p
1 g
F P
s
P
p
.002 w
.63597 .29735 m .66598 .34055 L .67449 .34222 L p
1 g
F P
s
P
p
.002 w
.38204 .58572 m .43304 .61454 L .44041 .61029 L p
1 g
F P
s
P
p
.002 w
.49878 .62349 m .44041 .61029 L .43304 .61454 L p
1 g
F P
s
P
p
.002 w
.62687 .5721 m .66767 .53125 L .66898 .51655 L p
1 g
F P
s
P
p
.002 w
.692 .46471 m .66898 .51655 L .66767 .53125 L p
1 g
F P
s
P
p
.002 w
.64098 .29394 m .59379 .25836 L .59374 .26551 L p
1 g
F P
s
P
p
.002 w
.59374 .26551 m .63597 .29735 L .64098 .29394 L p
1 g
F P
s
P
p
.002 w
.56695 .60936 m .62016 .58517 L .62687 .5721 L p
1 g
F P
s
P
p
.002 w
.66767 .53125 m .62687 .5721 L .62016 .58517 L p
1 g
F P
s
P
p
.002 w
.67449 .34222 m .64098 .29394 L .63597 .29735 L p
1 g
F P
s
P
p
.002 w
.49878 .62349 m .5572 .61829 L .56695 .60936 L p
1 g
F P
s
P
p
.002 w
.62016 .58517 m .56695 .60936 L .5572 .61829 L p
1 g
F P
s
P
p
.002 w
.30271 .43628 m .31352 .49233 L .31655 .48359 L p
1 g
F P
s
P
p
.002 w
.31655 .48359 m .30537 .42536 L .30271 .43628 L p
1 g
F P
s
P
p
.002 w
.53177 .2357 m .47143 .23624 L .48285 .24028 L p
1 g
F P
s
P
p
.002 w
.48285 .24028 m .5388 .23984 L .53177 .2357 L p
1 g
F P
s
P
p
.002 w
.46032 .23745 m .40381 .25872 L .41736 .25653 L p
1 g
F P
s
P
p
.002 w
.41736 .25653 m .47143 .23624 L .46032 .23745 L p
1 g
F P
s
P
p
.002 w
.43304 .61454 m .48927 .62731 L .49878 .62349 L p
1 g
F P
s
P
p
.002 w
.5572 .61829 m .49878 .62349 L .48927 .62731 L p
1 g
F P
s
P
p
.002 w
.3924 .26581 m .34808 .30504 L .36014 .29731 L p
1 g
F P
s
P
p
.002 w
.36014 .29731 m .40381 .25872 L .3924 .26581 L p
1 g
F P
s
P
p
.002 w
.692 .46471 m .69559 .40572 L .69033 .39712 L p
1 g
F P
s
P
p
.002 w
.67449 .34222 m .69033 .39712 L .69559 .40572 L p
1 g
F P
s
P
p
.002 w
.3398 .3166 m .31309 .36772 L .32101 .35676 L p
1 g
F P
s
P
p
.002 w
.32101 .35676 m .34808 .30504 L .3398 .3166 L p
1 g
F P
s
P
p
.002 w
.59121 .25572 m .53177 .2357 L .5388 .23984 L p
1 g
F P
s
P
p
.002 w
.5388 .23984 m .59379 .25836 L .59121 .25572 L p
1 g
F P
s
P
p
.002 w
.3101 .38089 m .30271 .43628 L .30537 .42536 L p
1 g
F P
s
P
p
.002 w
.30537 .42536 m .31309 .36772 L .3101 .38089 L p
1 g
F P
s
P
p
.002 w
.34117 .54766 m .37959 .58691 L .38204 .58572 L p
1 g
F P
s
P
p
.002 w
.38204 .58572 m .34092 .5437 L .34117 .54766 L p
1 g
F P
s
P
p
.002 w
.43304 .61454 m .38204 .58572 L .37959 .58691 L p
1 g
F P
s
P
p
.002 w
.66767 .53125 m .6918 .47713 L .692 .46471 L p
1 g
F P
s
P
p
.002 w
.69559 .40572 m .692 .46471 L .6918 .47713 L p
1 g
F P
s
P
p
.002 w
.31558 .49971 m .34117 .54766 L .34092 .5437 L p
1 g
F P
s
P
p
.002 w
.34092 .5437 m .31352 .49233 L .31558 .49971 L p
1 g
F P
s
P
p
.002 w
.69559 .40572 m .67851 .34643 L .67449 .34222 L p
1 g
F P
s
P
p
.002 w
.64098 .29394 m .67449 .34222 L .67851 .34643 L p
1 g
F P
s
P
p
.002 w
.62016 .58517 m .66165 .54374 L .66767 .53125 L p
1 g
F P
s
P
p
.002 w
.6918 .47713 m .66767 .53125 L .66165 .54374 L p
1 g
F P
s
P
p
.004 w
.41104 .22958 m
.41343 .235 L
s
P
p
.002 w
.37959 .58691 m .42722 .61384 L .43304 .61454 L p
1 g
F P
s
P
p
.002 w
.48927 .62731 m .43304 .61454 L .42722 .61384 L p
1 g
F P
s
P
p
.002 w
.5572 .61829 m .60983 .59445 L .62016 .58517 L p
1 g
F P
s
P
p
.002 w
.66165 .54374 m .62016 .58517 L .60983 .59445 L p
1 g
F P
s
P
p
.002 w
.64228 .29421 m .59121 .25572 L .59379 .25836 L p
1 g
F P
s
P
p
.002 w
.59379 .25836 m .64098 .29394 L .64228 .29421 L p
1 g
F P
s
P
p
.002 w
.67851 .34643 m .64228 .29421 L .64098 .29394 L p
1 g
F P
s
P
p
.002 w
.48927 .62731 m .54546 .62235 L .5572 .61829 L p
1 g
F P
s
P
p
.002 w
.60983 .59445 m .5572 .61829 L .54546 .62235 L p
1 g
F P
s
P
p
.002 w
.52354 .23691 m .46032 .23745 L .47143 .23624 L p
1 g
F P
s
P
p
.002 w
.47143 .23624 m .53177 .2357 L .52354 .23691 L p
1 g
F P
s
P
p
.002 w
.30551 .44748 m .31558 .49971 L .31352 .49233 L p
1 g
F P
s
P
p
.002 w
.31352 .49233 m .30271 .43628 L .30551 .44748 L p
1 g
F P
s
P
p
.002 w
.44988 .24423 m .3924 .26581 L .40381 .25872 L p
1 g
F P
s
P
p
.002 w
.40381 .25872 m .46032 .23745 L .44988 .24423 L p
1 g
F P
s
P
p
.002 w
.38362 .2779 m .3398 .3166 L .34808 .30504 L p
1 g
F P
s
P
p
.002 w
.34808 .30504 m .3924 .26581 L .38362 .2779 L p
1 g
F P
s
P
p
.002 w
.42722 .61384 m .47966 .62575 L .48927 .62731 L p
1 g
F P
s
P
p
.002 w
.54546 .62235 m .48927 .62731 L .47966 .62575 L p
1 g
F P
s
P
p
.002 w
.6918 .47713 m .69557 .41539 L .69559 .40572 L p
1 g
F P
s
P
p
.002 w
.67851 .34643 m .69559 .40572 L .69557 .41539 L p
1 g
F P
s
P
p
.002 w
.33577 .33189 m .3101 .38089 L .31309 .36772 L p
1 g
F P
s
P
p
.002 w
.31309 .36772 m .3398 .3166 L .33577 .33189 L p
1 g
F P
s
P
p
.002 w
.31245 .39601 m .30551 .44748 L .30271 .43628 L p
1 g
F P
s
P
p
.002 w
.30271 .43628 m .3101 .38089 L .31245 .39601 L p
1 g
F P
s
P
p
.002 w
.58592 .25794 m .52354 .23691 L .53177 .2357 L p
1 g
F P
s
P
p
.002 w
.53177 .2357 m .59121 .25572 L .58592 .25794 L p
1 g
F P
s
P
p
.002 w
.66165 .54374 m .68617 .48874 L .6918 .47713 L p
1 g
F P
s
P
p
.002 w
.69557 .41539 m .6918 .47713 L .68617 .48874 L p
1 g
F P
s
P
p
.002 w
.34594 .54846 m .38045 .58372 L .37959 .58691 L p
1 g
F P
s
P
p
.002 w
.37959 .58691 m .34117 .54766 L .34594 .54846 L p
1 g
F P
s
P
p
.002 w
.42722 .61384 m .37959 .58691 L .38045 .58372 L p
1 g
F P
s
P
p
.002 w
.60983 .59445 m .6508 .55352 L .66165 .54374 L p
1 g
F P
s
P
p
.002 w
.68617 .48874 m .66165 .54374 L .6508 .55352 L p
1 g
F P
s
P
p
.002 w
.323 .50543 m .34594 .54846 L .34117 .54766 L p
1 g
F P
s
P
p
.002 w
.34117 .54766 m .31558 .49971 L .323 .50543 L p
1 g
F P
s
P
p
.002 w
.54546 .62235 m .59596 .59945 L .60983 .59445 L p
1 g
F P
s
P
p
.002 w
.6508 .55352 m .60983 .59445 L .59596 .59945 L p
1 g
F P
s
P
p
.002 w
.69557 .41539 m .67762 .35321 L .67851 .34643 L p
1 g
F P
s
P
p
.002 w
.64228 .29421 m .67851 .34643 L .67762 .35321 L p
1 g
F P
s
P
p
.002 w
.38045 .58372 m .42321 .60788 L .42722 .61384 L p
1 g
F P
s
P
p
.002 w
.47966 .62575 m .42722 .61384 L .42321 .60788 L p
1 g
F P
s
P
p
.002 w
.63956 .29839 m .58592 .25794 L .59121 .25572 L p
1 g
F P
s
P
p
.002 w
.59121 .25572 m .64228 .29421 L .63956 .29839 L p
1 g
F P
s
P
p
.002 w
.47966 .62575 m .53194 .62111 L .54546 .62235 L p
1 g
F P
s
P
p
.002 w
.59596 .59945 m .54546 .62235 L .53194 .62111 L p
1 g
F P
s
P
p
.002 w
.51428 .24376 m .44988 .24423 L .46032 .23745 L p
1 g
F P
s
P
p
.002 w
.46032 .23745 m .52354 .23691 L .51428 .24376 L p
1 g
F P
s
P
p
.002 w
.67762 .35321 m .63956 .29839 L .64228 .29421 L p
1 g
F P
s
P
p
.002 w
.31405 .45867 m .323 .50543 L .31558 .49971 L p
1 g
F P
s
P
p
.002 w
.31558 .49971 m .30551 .44748 L .31405 .45867 L p
1 g
F P
s
P
p
.002 w
.44048 .2567 m .38362 .2779 L .3924 .26581 L p
1 g
F P
s
P
p
.002 w
.3924 .26581 m .44988 .24423 L .44048 .2567 L p
1 g
F P
s
P
p
.004 w
.41343 .235 m
.41789 .24505 L
s
P
p
.002 w
.37788 .29491 m .33577 .33189 L .3398 .3166 L p
1 g
F P
s
P
p
.002 w
.3398 .3166 m .38362 .2779 L .37788 .29491 L p
1 g
F P
s
P
p
.002 w
.42321 .60788 m .47022 .61852 L .47966 .62575 L p
1 g
F P
s
P
p
.002 w
.53194 .62111 m .47966 .62575 L .47022 .61852 L p
1 g
F P
s
P
p
.002 w
.33639 .35064 m .31245 .39601 L .3101 .38089 L p
1 g
F P
s
P
p
.002 w
.3101 .38089 m .33577 .33189 L .33639 .35064 L p
1 g
F P
s
P
p
.002 w
.68617 .48874 m .68992 .4259 L .69557 .41539 L p
1 g
F P
s
P
p
.002 w
.67762 .35321 m .69557 .41539 L .68992 .4259 L p
1 g
F P
s
P
p
.002 w
.32037 .41273 m .31405 .45867 L .30551 .44748 L p
1 g
F P
s
P
p
.002 w
.30551 .44748 m .31245 .39601 L .32037 .41273 L p
1 g
F P
s
P
p
.002 w
.6508 .55352 m .67492 .49914 L .68617 .48874 L p
1 g
F P
s
P
p
.002 w
.68992 .4259 m .68617 .48874 L .67492 .49914 L p
1 g
F P
s
P
p
.002 w
.57789 .26529 m .51428 .24376 L .52354 .23691 L p
1 g
F P
s
P
p
.002 w
.52354 .23691 m .58592 .25794 L .57789 .26529 L p
1 g
F P
s
P
p
.002 w
.59596 .59945 m .63516 .56014 L .6508 .55352 L p
1 g
F P
s
P
p
.002 w
.67492 .49914 m .6508 .55352 L .63516 .56014 L p
1 g
F P
s
P
p
.002 w
.35539 .54587 m .38481 .57594 L .38045 .58372 L p
1 g
F P
s
P
p
.002 w
.38045 .58372 m .34594 .54846 L .35539 .54587 L p
1 g
F P
s
P
p
.002 w
.42321 .60788 m .38045 .58372 L .38481 .57594 L p
1 g
F P
s
P
p
.002 w
.53194 .62111 m .57878 .59975 L .59596 .59945 L p
1 g
F P
s
P
p
.002 w
.63516 .56014 m .59596 .59945 L .57878 .59975 L p
1 g
F P
s
P
p
.002 w
.3359 .50921 m .35539 .54587 L .34594 .54846 L p
1 g
F P
s
P
p
.002 w
.34594 .54846 m .323 .50543 L .3359 .50921 L p
1 g
F P
s
P
p
.002 w
.68992 .4259 m .67154 .36254 L .67762 .35321 L p
1 g
F P
s
P
p
.002 w
.63956 .29839 m .67762 .35321 L .67154 .36254 L p
1 g
F P
s
P
p
.002 w
.38481 .57594 m .42127 .59651 L .42321 .60788 L p
1 g
F P
s
P
p
.002 w
.47022 .61852 m .42321 .60788 L .42127 .59651 L p
1 g
F P
s
P
p
.002 w
.47022 .61852 m .51695 .61428 L .53194 .62111 L p
1 g
F P
s
P
p
.002 w
.57878 .59975 m .53194 .62111 L .51695 .61428 L p
1 g
F P
s
P
p
.002 w
.50423 .2564 m .44048 .2567 L .44988 .24423 L p
1 g
F P
s
P
p
.002 w
.44988 .24423 m .51428 .24376 L .50423 .2564 L p
1 g
F P
s
P
p
.002 w
.63265 .3066 m .57789 .26529 L .58592 .25794 L p
1 g
F P
s
P
p
.002 w
.58592 .25794 m .63956 .29839 L .63265 .3066 L p
1 g
F P
s
P
p
.002 w
.32839 .46946 m .3359 .50921 L .323 .50543 L p
1 g
F P
s
P
p
.002 w
.323 .50543 m .31405 .45867 L .32839 .46946 L p
1 g
F P
s
P
p
.002 w
.67154 .36254 m .63265 .3066 L .63956 .29839 L p
1 g
F P
s
P
p
.002 w
.43248 .27479 m .37788 .29491 L .38362 .2779 L p
1 g
F P
s
P
p
.002 w
.38362 .2779 m .44048 .2567 L .43248 .27479 L p
1 g
F P
s
P
p
.004 w
.41789 .24505 m
.42699 .26562 L
s
P
p
.002 w
.37555 .31656 m .33639 .35064 L .33577 .33189 L p
1 g
F P
s
P
p
.002 w
.33577 .33189 m .37788 .29491 L .37555 .31656 L p
1 g
F P
s
P
p
.002 w
.34188 .37242 m .32037 .41273 L .31245 .39601 L p
1 g
F P
s
P
p
.002 w
.31245 .39601 m .33639 .35064 L .34188 .37242 L p
1 g
F P
s
P
p
.002 w
.42127 .59651 m .46127 .60549 L .47022 .61852 L p
1 g
F P
s
P
p
.002 w
.51695 .61428 m .47022 .61852 L .46127 .60549 L p
1 g
F P
s
P
p
.002 w
.67492 .49914 m .67848 .43697 L .68992 .4259 L p
1 g
F P
s
P
p
.002 w
.67154 .36254 m .68992 .4259 L .67848 .43697 L p
1 g
F P
s
P
p
.002 w
.33391 .43058 m .32839 .46946 L .31405 .45867 L p
1 g
F P
s
P
p
.002 w
.31405 .45867 m .32037 .41273 L .33391 .43058 L p
1 g
F P
s
P
p
.002 w
.63516 .56014 m .6581 .50793 L .67492 .49914 L p
1 g
F P
s
P
p
.002 w
.67848 .43697 m .67492 .49914 L .6581 .50793 L p
1 g
F P
s
P
p
.002 w
.56723 .27785 m .50423 .2564 L .51428 .24376 L p
1 g
F P
s
P
p
.002 w
.51428 .24376 m .57789 .26529 L .56723 .27785 L p
1 g
F P
s
P
p
.002 w
.57878 .59975 m .61496 .56318 L .63516 .56014 L p
1 g
F P
s
P
p
.002 w
.6581 .50793 m .63516 .56014 L .61496 .56318 L p
1 g
F P
s
P
p
.002 w
.51695 .61428 m .55863 .59508 L .57878 .59975 L p
1 g
F P
s
P
p
.002 w
.61496 .56318 m .57878 .59975 L .55863 .59508 L p
1 g
F P
s
P
p
.002 w
.36952 .53976 m .39276 .56354 L .38481 .57594 L p
1 g
F P
s
P
p
.002 w
.38481 .57594 m .35539 .54587 L .36952 .53976 L p
1 g
F P
s
P
p
.002 w
.42127 .59651 m .38481 .57594 L .39276 .56354 L p
1 g
F P
s
P
p
.002 w
.35419 .51079 m .36952 .53976 L .35539 .54587 L p
1 g
F P
s
P
p
.002 w
.35539 .54587 m .3359 .50921 L .35419 .51079 L p
1 g
F P
s
P
p
.002 w
.46127 .60549 m .50089 .60176 L .51695 .61428 L p
1 g
F P
s
P
p
.002 w
.55863 .59508 m .51695 .61428 L .50089 .60176 L p
1 g
F P
s
P
p
.002 w
.67848 .43697 m .66013 .37425 L .67154 .36254 L p
1 g
F P
s
P
p
.002 w
.63265 .3066 m .67154 .36254 L .66013 .37425 L p
1 g
F P
s
P
p
.002 w
.39276 .56354 m .42158 .57976 L .42127 .59651 L p
1 g
F P
s
P
p
.002 w
.46127 .60549 m .42127 .59651 L .42158 .57976 L p
1 g
F P
s
P
p
.002 w
.49366 .27474 m .43248 .27479 L .44048 .2567 L p
1 g
F P
s
P
p
.002 w
.44048 .2567 m .50423 .2564 L .49366 .27474 L p
1 g
F P
s
P
p
.002 w
.6215 .31883 m .56723 .27785 L .57789 .26529 L p
1 g
F P
s
P
p
.002 w
.57789 .26529 m .63265 .3066 L .6215 .31883 L p
1 g
F P
s
P
p
.002 w
.42623 .2982 m .37555 .31656 L .37788 .29491 L p
1 g
F P
s
P
p
.002 w
.37788 .29491 m .43248 .27479 L .42623 .2982 L p
1 g
F P
s
P
p
.002 w
.37689 .34234 m .34188 .37242 L .33639 .35064 L p
1 g
F P
s
P
p
.002 w
.33639 .35064 m .37555 .31656 L .37689 .34234 L p
1 g
F P
s
P
p
.002 w
.34839 .47948 m .35419 .51079 L .3359 .50921 L p
1 g
F P
s
P
p
.002 w
.3359 .50921 m .32839 .46946 L .34839 .47948 L p
1 g
F P
s
P
p
.002 w
.66013 .37425 m .6215 .31883 L .63265 .3066 L p
1 g
F P
s
P
p
.002 w
.3523 .39665 m .33391 .43058 L .32037 .41273 L p
1 g
F P
s
P
p
.002 w
.32037 .41273 m .34188 .37242 L .3523 .39665 L p
1 g
F P
s
P
p
.002 w
.42158 .57976 m .45313 .58675 L .46127 .60549 L p
1 g
F P
s
P
p
.002 w
.50089 .60176 m .46127 .60549 L .45313 .58675 L p
1 g
F P
s
P
p
.002 w
.6581 .50793 m .66128 .44827 L .67848 .43697 L p
1 g
F P
s
P
p
.002 w
.66013 .37425 m .67848 .43697 L .66128 .44827 L p
1 g
F P
s
P
p
.002 w
.61496 .56318 m .63596 .51471 L .6581 .50793 L p
1 g
F P
s
P
p
.002 w
.66128 .44827 m .6581 .50793 L .63596 .51471 L p
1 g
F P
s
P
p
.002 w
.3529 .44899 m .34839 .47948 L .32839 .46946 L p
1 g
F P
s
P
p
.002 w
.32839 .46946 m .33391 .43058 L .3529 .44899 L p
1 g
F P
s
P
p
.002 w
.55863 .59508 m .59064 .56236 L .61496 .56318 L p
1 g
F P
s
P
p
.002 w
.63596 .51471 m .61496 .56318 L .59064 .56236 L p
1 g
F P
s
P
p
.002 w
.50089 .60176 m .53605 .58533 L .55863 .59508 L p
1 g
F P
s
P
p
.002 w
.59064 .56236 m .55863 .59508 L .53605 .58533 L p
1 g
F P
s
P
p
.002 w
.55413 .29549 m .49366 .27474 L .50423 .2564 L p
1 g
F P
s
P
p
.002 w
.50423 .2564 m .56723 .27785 L .55413 .29549 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.45313 .58675 m .48426 .58367 L .50089 .60176 L p
1 g
F P
s
P
p
.002 w
.53605 .58533 m .50089 .60176 L .48426 .58367 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.38812 .53013 m .40425 .54665 L .39276 .56354 L p
1 g
F P
s
P
p
.002 w
.39276 .56354 m .36952 .53976 L .38812 .53013 L p
1 g
F P
s
P
p
.002 w
.42158 .57976 m .39276 .56354 L .40425 .54665 L p
1 g
F P
s
P
p
.002 w
.37753 .51001 m .38812 .53013 L .36952 .53976 L p
1 g
F P
s
P
p
.002 w
.36952 .53976 m .35419 .51079 L .37753 .51001 L p
1 g
F P
s
P
p
.002 w
.48294 .29842 m .42623 .2982 L .43248 .27479 L p
1 g
F P
s
P
p
.002 w
.43248 .27479 m .49366 .27474 L .48294 .29842 L p
1 g
F P
s
P
p
.004 w
.42699 .26562 m
.43513 .28399 L
s
P
p
.004 w
.43513 .28399 m
.4382 .29093 L
s
P
p
.002 w
.66128 .44827 m .64347 .3881 L .66013 .37425 L p
1 g
F P
s
P
p
.002 w
.6215 .31883 m .66013 .37425 L .64347 .3881 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.42205 .32634 m .37689 .34234 L .37555 .31656 L p
1 g
F P
s
P
p
.002 w
.37555 .31656 m .42623 .2982 L .42205 .32634 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.40425 .54665 m .42427 .55787 L .42158 .57976 L p
1 g
F P
s
P
p
.002 w
.45313 .58675 m .42158 .57976 L .42427 .55787 L p
1 g
F P
s
P
p
.002 w
.38203 .37153 m .3523 .39665 L .34188 .37242 L p
1 g
F P
s
P
p
.002 w
.34188 .37242 m .37689 .34234 L .38203 .37153 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.60627 .33491 m .55413 .29549 L .56723 .27785 L p
1 g
F P
s
P
p
.002 w
.56723 .27785 m .6215 .31883 L .60627 .33491 L p
1 g
F P
s
P
p
.002 w
.37362 .48833 m .37753 .51001 L .35419 .51079 L p
1 g
F P
s
P
p
.002 w
.35419 .51079 m .34839 .47948 L .37362 .48833 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.3675 .42257 m .3529 .44899 L .33391 .43058 L p
1 g
F P
s
P
p
.002 w
.33391 .43058 m .3523 .39665 L .3675 .42257 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.64347 .3881 m .60627 .33491 L .6215 .31883 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.42427 .55787 m .44614 .56264 L .45313 .58675 L p
1 g
F P
s
P
p
.002 w
.45313 .58675 m .4474 .56698 L p
.48134 .58234 L 1 g
F P
s
P
p
.002 w
.48426 .58367 m .48359 .58373 L p
.48134 .58234 L 1 g
F P
s
P
p
.002 w
.48359 .58373 m .45313 .58675 L p
.48134 .58234 L 1 g
F P
s
P
p
.002 w
.4474 .56698 m .44614 .56264 L p
.45426 .56712 L 1 g
F P
s
P
p
.4655 .57332 m .45754 .57053 L .45426 .56712 L 1 g
F
P
p
.45754 .57053 m .4474 .56698 L .45426 .56712 L 1 g
F
P
p
.002 w
.42427 .55787 m .42887 .53397 L p
.44067 .55356 L 1 g
F P
s
P
p
.002 w
.42887 .53397 m .42936 .53139 L p
.43613 .54399 L 1 g
F P
s
P
p
.44614 .56264 m .42887 .53397 L .43613 .54399 L 1 g
F
P
p
.002 w
.43844 .54718 m .43925 .54566 L p
.43491 .53707 L 1 g
F P
s
P
p
.45146 .56129 m .44391 .55473 L .44485 .55603 L 1 g
F
P
p
.002 w
.44488 .55607 m .44614 .56264 L p
.43613 .54399 L 1 g
F P
s
P
p
.002 w
.45068 .56339 m .45146 .56129 L p
.44485 .55603 L 1 g
F P
s
P
p
.002 w
.44961 .56228 m .44614 .56264 L .44488 .55607 L p
1 g
F P
s
P
p
.44485 .55603 m .43955 .55181 L .44961 .56228 L 1 g
F
P
p
.44485 .55603 m .44961 .56228 L .45068 .56339 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45068 .56339 L p
1 g
F P
s
P
p
.002 w
.44614 .56264 m .44899 .56234 L p
.46836 .57432 L 1 g
F P
s
P
p
.47699 .57966 m .4655 .57332 L .46836 .57432 L 1 g
F
P
p
.4655 .57332 m .44614 .56264 L .46836 .57432 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46836 .57432 L p
1 g
F P
s
P
p
.48921 .57862 m .46836 .57432 L .47802 .5777 L 1 g
F
P
p
.48921 .57862 m .47802 .5777 L .48066 .57863 L 1 g
F
P
p
.48921 .57862 m .48066 .57863 L .48645 .5802 L 1 g
F
P
p
.002 w
.4897 .58108 m .48426 .58367 L .48209 .58062 L p
1 g
F P
s
P
p
.002 w
.48209 .58062 m .48066 .57863 L p
.48904 .5809 L 1 g
F P
s
P
p
.4897 .58108 m .48209 .58062 L .48904 .5809 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .5809 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .5809 L .48999 .58094 L 1 g
F
P
p
.51119 .58453 m .50025 .58268 L .51136 .58018 L 1 g
F
P
p
.50025 .58268 m .48999 .58094 L .51091 .5802 L 1 g
F
P
p
.50025 .58268 m .51091 .5802 L .51136 .58018 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .5802 L p
1 g
F P
s
P
p
.53128 .57265 m .51091 .5802 L .52126 .57779 L 1 g
F
P
p
.51079 .57862 m .48999 .58094 L .50117 .58054 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.4897 .58108 m .48999 .58094 L p
.51119 .58453 L 1 g
F P
s
P
p
.002 w
.48426 .58367 m .4897 .58108 L p
.51119 .58453 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.48999 .58094 m .51172 .5706 L p
.51136 .58018 L 1 g
F P
s
P
p
.53605 .58533 m .51119 .58453 L .51136 .58009 L 1 g
F
P
p
.53128 .57265 m .52126 .57779 L .52294 .5774 L 1 g
F
P
p
.002 w
.55516 .5655 m .53605 .58533 L .52492 .5786 L p
1 g
F P
s
P
p
.002 w
.52492 .5786 m .52294 .5774 L p
.53162 .5742 L 1 g
F P
s
P
p
.55516 .5655 m .52492 .5786 L .53162 .5742 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53162 .5742 L p
1 g
F P
s
P
p
.54854 .56129 m .53162 .5742 L .5425 .56705 L 1 g
F
P
p
.002 w
.53162 .5742 m .53128 .57265 L p
.52294 .5774 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54908 .56273 m .54854 .56129 L p
.5425 .56705 L 1 g
F P
s
P
p
.002 w
.52294 .5774 m .51172 .5706 L p
.54261 .56698 L 1 g
F P
s
P
p
.55516 .5655 m .53162 .5742 L .54261 .56698 L 1 g
F
P
p
.53162 .5742 m .52294 .5774 L .54261 .56698 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56285 .55752 m .55516 .5655 L p
.54559 .56663 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54908 .56273 L p
1 g
F P
s
P
p
.56075 .54566 m .54908 .56273 L .55497 .55614 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.55103 .56055 m .54559 .56663 L .51172 .5706 L 1 g
F
P
p
.56285 .55752 m .54559 .56663 L .55103 .56055 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.56075 .54566 m .55497 .55614 L .55562 .55542 L 1 g
F
P
p
.002 w
.57583 .52625 m .56285 .55752 L .55852 .55626 L p
1 g
F P
s
P
p
.002 w
.55852 .55626 m .55562 .55542 L p
.56146 .54699 L 1 g
F P
s
P
p
.57583 .52625 m .55852 .55626 L .56146 .54699 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56146 .54699 L p
1 g
F P
s
P
p
.56654 .52734 m .56146 .54699 L .56499 .53582 L 1 g
F
P
p
.002 w
.56146 .54699 m .56075 .54566 L p
.55562 .55542 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56732 .52847 m .56654 .52734 L p
.56499 .53582 L 1 g
F P
s
P
p
.002 w
.55562 .55542 m .53246 .54868 L p
.56649 .53108 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56732 .52847 L p
1 g
F P
s
P
p
.57583 .52625 m .56769 .538 L .5674 .53061 L 1 g
F
P
p
.56515 .50826 m .56732 .52847 L .56701 .52068 L 1 g
F
P
p
.57942 .47958 m .5687 .51508 L .56454 .49659 L 1 g
F
P
p
.5687 .51508 m .56701 .52068 L .56582 .50906 L 1 g
F
P
p
.5687 .51508 m .56582 .50906 L .56454 .49659 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56582 .50906 L p
1 g
F P
s
P
p
.55661 .4905 m .56582 .50906 L .56055 .49804 L 1 g
F
P
p
.56515 .50826 m .56701 .52068 L .5669 .51964 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.57942 .47958 m .57802 .52098 L .56701 .52068 L p
1 g
F P
s
P
p
.002 w
.57802 .52098 m .57583 .52625 L p
.5674 .53061 L 1 g
F P
s
P
p
.56728 .52751 m .5674 .53061 L .53246 .54868 L 1 g
F
P
p
.57802 .52098 m .5674 .53061 L .56728 .52751 L 1 g
F
P
p
.002 w
.53246 .54868 m .54402 .52005 L .57802 .52098 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56659 .50998 L p
1 g
F P
s
P
p
.002 w
.56659 .50998 m .56515 .50826 L p
.56699 .52021 L 1 g
F P
s
P
p
.56699 .52021 m .56854 .53025 L .56659 .50998 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56701 .52068 m .54402 .52005 L p
.56151 .50005 L 1 g
F P
s
P
p
.56454 .49659 m .56582 .50906 L .56151 .50005 L 1 g
F
P
p
.56582 .50906 m .56701 .52068 L .56151 .50005 L 1 g
F
P
p
.002 w
.55729 .49122 m .55661 .4905 L p
.56055 .49804 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54402 .52005 m .54485 .48778 L .55197 .48609 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55729 .49122 L p
1 g
F P
s
P
p
.54174 .47608 m .55729 .49122 L .55197 .48609 L 1 g
F
P
p
.002 w
.55197 .48609 m .54485 .48778 L p
.54748 .48173 L 1 g
F P
s
P
p
.55091 .48506 m .55197 .48609 L .55137 .48551 L 1 g
F
P
p
.54174 .47608 m .55197 .48609 L .55091 .48506 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56648 .43803 m .57942 .47958 L .55197 .48609 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.56377 .49748 m .54402 .52005 L .55197 .48609 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55729 .49122 L p
1 g
F P
s
P
p
.56055 .49804 m .56713 .51061 L .55729 .49122 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54485 .48778 m .54117 .4762 L p
.54748 .48173 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47675 L p
1 g
F P
s
P
p
.52214 .46667 m .54235 .47675 L .54117 .4762 L 1 g
F
P
p
.002 w
.54117 .4762 m .54485 .48778 L p
.52572 .46873 L 1 g
F P
s
P
p
.53183 .47169 m .54117 .4762 L .53508 .47337 L 1 g
F
P
p
.52214 .46667 m .54117 .4762 L .53183 .47169 L 1 g
F
P
p
.002 w
.54485 .48778 m .50861 .49426 L p
.52572 .46873 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.54748 .48173 m .54117 .4762 L .54235 .47675 L 1 g
F
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.52572 .46873 m .50861 .49426 L .51636 .46632 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46714 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46714 L .51387 .46598 L 1 g
F
P
p
.002 w
.51387 .46598 m .50148 .47225 L p
.50368 .46446 L 1 g
F P
s
P
p
.51188 .46568 m .51387 .46598 L .51236 .46578 L 1 g
F
P
p
.5 .4634 m .51387 .46598 L .51188 .46568 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.51428 .42699 m .53459 .4555 L .51387 .46598 L p
1 g
F P
s
P
p
.52572 .46873 m .51636 .46632 L .52242 .46714 L 1 g
F
P
p
.002 w
.50861 .49426 m .50148 .47225 L .51387 .46598 L p
1 g
F P
s
P
p
.51636 .46632 m .50861 .49426 L .51387 .46598 L 1 g
F
P
p
.002 w
.5 .46391 m .5 .4634 L p
.51188 .46568 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48757 .45285 m .51428 .42699 L p
.50368 .46446 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50148 .47225 m .49598 .46458 L p
.50368 .46446 L 1 g
F P
s
P
p
.50368 .46446 m .49598 .46458 L .5 .46391 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.46845 .48765 m .4614 .47787 L .46741 .47212 L p
1 g
F P
s
P
p
.47137 .47019 m .46845 .48765 L .46741 .47212 L 1 g
F
P
p
.47988 .46685 m .46845 .48765 L .47137 .47019 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46717 L p
1 g
F P
s
P
p
.45826 .47608 m .47756 .46717 L .46855 .47157 L 1 g
F
P
p
.47756 .46717 m .47137 .47019 L .47173 .46799 L 1 g
F
P
p
.47988 .46685 m .47137 .47019 L .47756 .46717 L 1 g
F
P
p
.002 w
.47756 .46717 m .47718 .46778 L p
.46855 .47157 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43862 .49936 m .43678 .50109 L p
.44153 .49238 L 1 g
F P
s
P
p
.44729 .48182 m .44256 .49138 L .44153 .49238 L 1 g
F
P
p
.44256 .49138 m .43862 .49936 L .44153 .49238 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44253 .49141 L p
1 g
F P
s
P
p
.002 w
.44253 .49141 m .44248 .49147 L p
.44217 .49215 L 1 g
F P
s
P
p
.43485 .50826 m .44253 .49141 L .44217 .49215 L 1 g
F
P
p
.43485 .50826 m .44248 .49147 L .44195 .49255 L 1 g
F
P
p
.43485 .50826 m .4424 .49155 L .44175 .49289 L 1 g
F
P
p
.43485 .50826 m .4423 .49165 L .44159 .49314 L 1 g
F
P
p
.43485 .50826 m .4422 .49176 L .44149 .49326 L 1 g
F
P
p
.43485 .50826 m .44211 .49186 L .44147 .49321 L 1 g
F
P
p
.43485 .50826 m .44203 .49195 L .44156 .49295 L 1 g
F
P
p
.43485 .50826 m .44197 .492 L .44176 .49247 L 1 g
F
P
p
.43485 .50826 m .44195 .49203 L .43996 .49632 L 1 g
F
P
p
.002 w
.43754 .50155 m .43678 .50109 L .43765 .50131 L p
1 g
F P
s
P
p
.002 w
.43742 .5018 m .43678 .50109 L .43754 .50155 L p
1 g
F P
s
P
p
.002 w
.43727 .50213 m .43678 .50109 L .43742 .5018 L p
1 g
F P
s
P
p
.002 w
.43697 .50276 m .43678 .50109 L .43727 .50213 L p
1 g
F P
s
P
p
.002 w
.4357 .50549 m .43678 .50109 L .43697 .50276 L p
1 g
F P
s
P
p
.002 w
.41905 .52563 m .43678 .50109 L .4357 .50549 L p
1 g
F P
s
P
p
.002 w
.42485 .52887 m .41905 .52563 L p
.43403 .50752 L 1 g
F P
s
P
p
.43388 .50942 m .43403 .50752 L .4357 .50549 L 1 g
F
P
p
.42485 .52887 m .43403 .50752 L .43388 .50942 L 1 g
F
P
p
.002 w
.43237 .52893 m .43346 .52734 L p
.43316 .51868 L 1 g
F P
s
P
p
.43485 .50826 m .43893 .49871 L .43758 .50145 L 1 g
F
P
p
.002 w
.4333 .51011 m .43387 .50943 L p
.43758 .50145 L 1 g
F P
s
P
p
.002 w
.43387 .50943 m .43485 .50826 L p
.43758 .50145 L 1 g
F P
s
P
p
.002 w
.43214 .53198 m .42936 .53139 L .43114 .52412 L p
1 g
F P
s
P
p
.002 w
.43114 .52412 m .43347 .5146 L p
.43237 .52893 L 1 g
F P
s
P
p
.43214 .53198 m .43114 .52412 L .43237 .52893 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43321 .53221 m .43214 .53198 L p
.43249 .52938 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43237 .52893 L p
1 g
F P
s
P
p
.43214 .53198 m .43237 .52893 L .43249 .52938 L 1 g
F
P
p
.002 w
.43237 .52893 m .43217 .52922 L p
.43286 .53082 L 1 g
F P
s
P
p
.43925 .54566 m .43237 .52893 L .43286 .53082 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50942 L p
1 g
F P
s
P
p
.002 w
.42936 .53139 m .42485 .52887 L p
.43388 .50942 L 1 g
F P
s
P
p
.002 w
.43347 .5146 m .42936 .53139 L p
.43388 .50942 L 1 g
F P
s
P
p
.002 w
.43388 .50942 m .43287 .51061 L p
.43316 .51863 L 1 g
F P
s
P
p
.43346 .52734 m .43388 .50942 L .43316 .51863 L 1 g
F
P
p
.002 w
.4357 .50549 m .43347 .5146 L p
.43388 .50942 L 1 g
F P
s
P
p
.002 w
.43347 .5146 m .4357 .50549 L p
.43249 .52938 L 1 g
F P
s
P
p
.43237 .52893 m .43347 .5146 L .43249 .52938 L 1 g
F
P
p
.43925 .54566 m .43217 .52922 L .43491 .53707 L 1 g
F
P
p
.002 w
.4406 .53379 m .44488 .55607 L p
.43738 .54413 L 1 g
F P
s
P
p
.002 w
.42936 .53139 m .43321 .53221 L p
.43738 .54413 L 1 g
F P
s
P
p
.002 w
.43321 .53221 m .4406 .53379 L p
.43738 .54413 L 1 g
F P
s
P
p
.002 w
.43217 .52922 m .43146 .53025 L p
.43491 .53707 L 1 g
F P
s
P
p
.43613 .54399 m .42936 .53139 L .44488 .55607 L 1 g
F
P
p
.43491 .53707 m .43399 .53525 L .43844 .54718 L 1 g
F
P
p
.43399 .53525 m .43146 .53025 L .43474 .53822 L 1 g
F
P
p
.43399 .53525 m .43474 .53822 L .43844 .54718 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43749 .54898 L p
1 g
F P
s
P
p
.002 w
.43749 .54898 m .43844 .54718 L p
.43474 .53822 L 1 g
F P
s
P
p
.43474 .53822 m .43146 .53025 L .43749 .54898 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.4406 .53379 m .43321 .53221 L p
.4357 .50549 L 1 g
F P
s
P
p
.43321 .53221 m .43249 .52938 L .4357 .50549 L 1 g
F
P
p
.002 w
.43235 .52896 m .43237 .52893 L p
.43316 .51863 L 1 g
F P
s
P
p
.43316 .51868 m .43316 .51863 L .43237 .52893 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43235 .52896 L p
1 g
F P
s
P
p
.43316 .51863 m .43287 .51061 L .43235 .52896 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.4614 .47787 m .46845 .48765 L .43802 .50056 L p
1 g
F P
s
P
p
.002 w
.43802 .50056 m .43678 .50109 L .43862 .49936 L p
1 g
F P
s
P
p
.002 w
.43862 .49936 m .4614 .47787 L p
.43802 .50056 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.46845 .48765 m .47212 .49875 L .43779 .50102 L p
1 g
F P
s
P
p
.002 w
.43779 .50102 m .43678 .50109 L .43802 .50056 L p
1 g
F P
s
P
p
.002 w
.43802 .50056 m .46845 .48765 L p
.43779 .50102 L 1 g
F P
s
P
p
.002 w
.44248 .49147 m .4424 .49155 L p
.44195 .49255 L 1 g
F P
s
P
p
.002 w
.4424 .49155 m .4423 .49165 L p
.44175 .49289 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.47212 .49875 m .47203 .50994 L .43765 .50131 L p
1 g
F P
s
P
p
.002 w
.43765 .50131 m .43678 .50109 L .43779 .50102 L p
1 g
F P
s
P
p
.002 w
.43779 .50102 m .47212 .49875 L p
.43765 .50131 L 1 g
F P
s
P
p
.002 w
.47203 .50994 m .46822 .51998 L .43754 .50155 L p
1 g
F P
s
P
p
.002 w
.43765 .50131 m .47203 .50994 L p
.43754 .50155 L 1 g
F P
s
P
p
.002 w
.4423 .49165 m .4422 .49176 L p
.44159 .49314 L 1 g
F P
s
P
p
.002 w
.4422 .49176 m .44211 .49186 L p
.44149 .49326 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.46822 .51998 m .46114 .52779 L .43742 .5018 L p
1 g
F P
s
P
p
.002 w
.43754 .50155 m .46822 .51998 L p
.43742 .5018 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.46114 .52779 m .45159 .53255 L .43727 .50213 L p
1 g
F P
s
P
p
.002 w
.43742 .5018 m .46114 .52779 L p
.43727 .50213 L 1 g
F P
s
P
p
.002 w
.44211 .49186 m .44203 .49195 L p
.44147 .49321 L 1 g
F P
s
P
p
.002 w
.44203 .49195 m .44197 .492 L p
.44156 .49295 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.45159 .53255 m .4406 .53379 L .43697 .50276 L p
1 g
F P
s
P
p
.002 w
.43727 .50213 m .45159 .53255 L p
.43697 .50276 L 1 g
F P
s
P
p
.002 w
.43697 .50276 m .4406 .53379 L p
.4357 .50549 L 1 g
F P
s
P
p
.002 w
.44197 .492 m .44195 .49203 L p
.44176 .49247 L 1 g
F P
s
P
p
.002 w
.44195 .49203 m .44166 .49233 L p
.43996 .49632 L 1 g
F P
s
P
p
.002 w
.44256 .49138 m .44339 .4905 L p
.45053 .48366 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4614 .47787 m .43862 .49936 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45754 .47687 L p
1 g
F P
s
P
p
.44339 .4905 m .45754 .47687 L .45053 .48366 L 1 g
F
P
p
.44729 .48182 m .45452 .47979 L .44256 .49138 L 1 g
F
P
p
.45452 .47979 m .4614 .47787 L .44256 .49138 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45913 .47613 m .4614 .47787 L p
.44606 .48216 L 1 g
F P
s
P
p
.002 w
.45754 .47687 m .45698 .47747 L p
.45053 .48366 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.45053 .48366 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .4333 .51011 L p
1 g
F P
s
P
p
.43893 .49871 m .44166 .49233 L .4333 .51011 L 1 g
F
P
p
.002 w
.43678 .50109 m .44606 .48216 L p
.44729 .48182 L 1 g
F P
s
P
p
.45826 .47608 m .46855 .47157 L .46741 .47212 L 1 g
F
P
p
.002 w
.4614 .47787 m .45913 .47613 L p
.46196 .47477 L 1 g
F P
s
P
p
.002 w
.45748 .47693 m .45826 .47608 L p
.46741 .47212 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46847 .43828 m .48757 .45285 L .46741 .47212 L p
1 g
F P
s
P
p
.002 w
.46741 .47212 m .4614 .47787 L p
.46196 .47477 L 1 g
F P
s
P
p
.46847 .43828 m .46741 .47212 L .46196 .47477 L 1 g
F
P
p
.46741 .47212 m .47718 .46778 L .45742 .477 L 1 g
F
P
p
.46855 .47157 m .46864 .47153 L .46741 .47212 L 1 g
F
P
p
.46864 .47153 m .47718 .46778 L .46741 .47212 L 1 g
F
P
p
.002 w
.45742 .477 m .45748 .47693 L p
.46741 .47212 L 1 g
F P
s
P
p
.002 w
.45177 .47051 m .46847 .43828 L p
.46196 .47477 L 1 g
F P
s
P
p
.002 w
.45913 .47613 m .45177 .47051 L p
.46196 .47477 L 1 g
F P
s
P
p
.002 w
.44606 .48216 m .45177 .47051 L .45913 .47613 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .45742 .477 L p
.47191 .47024 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .47569 .4685 L p
.47191 .47024 L 1 g
F P
s
P
p
.002 w
.47569 .4685 m .45698 .47747 L p
.47191 .47024 L 1 g
F P
s
P
p
.002 w
.46741 .47212 m .47173 .46799 L p
.47137 .47019 L 1 g
F P
s
P
p
.002 w
.47756 .46717 m .47786 .46667 L p
.48965 .46547 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.50148 .47225 m .46845 .48765 L p
.47988 .46685 L 1 g
F P
s
P
p
.002 w
.49598 .46458 m .50148 .47225 L p
.47988 .46685 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46391 L .49219 .46521 L 1 g
F
P
p
.002 w
.48757 .45285 m .49598 .46458 L p
.47988 .46685 L 1 g
F P
s
P
p
.49219 .46521 m .49598 .46458 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46391 m .5 .46401 L p
.49598 .46458 L 1 g
F P
s
P
p
.002 w
.5 .46401 m .5 .46442 L p
.49598 .46458 L 1 g
F P
s
P
p
.002 w
.49496 .46316 m .48757 .45285 L p
.50237 .46351 L 1 g
F P
s
P
p
.50368 .46446 m .5 .46391 L .50237 .46351 L 1 g
F
P
p
.5 .46391 m .49496 .46316 L .50237 .46351 L 1 g
F
P
p
.002 w
.47173 .46799 m .48757 .45285 L p
.47988 .46685 L 1 g
F P
s
P
p
.002 w
.47723 .46771 m .47756 .46717 L p
.49219 .46521 L 1 g
F P
s
P
p
.48965 .46547 m .49219 .46521 L .47756 .46717 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47723 .46771 L p
1 g
F P
s
P
p
.49219 .46521 m .5 .46442 L .47723 .46771 L 1 g
F
P
p
.002 w
.49598 .46458 m .49496 .46316 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.5 .4641 m .5 .46391 L p
.51236 .46578 L 1 g
F P
s
P
p
.51188 .46568 m .51236 .46578 L .5 .46391 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4641 L p
1 g
F P
s
P
p
.51236 .46578 m .52282 .46778 L .5 .4641 L 1 g
F
P
p
.002 w
.51387 .46598 m .51688 .46446 L p
.51636 .46632 L 1 g
F P
s
P
p
.51428 .42699 m .51387 .46598 L .50368 .46446 L 1 g
F
P
p
.52242 .46714 m .51636 .46632 L .51688 .46446 L 1 g
F
P
p
.002 w
.52242 .46714 m .52282 .46778 L p
.51236 .46578 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52242 .46714 L p
1 g
F P
s
P
p
.002 w
.52242 .46714 m .52214 .46667 L p
.53183 .47169 L 1 g
F P
s
P
p
.53183 .47169 m .54302 .47747 L .52242 .46714 L 1 g
F
P
p
.002 w
.51688 .46446 m .53459 .4555 L p
.52572 .46873 L 1 g
F P
s
P
p
.002 w
.53459 .4555 m .54117 .4762 L p
.52572 .46873 L 1 g
F P
s
P
p
.002 w
.54117 .4762 m .54089 .47533 L p
.54235 .47675 L 1 g
F P
s
P
p
.002 w
.54235 .47675 m .54302 .47747 L p
.53508 .47337 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54235 .47675 L p
1 g
F P
s
P
p
.002 w
.54235 .47675 m .54174 .47608 L p
.55091 .48506 L 1 g
F P
s
P
p
.55091 .48506 m .55834 .49233 L .54235 .47675 L 1 g
F
P
p
.002 w
.53459 .4555 m .56648 .43803 L p
.54748 .48173 L 1 g
F P
s
P
p
.002 w
.54089 .47533 m .53459 .4555 L p
.54748 .48173 L 1 g
F P
s
P
p
.56648 .43803 m .55197 .48609 L .54748 .48173 L 1 g
F
P
p
.002 w
.55197 .48609 m .57942 .47958 L p
.56377 .49748 L 1 g
F P
s
P
p
.002 w
.55729 .49122 m .55834 .49233 L p
.55137 .48551 L 1 g
F P
s
P
p
.002 w
.56582 .50906 m .56713 .51061 L p
.56055 .49804 L 1 g
F P
s
P
p
.5669 .51964 m .56701 .52068 L .56699 .52021 L 1 g
F
P
p
.002 w
.56732 .52847 m .56854 .53025 L p
.56699 .52021 L 1 g
F P
s
P
p
.5674 .53061 m .56146 .54699 L .56649 .53108 L 1 g
F
P
p
.56769 .538 m .56146 .54699 L .5674 .53061 L 1 g
F
P
p
.56146 .54699 m .55562 .55542 L .56649 .53108 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56732 .52847 L p
1 g
F P
s
P
p
.56499 .53582 m .56257 .5491 L .56732 .52847 L 1 g
F
P
p
.002 w
.56146 .54699 m .56257 .5491 L p
.56499 .53582 L 1 g
F P
s
P
p
.002 w
.56209 .54819 m .56146 .54699 L p
.55562 .55542 L 1 g
F P
s
P
p
.002 w
.51172 .5706 m .53246 .54868 L .55562 .55542 L p
1 g
F P
s
P
p
.002 w
.55562 .55542 m .56285 .55752 L p
.55103 .56055 L 1 g
F P
s
P
p
.55103 .56055 m .51172 .5706 L .55562 .55542 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56209 .54819 L p
1 g
F P
s
P
p
.55497 .55614 m .54998 .56518 L .56209 .54819 L 1 g
F
P
p
.002 w
.54908 .56273 m .54998 .56518 L p
.55497 .55614 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54908 .56273 L p
1 g
F P
s
P
p
.5425 .56705 m .5322 .57686 L .54908 .56273 L 1 g
F
P
p
.002 w
.53162 .5742 m .5322 .57686 L p
.5425 .56705 L 1 g
F P
s
P
p
.002 w
.53186 .57532 m .53162 .5742 L p
.52294 .5774 L 1 g
F P
s
P
p
.002 w
.51172 .5706 m .52294 .5774 L p
.51136 .58009 L 1 g
F P
s
P
p
.002 w
.52294 .5774 m .53605 .58533 L p
.51136 .58009 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53186 .57532 L p
1 g
F P
s
P
p
.52126 .57779 m .51111 .583 L .53186 .57532 L 1 g
F
P
p
.002 w
.51091 .5802 m .51111 .583 L p
.52126 .57779 L 1 g
F P
s
P
p
.50117 .58054 m .48999 .58094 L .49765 .58125 L 1 g
F
P
p
.002 w
.48904 .58097 m .48904 .5809 L p
.48596 .58048 L 1 g
F P
s
P
p
.002 w
.48904 .5809 m .48921 .57862 L p
.48645 .5802 L 1 g
F P
s
P
p
.48645 .5802 m .48596 .58048 L .48904 .5809 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51172 .5706 m .4897 .58108 L p
.46762 .56038 L 1 g
F P
s
P
p
.002 w
.48066 .57863 m .46762 .56038 L p
.4897 .58108 L 1 g
F P
s
P
p
.002 w
.48904 .5809 m .48889 .583 L p
.49765 .58125 L 1 g
F P
s
P
p
.48645 .5802 m .48066 .57863 L .48596 .58048 L 1 g
F
P
p
.002 w
.48899 .58154 m .48904 .58097 L p
.48596 .58048 L 1 g
F P
s
P
p
.002 w
.46762 .56038 m .48426 .58367 L p
.47699 .57966 L 1 g
F P
s
P
p
.46872 .57265 m .45068 .56339 L .46006 .56919 L 1 g
F
P
p
.002 w
.46836 .57432 m .46872 .57265 L p
.46006 .56919 L 1 g
F P
s
P
p
.002 w
.44899 .56234 m .46762 .56038 L p
.47699 .57966 L 1 g
F P
s
P
p
.48426 .58367 m .4474 .56698 L .4655 .57332 L 1 g
F
P
p
.002 w
.46836 .57432 m .4678 .57686 L p
.47802 .5777 L 1 g
F P
s
P
p
.002 w
.45068 .56339 m .45002 .56518 L p
.46006 .56919 L 1 g
F P
s
P
p
.002 w
.46762 .56038 m .44961 .56228 L p
.4406 .53379 L 1 g
F P
s
P
p
.002 w
.44488 .55607 m .4406 .53379 L p
.44961 .56228 L 1 g
F P
s
P
p
.002 w
.43955 .55181 m .45002 .56518 L .45051 .56384 L p
1 g
F P
s
P
p
.002 w
.45051 .56384 m .45068 .56339 L p
.44868 .56131 L 1 g
F P
s
P
p
.44868 .56131 m .43955 .55181 L .45051 .56384 L 1 g
F
P
p
.002 w
.44614 .56264 m .44365 .5621 L p
.44067 .55356 L 1 g
F P
s
P
p
.002 w
.44365 .5621 m .42427 .55787 L p
.44067 .55356 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .43955 .55181 L p
.44485 .55603 L 1 g
F P
s
P
p
.44391 .55473 m .43743 .5491 L .44485 .55603 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46836 .57432 L p
1 g
F P
s
P
p
.46006 .56919 m .45002 .56518 L .46836 .57432 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58154 L p
1 g
F P
s
P
p
.47802 .5777 m .4678 .57686 L .48899 .58154 L 1 g
F
P
p
.002 w
.63596 .51471 m .63861 .45942 L .66128 .44827 L p
1 g
F P
s
P
p
.002 w
.64347 .3881 m .66128 .44827 L .63861 .45942 L p
1 g
F P
s
P
p
.002 w
.53605 .58533 m .56285 .55752 L .59064 .56236 L p
1 g
F P
s
P
p
.002 w
.60901 .51915 m .59064 .56236 L .56285 .55752 L p
1 g
F P
s
P
p
.002 w
.59064 .56236 m .60901 .51915 L .63596 .51471 L p
1 g
F P
s
P
p
.002 w
.63861 .45942 m .63596 .51471 L .60901 .51915 L p
1 g
F P
s
P
p
.002 w
.37688 .46734 m .37362 .48833 L .34839 .47948 L p
1 g
F P
s
P
p
.002 w
.34839 .47948 m .3529 .44899 L .37688 .46734 L p
1 g
F P
s
P
p
.004 w
.48307 .44941 m
.5 .43051 L
s
P
p
.002 w
.53895 .31784 m .48294 .29842 L .49366 .27474 L p
1 g
F P
s
P
p
.002 w
.49366 .27474 m .55413 .29549 L .53895 .31784 L p
1 g
F P
s
P
p
.002 w
.3909 .40317 m .3675 .42257 L .3523 .39665 L p
1 g
F P
s
P
p
.002 w
.3523 .39665 m .38203 .37153 L .3909 .40317 L p
1 g
F P
s
P
p
.002 w
.47245 .32683 m .42205 .32634 L .42623 .2982 L p
1 g
F P
s
P
p
.004 w
.45402 .32665 m
.5 .43051 L
s
P
p
.002 w
.42623 .2982 m .48294 .29842 L .47245 .32683 L p
1 g
F P
s
P
p
.004 w
.4382 .29093 m
.44428 .30466 L
s
P
p
.004 w
.44428 .30466 m
.44472 .30567 L
s
P
p
.002 w
.42017 .35836 m .38203 .37153 L .37689 .34234 L p
1 g
F P
s
P
p
.002 w
.37689 .34234 m .42205 .32634 L .42017 .35836 L p
1 g
F P
s
P
p
.002 w
.41076 .51713 m .41905 .52563 L .40425 .54665 L p
1 g
F P
s
P
p
.002 w
.40425 .54665 m .38812 .53013 L .41076 .51713 L p
1 g
F P
s
P
p
.002 w
.42427 .55787 m .40425 .54665 L .41905 .52563 L p
1 g
F P
s
P
p
.002 w
.40534 .50677 m .41076 .51713 L .38812 .53013 L p
1 g
F P
s
P
p
.002 w
.38812 .53013 m .37753 .51001 L .40534 .50677 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.63861 .45942 m .62187 .4037 L .64347 .3881 L p
1 g
F P
s
P
p
.002 w
.60627 .33491 m .64347 .3881 L .62187 .4037 L p
1 g
F P
s
P
p
.002 w
.38709 .44927 m .37688 .46734 L .3529 .44899 L p
1 g
F P
s
P
p
.002 w
.3529 .44899 m .3675 .42257 L .38709 .44927 L p
1 g
F P
s
P
p
.002 w
.41905 .52563 m .42936 .53139 L .42427 .55787 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.4034 .49565 m .40534 .50677 L .37753 .51001 L p
1 g
F P
s
P
p
.002 w
.37753 .51001 m .37362 .48833 L .4034 .49565 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.58728 .35443 m .53895 .31784 L .55413 .29549 L p
1 g
F P
s
P
p
.002 w
.55413 .29549 m .60627 .33491 L .58728 .35443 L p
1 g
F P
s
P
p
.002 w
.62187 .4037 m .58728 .35443 L .60627 .33491 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.56285 .55752 m .57802 .52098 L .60901 .51915 L p
1 g
F P
s
P
p
.002 w
.60901 .51915 m .61104 .46999 L .63861 .45942 L p
1 g
F P
s
P
p
.002 w
.62187 .4037 m .63861 .45942 L .61104 .46999 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.46762 .56038 m .48644 .55123 L .51172 .5706 L p
1 g
F P
s
P
p
.002 w
.53246 .54868 m .51172 .5706 L .48644 .55123 L p
1 g
F P
s
P
p
.002 w
.61104 .46999 m .60901 .51915 L .57802 .52098 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40516 .48493 m .4034 .49565 L .37362 .48833 L p
1 g
F P
s
P
p
.002 w
.37362 .48833 m .37688 .46734 L .40516 .48493 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4406 .53379 m .45159 .53255 L .46762 .56038 L p
1 g
F P
s
P
p
.002 w
.48644 .55123 m .46762 .56038 L .45159 .53255 L p
1 g
F P
s
P
p
.002 w
.52217 .34427 m .47245 .32683 L .48294 .29842 L p
1 g
F P
s
P
p
.002 w
.48294 .29842 m .53895 .31784 L .52217 .34427 L p
1 g
F P
s
P
p
.002 w
.40328 .43614 m .38709 .44927 L .3675 .42257 L p
1 g
F P
s
P
p
.002 w
.3675 .42257 m .3909 .40317 L .40328 .43614 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42074 .39318 m .3909 .40317 L .38203 .37153 L p
1 g
F P
s
P
p
.002 w
.38203 .37153 m .42017 .35836 L .42074 .39318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4626 .35906 m .42017 .35836 L .42205 .32634 L p
1 g
F P
s
P
p
.002 w
.42205 .32634 m .47245 .32683 L .4626 .35906 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41046 .47578 m .40516 .48493 L .37688 .46734 L p
1 g
F P
s
P
p
.002 w
.37688 .46734 m .38709 .44927 L .41046 .47578 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41905 .52563 m .41076 .51713 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.61104 .46999 m .59593 .42054 L .62187 .4037 L p
1 g
F P
s
P
p
.002 w
.58728 .35443 m .62187 .4037 L .59593 .42054 L p
1 g
F P
s
P
p
.002 w
.41076 .51713 m .40534 .50677 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48644 .55123 m .50053 .53603 L .53246 .54868 L p
1 g
F P
s
P
p
.002 w
.54402 .52005 m .53246 .54868 L .50053 .53603 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.40534 .50677 m .4034 .49565 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.45159 .53255 m .46114 .52779 L .48644 .55123 L p
1 g
F P
s
P
p
.002 w
.50053 .53603 m .48644 .55123 L .46114 .52779 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57802 .52098 m .57942 .47958 L .61104 .46999 L p
1 g
F P
s
P
p
.002 w
.5651 .37682 m .52217 .34427 L .53895 .31784 L p
1 g
F P
s
P
p
.002 w
.53895 .31784 m .58728 .35443 L .5651 .37682 L p
1 g
F P
s
P
p
.002 w
.59593 .42054 m .61104 .46999 L .57942 .47958 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.4034 .49565 m .40516 .48493 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.59593 .42054 m .5651 .37682 L .58728 .35443 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.41877 .4692 m .41046 .47578 L .38709 .44927 L p
1 g
F P
s
P
p
.002 w
.38709 .44927 m .40328 .43614 L .41877 .4692 L p
1 g
F P
s
P
p
.002 w
.42378 .4295 m .40328 .43614 L .3909 .40317 L p
1 g
F P
s
P
p
.002 w
.3909 .40317 m .42074 .39318 L .42378 .4295 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.40516 .48493 m .41046 .47578 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45378 .39396 m .42074 .39318 L .42017 .35836 L p
1 g
F P
s
P
p
.002 w
.42017 .35836 m .4626 .35906 L .45378 .39396 L p
1 g
F P
s
P
p
.002 w
.50437 .3739 m .4626 .35906 L .47245 .32683 L p
1 g
F P
s
P
p
.002 w
.47245 .32683 m .52217 .34427 L .50437 .3739 L p
1 g
F P
s
P
p
.002 w
.46114 .52779 m .46822 .51998 L .50053 .53603 L p
1 g
F P
s
P
p
.002 w
.50824 .51634 m .50053 .53603 L .46822 .51998 L p
1 g
F P
s
P
p
.002 w
.50053 .53603 m .50824 .51634 L .54402 .52005 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.41046 .47578 m .41877 .4692 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54485 .48778 m .54402 .52005 L .50824 .51634 L p
1 g
F P
s
P
p
.002 w
.44062 .46638 m .45177 .47051 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.4292 .46594 m .44062 .46638 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.41877 .4692 m .4292 .46594 L .43678 .50109 L closepath p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4292 .46594 m .41877 .4692 L .40328 .43614 L p
1 g
F P
s
P
p
.002 w
.40328 .43614 m .42378 .4295 L .4292 .46594 L p
1 g
F P
s
P
p
.002 w
.57942 .47958 m .56648 .43803 L .59593 .42054 L p
1 g
F P
s
P
p
.002 w
.5651 .37682 m .59593 .42054 L .56648 .43803 L p
1 g
F P
s
P
p
.002 w
.46822 .51998 m .47203 .50994 L .50824 .51634 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.54046 .40131 m .50437 .3739 L .52217 .34427 L p
1 g
F P
s
P
p
.002 w
.52217 .34427 m .5651 .37682 L .54046 .40131 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.44635 .43021 m .42378 .4295 L .42074 .39318 L p
1 g
F P
s
P
p
.002 w
.42074 .39318 m .45378 .39396 L .44635 .43021 L p
1 g
F P
s
P
p
.002 w
.50861 .49426 m .50824 .51634 L .47203 .50994 L p
1 g
F P
s
P
p
.002 w
.50824 .51634 m .50861 .49426 L .54485 .48778 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56648 .43803 m .54046 .40131 L .5651 .37682 L p
1 g
F P
s
P
p
.002 w
.47203 .50994 m .47212 .49875 L .50861 .49426 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.48623 .40565 m .45378 .39396 L .4626 .35906 L p
1 g
F P
s
P
p
.002 w
.4626 .35906 m .50437 .3739 L .48623 .40565 L p
1 g
F P
s
P
p
.002 w
.44062 .46638 m .4292 .46594 L .42378 .4295 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.42378 .4295 m .44635 .43021 L .44062 .46638 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47212 .49875 m .46845 .48765 L .50148 .47225 L p
1 g
F P
s
P
p
.002 w
.50148 .47225 m .50861 .49426 L .47212 .49875 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.45177 .47051 m .44062 .46638 L .44635 .43021 L p
1 g
F P
s
P
p
.002 w
.54046 .40131 m .56648 .43803 L .53459 .4555 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.44635 .43021 m .46847 .43828 L .45177 .47051 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.004 w
.43037 .50825 m
.43081 .50775 L
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.46847 .43828 m .44635 .43021 L .45378 .39396 L p
1 g
F P
s
P
p
.002 w
.45378 .39396 m .48623 .40565 L .46847 .43828 L p
1 g
F P
s
P
p
.002 w
.51428 .42699 m .48623 .40565 L .50437 .3739 L p
1 g
F P
s
P
p
.002 w
.50437 .3739 m .54046 .40131 L .51428 .42699 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53459 .4555 m .51428 .42699 L .54046 .40131 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.48757 .45285 m .46847 .43828 L .48623 .40565 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.48623 .40565 m .51428 .42699 L .48757 .45285 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.3983 .54405 m
.41728 .52285 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .41104 .22958 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .3983 .54405 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.417829)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.417829)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45583 .43462 m .47203 .45641 L .49184 .43606 L p
1 g
F P
s
P
p
.002 w
.49184 .43606 m .48083 .42123 L .45583 .43462 L p
1 g
F P
s
P
p
.002 w
.50694 .44672 m .49184 .43606 L .47203 .45641 L p
1 g
F P
s
P
p
.002 w
.48083 .42123 m .49184 .43606 L .5118 .41563 L p
1 g
F P
s
P
p
.002 w
.49184 .43606 m .50694 .44672 L .51946 .42103 L p
1 g
F P
s
P
p
.002 w
.51946 .42103 m .5118 .41563 L .49184 .43606 L p
1 g
F P
s
P
p
.002 w
.47203 .45641 m .49422 .47208 L .50694 .44672 L p
1 g
F P
s
P
p
.002 w
.52456 .45207 m .50694 .44672 L .49422 .47208 L p
1 g
F P
s
P
p
.002 w
.50694 .44672 m .52456 .45207 L .5284 .42372 L p
1 g
F P
s
P
p
.002 w
.5284 .42372 m .51946 .42103 L .50694 .44672 L p
1 g
F P
s
P
p
.002 w
.5118 .41563 m .50623 .4081 L .48083 .42123 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .50623 .4081 L .5118 .41563 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .5118 .41563 L .51946 .42103 L closepath p
1 g
F P
s
P
p
.002 w
.44731 .40897 m .45583 .43462 L .48083 .42123 L p
1 g
F P
s
P
p
.002 w
.48083 .42123 m .47509 .40377 L .44731 .40897 L p
1 g
F P
s
P
p
.002 w
.47509 .40377 m .48083 .42123 L .50623 .4081 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .51946 .42103 L .5284 .42372 L closepath p
1 g
F P
s
P
p
.002 w
.50623 .4081 m .50334 .39925 L .47509 .40377 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .50334 .39925 L .50623 .4081 L closepath p
1 g
F P
s
P
p
.002 w
.53765 .42341 m .5284 .42372 L .52456 .45207 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .5284 .42372 L .53765 .42341 L closepath p
1 g
F P
s
P
p
.002 w
.47524 .38553 m .47509 .40377 L .50334 .39925 L p
1 g
F P
s
P
p
.002 w
.50334 .39925 m .50345 .39001 L .47524 .38553 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .50345 .39001 L .50334 .39925 L closepath p
1 g
F P
s
P
p
.002 w
.49422 .47208 m .5201 .48001 L .52456 .45207 L p
1 g
F P
s
P
p
.002 w
.54283 .45153 m .52456 .45207 L .5201 .48001 L p
1 g
F P
s
P
p
.002 w
.52456 .45207 m .54283 .45153 L .53765 .42341 L p
1 g
F P
s
P
p
.002 w
.44743 .38211 m .44731 .40897 L .47509 .40377 L p
1 g
F P
s
P
p
.002 w
.47509 .40377 m .47524 .38553 L .44743 .38211 L p
1 g
F P
s
P
p
.002 w
.43168 .44803 m .45274 .4763 L .47203 .45641 L p
1 g
F P
s
P
p
.002 w
.47203 .45641 m .45583 .43462 L .43168 .44803 L p
1 g
F P
s
P
p
.002 w
.49422 .47208 m .47203 .45641 L .45274 .4763 L p
1 g
F P
s
P
p
.002 w
.54622 .42012 m .53765 .42341 L .54283 .45153 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .53765 .42341 L .54622 .42012 L closepath p
1 g
F P
s
P
p
.002 w
.48132 .36844 m .47524 .38553 L .50345 .39001 L p
1 g
F P
s
P
p
.002 w
.50345 .39001 m .50657 .38138 L .48132 .36844 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .50657 .38138 L .50345 .39001 L closepath p
1 g
F P
s
P
p
.002 w
.45274 .4763 m .48153 .49666 L .49422 .47208 L p
1 g
F P
s
P
p
.002 w
.5201 .48001 m .49422 .47208 L .48153 .49666 L p
1 g
F P
s
P
p
.002 w
.42053 .41475 m .43168 .44803 L .45583 .43462 L p
1 g
F P
s
P
p
.002 w
.45583 .43462 m .44731 .40897 L .42053 .41475 L p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .52929 .36763 L .52022 .36954 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .52022 .36954 L .51236 .3743 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .51236 .3743 L .50657 .38138 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .54622 .42012 L .5532 .4142 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .5532 .4142 L .5578 .40627 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .5578 .40627 L .55953 .39718 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .55953 .39718 L .55817 .38793 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .55817 .38793 L .55387 .37954 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .55387 .37954 L .5471 .37291 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .5471 .37291 L .53859 .3688 L closepath p
1 g
F P
s
P
p
.002 w
.53156 .39547 m .53859 .3688 L .52929 .36763 L closepath p
1 g
F P
s
P
p
.002 w
.54283 .45153 m .55981 .44511 L .54622 .42012 L p
1 g
F P
s
P
p
.002 w
.5532 .4142 m .54622 .42012 L .55981 .44511 L p
1 g
F P
s
P
p
.002 w
.5201 .48001 m .547 .47931 L .54283 .45153 L p
1 g
F P
s
P
p
.002 w
.55981 .44511 m .54283 .45153 L .547 .47931 L p
1 g
F P
s
P
p
.002 w
.49272 .35435 m .48132 .36844 L .50657 .38138 L p
1 g
F P
s
P
p
.002 w
.50657 .38138 m .51236 .3743 L .49272 .35435 L p
1 g
F P
s
P
p
.002 w
.45627 .35688 m .44743 .38211 L .47524 .38553 L p
1 g
F P
s
P
p
.002 w
.47524 .38553 m .48132 .36844 L .45627 .35688 L p
1 g
F P
s
P
p
.002 w
.48153 .49666 m .51512 .50703 L .5201 .48001 L p
1 g
F P
s
P
p
.002 w
.547 .47931 m .5201 .48001 L .51512 .50703 L p
1 g
F P
s
P
p
.002 w
.55981 .44511 m .57368 .43345 L .5532 .4142 L p
1 g
F P
s
P
p
.002 w
.5578 .40627 m .5532 .4142 L .57368 .43345 L p
1 g
F P
s
P
p
.002 w
.42055 .37984 m .42053 .41475 L .44731 .40897 L p
1 g
F P
s
P
p
.002 w
.44731 .40897 m .44743 .38211 L .42055 .37984 L p
1 g
F P
s
P
p
.002 w
.50826 .34483 m .49272 .35435 L .51236 .3743 L p
1 g
F P
s
P
p
.002 w
.51236 .3743 m .52022 .36954 L .50826 .34483 L p
1 g
F P
s
P
p
.002 w
.547 .47931 m .57207 .46996 L .55981 .44511 L p
1 g
F P
s
P
p
.002 w
.57368 .43345 m .55981 .44511 L .57207 .46996 L p
1 g
F P
s
P
p
.002 w
.57368 .43345 m .5829 .41776 L .5578 .40627 L p
1 g
F P
s
P
p
.002 w
.55953 .39718 m .5578 .40627 L .5829 .41776 L p
1 g
F P
s
P
p
.002 w
.52628 .34096 m .50826 .34483 L .52022 .36954 L p
1 g
F P
s
P
p
.002 w
.52022 .36954 m .52929 .36763 L .52628 .34096 L p
1 g
F P
s
P
p
.002 w
.473 .336 m .45627 .35688 L .48132 .36844 L p
1 g
F P
s
P
p
.002 w
.48132 .36844 m .49272 .35435 L .473 .336 L p
1 g
F P
s
P
p
.002 w
.40883 .46122 m .43432 .49535 L .45274 .4763 L p
1 g
F P
s
P
p
.002 w
.45274 .4763 m .43168 .44803 L .40883 .46122 L p
1 g
F P
s
P
p
.002 w
.48153 .49666 m .45274 .4763 L .43432 .49535 L p
1 g
F P
s
P
p
.002 w
.51512 .50703 m .55006 .50624 L .547 .47931 L p
1 g
F P
s
P
p
.002 w
.57207 .46996 m .547 .47931 L .55006 .50624 L p
1 g
F P
s
P
p
.002 w
.5829 .41776 m .5864 .39973 L .55953 .39718 L p
1 g
F P
s
P
p
.002 w
.55817 .38793 m .55953 .39718 L .5864 .39973 L p
1 g
F P
s
P
p
.002 w
.43432 .49535 m .4691 .51998 L .48153 .49666 L p
1 g
F P
s
P
p
.002 w
.51512 .50703 m .48153 .49666 L .4691 .51998 L p
1 g
F P
s
P
p
.002 w
.54479 .34323 m .52628 .34096 L .52929 .36763 L p
1 g
F P
s
P
p
.002 w
.52929 .36763 m .53859 .3688 L .54479 .34323 L p
1 g
F P
s
P
p
.002 w
.39526 .42101 m .40883 .46122 L .43168 .44803 L p
1 g
F P
s
P
p
.002 w
.43168 .44803 m .42053 .41475 L .39526 .42101 L p
1 g
F P
s
P
p
.002 w
.4319 .34695 m .42055 .37984 L .44743 .38211 L p
1 g
F P
s
P
p
.002 w
.44743 .38211 m .45627 .35688 L .4319 .34695 L p
1 g
F P
s
P
p
.002 w
.5864 .39973 m .58376 .38133 L .55817 .38793 L p
1 g
F P
s
P
p
.002 w
.55387 .37954 m .55817 .38793 L .58376 .38133 L p
1 g
F P
s
P
p
.002 w
.56174 .3514 m .54479 .34323 L .53859 .3688 L p
1 g
F P
s
P
p
.002 w
.53859 .3688 m .5471 .37291 L .56174 .3514 L p
1 g
F P
s
P
p
.002 w
.57207 .46996 m .59262 .45287 L .57368 .43345 L p
1 g
F P
s
P
p
.002 w
.5829 .41776 m .57368 .43345 L .59262 .45287 L p
1 g
F P
s
P
p
.002 w
.58376 .38133 m .57523 .36459 L .55387 .37954 L p
1 g
F P
s
P
p
.002 w
.5471 .37291 m .55387 .37954 L .57523 .36459 L p
1 g
F P
s
P
p
.002 w
.57523 .36459 m .56174 .3514 L .5471 .37291 L p
1 g
F P
s
P
p
.002 w
.49591 .32182 m .473 .336 L .49272 .35435 L p
1 g
F P
s
P
p
.002 w
.49272 .35435 m .50826 .34483 L .49591 .32182 L p
1 g
F P
s
P
p
.002 w
.4691 .51998 m .50968 .5326 L .51512 .50703 L p
1 g
F P
s
P
p
.002 w
.55006 .50624 m .51512 .50703 L .50968 .5326 L p
1 g
F P
s
P
p
.002 w
.39513 .37878 m .39526 .42101 L .42053 .41475 L p
1 g
F P
s
P
p
.002 w
.42053 .41475 m .42055 .37984 L .39513 .37878 L p
1 g
F P
s
P
p
.002 w
.55006 .50624 m .58273 .49423 L .57207 .46996 L p
1 g
F P
s
P
p
.002 w
.59262 .45287 m .57207 .46996 L .58273 .49423 L p
1 g
F P
s
P
p
.002 w
.59262 .45287 m .60634 .42976 L .5829 .41776 L p
1 g
F P
s
P
p
.002 w
.5864 .39973 m .5829 .41776 L .60634 .42976 L p
1 g
F P
s
P
p
.002 w
.45356 .31965 m .4319 .34695 L .45627 .35688 L p
1 g
F P
s
P
p
.002 w
.45627 .35688 m .473 .336 L .45356 .31965 L p
1 g
F P
s
P
p
.002 w
.52255 .316 m .49591 .32182 L .50826 .34483 L p
1 g
F P
s
P
p
.002 w
.50826 .34483 m .52628 .34096 L .52255 .316 L p
1 g
F P
s
P
p
.002 w
.50968 .5326 m .55195 .53179 L .55006 .50624 L p
1 g
F P
s
P
p
.002 w
.58273 .49423 m .55006 .50624 L .55195 .53179 L p
1 g
F P
s
P
p
.002 w
.60634 .42976 m .61164 .4031 L .5864 .39973 L p
1 g
F P
s
P
p
.002 w
.58376 .38133 m .5864 .39973 L .61164 .4031 L p
1 g
F P
s
P
p
.002 w
.38777 .47392 m .41716 .51319 L .43432 .49535 L p
1 g
F P
s
P
p
.002 w
.43432 .49535 m .40883 .46122 L .38777 .47392 L p
1 g
F P
s
P
p
.002 w
.4691 .51998 m .43432 .49535 L .41716 .51319 L p
1 g
F P
s
P
p
.002 w
.55 .31928 m .52255 .316 L .52628 .34096 L p
1 g
F P
s
P
p
.002 w
.52628 .34096 m .54479 .34323 L .55 .31928 L p
1 g
F P
s
P
p
.002 w
.4087 .3389 m .39513 .37878 L .42055 .37984 L p
1 g
F P
s
P
p
.002 w
.42055 .37984 m .4319 .34695 L .4087 .3389 L p
1 g
F P
s
P
p
.002 w
.41716 .51319 m .45718 .54157 L .4691 .51998 L p
1 g
F P
s
P
p
.002 w
.50968 .5326 m .4691 .51998 L .45718 .54157 L p
1 g
F P
s
P
p
.002 w
.58273 .49423 m .6096 .47209 L .59262 .45287 L p
1 g
F P
s
P
p
.002 w
.60634 .42976 m .59262 .45287 L .6096 .47209 L p
1 g
F P
s
P
p
.002 w
.37203 .42765 m .38777 .47392 L .40883 .46122 L p
1 g
F P
s
P
p
.002 w
.40883 .46122 m .39526 .42101 L .37203 .42765 L p
1 g
F P
s
P
p
.002 w
.61164 .4031 m .6078 .37581 L .58376 .38133 L p
1 g
F P
s
P
p
.002 w
.57523 .36459 m .58376 .38133 L .6078 .37581 L p
1 g
F P
s
P
p
.002 w
.57516 .33138 m .55 .31928 L .54479 .34323 L p
1 g
F P
s
P
p
.002 w
.54479 .34323 m .56174 .3514 L .57516 .33138 L p
1 g
F P
s
P
p
.002 w
.48337 .30102 m .45356 .31965 L .473 .336 L p
1 g
F P
s
P
p
.002 w
.473 .336 m .49591 .32182 L .48337 .30102 L p
1 g
F P
s
P
p
.002 w
.6078 .37581 m .59519 .35096 L .57523 .36459 L p
1 g
F P
s
P
p
.002 w
.56174 .3514 m .57523 .36459 L .59519 .35096 L p
1 g
F P
s
P
p
.002 w
.59519 .35096 m .57516 .33138 L .56174 .3514 L p
1 g
F P
s
P
p
.002 w
.45718 .54157 m .50387 .55619 L .50968 .5326 L p
1 g
F P
s
P
p
.002 w
.55195 .53179 m .50968 .5326 L .50387 .55619 L p
1 g
F P
s
P
p
.002 w
.55195 .53179 m .59156 .51741 L .58273 .49423 L p
1 g
F P
s
P
p
.002 w
.6096 .47209 m .58273 .49423 L .59156 .51741 L p
1 g
F P
s
P
p
.002 w
.37173 .379 m .37203 .42765 L .39526 .42101 L p
1 g
F P
s
P
p
.002 w
.39526 .42101 m .39513 .37878 L .37173 .379 L p
1 g
F P
s
P
p
.002 w
.6096 .47209 m .62764 .44203 L .60634 .42976 L p
1 g
F P
s
P
p
.002 w
.61164 .4031 m .60634 .42976 L .62764 .44203 L p
1 g
F P
s
P
p
.002 w
.43482 .30569 m .4087 .3389 L .4319 .34695 L p
1 g
F P
s
P
p
.002 w
.4319 .34695 m .45356 .31965 L .43482 .30569 L p
1 g
F P
s
P
p
.002 w
.51816 .29329 m .48337 .30102 L .49591 .32182 L p
1 g
F P
s
P
p
.002 w
.49591 .32182 m .52255 .316 L .51816 .29329 L p
1 g
F P
s
P
p
.002 w
.50387 .55619 m .55258 .55541 L .55195 .53179 L p
1 g
F P
s
P
p
.002 w
.59156 .51741 m .55195 .53179 L .55258 .55541 L p
1 g
F P
s
P
p
.002 w
.62764 .44203 m .63469 .40723 L .61164 .4031 L p
1 g
F P
s
P
p
.002 w
.6078 .37581 m .61164 .4031 L .63469 .40723 L p
1 g
F P
s
P
p
.002 w
.55409 .2975 m .51816 .29329 L .52255 .316 L p
1 g
F P
s
P
p
.002 w
.52255 .316 m .55 .31928 L .55409 .2975 L p
1 g
F P
s
P
p
.002 w
.3872 .33296 m .37173 .379 L .39513 .37878 L p
1 g
F P
s
P
p
.002 w
.39513 .37878 m .4087 .3389 L .3872 .33296 L p
1 g
F P
s
P
p
.002 w
.36898 .48587 m .40162 .52942 L .41716 .51319 L p
1 g
F P
s
P
p
.002 w
.41716 .51319 m .38777 .47392 L .36898 .48587 L p
1 g
F P
s
P
p
.002 w
.45718 .54157 m .41716 .51319 L .40162 .52942 L p
1 g
F P
s
P
p
.002 w
.59156 .51741 m .62423 .49073 L .6096 .47209 L p
1 g
F P
s
P
p
.002 w
.62764 .44203 m .6096 .47209 L .62423 .49073 L p
1 g
F P
s
P
p
.002 w
.40162 .52942 m .44602 .56094 L .45718 .54157 L p
1 g
F P
s
P
p
.002 w
.50387 .55619 m .45718 .54157 L .44602 .56094 L p
1 g
F P
s
P
p
.002 w
.47092 .28293 m .43482 .30569 L .45356 .31965 L p
1 g
F P
s
P
p
.002 w
.45356 .31965 m .48337 .30102 L .47092 .28293 L p
1 g
F P
s
P
p
.002 w
.35141 .43455 m .36898 .48587 L .38777 .47392 L p
1 g
F P
s
P
p
.002 w
.38777 .47392 m .37203 .42765 L .35141 .43455 L p
1 g
F P
s
P
p
.002 w
.63469 .40723 m .62977 .37152 L .6078 .37581 L p
1 g
F P
s
P
p
.002 w
.59519 .35096 m .6078 .37581 L .62977 .37152 L p
1 g
F P
s
P
p
.002 w
.58707 .31331 m .55409 .2975 L .55 .31928 L p
1 g
F P
s
P
p
.002 w
.55 .31928 m .57516 .33138 L .58707 .31331 L p
1 g
F P
s
P
p
.002 w
.62977 .37152 m .61329 .33897 L .59519 .35096 L p
1 g
F P
s
P
p
.002 w
.57516 .33138 m .59519 .35096 L .61329 .33897 L p
1 g
F P
s
P
p
.002 w
.61329 .33897 m .58707 .31331 L .57516 .33138 L p
1 g
F P
s
P
p
.002 w
.44602 .56094 m .49781 .57725 L .50387 .55619 L p
1 g
F P
s
P
p
.002 w
.55258 .55541 m .50387 .55619 L .49781 .57725 L p
1 g
F P
s
P
p
.002 w
.55258 .55541 m .5983 .53901 L .59156 .51741 L p
1 g
F P
s
P
p
.002 w
.62423 .49073 m .59156 .51741 L .5983 .53901 L p
1 g
F P
s
P
p
.002 w
.35091 .38053 m .35141 .43455 L .37203 .42765 L p
1 g
F P
s
P
p
.002 w
.37203 .42765 m .37173 .379 L .35091 .38053 L p
1 g
F P
s
P
p
.002 w
.62423 .49073 m .64627 .45434 L .62764 .44203 L p
1 g
F P
s
P
p
.002 w
.63469 .40723 m .62764 .44203 L .64627 .45434 L p
1 g
F P
s
P
p
.002 w
.41719 .29451 m .3872 .33296 L .4087 .3389 L p
1 g
F P
s
P
p
.002 w
.4087 .3389 m .43482 .30569 L .41719 .29451 L p
1 g
F P
s
P
p
.002 w
.51318 .2734 m .47092 .28293 L .48337 .30102 L p
1 g
F P
s
P
p
.002 w
.48337 .30102 m .51816 .29329 L .51318 .2734 L p
1 g
F P
s
P
p
.002 w
.49781 .57725 m .55188 .57653 L .55258 .55541 L p
1 g
F P
s
P
p
.002 w
.5983 .53901 m .55258 .55541 L .55188 .57653 L p
1 g
F P
s
P
p
.002 w
.64627 .45434 m .65498 .41208 L .63469 .40723 L p
1 g
F P
s
P
p
.002 w
.62977 .37152 m .63469 .40723 L .65498 .41208 L p
1 g
F P
s
P
p
.002 w
.5983 .53901 m .63612 .50837 L .62423 .49073 L p
1 g
F P
s
P
p
.002 w
.64627 .45434 m .62423 .49073 L .63612 .50837 L p
1 g
F P
s
P
p
.002 w
.36792 .32934 m .35091 .38053 L .37173 .379 L p
1 g
F P
s
P
p
.002 w
.37173 .379 m .3872 .33296 L .36792 .32934 L p
1 g
F P
s
P
p
.002 w
.55692 .27843 m .51318 .2734 L .51816 .29329 L p
1 g
F P
s
P
p
.002 w
.51816 .29329 m .55409 .2975 L .55692 .27843 L p
1 g
F P
s
P
p
.002 w
.35295 .49678 m .38812 .54362 L .40162 .52942 L p
1 g
F P
s
P
p
.002 w
.40162 .52942 m .36898 .48587 L .35295 .49678 L p
1 g
F P
s
P
p
.002 w
.44602 .56094 m .40162 .52942 L .38812 .54362 L p
1 g
F P
s
P
p
.002 w
.45881 .26807 m .41719 .29451 L .43482 .30569 L p
1 g
F P
s
P
p
.002 w
.43482 .30569 m .47092 .28293 L .45881 .26807 L p
1 g
F P
s
P
p
.002 w
.38812 .54362 m .43589 .57757 L .44602 .56094 L p
1 g
F P
s
P
p
.002 w
.49781 .57725 m .44602 .56094 L .43589 .57757 L p
1 g
F P
s
P
p
.002 w
.33394 .44157 m .35295 .49678 L .36898 .48587 L p
1 g
F P
s
P
p
.002 w
.36898 .48587 m .35141 .43455 L .33394 .44157 L p
1 g
F P
s
P
p
.002 w
.65498 .41208 m .64909 .36862 L .62977 .37152 L p
1 g
F P
s
P
p
.002 w
.61329 .33897 m .62977 .37152 L .64909 .36862 L p
1 g
F P
s
P
p
.002 w
.59712 .29766 m .55692 .27843 L .55409 .2975 L p
1 g
F P
s
P
p
.002 w
.55409 .2975 m .58707 .31331 L .59712 .29766 L p
1 g
F P
s
P
p
.002 w
.64909 .36862 m .62907 .32893 L .61329 .33897 L p
1 g
F P
s
P
p
.002 w
.58707 .31331 m .61329 .33897 L .62907 .32893 L p
1 g
F P
s
P
p
.002 w
.62907 .32893 m .59712 .29766 L .58707 .31331 L p
1 g
F P
s
P
p
.002 w
.55188 .57653 m .60272 .55849 L .5983 .53901 L p
1 g
F P
s
P
p
.002 w
.63612 .50837 m .5983 .53901 L .60272 .55849 L p
1 g
F P
s
P
p
.002 w
.43589 .57757 m .49161 .59521 L .49781 .57725 L p
1 g
F P
s
P
p
.002 w
.55188 .57653 m .49781 .57725 L .49161 .59521 L p
1 g
F P
s
P
p
.002 w
.63612 .50837 m .66173 .46643 L .64627 .45434 L p
1 g
F P
s
P
p
.002 w
.65498 .41208 m .64627 .45434 L .66173 .46643 L p
1 g
F P
s
P
p
.002 w
.33326 .38343 m .33394 .44157 L .35141 .43455 L p
1 g
F P
s
P
p
.002 w
.35141 .43455 m .35091 .38053 L .33326 .38343 L p
1 g
F P
s
P
p
.002 w
.40111 .28649 m .36792 .32934 L .3872 .33296 L p
1 g
F P
s
P
p
.002 w
.3872 .33296 m .41719 .29451 L .40111 .28649 L p
1 g
F P
s
P
p
.002 w
.50768 .25691 m .45881 .26807 L .47092 .28293 L p
1 g
F P
s
P
p
.002 w
.47092 .28293 m .51318 .2734 L .50768 .25691 L p
1 g
F P
s
P
p
.002 w
.49161 .59521 m .54981 .59457 L .55188 .57653 L p
1 g
F P
s
P
p
.002 w
.60272 .55849 m .55188 .57653 L .54981 .59457 L p
1 g
F P
s
P
p
.002 w
.66173 .46643 m .67193 .41758 L .65498 .41208 L p
1 g
F P
s
P
p
.002 w
.64909 .36862 m .65498 .41208 L .67193 .41758 L p
1 g
F P
s
P
p
.002 w
.60272 .55849 m .64487 .52458 L .63612 .50837 L p
1 g
F P
s
P
p
.002 w
.66173 .46643 m .63612 .50837 L .64487 .52458 L p
1 g
F P
s
P
p
.002 w
.35142 .32825 m .33326 .38343 L .35091 .38053 L p
1 g
F P
s
P
p
.002 w
.35091 .38053 m .36792 .32934 L .35142 .32825 L p
1 g
F P
s
P
p
.002 w
.55837 .26266 m .50768 .25691 L .51318 .2734 L p
1 g
F P
s
P
p
.002 w
.51318 .2734 m .55692 .27843 L .55837 .26266 L p
1 g
F P
s
P
p
.002 w
.34018 .50635 m .37705 .55539 L .38812 .54362 L p
1 g
F P
s
P
p
.002 w
.38812 .54362 m .35295 .49678 L .34018 .50635 L p
1 g
F P
s
P
p
.002 w
.43589 .57757 m .38812 .54362 L .37705 .55539 L p
1 g
F P
s
P
p
.002 w
.44734 .25694 m .40111 .28649 L .41719 .29451 L p
1 g
F P
s
P
p
.002 w
.41719 .29451 m .45881 .26807 L .44734 .25694 L p
1 g
F P
s
P
p
.002 w
.37705 .55539 m .42708 .59096 L .43589 .57757 L p
1 g
F P
s
P
p
.002 w
.49161 .59521 m .43589 .57757 L .42708 .59096 L p
1 g
F P
s
P
p
.002 w
.32019 .44856 m .34018 .50635 L .35295 .49678 L p
1 g
F P
s
P
p
.002 w
.35295 .49678 m .33394 .44157 L .32019 .44856 L p
1 g
F P
s
P
p
.002 w
.67193 .41758 m .66522 .36722 L .64909 .36862 L p
1 g
F P
s
P
p
.002 w
.62907 .32893 m .64909 .36862 L .66522 .36722 L p
1 g
F P
s
P
p
.002 w
.60499 .28491 m .55837 .26266 L .55692 .27843 L p
1 g
F P
s
P
p
.002 w
.55692 .27843 m .59712 .29766 L .60499 .28491 L p
1 g
F P
s
P
p
.002 w
.54981 .59457 m .6046 .5753 L .60272 .55849 L p
1 g
F P
s
P
p
.002 w
.64487 .52458 m .60272 .55849 L .6046 .5753 L p
1 g
F P
s
P
p
.002 w
.66522 .36722 m .64205 .32119 L .62907 .32893 L p
1 g
F P
s
P
p
.002 w
.59712 .29766 m .62907 .32893 L .64205 .32119 L p
1 g
F P
s
P
p
.002 w
.64205 .32119 m .60499 .28491 L .59712 .29766 L p
1 g
F P
s
P
p
.002 w
.42708 .59096 m .48541 .60951 L .49161 .59521 L p
1 g
F P
s
P
p
.002 w
.54981 .59457 m .49161 .59521 L .48541 .60951 L p
1 g
F P
s
P
p
.002 w
.64487 .52458 m .67349 .47801 L .66173 .46643 L p
1 g
F P
s
P
p
.002 w
.67193 .41758 m .66173 .46643 L .67349 .47801 L p
1 g
F P
s
P
p
.002 w
.38706 .282 m .35142 .32825 L .36792 .32934 L p
1 g
F P
s
P
p
.002 w
.36792 .32934 m .40111 .28649 L .38706 .282 L p
1 g
F P
s
P
p
.002 w
.31936 .38767 m .32019 .44856 L .33394 .44157 L p
1 g
F P
s
P
p
.002 w
.33394 .44157 m .33326 .38343 L .31936 .38767 L p
1 g
F P
s
P
p
.002 w
.50177 .2444 m .44734 .25694 L .45881 .26807 L p
1 g
F P
s
P
p
.002 w
.45881 .26807 m .50768 .25691 L .50177 .2444 L p
1 g
F P
s
P
p
.002 w
.48541 .60951 m .54635 .60895 L .54981 .59457 L p
1 g
F P
s
P
p
.002 w
.6046 .5753 m .54981 .59457 L .54635 .60895 L p
1 g
F P
s
P
p
.002 w
.67349 .47801 m .68498 .42362 L .67193 .41758 L p
1 g
F P
s
P
p
.002 w
.66522 .36722 m .67193 .41758 L .68498 .42362 L p
1 g
F P
s
P
p
.002 w
.6046 .5753 m .6501 .5389 L .64487 .52458 L p
1 g
F P
s
P
p
.002 w
.67349 .47801 m .64487 .52458 L .6501 .5389 L p
1 g
F P
s
P
p
.002 w
.33826 .32986 m .31936 .38767 L .33326 .38343 L p
1 g
F P
s
P
p
.002 w
.33326 .38343 m .35142 .32825 L .33826 .32986 L p
1 g
F P
s
P
p
.002 w
.55831 .25074 m .50177 .2444 L .50768 .25691 L p
1 g
F P
s
P
p
.002 w
.50768 .25691 m .55837 .26266 L .55831 .25074 L p
1 g
F P
s
P
p
.002 w
.43684 .25003 m .38706 .282 L .40111 .28649 L p
1 g
F P
s
P
p
.002 w
.40111 .28649 m .44734 .25694 L .43684 .25003 L p
1 g
F P
s
P
p
.002 w
.33118 .51427 m .36882 .5643 L .37705 .55539 L p
1 g
F P
s
P
p
.002 w
.37705 .55539 m .34018 .50635 L .33118 .51427 L p
1 g
F P
s
P
p
.002 w
.42708 .59096 m .37705 .55539 L .36882 .5643 L p
1 g
F P
s
P
p
.002 w
.36882 .5643 m .41985 .6006 L .42708 .59096 L p
1 g
F P
s
P
p
.002 w
.48541 .60951 m .42708 .59096 L .41985 .6006 L p
1 g
F P
s
P
p
.002 w
.31072 .45535 m .33118 .51427 L .34018 .50635 L p
1 g
F P
s
P
p
.002 w
.34018 .50635 m .32019 .44856 L .31072 .45535 L p
1 g
F P
s
P
p
.002 w
.68498 .42362 m .67757 .36746 L .66522 .36722 L p
1 g
F P
s
P
p
.002 w
.64205 .32119 m .66522 .36722 L .67757 .36746 L p
1 g
F P
s
P
p
.002 w
.61038 .27555 m .55831 .25074 L .55837 .26266 L p
1 g
F P
s
P
p
.002 w
.55837 .26266 m .60499 .28491 L .61038 .27555 L p
1 g
F P
s
P
p
.002 w
.54635 .60895 m .60376 .5889 L .6046 .5753 L p
1 g
F P
s
P
p
.002 w
.6501 .5389 m .6046 .5753 L .60376 .5889 L p
1 g
F P
s
P
p
.002 w
.67757 .36746 m .65175 .31606 L .64205 .32119 L p
1 g
F P
s
P
p
.002 w
.60499 .28491 m .64205 .32119 L .65175 .31606 L p
1 g
F P
s
P
p
.002 w
.65175 .31606 m .61038 .27555 L .60499 .28491 L p
1 g
F P
s
P
p
.002 w
.41985 .6006 m .47934 .61959 L .48541 .60951 L p
1 g
F P
s
P
p
.002 w
.54635 .60895 m .48541 .60951 L .47934 .61959 L p
1 g
F P
s
P
p
.002 w
.6501 .5389 m .68107 .48877 L .67349 .47801 L p
1 g
F P
s
P
p
.002 w
.68498 .42362 m .67349 .47801 L .68107 .48877 L p
1 g
F P
s
P
p
.002 w
.3755 .28135 m .33826 .32986 L .35142 .32825 L p
1 g
F P
s
P
p
.002 w
.35142 .32825 m .38706 .282 L .3755 .28135 L p
1 g
F P
s
P
p
.002 w
.30978 .39326 m .31072 .45535 L .32019 .44856 L p
1 g
F P
s
P
p
.002 w
.32019 .44856 m .31936 .38767 L .30978 .39326 L p
1 g
F P
s
P
p
.002 w
.49556 .23641 m .43684 .25003 L .44734 .25694 L p
1 g
F P
s
P
p
.002 w
.44734 .25694 m .50177 .2444 L .49556 .23641 L p
1 g
F P
s
P
p
.002 w
.47934 .61959 m .5415 .6191 L .54635 .60895 L p
1 g
F P
s
P
p
.002 w
.60376 .5889 m .54635 .60895 L .5415 .6191 L p
1 g
F P
s
P
p
.002 w
.68107 .48877 m .69356 .4301 L .68498 .42362 L p
1 g
F P
s
P
p
.002 w
.67757 .36746 m .68498 .42362 L .69356 .4301 L p
1 g
F P
s
P
p
.002 w
.60376 .5889 m .65149 .55086 L .6501 .5389 L p
1 g
F P
s
P
p
.002 w
.68107 .48877 m .6501 .5389 L .65149 .55086 L p
1 g
F P
s
P
p
.002 w
.32897 .33429 m .30978 .39326 L .31936 .38767 L p
1 g
F P
s
P
p
.002 w
.31936 .38767 m .33826 .32986 L .32897 .33429 L p
1 g
F P
s
P
p
.002 w
.55667 .24322 m .49556 .23641 L .50177 .2444 L p
1 g
F P
s
P
p
.002 w
.50177 .2444 m .55831 .25074 L .55667 .24322 L p
1 g
F P
s
P
p
.002 w
.42762 .24778 m .3755 .28135 L .38706 .282 L p
1 g
F P
s
P
p
.002 w
.38706 .282 m .43684 .25003 L .42762 .24778 L p
1 g
F P
s
P
p
.002 w
.32638 .52025 m .3638 .56995 L .36882 .5643 L p
1 g
F P
s
P
p
.002 w
.36882 .5643 m .33118 .51427 L .32638 .52025 L p
1 g
F P
s
P
p
.002 w
.41985 .6006 m .36882 .5643 L .3638 .56995 L p
1 g
F P
s
P
p
.002 w
.3638 .56995 m .4145 .60603 L .41985 .6006 L p
1 g
F P
s
P
p
.002 w
.47934 .61959 m .41985 .6006 L .4145 .60603 L p
1 g
F P
s
P
p
.002 w
.69356 .4301 m .68561 .36943 L .67757 .36746 L p
1 g
F P
s
P
p
.002 w
.65175 .31606 m .67757 .36746 L .68561 .36943 L p
1 g
F P
s
P
p
.002 w
.30603 .46174 m .32638 .52025 L .33118 .51427 L p
1 g
F P
s
P
p
.002 w
.33118 .51427 m .31072 .45535 L .30603 .46174 L p
1 g
F P
s
P
p
.002 w
.61297 .27003 m .55667 .24322 L .55831 .25074 L p
1 g
F P
s
P
p
.002 w
.55831 .25074 m .61038 .27555 L .61297 .27003 L p
1 g
F P
s
P
p
.002 w
.5415 .6191 m .60006 .59873 L .60376 .5889 L p
1 g
F P
s
P
p
.002 w
.65149 .55086 m .60376 .5889 L .60006 .59873 L p
1 g
F P
s
P
p
.002 w
.68561 .36943 m .65772 .31385 L .65175 .31606 L p
1 g
F P
s
P
p
.002 w
.61038 .27555 m .65175 .31606 L .65772 .31385 L p
1 g
F P
s
P
p
.002 w
.4145 .60603 m .47358 .62492 L .47934 .61959 L p
1 g
F P
s
P
p
.002 w
.5415 .6191 m .47934 .61959 L .47358 .62492 L p
1 g
F P
s
P
p
.002 w
.65149 .55086 m .68401 .49838 L .68107 .48877 L p
1 g
F P
s
P
p
.002 w
.69356 .4301 m .68107 .48877 L .68401 .49838 L p
1 g
F P
s
P
p
.002 w
.65772 .31385 m .61297 .27003 L .61038 .27555 L p
1 g
F P
s
P
p
.002 w
.3669 .2848 m .32897 .33429 L .33826 .32986 L p
1 g
F P
s
P
p
.002 w
.33826 .32986 m .3755 .28135 L .3669 .2848 L p
1 g
F P
s
P
p
.002 w
.30506 .4001 m .30603 .46174 L .31072 .45535 L p
1 g
F P
s
P
p
.002 w
.31072 .45535 m .30978 .39326 L .30506 .4001 L p
1 g
F P
s
P
p
.002 w
.48921 .23346 m .42762 .24778 L .43684 .25003 L p
1 g
F P
s
P
p
.002 w
.43684 .25003 m .49556 .23641 L .48921 .23346 L p
1 g
F P
s
P
p
.002 w
.47358 .62492 m .5353 .62448 L .5415 .6191 L p
1 g
F P
s
P
p
.002 w
.60006 .59873 m .5415 .6191 L .5353 .62448 L p
1 g
F P
s
P
p
.002 w
.60006 .59873 m .64875 .56 L .65149 .55086 L p
1 g
F P
s
P
p
.002 w
.68401 .49838 m .65149 .55086 L .64875 .56 L p
1 g
F P
s
P
p
.002 w
.68401 .49838 m .69715 .43687 L .69356 .4301 L p
1 g
F P
s
P
p
.002 w
.68561 .36943 m .69356 .4301 L .69715 .43687 L p
1 g
F P
s
P
p
.002 w
.32407 .3416 m .30506 .4001 L .30978 .39326 L p
1 g
F P
s
P
p
.002 w
.30978 .39326 m .32897 .33429 L .32407 .3416 L p
1 g
F P
s
P
p
.002 w
.55337 .24058 m .48921 .23346 L .49556 .23641 L p
1 g
F P
s
P
p
.002 w
.49556 .23641 m .55667 .24322 L .55337 .24058 L p
1 g
F P
s
P
p
.002 w
.42004 .25055 m .3669 .2848 L .3755 .28135 L p
1 g
F P
s
P
p
.002 w
.3755 .28135 m .42762 .24778 L .42004 .25055 L p
1 g
F P
s
P
p
.002 w
.32622 .524 m .36234 .57197 L .3638 .56995 L p
1 g
F P
s
P
p
.002 w
.3638 .56995 m .32638 .52025 L .32622 .524 L p
1 g
F P
s
P
p
.002 w
.4145 .60603 m .3638 .56995 L .36234 .57197 L p
1 g
F P
s
P
p
.002 w
.36234 .57197 m .41129 .60681 L .4145 .60603 L p
1 g
F P
s
P
p
.002 w
.47358 .62492 m .4145 .60603 L .41129 .60681 L p
1 g
F P
s
P
p
.002 w
.69715 .43687 m .68883 .37318 L .68561 .36943 L p
1 g
F P
s
P
p
.002 w
.65772 .31385 m .68561 .36943 L .68883 .37318 L p
1 g
F P
s
P
p
.002 w
.30657 .46754 m .32622 .524 L .32638 .52025 L p
1 g
F P
s
P
p
.002 w
.32638 .52025 m .30603 .46174 L .30657 .46754 L p
1 g
F P
s
P
p
.004 w
.56296 .22623 m
.5647 .22057 L
s
P
p
.002 w
.61252 .26875 m .55337 .24058 L .55667 .24322 L p
1 g
F P
s
P
p
.004 w
.55972 .23674 m
.56296 .22623 L
s
P
p
.002 w
.55667 .24322 m .61297 .27003 L .61252 .26875 L p
1 g
F P
s
P
p
.002 w
.5353 .62448 m .59341 .6043 L .60006 .59873 L p
1 g
F P
s
P
p
.002 w
.64875 .56 m .60006 .59873 L .59341 .6043 L p
1 g
F P
s
P
p
.002 w
.64875 .56 m .68193 .50651 L .68401 .49838 L p
1 g
F P
s
P
p
.002 w
.69715 .43687 m .68401 .49838 L .68193 .50651 L p
1 g
F P
s
P
p
.002 w
.68883 .37318 m .65954 .31479 L .65772 .31385 L p
1 g
F P
s
P
p
.002 w
.61297 .27003 m .65772 .31385 L .65954 .31479 L p
1 g
F P
s
P
p
.002 w
.41129 .60681 m .46831 .62505 L .47358 .62492 L p
1 g
F P
s
P
p
.002 w
.5353 .62448 m .47358 .62492 L .46831 .62505 L p
1 g
F P
s
P
p
.002 w
.36169 .29252 m .32407 .3416 L .32897 .33429 L p
1 g
F P
s
P
p
.002 w
.32897 .33429 m .3669 .2848 L .36169 .29252 L p
1 g
F P
s
P
p
.002 w
.65954 .31479 m .61252 .26875 L .61297 .27003 L p
1 g
F P
s
P
p
.002 w
.30564 .40811 m .30657 .46754 L .30603 .46174 L p
1 g
F P
s
P
p
.002 w
.30603 .46174 m .30506 .4001 L .30564 .40811 L p
1 g
F P
s
P
p
.002 w
.48289 .23595 m .42004 .25055 L .42762 .24778 L p
1 g
F P
s
P
p
.002 w
.42762 .24778 m .48921 .23346 L .48289 .23595 L p
1 g
F P
s
P
p
.002 w
.46831 .62505 m .52783 .62463 L .5353 .62448 L p
1 g
F P
s
P
p
.002 w
.59341 .6043 m .5353 .62448 L .52783 .62463 L p
1 g
F P
s
P
p
.002 w
.59341 .6043 m .6417 .56589 L .64875 .56 L p
1 g
F P
s
P
p
.002 w
.68193 .50651 m .64875 .56 L .6417 .56589 L p
1 g
F P
s
P
p
.002 w
.68193 .50651 m .69534 .44375 L .69715 .43687 L p
1 g
F P
s
P
p
.002 w
.68883 .37318 m .69715 .43687 L .69534 .44375 L p
1 g
F P
s
P
p
.002 w
.32398 .35176 m .30564 .40811 L .30506 .4001 L p
1 g
F P
s
P
p
.002 w
.30506 .4001 m .32407 .3416 L .32398 .35176 L p
1 g
F P
s
P
p
.002 w
.5484 .24325 m .48289 .23595 L .48921 .23346 L p
1 g
F P
s
P
p
.002 w
.48921 .23346 m .55337 .24058 L .5484 .24325 L p
1 g
F P
s
P
p
.002 w
.41442 .25859 m .36169 .29252 L .3669 .2848 L p
1 g
F P
s
P
p
.002 w
.3669 .2848 m .42004 .25055 L .41442 .25859 L p
1 g
F P
s
P
p
.002 w
.33099 .52525 m .36473 .57007 L .36234 .57197 L p
1 g
F P
s
P
p
.002 w
.36234 .57197 m .32622 .524 L .33099 .52525 L p
1 g
F P
s
P
p
.002 w
.41129 .60681 m .36234 .57197 L .36473 .57007 L p
1 g
F P
s
P
p
.002 w
.36473 .57007 m .41047 .60262 L .41129 .60681 L p
1 g
F P
s
P
p
.002 w
.46831 .62505 m .41129 .60681 L .41047 .60262 L p
1 g
F P
s
P
p
.002 w
.69534 .44375 m .68682 .37873 L .68883 .37318 L p
1 g
F P
s
P
p
.002 w
.65954 .31479 m .68883 .37318 L .68682 .37873 L p
1 g
F P
s
P
p
.002 w
.31266 .47253 m .33099 .52525 L .32622 .524 L p
1 g
F P
s
P
p
.002 w
.32622 .524 m .30657 .46754 L .31266 .47253 L p
1 g
F P
s
P
p
.002 w
.52783 .62463 m .58381 .60516 L .59341 .6043 L p
1 g
F P
s
P
p
.002 w
.6417 .56589 m .59341 .6043 L .58381 .60516 L p
1 g
F P
s
P
p
.002 w
.60883 .27204 m .5484 .24325 L .55337 .24058 L p
1 g
F P
s
P
p
.002 w
.55337 .24058 m .61252 .26875 L .60883 .27204 L p
1 g
F P
s
P
p
.002 w
.6417 .56589 m .67458 .51282 L .68193 .50651 L p
1 g
F P
s
P
p
.002 w
.69534 .44375 m .68193 .50651 L .67458 .51282 L p
1 g
F P
s
P
p
.002 w
.36025 .30455 m .32398 .35176 L .32407 .3416 L p
1 g
F P
s
P
p
.002 w
.32407 .3416 m .36169 .29252 L .36025 .30455 L p
1 g
F P
s
P
p
.002 w
.41047 .60262 m .46372 .61963 L .46831 .62505 L p
1 g
F P
s
P
p
.002 w
.52783 .62463 m .46831 .62505 L .46372 .61963 L p
1 g
F P
s
P
p
.002 w
.68682 .37873 m .65688 .31909 L .65954 .31479 L p
1 g
F P
s
P
p
.002 w
.61252 .26875 m .65954 .31479 L .65688 .31909 L p
1 g
F P
s
P
p
.002 w
.65688 .31909 m .60883 .27204 L .61252 .26875 L p
1 g
F P
s
P
p
.002 w
.31184 .4171 m .31266 .47253 L .30657 .46754 L p
1 g
F P
s
P
p
.002 w
.30657 .46754 m .30564 .40811 L .31184 .4171 L p
1 g
F P
s
P
p
.002 w
.47679 .24416 m .41442 .25859 L .42004 .25055 L p
1 g
F P
s
P
p
.002 w
.42004 .25055 m .48289 .23595 L .47679 .24416 L p
1 g
F P
s
P
p
.002 w
.46372 .61963 m .51924 .61919 L .52783 .62463 L p
1 g
F P
s
P
p
.002 w
.58381 .60516 m .52783 .62463 L .51924 .61919 L p
1 g
F P
s
P
p
.002 w
.58381 .60516 m .63028 .56813 L .6417 .56589 L p
1 g
F P
s
P
p
.002 w
.67458 .51282 m .6417 .56589 L .63028 .56813 L p
1 g
F P
s
P
p
.002 w
.67458 .51282 m .68782 .45055 L .69534 .44375 L p
1 g
F P
s
P
p
.002 w
.68682 .37873 m .69534 .44375 L .68782 .45055 L p
1 g
F P
s
P
p
.002 w
.32901 .36463 m .31184 .4171 L .30564 .40811 L p
1 g
F P
s
P
p
.002 w
.30564 .40811 m .32398 .35176 L .32901 .36463 L p
1 g
F P
s
P
p
.002 w
.41106 .27198 m .36025 .30455 L .36169 .29252 L p
1 g
F P
s
P
p
.002 w
.36169 .29252 m .41442 .25859 L .41106 .27198 L p
1 g
F P
s
P
p
.002 w
.54181 .25147 m .47679 .24416 L .48289 .23595 L p
1 g
F P
s
P
p
.002 w
.48289 .23595 m .5484 .24325 L .54181 .25147 L p
1 g
F P
s
P
p
.002 w
.34088 .5238 m .37114 .56403 L .36473 .57007 L p
1 g
F P
s
P
p
.002 w
.36473 .57007 m .33099 .52525 L .34088 .5238 L p
1 g
F P
s
P
p
.002 w
.41047 .60262 m .36473 .57007 L .37114 .56403 L p
1 g
F P
s
P
p
.002 w
.37114 .56403 m .4122 .59324 L .41047 .60262 L p
1 g
F P
s
P
p
.002 w
.46372 .61963 m .41047 .60262 L .4122 .59324 L p
1 g
F P
s
P
p
.002 w
.68782 .45055 m .6793 .38602 L .68682 .37873 L p
1 g
F P
s
P
p
.002 w
.65688 .31909 m .68682 .37873 L .6793 .38602 L p
1 g
F P
s
P
p
.002 w
.32449 .4765 m .34088 .5238 L .33099 .52525 L p
1 g
F P
s
P
p
.002 w
.33099 .52525 m .31266 .47253 L .32449 .4765 L p
1 g
F P
s
P
p
.002 w
.51924 .61919 m .57138 .60098 L .58381 .60516 L p
1 g
F P
s
P
p
.002 w
.63028 .56813 m .58381 .60516 L .57138 .60098 L p
1 g
F P
s
P
p
.002 w
.6018 .2801 m .54181 .25147 L .5484 .24325 L p
1 g
F P
s
P
p
.002 w
.5484 .24325 m .60883 .27204 L .6018 .2801 L p
1 g
F P
s
P
p
.002 w
.63028 .56813 m .66184 .517 L .67458 .51282 L p
1 g
F P
s
P
p
.002 w
.68782 .45055 m .67458 .51282 L .66184 .517 L p
1 g
F P
s
P
p
.002 w
.36287 .32078 m .32901 .36463 L .32398 .35176 L p
1 g
F P
s
P
p
.002 w
.32398 .35176 m .36025 .30455 L .36287 .32078 L p
1 g
F P
s
P
p
.002 w
.4122 .59324 m .45998 .60846 L .46372 .61963 L p
1 g
F P
s
P
p
.002 w
.51924 .61919 m .46372 .61963 L .45998 .60846 L p
1 g
F P
s
P
p
.002 w
.6793 .38602 m .64953 .32682 L .65688 .31909 L p
1 g
F P
s
P
p
.002 w
.60883 .27204 m .65688 .31909 L .64953 .32682 L p
1 g
F P
s
P
p
.002 w
.64953 .32682 m .6018 .2801 L .60883 .27204 L p
1 g
F P
s
P
p
.002 w
.47112 .25821 m .41106 .27198 L .41442 .25859 L p
1 g
F P
s
P
p
.002 w
.41442 .25859 m .47679 .24416 L .47112 .25821 L p
1 g
F P
s
P
p
.002 w
.32384 .42686 m .32449 .4765 L .31266 .47253 L p
1 g
F P
s
P
p
.002 w
.31266 .47253 m .31184 .4171 L .32384 .42686 L p
1 g
F P
s
P
p
.002 w
.45998 .60846 m .50972 .608 L .51924 .61919 L p
1 g
F P
s
P
p
.002 w
.57138 .60098 m .51924 .61919 L .50972 .608 L p
1 g
F P
s
P
p
.002 w
.57138 .60098 m .61456 .56643 L .63028 .56813 L p
1 g
F P
s
P
p
.002 w
.66184 .517 m .63028 .56813 L .61456 .56643 L p
1 g
F P
s
P
p
.002 w
.66184 .517 m .67447 .45704 L .68782 .45055 L p
1 g
F P
s
P
p
.002 w
.6793 .38602 m .68782 .45055 L .67447 .45704 L p
1 g
F P
s
P
p
.002 w
.33932 .37997 m .32384 .42686 L .31184 .4171 L p
1 g
F P
s
P
p
.002 w
.31184 .4171 m .32901 .36463 L .33932 .37997 L p
1 g
F P
s
P
p
.002 w
.41021 .29061 m .36287 .32078 L .36025 .30455 L p
1 g
F P
s
P
p
.002 w
.36025 .30455 m .41106 .27198 L .41021 .29061 L p
1 g
F P
s
P
p
.002 w
.53371 .26534 m .47112 .25821 L .47679 .24416 L p
1 g
F P
s
P
p
.002 w
.47679 .24416 m .54181 .25147 L .53371 .26534 L p
1 g
F P
s
P
p
.002 w
.35589 .51952 m .38164 .55379 L .37114 .56403 L p
1 g
F P
s
P
p
.002 w
.37114 .56403 m .34088 .5238 L .35589 .51952 L p
1 g
F P
s
P
p
.002 w
.4122 .59324 m .37114 .56403 L .38164 .55379 L p
1 g
F P
s
P
p
.002 w
.38164 .55379 m .41661 .57865 L .4122 .59324 L p
1 g
F P
s
P
p
.002 w
.45998 .60846 m .4122 .59324 L .41661 .57865 L p
1 g
F P
s
P
p
.002 w
.50972 .608 m .55634 .5916 L .57138 .60098 L p
1 g
F P
s
P
p
.002 w
.61456 .56643 m .57138 .60098 L .55634 .5916 L p
1 g
F P
s
P
p
.002 w
.67447 .45704 m .66617 .39493 L .6793 .38602 L p
1 g
F P
s
P
p
.002 w
.64953 .32682 m .6793 .38602 L .66617 .39493 L p
1 g
F P
s
P
p
.002 w
.34201 .47927 m .35589 .51952 L .34088 .5238 L p
1 g
F P
s
P
p
.002 w
.34088 .5238 m .32449 .4765 L .34201 .47927 L p
1 g
F P
s
P
p
.002 w
.59146 .29296 m .53371 .26534 L .54181 .25147 L p
1 g
F P
s
P
p
.002 w
.54181 .25147 m .6018 .2801 L .59146 .29296 L p
1 g
F P
s
P
p
.004 w
.5531 .25823 m
.55972 .23674 L
s
P
p
.002 w
.61456 .56643 m .6438 .51878 L .66184 .517 L p
1 g
F P
s
P
p
.002 w
.67447 .45704 m .66184 .517 L .6438 .51878 L p
1 g
F P
s
P
p
.002 w
.36969 .3409 m .33932 .37997 L .32901 .36463 L p
1 g
F P
s
P
p
.002 w
.32901 .36463 m .36287 .32078 L .36969 .3409 L p
1 g
F P
s
P
p
.002 w
.41661 .57865 m .45728 .59156 L .45998 .60846 L p
1 g
F P
s
P
p
.002 w
.50972 .608 m .45998 .60846 L .45728 .59156 L p
1 g
F P
s
P
p
.002 w
.66617 .39493 m .63744 .33795 L .64953 .32682 L p
1 g
F P
s
P
p
.002 w
.6018 .2801 m .64953 .32682 L .63744 .33795 L p
1 g
F P
s
P
p
.002 w
.4661 .27796 m .41021 .29061 L .41106 .27198 L p
1 g
F P
s
P
p
.002 w
.41106 .27198 m .47112 .25821 L .4661 .27796 L p
1 g
F P
s
P
p
.002 w
.63744 .33795 m .59146 .29296 L .6018 .2801 L p
1 g
F P
s
P
p
.002 w
.34156 .4371 m .34201 .47927 L .32449 .4765 L p
1 g
F P
s
P
p
.002 w
.32449 .4765 m .32384 .42686 L .34156 .4371 L p
1 g
F P
s
P
p
.002 w
.55634 .5916 m .59483 .5606 L .61456 .56643 L p
1 g
F P
s
P
p
.002 w
.6438 .51878 m .61456 .56643 L .59483 .5606 L p
1 g
F P
s
P
p
.002 w
.45728 .59156 m .49955 .59107 L .50972 .608 L p
1 g
F P
s
P
p
.002 w
.55634 .5916 m .50972 .608 L .49955 .59107 L p
1 g
F P
s
P
p
.002 w
.6438 .51878 m .65539 .46299 L .67447 .45704 L p
1 g
F P
s
P
p
.002 w
.66617 .39493 m .67447 .45704 L .65539 .46299 L p
1 g
F P
s
P
p
.002 w
.35483 .39738 m .34156 .4371 L .32384 .42686 L p
1 g
F P
s
P
p
.002 w
.32384 .42686 m .33932 .37997 L .35483 .39738 L p
1 g
F P
s
P
p
.002 w
.41204 .31413 m .36969 .3409 L .36287 .32078 L p
1 g
F P
s
P
p
.002 w
.36287 .32078 m .41021 .29061 L .41204 .31413 L p
1 g
F P
s
P
p
.002 w
.52429 .28472 m .4661 .27796 L .47112 .25821 L p
1 g
F P
s
P
p
.002 w
.47112 .25821 m .53371 .26534 L .52429 .28472 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37582 .51241 m .39611 .53945 L .38164 .55379 L p
1 g
F P
s
P
p
.002 w
.38164 .55379 m .35589 .51952 L .37582 .51241 L p
1 g
F P
s
P
p
.002 w
.41661 .57865 m .38164 .55379 L .39611 .53945 L p
1 g
F P
s
P
p
.002 w
.49955 .59107 m .53906 .57702 L .55634 .5916 L p
1 g
F P
s
P
p
.002 w
.59483 .5606 m .55634 .5916 L .53906 .57702 L p
1 g
F P
s
P
p
.002 w
.39611 .53945 m .4237 .55905 L .41661 .57865 L p
1 g
F P
s
P
p
.002 w
.45728 .59156 m .41661 .57865 L .4237 .55905 L p
1 g
F P
s
P
p
.002 w
.65539 .46299 m .64752 .40525 L .66617 .39493 L p
1 g
F P
s
P
p
.002 w
.63744 .33795 m .66617 .39493 L .64752 .40525 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.36494 .48067 m .37582 .51241 L .35589 .51952 L p
1 g
F P
s
P
p
.002 w
.35589 .51952 m .34201 .47927 L .36494 .48067 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.59483 .5606 m .62077 .51797 L .6438 .51878 L p
1 g
F P
s
P
p
.002 w
.65539 .46299 m .6438 .51878 L .62077 .51797 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.57797 .31046 m .52429 .28472 L .53371 .26534 L p
1 g
F P
s
P
p
.002 w
.53371 .26534 m .59146 .29296 L .57797 .31046 L p
1 g
F P
s
P
p
.004 w
.55074 .26586 m
.5531 .25823 L
s
P
p
.004 w
.54534 .2834 m
.55074 .26586 L
s
P
p
.002 w
.3807 .3644 m .35483 .39738 L .33932 .37997 L p
1 g
F P
s
P
p
.002 w
.33932 .37997 m .36969 .3409 L .3807 .3644 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.4237 .55905 m .45577 .56916 L .45728 .59156 L p
1 g
F P
s
P
p
.002 w
.45728 .59156 m .45587 .57061 L p
.49724 .58998 L 1 g
F P
s
P
p
.002 w
.49955 .59107 m .49924 .59107 L p
.49724 .58998 L 1 g
F P
s
P
p
.002 w
.49924 .59107 m .45728 .59156 L p
.49724 .58998 L 1 g
F P
s
P
p
.002 w
.45587 .57061 m .45577 .56916 L p
.46263 .57259 L 1 g
F P
s
P
p
.49955 .59107 m .45587 .57061 L .46263 .57259 L 1 g
F
P
p
.002 w
.46837 .57428 m .46872 .57265 L p
.45741 .56813 L 1 g
F P
s
P
p
.002 w
.45889 .56912 m .45577 .56916 L .45576 .56703 L p
1 g
F P
s
P
p
.45741 .56813 m .45615 .56763 L .45889 .56912 L 1 g
F
P
p
.45741 .56813 m .45889 .56912 L .46837 .57428 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.49955 .59107 m .49554 .58906 L .49287 .58068 L 1 g
F
P
p
.002 w
.49475 .58084 m .49955 .59107 L p
.49287 .58068 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56312 L p
1 g
F P
s
P
p
.002 w
.4237 .55905 m .42893 .54595 L p
.45467 .56821 L 1 g
F P
s
P
p
.002 w
.45577 .56916 m .45528 .56901 L p
.45467 .56821 L 1 g
F P
s
P
p
.002 w
.45528 .56901 m .4237 .55905 L p
.45467 .56821 L 1 g
F P
s
P
p
.002 w
.45078 .56312 m .45146 .56129 L p
.44527 .55591 L 1 g
F P
s
P
p
.46872 .57265 m .45078 .56312 L .4553 .56667 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43851 .54706 L p
1 g
F P
s
P
p
.45146 .56129 m .43851 .54706 L .44527 .55591 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.43478 .53702 m .4349 .53735 L .43336 .53485 L 1 g
F
P
p
.002 w
.42893 .54595 m .43192 .53845 L p
.45078 .56312 L 1 g
F P
s
P
p
.002 w
.43851 .54706 m .43925 .54566 L p
.43449 .53624 L 1 g
F P
s
P
p
.002 w
.43192 .53845 m .43336 .53485 L p
.4349 .53735 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52882 L p
1 g
F P
s
P
p
.002 w
.41424 .52129 m .42722 .5082 L p
.43233 .53036 L 1 g
F P
s
P
p
.002 w
.43336 .53485 m .43205 .53393 L p
.43233 .53036 L 1 g
F P
s
P
p
.002 w
.43205 .53393 m .41424 .52129 L p
.43233 .53036 L 1 g
F P
s
P
p
.002 w
.43244 .52882 m .43346 .52734 L p
.43318 .51917 L 1 g
F P
s
P
p
.43925 .54566 m .43244 .52882 L .43343 .53271 L 1 g
F
P
p
.43336 .53485 m .42722 .5082 L .43348 .53292 L 1 g
F
P
p
.43925 .54566 m .43343 .53271 L .43449 .53624 L 1 g
F
P
p
.002 w
.43374 .53396 m .43336 .53485 L p
.43348 .53292 L 1 g
F P
s
P
p
.43343 .53271 m .43396 .53483 L .43449 .53624 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45557 .54181 m .43405 .53507 L p
.44535 .50676 L 1 g
F P
s
P
p
.002 w
.43405 .53507 m .43336 .53485 L .43374 .53396 L p
1 g
F P
s
P
p
.002 w
.43374 .53396 m .44535 .50676 L p
.43405 .53507 L 1 g
F P
s
P
p
.43374 .53396 m .43198 .52949 L .43396 .53483 L 1 g
F
P
p
.43343 .53271 m .43334 .53252 L .43374 .53396 L 1 g
F
P
p
.43334 .53252 m .43198 .52949 L .43374 .53396 L 1 g
F
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43554 .49981 m .43765 .50131 L p
.43518 .50665 L 1 g
F P
s
P
p
.002 w
.43392 .50937 m .43485 .50826 L p
.43892 .49873 L 1 g
F P
s
P
p
.002 w
.43765 .50131 m .43554 .49981 L .44126 .494 L p
1 g
F P
s
P
p
.43892 .49873 m .43987 .49652 L .43765 .50131 L 1 g
F
P
p
.43892 .49873 m .43765 .50131 L .43392 .50937 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44256 .49139 L p
1 g
F P
s
P
p
.002 w
.44126 .494 m .43554 .49981 L p
.43836 .49545 L 1 g
F P
s
P
p
.43836 .49545 m .44761 .48117 L .44256 .49139 L 1 g
F
P
p
.43836 .49545 m .44256 .49139 L .44126 .494 L 1 g
F
P
p
.002 w
.44256 .49139 m .44196 .49202 L p
.43978 .49699 L 1 g
F P
s
P
p
.43485 .50826 m .44256 .49139 L .43978 .49699 L 1 g
F
P
p
.002 w
.44256 .49139 m .44339 .4905 L p
.45057 .48363 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.45826 .47608 m .4685 .47159 L .46746 .47209 L 1 g
F
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49426 .46522 m .4612 .47514 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.47755 .46719 m .47786 .46667 L p
.49129 .4653 L 1 g
F P
s
P
p
.002 w
.4941 .46492 m .49426 .46522 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.4961 .47701 m .49426 .46522 L .49626 .46456 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46394 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46394 L .49666 .46449 L 1 g
F
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46394 m .4961 .47701 L .49626 .46456 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46718 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46718 L .51126 .46557 L 1 g
F
P
p
.51224 .46571 m .4961 .47701 L .5 .46394 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53305 .47685 m .4961 .47701 L p
.51522 .46363 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47677 L p
1 g
F P
s
P
p
.002 w
.52879 .49952 m .53305 .47685 L .54172 .47647 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54237 .47677 m .52879 .49952 L .54172 .47647 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5662 .50951 L p
1 g
F P
s
P
p
.59333 .51445 m .57273 .52401 L .5662 .50951 L 1 g
F
P
p
.002 w
.56597 .50899 m .56618 .50903 L p
.5662 .50951 L 1 g
F P
s
P
p
.002 w
.56618 .50903 m .59333 .51445 L p
.5662 .50951 L 1 g
F P
s
P
p
.002 w
.5662 .50951 m .56515 .50826 L p
.56664 .5179 L 1 g
F P
s
P
p
.55661 .4905 m .5662 .50951 L .56597 .50899 L 1 g
F
P
p
.60172 .47231 m .56597 .50899 L .56462 .50615 L 1 g
F
P
p
.55661 .4905 m .56597 .50899 L .56327 .50332 L 1 g
F
P
p
.002 w
.56871 .47526 m .56327 .50332 L p
.55387 .48428 L 1 g
F P
s
P
p
.56254 .50184 m .56327 .50332 L .56283 .50239 L 1 g
F
P
p
.55661 .4905 m .56327 .50332 L .56254 .50184 L 1 g
F
P
p
.002 w
.56871 .47526 m .60172 .47231 L p
.56462 .50615 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56231 .50826 m .56327 .50332 L p
.56462 .50615 L 1 g
F P
s
P
p
.002 w
.56327 .50332 m .56871 .47526 L p
.56462 .50615 L 1 g
F P
s
P
p
.002 w
.60172 .47231 m .59333 .51445 L .56597 .50899 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55773 .49169 L p
1 g
F P
s
P
p
.002 w
.55773 .49169 m .55661 .4905 L p
.56283 .50239 L 1 g
F P
s
P
p
.56283 .50239 m .56713 .51061 L .55773 .49169 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55731 .49124 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56231 .50826 m .52879 .49952 L p
.55157 .48568 L 1 g
F P
s
P
p
.54174 .47608 m .55731 .49124 L .54929 .48347 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55387 .48428 m .55581 .48979 L .55157 .48568 L 1 g
F
P
p
.55581 .48979 m .56231 .50826 L .55157 .48568 L 1 g
F
P
p
.002 w
.56327 .50332 m .56231 .50826 L p
.55387 .48428 L 1 g
F P
s
P
p
.56283 .50239 m .56597 .50899 L .56406 .50475 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56717 .52826 L p
1 g
F P
s
P
p
.56515 .50826 m .56717 .52826 L .56664 .5179 L 1 g
F
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.5662 .50951 m .54542 .53667 L .56597 .50899 L 1 g
F
P
p
.57273 .52401 m .56709 .52662 L .5662 .50951 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56709 .52662 m .54542 .53667 L .5662 .50951 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.59333 .51445 m .57155 .55062 L .5622 .54563 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56158 .54722 L p
1 g
F P
s
P
p
.57155 .55062 m .55962 .55222 L .56158 .54722 L 1 g
F
P
p
.002 w
.5622 .54563 m .56267 .54588 L p
.56158 .54722 L 1 g
F P
s
P
p
.002 w
.56267 .54588 m .57155 .55062 L p
.56158 .54722 L 1 g
F P
s
P
p
.002 w
.56158 .54722 m .56075 .54566 L p
.55633 .55368 L 1 g
F P
s
P
p
.56654 .52734 m .56158 .54722 L .56199 .54617 L 1 g
F
P
p
.56654 .52734 m .56169 .54743 L .56496 .53601 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54904 .56264 L p
1 g
F P
s
P
p
.56075 .54566 m .54904 .56264 L .55633 .55368 L 1 g
F
P
p
.56158 .54722 m .52004 .55751 L .5622 .54563 L 1 g
F
P
p
.55962 .55222 m .55726 .55253 L .56158 .54722 L 1 g
F
P
p
.55726 .55253 m .52004 .55751 L .56158 .54722 L 1 g
F
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.57155 .55062 m .53906 .57702 L .53497 .57283 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57457 L p
1 g
F P
s
P
p
.53906 .57702 m .52995 .5755 L .5317 .57457 L 1 g
F
P
p
.002 w
.53497 .57283 m .53565 .57352 L p
.5317 .57457 L 1 g
F P
s
P
p
.002 w
.53565 .57352 m .53906 .57702 L p
.5317 .57457 L 1 g
F P
s
P
p
.002 w
.5317 .57457 m .53128 .57265 L p
.52309 .57685 L 1 g
F P
s
P
p
.54854 .56129 m .5317 .57457 L .53387 .57341 L 1 g
F
P
p
.54854 .56129 m .53182 .57511 L .54107 .56841 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58009 L p
1 g
F P
s
P
p
.002 w
.49955 .59107 m .49623 .58398 L p
.52396 .57947 L 1 g
F P
s
P
p
.002 w
.53906 .57702 m .53341 .57903 L p
.52396 .57947 L 1 g
F P
s
P
p
.002 w
.53341 .57903 m .49955 .59107 L p
.52396 .57947 L 1 g
F P
s
P
p
.002 w
.5109 .58009 m .51079 .57862 L p
.50117 .58054 L 1 g
F P
s
P
p
.53128 .57265 m .5109 .58009 L .52309 .57685 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58035 L p
1 g
F P
s
P
p
.51079 .57862 m .48908 .58035 L .49284 .58068 L 1 g
F
P
p
.49554 .58906 m .47769 .57935 L .49287 .58068 L 1 g
F
P
p
.51079 .57862 m .48902 .58111 L .50117 .58054 L 1 g
F
P
p
.45577 .56916 m .42893 .54595 L .45293 .56481 L 1 g
F
P
p
.002 w
.45576 .56703 m .45577 .56916 L p
.45293 .56481 L 1 g
F P
s
P
p
.4569 .56793 m .45029 .56444 L .45615 .56763 L 1 g
F
P
p
.46872 .57265 m .4553 .56667 L .4569 .56793 L 1 g
F
P
p
.4553 .56667 m .45029 .56444 L .4569 .56793 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43336 .53485 m .45557 .54181 L .45576 .56703 L p
1 g
F P
s
P
p
.45293 .56481 m .43336 .53485 L .45576 .56703 L 1 g
F
P
p
.002 w
.48908 .58035 m .48921 .57862 L p
.48085 .57793 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46837 .57428 L p
1 g
F P
s
P
p
.47769 .57935 m .46837 .57428 L .48908 .58035 L 1 g
F
P
p
.002 w
.45577 .56916 m .45889 .56912 L p
.49554 .58906 L 1 g
F P
s
P
p
.002 w
.46837 .57428 m .4678 .57686 L p
.48085 .57793 L 1 g
F P
s
P
p
.48921 .57862 m .46837 .57428 L .48085 .57793 L 1 g
F
P
p
.48908 .58035 m .45889 .56912 L .49287 .58068 L 1 g
F
P
p
.46837 .57428 m .45889 .56912 L .48908 .58035 L 1 g
F
P
p
.002 w
.45889 .56912 m .48905 .56868 L p
.49287 .58068 L 1 g
F P
s
P
p
.002 w
.48908 .58035 m .48902 .58111 L p
.49284 .58068 L 1 g
F P
s
P
p
.52886 .57532 m .5109 .58009 L .48905 .56868 L 1 g
F
P
p
.002 w
.49623 .58398 m .49475 .58084 L p
.5109 .58009 L 1 g
F P
s
P
p
.002 w
.49475 .58084 m .48905 .56868 L p
.5109 .58009 L 1 g
F P
s
P
p
.002 w
.48902 .58111 m .48889 .583 L p
.50117 .58054 L 1 g
F P
s
P
p
.53906 .57702 m .49623 .58398 L .52886 .57532 L 1 g
F
P
p
.002 w
.51106 .58228 m .5109 .58009 L p
.49816 .58114 L 1 g
F P
s
P
p
.50117 .58054 m .49816 .58114 L .5109 .58009 L 1 g
F
P
p
.002 w
.5109 .58009 m .51111 .583 L p
.52309 .57685 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.52995 .5755 m .48905 .56868 L .53497 .57283 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5317 .57457 L p
1 g
F P
s
P
p
.52309 .57685 m .51111 .583 L .5317 .57457 L 1 g
F
P
p
.002 w
.5317 .57457 m .53182 .57511 L p
.53387 .57341 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48905 .56868 m .52004 .55751 L .53497 .57283 L p
1 g
F P
s
P
p
.57155 .55062 m .53497 .57283 L .56429 .55159 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.53497 .57283 m .52004 .55751 L p
.56429 .55159 L 1 g
F P
s
P
p
.002 w
.53182 .57511 m .5322 .57686 L p
.54107 .56841 L 1 g
F P
s
P
p
.002 w
.54904 .56264 m .54998 .56518 L p
.55633 .55368 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56158 .54722 L p
1 g
F P
s
P
p
.55633 .55368 m .54998 .56518 L .56158 .54722 L 1 g
F
P
p
.002 w
.56158 .54722 m .56169 .54743 L p
.56199 .54617 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52004 .55751 m .54542 .53667 L .5622 .54563 L p
1 g
F P
s
P
p
.59333 .51445 m .5622 .54563 L .56773 .52633 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.5622 .54563 m .54542 .53667 L p
.56773 .52633 L 1 g
F P
s
P
p
.002 w
.56169 .54743 m .56257 .5491 L p
.56496 .53601 L 1 g
F P
s
P
p
.002 w
.56717 .52826 m .56854 .53025 L p
.56664 .5179 L 1 g
F P
s
P
p
.002 w
.56597 .50899 m .56231 .50826 L p
.56462 .50615 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5662 .50951 L p
1 g
F P
s
P
p
.56664 .5179 m .56854 .53025 L .5662 .50951 L 1 g
F
P
p
.002 w
.5662 .50951 m .56713 .51061 L p
.56406 .50475 L 1 g
F P
s
P
p
.002 w
.54542 .53667 m .56231 .50826 L .56597 .50899 L p
1 g
F P
s
P
p
.55157 .48568 m .52879 .49952 L .54237 .47677 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54237 .47677 L p
1 g
F P
s
P
p
.002 w
.54237 .47677 m .54174 .47608 L p
.54929 .48347 L 1 g
F P
s
P
p
.54929 .48347 m .55834 .49233 L .54237 .47677 L 1 g
F
P
p
.56871 .47526 m .55593 .48303 L .54237 .47677 L 1 g
F
P
p
.002 w
.54172 .47647 m .54204 .47645 L p
.54237 .47677 L 1 g
F P
s
P
p
.002 w
.54204 .47645 m .56871 .47526 L p
.54237 .47677 L 1 g
F P
s
P
p
.55593 .48303 m .55157 .48568 L .54237 .47677 L 1 g
F
P
p
.002 w
.55731 .49124 m .55834 .49233 L p
.54929 .48347 L 1 g
F P
s
P
p
.52214 .46667 m .54237 .47677 L .54172 .47647 L 1 g
F
P
p
.002 w
.54172 .47647 m .53305 .47685 L p
.53579 .47368 L 1 g
F P
s
P
p
.53708 .47428 m .54172 .47647 L .53802 .47476 L 1 g
F
P
p
.52214 .46667 m .54172 .47647 L .53708 .47428 L 1 g
F
P
p
.002 w
.53305 .47685 m .53232 .47204 L p
.53579 .47368 L 1 g
F P
s
P
p
.52214 .46667 m .54273 .47716 L .53619 .47394 L 1 g
F
P
p
.002 w
.52953 .4536 m .56372 .44132 L p
.53579 .47368 L 1 g
F P
s
P
p
.002 w
.53232 .47204 m .53305 .47685 L p
.51522 .46363 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53232 .47204 m .52953 .4536 L p
.53579 .47368 L 1 g
F P
s
P
p
.002 w
.56372 .44132 m .56871 .47526 L .54172 .47647 L p
1 g
F P
s
P
p
.56372 .44132 m .54172 .47647 L .53579 .47368 L 1 g
F
P
p
.53802 .47476 m .54172 .47647 L .54273 .47716 L 1 g
F
P
p
.002 w
.54237 .47677 m .54238 .47678 L p
.54172 .47647 L 1 g
F P
s
P
p
.002 w
.54238 .47678 m .54273 .47716 L p
.54172 .47647 L 1 g
F P
s
P
p
.002 w
.52953 .4536 m .53232 .47204 L p
.51522 .46363 L 1 g
F P
s
P
p
.002 w
.54273 .47716 m .54302 .47747 L p
.53619 .47394 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46394 L p
1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .4634 L p
.51126 .46557 L 1 g
F P
s
P
p
.51126 .46557 m .52282 .46778 L .5 .46394 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.52953 .4536 m .51941 .46069 L .5 .46394 L 1 g
F
P
p
.47786 .46667 m .49666 .46449 L .49129 .4653 L 1 g
F
P
p
.49666 .46449 m .49626 .46456 L .49129 .4653 L 1 g
F
P
p
.002 w
.49626 .46456 m .49426 .46522 L p
.49454 .46485 L 1 g
F P
s
P
p
.49626 .46456 m .49426 .4649 L .4941 .46492 L 1 g
F
P
p
.49626 .46456 m .4941 .46492 L .49129 .4653 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48867 .45447 m .51856 .43237 L p
.49454 .46485 L 1 g
F P
s
P
p
.002 w
.49426 .46522 m .4941 .46492 L p
.49454 .46485 L 1 g
F P
s
P
p
.002 w
.4941 .46492 m .48867 .45447 L p
.49454 .46485 L 1 g
F P
s
P
p
.002 w
.51856 .43237 m .52953 .4536 L .49626 .46456 L p
1 g
F P
s
P
p
.51856 .43237 m .49626 .46456 L .49454 .46485 L 1 g
F
P
p
.49626 .46456 m .5 .46411 L .49426 .4649 L 1 g
F
P
p
.49666 .46449 m .49668 .46449 L .49626 .46456 L 1 g
F
P
p
.49668 .46449 m .5 .46411 L .49626 .46456 L 1 g
F
P
p
.002 w
.49626 .46456 m .49872 .46375 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.49872 .46375 m .52953 .4536 L p
.5 .46394 L 1 g
F P
s
P
p
.51941 .46069 m .51224 .46571 L .5 .46394 L 1 g
F
P
p
.002 w
.52245 .46718 m .52282 .46778 L p
.51126 .46557 L 1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .46411 L p
.49666 .46449 L 1 g
F P
s
P
p
.002 w
.5 .46411 m .5 .46442 L p
.49129 .4653 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.48867 .45447 m .49171 .4603 L p
.47709 .46725 L 1 g
F P
s
P
p
.002 w
.45753 .47687 m .45826 .47608 L p
.46746 .47209 L 1 g
F P
s
P
p
.002 w
.4794 .50599 m .46852 .51004 L .45938 .47602 L p
1 g
F P
s
P
p
.002 w
.45947 .47598 m .4794 .50599 L p
.45938 .47602 L 1 g
F P
s
P
p
.002 w
.45675 .5103 m .44535 .50676 L .4591 .47615 L p
1 g
F P
s
P
p
.002 w
.48822 .49856 m .4794 .50599 L .45947 .47598 L p
1 g
F P
s
P
p
.002 w
.4961 .47701 m .494 .48854 L .45971 .47586 L p
1 g
F P
s
P
p
.46746 .47209 m .4612 .47514 L .45753 .47687 L 1 g
F
P
p
.002 w
.4612 .47514 m .49426 .46522 L p
.45997 .47574 L 1 g
F P
s
P
p
.4612 .47514 m .46028 .47559 L .46025 .4756 L 1 g
F
P
p
.4612 .47514 m .46025 .4756 L .45753 .47687 L 1 g
F
P
p
.002 w
.49426 .46522 m .4961 .47701 L .45997 .47574 L p
1 g
F P
s
P
p
.002 w
.45997 .47574 m .45929 .47571 L .4612 .47514 L p
1 g
F P
s
P
p
.002 w
.45971 .47586 m .45929 .47571 L .45997 .47574 L p
1 g
F P
s
P
p
.002 w
.45997 .47574 m .4961 .47701 L p
.45971 .47586 L 1 g
F P
s
P
p
.46028 .47559 m .45997 .47574 L .45993 .47576 L 1 g
F
P
p
.46028 .47559 m .45993 .47576 L .45753 .47687 L 1 g
F
P
p
.45997 .47574 m .45981 .47582 L .45975 .47584 L 1 g
F
P
p
.45997 .47574 m .45975 .47584 L .45753 .47687 L 1 g
F
P
p
.002 w
.494 .48854 m .48822 .49856 L .45957 .47593 L p
1 g
F P
s
P
p
.002 w
.45957 .47593 m .45929 .47571 L .45971 .47586 L p
1 g
F P
s
P
p
.002 w
.45971 .47586 m .494 .48854 L p
.45957 .47593 L 1 g
F P
s
P
p
.002 w
.45947 .47598 m .45929 .47571 L .45957 .47593 L p
1 g
F P
s
P
p
.002 w
.45957 .47593 m .48822 .49856 L p
.45947 .47598 L 1 g
F P
s
P
p
.45981 .47582 m .45963 .4759 L .45951 .47596 L 1 g
F
P
p
.45981 .47582 m .45951 .47596 L .45753 .47687 L 1 g
F
P
p
.45963 .4759 m .45957 .47593 L .4594 .47601 L 1 g
F
P
p
.45963 .4759 m .4594 .47601 L .45753 .47687 L 1 g
F
P
p
.002 w
.46852 .51004 m .45675 .5103 L .45927 .47607 L p
1 g
F P
s
P
p
.002 w
.45927 .47607 m .45929 .47571 L .45938 .47602 L p
1 g
F P
s
P
p
.002 w
.45938 .47602 m .46852 .51004 L p
.45927 .47607 L 1 g
F P
s
P
p
.002 w
.4591 .47615 m .45929 .47571 L .45927 .47607 L p
1 g
F P
s
P
p
.002 w
.45927 .47607 m .45675 .5103 L p
.4591 .47615 L 1 g
F P
s
P
p
.45957 .47593 m .45951 .47596 L .45919 .47611 L 1 g
F
P
p
.45957 .47593 m .45919 .47611 L .45753 .47687 L 1 g
F
P
p
.45951 .47596 m .45866 .47635 L .45753 .47687 L 1 g
F
P
p
.43485 .50826 m .44196 .49202 L .43987 .49652 L 1 g
F
P
p
.002 w
.44126 .494 m .45866 .47635 L p
.43765 .50131 L 1 g
F P
s
P
p
.002 w
.45866 .47635 m .45929 .47571 L p
.45881 .47628 L 1 g
F P
s
P
p
.43765 .50131 m .45866 .47635 L .45881 .47628 L 1 g
F
P
p
.002 w
.44535 .50676 m .43765 .50131 L p
.45881 .47628 L 1 g
F P
s
P
p
.002 w
.4591 .47615 m .44535 .50676 L p
.45881 .47628 L 1 g
F P
s
P
p
.44126 .494 m .44256 .49139 L .45856 .4764 L 1 g
F
P
p
.002 w
.45866 .47635 m .44126 .494 L p
.45856 .4764 L 1 g
F P
s
P
p
.002 w
.45821 .47622 m .45929 .47571 L p
.44256 .49139 L 1 g
F P
s
P
p
.002 w
.47501 .46883 m .45698 .47747 L .45753 .47688 L p
1 g
F P
s
P
p
.002 w
.45753 .47688 m .45753 .47687 L p
.45866 .47635 L 1 g
F P
s
P
p
.45866 .47635 m .47501 .46883 L .45753 .47688 L 1 g
F
P
p
.45951 .47596 m .45947 .47598 L .45866 .47635 L 1 g
F
P
p
.002 w
.45929 .47571 m .4591 .47615 L p
.45881 .47628 L 1 g
F P
s
P
p
.002 w
.45938 .47602 m .45929 .47571 L .45947 .47598 L p
1 g
F P
s
P
p
.4597 .47587 m .47501 .46883 L .45947 .47598 L 1 g
F
P
p
.46746 .47209 m .47017 .47092 L .4597 .47587 L 1 g
F
P
p
.47017 .47092 m .47501 .46883 L .4597 .47587 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45929 .47571 m .46957 .46829 L p
.47709 .46725 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46957 .46829 m .48867 .45447 L p
.47709 .46725 L 1 g
F P
s
P
p
.002 w
.49171 .4603 m .4941 .46492 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47755 .46719 L p
1 g
F P
s
P
p
.49129 .4653 m .5 .46442 L .47755 .46719 L 1 g
F
P
p
.002 w
.4612 .47514 m .45929 .47571 L p
.49171 .4603 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .47501 .46883 L p
.46746 .47209 L 1 g
F P
s
P
p
.4685 .47159 m .47718 .46778 L .46746 .47209 L 1 g
F
P
p
.002 w
.45929 .47571 m .45866 .47635 L p
.45856 .4764 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45753 .47687 L p
1 g
F P
s
P
p
.44339 .4905 m .45753 .47687 L .45057 .48363 L 1 g
F
P
p
.002 w
.44761 .48117 m .45821 .47622 L p
.44256 .49139 L 1 g
F P
s
P
p
.002 w
.45753 .47687 m .45698 .47747 L p
.45057 .48363 L 1 g
F P
s
P
p
.002 w
.44196 .49202 m .44166 .49233 L p
.43987 .49652 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49139 L p
1 g
F P
s
P
p
.45057 .48363 m .45698 .47747 L .44256 .49139 L 1 g
F
P
p
.002 w
.43554 .49981 m .42835 .49019 L .44761 .48117 L p
1 g
F P
s
P
p
.43348 .53292 m .4351 .50682 L .43374 .53396 L 1 g
F
P
p
.4351 .50682 m .43554 .49981 L .43518 .50665 L 1 g
F
P
p
.4351 .50682 m .43518 .50665 L .43374 .53396 L 1 g
F
P
p
.002 w
.42722 .5082 m .43554 .49981 L p
.4351 .50682 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43392 .50937 L p
1 g
F P
s
P
p
.43244 .52882 m .42978 .5183 L .43392 .50937 L 1 g
F
P
p
.42978 .5183 m .42722 .5082 L .4351 .50682 L 1 g
F
P
p
.002 w
.43392 .50937 m .43287 .51061 L p
.43318 .51917 L 1 g
F P
s
P
p
.43346 .52734 m .43392 .50937 L .43318 .51917 L 1 g
F
P
p
.43348 .53292 m .43244 .52882 L .4351 .50682 L 1 g
F
P
p
.43244 .52882 m .43392 .50937 L .4351 .50682 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43392 .50937 L p
1 g
F P
s
P
p
.43987 .49652 m .44166 .49233 L .43392 .50937 L 1 g
F
P
p
.002 w
.44535 .50676 m .43374 .53396 L p
.43518 .50665 L 1 g
F P
s
P
p
.002 w
.43765 .50131 m .44535 .50676 L p
.43518 .50665 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43244 .52882 L p
1 g
F P
s
P
p
.43318 .51917 m .43287 .51061 L .43244 .52882 L 1 g
F
P
p
.002 w
.43244 .52882 m .43198 .52949 L p
.43343 .53271 L 1 g
F P
s
P
p
.45078 .56312 m .43851 .54706 L .4349 .53735 L 1 g
F
P
p
.43851 .54706 m .43192 .53845 L .4349 .53735 L 1 g
F
P
p
.002 w
.43198 .52949 m .43146 .53025 L p
.43449 .53624 L 1 g
F P
s
P
p
.002 w
.41424 .52129 m .43336 .53485 L .4237 .55905 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43851 .54706 L p
1 g
F P
s
P
p
.43449 .53624 m .43146 .53025 L .43851 .54706 L 1 g
F
P
p
.45293 .56481 m .45078 .56312 L .4349 .53735 L 1 g
F
P
p
.45293 .56481 m .4349 .53735 L .43478 .53702 L 1 g
F
P
p
.002 w
.43851 .54706 m .43743 .5491 L p
.44527 .55591 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56312 L p
1 g
F P
s
P
p
.44527 .55591 m .43743 .5491 L .45078 .56312 L 1 g
F
P
p
.002 w
.45078 .56312 m .45029 .56444 L p
.4553 .56667 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58228 L p
1 g
F P
s
P
p
.49816 .58114 m .48889 .583 L .51106 .58228 L 1 g
F
P
p
.002 w
.48905 .56868 m .49475 .58084 L p
.49287 .58068 L 1 g
F P
s
P
p
.002 w
.45029 .56444 m .45002 .56518 L p
.45615 .56763 L 1 g
F P
s
P
p
.002 w
.48905 .56868 m .45889 .56912 L p
.45557 .54181 L 1 g
F P
s
P
p
.002 w
.45576 .56703 m .45557 .54181 L p
.45889 .56912 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46837 .57428 L p
1 g
F P
s
P
p
.45615 .56763 m .45002 .56518 L .46837 .57428 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58035 L p
1 g
F P
s
P
p
.48085 .57793 m .4678 .57686 L .48908 .58035 L 1 g
F
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.46194 .30302 m .41204 .31413 L .41021 .29061 L p
1 g
F P
s
P
p
.002 w
.41021 .29061 m .4661 .27796 L .46194 .30302 L p
1 g
F P
s
P
p
.002 w
.64752 .40525 m .62073 .3523 L .63744 .33795 L p
1 g
F P
s
P
p
.002 w
.59146 .29296 m .63744 .33795 L .62073 .3523 L p
1 g
F P
s
P
p
.002 w
.3647 .44749 m .36494 .48067 L .34201 .47927 L p
1 g
F P
s
P
p
.002 w
.34201 .47927 m .34156 .4371 L .3647 .44749 L p
1 g
F P
s
P
p
.002 w
.62073 .3523 m .57797 .31046 L .59146 .29296 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53906 .57702 m .57155 .55062 L .59483 .5606 L p
1 g
F P
s
P
p
.002 w
.62077 .51797 m .59483 .5606 L .57155 .55062 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.62077 .51797 m .63092 .46816 L .65539 .46299 L p
1 g
F P
s
P
p
.002 w
.64752 .40525 m .65539 .46299 L .63092 .46816 L p
1 g
F P
s
P
p
.002 w
.37526 .41634 m .3647 .44749 L .34156 .4371 L p
1 g
F P
s
P
p
.002 w
.34156 .4371 m .35483 .39738 L .37526 .41634 L p
1 g
F P
s
P
p
.002 w
.41663 .34194 m .3807 .3644 L .36969 .3409 L p
1 g
F P
s
P
p
.002 w
.36969 .3409 m .41204 .31413 L .41663 .34194 L p
1 g
F P
s
P
p
.002 w
.51381 .3092 m .46194 .30302 L .4661 .27796 L p
1 g
F P
s
P
p
.002 w
.4661 .27796 m .52429 .28472 L .51381 .3092 L p
1 g
F P
s
P
p
.002 w
.40021 .50255 m .41424 .52129 L .39611 .53945 L p
1 g
F P
s
P
p
.002 w
.39611 .53945 m .37582 .51241 L .40021 .50255 L p
1 g
F P
s
P
p
.002 w
.4237 .55905 m .39611 .53945 L .41424 .52129 L p
1 g
F P
s
P
p
.002 w
.63092 .46816 m .62376 .41669 L .64752 .40525 L p
1 g
F P
s
P
p
.002 w
.62073 .3523 m .64752 .40525 L .62376 .41669 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.57155 .55062 m .59333 .51445 L .62077 .51797 L p
1 g
F P
s
P
p
.002 w
.63092 .46816 m .62077 .51797 L .59333 .51445 L p
1 g
F P
s
P
p
.002 w
.39568 .39059 m .37526 .41634 L .35483 .39738 L p
1 g
F P
s
P
p
.002 w
.35483 .39738 m .3807 .3644 L .39568 .39059 L p
1 g
F P
s
P
p
.002 w
.39274 .48057 m .40021 .50255 L .37582 .51241 L p
1 g
F P
s
P
p
.002 w
.37582 .51241 m .36494 .48067 L .39274 .48057 L p
1 g
F P
s
P
p
.002 w
.56165 .33222 m .51381 .3092 L .52429 .28472 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53434 .31908 L
s
P
p
.002 w
.52429 .28472 m .57797 .31046 L .56165 .33222 L p
1 g
F P
s
P
p
.004 w
.54053 .29902 m
.54214 .29376 L
s
P
p
.004 w
.54214 .29376 m
.54534 .2834 L
s
P
p
.004 w
.5402 .30007 m
.54053 .29902 L
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.45883 .33273 m .41663 .34194 L .41204 .31413 L p
1 g
F P
s
P
p
.002 w
.41204 .31413 m .46194 .30302 L .45883 .33273 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39266 .45764 m .39274 .48057 L .36494 .48067 L p
1 g
F P
s
P
p
.002 w
.36494 .48067 m .3647 .44749 L .39266 .45764 L p
1 g
F P
s
P
p
.002 w
.62376 .41669 m .59978 .36951 L .62073 .3523 L p
1 g
F P
s
P
p
.002 w
.57797 .31046 m .62073 .3523 L .59978 .36951 L p
1 g
F P
s
P
p
.002 w
.59978 .36951 m .56165 .33222 L .57797 .31046 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45557 .54181 m .47857 .54139 L .48905 .56868 L p
1 g
F P
s
P
p
.002 w
.52004 .55751 m .48905 .56868 L .47857 .54139 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.4239 .37316 m .39568 .39059 L .3807 .3644 L p
1 g
F P
s
P
p
.002 w
.3807 .3644 m .41663 .34194 L .4239 .37316 L p
1 g
F P
s
P
p
.002 w
.40005 .43621 m .39266 .45764 L .3647 .44749 L p
1 g
F P
s
P
p
.002 w
.3647 .44749 m .37526 .41634 L .40005 .43621 L p
1 g
F P
s
P
p
.002 w
.59333 .51445 m .60172 .47231 L .63092 .46816 L p
1 g
F P
s
P
p
.002 w
.62376 .41669 m .63092 .46816 L .60172 .47231 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50263 .33808 m .45883 .33273 L .46194 .30302 L p
1 g
F P
s
P
p
.002 w
.46194 .30302 m .51381 .3092 L .50263 .33808 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.47857 .54139 m .49991 .53358 L .52004 .55751 L p
1 g
F P
s
P
p
.002 w
.54542 .53667 m .52004 .55751 L .49991 .53358 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41421 .41857 m .40005 .43621 L .37526 .41634 L p
1 g
F P
s
P
p
.002 w
.37526 .41634 m .39568 .39059 L .41421 .41857 L p
1 g
F P
s
P
p
.002 w
.42835 .49019 m .43554 .49981 L .41424 .52129 L p
1 g
F P
s
P
p
.002 w
.41424 .52129 m .40021 .50255 L .42835 .49019 L p
1 g
F P
s
P
p
.002 w
.60172 .47231 m .59551 .42885 L .62376 .41669 L p
1 g
F P
s
P
p
.002 w
.59978 .36951 m .62376 .41669 L .59551 .42885 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42455 .47891 m .42835 .49019 L .40021 .50255 L p
1 g
F P
s
P
p
.002 w
.40021 .50255 m .39274 .48057 L .42455 .47891 L p
1 g
F P
s
P
p
.002 w
.54299 .35758 m .50263 .33808 L .51381 .3092 L p
1 g
F P
s
P
p
.002 w
.51381 .3092 m .56165 .33222 L .54299 .35758 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.45694 .36612 m .4239 .37316 L .41663 .34194 L p
1 g
F P
s
P
p
.002 w
.41663 .34194 m .45883 .33273 L .45694 .36612 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.44535 .50676 m .45675 .5103 L .45557 .54181 L p
1 g
F P
s
P
p
.002 w
.47857 .54139 m .45557 .54181 L .45675 .5103 L p
1 g
F P
s
P
p
.002 w
.42457 .46718 m .42455 .47891 L .39274 .48057 L p
1 g
F P
s
P
p
.002 w
.39274 .48057 m .39266 .45764 L .42457 .46718 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59551 .42885 m .57519 .38906 L .59978 .36951 L p
1 g
F P
s
P
p
.002 w
.56165 .33222 m .59978 .36951 L .57519 .38906 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57519 .38906 m .54299 .35758 L .56165 .33222 L p
1 g
F P
s
P
p
.002 w
.49991 .53358 m .5173 .51913 L .54542 .53667 L p
1 g
F P
s
P
p
.002 w
.56231 .50826 m .54542 .53667 L .5173 .51913 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45675 .5103 m .46852 .51004 L .47857 .54139 L p
1 g
F P
s
P
p
.002 w
.49991 .53358 m .47857 .54139 L .46852 .51004 L p
1 g
F P
s
P
p
.002 w
.43368 .40672 m .41421 .41857 L .39568 .39059 L p
1 g
F P
s
P
p
.002 w
.39568 .39059 m .4239 .37316 L .43368 .40672 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42841 .45625 m .42457 .46718 L .39266 .45764 L p
1 g
F P
s
P
p
.002 w
.39266 .45764 m .40005 .43621 L .42841 .45625 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.59551 .42885 m .60172 .47231 L .56871 .47526 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.49115 .37043 m .45694 .36612 L .45883 .33273 L p
1 g
F P
s
P
p
.002 w
.45883 .33273 m .50263 .33808 L .49115 .37043 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.46852 .51004 m .4794 .50599 L .49991 .53358 L p
1 g
F P
s
P
p
.002 w
.5173 .51913 m .49991 .53358 L .4794 .50599 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.43568 .44732 m .42841 .45625 L .40005 .43621 L p
1 g
F P
s
P
p
.002 w
.40005 .43621 m .41421 .41857 L .43568 .44732 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5173 .51913 m .52879 .49952 L .56231 .50826 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56871 .47526 m .56372 .44132 L .59551 .42885 L p
1 g
F P
s
P
p
.002 w
.57519 .38906 m .59551 .42885 L .56372 .44132 L p
1 g
F P
s
P
p
.002 w
.45637 .40201 m .43368 .40672 L .4239 .37316 L p
1 g
F P
s
P
p
.002 w
.4239 .37316 m .45694 .36612 L .45637 .40201 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.42835 .49019 m .42455 .47891 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.52263 .38571 m .49115 .37043 L .50263 .33808 L p
1 g
F P
s
P
p
.002 w
.50263 .33808 m .54299 .35758 L .52263 .38571 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.4794 .50599 m .48822 .49856 L .5173 .51913 L p
1 g
F P
s
P
p
.002 w
.52879 .49952 m .5173 .51913 L .48822 .49856 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.42455 .47891 m .42457 .46718 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.44563 .44135 m .43568 .44732 L .41421 .41857 L p
1 g
F P
s
P
p
.002 w
.41421 .41857 m .43368 .40672 L .44563 .44135 L p
1 g
F P
s
P
p
.002 w
.56372 .44132 m .54778 .41028 L .57519 .38906 L p
1 g
F P
s
P
p
.002 w
.54299 .35758 m .57519 .38906 L .54778 .41028 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.54778 .41028 m .52263 .38571 L .54299 .35758 L p
1 g
F P
s
P
p
.002 w
.42457 .46718 m .42841 .45625 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.4798 .40505 m .45637 .40201 L .45694 .36612 L p
1 g
F P
s
P
p
.002 w
.45694 .36612 m .49115 .37043 L .4798 .40505 L p
1 g
F P
s
P
p
.002 w
.42841 .45625 m .43568 .44732 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.48822 .49856 m .494 .48854 L .52879 .49952 L p
1 g
F P
s
P
p
.002 w
.53305 .47685 m .52879 .49952 L .494 .48854 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.45717 .43902 m .44563 .44135 L .43368 .40672 L p
1 g
F P
s
P
p
.002 w
.43368 .40672 m .45637 .40201 L .45717 .43902 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.43568 .44732 m .44563 .44135 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.54778 .41028 m .56372 .44132 L .52953 .4536 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.44563 .44135 m .45717 .43902 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .44596 m .48867 .45447 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.004 w
.48322 .44915 m
.5 .43051 L
s
P
p
.002 w
.46904 .44061 m .47995 .44596 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.45717 .43902 m .46904 .44061 L .45929 .47571 L closepath p
1 g
F P
s
P
p
.002 w
.50134 .41556 m .4798 .40505 L .49115 .37043 L p
1 g
F P
s
P
p
.002 w
.49115 .37043 m .52263 .38571 L .50134 .41556 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.494 .48854 m .4961 .47701 L .53305 .47685 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.004 w
.45798 .47717 m
.45929 .47571 L
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46904 .44061 m .45717 .43902 L .45637 .40201 L p
1 g
F P
s
P
p
.002 w
.45637 .40201 m .4798 .40505 L .46904 .44061 L p
1 g
F P
s
P
p
.002 w
.52953 .4536 m .51856 .43237 L .54778 .41028 L p
1 g
F P
s
P
p
.002 w
.52263 .38571 m .54778 .41028 L .51856 .43237 L p
1 g
F P
s
P
p
.002 w
.51856 .43237 m .50134 .41556 L .52263 .38571 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47995 .44596 m .46904 .44061 L .4798 .40505 L p
1 g
F P
s
P
p
.002 w
.4798 .40505 m .50134 .41556 L .47995 .44596 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.48867 .45447 m .47995 .44596 L .50134 .41556 L p
1 g
F P
s
P
p
.002 w
.50134 .41556 m .51856 .43237 L .48867 .45447 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.43417 .50361 m
.45798 .47717 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .5647 .22057 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .43417 .50361 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.423256)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.423256)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4743 .45285 m .49137 .46001 L .49796 .43229 L p
1 g
F P
s
P
p
.002 w
.49796 .43229 m .48932 .42866 L .4743 .45285 L p
1 g
F P
s
P
p
.002 w
.50731 .43295 m .49796 .43229 L .49137 .46001 L p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .48932 .42866 L .49796 .43229 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .49796 .43229 L .50731 .43295 L closepath p
1 g
F P
s
P
p
.002 w
.49137 .46001 m .50985 .46132 L .50731 .43295 L p
1 g
F P
s
P
p
.002 w
.51636 .43058 m .50731 .43295 L .50985 .46132 L p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .50731 .43295 L .51636 .43058 L closepath p
1 g
F P
s
P
p
.002 w
.46045 .44061 m .4743 .45285 L .48932 .42866 L p
1 g
F P
s
P
p
.002 w
.48932 .42866 m .48233 .42246 L .46045 .44061 L p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .48233 .42246 L .48932 .42866 L closepath p
1 g
F P
s
P
p
.002 w
.50985 .46132 m .52775 .45664 L .51636 .43058 L p
1 g
F P
s
P
p
.002 w
.52414 .42542 m .51636 .43058 L .52775 .45664 L p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .51636 .43058 L .52414 .42542 L closepath p
1 g
F P
s
P
p
.002 w
.4513 .42457 m .46045 .44061 L .48233 .42246 L p
1 g
F P
s
P
p
.002 w
.48233 .42246 m .47772 .41435 L .4513 .42457 L p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .47772 .41435 L .48233 .42246 L closepath p
1 g
F P
s
P
p
.002 w
.52775 .45664 m .54316 .44647 L .52414 .42542 L p
1 g
F P
s
P
p
.002 w
.52981 .41802 m .52414 .42542 L .54316 .44647 L p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .52414 .42542 L .52981 .41802 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .51564 .37874 L .50648 .37655 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .50648 .37655 L .4971 .37744 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .4971 .37744 L .48854 .3813 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .48854 .3813 L .48173 .38772 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .48173 .38772 L .4774 .39598 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .4774 .39598 L .47602 .40519 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .47602 .40519 L .47772 .41435 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .52981 .41802 L .53275 .40919 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .53275 .40919 L .53264 .39987 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .53264 .39987 L .52948 .39108 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .52948 .39108 L .5236 .38376 L closepath p
1 g
F P
s
P
p
.002 w
.50459 .40455 m .5236 .38376 L .51564 .37874 L closepath p
1 g
F P
s
P
p
.002 w
.44788 .40645 m .4513 .42457 L .47772 .41435 L p
1 g
F P
s
P
p
.002 w
.47772 .41435 m .47602 .40519 L .44788 .40645 L p
1 g
F P
s
P
p
.002 w
.45979 .47667 m .48495 .48719 L .49137 .46001 L p
1 g
F P
s
P
p
.002 w
.49137 .46001 m .4743 .45285 L .45979 .47667 L p
1 g
F P
s
P
p
.002 w
.50985 .46132 m .49137 .46001 L .48495 .48719 L p
1 g
F P
s
P
p
.002 w
.54316 .44647 m .55442 .43186 L .52981 .41802 L p
1 g
F P
s
P
p
.002 w
.53275 .40919 m .52981 .41802 L .55442 .43186 L p
1 g
F P
s
P
p
.002 w
.48495 .48719 m .51216 .48914 L .50985 .46132 L p
1 g
F P
s
P
p
.002 w
.52775 .45664 m .50985 .46132 L .51216 .48914 L p
1 g
F P
s
P
p
.002 w
.43935 .45866 m .45979 .47667 L .4743 .45285 L p
1 g
F P
s
P
p
.002 w
.4743 .45285 m .46045 .44061 L .43935 .45866 L p
1 g
F P
s
P
p
.002 w
.45056 .3882 m .44788 .40645 L .47602 .40519 L p
1 g
F P
s
P
p
.002 w
.47602 .40519 m .4774 .39598 L .45056 .3882 L p
1 g
F P
s
P
p
.002 w
.51216 .48914 m .53855 .48228 L .52775 .45664 L p
1 g
F P
s
P
p
.002 w
.54316 .44647 m .52775 .45664 L .53855 .48228 L p
1 g
F P
s
P
p
.002 w
.55442 .43186 m .5603 .41438 L .53275 .40919 L p
1 g
F P
s
P
p
.002 w
.53264 .39987 m .53275 .40919 L .5603 .41438 L p
1 g
F P
s
P
p
.002 w
.42581 .43504 m .43935 .45866 L .46045 .44061 L p
1 g
F P
s
P
p
.002 w
.46045 .44061 m .4513 .42457 L .42581 .43504 L p
1 g
F P
s
P
p
.002 w
.4591 .37178 m .45056 .3882 L .4774 .39598 L p
1 g
F P
s
P
p
.002 w
.4774 .39598 m .48173 .38772 L .4591 .37178 L p
1 g
F P
s
P
p
.002 w
.5603 .41438 m .56013 .3959 L .53264 .39987 L p
1 g
F P
s
P
p
.002 w
.52948 .39108 m .53264 .39987 L .56013 .3959 L p
1 g
F P
s
P
p
.002 w
.53855 .48228 m .5613 .46733 L .54316 .44647 L p
1 g
F P
s
P
p
.002 w
.55442 .43186 m .54316 .44647 L .5613 .46733 L p
1 g
F P
s
P
p
.002 w
.4726 .35902 m .4591 .37178 L .48173 .38772 L p
1 g
F P
s
P
p
.002 w
.48173 .38772 m .48854 .3813 L .4726 .35902 L p
1 g
F P
s
P
p
.002 w
.42069 .40832 m .42581 .43504 L .4513 .42457 L p
1 g
F P
s
P
p
.002 w
.4513 .42457 m .44788 .40645 L .42069 .40832 L p
1 g
F P
s
P
p
.002 w
.56013 .3959 m .55389 .37843 L .52948 .39108 L p
1 g
F P
s
P
p
.002 w
.5236 .38376 m .52948 .39108 L .55389 .37843 L p
1 g
F P
s
P
p
.002 w
.4896 .35131 m .4726 .35902 L .48854 .3813 L p
1 g
F P
s
P
p
.002 w
.48854 .3813 m .4971 .37744 L .4896 .35131 L p
1 g
F P
s
P
p
.002 w
.55389 .37843 m .54224 .36389 L .5236 .38376 L p
1 g
F P
s
P
p
.002 w
.51564 .37874 m .5236 .38376 L .54224 .36389 L p
1 g
F P
s
P
p
.002 w
.50823 .34954 m .4896 .35131 L .4971 .37744 L p
1 g
F P
s
P
p
.002 w
.4971 .37744 m .50648 .37655 L .50823 .34954 L p
1 g
F P
s
P
p
.002 w
.50648 .37655 m .51564 .37874 L .52645 .35389 L p
1 g
F P
s
P
p
.002 w
.54224 .36389 m .52645 .35389 L .51564 .37874 L p
1 g
F P
s
P
p
.002 w
.52645 .35389 m .50823 .34954 L .50648 .37655 L p
1 g
F P
s
P
p
.002 w
.5613 .46733 m .57797 .44582 L .55442 .43186 L p
1 g
F P
s
P
p
.002 w
.5603 .41438 m .55442 .43186 L .57797 .44582 L p
1 g
F P
s
P
p
.002 w
.42458 .38134 m .42069 .40832 L .44788 .40645 L p
1 g
F P
s
P
p
.002 w
.44788 .40645 m .45056 .3882 L .42458 .38134 L p
1 g
F P
s
P
p
.002 w
.44607 .49968 m .47882 .51335 L .48495 .48719 L p
1 g
F P
s
P
p
.002 w
.48495 .48719 m .45979 .47667 L .44607 .49968 L p
1 g
F P
s
P
p
.002 w
.51216 .48914 m .48495 .48719 L .47882 .51335 L p
1 g
F P
s
P
p
.002 w
.47882 .51335 m .51422 .51589 L .51216 .48914 L p
1 g
F P
s
P
p
.002 w
.53855 .48228 m .51216 .48914 L .51422 .51589 L p
1 g
F P
s
P
p
.002 w
.41943 .47627 m .44607 .49968 L .45979 .47667 L p
1 g
F P
s
P
p
.002 w
.45979 .47667 m .43935 .45866 L .41943 .47627 L p
1 g
F P
s
P
p
.002 w
.57797 .44582 m .58672 .42003 L .5603 .41438 L p
1 g
F P
s
P
p
.002 w
.56013 .3959 m .5603 .41438 L .58672 .42003 L p
1 g
F P
s
P
p
.002 w
.51422 .51589 m .54856 .50701 L .53855 .48228 L p
1 g
F P
s
P
p
.002 w
.5613 .46733 m .53855 .48228 L .54856 .50701 L p
1 g
F P
s
P
p
.002 w
.43715 .35705 m .42458 .38134 L .45056 .3882 L p
1 g
F P
s
P
p
.002 w
.45056 .3882 m .4591 .37178 L .43715 .35705 L p
1 g
F P
s
P
p
.002 w
.40175 .44556 m .41943 .47627 L .43935 .45866 L p
1 g
F P
s
P
p
.002 w
.43935 .45866 m .42581 .43504 L .40175 .44556 L p
1 g
F P
s
P
p
.002 w
.58672 .42003 m .58654 .39273 L .56013 .3959 L p
1 g
F P
s
P
p
.002 w
.55389 .37843 m .56013 .3959 L .58654 .39273 L p
1 g
F P
s
P
p
.002 w
.54856 .50701 m .57821 .48759 L .5613 .46733 L p
1 g
F P
s
P
p
.002 w
.57797 .44582 m .5613 .46733 L .57821 .48759 L p
1 g
F P
s
P
p
.002 w
.45707 .33812 m .43715 .35705 L .4591 .37178 L p
1 g
F P
s
P
p
.002 w
.4591 .37178 m .4726 .35902 L .45707 .33812 L p
1 g
F P
s
P
p
.002 w
.39498 .41076 m .40175 .44556 L .42581 .43504 L p
1 g
F P
s
P
p
.002 w
.42581 .43504 m .42069 .40832 L .39498 .41076 L p
1 g
F P
s
P
p
.002 w
.58654 .39273 m .57737 .36687 L .55389 .37843 L p
1 g
F P
s
P
p
.002 w
.54224 .36389 m .55389 .37843 L .57737 .36687 L p
1 g
F P
s
P
p
.002 w
.48221 .32668 m .45707 .33812 L .4726 .35902 L p
1 g
F P
s
P
p
.002 w
.4726 .35902 m .4896 .35131 L .48221 .32668 L p
1 g
F P
s
P
p
.002 w
.57737 .36687 m .56017 .34532 L .54224 .36389 L p
1 g
F P
s
P
p
.002 w
.52645 .35389 m .54224 .36389 L .56017 .34532 L p
1 g
F P
s
P
p
.002 w
.57821 .48759 m .59999 .45964 L .57797 .44582 L p
1 g
F P
s
P
p
.002 w
.58672 .42003 m .57797 .44582 L .59999 .45964 L p
1 g
F P
s
P
p
.002 w
.50981 .32403 m .48221 .32668 L .4896 .35131 L p
1 g
F P
s
P
p
.002 w
.4896 .35131 m .50823 .34954 L .50981 .32403 L p
1 g
F P
s
P
p
.002 w
.50823 .34954 m .52645 .35389 L .53679 .33048 L p
1 g
F P
s
P
p
.002 w
.56017 .34532 m .53679 .33048 L .52645 .35389 L p
1 g
F P
s
P
p
.002 w
.53679 .33048 m .50981 .32403 L .50823 .34954 L p
1 g
F P
s
P
p
.002 w
.39997 .37558 m .39498 .41076 L .42069 .40832 L p
1 g
F P
s
P
p
.002 w
.42069 .40832 m .42458 .38134 L .39997 .37558 L p
1 g
F P
s
P
p
.002 w
.43342 .52142 m .47309 .53796 L .47882 .51335 L p
1 g
F P
s
P
p
.002 w
.47882 .51335 m .44607 .49968 L .43342 .52142 L p
1 g
F P
s
P
p
.002 w
.51422 .51589 m .47882 .51335 L .47309 .53796 L p
1 g
F P
s
P
p
.002 w
.47309 .53796 m .51596 .54104 L .51422 .51589 L p
1 g
F P
s
P
p
.002 w
.54856 .50701 m .51422 .51589 L .51596 .54104 L p
1 g
F P
s
P
p
.002 w
.59999 .45964 m .61148 .42605 L .58672 .42003 L p
1 g
F P
s
P
p
.002 w
.58654 .39273 m .58672 .42003 L .61148 .42605 L p
1 g
F P
s
P
p
.002 w
.40111 .49311 m .43342 .52142 L .44607 .49968 L p
1 g
F P
s
P
p
.002 w
.44607 .49968 m .41943 .47627 L .40111 .49311 L p
1 g
F P
s
P
p
.002 w
.41629 .34384 m .39997 .37558 L .42458 .38134 L p
1 g
F P
s
P
p
.002 w
.42458 .38134 m .43715 .35705 L .41629 .34384 L p
1 g
F P
s
P
p
.002 w
.51596 .54104 m .55756 .53033 L .54856 .50701 L p
1 g
F P
s
P
p
.002 w
.57821 .48759 m .54856 .50701 L .55756 .53033 L p
1 g
F P
s
P
p
.002 w
.37961 .45594 m .40111 .49311 L .41943 .47627 L p
1 g
F P
s
P
p
.002 w
.41943 .47627 m .40175 .44556 L .37961 .45594 L p
1 g
F P
s
P
p
.002 w
.61148 .42605 m .61134 .39042 L .58654 .39273 L p
1 g
F P
s
P
p
.002 w
.57737 .36687 m .58654 .39273 L .61134 .39042 L p
1 g
F P
s
P
p
.002 w
.44227 .31906 m .41629 .34384 L .43715 .35705 L p
1 g
F P
s
P
p
.002 w
.43715 .35705 m .45707 .33812 L .44227 .31906 L p
1 g
F P
s
P
p
.002 w
.55756 .53033 m .59353 .50687 L .57821 .48759 L p
1 g
F P
s
P
p
.002 w
.59999 .45964 m .57821 .48759 L .59353 .50687 L p
1 g
F P
s
P
p
.002 w
.37131 .41376 m .37961 .45594 L .40175 .44556 L p
1 g
F P
s
P
p
.002 w
.40175 .44556 m .39498 .41076 L .37131 .41376 L p
1 g
F P
s
P
p
.002 w
.61134 .39042 m .59944 .35663 L .57737 .36687 L p
1 g
F P
s
P
p
.002 w
.56017 .34532 m .57737 .36687 L .59944 .35663 L p
1 g
F P
s
P
p
.002 w
.4751 .30406 m .44227 .31906 L .45707 .33812 L p
1 g
F P
s
P
p
.002 w
.45707 .33812 m .48221 .32668 L .4751 .30406 L p
1 g
F P
s
P
p
.002 w
.59353 .50687 m .62001 .47304 L .59999 .45964 L p
1 g
F P
s
P
p
.002 w
.61148 .42605 m .59999 .45964 L .62001 .47304 L p
1 g
F P
s
P
p
.002 w
.59944 .35663 m .57701 .32844 L .56017 .34532 L p
1 g
F P
s
P
p
.002 w
.53679 .33048 m .56017 .34532 L .57701 .32844 L p
1 g
F P
s
P
p
.002 w
.51118 .30057 m .4751 .30406 L .48221 .32668 L p
1 g
F P
s
P
p
.002 w
.48221 .32668 m .50981 .32403 L .51118 .30057 L p
1 g
F P
s
P
p
.002 w
.50981 .32403 m .53679 .33048 L .54646 .30902 L p
1 g
F P
s
P
p
.002 w
.57701 .32844 m .54646 .30902 L .53679 .33048 L p
1 g
F P
s
P
p
.002 w
.37725 .37105 m .37131 .41376 L .39498 .41076 L p
1 g
F P
s
P
p
.002 w
.39498 .41076 m .39997 .37558 L .37725 .37105 L p
1 g
F P
s
P
p
.002 w
.54646 .30902 m .51118 .30057 L .50981 .32403 L p
1 g
F P
s
P
p
.002 w
.42212 .54143 m .46789 .56049 L .47309 .53796 L p
1 g
F P
s
P
p
.002 w
.47309 .53796 m .43342 .52142 L .42212 .54143 L p
1 g
F P
s
P
p
.002 w
.51596 .54104 m .47309 .53796 L .46789 .56049 L p
1 g
F P
s
P
p
.002 w
.62001 .47304 m .63405 .43233 L .61148 .42605 L p
1 g
F P
s
P
p
.002 w
.61134 .39042 m .61148 .42605 L .63405 .43233 L p
1 g
F P
s
P
p
.002 w
.46789 .56049 m .51734 .56406 L .51596 .54104 L p
1 g
F P
s
P
p
.002 w
.55756 .53033 m .51596 .54104 L .51734 .56406 L p
1 g
F P
s
P
p
.002 w
.38481 .50882 m .42212 .54143 L .43342 .52142 L p
1 g
F P
s
P
p
.002 w
.43342 .52142 m .40111 .49311 L .38481 .50882 L p
1 g
F P
s
P
p
.002 w
.39699 .33246 m .37725 .37105 L .39997 .37558 L p
1 g
F P
s
P
p
.002 w
.39997 .37558 m .41629 .34384 L .39699 .33246 L p
1 g
F P
s
P
p
.002 w
.51734 .56406 m .56535 .55174 L .55756 .53033 L p
1 g
F P
s
P
p
.002 w
.59353 .50687 m .55756 .53033 L .56535 .55174 L p
1 g
F P
s
P
p
.002 w
.35991 .46596 m .38481 .50882 L .40111 .49311 L p
1 g
F P
s
P
p
.002 w
.40111 .49311 m .37961 .45594 L .35991 .46596 L p
1 g
F P
s
P
p
.002 w
.63405 .43233 m .63397 .38907 L .61134 .39042 L p
1 g
F P
s
P
p
.002 w
.59944 .35663 m .61134 .39042 L .63397 .38907 L p
1 g
F P
s
P
p
.002 w
.42851 .30229 m .39699 .33246 L .41629 .34384 L p
1 g
F P
s
P
p
.002 w
.41629 .34384 m .44227 .31906 L .42851 .30229 L p
1 g
F P
s
P
p
.002 w
.56535 .55174 m .6069 .52474 L .59353 .50687 L p
1 g
F P
s
P
p
.002 w
.62001 .47304 m .59353 .50687 L .6069 .52474 L p
1 g
F P
s
P
p
.002 w
.35022 .41727 m .35991 .46596 L .37961 .45594 L p
1 g
F P
s
P
p
.002 w
.37961 .45594 m .37131 .41376 L .35022 .41727 L p
1 g
F P
s
P
p
.002 w
.63397 .38907 m .6196 .34799 L .59944 .35663 L p
1 g
F P
s
P
p
.002 w
.57701 .32844 m .59944 .35663 L .6196 .34799 L p
1 g
F P
s
P
p
.002 w
.46842 .284 m .42851 .30229 L .44227 .31906 L p
1 g
F P
s
P
p
.002 w
.44227 .31906 m .4751 .30406 L .46842 .284 L p
1 g
F P
s
P
p
.002 w
.6069 .52474 m .63755 .48573 L .62001 .47304 L p
1 g
F P
s
P
p
.002 w
.63405 .43233 m .62001 .47304 L .63755 .48573 L p
1 g
F P
s
P
p
.002 w
.6196 .34799 m .59238 .31367 L .57701 .32844 L p
1 g
F P
s
P
p
.002 w
.54646 .30902 m .57701 .32844 L .59238 .31367 L p
1 g
F P
s
P
p
.002 w
.5123 .27973 m .46842 .284 L .4751 .30406 L p
1 g
F P
s
P
p
.002 w
.4751 .30406 m .51118 .30057 L .5123 .27973 L p
1 g
F P
s
P
p
.002 w
.35699 .3679 m .35022 .41727 L .37131 .41376 L p
1 g
F P
s
P
p
.002 w
.37131 .41376 m .37725 .37105 L .35699 .3679 L p
1 g
F P
s
P
p
.002 w
.51118 .30057 m .54646 .30902 L .55523 .29001 L p
1 g
F P
s
P
p
.002 w
.59238 .31367 m .55523 .29001 L .54646 .30902 L p
1 g
F P
s
P
p
.002 w
.55523 .29001 m .5123 .27973 L .51118 .30057 L p
1 g
F P
s
P
p
.002 w
.41247 .55922 m .46335 .58038 L .46789 .56049 L p
1 g
F P
s
P
p
.002 w
.46789 .56049 m .42212 .54143 L .41247 .55922 L p
1 g
F P
s
P
p
.002 w
.51734 .56406 m .46789 .56049 L .46335 .58038 L p
1 g
F P
s
P
p
.002 w
.63755 .48573 m .65387 .43874 L .63405 .43233 L p
1 g
F P
s
P
p
.002 w
.63397 .38907 m .63405 .43233 L .65387 .43874 L p
1 g
F P
s
P
p
.002 w
.46335 .58038 m .51832 .58436 L .51734 .56406 L p
1 g
F P
s
P
p
.002 w
.56535 .55174 m .51734 .56406 L .51832 .58436 L p
1 g
F P
s
P
p
.002 w
.37094 .523 m .41247 .55922 L .42212 .54143 L p
1 g
F P
s
P
p
.002 w
.42212 .54143 m .38481 .50882 L .37094 .523 L p
1 g
F P
s
P
p
.002 w
.37973 .32324 m .35699 .3679 L .37725 .37105 L p
1 g
F P
s
P
p
.002 w
.37725 .37105 m .39699 .33246 L .37973 .32324 L p
1 g
F P
s
P
p
.002 w
.51832 .58436 m .57171 .57072 L .56535 .55174 L p
1 g
F P
s
P
p
.002 w
.6069 .52474 m .56535 .55174 L .57171 .57072 L p
1 g
F P
s
P
p
.002 w
.34318 .47538 m .37094 .523 L .38481 .50882 L p
1 g
F P
s
P
p
.002 w
.38481 .50882 m .35991 .46596 L .34318 .47538 L p
1 g
F P
s
P
p
.002 w
.65387 .43874 m .65388 .38874 L .63397 .38907 L p
1 g
F P
s
P
p
.002 w
.6196 .34799 m .63397 .38907 L .65388 .38874 L p
1 g
F P
s
P
p
.002 w
.41614 .28828 m .37973 .32324 L .39699 .33246 L p
1 g
F P
s
P
p
.002 w
.39699 .33246 m .42851 .30229 L .41614 .28828 L p
1 g
F P
s
P
p
.002 w
.57171 .57072 m .61795 .54075 L .6069 .52474 L p
1 g
F P
s
P
p
.002 w
.63755 .48573 m .6069 .52474 L .61795 .54075 L p
1 g
F P
s
P
p
.002 w
.33231 .42123 m .34318 .47538 L .35991 .46596 L p
1 g
F P
s
P
p
.002 w
.35991 .46596 m .35022 .41727 L .33231 .42123 L p
1 g
F P
s
P
p
.002 w
.65388 .38874 m .63734 .34119 L .6196 .34799 L p
1 g
F P
s
P
p
.002 w
.59238 .31367 m .6196 .34799 L .63734 .34119 L p
1 g
F P
s
P
p
.002 w
.46233 .26706 m .41614 .28828 L .42851 .30229 L p
1 g
F P
s
P
p
.002 w
.42851 .30229 m .46842 .284 L .46233 .26706 L p
1 g
F P
s
P
p
.002 w
.61795 .54075 m .65212 .49742 L .63755 .48573 L p
1 g
F P
s
P
p
.002 w
.65387 .43874 m .63755 .48573 L .65212 .49742 L p
1 g
F P
s
P
p
.002 w
.63734 .34119 m .60587 .30142 L .59238 .31367 L p
1 g
F P
s
P
p
.002 w
.55523 .29001 m .59238 .31367 L .60587 .30142 L p
1 g
F P
s
P
p
.002 w
.51315 .26208 m .46233 .26706 L .46842 .284 L p
1 g
F P
s
P
p
.002 w
.46842 .284 m .5123 .27973 L .51315 .26208 L p
1 g
F P
s
P
p
.002 w
.33974 .36627 m .33231 .42123 L .35022 .41727 L p
1 g
F P
s
P
p
.002 w
.35022 .41727 m .35699 .3679 L .33974 .36627 L p
1 g
F P
s
P
p
.002 w
.5123 .27973 m .55523 .29001 L .56288 .27399 L p
1 g
F P
s
P
p
.002 w
.60587 .30142 m .56288 .27399 L .55523 .29001 L p
1 g
F P
s
P
p
.002 w
.56288 .27399 m .51315 .26208 L .5123 .27973 L p
1 g
F P
s
P
p
.002 w
.65212 .49742 m .67037 .44516 L .65387 .43874 L p
1 g
F P
s
P
p
.002 w
.65388 .38874 m .65387 .43874 L .67037 .44516 L p
1 g
F P
s
P
p
.002 w
.40475 .57429 m .45961 .59707 L .46335 .58038 L p
1 g
F P
s
P
p
.002 w
.46335 .58038 m .41247 .55922 L .40475 .57429 L p
1 g
F P
s
P
p
.002 w
.51832 .58436 m .46335 .58038 L .45961 .59707 L p
1 g
F P
s
P
p
.002 w
.45961 .59707 m .51886 .60137 L .51832 .58436 L p
1 g
F P
s
P
p
.002 w
.57171 .57072 m .51832 .58436 L .51886 .60137 L p
1 g
F P
s
P
p
.002 w
.35995 .53528 m .40475 .57429 L .41247 .55922 L p
1 g
F P
s
P
p
.002 w
.41247 .55922 m .37094 .523 L .35995 .53528 L p
1 g
F P
s
P
p
.002 w
.36498 .31649 m .33974 .36627 L .35699 .3679 L p
1 g
F P
s
P
p
.002 w
.35699 .3679 m .37973 .32324 L .36498 .31649 L p
1 g
F P
s
P
p
.002 w
.51886 .60137 m .57642 .58671 L .57171 .57072 L p
1 g
F P
s
P
p
.002 w
.61795 .54075 m .57171 .57072 L .57642 .58671 L p
1 g
F P
s
P
p
.002 w
.32995 .48397 m .35995 .53528 L .37094 .523 L p
1 g
F P
s
P
p
.002 w
.37094 .523 m .34318 .47538 L .32995 .48397 L p
1 g
F P
s
P
p
.002 w
.67037 .44516 m .67048 .38948 L .65388 .38874 L p
1 g
F P
s
P
p
.002 w
.63734 .34119 m .65388 .38874 L .67048 .38948 L p
1 g
F P
s
P
p
.002 w
.40552 .27748 m .36498 .31649 L .37973 .32324 L p
1 g
F P
s
P
p
.002 w
.37973 .32324 m .41614 .28828 L .40552 .27748 L p
1 g
F P
s
P
p
.002 w
.57642 .58671 m .62632 .55446 L .61795 .54075 L p
1 g
F P
s
P
p
.002 w
.65212 .49742 m .61795 .54075 L .62632 .55446 L p
1 g
F P
s
P
p
.002 w
.31814 .42559 m .32995 .48397 L .34318 .47538 L p
1 g
F P
s
P
p
.002 w
.34318 .47538 m .33231 .42123 L .31814 .42559 L p
1 g
F P
s
P
p
.002 w
.67048 .38948 m .65212 .33648 L .63734 .34119 L p
1 g
F P
s
P
p
.002 w
.60587 .30142 m .63734 .34119 L .65212 .33648 L p
1 g
F P
s
P
p
.002 w
.457 .25377 m .40552 .27748 L .41614 .28828 L p
1 g
F P
s
P
p
.002 w
.41614 .28828 m .46233 .26706 L .457 .25377 L p
1 g
F P
s
P
p
.002 w
.62632 .55446 m .66323 .50779 L .65212 .49742 L p
1 g
F P
s
P
p
.002 w
.67037 .44516 m .65212 .49742 L .66323 .50779 L p
1 g
F P
s
P
p
.002 w
.65212 .33648 m .61709 .29211 L .60587 .30142 L p
1 g
F P
s
P
p
.002 w
.56288 .27399 m .60587 .30142 L .61709 .29211 L p
1 g
F P
s
P
p
.002 w
.51368 .24821 m .457 .25377 L .46233 .26706 L p
1 g
F P
s
P
p
.002 w
.46233 .26706 m .51315 .26208 L .51368 .24821 L p
1 g
F P
s
P
p
.002 w
.32608 .36629 m .31814 .42559 L .33231 .42123 L p
1 g
F P
s
P
p
.002 w
.33231 .42123 m .33974 .36627 L .32608 .36629 L p
1 g
F P
s
P
p
.002 w
.51315 .26208 m .56288 .27399 L .56915 .26149 L p
1 g
F P
s
P
p
.002 w
.61709 .29211 m .56915 .26149 L .56288 .27399 L p
1 g
F P
s
P
p
.002 w
.56915 .26149 m .51368 .24821 L .51315 .26208 L p
1 g
F P
s
P
p
.002 w
.66323 .50779 m .683 .45144 L .67037 .44516 L p
1 g
F P
s
P
p
.002 w
.67048 .38948 m .67037 .44516 L .683 .45144 L p
1 g
F P
s
P
p
.002 w
.39925 .58613 m .45679 .61001 L .45961 .59707 L p
1 g
F P
s
P
p
.002 w
.45961 .59707 m .40475 .57429 L .39925 .58613 L p
1 g
F P
s
P
p
.002 w
.51886 .60137 m .45961 .59707 L .45679 .61001 L p
1 g
F P
s
P
p
.002 w
.45679 .61001 m .51892 .61452 L .51886 .60137 L p
1 g
F P
s
P
p
.002 w
.57642 .58671 m .51886 .60137 L .51892 .61452 L p
1 g
F P
s
P
p
.002 w
.35224 .54526 m .39925 .58613 L .40475 .57429 L p
1 g
F P
s
P
p
.002 w
.40475 .57429 m .35995 .53528 L .35224 .54526 L p
1 g
F P
s
P
p
.002 w
.35326 .31251 m .32608 .36629 L .33974 .36627 L p
1 g
F P
s
P
p
.002 w
.33974 .36627 m .36498 .31649 L .35326 .31251 L p
1 g
F P
s
P
p
.002 w
.51892 .61452 m .57929 .59918 L .57642 .58671 L p
1 g
F P
s
P
p
.002 w
.62632 .55446 m .57642 .58671 L .57929 .59918 L p
1 g
F P
s
P
p
.002 w
.32074 .49148 m .35224 .54526 L .35995 .53528 L p
1 g
F P
s
P
p
.002 w
.35995 .53528 m .32995 .48397 L .32074 .49148 L p
1 g
F P
s
P
p
.002 w
.683 .45144 m .68319 .39135 L .67048 .38948 L p
1 g
F P
s
P
p
.002 w
.65212 .33648 m .67048 .38948 L .68319 .39135 L p
1 g
F P
s
P
p
.002 w
.397 .27034 m .35326 .31251 L .36498 .31649 L p
1 g
F P
s
P
p
.002 w
.36498 .31649 m .40552 .27748 L .397 .27034 L p
1 g
F P
s
P
p
.002 w
.57929 .59918 m .63165 .56541 L .62632 .55446 L p
1 g
F P
s
P
p
.002 w
.66323 .50779 m .62632 .55446 L .63165 .56541 L p
1 g
F P
s
P
p
.002 w
.30829 .43026 m .32074 .49148 L .32995 .48397 L p
1 g
F P
s
P
p
.002 w
.32995 .48397 m .31814 .42559 L .30829 .43026 L p
1 g
F P
s
P
p
.002 w
.68319 .39135 m .66343 .33409 L .65212 .33648 L p
1 g
F P
s
P
p
.002 w
.61709 .29211 m .65212 .33648 L .66343 .33409 L p
1 g
F P
s
P
p
.002 w
.4526 .2447 m .397 .27034 L .40552 .27748 L p
1 g
F P
s
P
p
.002 w
.40552 .27748 m .457 .25377 L .4526 .2447 L p
1 g
F P
s
P
p
.002 w
.63165 .56541 m .67041 .5165 L .66323 .50779 L p
1 g
F P
s
P
p
.002 w
.683 .45144 m .66323 .50779 L .67041 .5165 L p
1 g
F P
s
P
p
.002 w
.66343 .33409 m .62562 .28614 L .61709 .29211 L p
1 g
F P
s
P
p
.002 w
.56915 .26149 m .61709 .29211 L .62562 .28614 L p
1 g
F P
s
P
p
.002 w
.51387 .23866 m .4526 .2447 L .457 .25377 L p
1 g
F P
s
P
p
.002 w
.457 .25377 m .51368 .24821 L .51387 .23866 L p
1 g
F P
s
P
p
.002 w
.31656 .36803 m .30829 .43026 L .31814 .42559 L p
1 g
F P
s
P
p
.002 w
.31814 .42559 m .32608 .36629 L .31656 .36803 L p
1 g
F P
s
P
p
.002 w
.51368 .24821 m .56915 .26149 L .57382 .25303 L p
1 g
F P
s
P
p
.002 w
.62562 .28614 m .57382 .25303 L .56915 .26149 L p
1 g
F P
s
P
p
.002 w
.57382 .25303 m .51387 .23866 L .51368 .24821 L p
1 g
F P
s
P
p
.002 w
.67041 .5165 m .69121 .4574 L .683 .45144 L p
1 g
F P
s
P
p
.002 w
.68319 .39135 m .683 .45144 L .69121 .4574 L p
1 g
F P
s
P
p
.002 w
.39626 .59425 m .45502 .61863 L .45679 .61001 L p
1 g
F P
s
P
p
.002 w
.45679 .61001 m .39925 .58613 L .39626 .59425 L p
1 g
F P
s
P
p
.002 w
.51892 .61452 m .45679 .61001 L .45502 .61863 L p
1 g
F P
s
P
p
.002 w
.45502 .61863 m .51848 .62325 L .51892 .61452 L p
1 g
F P
s
P
p
.002 w
.57929 .59918 m .51892 .61452 L .51848 .62325 L p
1 g
F P
s
P
p
.002 w
.34823 .55254 m .39626 .59425 L .39925 .58613 L p
1 g
F P
s
P
p
.002 w
.39925 .58613 m .35224 .54526 L .34823 .55254 L p
1 g
F P
s
P
p
.002 w
.34504 .31158 m .31656 .36803 L .32608 .36629 L p
1 g
F P
s
P
p
.002 w
.32608 .36629 m .35326 .31251 L .34504 .31158 L p
1 g
F P
s
P
p
.002 w
.51848 .62325 m .58013 .6076 L .57929 .59918 L p
1 g
F P
s
P
p
.002 w
.63165 .56541 m .57929 .59918 L .58013 .6076 L p
1 g
F P
s
P
p
.002 w
.31603 .49764 m .34823 .55254 L .35224 .54526 L p
1 g
F P
s
P
p
.002 w
.35224 .54526 m .32074 .49148 L .31603 .49764 L p
1 g
F P
s
P
p
.002 w
.69121 .4574 m .69146 .39436 L .68319 .39135 L p
1 g
F P
s
P
p
.002 w
.66343 .33409 m .68319 .39135 L .69146 .39436 L p
1 g
F P
s
P
p
.002 w
.39093 .26729 m .34504 .31158 L .35326 .31251 L p
1 g
F P
s
P
p
.002 w
.35326 .31251 m .397 .27034 L .39093 .26729 L p
1 g
F P
s
P
p
.002 w
.58013 .6076 m .63362 .57314 L .63165 .56541 L p
1 g
F P
s
P
p
.002 w
.67041 .5165 m .63165 .56541 L .63362 .57314 L p
1 g
F P
s
P
p
.002 w
.30328 .43513 m .31603 .49764 L .32074 .49148 L p
1 g
F P
s
P
p
.002 w
.32074 .49148 m .30829 .43026 L .30328 .43513 L p
1 g
F P
s
P
p
.002 w
.69146 .39436 m .67075 .33424 L .66343 .33409 L p
1 g
F P
s
P
p
.002 w
.62562 .28614 m .66343 .33409 L .67075 .33424 L p
1 g
F P
s
P
p
.002 w
.44932 .24033 m .39093 .26729 L .397 .27034 L p
1 g
F P
s
P
p
.002 w
.397 .27034 m .4526 .2447 L .44932 .24033 L p
1 g
F P
s
P
p
.002 w
.63362 .57314 m .67322 .52322 L .67041 .5165 L p
1 g
F P
s
P
p
.002 w
.69121 .4574 m .67041 .5165 L .67322 .52322 L p
1 g
F P
s
P
p
.002 w
.67075 .33424 m .63107 .28387 L .62562 .28614 L p
1 g
F P
s
P
p
.002 w
.57382 .25303 m .62562 .28614 L .63107 .28387 L p
1 g
F P
s
P
p
.002 w
.3117 .37159 m .30328 .43513 L .30829 .43026 L p
1 g
F P
s
P
p
.002 w
.30829 .43026 m .31656 .36803 L .3117 .37159 L p
1 g
F P
s
P
p
.002 w
.51368 .23399 m .44932 .24033 L .4526 .2447 L p
1 g
F P
s
P
p
.002 w
.4526 .2447 m .51387 .23866 L .51368 .23399 L p
1 g
F P
s
P
p
.002 w
.51387 .23866 m .57382 .25303 L .57667 .24908 L p
1 g
F P
s
P
p
.002 w
.63107 .28387 m .57667 .24908 L .57382 .25303 L p
1 g
F P
s
P
p
.002 w
.57667 .24908 m .51368 .23399 L .51387 .23866 L p
1 g
F P
s
P
p
.002 w
.67322 .52322 m .69449 .46289 L .69121 .4574 L p
1 g
F P
s
P
p
.002 w
.69146 .39436 m .69121 .4574 L .69449 .46289 L p
1 g
F P
s
P
p
.002 w
.396 .5982 m .45442 .62243 L .45502 .61863 L p
1 g
F P
s
P
p
.002 w
.45502 .61863 m .39626 .59425 L .396 .5982 L p
1 g
F P
s
P
p
.002 w
.51848 .62325 m .45502 .61863 L .45442 .62243 L p
1 g
F P
s
P
p
.002 w
.45442 .62243 m .5175 .62702 L .51848 .62325 L p
1 g
F P
s
P
p
.002 w
.58013 .6076 m .51848 .62325 L .5175 .62702 L p
1 g
F P
s
P
p
.002 w
.34077 .31392 m .3117 .37159 L .31656 .36803 L p
1 g
F P
s
P
p
.002 w
.31656 .36803 m .34504 .31158 L .34077 .31392 L p
1 g
F P
s
P
p
.002 w
.34826 .55675 m .396 .5982 L .39626 .59425 L p
1 g
F P
s
P
p
.002 w
.39626 .59425 m .34823 .55254 L .34826 .55675 L p
1 g
F P
s
P
p
.002 w
.5175 .62702 m .57879 .61148 L .58013 .6076 L p
1 g
F P
s
P
p
.002 w
.63362 .57314 m .58013 .6076 L .57879 .61148 L p
1 g
F P
s
P
p
.002 w
.31625 .5022 m .34826 .55675 L .34823 .55254 L p
1 g
F P
s
P
p
.002 w
.34823 .55254 m .31603 .49764 L .31625 .5022 L p
1 g
F P
s
P
p
.002 w
.69449 .46289 m .69477 .3985 L .69146 .39436 L p
1 g
F P
s
P
p
.002 w
.67075 .33424 m .69146 .39436 L .69477 .3985 L p
1 g
F P
s
P
p
.002 w
.38765 .26866 m .34077 .31392 L .34504 .31158 L p
1 g
F P
s
P
p
.002 w
.34504 .31158 m .39093 .26729 L .38765 .26866 L p
1 g
F P
s
P
p
.002 w
.57879 .61148 m .63195 .57724 L .63362 .57314 L p
1 g
F P
s
P
p
.002 w
.67322 .52322 m .63362 .57314 L .63195 .57724 L p
1 g
F P
s
P
p
.004 w
.6849 .29295 m
.69999 .28172 L
s
P
p
.002 w
.30357 .44009 m .31625 .5022 L .31603 .49764 L p
1 g
F P
s
P
p
.002 w
.31603 .49764 m .30328 .43513 L .30357 .44009 L p
1 g
F P
s
P
p
.002 w
.69477 .3985 m .67363 .33709 L .67075 .33424 L p
1 g
F P
s
P
p
.002 w
.63107 .28387 m .67075 .33424 L .67363 .33709 L p
1 g
F P
s
P
p
.002 w
.44732 .24112 m .38765 .26866 L .39093 .26729 L p
1 g
F P
s
P
p
.002 w
.39093 .26729 m .44932 .24033 L .44732 .24112 L p
1 g
F P
s
P
p
.002 w
.63195 .57724 m .67131 .52764 L .67322 .52322 L p
1 g
F P
s
P
p
.002 w
.69449 .46289 m .67322 .52322 L .67131 .52764 L p
1 g
F P
s
P
p
.002 w
.67363 .33709 m .63308 .28561 L .63107 .28387 L p
1 g
F P
s
P
p
.002 w
.57667 .24908 m .63107 .28387 L .63308 .28561 L p
1 g
F P
s
P
p
.002 w
.31194 .37696 m .30357 .44009 L .30328 .43513 L p
1 g
F P
s
P
p
.002 w
.30328 .43513 m .3117 .37159 L .31194 .37696 L p
1 g
F P
s
P
p
.002 w
.5131 .23464 m .44732 .24112 L .44932 .24033 L p
1 g
F P
s
P
p
.002 w
.44932 .24033 m .51368 .23399 L .5131 .23464 L p
1 g
F P
s
P
p
.002 w
.51368 .23399 m .57667 .24908 L .57748 .25007 L p
1 g
F P
s
P
p
.002 w
.63308 .28561 m .57748 .25007 L .57667 .24908 L p
1 g
F P
s
P
p
.002 w
.57748 .25007 m .5131 .23464 L .51368 .23399 L p
1 g
F P
s
P
p
.002 w
.67131 .52764 m .69244 .4677 L .69449 .46289 L p
1 g
F P
s
P
p
.002 w
.69477 .3985 m .69449 .46289 L .69244 .4677 L p
1 g
F P
s
P
p
.002 w
.39867 .59759 m .45508 .62098 L .45442 .62243 L p
1 g
F P
s
P
p
.002 w
.45442 .62243 m .396 .5982 L .39867 .59759 L p
1 g
F P
s
P
p
.002 w
.5175 .62702 m .45442 .62243 L .45508 .62098 L p
1 g
F P
s
P
p
.002 w
.45508 .62098 m .51598 .62542 L .5175 .62702 L p
1 g
F P
s
P
p
.002 w
.57879 .61148 m .5175 .62702 L .51598 .62542 L p
1 g
F P
s
P
p
.002 w
.34084 .31968 m .31194 .37696 L .3117 .37159 L p
1 g
F P
s
P
p
.002 w
.3117 .37159 m .34077 .31392 L .34084 .31968 L p
1 g
F P
s
P
p
.002 w
.35259 .55757 m .39867 .59759 L .396 .5982 L p
1 g
F P
s
P
p
.002 w
.396 .5982 m .34826 .55675 L .35259 .55757 L p
1 g
F P
s
P
p
.002 w
.51598 .62542 m .57516 .6104 L .57879 .61148 L p
1 g
F P
s
P
p
.002 w
.63195 .57724 m .57879 .61148 L .57516 .6104 L p
1 g
F P
s
P
p
.002 w
.32171 .50491 m .35259 .55757 L .34826 .55675 L p
1 g
F P
s
P
p
.002 w
.34826 .55675 m .31625 .5022 L .32171 .50491 L p
1 g
F P
s
P
p
.002 w
.69244 .4677 m .69271 .40373 L .69477 .3985 L p
1 g
F P
s
P
p
.002 w
.67363 .33709 m .69477 .3985 L .69271 .40373 L p
1 g
F P
s
P
p
.002 w
.38744 .27473 m .34084 .31968 L .34077 .31392 L p
1 g
F P
s
P
p
.002 w
.34077 .31392 m .38765 .26866 L .38744 .27473 L p
1 g
F P
s
P
p
.002 w
.57516 .6104 m .62646 .57735 L .63195 .57724 L p
1 g
F P
s
P
p
.002 w
.67131 .52764 m .63195 .57724 L .62646 .57735 L p
1 g
F P
s
P
p
.002 w
.30951 .445 m .32171 .50491 L .31625 .5022 L p
1 g
F P
s
P
p
.002 w
.31625 .5022 m .30357 .44009 L .30951 .445 L p
1 g
F P
s
P
p
.002 w
.69271 .40373 m .67168 .34273 L .67363 .33709 L p
1 g
F P
s
P
p
.002 w
.63308 .28561 m .67363 .33709 L .67168 .34273 L p
1 g
F P
s
P
p
.002 w
.44674 .24737 m .38744 .27473 L .38765 .26866 L p
1 g
F P
s
P
p
.002 w
.38765 .26866 m .44732 .24112 L .44674 .24737 L p
1 g
F P
s
P
p
.002 w
.62646 .57735 m .66441 .52948 L .67131 .52764 L p
1 g
F P
s
P
p
.002 w
.69244 .4677 m .67131 .52764 L .66441 .52948 L p
1 g
F P
s
P
p
.002 w
.67168 .34273 m .63137 .29159 L .63308 .28561 L p
1 g
F P
s
P
p
.002 w
.57748 .25007 m .63308 .28561 L .63137 .29159 L p
1 g
F P
s
P
p
.002 w
.31763 .38412 m .30951 .445 L .30357 .44009 L p
1 g
F P
s
P
p
.002 w
.30357 .44009 m .31194 .37696 L .31763 .38412 L p
1 g
F P
s
P
p
.002 w
.51212 .24094 m .44674 .24737 L .44732 .24112 L p
1 g
F P
s
P
p
.002 w
.44732 .24112 m .5131 .23464 L .51212 .24094 L p
1 g
F P
s
P
p
.002 w
.5131 .23464 m .57748 .25007 L .5761 .25627 L p
1 g
F P
s
P
p
.002 w
.63137 .29159 m .5761 .25627 L .57748 .25007 L p
1 g
F P
s
P
p
.002 w
.5761 .25627 m .51212 .24094 L .5131 .23464 L p
1 g
F P
s
P
p
.002 w
.66441 .52948 m .68476 .47166 L .69244 .4677 L p
1 g
F P
s
P
p
.002 w
.69271 .40373 m .69244 .4677 L .68476 .47166 L p
1 g
F P
s
P
p
.002 w
.40439 .59212 m .45706 .61397 L .45508 .62098 L p
1 g
F P
s
P
p
.002 w
.45508 .62098 m .39867 .59759 L .40439 .59212 L p
1 g
F P
s
P
p
.002 w
.51598 .62542 m .45508 .62098 L .45706 .61397 L p
1 g
F P
s
P
p
.002 w
.45706 .61397 m .51394 .61811 L .51598 .62542 L p
1 g
F P
s
P
p
.002 w
.57516 .6104 m .51598 .62542 L .51394 .61811 L p
1 g
F P
s
P
p
.002 w
.34554 .3289 m .31763 .38412 L .31194 .37696 L p
1 g
F P
s
P
p
.002 w
.31194 .37696 m .34084 .31968 L .34554 .3289 L p
1 g
F P
s
P
p
.002 w
.36138 .55474 m .40439 .59212 L .39867 .59759 L p
1 g
F P
s
P
p
.002 w
.39867 .59759 m .35259 .55757 L .36138 .55474 L p
1 g
F P
s
P
p
.002 w
.51394 .61811 m .56919 .60408 L .57516 .6104 L p
1 g
F P
s
P
p
.002 w
.62646 .57735 m .57516 .6104 L .56919 .60408 L p
1 g
F P
s
P
p
.002 w
.3326 .50558 m .36138 .55474 L .35259 .55757 L p
1 g
F P
s
P
p
.002 w
.35259 .55757 m .32171 .50491 L .3326 .50558 L p
1 g
F P
s
P
p
.002 w
.68476 .47166 m .68496 .40997 L .69271 .40373 L p
1 g
F P
s
P
p
.002 w
.67168 .34273 m .69271 .40373 L .68496 .40997 L p
1 g
F P
s
P
p
.002 w
.3905 .2856 m .34554 .3289 L .34084 .31968 L p
1 g
F P
s
P
p
.002 w
.34084 .31968 m .38744 .27473 L .3905 .2856 L p
1 g
F P
s
P
p
.002 w
.56919 .60408 m .61705 .57319 L .62646 .57735 L p
1 g
F P
s
P
p
.002 w
.66441 .52948 m .62646 .57735 L .61705 .57319 L p
1 g
F P
s
P
p
.002 w
.32128 .44968 m .3326 .50558 L .32171 .50491 L p
1 g
F P
s
P
p
.002 w
.32171 .50491 m .30951 .445 L .32128 .44968 L p
1 g
F P
s
P
p
.002 w
.68496 .40997 m .66464 .35117 L .67168 .34273 L p
1 g
F P
s
P
p
.002 w
.63137 .29159 m .67168 .34273 L .66464 .35117 L p
1 g
F P
s
P
p
.004 w
.67091 .30335 m
.6849 .29295 L
s
P
p
.002 w
.44769 .25926 m .3905 .2856 L .38744 .27473 L p
1 g
F P
s
P
p
.002 w
.38744 .27473 m .44674 .24737 L .44769 .25926 L p
1 g
F P
s
P
p
.002 w
.61705 .57319 m .65242 .52851 L .66441 .52948 L p
1 g
F P
s
P
p
.002 w
.68476 .47166 m .66441 .52948 L .65242 .52851 L p
1 g
F P
s
P
p
.002 w
.66464 .35117 m .62574 .30189 L .63137 .29159 L p
1 g
F P
s
P
p
.002 w
.5761 .25627 m .63137 .29159 L .62574 .30189 L p
1 g
F P
s
P
p
.002 w
.32892 .39294 m .32128 .44968 L .30951 .445 L p
1 g
F P
s
P
p
.002 w
.30951 .445 m .31763 .38412 L .32892 .39294 L p
1 g
F P
s
P
p
.002 w
.51074 .25308 m .44769 .25926 L .44674 .24737 L p
1 g
F P
s
P
p
.002 w
.44674 .24737 m .51212 .24094 L .51074 .25308 L p
1 g
F P
s
P
p
.002 w
.62574 .30189 m .57244 .26786 L .5761 .25627 L p
1 g
F P
s
P
p
.002 w
.51212 .24094 m .5761 .25627 L .57244 .26786 L p
1 g
F P
s
P
p
.002 w
.57244 .26786 m .51074 .25308 L .51212 .24094 L p
1 g
F P
s
P
p
.002 w
.65242 .52851 m .67132 .47457 L .68476 .47166 L p
1 g
F P
s
P
p
.002 w
.68496 .40997 m .68476 .47166 L .67132 .47457 L p
1 g
F P
s
P
p
.002 w
.41316 .58166 m .46039 .60127 L .45706 .61397 L p
1 g
F P
s
P
p
.002 w
.45706 .61397 m .40439 .59212 L .41316 .58166 L p
1 g
F P
s
P
p
.002 w
.51394 .61811 m .45706 .61397 L .46039 .60127 L p
1 g
F P
s
P
p
.002 w
.355 .34152 m .32892 .39294 L .31763 .38412 L p
1 g
F P
s
P
p
.002 w
.31763 .38412 m .34554 .3289 L .355 .34152 L p
1 g
F P
s
P
p
.002 w
.46039 .60127 m .5114 .60497 L .51394 .61811 L p
1 g
F P
s
P
p
.002 w
.56919 .60408 m .51394 .61811 L .5114 .60497 L p
1 g
F P
s
P
p
.002 w
.37463 .54812 m .41316 .58166 L .40439 .59212 L p
1 g
F P
s
P
p
.002 w
.40439 .59212 m .36138 .55474 L .37463 .54812 L p
1 g
F P
s
P
p
.002 w
.5114 .60497 m .56092 .59236 L .56919 .60408 L p
1 g
F P
s
P
p
.002 w
.61705 .57319 m .56919 .60408 L .56092 .59236 L p
1 g
F P
s
P
p
.002 w
.3489 .50405 m .37463 .54812 L .36138 .55474 L p
1 g
F P
s
P
p
.002 w
.36138 .55474 m .3326 .50558 L .3489 .50405 L p
1 g
F P
s
P
p
.002 w
.67132 .47457 m .67144 .41707 L .68496 .40997 L p
1 g
F P
s
P
p
.002 w
.66464 .35117 m .68496 .40997 L .67144 .41707 L p
1 g
F P
s
P
p
.002 w
.39694 .30122 m .355 .34152 L .34554 .3289 L p
1 g
F P
s
P
p
.002 w
.34554 .3289 m .3905 .2856 L .39694 .30122 L p
1 g
F P
s
P
p
.002 w
.56092 .59236 m .60379 .56464 L .61705 .57319 L p
1 g
F P
s
P
p
.002 w
.65242 .52851 m .61705 .57319 L .60379 .56464 L p
1 g
F P
s
P
p
.002 w
.33885 .45399 m .3489 .50405 L .3326 .50558 L p
1 g
F P
s
P
p
.002 w
.3326 .50558 m .32128 .44968 L .33885 .45399 L p
1 g
F P
s
P
p
.002 w
.67144 .41707 m .65243 .36231 L .66464 .35117 L p
1 g
F P
s
P
p
.002 w
.62574 .30189 m .66464 .35117 L .65243 .36231 L p
1 g
F P
s
P
p
.004 w
.65759 .31327 m
.67091 .30335 L
s
P
p
.002 w
.45025 .27674 m .39694 .30122 L .3905 .2856 L p
1 g
F P
s
P
p
.002 w
.3905 .2856 m .44769 .25926 L .45025 .27674 L p
1 g
F P
s
P
p
.002 w
.60379 .56464 m .6354 .52458 L .65242 .52851 L p
1 g
F P
s
P
p
.002 w
.67132 .47457 m .65242 .52851 L .6354 .52458 L p
1 g
F P
s
P
p
.002 w
.65243 .36231 m .61613 .31644 L .62574 .30189 L p
1 g
F P
s
P
p
.002 w
.57244 .26786 m .62574 .30189 L .61613 .31644 L p
1 g
F P
s
P
p
.002 w
.34577 .40323 m .33885 .45399 L .32128 .44968 L p
1 g
F P
s
P
p
.002 w
.32128 .44968 m .32892 .39294 L .34577 .40323 L p
1 g
F P
s
P
p
.002 w
.50898 .27101 m .45025 .27674 L .44769 .25926 L p
1 g
F P
s
P
p
.002 w
.44769 .25926 m .51074 .25308 L .50898 .27101 L p
1 g
F P
s
P
p
.002 w
.51074 .25308 m .57244 .26786 L .56645 .28478 L p
1 g
F P
s
P
p
.002 w
.61613 .31644 m .56645 .28478 L .57244 .26786 L p
1 g
F P
s
P
p
.002 w
.56645 .28478 m .50898 .27101 L .51074 .25308 L p
1 g
F P
s
P
p
.002 w
.6354 .52458 m .65223 .47628 L .67132 .47457 L p
1 g
F P
s
P
p
.002 w
.67144 .41707 m .67132 .47457 L .65223 .47628 L p
1 g
F P
s
P
p
.002 w
.42489 .56625 m .46504 .58294 L .46039 .60127 L p
1 g
F P
s
P
p
.002 w
.46039 .60127 m .41316 .58166 L .42489 .56625 L p
1 g
F P
s
P
p
.002 w
.5114 .60497 m .46039 .60127 L .46504 .58294 L p
1 g
F P
s
P
p
.002 w
.36919 .35729 m .34577 .40323 L .32892 .39294 L p
1 g
F P
s
P
p
.002 w
.32892 .39294 m .355 .34152 L .36919 .35729 L p
1 g
F P
s
P
p
.002 w
.46504 .58294 m .50842 .58608 L .5114 .60497 L p
1 g
F P
s
P
p
.002 w
.56092 .59236 m .5114 .60497 L .50842 .58608 L p
1 g
F P
s
P
p
.002 w
.39217 .53771 m .42489 .56625 L .41316 .58166 L p
1 g
F P
s
P
p
.002 w
.41316 .58166 m .37463 .54812 L .39217 .53771 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50842 .58608 m .55051 .57533 L .56092 .59236 L p
1 g
F P
s
P
p
.002 w
.60379 .56464 m .56092 .59236 L .55051 .57533 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.65223 .47628 m .65224 .42485 L .67144 .41707 L p
1 g
F P
s
P
p
.002 w
.65243 .36231 m .67144 .41707 L .65224 .42485 L p
1 g
F P
s
P
p
.002 w
.37037 .50024 m .39217 .53771 L .37463 .54812 L p
1 g
F P
s
P
p
.002 w
.37463 .54812 m .3489 .50405 L .37037 .50024 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.40674 .32134 m .36919 .35729 L .355 .34152 L p
1 g
F P
s
P
p
.002 w
.355 .34152 m .39694 .30122 L .40674 .32134 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.55051 .57533 m .58689 .55172 L .60379 .56464 L p
1 g
F P
s
P
p
.002 w
.6354 .52458 m .60379 .56464 L .58689 .55172 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.36193 .45773 m .37037 .50024 L .3489 .50405 L p
1 g
F P
s
P
p
.002 w
.3489 .50405 m .33885 .45399 L .36193 .45773 L p
1 g
F P
s
P
p
.002 w
.65224 .42485 m .63515 .37592 L .65243 .36231 L p
1 g
F P
s
P
p
.002 w
.61613 .31644 m .65243 .36231 L .63515 .37592 L p
1 g
F P
s
P
p
.004 w
.64106 .32556 m
.65759 .31327 L
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.45441 .29952 m .40674 .32134 L .39694 .30122 L p
1 g
F P
s
P
p
.002 w
.39694 .30122 m .45025 .27674 L .45441 .29952 L p
1 g
F P
s
P
p
.002 w
.58689 .55172 m .61367 .51766 L .6354 .52458 L p
1 g
F P
s
P
p
.002 w
.65223 .47628 m .6354 .52458 L .61367 .51766 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.36791 .4147 m .36193 .45773 L .33885 .45399 L p
1 g
F P
s
P
p
.002 w
.33885 .45399 m .34577 .40323 L .36791 .4147 L p
1 g
F P
s
P
p
.002 w
.63515 .37592 m .60265 .33498 L .61613 .31644 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.61221 .34703 L
s
P
p
.004 w
.62529 .33729 m
.62629 .33655 L
s
P
p
.004 w
.62629 .33655 m
.63127 .33285 L
s
P
p
.004 w
.63127 .33285 m
.64106 .32556 L
s
P
p
.002 w
.56645 .28478 m .61613 .31644 L .60265 .33498 L p
1 g
F P
s
P
p
.002 w
.50689 .29444 m .45441 .29952 L .45025 .27674 L p
1 g
F P
s
P
p
.002 w
.45025 .27674 m .50898 .27101 L .50689 .29444 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.50898 .27101 m .56645 .28478 L .55824 .30673 L p
1 g
F P
s
P
p
.002 w
.60265 .33498 m .55824 .30673 L .56645 .28478 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.55824 .30673 m .50689 .29444 L .50898 .27101 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.61367 .51766 m .62785 .47665 L .65223 .47628 L p
1 g
F P
s
P
p
.002 w
.65224 .42485 m .65223 .47628 L .62785 .47665 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.38785 .37582 m .36791 .4147 L .34577 .40323 L p
1 g
F P
s
P
p
.002 w
.34577 .40323 m .36919 .35729 L .38785 .37582 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.46504 .58294 m .45055 .56223 L .45099 .56254 L 1 g
F
P
p
.002 w
.46725 .57403 m .4658 .57987 L p
.45099 .56254 L 1 g
F P
s
P
p
.002 w
.4658 .57987 m .46504 .58294 L p
.45099 .56254 L 1 g
F P
s
P
p
.002 w
.45099 .56254 m .45146 .56129 L p
.44547 .55609 L 1 g
F P
s
P
p
.46872 .57265 m .46084 .5695 L .46725 .57403 L 1 g
F
P
p
.002 w
.48687 .58452 m .46504 .58294 L .46719 .5743 L p
1 g
F P
s
P
p
.002 w
.46719 .5743 m .46725 .57403 L p
.4683 .57459 L 1 g
F P
s
P
p
.48687 .58452 m .46719 .5743 L .4683 .57459 L 1 g
F
P
p
.002 w
.4891 .58012 m .48921 .57862 L p
.48089 .57794 L 1 g
F P
s
P
p
.002 w
.50842 .58608 m .48687 .58452 L p
.48393 .57988 L 1 g
F P
s
P
p
.50842 .58608 m .48393 .57988 L .48831 .58008 L 1 g
F
P
p
.51079 .57862 m .50065 .58065 L .50771 .58097 L 1 g
F
P
p
.002 w
.5406 .57786 m .50842 .58608 L .50781 .58167 L p
1 g
F P
s
P
p
.002 w
.50781 .58167 m .50771 .58097 L p
.51094 .58067 L 1 g
F P
s
P
p
.5406 .57786 m .50781 .58167 L .51094 .58067 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58067 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58067 L .52344 .57667 L 1 g
F
P
p
.002 w
.51094 .58067 m .51079 .57862 L p
.50771 .58097 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58012 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58012 L .50065 .58065 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57459 L p
1 g
F P
s
P
p
.48921 .57862 m .4683 .57459 L .48089 .57794 L 1 g
F
P
p
.50081 .58066 m .48306 .57852 L .47091 .55933 L 1 g
F
P
p
.50656 .58476 m .4891 .58012 L .50081 .58066 L 1 g
F
P
p
.4891 .58012 m .48306 .57852 L .50081 .58066 L 1 g
F
P
p
.50842 .58608 m .48306 .57852 L .50656 .58476 L 1 g
F
P
p
.002 w
.4891 .58012 m .48889 .583 L p
.50065 .58065 L 1 g
F P
s
P
p
.002 w
.53159 .57407 m .53128 .57265 L p
.52344 .57667 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53159 .57407 L p
1 g
F P
s
P
p
.53196 .57395 m .53162 .57405 L .53186 .5739 L 1 g
F
P
p
.5406 .57786 m .51094 .58067 L .53196 .57395 L 1 g
F
P
p
.54854 .56129 m .53159 .57407 L .54109 .56839 L 1 g
F
P
p
.51094 .58067 m .50771 .58097 L .53196 .57395 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55051 .57533 m .5406 .57786 L p
.53186 .5739 L 1 g
F P
s
P
p
.53648 .57115 m .53186 .5739 L .50507 .56179 L 1 g
F
P
p
.55051 .57533 m .53186 .5739 L .53648 .57115 L 1 g
F
P
p
.54854 .56129 m .54109 .56839 L .54525 .56591 L 1 g
F
P
p
.58689 .55172 m .54731 .5652 L .56224 .55252 L 1 g
F
P
p
.54731 .5652 m .54525 .56591 L .54912 .56285 L 1 g
F
P
p
.54731 .5652 m .54912 .56285 L .56224 .55252 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54912 .56285 L p
1 g
F P
s
P
p
.002 w
.58689 .55172 m .55051 .57533 L .54525 .56591 L p
1 g
F P
s
P
p
.56075 .54566 m .54912 .56285 L .55665 .5531 L 1 g
F
P
p
.002 w
.54912 .56285 m .54854 .56129 L p
.54525 .56591 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56142 .54692 m .56075 .54566 L p
.55665 .5531 L 1 g
F P
s
P
p
.002 w
.54525 .56591 m .5382 .55329 L p
.55697 .55269 L 1 g
F P
s
P
p
.56224 .55252 m .54912 .56285 L .55697 .55269 L 1 g
F
P
p
.54912 .56285 m .54525 .56591 L .55697 .55269 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56678 .53467 m .58689 .55172 L p
.55924 .55261 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56142 .54692 L p
1 g
F P
s
P
p
.56654 .52734 m .56142 .54692 L .56438 .53915 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56586 .53527 m .56678 .53467 L p
.55924 .55261 L 1 g
F P
s
P
p
.002 w
.61367 .51766 m .58689 .55172 L .56678 .53467 L p
1 g
F P
s
P
p
.002 w
.56678 .53467 m .58776 .50785 L .61367 .51766 L p
1 g
F P
s
P
p
.002 w
.56678 .53467 m .56586 .53527 L p
.56609 .53454 L 1 g
F P
s
P
p
.56654 .52734 m .56397 .54142 L .56621 .53415 L 1 g
F
P
p
.58776 .50785 m .56781 .53219 L .57217 .51002 L 1 g
F
P
p
.56781 .53219 m .56621 .53415 L .56753 .52879 L 1 g
F
P
p
.56781 .53219 m .56753 .52879 L .57217 .51002 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56753 .52879 L p
1 g
F P
s
P
p
.56515 .50826 m .56753 .52879 L .56665 .518 L 1 g
F
P
p
.002 w
.56753 .52879 m .56654 .52734 L p
.56621 .53415 L 1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56593 .50919 m .56515 .50826 L p
.56665 .518 L 1 g
F P
s
P
p
.002 w
.56621 .53415 m .54406 .51393 L p
.56607 .51087 L 1 g
F P
s
P
p
.57217 .51002 m .56753 .52879 L .56607 .51087 L 1 g
F
P
p
.56753 .52879 m .56621 .53415 L .56607 .51087 L 1 g
F
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56593 .50919 L p
1 g
F P
s
P
p
.55661 .4905 m .56593 .50919 L .56218 .50115 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55973 .49592 m .58776 .50785 L p
.56668 .51078 L 1 g
F P
s
P
p
.002 w
.59881 .47562 m .58776 .50785 L .55973 .49592 L p
1 g
F P
s
P
p
.59881 .47562 m .55973 .49592 L .55929 .49499 L 1 g
F
P
p
.55661 .4905 m .56316 .50304 L .55889 .49417 L 1 g
F
P
p
.002 w
.56602 .47315 m .55924 .49314 L p
.54989 .47625 L 1 g
F P
s
P
p
.002 w
.55924 .49314 m .55889 .49417 L p
.55755 .4915 L 1 g
F P
s
P
p
.55924 .49314 m .55755 .4915 L .54989 .47625 L 1 g
F
P
p
.002 w
.55755 .4915 m .55661 .4905 L p
.55889 .49417 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55755 .4915 L p
1 g
F P
s
P
p
.002 w
.55766 .49162 m .55755 .4915 L p
.55889 .49417 L 1 g
F P
s
P
p
.54174 .47608 m .55755 .4915 L .55003 .4842 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55848 .49539 m .52684 .48067 L p
.54317 .47754 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54174 .47608 L p
.55003 .4842 L 1 g
F P
s
P
p
.54989 .47625 m .55611 .4901 L .54317 .47754 L 1 g
F
P
p
.55611 .4901 m .55848 .49539 L .54317 .47754 L 1 g
F
P
p
.002 w
.55889 .49417 m .55848 .49539 L p
.54989 .47625 L 1 g
F P
s
P
p
.002 w
.56602 .47315 m .59881 .47562 L p
.55929 .49499 L 1 g
F P
s
P
p
.002 w
.55848 .49539 m .55889 .49417 L p
.55929 .49499 L 1 g
F P
s
P
p
.002 w
.55889 .49417 m .56602 .47315 L p
.55929 .49499 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55766 .49162 L p
1 g
F P
s
P
p
.56316 .50304 m .56713 .51061 L .55766 .49162 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54232 .47671 L p
1 g
F P
s
P
p
.002 w
.53065 .46932 m .56602 .47315 L p
.54382 .47741 L 1 g
F P
s
P
p
.002 w
.52684 .48067 m .53009 .47099 L p
.54382 .47741 L 1 g
F P
s
P
p
.52214 .46667 m .54232 .47671 L .53418 .4729 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.52684 .48067 m .49507 .46476 L p
.52516 .46856 L 1 g
F P
s
P
p
.002 w
.49631 .46455 m .52516 .46856 L p
.49507 .46476 L 1 g
F P
s
P
p
.002 w
.49775 .49982 m .48566 .49896 L .49387 .46494 L p
1 g
F P
s
P
p
.002 w
.51951 .49017 m .50945 .49679 L .49434 .46487 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49404 .46424 m .5305 .45733 L .53052 .45887 L p
1 g
F P
s
P
p
.52214 .46667 m .5384 .47509 L .52516 .46856 L 1 g
F
P
p
.002 w
.52516 .46856 m .49631 .46455 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .51179 .46567 L 1 g
F
P
p
.52248 .46723 m .52516 .46856 L .5 .46394 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46394 L p
1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .4634 L p
.51179 .46567 L 1 g
F P
s
P
p
.51179 .46567 m .52282 .46778 L .5 .46394 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46394 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46394 L .49956 .46401 L 1 g
F
P
p
.47786 .46667 m .5 .46396 L .49947 .46404 L 1 g
F
P
p
.47786 .46667 m .5 .46398 L .4993 .46409 L 1 g
F
P
p
.47786 .46667 m .5 .46401 L .49917 .46413 L 1 g
F
P
p
.47786 .46667 m .5 .46403 L .49911 .46417 L 1 g
F
P
p
.002 w
.52684 .48067 m .51951 .49017 L .49462 .46483 L p
1 g
F P
s
P
p
.002 w
.49507 .46476 m .52684 .48067 L p
.49462 .46483 L 1 g
F P
s
P
p
.002 w
.49462 .46483 m .51951 .49017 L p
.49434 .46487 L 1 g
F P
s
P
p
.002 w
.50945 .49679 m .49775 .49982 L .49411 .46491 L p
1 g
F P
s
P
p
.002 w
.49434 .46487 m .50945 .49679 L p
.49411 .46491 L 1 g
F P
s
P
p
.002 w
.49411 .46491 m .49775 .49982 L p
.49387 .46494 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46406 L .49355 .46499 L 1 g
F
P
p
.002 w
.46543 .48631 m .45951 .47596 L p
.49057 .4654 L 1 g
F P
s
P
p
.002 w
.46022 .47562 m .49057 .4654 L p
.45951 .47596 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.46543 .48631 m .43829 .50636 L p
.45935 .47604 L 1 g
F P
s
P
p
.002 w
.45951 .47596 m .46543 .48631 L p
.45935 .47604 L 1 g
F P
s
P
p
.45826 .47608 m .46851 .47159 L .45951 .47596 L 1 g
F
P
p
.47786 .46667 m .49355 .46499 L .4923 .46517 L 1 g
F
P
p
.002 w
.49295 .46507 m .46543 .48631 L p
.49057 .4654 L 1 g
F P
s
P
p
.49132 .4653 m .4923 .46517 L .4914 .46529 L 1 g
F
P
p
.47786 .46667 m .4923 .46517 L .49132 .4653 L 1 g
F
P
p
.002 w
.49057 .4654 m .46022 .47562 L p
.47755 .46719 L 1 g
F P
s
P
p
.002 w
.47724 .46769 m .47755 .46719 L p
.49249 .46518 L 1 g
F P
s
P
p
.002 w
.47755 .46719 m .47786 .46667 L p
.49132 .4653 L 1 g
F P
s
P
p
.49132 .4653 m .49249 .46518 L .47755 .46719 L 1 g
F
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4837 .4642 m .49404 .46424 L .49057 .4654 L p
1 g
F P
s
P
p
.47755 .46719 m .4837 .4642 L .49057 .4654 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.45723 .4641 m .4837 .4642 L p
.47746 .4672 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45946 .47587 m .45832 .46983 L p
.47746 .4672 L 1 g
F P
s
P
p
.002 w
.45832 .46983 m .45723 .4641 L p
.47746 .4672 L 1 g
F P
s
P
p
.46851 .47159 m .46022 .47562 L .45951 .47596 L 1 g
F
P
p
.002 w
.46022 .47562 m .45946 .47587 L p
.4837 .4642 L 1 g
F P
s
P
p
.46851 .47159 m .4686 .47155 L .46022 .47562 L 1 g
F
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.42655 .48597 m .43663 .50348 L p
.41359 .52367 L 1 g
F P
s
P
p
.43485 .50826 m .43865 .49938 L .43663 .50348 L 1 g
F
P
p
.43485 .50826 m .43663 .50348 L .43563 .50562 L 1 g
F
P
p
.002 w
.43382 .50949 m .43485 .50826 L p
.43571 .50535 L 1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43382 .50949 L p
1 g
F P
s
P
p
.002 w
.432 .53977 m .42342 .53227 L p
.43036 .52018 L 1 g
F P
s
P
p
.43268 .52848 m .43036 .52018 L .4335 .51469 L 1 g
F
P
p
.432 .53977 m .43036 .52018 L .43268 .52848 L 1 g
F
P
p
.43925 .54566 m .43528 .53781 L .43707 .5442 L 1 g
F
P
p
.002 w
.43824 .54765 m .42489 .56625 L p
.43655 .54515 L 1 g
F P
s
P
p
.43655 .54515 m .43707 .5442 L .43822 .5476 L 1 g
F
P
p
.43655 .54515 m .43822 .5476 L .43824 .54765 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43822 .5476 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45099 .56254 L p
1 g
F P
s
P
p
.46504 .58294 m .43544 .55155 L .4479 .56036 L 1 g
F
P
p
.46504 .58294 m .43825 .54764 L .44975 .56109 L 1 g
F
P
p
.002 w
.45099 .56254 m .45002 .56518 L p
.46084 .5695 L 1 g
F P
s
P
p
.46872 .57265 m .45099 .56254 L .46084 .5695 L 1 g
F
P
p
.002 w
.46504 .58294 m .42489 .56625 L .43544 .55155 L p
1 g
F P
s
P
p
.002 w
.43544 .55155 m .43825 .54764 L p
.4479 .56036 L 1 g
F P
s
P
p
.45146 .56129 m .43822 .5476 L .43825 .54764 L 1 g
F
P
p
.45146 .56129 m .43825 .54764 L .44547 .55609 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.45099 .56254 m .43931 .54617 L .46725 .57403 L 1 g
F
P
p
.45055 .56223 m .44975 .56109 L .45099 .56254 L 1 g
F
P
p
.44975 .56109 m .43931 .54617 L .45099 .56254 L 1 g
F
P
p
.44547 .55609 m .43825 .54764 L .4419 .55299 L 1 g
F
P
p
.002 w
.43825 .54764 m .43931 .54617 L p
.44975 .56109 L 1 g
F P
s
P
p
.4419 .55299 m .43825 .54764 L .43743 .5491 L 1 g
F
P
p
.002 w
.43822 .5476 m .43925 .54566 L p
.43707 .5442 L 1 g
F P
s
P
p
.002 w
.43707 .5442 m .43931 .54617 L .43824 .54765 L p
1 g
F P
s
P
p
.002 w
.43822 .5476 m .43822 .5476 L p
.43825 .54764 L 1 g
F P
s
P
p
.002 w
.43822 .5476 m .43743 .5491 L p
.43825 .54764 L 1 g
F P
s
P
p
.002 w
.43809 .54785 m .43822 .5476 L p
.43707 .5442 L 1 g
F P
s
P
p
.002 w
.41359 .52367 m .43707 .5442 L p
.42489 .56625 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43268 .52848 L p
1 g
F P
s
P
p
.43925 .54566 m .43268 .52848 L .43528 .53781 L 1 g
F
P
p
.002 w
.43931 .54617 m .43707 .5442 L p
.43829 .50636 L 1 g
F P
s
P
p
.002 w
.43707 .5442 m .432 .53977 L p
.43354 .53158 L 1 g
F P
s
P
p
.43707 .5442 m .43354 .53158 L .43829 .50636 L 1 g
F
P
p
.43346 .52734 m .43382 .50949 L .4332 .51979 L 1 g
F
P
p
.002 w
.42342 .53227 m .41359 .52367 L .43382 .50949 L p
1 g
F P
s
P
p
.002 w
.43382 .50949 m .43829 .50636 L p
.42342 .53227 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43268 .52848 L p
1 g
F P
s
P
p
.002 w
.43268 .52848 m .43346 .52734 L p
.4332 .51979 L 1 g
F P
s
P
p
.4332 .51979 m .43287 .51061 L .43268 .52848 L 1 g
F
P
p
.432 .53977 m .4335 .51469 L .43829 .50636 L 1 g
F
P
p
.002 w
.43268 .52848 m .43146 .53025 L p
.43528 .53781 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43809 .54785 L p
1 g
F P
s
P
p
.43528 .53781 m .43146 .53025 L .43809 .54785 L 1 g
F
P
p
.002 w
.43382 .50949 m .43287 .51061 L p
.4332 .51979 L 1 g
F P
s
P
p
.44262 .49132 m .42889 .49004 L .44746 .4815 L 1 g
F
P
p
.002 w
.43663 .50348 m .43428 .4994 L p
.44262 .49132 L 1 g
F P
s
P
p
.002 w
.43428 .4994 m .42889 .49004 L p
.44262 .49132 L 1 g
F P
s
P
p
.002 w
.44325 .49079 m .44166 .49233 L p
.43485 .50826 L 1 g
F P
s
P
p
.002 w
.44332 .49064 m .44339 .4905 L p
.44262 .49132 L 1 g
F P
s
P
p
.002 w
.44262 .49132 m .44339 .4905 L p
.45027 .48391 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.43663 .50348 m .44262 .49132 L .45935 .47604 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45754 .47687 L p
1 g
F P
s
P
p
.44339 .4905 m .45754 .47687 L .45027 .48391 L 1 g
F
P
p
.44262 .49132 m .44746 .4815 L .45754 .47687 L 1 g
F
P
p
.44262 .49132 m .45754 .47687 L .45935 .47604 L 1 g
F
P
p
.002 w
.45754 .47687 m .45698 .47747 L p
.45027 .48391 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44262 .49132 L p
1 g
F P
s
P
p
.45027 .48391 m .45698 .47747 L .44262 .49132 L 1 g
F
P
p
.002 w
.43663 .50348 m .43829 .50636 L .43382 .50949 L p
1 g
F P
s
P
p
.002 w
.43382 .50949 m .41359 .52367 L p
.43663 .50348 L 1 g
F P
s
P
p
.43563 .50562 m .43663 .50348 L .43571 .50535 L 1 g
F
P
p
.002 w
.43345 .50993 m .43382 .50949 L p
.43571 .50535 L 1 g
F P
s
P
p
.002 w
.43829 .50636 m .43663 .50348 L p
.45935 .47604 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43345 .50993 L p
1 g
F P
s
P
p
.43865 .49938 m .44166 .49233 L .43345 .50993 L 1 g
F
P
p
.002 w
.45745 .47696 m .45754 .47687 L p
.45951 .47596 L 1 g
F P
s
P
p
.002 w
.45754 .47687 m .45826 .47608 L p
.45951 .47596 L 1 g
F P
s
P
p
.002 w
.42655 .48597 m .45946 .47587 L p
.45935 .47604 L 1 g
F P
s
P
p
.002 w
.42889 .49004 m .42655 .48597 L p
.45935 .47604 L 1 g
F P
s
P
p
.002 w
.45946 .47587 m .45951 .47596 L p
.45935 .47604 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .45745 .47696 L p
.46734 .47236 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .47451 .46907 L p
.46734 .47236 L 1 g
F P
s
P
p
.002 w
.47451 .46907 m .45698 .47747 L p
.46734 .47236 L 1 g
F P
s
P
p
.4686 .47155 m .47718 .46778 L .45745 .47696 L 1 g
F
P
p
.002 w
.45951 .47596 m .45946 .47587 L .46022 .47562 L p
1 g
F P
s
P
p
.002 w
.49057 .4654 m .49404 .46424 L .49295 .46507 L p
1 g
F P
s
P
p
.4914 .46529 m .49295 .46507 L .49158 .46527 L 1 g
F
P
p
.002 w
.49355 .46499 m .47449 .49429 L p
.49295 .46507 L 1 g
F P
s
P
p
.49295 .46507 m .49355 .46499 L .49331 .46502 L 1 g
F
P
p
.49295 .46507 m .49331 .46502 L .49158 .46527 L 1 g
F
P
p
.002 w
.47449 .49429 m .46543 .48631 L .49295 .46507 L p
1 g
F P
s
P
p
.002 w
.49295 .46507 m .49404 .46424 L .49355 .46499 L p
1 g
F P
s
P
p
.002 w
.49631 .46455 m .49404 .46424 L p
.49803 .46365 L 1 g
F P
s
P
p
.53052 .45887 m .5 .46394 L .49803 .46365 L 1 g
F
P
p
.5 .46394 m .49631 .46455 L .49803 .46365 L 1 g
F
P
p
.51183 .46197 m .52248 .46723 L .5 .46394 L 1 g
F
P
p
.002 w
.52248 .46723 m .52282 .46778 L p
.51179 .46567 L 1 g
F P
s
P
p
.002 w
.52248 .46724 m .52248 .46723 L p
.52516 .46856 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.52516 .46856 L 1 g
F P
s
P
p
.002 w
.53052 .45887 m .53065 .46932 L .52516 .46856 L p
1 g
F P
s
P
p
.53052 .45887 m .52516 .46856 L .51183 .46197 L 1 g
F
P
p
.002 w
.5 .46394 m .5 .46396 L p
.49956 .46401 L 1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .46398 L p
.49947 .46404 L 1 g
F P
s
P
p
.002 w
.49462 .46483 m .49404 .46424 L .49507 .46476 L p
1 g
F P
s
P
p
.002 w
.49434 .46487 m .49404 .46424 L .49462 .46483 L p
1 g
F P
s
P
p
.002 w
.5 .46398 m .5 .46401 L p
.4993 .46409 L 1 g
F P
s
P
p
.002 w
.5 .46401 m .5 .46403 L p
.49917 .46413 L 1 g
F P
s
P
p
.002 w
.49411 .46491 m .49404 .46424 L .49434 .46487 L p
1 g
F P
s
P
p
.002 w
.49387 .46494 m .49404 .46424 L .49411 .46491 L p
1 g
F P
s
P
p
.002 w
.5 .46403 m .5 .46406 L p
.49911 .46417 L 1 g
F P
s
P
p
.002 w
.48566 .49896 m .47449 .49429 L .49355 .46499 L p
1 g
F P
s
P
p
.002 w
.49387 .46494 m .48566 .49896 L p
.49355 .46499 L 1 g
F P
s
P
p
.002 w
.5 .46406 m .5 .46442 L p
.49158 .46527 L 1 g
F P
s
P
p
.002 w
.49355 .46499 m .49404 .46424 L .49387 .46494 L p
1 g
F P
s
P
p
.002 w
.49507 .46476 m .49404 .46424 L .49631 .46455 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47724 .46769 L p
1 g
F P
s
P
p
.49249 .46518 m .5 .46442 L .47724 .46769 L 1 g
F
P
p
.002 w
.53009 .47099 m .52684 .48067 L p
.52516 .46856 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52248 .46724 L p
1 g
F P
s
P
p
.5384 .47509 m .54302 .47747 L .52248 .46724 L 1 g
F
P
p
.002 w
.52516 .46856 m .53065 .46932 L .53009 .47099 L p
1 g
F P
s
P
p
.002 w
.53009 .47099 m .53065 .46932 L p
.54382 .47741 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54302 .47747 L p
.53418 .4729 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54232 .47671 L p
1 g
F P
s
P
p
.55003 .4842 m .55834 .49233 L .54232 .47671 L 1 g
F
P
p
.002 w
.55755 .4915 m .55834 .49233 L p
.55003 .4842 L 1 g
F P
s
P
p
.002 w
.55973 .49592 m .55848 .49539 L p
.55929 .49499 L 1 g
F P
s
P
p
.002 w
.54406 .51393 m .55848 .49539 L .55973 .49592 L p
1 g
F P
s
P
p
.56668 .51078 m .54406 .51393 L .55973 .49592 L 1 g
F
P
p
.002 w
.56593 .50919 m .56713 .51061 L p
.56218 .50115 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56593 .50919 L p
1 g
F P
s
P
p
.56665 .518 m .56854 .53025 L .56593 .50919 L 1 g
F
P
p
.002 w
.56753 .52879 m .56854 .53025 L p
.56665 .518 L 1 g
F P
s
P
p
.002 w
.56776 .52912 m .56753 .52879 L p
.56621 .53415 L 1 g
F P
s
P
p
.002 w
.58776 .50785 m .56678 .53467 L .56621 .53415 L p
1 g
F P
s
P
p
.002 w
.52435 .52683 m .54406 .51393 L .56678 .53467 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56776 .52912 L p
1 g
F P
s
P
p
.56397 .54142 m .56257 .5491 L .56776 .52912 L 1 g
F
P
p
.002 w
.5382 .55329 m .52435 .52683 L p
.56609 .53454 L 1 g
F P
s
P
p
.002 w
.56586 .53527 m .5382 .55329 L p
.56609 .53454 L 1 g
F P
s
P
p
.002 w
.5382 .55329 m .56586 .53527 L p
.55924 .55261 L 1 g
F P
s
P
p
.002 w
.56142 .54692 m .56257 .5491 L p
.56438 .53915 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56142 .54692 L p
1 g
F P
s
P
p
.55665 .5531 m .54998 .56518 L .56142 .54692 L 1 g
F
P
p
.002 w
.54912 .56285 m .54998 .56518 L p
.55665 .5531 L 1 g
F P
s
P
p
.002 w
.54935 .56346 m .54912 .56285 L p
.54525 .56591 L 1 g
F P
s
P
p
.002 w
.50507 .56179 m .5382 .55329 L .55051 .57533 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54935 .56346 L p
1 g
F P
s
P
p
.54109 .56839 m .5322 .57686 L .54935 .56346 L 1 g
F
P
p
.002 w
.53159 .57407 m .5322 .57686 L p
.54109 .56839 L 1 g
F P
s
P
p
.002 w
.50771 .58097 m .50507 .56179 L p
.53186 .5739 L 1 g
F P
s
P
p
.53162 .57405 m .50771 .58097 L .53186 .5739 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53159 .57407 L p
1 g
F P
s
P
p
.52344 .57667 m .51111 .583 L .53159 .57407 L 1 g
F
P
p
.002 w
.51094 .58067 m .51111 .583 L p
.52344 .57667 L 1 g
F P
s
P
p
.002 w
.51098 .58112 m .51094 .58067 L p
.50771 .58097 L 1 g
F P
s
P
p
.002 w
.47091 .55933 m .50507 .56179 L .50842 .58608 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58112 L p
1 g
F P
s
P
p
.50065 .58065 m .48889 .583 L .51098 .58112 L 1 g
F
P
p
.48831 .58008 m .48393 .57988 L .48306 .57852 L 1 g
F
P
p
.002 w
.4683 .57459 m .46872 .57265 L p
.46725 .57403 L 1 g
F P
s
P
p
.002 w
.46725 .57403 m .47091 .55933 L p
.48687 .58452 L 1 g
F P
s
P
p
.002 w
.4683 .57459 m .4678 .57686 L p
.48089 .57794 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58012 L p
1 g
F P
s
P
p
.48089 .57794 m .4678 .57686 L .4891 .58012 L 1 g
F
P
p
.002 w
.46826 .57475 m .4683 .57459 L p
.46725 .57403 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45099 .56254 L p
1 g
F P
s
P
p
.44547 .55609 m .43743 .5491 L .45099 .56254 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46826 .57475 L p
1 g
F P
s
P
p
.46084 .5695 m .45002 .56518 L .46826 .57475 L 1 g
F
P
p
.002 w
.43931 .54617 m .47091 .55933 L .46725 .57403 L p
1 g
F P
s
P
p
.002 w
.42489 .56625 m .39217 .53771 L .41359 .52367 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.62785 .47665 m .62774 .43306 L .65224 .42485 L p
1 g
F P
s
P
p
.002 w
.63515 .37592 m .65224 .42485 L .62774 .43306 L p
1 g
F P
s
P
p
.002 w
.39651 .49417 m .41359 .52367 L .39217 .53771 L p
1 g
F P
s
P
p
.002 w
.39217 .53771 m .37037 .50024 L .39651 .49417 L p
1 g
F P
s
P
p
.002 w
.41972 .34545 m .38785 .37582 L .36919 .35729 L p
1 g
F P
s
P
p
.002 w
.36919 .35729 m .40674 .32134 L .41972 .34545 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.38997 .46076 m .39651 .49417 L .37037 .50024 L p
1 g
F P
s
P
p
.002 w
.37037 .50024 m .36193 .45773 L .38997 .46076 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.62774 .43306 m .61317 .39165 L .63515 .37592 L p
1 g
F P
s
P
p
.002 w
.60265 .33498 m .63515 .37592 L .61317 .39165 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4601 .32704 m .41972 .34545 L .40674 .32134 L p
1 g
F P
s
P
p
.002 w
.40674 .32134 m .45441 .29952 L .4601 .32704 L p
1 g
F P
s
P
p
.002 w
.62785 .47665 m .61367 .51766 L .58776 .50785 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.39476 .42699 m .38997 .46076 L .36193 .45773 L p
1 g
F P
s
P
p
.002 w
.36193 .45773 m .36791 .4147 L .39476 .42699 L p
1 g
F P
s
P
p
.002 w
.61317 .39165 m .58559 .35704 L .60265 .33498 L p
1 g
F P
s
P
p
.002 w
.55824 .30673 m .60265 .33498 L .58559 .35704 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.50452 .32277 m .4601 .32704 L .45441 .29952 L p
1 g
F P
s
P
p
.002 w
.45441 .29952 m .50689 .29444 L .50452 .32277 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.50689 .29444 m .55824 .30673 L .54798 .33316 L p
1 g
F P
s
P
p
.002 w
.58559 .35704 m .54798 .33316 L .55824 .30673 L p
1 g
F P
s
P
p
.002 w
.54798 .33316 m .50452 .32277 L .50689 .29444 L p
1 g
F P
s
P
p
.002 w
.58776 .50785 m .59881 .47562 L .62785 .47665 L p
1 g
F P
s
P
p
.002 w
.62774 .43306 m .62785 .47665 L .59881 .47562 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.41048 .39655 m .39476 .42699 L .36791 .4147 L p
1 g
F P
s
P
p
.002 w
.36791 .4147 m .38785 .37582 L .41048 .39655 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.45603 .52192 m .47786 .53103 L .47091 .55933 L p
1 g
F P
s
P
p
.002 w
.47091 .55933 m .43931 .54617 L .45603 .52192 L p
1 g
F P
s
P
p
.002 w
.50507 .56179 m .47091 .55933 L .47786 .53103 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.47786 .53103 m .50148 .53273 L .50507 .56179 L p
1 g
F P
s
P
p
.002 w
.5382 .55329 m .50507 .56179 L .50148 .53273 L p
1 g
F P
s
P
p
.002 w
.43829 .50636 m .45603 .52192 L .43931 .54617 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.50148 .53273 m .52435 .52683 L .5382 .55329 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.59881 .47562 m .59862 .44142 L .62774 .43306 L p
1 g
F P
s
P
p
.002 w
.61317 .39165 m .62774 .43306 L .59862 .44142 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.41359 .52367 m .39651 .49417 L .42655 .48597 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43552 .37281 m .41048 .39655 L .38785 .37582 L p
1 g
F P
s
P
p
.002 w
.38785 .37582 m .41972 .34545 L .43552 .37281 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.4221 .46291 m .42655 .48597 L .39651 .49417 L p
1 g
F P
s
P
p
.002 w
.39651 .49417 m .38997 .46076 L .4221 .46291 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.59862 .44142 m .58711 .40899 L .61317 .39165 L p
1 g
F P
s
P
p
.002 w
.58559 .35704 m .61317 .39165 L .58711 .40899 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46717 .35846 m .43552 .37281 L .41972 .34545 L p
1 g
F P
s
P
p
.002 w
.41972 .34545 m .4601 .32704 L .46717 .35846 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42548 .43967 m .4221 .46291 L .38997 .46076 L p
1 g
F P
s
P
p
.002 w
.38997 .46076 m .39476 .42699 L .42548 .43967 L p
1 g
F P
s
P
p
.002 w
.58711 .40899 m .56545 .38193 L .58559 .35704 L p
1 g
F P
s
P
p
.002 w
.54798 .33316 m .58559 .35704 L .56545 .38193 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.50195 .35514 m .46717 .35846 L .4601 .32704 L p
1 g
F P
s
P
p
.002 w
.4601 .32704 m .50452 .32277 L .50195 .35514 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.59862 .44142 m .59881 .47562 L .56602 .47315 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.50452 .32277 m .54798 .33316 L .53597 .36327 L p
1 g
F P
s
P
p
.002 w
.56545 .38193 m .53597 .36327 L .54798 .33316 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53597 .36327 m .50195 .35514 L .50452 .32277 L p
1 g
F P
s
P
p
.002 w
.43637 .41876 m .42548 .43967 L .39476 .42699 L p
1 g
F P
s
P
p
.002 w
.39476 .42699 m .41048 .39655 L .43637 .41876 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.47449 .49429 m .48566 .49896 L .47786 .53103 L p
1 g
F P
s
P
p
.002 w
.47786 .53103 m .45603 .52192 L .47449 .49429 L p
1 g
F P
s
P
p
.002 w
.50148 .53273 m .47786 .53103 L .48566 .49896 L p
1 g
F P
s
P
p
.002 w
.48566 .49896 m .49775 .49982 L .50148 .53273 L p
1 g
F P
s
P
p
.002 w
.52435 .52683 m .50148 .53273 L .49775 .49982 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46543 .48631 m .47449 .49429 L .45603 .52192 L p
1 g
F P
s
P
p
.002 w
.45603 .52192 m .43829 .50636 L .46543 .48631 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49775 .49982 m .50945 .49679 L .52435 .52683 L p
1 g
F P
s
P
p
.002 w
.54406 .51393 m .52435 .52683 L .50945 .49679 L p
1 g
F P
s
P
p
.002 w
.56602 .47315 m .56581 .44962 L .59862 .44142 L p
1 g
F P
s
P
p
.002 w
.58711 .40899 m .59862 .44142 L .56581 .44962 L p
1 g
F P
s
P
p
.002 w
.45363 .40249 m .43637 .41876 L .41048 .39655 L p
1 g
F P
s
P
p
.002 w
.41048 .39655 m .43552 .37281 L .45363 .40249 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50945 .49679 m .51951 .49017 L .54406 .51393 L p
1 g
F P
s
P
p
.002 w
.55848 .49539 m .54406 .51393 L .51951 .49017 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45723 .4641 m .45946 .47587 L .42655 .48597 L p
1 g
F P
s
P
p
.002 w
.42655 .48597 m .4221 .46291 L .45723 .4641 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56581 .44962 m .55783 .42734 L .58711 .40899 L p
1 g
F P
s
P
p
.002 w
.56545 .38193 m .58711 .40899 L .55783 .42734 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.51951 .49017 m .52684 .48067 L .55848 .49539 L p
1 g
F P
s
P
p
.002 w
.47539 .39267 m .45363 .40249 L .43552 .37281 L p
1 g
F P
s
P
p
.002 w
.43552 .37281 m .46717 .35846 L .47539 .39267 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.459 .45225 m .45723 .4641 L .4221 .46291 L p
1 g
F P
s
P
p
.002 w
.4221 .46291 m .42548 .43967 L .459 .45225 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55783 .42734 m .5429 .40878 L .56545 .38193 L p
1 g
F P
s
P
p
.002 w
.53597 .36327 m .56545 .38193 L .5429 .40878 L p
1 g
F P
s
P
p
.002 w
.49928 .39042 m .47539 .39267 L .46717 .35846 L p
1 g
F P
s
P
p
.002 w
.46717 .35846 m .50195 .35514 L .49928 .39042 L p
1 g
F P
s
P
p
.002 w
.56581 .44962 m .56602 .47315 L .53065 .46932 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.50195 .35514 m .53597 .36327 L .52264 .39599 L p
1 g
F P
s
P
p
.002 w
.5429 .40878 m .52264 .39599 L .53597 .36327 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52264 .39599 m .49928 .39042 L .50195 .35514 L p
1 g
F P
s
P
p
.002 w
.46458 .44162 m .459 .45225 L .42548 .43967 L p
1 g
F P
s
P
p
.002 w
.42548 .43967 m .43637 .41876 L .46458 .44162 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.53065 .46932 m .5305 .45733 L .56581 .44962 L p
1 g
F P
s
P
p
.002 w
.55783 .42734 m .56581 .44962 L .5305 .45733 L p
1 g
F P
s
P
p
.002 w
.47339 .43337 m .46458 .44162 L .43637 .41876 L p
1 g
F P
s
P
p
.002 w
.43637 .41876 m .45363 .40249 L .47339 .43337 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.5305 .45733 m .5264 .446 L .55783 .42734 L p
1 g
F P
s
P
p
.002 w
.5429 .40878 m .55783 .42734 L .5264 .446 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.45723 .4641 m .459 .45225 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.48446 .4284 m .47339 .43337 L .45363 .40249 L p
1 g
F P
s
P
p
.002 w
.45363 .40249 m .47539 .39267 L .48446 .4284 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5264 .446 m .51878 .43658 L .5429 .40878 L p
1 g
F P
s
P
p
.002 w
.52264 .39599 m .5429 .40878 L .51878 .43658 L p
1 g
F P
s
P
p
.002 w
.459 .45225 m .46458 .44162 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.4966 .42726 m .48446 .4284 L .47539 .39267 L p
1 g
F P
s
P
p
.002 w
.47539 .39267 m .49928 .39042 L .4966 .42726 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49928 .39042 m .52264 .39599 L .50848 .4301 L p
1 g
F P
s
P
p
.002 w
.51878 .43658 m .50848 .4301 L .52264 .39599 L p
1 g
F P
s
P
p
.002 w
.5264 .446 m .5305 .45733 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.50848 .4301 m .4966 .42726 L .49928 .39042 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.46458 .44162 m .47339 .43337 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.4966 .42726 m .50848 .4301 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.48446 .4284 m .4966 .42726 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.47339 .43337 m .48446 .4284 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.51878 .43658 m .5264 .446 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.50848 .4301 m .51878 .43658 L .49404 .46424 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.49033 .48518 m
.49404 .46424 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .69999 .28172 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .49033 .48518 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.428682)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.428682)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49386 .45401 m .51028 .44551 L .49326 .42257 L p
1 g
F P
s
P
p
.002 w
.49326 .42257 m .48494 .42687 L .49386 .45401 L p
1 g
F P
s
P
p
.002 w
.49979 .41585 m .49326 .42257 L .51028 .44551 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .48494 .42687 L .49326 .42257 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .49326 .42257 L .49979 .41585 L closepath p
1 g
F P
s
P
p
.002 w
.51028 .44551 m .52318 .43226 L .49979 .41585 L p
1 g
F P
s
P
p
.002 w
.50383 .40743 m .49979 .41585 L .52318 .43226 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .49979 .41585 L .50383 .40743 L closepath p
1 g
F P
s
P
p
.002 w
.47565 .45684 m .49386 .45401 L .48494 .42687 L p
1 g
F P
s
P
p
.002 w
.48494 .42687 m .47571 .42828 L .47565 .45684 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .47571 .42828 L .48494 .42687 L closepath p
1 g
F P
s
P
p
.002 w
.50297 .4807 m .52712 .46819 L .51028 .44551 L p
1 g
F P
s
P
p
.002 w
.51028 .44551 m .49386 .45401 L .50297 .4807 L p
1 g
F P
s
P
p
.002 w
.52318 .43226 m .51028 .44551 L .52712 .46819 L p
1 g
F P
s
P
p
.002 w
.52712 .46819 m .54611 .4487 L .52318 .43226 L p
1 g
F P
s
P
p
.002 w
.53118 .41565 m .52318 .43226 L .54611 .4487 L p
1 g
F P
s
P
p
.002 w
.52318 .43226 m .53118 .41565 L .50383 .40743 L p
1 g
F P
s
P
p
.002 w
.50493 .39821 m .50383 .40743 L .53118 .41565 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .50383 .40743 L .50493 .39821 L closepath p
1 g
F P
s
P
p
.002 w
.47617 .48493 m .50297 .4807 L .49386 .45401 L p
1 g
F P
s
P
p
.002 w
.49386 .45401 m .47565 .45684 L .47617 .48493 L p
1 g
F P
s
P
p
.002 w
.45757 .45369 m .47565 .45684 L .47571 .42828 L p
1 g
F P
s
P
p
.002 w
.47571 .42828 m .46657 .42666 L .45757 .45369 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .46657 .42666 L .47571 .42828 L closepath p
1 g
F P
s
P
p
.002 w
.53118 .41565 m .53342 .39743 L .50493 .39821 L p
1 g
F P
s
P
p
.002 w
.50298 .38917 m .50493 .39821 L .53342 .39743 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .50493 .39821 L .50298 .38917 L closepath p
1 g
F P
s
P
p
.002 w
.44157 .44485 m .45757 .45369 L .46657 .42666 L p
1 g
F P
s
P
p
.002 w
.46657 .42666 m .4585 .42216 L .44157 .44485 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .4585 .42216 L .46657 .42666 L closepath p
1 g
F P
s
P
p
.002 w
.54611 .4487 m .55793 .42427 L .53118 .41565 L p
1 g
F P
s
P
p
.002 w
.53342 .39743 m .53118 .41565 L .55793 .42427 L p
1 g
F P
s
P
p
.002 w
.44954 .48036 m .47617 .48493 L .47565 .45684 L p
1 g
F P
s
P
p
.002 w
.47565 .45684 m .45757 .45369 L .44954 .48036 L p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .49817 .3813 L .491 .37545 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .48226 .37227 L .4729 .37212 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .4729 .37212 L .46392 .37501 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .46392 .37501 L .45633 .38064 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .45633 .38064 L .45095 .38839 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .45095 .38839 L .44837 .3974 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .44837 .3974 L .44887 .4067 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .44887 .4067 L .45238 .41526 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .45238 .41526 L .4585 .42216 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .50298 .38917 L .49817 .3813 L closepath p
1 g
F P
s
P
p
.002 w
.47636 .39977 m .491 .37545 L .48226 .37227 L closepath p
1 g
F P
s
P
p
.002 w
.53342 .39743 m .52963 .37954 L .50298 .38917 L p
1 g
F P
s
P
p
.002 w
.49817 .3813 m .50298 .38917 L .52963 .37954 L p
1 g
F P
s
P
p
.002 w
.42938 .43123 m .44157 .44485 L .4585 .42216 L p
1 g
F P
s
P
p
.002 w
.4585 .42216 m .45238 .41526 L .42938 .43123 L p
1 g
F P
s
P
p
.002 w
.51211 .50646 m .54348 .49018 L .52712 .46819 L p
1 g
F P
s
P
p
.002 w
.52712 .46819 m .50297 .4807 L .51211 .50646 L p
1 g
F P
s
P
p
.002 w
.54611 .4487 m .52712 .46819 L .54348 .49018 L p
1 g
F P
s
P
p
.002 w
.55793 .42427 m .56131 .39745 L .53342 .39743 L p
1 g
F P
s
P
p
.002 w
.52963 .37954 m .53342 .39743 L .56131 .39745 L p
1 g
F P
s
P
p
.002 w
.42589 .46742 m .44954 .48036 L .45757 .45369 L p
1 g
F P
s
P
p
.002 w
.45757 .45369 m .44157 .44485 L .42589 .46742 L p
1 g
F P
s
P
p
.002 w
.491 .37545 m .49817 .3813 L .52016 .36391 L p
1 g
F P
s
P
p
.002 w
.52963 .37954 m .52016 .36391 L .49817 .3813 L p
1 g
F P
s
P
p
.002 w
.54348 .49018 m .56816 .46487 L .54611 .4487 L p
1 g
F P
s
P
p
.002 w
.55793 .42427 m .54611 .4487 L .56816 .46487 L p
1 g
F P
s
P
p
.002 w
.42235 .41428 m .42938 .43123 L .45238 .41526 L p
1 g
F P
s
P
p
.002 w
.45238 .41526 m .44887 .4067 L .42235 .41428 L p
1 g
F P
s
P
p
.002 w
.47729 .51202 m .51211 .50646 L .50297 .4807 L p
1 g
F P
s
P
p
.002 w
.50297 .4807 m .47617 .48493 L .47729 .51202 L p
1 g
F P
s
P
p
.002 w
.52016 .36391 m .506 .35225 L .491 .37545 L p
1 g
F P
s
P
p
.002 w
.48226 .37227 m .491 .37545 L .506 .35225 L p
1 g
F P
s
P
p
.002 w
.4213 .39582 m .42235 .41428 L .44887 .4067 L p
1 g
F P
s
P
p
.002 w
.44887 .4067 m .44837 .3974 L .4213 .39582 L p
1 g
F P
s
P
p
.002 w
.56816 .46487 m .58359 .43315 L .55793 .42427 L p
1 g
F P
s
P
p
.002 w
.56131 .39745 m .55793 .42427 L .58359 .43315 L p
1 g
F P
s
P
p
.002 w
.56131 .39745 m .55582 .37105 L .52963 .37954 L p
1 g
F P
s
P
p
.002 w
.52016 .36391 m .52963 .37954 L .55582 .37105 L p
1 g
F P
s
P
p
.002 w
.44263 .50619 m .47729 .51202 L .47617 .48493 L p
1 g
F P
s
P
p
.002 w
.47617 .48493 m .44954 .48036 L .44263 .50619 L p
1 g
F P
s
P
p
.002 w
.40781 .44739 m .42589 .46742 L .44157 .44485 L p
1 g
F P
s
P
p
.002 w
.44157 .44485 m .42938 .43123 L .40781 .44739 L p
1 g
F P
s
P
p
.002 w
.506 .35225 m .48867 .34587 L .48226 .37227 L p
1 g
F P
s
P
p
.002 w
.4729 .37212 m .48226 .37227 L .48867 .34587 L p
1 g
F P
s
P
p
.002 w
.42639 .37788 m .4213 .39582 L .44837 .3974 L p
1 g
F P
s
P
p
.002 w
.44837 .3974 m .45095 .38839 L .42639 .37788 L p
1 g
F P
s
P
p
.002 w
.48867 .34587 m .47004 .34552 L .4729 .37212 L p
1 g
F P
s
P
p
.002 w
.46392 .37501 m .4729 .37212 L .47004 .34552 L p
1 g
F P
s
P
p
.002 w
.43707 .36245 m .42639 .37788 L .45095 .38839 L p
1 g
F P
s
P
p
.002 w
.45095 .38839 m .45633 .38064 L .43707 .36245 L p
1 g
F P
s
P
p
.002 w
.47004 .34552 m .45218 .35125 L .46392 .37501 L p
1 g
F P
s
P
p
.002 w
.45633 .38064 m .46392 .37501 L .45218 .35125 L p
1 g
F P
s
P
p
.002 w
.45218 .35125 m .43707 .36245 L .45633 .38064 L p
1 g
F P
s
P
p
.002 w
.506 .35225 m .52016 .36391 L .54194 .34793 L p
1 g
F P
s
P
p
.002 w
.55582 .37105 m .54194 .34793 L .52016 .36391 L p
1 g
F P
s
P
p
.002 w
.58359 .43315 m .58809 .39828 L .56131 .39745 L p
1 g
F P
s
P
p
.002 w
.55582 .37105 m .56131 .39745 L .58809 .39828 L p
1 g
F P
s
P
p
.002 w
.39733 .42238 m .40781 .44739 L .42938 .43123 L p
1 g
F P
s
P
p
.002 w
.42938 .43123 m .42235 .41428 L .39733 .42238 L p
1 g
F P
s
P
p
.002 w
.41178 .48945 m .44263 .50619 L .44954 .48036 L p
1 g
F P
s
P
p
.002 w
.44954 .48036 m .42589 .46742 L .41178 .48945 L p
1 g
F P
s
P
p
.002 w
.5211 .53079 m .55903 .51106 L .54348 .49018 L p
1 g
F P
s
P
p
.002 w
.54348 .49018 m .51211 .50646 L .5211 .53079 L p
1 g
F P
s
P
p
.002 w
.56816 .46487 m .54348 .49018 L .55903 .51106 L p
1 g
F P
s
P
p
.002 w
.55903 .51106 m .5889 .48047 L .56816 .46487 L p
1 g
F P
s
P
p
.002 w
.58359 .43315 m .56816 .46487 L .5889 .48047 L p
1 g
F P
s
P
p
.002 w
.47899 .53759 m .5211 .53079 L .51211 .50646 L p
1 g
F P
s
P
p
.002 w
.51211 .50646 m .47729 .51202 L .47899 .53759 L p
1 g
F P
s
P
p
.002 w
.54194 .34793 m .52109 .33062 L .506 .35225 L p
1 g
F P
s
P
p
.002 w
.48867 .34587 m .506 .35225 L .52109 .33062 L p
1 g
F P
s
P
p
.002 w
.39569 .39507 m .39733 .42238 L .42235 .41428 L p
1 g
F P
s
P
p
.002 w
.42235 .41428 m .4213 .39582 L .39569 .39507 L p
1 g
F P
s
P
p
.002 w
.58809 .39828 m .58106 .3639 L .55582 .37105 L p
1 g
F P
s
P
p
.002 w
.54194 .34793 m .55582 .37105 L .58106 .3639 L p
1 g
F P
s
P
p
.002 w
.38812 .46345 m .41178 .48945 L .42589 .46742 L p
1 g
F P
s
P
p
.002 w
.42589 .46742 m .40781 .44739 L .38812 .46345 L p
1 g
F P
s
P
p
.002 w
.5889 .48047 m .60764 .44213 L .58359 .43315 L p
1 g
F P
s
P
p
.002 w
.58809 .39828 m .58359 .43315 L .60764 .44213 L p
1 g
F P
s
P
p
.002 w
.437 .53065 m .47899 .53759 L .47729 .51202 L p
1 g
F P
s
P
p
.002 w
.47729 .51202 m .44263 .50619 L .437 .53065 L p
1 g
F P
s
P
p
.002 w
.52109 .33062 m .49547 .3211 L .48867 .34587 L p
1 g
F P
s
P
p
.002 w
.47004 .34552 m .48867 .34587 L .49547 .3211 L p
1 g
F P
s
P
p
.002 w
.40316 .36847 m .39569 .39507 L .4213 .39582 L p
1 g
F P
s
P
p
.002 w
.4213 .39582 m .42639 .37788 L .40316 .36847 L p
1 g
F P
s
P
p
.002 w
.49547 .3211 m .46788 .3205 L .47004 .34552 L p
1 g
F P
s
P
p
.002 w
.45218 .35125 m .47004 .34552 L .46788 .3205 L p
1 g
F P
s
P
p
.002 w
.41898 .34558 m .40316 .36847 L .42639 .37788 L p
1 g
F P
s
P
p
.002 w
.42639 .37788 m .43707 .36245 L .41898 .34558 L p
1 g
F P
s
P
p
.002 w
.46788 .3205 m .44139 .32897 L .45218 .35125 L p
1 g
F P
s
P
p
.002 w
.43707 .36245 m .45218 .35125 L .44139 .32897 L p
1 g
F P
s
P
p
.002 w
.52109 .33062 m .54194 .34793 L .56309 .33369 L p
1 g
F P
s
P
p
.002 w
.58106 .3639 m .56309 .33369 L .54194 .34793 L p
1 g
F P
s
P
p
.002 w
.44139 .32897 m .41898 .34558 L .43707 .36245 L p
1 g
F P
s
P
p
.002 w
.37433 .43086 m .38812 .46345 L .40781 .44739 L p
1 g
F P
s
P
p
.002 w
.40781 .44739 m .39733 .42238 L .37433 .43086 L p
1 g
F P
s
P
p
.002 w
.60764 .44213 m .6132 .39993 L .58809 .39828 L p
1 g
F P
s
P
p
.002 w
.58106 .3639 m .58809 .39828 L .6132 .39993 L p
1 g
F P
s
P
p
.002 w
.39957 .5105 m .437 .53065 L .44263 .50619 L p
1 g
F P
s
P
p
.002 w
.44263 .50619 m .41178 .48945 L .39957 .5105 L p
1 g
F P
s
P
p
.002 w
.52977 .55316 m .57346 .5304 L .55903 .51106 L p
1 g
F P
s
P
p
.002 w
.55903 .51106 m .5211 .53079 L .52977 .55316 L p
1 g
F P
s
P
p
.002 w
.5889 .48047 m .55903 .51106 L .57346 .5304 L p
1 g
F P
s
P
p
.002 w
.57346 .5304 m .6079 .49518 L .5889 .48047 L p
1 g
F P
s
P
p
.002 w
.60764 .44213 m .5889 .48047 L .6079 .49518 L p
1 g
F P
s
P
p
.002 w
.56309 .33369 m .53597 .31101 L .52109 .33062 L p
1 g
F P
s
P
p
.002 w
.49547 .3211 m .52109 .33062 L .53597 .31101 L p
1 g
F P
s
P
p
.002 w
.48125 .56109 m .52977 .55316 L .5211 .53079 L p
1 g
F P
s
P
p
.002 w
.5211 .53079 m .47899 .53759 L .48125 .56109 L p
1 g
F P
s
P
p
.002 w
.37208 .39518 m .37433 .43086 L .39733 .42238 L p
1 g
F P
s
P
p
.002 w
.39733 .42238 m .39569 .39507 L .37208 .39518 L p
1 g
F P
s
P
p
.002 w
.6132 .39993 m .60483 .35825 L .58106 .3639 L p
1 g
F P
s
P
p
.002 w
.56309 .33369 m .58106 .3639 L .60483 .35825 L p
1 g
F P
s
P
p
.002 w
.37076 .47907 m .39957 .5105 L .41178 .48945 L p
1 g
F P
s
P
p
.002 w
.41178 .48945 m .38812 .46345 L .37076 .47907 L p
1 g
F P
s
P
p
.002 w
.6079 .49518 m .62956 .45102 L .60764 .44213 L p
1 g
F P
s
P
p
.002 w
.6132 .39993 m .60764 .44213 L .62956 .45102 L p
1 g
F P
s
P
p
.002 w
.43282 .55321 m .48125 .56109 L .47899 .53759 L p
1 g
F P
s
P
p
.002 w
.47899 .53759 m .437 .53065 L .43282 .55321 L p
1 g
F P
s
P
p
.002 w
.53597 .31101 m .50254 .29847 L .49547 .3211 L p
1 g
F P
s
P
p
.002 w
.46788 .3205 m .49547 .3211 L .50254 .29847 L p
1 g
F P
s
P
p
.002 w
.38178 .36039 m .37208 .39518 L .39569 .39507 L p
1 g
F P
s
P
p
.002 w
.39569 .39507 m .40316 .36847 L .38178 .36039 L p
1 g
F P
s
P
p
.002 w
.50254 .29847 m .46646 .29761 L .46788 .3205 L p
1 g
F P
s
P
p
.002 w
.44139 .32897 m .46788 .3205 L .46646 .29761 L p
1 g
F P
s
P
p
.002 w
.40244 .3304 m .38178 .36039 L .40316 .36847 L p
1 g
F P
s
P
p
.002 w
.40316 .36847 m .41898 .34558 L .40244 .3304 L p
1 g
F P
s
P
p
.002 w
.60483 .35825 m .58317 .32154 L .56309 .33369 L p
1 g
F P
s
P
p
.002 w
.53597 .31101 m .56309 .33369 L .58317 .32154 L p
1 g
F P
s
P
p
.002 w
.35388 .43955 m .37076 .47907 L .38812 .46345 L p
1 g
F P
s
P
p
.002 w
.38812 .46345 m .37433 .43086 L .35388 .43955 L p
1 g
F P
s
P
p
.002 w
.46646 .29761 m .43178 .30865 L .44139 .32897 L p
1 g
F P
s
P
p
.002 w
.41898 .34558 m .44139 .32897 L .43178 .30865 L p
1 g
F P
s
P
p
.002 w
.62956 .45102 m .6361 .40239 L .6132 .39993 L p
1 g
F P
s
P
p
.002 w
.60483 .35825 m .6132 .39993 L .6361 .40239 L p
1 g
F P
s
P
p
.002 w
.43178 .30865 m .40244 .3304 L .41898 .34558 L p
1 g
F P
s
P
p
.002 w
.38956 .5301 m .43282 .55321 L .437 .53065 L p
1 g
F P
s
P
p
.002 w
.437 .53065 m .39957 .5105 L .38956 .5301 L p
1 g
F P
s
P
p
.002 w
.53794 .57306 m .58643 .54776 L .57346 .5304 L p
1 g
F P
s
P
p
.002 w
.57346 .5304 m .52977 .55316 L .53794 .57306 L p
1 g
F P
s
P
p
.002 w
.6079 .49518 m .57346 .5304 L .58643 .54776 L p
1 g
F P
s
P
p
.002 w
.58317 .32154 m .55034 .2939 L .53597 .31101 L p
1 g
F P
s
P
p
.002 w
.50254 .29847 m .53597 .31101 L .55034 .2939 L p
1 g
F P
s
P
p
.002 w
.35103 .3962 m .35388 .43955 L .37433 .43086 L p
1 g
F P
s
P
p
.002 w
.37433 .43086 m .37208 .39518 L .35103 .3962 L p
1 g
F P
s
P
p
.002 w
.58643 .54776 m .6247 .50866 L .6079 .49518 L p
1 g
F P
s
P
p
.002 w
.62956 .45102 m .6079 .49518 L .6247 .50866 L p
1 g
F P
s
P
p
.002 w
.48406 .58195 m .53794 .57306 L .52977 .55316 L p
1 g
F P
s
P
p
.002 w
.52977 .55316 m .48125 .56109 L .48406 .58195 L p
1 g
F P
s
P
p
.002 w
.6361 .40239 m .62658 .35428 L .60483 .35825 L p
1 g
F P
s
P
p
.002 w
.58317 .32154 m .60483 .35825 L .62658 .35428 L p
1 g
F P
s
P
p
.002 w
.35618 .49391 m .38956 .5301 L .39957 .5105 L p
1 g
F P
s
P
p
.002 w
.39957 .5105 m .37076 .47907 L .35618 .49391 L p
1 g
F P
s
P
p
.002 w
.6247 .50866 m .64883 .45966 L .62956 .45102 L p
1 g
F P
s
P
p
.002 w
.6361 .40239 m .62956 .45102 L .64883 .45966 L p
1 g
F P
s
P
p
.002 w
.43024 .57332 m .48406 .58195 L .48125 .56109 L p
1 g
F P
s
P
p
.002 w
.48125 .56109 m .43282 .55321 L .43024 .57332 L p
1 g
F P
s
P
p
.002 w
.55034 .2939 m .50975 .27855 L .50254 .29847 L p
1 g
F P
s
P
p
.002 w
.46646 .29761 m .50254 .29847 L .50975 .27855 L p
1 g
F P
s
P
p
.002 w
.36276 .35384 m .35103 .3962 L .37208 .39518 L p
1 g
F P
s
P
p
.002 w
.37208 .39518 m .38178 .36039 L .36276 .35384 L p
1 g
F P
s
P
p
.002 w
.50975 .27855 m .46586 .27743 L .46646 .29761 L p
1 g
F P
s
P
p
.002 w
.43178 .30865 m .46646 .29761 L .46586 .27743 L p
1 g
F P
s
P
p
.002 w
.55034 .2939 m .58317 .32154 L .60172 .31182 L p
1 g
F P
s
P
p
.002 w
.62658 .35428 m .60172 .31182 L .58317 .32154 L p
1 g
F P
s
P
p
.002 w
.38789 .31731 m .36276 .35384 L .38178 .36039 L p
1 g
F P
s
P
p
.002 w
.38178 .36039 m .40244 .3304 L .38789 .31731 L p
1 g
F P
s
P
p
.002 w
.33655 .4483 m .35618 .49391 L .37076 .47907 L p
1 g
F P
s
P
p
.002 w
.37076 .47907 m .35388 .43955 L .33655 .4483 L p
1 g
F P
s
P
p
.002 w
.64883 .45966 m .65621 .40564 L .6361 .40239 L p
1 g
F P
s
P
p
.002 w
.62658 .35428 m .6361 .40239 L .65621 .40564 L p
1 g
F P
s
P
p
.002 w
.46586 .27743 m .42363 .29082 L .43178 .30865 L p
1 g
F P
s
P
p
.002 w
.40244 .3304 m .43178 .30865 L .42363 .29082 L p
1 g
F P
s
P
p
.002 w
.42363 .29082 m .38789 .31731 L .40244 .3304 L p
1 g
F P
s
P
p
.002 w
.38208 .54776 m .43024 .57332 L .43282 .55321 L p
1 g
F P
s
P
p
.002 w
.43282 .55321 m .38956 .5301 L .38208 .54776 L p
1 g
F P
s
P
p
.002 w
.60172 .31182 m .56387 .27976 L .55034 .2939 L p
1 g
F P
s
P
p
.002 w
.50975 .27855 m .55034 .2939 L .56387 .27976 L p
1 g
F P
s
P
p
.002 w
.54539 .58994 m .59761 .56266 L .58643 .54776 L p
1 g
F P
s
P
p
.002 w
.58643 .54776 m .53794 .57306 L .54539 .58994 L p
1 g
F P
s
P
p
.002 w
.6247 .50866 m .58643 .54776 L .59761 .56266 L p
1 g
F P
s
P
p
.002 w
.33314 .39815 m .33655 .4483 L .35388 .43955 L p
1 g
F P
s
P
p
.002 w
.35388 .43955 m .35103 .3962 L .33314 .39815 L p
1 g
F P
s
P
p
.002 w
.59761 .56266 m .63884 .52057 L .6247 .50866 L p
1 g
F P
s
P
p
.002 w
.64883 .45966 m .6247 .50866 L .63884 .52057 L p
1 g
F P
s
P
p
.002 w
.48737 .59959 m .54539 .58994 L .53794 .57306 L p
1 g
F P
s
P
p
.002 w
.53794 .57306 m .48406 .58195 L .48737 .59959 L p
1 g
F P
s
P
p
.002 w
.65621 .40564 m .64578 .35214 L .62658 .35428 L p
1 g
F P
s
P
p
.002 w
.60172 .31182 m .62658 .35428 L .64578 .35214 L p
1 g
F P
s
P
p
.002 w
.34485 .50761 m .38208 .54776 L .38956 .5301 L p
1 g
F P
s
P
p
.002 w
.38956 .5301 m .35618 .49391 L .34485 .50761 L p
1 g
F P
s
P
p
.002 w
.63884 .52057 m .66489 .46783 L .64883 .45966 L p
1 g
F P
s
P
p
.002 w
.65621 .40564 m .64883 .45966 L .66489 .46783 L p
1 g
F P
s
P
p
.002 w
.56387 .27976 m .51696 .2619 L .50975 .27855 L p
1 g
F P
s
P
p
.002 w
.46586 .27743 m .50975 .27855 L .51696 .2619 L p
1 g
F P
s
P
p
.002 w
.42938 .59041 m .48737 .59959 L .48406 .58195 L p
1 g
F P
s
P
p
.002 w
.48406 .58195 m .43024 .57332 L .42938 .59041 L p
1 g
F P
s
P
p
.002 w
.34664 .34906 m .33314 .39815 L .35103 .3962 L p
1 g
F P
s
P
p
.002 w
.35103 .3962 m .36276 .35384 L .34664 .34906 L p
1 g
F P
s
P
p
.002 w
.56387 .27976 m .60172 .31182 L .61825 .30485 L p
1 g
F P
s
P
p
.002 w
.64578 .35214 m .61825 .30485 L .60172 .31182 L p
1 g
F P
s
P
p
.002 w
.51696 .2619 m .46613 .26051 L .46586 .27743 L p
1 g
F P
s
P
p
.002 w
.42363 .29082 m .46586 .27743 L .46613 .26051 L p
1 g
F P
s
P
p
.002 w
.32287 .45689 m .34485 .50761 L .35618 .49391 L p
1 g
F P
s
P
p
.002 w
.35618 .49391 m .33655 .4483 L .32287 .45689 L p
1 g
F P
s
P
p
.002 w
.37574 .30669 m .34664 .34906 L .36276 .35384 L p
1 g
F P
s
P
p
.002 w
.36276 .35384 m .38789 .31731 L .37574 .30669 L p
1 g
F P
s
P
p
.002 w
.66489 .46783 m .67295 .40966 L .65621 .40564 L p
1 g
F P
s
P
p
.002 w
.64578 .35214 m .65621 .40564 L .67295 .40966 L p
1 g
F P
s
P
p
.002 w
.37743 .56299 m .42938 .59041 L .43024 .57332 L p
1 g
F P
s
P
p
.002 w
.43024 .57332 m .38208 .54776 L .37743 .56299 L p
1 g
F P
s
P
p
.002 w
.46613 .26051 m .41717 .276 L .42363 .29082 L p
1 g
F P
s
P
p
.002 w
.38789 .31731 m .42363 .29082 L .41717 .276 L p
1 g
F P
s
P
p
.002 w
.41717 .276 m .37574 .30669 L .38789 .31731 L p
1 g
F P
s
P
p
.002 w
.61825 .30485 m .57621 .26907 L .56387 .27976 L p
1 g
F P
s
P
p
.002 w
.51696 .2619 m .56387 .27976 L .57621 .26907 L p
1 g
F P
s
P
p
.002 w
.55193 .60326 m .60664 .57466 L .59761 .56266 L p
1 g
F P
s
P
p
.002 w
.59761 .56266 m .54539 .58994 L .55193 .60326 L p
1 g
F P
s
P
p
.002 w
.63884 .52057 m .59761 .56266 L .60664 .57466 L p
1 g
F P
s
P
p
.002 w
.31897 .40102 m .32287 .45689 L .33655 .4483 L p
1 g
F P
s
P
p
.002 w
.33655 .4483 m .33314 .39815 L .31897 .40102 L p
1 g
F P
s
P
p
.002 w
.60664 .57466 m .64985 .53056 L .63884 .52057 L p
1 g
F P
s
P
p
.002 w
.66489 .46783 m .63884 .52057 L .64985 .53056 L p
1 g
F P
s
P
p
.002 w
.67295 .40966 m .66184 .35199 L .64578 .35214 L p
1 g
F P
s
P
p
.002 w
.61825 .30485 m .64578 .35214 L .66184 .35199 L p
1 g
F P
s
P
p
.002 w
.49114 .61344 m .55193 .60326 L .54539 .58994 L p
1 g
F P
s
P
p
.002 w
.54539 .58994 m .48737 .59959 L .49114 .61344 L p
1 g
F P
s
P
p
.002 w
.3372 .51979 m .37743 .56299 L .38208 .54776 L p
1 g
F P
s
P
p
.002 w
.38208 .54776 m .34485 .50761 L .3372 .51979 L p
1 g
F P
s
P
p
.002 w
.64985 .53056 m .67721 .47532 L .66489 .46783 L p
1 g
F P
s
P
p
.002 w
.67295 .40966 m .66489 .46783 L .67721 .47532 L p
1 g
F P
s
P
p
.002 w
.57621 .26907 m .52398 .24906 L .51696 .2619 L p
1 g
F P
s
P
p
.002 w
.46613 .26051 m .51696 .2619 L .52398 .24906 L p
1 g
F P
s
P
p
.002 w
.43036 .60391 m .49114 .61344 L .48737 .59959 L p
1 g
F P
s
P
p
.002 w
.48737 .59959 m .42938 .59041 L .43036 .60391 L p
1 g
F P
s
P
p
.002 w
.33397 .34626 m .31897 .40102 L .33314 .39815 L p
1 g
F P
s
P
p
.002 w
.33314 .39815 m .34664 .34906 L .33397 .34626 L p
1 g
F P
s
P
p
.002 w
.66184 .35199 m .63228 .30095 L .61825 .30485 L p
1 g
F P
s
P
p
.002 w
.57621 .26907 m .61825 .30485 L .63228 .30095 L p
1 g
F P
s
P
p
.002 w
.3134 .46512 m .3372 .51979 L .34485 .50761 L p
1 g
F P
s
P
p
.002 w
.34485 .50761 m .32287 .45689 L .3134 .46512 L p
1 g
F P
s
P
p
.002 w
.52398 .24906 m .46731 .24745 L .46613 .26051 L p
1 g
F P
s
P
p
.002 w
.41717 .276 m .46613 .26051 L .46731 .24745 L p
1 g
F P
s
P
p
.002 w
.36641 .29896 m .33397 .34626 L .34664 .34906 L p
1 g
F P
s
P
p
.002 w
.34664 .34906 m .37574 .30669 L .36641 .29896 L p
1 g
F P
s
P
p
.002 w
.67721 .47532 m .68575 .41438 L .67295 .40966 L p
1 g
F P
s
P
p
.002 w
.66184 .35199 m .67295 .40966 L .68575 .41438 L p
1 g
F P
s
P
p
.002 w
.37588 .57526 m .43036 .60391 L .42938 .59041 L p
1 g
F P
s
P
p
.002 w
.42938 .59041 m .37743 .56299 L .37588 .57526 L p
1 g
F P
s
P
p
.002 w
.46731 .24745 m .41266 .2647 L .41717 .276 L p
1 g
F P
s
P
p
.002 w
.37574 .30669 m .41717 .276 L .41266 .2647 L p
1 g
F P
s
P
p
.002 w
.41266 .2647 m .36641 .29896 L .37574 .30669 L p
1 g
F P
s
P
p
.002 w
.63228 .30095 m .587 .26227 L .57621 .26907 L p
1 g
F P
s
P
p
.002 w
.52398 .24906 m .57621 .26907 L .587 .26227 L p
1 g
F P
s
P
p
.002 w
.30911 .4048 m .3134 .46512 L .32287 .45689 L p
1 g
F P
s
P
p
.002 w
.32287 .45689 m .31897 .40102 L .30911 .4048 L p
1 g
F P
s
P
p
.002 w
.55734 .61249 m .61318 .58328 L .60664 .57466 L p
1 g
F P
s
P
p
.002 w
.60664 .57466 m .55193 .60326 L .55734 .61249 L p
1 g
F P
s
P
p
.002 w
.64985 .53056 m .60664 .57466 L .61318 .58328 L p
1 g
F P
s
P
p
.002 w
.68575 .41438 m .67421 .35393 L .66184 .35199 L p
1 g
F P
s
P
p
.002 w
.63228 .30095 m .66184 .35199 L .67421 .35393 L p
1 g
F P
s
P
p
.002 w
.61318 .58328 m .6573 .53827 L .64985 .53056 L p
1 g
F P
s
P
p
.002 w
.67721 .47532 m .64985 .53056 L .6573 .53827 L p
1 g
F P
s
P
p
.002 w
.49531 .62293 m .55734 .61249 L .55193 .60326 L p
1 g
F P
s
P
p
.002 w
.55193 .60326 m .49114 .61344 L .49531 .62293 L p
1 g
F P
s
P
p
.002 w
.33364 .53005 m .37588 .57526 L .37743 .56299 L p
1 g
F P
s
P
p
.002 w
.37743 .56299 m .3372 .51979 L .33364 .53005 L p
1 g
F P
s
P
p
.002 w
.6573 .53827 m .68527 .48191 L .67721 .47532 L p
1 g
F P
s
P
p
.002 w
.68575 .41438 m .67721 .47532 L .68527 .48191 L p
1 g
F P
s
P
p
.002 w
.587 .26227 m .53065 .2406 L .52398 .24906 L p
1 g
F P
s
P
p
.002 w
.46731 .24745 m .52398 .24906 L .53065 .2406 L p
1 g
F P
s
P
p
.002 w
.43327 .61327 m .49531 .62293 L .49114 .61344 L p
1 g
F P
s
P
p
.002 w
.49114 .61344 m .43036 .60391 L .43327 .61327 L p
1 g
F P
s
P
p
.002 w
.32527 .34562 m .30911 .4048 L .31897 .40102 L p
1 g
F P
s
P
p
.002 w
.31897 .40102 m .33397 .34626 L .32527 .34562 L p
1 g
F P
s
P
p
.002 w
.67421 .35393 m .6433 .30039 L .63228 .30095 L p
1 g
F P
s
P
p
.002 w
.587 .26227 m .63228 .30095 L .6433 .30039 L p
1 g
F P
s
P
p
.002 w
.30862 .47274 m .33364 .53005 L .3372 .51979 L p
1 g
F P
s
P
p
.002 w
.3372 .51979 m .3134 .46512 L .30862 .47274 L p
1 g
F P
s
P
p
.002 w
.53065 .2406 m .46942 .2388 L .46731 .24745 L p
1 g
F P
s
P
p
.002 w
.41266 .2647 m .46731 .24745 L .46942 .2388 L p
1 g
F P
s
P
p
.002 w
.36033 .29447 m .32527 .34562 L .33397 .34626 L p
1 g
F P
s
P
p
.002 w
.33397 .34626 m .36641 .29896 L .36033 .29447 L p
1 g
F P
s
P
p
.002 w
.68527 .48191 m .69404 .41974 L .68575 .41438 L p
1 g
F P
s
P
p
.002 w
.67421 .35393 m .68575 .41438 L .69404 .41974 L p
1 g
F P
s
P
p
.002 w
.37766 .58409 m .43327 .61327 L .43036 .60391 L p
1 g
F P
s
P
p
.002 w
.43036 .60391 m .37588 .57526 L .37766 .58409 L p
1 g
F P
s
P
p
.002 w
.46942 .2388 m .41033 .25742 L .41266 .2647 L p
1 g
F P
s
P
p
.002 w
.36641 .29896 m .41266 .2647 L .41033 .25742 L p
1 g
F P
s
P
p
.002 w
.41033 .25742 m .36033 .29447 L .36641 .29896 L p
1 g
F P
s
P
p
.002 w
.6433 .30039 m .59587 .25977 L .587 .26227 L p
1 g
F P
s
P
p
.002 w
.53065 .2406 m .587 .26227 L .59587 .25977 L p
1 g
F P
s
P
p
.002 w
.30408 .40945 m .30862 .47274 L .3134 .46512 L p
1 g
F P
s
P
p
.002 w
.3134 .46512 m .30911 .4048 L .30408 .40945 L p
1 g
F P
s
P
p
.002 w
.56141 .61713 m .6169 .58809 L .61318 .58328 L p
1 g
F P
s
P
p
.002 w
.61318 .58328 m .55734 .61249 L .56141 .61713 L p
1 g
F P
s
P
p
.002 w
.6573 .53827 m .61318 .58328 L .6169 .58809 L p
1 g
F P
s
P
p
.002 w
.69404 .41974 m .68232 .35805 L .67421 .35393 L p
1 g
F P
s
P
p
.002 w
.6433 .30039 m .67421 .35393 L .68232 .35805 L p
1 g
F P
s
P
p
.002 w
.6169 .58809 m .66076 .54337 L .6573 .53827 L p
1 g
F P
s
P
p
.002 w
.68527 .48191 m .6573 .53827 L .66076 .54337 L p
1 g
F P
s
P
p
.002 w
.33454 .53799 m .37766 .58409 L .37588 .57526 L p
1 g
F P
s
P
p
.002 w
.37588 .57526 m .33364 .53005 L .33454 .53799 L p
1 g
F P
s
P
p
.002 w
.49978 .62753 m .56141 .61713 L .55734 .61249 L p
1 g
F P
s
P
p
.002 w
.55734 .61249 m .49531 .62293 L .49978 .62753 L p
1 g
F P
s
P
p
.002 w
.66076 .54337 m .68857 .48737 L .68527 .48191 L p
1 g
F P
s
P
p
.002 w
.69404 .41974 m .68527 .48191 L .68857 .48737 L p
1 g
F P
s
P
p
.002 w
.59587 .25977 m .53676 .237 L .53065 .2406 L p
1 g
F P
s
P
p
.002 w
.46942 .2388 m .53065 .2406 L .53676 .237 L p
1 g
F P
s
P
p
.002 w
.43817 .61796 m .49978 .62753 L .49531 .62293 L p
1 g
F P
s
P
p
.002 w
.49531 .62293 m .43327 .61327 L .43817 .61796 L p
1 g
F P
s
P
p
.002 w
.32103 .3473 m .30408 .40945 L .30911 .4048 L p
1 g
F P
s
P
p
.002 w
.30911 .4048 m .32527 .34562 L .32103 .3473 L p
1 g
F P
s
P
p
.002 w
.68232 .35805 m .65083 .3034 L .6433 .30039 L p
1 g
F P
s
P
p
.002 w
.59587 .25977 m .6433 .30039 L .65083 .3034 L p
1 g
F P
s
P
p
.002 w
.30898 .47952 m .33454 .53799 L .33364 .53005 L p
1 g
F P
s
P
p
.002 w
.33364 .53005 m .30862 .47274 L .30898 .47952 L p
1 g
F P
s
P
p
.002 w
.53676 .237 m .47247 .23509 L .46942 .2388 L p
1 g
F P
s
P
p
.002 w
.41033 .25742 m .46942 .2388 L .47247 .23509 L p
1 g
F P
s
P
p
.002 w
.35785 .29357 m .32103 .3473 L .32527 .34562 L p
1 g
F P
s
P
p
.002 w
.32527 .34562 m .36033 .29447 L .35785 .29357 L p
1 g
F P
s
P
p
.002 w
.68857 .48737 m .69731 .42562 L .69404 .41974 L p
1 g
F P
s
P
p
.002 w
.68232 .35805 m .69404 .41974 L .69731 .42562 L p
1 g
F P
s
P
p
.002 w
.38294 .58901 m .43817 .61796 L .43327 .61327 L p
1 g
F P
s
P
p
.002 w
.43327 .61327 m .37766 .58409 L .38294 .58901 L p
1 g
F P
s
P
p
.002 w
.47247 .23509 m .41039 .25464 L .41033 .25742 L p
1 g
F P
s
P
p
.002 w
.36033 .29447 m .41033 .25742 L .41039 .25464 L p
1 g
F P
s
P
p
.002 w
.41039 .25464 m .35785 .29357 L .36033 .29447 L p
1 g
F P
s
P
p
.004 w
.69876 .40285 m
.71303 .40087 L
s
P
p
.004 w
.71303 .40087 m
.72134 .39971 L
s
P
p
.004 w
.72134 .39971 m
.77866 .39174 L
s
P
p
.002 w
.65083 .3034 m .60244 .26194 L .59587 .25977 L p
1 g
F P
s
P
p
.002 w
.53676 .237 m .59587 .25977 L .60244 .26194 L p
1 g
F P
s
P
p
.002 w
.30435 .4149 m .30898 .47952 L .30862 .47274 L p
1 g
F P
s
P
p
.002 w
.30862 .47274 m .30408 .40945 L .30435 .4149 L p
1 g
F P
s
P
p
.002 w
.69731 .42562 m .68569 .36437 L .68232 .35805 L p
1 g
F P
s
P
p
.002 w
.65083 .3034 m .68232 .35805 L .68569 .36437 L p
1 g
F P
s
P
p
.002 w
.56395 .61675 m .61752 .58871 L .6169 .58809 L p
1 g
F P
s
P
p
.002 w
.6169 .58809 m .56141 .61713 L .56395 .61675 L p
1 g
F P
s
P
p
.002 w
.66076 .54337 m .6169 .58809 L .61752 .58871 L p
1 g
F P
s
P
p
.002 w
.34014 .54324 m .38294 .58901 L .37766 .58409 L p
1 g
F P
s
P
p
.002 w
.37766 .58409 m .33454 .53799 L .34014 .54324 L p
1 g
F P
s
P
p
.002 w
.61752 .58871 m .65987 .54553 L .66076 .54337 L p
1 g
F P
s
P
p
.002 w
.68857 .48737 m .66076 .54337 L .65987 .54553 L p
1 g
F P
s
P
p
.002 w
.50446 .62678 m .56395 .61675 L .56141 .61713 L p
1 g
F P
s
P
p
.002 w
.56141 .61713 m .49978 .62753 L .50446 .62678 L p
1 g
F P
s
P
p
.002 w
.65987 .54553 m .68671 .49148 L .68857 .48737 L p
1 g
F P
s
P
p
.002 w
.69731 .42562 m .68857 .48737 L .68671 .49148 L p
1 g
F P
s
P
p
.002 w
.60244 .26194 m .5421 .23868 L .53676 .237 L p
1 g
F P
s
P
p
.002 w
.47247 .23509 m .53676 .237 L .5421 .23868 L p
1 g
F P
s
P
p
.002 w
.44502 .61754 m .50446 .62678 L .49978 .62753 L p
1 g
F P
s
P
p
.002 w
.49978 .62753 m .43817 .61796 L .44502 .61754 L p
1 g
F P
s
P
p
.002 w
.32167 .35142 m .30435 .4149 L .30408 .40945 L p
1 g
F P
s
P
p
.002 w
.30408 .40945 m .32103 .3473 L .32167 .35142 L p
1 g
F P
s
P
p
.002 w
.68569 .36437 m .65444 .31013 L .65083 .3034 L p
1 g
F P
s
P
p
.002 w
.60244 .26194 m .65083 .3034 L .65444 .31013 L p
1 g
F P
s
P
p
.002 w
.3148 .48519 m .34014 .54324 L .33454 .53799 L p
1 g
F P
s
P
p
.002 w
.33454 .53799 m .30898 .47952 L .3148 .48519 L p
1 g
F P
s
P
p
.002 w
.5421 .23868 m .47643 .23674 L .47247 .23509 L p
1 g
F P
s
P
p
.002 w
.41039 .25464 m .47247 .23509 L .47643 .23674 L p
1 g
F P
s
P
p
.002 w
.3593 .29652 m .32167 .35142 L .32103 .3473 L p
1 g
F P
s
P
p
.002 w
.32103 .3473 m .35785 .29357 L .3593 .29652 L p
1 g
F P
s
P
p
.002 w
.68671 .49148 m .69514 .4319 L .69731 .42562 L p
1 g
F P
s
P
p
.002 w
.68569 .36437 m .69731 .42562 L .69514 .4319 L p
1 g
F P
s
P
p
.004 w
.69711 .40308 m
.69876 .40285 L
s
P
p
.002 w
.3918 .5896 m .44502 .61754 L .43817 .61796 L p
1 g
F P
s
P
p
.002 w
.43817 .61796 m .38294 .58901 L .3918 .5896 L p
1 g
F P
s
P
p
.002 w
.47643 .23674 m .413 .25673 L .41039 .25464 L p
1 g
F P
s
P
p
.002 w
.35785 .29357 m .41039 .25464 L .413 .25673 L p
1 g
F P
s
P
p
.002 w
.413 .25673 m .3593 .29652 L .35785 .29357 L p
1 g
F P
s
P
p
.002 w
.65444 .31013 m .60639 .26899 L .60244 .26194 L p
1 g
F P
s
P
p
.002 w
.5421 .23868 m .60244 .26194 L .60639 .26899 L p
1 g
F P
s
P
p
.002 w
.31025 .42104 m .3148 .48519 L .30898 .47952 L p
1 g
F P
s
P
p
.002 w
.30898 .47952 m .30435 .4149 L .31025 .42104 L p
1 g
F P
s
P
p
.002 w
.69514 .4319 m .68391 .37286 L .68569 .36437 L p
1 g
F P
s
P
p
.002 w
.65444 .31013 m .68569 .36437 L .68391 .37286 L p
1 g
F P
s
P
p
.002 w
.56476 .61102 m .61481 .58483 L .61752 .58871 L p
1 g
F P
s
P
p
.002 w
.61752 .58871 m .56395 .61675 L .56476 .61102 L p
1 g
F P
s
P
p
.002 w
.65987 .54553 m .61752 .58871 L .61481 .58483 L p
1 g
F P
s
P
p
.002 w
.3506 .54547 m .3918 .5896 L .38294 .58901 L p
1 g
F P
s
P
p
.002 w
.38294 .58901 m .34014 .54324 L .3506 .54547 L p
1 g
F P
s
P
p
.002 w
.61481 .58483 m .65437 .54449 L .65987 .54553 L p
1 g
F P
s
P
p
.002 w
.68671 .49148 m .65987 .54553 L .65437 .54449 L p
1 g
F P
s
P
p
.002 w
.50921 .62036 m .56476 .61102 L .56395 .61675 L p
1 g
F P
s
P
p
.002 w
.56395 .61675 m .50446 .62678 L .50921 .62036 L p
1 g
F P
s
P
p
.002 w
.65437 .54449 m .67941 .49401 L .68671 .49148 L p
1 g
F P
s
P
p
.002 w
.69514 .4319 m .68671 .49148 L .67941 .49401 L p
1 g
F P
s
P
p
.002 w
.60639 .26899 m .54647 .24594 L .5421 .23868 L p
1 g
F P
s
P
p
.002 w
.47643 .23674 m .5421 .23868 L .54647 .24594 L p
1 g
F P
s
P
p
.002 w
.45377 .6117 m .50921 .62036 L .50446 .62678 L p
1 g
F P
s
P
p
.002 w
.50446 .62678 m .44502 .61754 L .45377 .6117 L p
1 g
F P
s
P
p
.002 w
.32749 .35801 m .31025 .42104 L .30435 .4149 L p
1 g
F P
s
P
p
.002 w
.30435 .4149 m .32167 .35142 L .32749 .35801 L p
1 g
F P
s
P
p
.002 w
.60639 .26899 m .65444 .31013 L .65375 .32061 L p
1 g
F P
s
P
p
.002 w
.68391 .37286 m .65375 .32061 L .65444 .31013 L p
1 g
F P
s
P
p
.002 w
.32626 .48952 m .3506 .54547 L .34014 .54324 L p
1 g
F P
s
P
p
.002 w
.34014 .54324 m .3148 .48519 L .32626 .48952 L p
1 g
F P
s
P
p
.002 w
.54647 .24594 m .48125 .24406 L .47643 .23674 L p
1 g
F P
s
P
p
.002 w
.413 .25673 m .47643 .23674 L .48125 .24406 L p
1 g
F P
s
P
p
.002 w
.67941 .49401 m .68723 .43842 L .69514 .4319 L p
1 g
F P
s
P
p
.002 w
.68391 .37286 m .69514 .4319 L .68723 .43842 L p
1 g
F P
s
P
p
.002 w
.3649 .30348 m .32749 .35801 L .32167 .35142 L p
1 g
F P
s
P
p
.002 w
.32167 .35142 m .3593 .29652 L .3649 .30348 L p
1 g
F P
s
P
p
.002 w
.40418 .58559 m .45377 .6117 L .44502 .61754 L p
1 g
F P
s
P
p
.002 w
.44502 .61754 m .3918 .5896 L .40418 .58559 L p
1 g
F P
s
P
p
.002 w
.48125 .24406 m .41825 .26395 L .413 .25673 L p
1 g
F P
s
P
p
.002 w
.3593 .29652 m .413 .25673 L .41825 .26395 L p
1 g
F P
s
P
p
.002 w
.41825 .26395 m .3649 .30348 L .3593 .29652 L p
1 g
F P
s
P
p
.002 w
.65375 .32061 m .60741 .28105 L .60639 .26899 L p
1 g
F P
s
P
p
.002 w
.54647 .24594 m .60639 .26899 L .60741 .28105 L p
1 g
F P
s
P
p
.002 w
.32196 .42772 m .32626 .48952 L .3148 .48519 L p
1 g
F P
s
P
p
.002 w
.3148 .48519 m .31025 .42104 L .32196 .42772 L p
1 g
F P
s
P
p
.002 w
.68723 .43842 m .6767 .38338 L .68391 .37286 L p
1 g
F P
s
P
p
.002 w
.65375 .32061 m .68391 .37286 L .6767 .38338 L p
1 g
F P
s
P
p
.002 w
.36589 .54441 m .40418 .58559 L .3918 .5896 L p
1 g
F P
s
P
p
.002 w
.3918 .5896 m .3506 .54547 L .36589 .54441 L p
1 g
F P
s
P
p
.002 w
.56372 .59977 m .60863 .57628 L .61481 .58483 L p
1 g
F P
s
P
p
.002 w
.61481 .58483 m .56476 .61102 L .56372 .59977 L p
1 g
F P
s
P
p
.002 w
.65437 .54449 m .61481 .58483 L .60863 .57628 L p
1 g
F P
s
P
p
.002 w
.60863 .57628 m .64412 .54008 L .65437 .54449 L p
1 g
F P
s
P
p
.002 w
.67941 .49401 m .65437 .54449 L .64412 .54008 L p
1 g
F P
s
P
p
.002 w
.5139 .60811 m .56372 .59977 L .56476 .61102 L p
1 g
F P
s
P
p
.002 w
.56476 .61102 m .50921 .62036 L .5139 .60811 L p
1 g
F P
s
P
p
.002 w
.60741 .28105 m .54966 .25893 L .54647 .24594 L p
1 g
F P
s
P
p
.002 w
.48125 .24406 m .54647 .24594 L .54966 .25893 L p
1 g
F P
s
P
p
.002 w
.64412 .54008 m .66654 .49479 L .67941 .49401 L p
1 g
F P
s
P
p
.002 w
.68723 .43842 m .67941 .49401 L .66654 .49479 L p
1 g
F P
s
P
p
.002 w
.46423 .60027 m .5139 .60811 L .50921 .62036 L p
1 g
F P
s
P
p
.002 w
.50921 .62036 m .45377 .6117 L .46423 .60027 L p
1 g
F P
s
P
p
.002 w
.33865 .36701 m .32196 .42772 L .31025 .42104 L p
1 g
F P
s
P
p
.002 w
.31025 .42104 m .32749 .35801 L .33865 .36701 L p
1 g
F P
s
P
p
.002 w
.6767 .38338 m .64851 .33476 L .65375 .32061 L p
1 g
F P
s
P
p
.002 w
.60741 .28105 m .65375 .32061 L .64851 .33476 L p
1 g
F P
s
P
p
.002 w
.34334 .49227 m .36589 .54441 L .3506 .54547 L p
1 g
F P
s
P
p
.002 w
.3506 .54547 m .32626 .48952 L .34334 .49227 L p
1 g
F P
s
P
p
.002 w
.66654 .49479 m .67348 .44497 L .68723 .43842 L p
1 g
F P
s
P
p
.002 w
.6767 .38338 m .68723 .43842 L .67348 .44497 L p
1 g
F P
s
P
p
.004 w
.6853 .40473 m
.69711 .40308 L
s
P
p
.004 w
.67845 .40568 m
.6853 .40473 L
s
P
p
.004 w
.67707 .40587 m
.67845 .40568 L
s
P
p
.002 w
.54966 .25893 m .48683 .25719 L .48125 .24406 L p
1 g
F P
s
P
p
.002 w
.41825 .26395 m .48125 .24406 L .48683 .25719 L p
1 g
F P
s
P
p
.002 w
.37473 .31449 m .33865 .36701 L .32749 .35801 L p
1 g
F P
s
P
p
.002 w
.32749 .35801 m .3649 .30348 L .37473 .31449 L p
1 g
F P
s
P
p
.002 w
.41991 .57681 m .46423 .60027 L .45377 .6117 L p
1 g
F P
s
P
p
.002 w
.45377 .6117 m .40418 .58559 L .41991 .57681 L p
1 g
F P
s
P
p
.002 w
.48683 .25719 m .42613 .2764 L .41825 .26395 L p
1 g
F P
s
P
p
.002 w
.3649 .30348 m .41825 .26395 L .42613 .2764 L p
1 g
F P
s
P
p
.002 w
.42613 .2764 m .37473 .31449 L .3649 .30348 L p
1 g
F P
s
P
p
.002 w
.64851 .33476 m .60529 .29802 L .60741 .28105 L p
1 g
F P
s
P
p
.002 w
.54966 .25893 m .60741 .28105 L .60529 .29802 L p
1 g
F P
s
P
p
.002 w
.33946 .43474 m .34334 .49227 L .32626 .48952 L p
1 g
F P
s
P
p
.002 w
.32626 .48952 m .32196 .42772 L .33946 .43474 L p
1 g
F P
s
P
p
.002 w
.67348 .44497 m .66395 .39573 L .6767 .38338 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.6662 .40738 L
s
P
p
.002 w
.64851 .33476 m .6767 .38338 L .66395 .39573 L p
1 g
F P
s
P
p
.002 w
.38577 .5399 m .41991 .57681 L .40418 .58559 L p
1 g
F P
s
P
p
.002 w
.40418 .58559 m .36589 .54441 L .38577 .5399 L p
1 g
F P
s
P
p
.002 w
.56074 .58302 m .59897 .56305 L .60863 .57628 L p
1 g
F P
s
P
p
.002 w
.60863 .57628 m .56372 .59977 L .56074 .58302 L p
1 g
F P
s
P
p
.002 w
.64412 .54008 m .60863 .57628 L .59897 .56305 L p
1 g
F P
s
P
p
.002 w
.59897 .56305 m .62916 .53223 L .64412 .54008 L p
1 g
F P
s
P
p
.002 w
.66654 .49479 m .64412 .54008 L .62916 .53223 L p
1 g
F P
s
P
p
.002 w
.51836 .59006 m .56074 .58302 L .56372 .59977 L p
1 g
F P
s
P
p
.002 w
.56372 .59977 m .5139 .60811 L .51836 .59006 L p
1 g
F P
s
P
p
.002 w
.60529 .29802 m .55149 .27754 L .54966 .25893 L p
1 g
F P
s
P
p
.002 w
.48683 .25719 m .54966 .25893 L .55149 .27754 L p
1 g
F P
s
P
p
.002 w
.62916 .53223 m .64819 .49368 L .66654 .49479 L p
1 g
F P
s
P
p
.002 w
.67348 .44497 m .66654 .49479 L .64819 .49368 L p
1 g
F P
s
P
p
.002 w
.47617 .58331 m .51836 .59006 L .5139 .60811 L p
1 g
F P
s
P
p
.002 w
.5139 .60811 m .46423 .60027 L .47617 .58331 L p
1 g
F P
s
P
p
.002 w
.35508 .37827 m .33946 .43474 L .32196 .42772 L p
1 g
F P
s
P
p
.002 w
.32196 .42772 m .33865 .36701 L .35508 .37827 L p
1 g
F P
s
P
p
.002 w
.60529 .29802 m .64851 .33476 L .63863 .35232 L p
1 g
F P
s
P
p
.002 w
.66395 .39573 m .63863 .35232 L .64851 .33476 L p
1 g
F P
s
P
p
.002 w
.36577 .49326 m .38577 .5399 L .36589 .54441 L p
1 g
F P
s
P
p
.002 w
.36589 .54441 m .34334 .49227 L .36577 .49326 L p
1 g
F P
s
P
p
.002 w
.64819 .49368 m .65399 .45133 L .67348 .44497 L p
1 g
F P
s
P
p
.002 w
.66395 .39573 m .67348 .44497 L .65399 .45133 L p
1 g
F P
s
P
p
.002 w
.55149 .27754 m .49301 .27603 L .48683 .25719 L p
1 g
F P
s
P
p
.002 w
.42613 .2764 m .48683 .25719 L .49301 .27603 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.47617 .58331 m .46423 .60027 L p
.43876 .56348 L 1 g
F P
s
P
p
.002 w
.43962 .56382 m .47617 .58331 L p
.43876 .56348 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51836 .59006 m .47617 .58331 L .47794 .58032 L p
1 g
F P
s
P
p
.51836 .59006 m .47794 .58032 L .48614 .58029 L 1 g
F
P
p
.002 w
.51091 .58021 m .51079 .57862 L p
.5027 .58024 L 1 g
F P
s
P
p
.002 w
.48909 .58028 m .48921 .57862 L p
.4778 .57768 L 1 g
F P
s
P
p
.002 w
.47919 .57819 m .47617 .58331 L p
.473 .57594 L 1 g
F P
s
P
p
.4778 .57768 m .47618 .57755 L .47919 .57819 L 1 g
F
P
p
.4778 .57768 m .47919 .57819 L .48909 .58028 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46837 .57426 L p
1 g
F P
s
P
p
.002 w
.47617 .58331 m .43962 .56382 L p
.46837 .57426 L 1 g
F P
s
P
p
.47381 .57782 m .46837 .57426 L .473 .57594 L 1 g
F
P
p
.47617 .58331 m .46837 .57426 L .47381 .57782 L 1 g
F
P
p
.002 w
.46837 .57426 m .46872 .57265 L p
.46152 .56978 L 1 g
F P
s
P
p
.48921 .57862 m .46837 .57426 L .4778 .57768 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45089 .56281 L p
1 g
F P
s
P
p
.46872 .57265 m .45089 .56281 L .46152 .56978 L 1 g
F
P
p
.473 .57594 m .46829 .57421 L .4598 .54528 L 1 g
F
P
p
.002 w
.43862 .56329 m .44428 .55848 L p
.45089 .56281 L 1 g
F P
s
P
p
.4575 .57023 m .43862 .56329 L .45089 .56281 L 1 g
F
P
p
.002 w
.45089 .56281 m .45146 .56129 L p
.44455 .55529 L 1 g
F P
s
P
p
.43862 .56329 m .43808 .546 L .43864 .5468 L 1 g
F
P
p
.002 w
.44585 .55715 m .44287 .55967 L p
.43864 .5468 L 1 g
F P
s
P
p
.002 w
.44287 .55967 m .43862 .56329 L p
.43864 .5468 L 1 g
F P
s
P
p
.002 w
.43864 .5468 m .43925 .54566 L p
.43644 .5401 L 1 g
F P
s
P
p
.44455 .55529 m .44585 .55715 L .45089 .56281 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.46829 .57421 m .45089 .56281 L .4598 .54528 L 1 g
F
P
p
.002 w
.44428 .55848 m .44585 .55715 L p
.45089 .56281 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .5468 L p
1 g
F P
s
P
p
.43862 .56329 m .42414 .52599 L .43808 .546 L 1 g
F
P
p
.002 w
.43864 .5468 m .4379 .54821 L p
.44316 .55329 L 1 g
F P
s
P
p
.45146 .56129 m .43864 .5468 L .44316 .55329 L 1 g
F
P
p
.002 w
.43862 .56329 m .4098 .5319 L .42414 .52599 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43264 .52854 L p
1 g
F P
s
P
p
.002 w
.42414 .52599 m .43089 .5232 L p
.43263 .52874 L 1 g
F P
s
P
p
.43808 .546 m .43241 .53785 L .43263 .52874 L 1 g
F
P
p
.43241 .53785 m .42414 .52599 L .43263 .52874 L 1 g
F
P
p
.002 w
.43264 .52854 m .43346 .52734 L p
.43314 .51811 L 1 g
F P
s
P
p
.002 w
.43279 .52242 m .4098 .5319 L p
.43364 .51186 L 1 g
F P
s
P
p
.43314 .51811 m .433 .51414 L .43279 .52242 L 1 g
F
P
p
.43314 .51811 m .43279 .52242 L .43264 .52854 L 1 g
F
P
p
.002 w
.42428 .48952 m .43321 .51083 L p
.4098 .5319 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43391 .50938 L p
1 g
F P
s
P
p
.002 w
.43364 .51186 m .43321 .51083 L p
.43382 .5102 L 1 g
F P
s
P
p
.002 w
.42428 .48952 m .44489 .48667 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.43321 .51083 m .4301 .50342 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.4301 .50342 m .42428 .48952 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44266 .49128 m .44339 .4905 L p
.45066 .48354 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45849 .48478 m .44786 .48625 L p
.45757 .47684 L 1 g
F P
s
P
p
.002 w
.45757 .47684 m .45826 .47608 L p
.46716 .4722 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45806 .47661 m .47756 .46718 L .49382 .46641 L 1 g
F
P
p
.002 w
.47756 .46718 m .47786 .46667 L p
.49127 .46531 L 1 g
F P
s
P
p
.002 w
.49426 .46489 m .49382 .46641 L .48853 .46569 L p
1 g
F P
s
P
p
.49127 .46531 m .49159 .46527 L .48853 .46569 L 1 g
F
P
p
.49127 .46531 m .48853 .46569 L .47756 .46718 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56603 .50931 L p
1 g
F P
s
P
p
.002 w
.58632 .50664 m .57181 .52149 L p
.56603 .50931 L 1 g
F P
s
P
p
.56529 .50157 m .56603 .50931 L .56199 .50078 L 1 g
F
P
p
.58632 .50664 m .56603 .50931 L .56529 .50157 L 1 g
F
P
p
.002 w
.56603 .50931 m .56515 .50826 L p
.56716 .52128 L 1 g
F P
s
P
p
.002 w
.56702 .5196 m .56987 .52347 L p
.56719 .52167 L 1 g
F P
s
P
p
.56716 .52128 m .56722 .52166 L .56702 .5196 L 1 g
F
P
p
.56716 .52128 m .56702 .5196 L .56603 .50931 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56754 .52879 L p
1 g
F P
s
P
p
.56779 .53992 m .56754 .52879 L .56987 .52347 L 1 g
F
P
p
.002 w
.56744 .52474 m .56918 .52383 L p
.56754 .52879 L 1 g
F P
s
P
p
.002 w
.56918 .52383 m .56987 .52347 L p
.56754 .52879 L 1 g
F P
s
P
p
.002 w
.56754 .52879 m .56654 .52734 L p
.56473 .53725 L 1 g
F P
s
P
p
.56515 .50826 m .56754 .52879 L .56747 .52569 L 1 g
F
P
p
.002 w
.56987 .52347 m .56744 .52474 L p
.56719 .52167 L 1 g
F P
s
P
p
.56716 .52128 m .56796 .52941 L .56722 .52166 L 1 g
F
P
p
.56515 .50826 m .56762 .52686 L .56716 .52128 L 1 g
F
P
p
.56762 .52686 m .56796 .52941 L .56716 .52128 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.54901 .53434 m .54051 .50374 L p
.56719 .52167 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56744 .52474 m .54901 .53434 L p
.56719 .52167 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56148 .54704 L p
1 g
F P
s
P
p
.56654 .52734 m .56148 .54704 L .56473 .53725 L 1 g
F
P
p
.002 w
.54901 .53434 m .56744 .52474 L p
.56754 .52879 L 1 g
F P
s
P
p
.56779 .53992 m .5642 .53885 L .56754 .52879 L 1 g
F
P
p
.5642 .53885 m .54901 .53434 L .56754 .52879 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.58595 .54531 m .55581 .56103 L .55471 .55671 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56323 L p
1 g
F P
s
P
p
.53909 .5737 m .54926 .56323 L .55581 .56103 L 1 g
F
P
p
.002 w
.55055 .5619 m .55172 .5617 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.55172 .5617 m .55581 .56103 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54854 .56129 L p
.54142 .56807 L 1 g
F P
s
P
p
.56075 .54566 m .54926 .56323 L .55055 .5619 L 1 g
F
P
p
.56075 .54566 m .55055 .5619 L .55189 .56022 L 1 g
F
P
p
.002 w
.55581 .56103 m .55055 .5619 L p
.55298 .55886 L 1 g
F P
s
P
p
.002 w
.55471 .55671 m .55581 .56103 L p
.55298 .55886 L 1 g
F P
s
P
p
.56075 .54566 m .54957 .56405 L .55446 .55706 L 1 g
F
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.52242 .56652 m .5259 .53809 L p
.55298 .55886 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53161 .57414 L p
1 g
F P
s
P
p
.54854 .56129 m .53161 .57414 L .54142 .56807 L 1 g
F
P
p
.002 w
.52242 .56652 m .55055 .5619 L p
.54926 .56323 L 1 g
F P
s
P
p
.53909 .5737 m .5351 .57198 L .54926 .56323 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.5351 .57198 m .52242 .56652 L .54926 .56323 L 1 g
F
P
p
.002 w
.56074 .58302 m .51836 .59006 L .52041 .57814 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58021 L p
1 g
F P
s
P
p
.002 w
.52041 .57814 m .51836 .59006 L p
.50889 .58065 L 1 g
F P
s
P
p
.002 w
.51091 .58021 m .511 .58149 L p
.51698 .57889 L 1 g
F P
s
P
p
.53128 .57265 m .51091 .58021 L .51698 .57889 L 1 g
F
P
p
.53128 .57265 m .511 .58149 L .52098 .57793 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.48924 .56112 m .52242 .56652 L .52041 .57814 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58028 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .58028 L .5027 .58024 L 1 g
F
P
p
.002 w
.47919 .57819 m .48924 .56112 L p
.50846 .58022 L 1 g
F P
s
P
p
.51378 .58551 m .48909 .58028 L .50846 .58022 L 1 g
F
P
p
.48909 .58028 m .47919 .57819 L .50846 .58022 L 1 g
F
P
p
.51836 .59006 m .47919 .57819 L .51378 .58551 L 1 g
F
P
p
.002 w
.48909 .58028 m .48889 .583 L p
.5027 .58024 L 1 g
F P
s
P
p
.51091 .58021 m .48924 .56112 L .52041 .57814 L 1 g
F
P
p
.50889 .58065 m .50846 .58022 L .51091 .58021 L 1 g
F
P
p
.50846 .58022 m .48924 .56112 L .51091 .58021 L 1 g
F
P
p
.56074 .58302 m .52041 .57814 L .53627 .57248 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.52041 .57814 m .52242 .56652 L p
.53627 .57248 L 1 g
F P
s
P
p
.002 w
.511 .58149 m .51111 .583 L p
.52098 .57793 L 1 g
F P
s
P
p
.002 w
.53161 .57414 m .5322 .57686 L p
.54142 .56807 L 1 g
F P
s
P
p
.002 w
.55055 .5619 m .52242 .56652 L p
.55298 .55886 L 1 g
F P
s
P
p
.55142 .56101 m .55055 .5619 L .54957 .56405 L 1 g
F
P
p
.002 w
.54926 .56323 m .54933 .56342 L p
.55055 .5619 L 1 g
F P
s
P
p
.002 w
.54933 .56342 m .54957 .56405 L p
.55055 .5619 L 1 g
F P
s
P
p
.55189 .56022 m .55055 .5619 L .55142 .56101 L 1 g
F
P
p
.58595 .54531 m .55471 .55671 L .5667 .53959 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.5259 .53809 m .54901 .53434 L .55471 .55671 L p
1 g
F P
s
P
p
.55298 .55886 m .5259 .53809 L .55471 .55671 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54926 .56323 L p
1 g
F P
s
P
p
.54142 .56807 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.002 w
.55581 .56103 m .56074 .58302 L p
.53909 .5737 L 1 g
F P
s
P
p
.002 w
.55471 .55671 m .54901 .53434 L p
.5667 .53959 L 1 g
F P
s
P
p
.002 w
.54957 .56405 m .54998 .56518 L p
.55446 .55706 L 1 g
F P
s
P
p
.002 w
.56148 .54704 m .56257 .5491 L p
.56473 .53725 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56754 .52879 L p
1 g
F P
s
P
p
.56473 .53725 m .56257 .5491 L .56754 .52879 L 1 g
F
P
p
.002 w
.56754 .52879 m .56796 .52941 L p
.56747 .52569 L 1 g
F P
s
P
p
.002 w
.56987 .52347 m .58595 .54531 L p
.56779 .53992 L 1 g
F P
s
P
p
.55661 .4905 m .56603 .50931 L .56203 .50087 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55963 .48955 m .58632 .50664 L p
.56199 .50078 L 1 g
F P
s
P
p
.55661 .4905 m .56203 .50087 L .56151 .49976 L 1 g
F
P
p
.002 w
.55764 .4916 m .55764 .49159 L p
.56199 .50078 L 1 g
F P
s
P
p
.002 w
.55764 .49159 m .55963 .48955 L p
.56068 .49452 L 1 g
F P
s
P
p
.56199 .50078 m .55764 .49159 L .56068 .49452 L 1 g
F
P
p
.002 w
.55763 .49158 m .5567 .49068 L p
.56595 .50816 L 1 g
F P
s
P
p
.002 w
.55121 .49818 m .53164 .47172 L p
.54772 .48196 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55763 .49158 L p
1 g
F P
s
P
p
.54174 .47608 m .55763 .49158 L .55761 .49156 L 1 g
F
P
p
.55454 .48858 m .55121 .49818 L .54772 .48196 L 1 g
F
P
p
.002 w
.55764 .4916 m .55121 .49818 L p
.55454 .48858 L 1 g
F P
s
P
p
.55764 .4916 m .55454 .48858 L .55763 .49158 L 1 g
F
P
p
.55071 .48486 m .55763 .49158 L .5539 .48798 L 1 g
F
P
p
.54174 .47608 m .55761 .49156 L .55071 .48486 L 1 g
F
P
p
.55761 .49156 m .55763 .49158 L .55071 .48486 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55763 .49158 m .55454 .48858 L .55519 .48672 L 1 g
F
P
p
.002 w
.55121 .49818 m .55764 .4916 L p
.56199 .50078 L 1 g
F P
s
P
p
.002 w
.56595 .50816 m .55834 .49233 L .55763 .49158 L p
1 g
F P
s
P
p
.002 w
.53539 .47348 m .54672 .48099 L p
.53164 .47172 L 1 g
F P
s
P
p
.54772 .48196 m .53164 .47172 L .54672 .48099 L 1 g
F
P
p
.54174 .47608 m .55071 .48486 L .54672 .48099 L 1 g
F
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.56488 .47876 m .55963 .48955 L .54672 .48099 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47674 L p
1 g
F P
s
P
p
.002 w
.54672 .48099 m .53539 .47348 L p
.54235 .47674 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54235 .47675 L p
.54221 .47668 L 1 g
F P
s
P
p
.52214 .46667 m .54235 .47674 L .54221 .47668 L 1 g
F
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.53059 .4703 m .53746 .47199 L p
.54235 .47674 L 1 g
F P
s
P
p
.52214 .46667 m .54235 .47675 L .54169 .47644 L 1 g
F
P
p
.52214 .46667 m .54239 .47678 L .53451 .47307 L 1 g
F
P
p
.002 w
.53539 .47348 m .53059 .4703 L p
.54235 .47674 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54174 .47608 L p
.54672 .48099 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53746 .47199 m .56488 .47876 L p
.54672 .48099 L 1 g
F P
s
P
p
.002 w
.54235 .47675 m .54235 .47674 L p
.54672 .48099 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54235 .47675 L p
1 g
F P
s
P
p
.55071 .48486 m .55834 .49233 L .54235 .47675 L 1 g
F
P
p
.002 w
.54672 .48099 m .55963 .48955 L p
.54772 .48196 L 1 g
F P
s
P
p
.55519 .48672 m .55454 .48858 L .54772 .48196 L 1 g
F
P
p
.002 w
.55763 .49158 m .55763 .49158 L p
.55761 .49156 L 1 g
F P
s
P
p
.002 w
.55763 .49158 m .55834 .49233 L p
.5539 .48798 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56595 .50816 L p
.56151 .49976 L 1 g
F P
s
P
p
.56203 .50087 m .56713 .51061 L .56151 .49976 L 1 g
F
P
p
.002 w
.55963 .48955 m .55764 .4916 L p
.55519 .48672 L 1 g
F P
s
P
p
.56199 .50078 m .56644 .5136 L .55121 .49818 L 1 g
F
P
p
.002 w
.56987 .52347 m .56702 .5196 L p
.56644 .5136 L 1 g
F P
s
P
p
.002 w
.56702 .5196 m .55121 .49818 L p
.56644 .5136 L 1 g
F P
s
P
p
.002 w
.56796 .52941 m .56854 .53025 L p
.56722 .52166 L 1 g
F P
s
P
p
.002 w
.54051 .50374 m .55121 .49818 L .56702 .5196 L p
1 g
F P
s
P
p
.56719 .52167 m .54051 .50374 L .56702 .5196 L 1 g
F
P
p
.002 w
.57181 .52149 m .56987 .52347 L p
.56199 .50078 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56603 .50931 L p
1 g
F P
s
P
p
.56722 .52166 m .56854 .53025 L .56603 .50931 L 1 g
F
P
p
.002 w
.56603 .50931 m .56713 .51061 L p
.56203 .50087 L 1 g
F P
s
P
p
.002 w
.55121 .49818 m .54051 .50374 L .53091 .47138 L p
1 g
F P
s
P
p
.002 w
.53164 .47172 m .55121 .49818 L p
.53091 .47138 L 1 g
F P
s
P
p
.002 w
.49382 .46641 m .49426 .46489 L p
.52786 .46989 L 1 g
F P
s
P
p
.002 w
.52817 .47004 m .49382 .46641 L p
.52786 .46989 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.53477 .47321 L 1 g
F P
s
P
p
.002 w
.54051 .50374 m .52867 .50563 L .53054 .4712 L p
1 g
F P
s
P
p
.002 w
.53091 .47138 m .54051 .50374 L p
.53054 .4712 L 1 g
F P
s
P
p
.002 w
.52867 .50563 m .51696 .50365 L .53027 .47107 L p
1 g
F P
s
P
p
.53477 .47321 m .5304 .47113 L .52248 .46723 L 1 g
F
P
p
.002 w
.50664 .49797 m .49883 .48921 L .52973 .47081 L p
1 g
F P
s
P
p
.002 w
.52973 .47081 m .53059 .4703 L .53002 .47095 L p
1 g
F P
s
P
p
.002 w
.53002 .47095 m .50664 .49797 L p
.52973 .47081 L 1 g
F P
s
P
p
.002 w
.49883 .48921 m .49439 .4783 L .52927 .47059 L p
1 g
F P
s
P
p
.002 w
.52927 .47059 m .53059 .4703 L .52973 .47081 L p
1 g
F P
s
P
p
.002 w
.52973 .47081 m .49883 .48921 L p
.52927 .47059 L 1 g
F P
s
P
p
.52988 .47089 m .52989 .47089 L .52954 .47072 L 1 g
F
P
p
.53002 .47095 m .52999 .47094 L .52988 .47089 L 1 g
F
P
p
.52999 .47094 m .52989 .47089 L .52988 .47089 L 1 g
F
P
p
.002 w
.53027 .47107 m .51696 .50365 L p
.53002 .47095 L 1 g
F P
s
P
p
.5304 .47113 m .53027 .47107 L .53002 .47095 L 1 g
F
P
p
.53027 .47107 m .52989 .47089 L .53002 .47095 L 1 g
F
P
p
.002 w
.49439 .4783 m .49382 .46641 L .52817 .47004 L p
1 g
F P
s
P
p
.002 w
.52817 .47004 m .53059 .4703 L .52927 .47059 L p
1 g
F P
s
P
p
.002 w
.52927 .47059 m .49439 .4783 L p
.52817 .47004 L 1 g
F P
s
P
p
.5304 .47113 m .52973 .47081 L .52248 .46723 L 1 g
F
P
p
.52973 .47081 m .52954 .47072 L .52817 .47004 L 1 g
F
P
p
.52973 .47081 m .52817 .47004 L .52248 .46723 L 1 g
F
P
p
.002 w
.51696 .50365 m .50664 .49797 L .53002 .47095 L p
1 g
F P
s
P
p
.002 w
.53002 .47095 m .53059 .4703 L .53027 .47107 L p
1 g
F P
s
P
p
.002 w
.53027 .47107 m .53059 .4703 L .53054 .4712 L p
1 g
F P
s
P
p
.002 w
.53054 .4712 m .52867 .50563 L p
.53027 .47107 L 1 g
F P
s
P
p
.53054 .4712 m .53885 .47532 L .52989 .47089 L 1 g
F
P
p
.53477 .47321 m .53518 .47342 L .53054 .4712 L 1 g
F
P
p
.53518 .47342 m .53885 .47532 L .53054 .4712 L 1 g
F
P
p
.002 w
.53054 .4712 m .53059 .4703 L .53091 .47138 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.49426 .46489 m .5 .46394 L .53059 .4703 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .51175 .46566 L 1 g
F
P
p
.002 w
.52465 .46755 m .53059 .4703 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46394 L p
1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .4634 L p
.51175 .46566 L 1 g
F P
s
P
p
.51175 .46566 m .52282 .46778 L .5 .46394 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46394 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.4972 .45485 m .5124 .46188 L p
.5 .46394 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46394 L .49617 .46457 L 1 g
F
P
p
.47786 .46667 m .5 .46413 L .49159 .46527 L 1 g
F
P
p
.002 w
.49426 .46489 m .49477 .46317 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.49477 .46317 m .4972 .45485 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.5124 .46188 m .52465 .46755 L p
.5 .46394 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52282 .46778 L p
.51175 .46566 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52248 .46723 L p
1 g
F P
s
P
p
.53885 .47532 m .54302 .47747 L .52248 .46723 L 1 g
F
P
p
.002 w
.53059 .4703 m .52817 .47004 L p
.52786 .46989 L 1 g
F P
s
P
p
.002 w
.53164 .47172 m .53059 .4703 L .53539 .47348 L p
1 g
F P
s
P
p
.002 w
.54235 .47675 m .54239 .47678 L p
.54169 .47644 L 1 g
F P
s
P
p
.002 w
.54239 .47678 m .54302 .47747 L p
.53451 .47307 L 1 g
F P
s
P
p
.002 w
.53091 .47138 m .53059 .4703 L .53164 .47172 L p
1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .46413 L p
.49617 .46457 L 1 g
F P
s
P
p
.002 w
.5 .46413 m .5 .46442 L p
.49159 .46527 L 1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.45726 .4614 m .48237 .46484 L p
.47756 .46718 L 1 g
F P
s
P
p
.46716 .4722 m .45806 .47661 L .45757 .47684 L 1 g
F
P
p
.002 w
.47718 .46778 m .47583 .46843 L p
.45826 .47608 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45755 .47686 L p
1 g
F P
s
P
p
.002 w
.45755 .47686 m .45698 .47747 L p
.45283 .48146 L 1 g
F P
s
P
p
.43346 .52734 m .43391 .50938 L .4331 .51692 L 1 g
F
P
p
.002 w
.43391 .50938 m .43485 .50826 L p
.43793 .50106 L 1 g
F P
s
P
p
.43321 .51083 m .44266 .49128 L .45849 .48478 L 1 g
F
P
p
.44339 .4905 m .45755 .47686 L .45402 .48029 L 1 g
F
P
p
.44339 .4905 m .45402 .48029 L .4517 .48254 L 1 g
F
P
p
.45066 .48354 m .44786 .48625 L .44266 .49128 L 1 g
F
P
p
.002 w
.44489 .48667 m .44786 .48625 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.44786 .48625 m .45849 .48478 L p
.44266 .49128 L 1 g
F P
s
P
p
.4517 .48254 m .45402 .48029 L .45283 .48146 L 1 g
F
P
p
.002 w
.45806 .47661 m .45805 .47637 L p
.47756 .46718 L 1 g
F P
s
P
p
.002 w
.45805 .47637 m .4577 .46987 L p
.46586 .46876 L 1 g
F P
s
P
p
.45805 .47637 m .46586 .46876 L .47756 .46718 L 1 g
F
P
p
.002 w
.4577 .46987 m .45726 .4614 L p
.47756 .46718 L 1 g
F P
s
P
p
.002 w
.4972 .45485 m .49426 .46489 L p
.45726 .4614 L 1 g
F P
s
P
p
.002 w
.48853 .46569 m .45726 .4614 L p
.49426 .46489 L 1 g
F P
s
P
p
.002 w
.48237 .46484 m .48853 .46569 L p
.47756 .46718 L 1 g
F P
s
P
p
.002 w
.48853 .46569 m .49382 .46641 L p
.47756 .46718 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46718 L p
1 g
F P
s
P
p
.49159 .46527 m .5 .46442 L .47756 .46718 L 1 g
F
P
p
.46716 .4722 m .47583 .46843 L .45806 .47661 L 1 g
F
P
p
.002 w
.45849 .48478 m .45806 .47661 L p
.49382 .46641 L 1 g
F P
s
P
p
.002 w
.45805 .47637 m .45806 .47661 L p
.45757 .47684 L 1 g
F P
s
P
p
.002 w
.45806 .47661 m .45849 .48478 L p
.45757 .47684 L 1 g
F P
s
P
p
.002 w
.47583 .46843 m .45698 .47747 L .45757 .47684 L p
1 g
F P
s
P
p
.45066 .48354 m .4517 .48254 L .44786 .48625 L 1 g
F
P
p
.002 w
.45726 .4614 m .45805 .47637 L p
.42428 .48952 L 1 g
F P
s
P
p
.002 w
.44786 .48625 m .42428 .48952 L p
.45805 .47637 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44266 .49128 L p
1 g
F P
s
P
p
.4517 .48254 m .45698 .47747 L .44266 .49128 L 1 g
F
P
p
.002 w
.43321 .51083 m .43364 .51186 L p
.43216 .5131 L 1 g
F P
s
P
p
.4098 .5319 m .43321 .51083 L .43216 .5131 L 1 g
F
P
p
.002 w
.43391 .50938 m .43287 .51061 L p
.4331 .51692 L 1 g
F P
s
P
p
.002 w
.43729 .52056 m .43364 .51186 L p
.45849 .48478 L 1 g
F P
s
P
p
.43364 .51186 m .43382 .5102 L .45849 .48478 L 1 g
F
P
p
.002 w
.43383 .50947 m .43391 .50938 L p
.44094 .49402 L 1 g
F P
s
P
p
.43793 .50106 m .44094 .49402 L .43391 .50938 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43383 .50947 L p
1 g
F P
s
P
p
.44094 .49402 m .44166 .49233 L .43383 .50947 L 1 g
F
P
p
.002 w
.43364 .51186 m .43729 .52056 L .43279 .52242 L p
1 g
F P
s
P
p
.43925 .54566 m .43264 .52854 L .43644 .5401 L 1 g
F
P
p
.002 w
.43089 .5232 m .43729 .52056 L p
.43805 .54501 L 1 g
F P
s
P
p
.43808 .546 m .43089 .5232 L .43805 .54501 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43264 .52854 L p
1 g
F P
s
P
p
.433 .51414 m .43287 .51061 L .43264 .52854 L 1 g
F
P
p
.002 w
.43264 .52854 m .43146 .53025 L p
.43644 .5401 L 1 g
F P
s
P
p
.45146 .56129 m .4379 .54821 L .44297 .55391 L 1 g
F
P
p
.002 w
.44585 .55715 m .4598 .54528 L p
.45089 .56281 L 1 g
F P
s
P
p
.002 w
.4379 .54821 m .43743 .5491 L p
.44297 .55391 L 1 g
F P
s
P
p
.43808 .546 m .43729 .52056 L .44585 .55715 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43864 .5468 L p
1 g
F P
s
P
p
.43644 .5401 m .43146 .53025 L .43864 .5468 L 1 g
F
P
p
.44455 .55529 m .44297 .55391 L .44585 .55715 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43729 .52056 m .4598 .54528 L .44585 .55715 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45089 .56281 L p
1 g
F P
s
P
p
.44297 .55391 m .43743 .5491 L .45089 .56281 L 1 g
F
P
p
.46829 .57421 m .4575 .57023 L .45089 .56281 L 1 g
F
P
p
.002 w
.45089 .56281 m .45002 .56518 L p
.46152 .56978 L 1 g
F P
s
P
p
.002 w
.43962 .56382 m .43862 .56329 L p
.473 .57594 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46837 .57426 L p
1 g
F P
s
P
p
.46152 .56978 m .45002 .56518 L .46837 .57426 L 1 g
F
P
p
.002 w
.46837 .57426 m .4678 .57686 L p
.4778 .57768 L 1 g
F P
s
P
p
.002 w
.4598 .54528 m .48924 .56112 L .47919 .57819 L p
1 g
F P
s
P
p
.473 .57594 m .4598 .54528 L .47919 .57819 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58021 L p
1 g
F P
s
P
p
.5027 .58024 m .48889 .583 L .51091 .58021 L 1 g
F
P
p
.002 w
.47794 .58032 m .47919 .57819 L p
.48614 .58029 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58028 L p
1 g
F P
s
P
p
.47618 .57755 m .4678 .57686 L .48909 .58028 L 1 g
F
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48888 .58308 L p
1 g
F P
s
P
p
.002 w
.48888 .58308 m .48889 .583 L p
.48861 .58297 L 1 g
F P
s
P
p
.48861 .58297 m .46687 .58109 L .48888 .58308 L 1 g
F
P
p
.002 w
.43862 .56329 m .43962 .56382 L p
.43876 .56348 L 1 g
F P
s
P
p
.002 w
.46423 .60027 m .41991 .57681 L .43862 .56329 L p
1 g
F P
s
P
p
.002 w
.38871 .32942 m .35508 .37827 L .33865 .36701 L p
1 g
F P
s
P
p
.002 w
.33865 .36701 m .37473 .31449 L .38871 .32942 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49301 .27603 m .43655 .29396 L .42613 .2764 L p
1 g
F P
s
P
p
.002 w
.37473 .31449 m .42613 .2764 L .43655 .29396 L p
1 g
F P
s
P
p
.002 w
.43655 .29396 m .38871 .32942 L .37473 .31449 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.63863 .35232 m .59992 .31961 L .60529 .29802 L p
1 g
F P
s
P
p
.002 w
.55149 .27754 m .60529 .29802 L .59992 .31961 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.36245 .44188 m .36577 .49326 L .34334 .49227 L p
1 g
F P
s
P
p
.002 w
.34334 .49227 m .33946 .43474 L .36245 .44188 L p
1 g
F P
s
P
p
.002 w
.65399 .45133 m .64579 .40957 L .66395 .39573 L p
1 g
F P
s
P
p
.002 w
.63863 .35232 m .66395 .39573 L .64579 .40957 L p
1 g
F P
s
P
p
.002 w
.4098 .5319 m .43862 .56329 L .41991 .57681 L p
1 g
F P
s
P
p
.002 w
.41991 .57681 m .38577 .5399 L .4098 .5319 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55581 .56103 m .58595 .54531 L .59897 .56305 L p
1 g
F P
s
P
p
.002 w
.59897 .56305 m .56074 .58302 L .55581 .56103 L p
1 g
F P
s
P
p
.002 w
.62916 .53223 m .59897 .56305 L .58595 .54531 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.58595 .54531 m .60974 .521 L .62916 .53223 L p
1 g
F P
s
P
p
.002 w
.64819 .49368 m .62916 .53223 L .60974 .521 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.59992 .31961 m .55183 .30146 L .55149 .27754 L p
1 g
F P
s
P
p
.002 w
.49301 .27603 m .55149 .27754 L .55183 .30146 L p
1 g
F P
s
P
p
.002 w
.60974 .521 m .62468 .49061 L .64819 .49368 L p
1 g
F P
s
P
p
.002 w
.65399 .45133 m .64819 .49368 L .62468 .49061 L p
1 g
F P
s
P
p
.002 w
.37651 .3915 m .36245 .44188 L .33946 .43474 L p
1 g
F P
s
P
p
.002 w
.33946 .43474 m .35508 .37827 L .37651 .3915 L p
1 g
F P
s
P
p
.002 w
.64579 .40957 m .6242 .37285 L .63863 .35232 L p
1 g
F P
s
P
p
.002 w
.59992 .31961 m .63863 .35232 L .6242 .37285 L p
1 g
F P
s
P
p
.002 w
.39301 .49236 m .4098 .5319 L .38577 .5399 L p
1 g
F P
s
P
p
.002 w
.38577 .5399 m .36577 .49326 L .39301 .49236 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.62468 .49061 m .62916 .45728 L .65399 .45133 L p
1 g
F P
s
P
p
.002 w
.64579 .40957 m .65399 .45133 L .62916 .45728 L p
1 g
F P
s
P
p
.002 w
.55183 .30146 m .49962 .30023 L .49301 .27603 L p
1 g
F P
s
P
p
.002 w
.43655 .29396 m .49301 .27603 L .49962 .30023 L p
1 g
F P
s
P
p
.002 w
.40656 .34795 m .37651 .3915 L .35508 .37827 L p
1 g
F P
s
P
p
.002 w
.35508 .37827 m .38871 .32942 L .40656 .34795 L p
1 g
F P
s
P
p
.002 w
.49962 .30023 m .44925 .3163 L .43655 .29396 L p
1 g
F P
s
P
p
.002 w
.38871 .32942 m .43655 .29396 L .44925 .3163 L p
1 g
F P
s
P
p
.002 w
.44925 .3163 m .40656 .34795 L .38871 .32942 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.6242 .37285 m .59132 .34528 L .59992 .31961 L p
1 g
F P
s
P
p
.002 w
.55183 .30146 m .59992 .31961 L .59132 .34528 L p
1 g
F P
s
P
p
.002 w
.39036 .44888 m .39301 .49236 L .36577 .49326 L p
1 g
F P
s
P
p
.002 w
.36577 .49326 m .36245 .44188 L .39036 .44888 L p
1 g
F P
s
P
p
.002 w
.62916 .45728 m .62259 .42448 L .64579 .40957 L p
1 g
F P
s
P
p
.002 w
.6242 .37285 m .64579 .40957 L .62259 .42448 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60974 .521 m .58595 .54531 L .56987 .52347 L p
1 g
F P
s
P
p
.002 w
.56987 .52347 m .58632 .50664 L .60974 .521 L p
1 g
F P
s
P
p
.002 w
.62468 .49061 m .60974 .521 L .58632 .50664 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.59132 .34528 m .55058 .33007 L .55183 .30146 L p
1 g
F P
s
P
p
.002 w
.49962 .30023 m .55183 .30146 L .55058 .33007 L p
1 g
F P
s
P
p
.002 w
.58632 .50664 m .59662 .48561 L .62468 .49061 L p
1 g
F P
s
P
p
.002 w
.62916 .45728 m .62468 .49061 L .59662 .48561 L p
1 g
F P
s
P
p
.002 w
.40235 .40632 m .39036 .44888 L .36245 .44188 L p
1 g
F P
s
P
p
.002 w
.36245 .44188 m .37651 .3915 L .40235 .40632 L p
1 g
F P
s
P
p
.002 w
.503 .53428 m .5259 .53809 L .52242 .56652 L p
1 g
F P
s
P
p
.002 w
.52242 .56652 m .48924 .56112 L .503 .53428 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59132 .34528 m .6242 .37285 L .60553 .39575 L p
1 g
F P
s
P
p
.002 w
.62259 .42448 m .60553 .39575 L .6242 .37285 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.4098 .5319 m .39301 .49236 L .42428 .48952 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59662 .48561 m .59964 .46257 L .62916 .45728 L p
1 g
F P
s
P
p
.002 w
.62259 .42448 m .62916 .45728 L .59964 .46257 L p
1 g
F P
s
P
p
.002 w
.48274 .52327 m .503 .53428 L .48924 .56112 L p
1 g
F P
s
P
p
.002 w
.48924 .56112 m .4598 .54528 L .48274 .52327 L p
1 g
F P
s
P
p
.002 w
.55058 .33007 m .50644 .32915 L .49962 .30023 L p
1 g
F P
s
P
p
.002 w
.44925 .3163 m .49962 .30023 L .50644 .32915 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42781 .36954 m .40235 .40632 L .37651 .3915 L p
1 g
F P
s
P
p
.002 w
.37651 .3915 m .40656 .34795 L .42781 .36954 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.50644 .32915 m .46388 .3428 L .44925 .3163 L p
1 g
F P
s
P
p
.002 w
.40656 .34795 m .44925 .3163 L .46388 .3428 L p
1 g
F P
s
P
p
.002 w
.60553 .39575 m .57967 .37426 L .59132 .34528 L p
1 g
F P
s
P
p
.002 w
.55058 .33007 m .59132 .34528 L .57967 .37426 L p
1 g
F P
s
P
p
.002 w
.46388 .3428 m .42781 .36954 L .40656 .34795 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42233 .45548 m .42428 .48952 L .39301 .49236 L p
1 g
F P
s
P
p
.002 w
.39301 .49236 m .39036 .44888 L .42233 .45548 L p
1 g
F P
s
P
p
.002 w
.59964 .46257 m .59502 .43997 L .62259 .42448 L p
1 g
F P
s
P
p
.002 w
.60553 .39575 m .62259 .42448 L .59502 .43997 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46733 .50618 m .48274 .52327 L .4598 .54528 L p
1 g
F P
s
P
p
.002 w
.4598 .54528 m .43729 .52056 L .46733 .50618 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.59662 .48561 m .58632 .50664 L .55963 .48955 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52867 .50563 m .54051 .50374 L .54901 .53434 L p
1 g
F P
s
P
p
.002 w
.54901 .53434 m .5259 .53809 L .52867 .50563 L p
1 g
F P
s
P
p
.002 w
.57967 .37426 m .54773 .36248 L .55058 .33007 L p
1 g
F P
s
P
p
.002 w
.50644 .32915 m .55058 .33007 L .54773 .36248 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55963 .48955 m .56488 .47876 L .59662 .48561 L p
1 g
F P
s
P
p
.002 w
.59964 .46257 m .59662 .48561 L .56488 .47876 L p
1 g
F P
s
P
p
.002 w
.43181 .42222 m .42233 .45548 L .39036 .44888 L p
1 g
F P
s
P
p
.002 w
.39036 .44888 m .40235 .40632 L .43181 .42222 L p
1 g
F P
s
P
p
.002 w
.57967 .37426 m .60553 .39575 L .58317 .42023 L p
1 g
F P
s
P
p
.002 w
.59502 .43997 m .58317 .42023 L .60553 .39575 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.51696 .50365 m .52867 .50563 L .5259 .53809 L p
1 g
F P
s
P
p
.002 w
.5259 .53809 m .503 .53428 L .51696 .50365 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45849 .48478 m .46733 .50618 L .43729 .52056 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.56488 .47876 m .56639 .46697 L .59964 .46257 L p
1 g
F P
s
P
p
.002 w
.59502 .43997 m .59964 .46257 L .56639 .46697 L p
1 g
F P
s
P
p
.002 w
.50664 .49797 m .51696 .50365 L .503 .53428 L p
1 g
F P
s
P
p
.002 w
.503 .53428 m .48274 .52327 L .50664 .49797 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.54773 .36248 m .5132 .36187 L .50644 .32915 L p
1 g
F P
s
P
p
.002 w
.46388 .3428 m .50644 .32915 L .5132 .36187 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.45176 .3935 m .43181 .42222 L .40235 .40632 L p
1 g
F P
s
P
p
.002 w
.40235 .40632 m .42781 .36954 L .45176 .3935 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58317 .42023 m .56531 .40554 L .57967 .37426 L p
1 g
F P
s
P
p
.002 w
.54773 .36248 m .57967 .37426 L .56531 .40554 L p
1 g
F P
s
P
p
.002 w
.42428 .48952 m .42233 .45548 L .45726 .4614 L p
1 g
F P
s
P
p
.002 w
.56639 .46697 m .56397 .45544 L .59502 .43997 L p
1 g
F P
s
P
p
.002 w
.58317 .42023 m .59502 .43997 L .56397 .45544 L p
1 g
F P
s
P
p
.002 w
.5132 .36187 m .47995 .3726 L .46388 .3428 L p
1 g
F P
s
P
p
.002 w
.42781 .36954 m .46388 .3428 L .47995 .3726 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47995 .3726 m .45176 .3935 L .42781 .36954 L p
1 g
F P
s
P
p
.002 w
.49883 .48921 m .50664 .49797 L .48274 .52327 L p
1 g
F P
s
P
p
.002 w
.48274 .52327 m .46733 .50618 L .49883 .48921 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56397 .45544 m .55788 .44541 L .58317 .42023 L p
1 g
F P
s
P
p
.002 w
.56531 .40554 m .58317 .42023 L .55788 .44541 L p
1 g
F P
s
P
p
.002 w
.56531 .40554 m .54334 .39756 L .54773 .36248 L p
1 g
F P
s
P
p
.002 w
.5132 .36187 m .54773 .36248 L .54334 .39756 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49439 .4783 m .49883 .48921 L .46733 .50618 L p
1 g
F P
s
P
p
.002 w
.46733 .50618 m .45849 .48478 L .49439 .4783 L p
1 g
F P
s
P
p
.002 w
.46384 .43861 m .45726 .4614 L .42233 .45548 L p
1 g
F P
s
P
p
.002 w
.42233 .45548 m .43181 .42222 L .46384 .43861 L p
1 g
F P
s
P
p
.002 w
.56639 .46697 m .56488 .47876 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56397 .45544 m .56639 .46697 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55788 .44541 m .54874 .43798 L .56531 .40554 L p
1 g
F P
s
P
p
.002 w
.54334 .39756 m .56531 .40554 L .54874 .43798 L p
1 g
F P
s
P
p
.002 w
.54334 .39756 m .51965 .39722 L .5132 .36187 L p
1 g
F P
s
P
p
.002 w
.47995 .3726 m .5132 .36187 L .51965 .39722 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.47754 .41894 m .46384 .43861 L .43181 .42222 L p
1 g
F P
s
P
p
.002 w
.43181 .42222 m .45176 .3935 L .47754 .41894 L p
1 g
F P
s
P
p
.002 w
.55788 .44541 m .56397 .45544 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.49382 .46641 m .49439 .4783 L .45849 .48478 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.51965 .39722 m .49687 .40461 L .47995 .3726 L p
1 g
F P
s
P
p
.002 w
.45176 .3935 m .47995 .3726 L .49687 .40461 L p
1 g
F P
s
P
p
.002 w
.49687 .40461 m .47754 .41894 L .45176 .3935 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.54874 .43798 m .55788 .44541 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54874 .43798 m .53755 .43397 L .54334 .39756 L p
1 g
F P
s
P
p
.002 w
.51965 .39722 m .54334 .39756 L .53755 .43397 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45726 .4614 m .46384 .43861 L .4972 .45485 L p
1 g
F P
s
P
p
.002 w
.53755 .43397 m .54874 .43798 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.52552 .43384 m .53755 .43397 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.51397 .43761 m .52552 .43384 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.50417 .44488 m .51397 .43761 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50855 .44163 L
s
P
p
.002 w
.4972 .45485 m .50417 .44488 L .53059 .4703 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53755 .43397 m .52552 .43384 L .51965 .39722 L p
1 g
F P
s
P
p
.002 w
.49687 .40461 m .51965 .39722 L .52552 .43384 L p
1 g
F P
s
P
p
.002 w
.50417 .44488 m .4972 .45485 L .46384 .43861 L p
1 g
F P
s
P
p
.002 w
.46384 .43861 m .47754 .41894 L .50417 .44488 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.52552 .43384 m .51397 .43761 L .49687 .40461 L p
1 g
F P
s
P
p
.002 w
.47754 .41894 m .49687 .40461 L .51397 .43761 L p
1 g
F P
s
P
p
.002 w
.51397 .43761 m .50417 .44488 L .47754 .41894 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.53059 .4703 m
.54952 .49493 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .77866 .39174 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .54952 .49493 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.434109)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.434109)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49655 .4561 m .5176 .43902 L .49645 .41981 L p
1 g
F P
s
P
p
.002 w
.49645 .41981 m .48209 .43145 L .49655 .4561 L p
1 g
F P
s
P
p
.002 w
.50659 .40442 m .49645 .41981 L .5176 .43902 L p
1 g
F P
s
P
p
.002 w
.48209 .43145 m .49645 .41981 L .47535 .40082 L p
1 g
F P
s
P
p
.002 w
.49645 .41981 m .50659 .40442 L .48049 .39299 L p
1 g
F P
s
P
p
.002 w
.48049 .39299 m .47535 .40082 L .49645 .41981 L p
1 g
F P
s
P
p
.002 w
.47149 .46595 m .49655 .4561 L .48209 .43145 L p
1 g
F P
s
P
p
.002 w
.48209 .43145 m .46499 .43811 L .47149 .46595 L p
1 g
F P
s
P
p
.002 w
.46499 .43811 m .48209 .43145 L .46804 .40673 L p
1 g
F P
s
P
p
.002 w
.47535 .40082 m .46804 .40673 L .48209 .43145 L p
1 g
F P
s
P
p
.002 w
.51115 .48024 m .53841 .4581 L .5176 .43902 L p
1 g
F P
s
P
p
.002 w
.5176 .43902 m .49655 .4561 L .51115 .48024 L p
1 g
F P
s
P
p
.002 w
.53252 .41646 m .5176 .43902 L .53841 .4581 L p
1 g
F P
s
P
p
.002 w
.5176 .43902 m .53252 .41646 L .50659 .40442 L p
1 g
F P
s
P
p
.002 w
.47871 .49309 m .51115 .48024 L .49655 .4561 L p
1 g
F P
s
P
p
.002 w
.49655 .4561 m .47149 .46595 L .47871 .49309 L p
1 g
F P
s
P
p
.002 w
.51144 .38685 m .50659 .40442 L .53252 .41646 L p
1 g
F P
s
P
p
.002 w
.50659 .40442 m .51144 .38685 L .48291 .38406 L p
1 g
F P
s
P
p
.002 w
.48291 .38406 m .48049 .39299 L .50659 .40442 L p
1 g
F P
s
P
p
.002 w
.53841 .4581 m .55779 .42891 L .53252 .41646 L p
1 g
F P
s
P
p
.002 w
.53973 .3907 m .53252 .41646 L .55779 .42891 L p
1 g
F P
s
P
p
.002 w
.53252 .41646 m .53973 .3907 L .51144 .38685 L p
1 g
F P
s
P
p
.002 w
.44497 .46749 m .47149 .46595 L .46499 .43811 L p
1 g
F P
s
P
p
.002 w
.46499 .43811 m .44694 .43907 L .44497 .46749 L p
1 g
F P
s
P
p
.002 w
.44694 .43907 m .46499 .43811 L .45935 .41009 L p
1 g
F P
s
P
p
.002 w
.46804 .40673 m .45935 .41009 L .46499 .43811 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .46804 .40673 L .47535 .40082 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .47535 .40082 L .48049 .39299 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .45935 .41009 L .46804 .40673 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .48049 .39299 L .48291 .38406 L closepath p
1 g
F P
s
P
p
.002 w
.51044 .36894 m .51144 .38685 L .53973 .3907 L p
1 g
F P
s
P
p
.002 w
.51144 .38685 m .51044 .36894 L .48235 .37499 L p
1 g
F P
s
P
p
.002 w
.48235 .37499 m .48291 .38406 L .51144 .38685 L p
1 g
F P
s
P
p
.002 w
.44433 .49526 m .47871 .49309 L .47149 .46595 L p
1 g
F P
s
P
p
.002 w
.47149 .46595 m .44497 .46749 L .44433 .49526 L p
1 g
F P
s
P
p
.002 w
.45935 .41009 m .45019 .41053 L .44694 .43907 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .45019 .41053 L .45935 .41009 L closepath p
1 g
F P
s
P
p
.002 w
.52564 .50343 m .5585 .47671 L .53841 .4581 L p
1 g
F P
s
P
p
.002 w
.53841 .4581 m .51115 .48024 L .52564 .50343 L p
1 g
F P
s
P
p
.002 w
.55779 .42891 m .53841 .4581 L .5585 .47671 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .48291 .38406 L .48235 .37499 L closepath p
1 g
F P
s
P
p
.002 w
.48655 .51904 m .52564 .50343 L .51115 .48024 L p
1 g
F P
s
P
p
.002 w
.51115 .48024 m .47871 .49309 L .48655 .51904 L p
1 g
F P
s
P
p
.002 w
.42982 .43418 m .44694 .43907 L .45019 .41053 L p
1 g
F P
s
P
p
.002 w
.45019 .41053 m .44153 .408 L .42982 .43418 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .44153 .408 L .45019 .41053 L closepath p
1 g
F P
s
P
p
.002 w
.41973 .46046 m .44497 .46749 L .44694 .43907 L p
1 g
F P
s
P
p
.002 w
.44694 .43907 m .42982 .43418 L .41973 .46046 L p
1 g
F P
s
P
p
.002 w
.55779 .42891 m .56727 .39555 L .53973 .3907 L p
1 g
F P
s
P
p
.002 w
.53842 .36437 m .53973 .3907 L .56727 .39555 L p
1 g
F P
s
P
p
.002 w
.53973 .3907 m .53842 .36437 L .51044 .36894 L p
1 g
F P
s
P
p
.002 w
.5585 .47671 m .58193 .44154 L .55779 .42891 L p
1 g
F P
s
P
p
.002 w
.56727 .39555 m .55779 .42891 L .58193 .44154 L p
1 g
F P
s
P
p
.002 w
.47885 .36675 m .48235 .37499 L .51044 .36894 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .48235 .37499 L .47885 .36675 L closepath p
1 g
F P
s
P
p
.002 w
.50365 .3526 m .51044 .36894 L .53842 .36437 L p
1 g
F P
s
P
p
.002 w
.51044 .36894 m .50365 .3526 L .47885 .36675 L p
1 g
F P
s
P
p
.002 w
.41548 .42389 m .42982 .43418 L .44153 .408 L p
1 g
F P
s
P
p
.002 w
.44153 .408 m .43432 .40274 L .41548 .42389 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .43432 .40274 L .44153 .408 L closepath p
1 g
F P
s
P
p
.002 w
.44505 .52186 m .48655 .51904 L .47871 .49309 L p
1 g
F P
s
P
p
.002 w
.47871 .49309 m .44433 .49526 L .44505 .52186 L p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .47885 .36675 L .47277 .36022 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .47277 .36022 L .46475 .35614 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .46475 .35614 L .45566 .35497 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .45566 .35497 L .44649 .35685 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .44649 .35685 L .43826 .36159 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .43826 .36159 L .43187 .36866 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .43187 .36866 L .42803 .37728 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .42803 .37728 L .42716 .38651 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .42716 .38651 L .42935 .39531 L closepath p
1 g
F P
s
P
p
.002 w
.45466 .38239 m .42935 .39531 L .43432 .40274 L closepath p
1 g
F P
s
P
p
.002 w
.4115 .48634 m .44433 .49526 L .44497 .46749 L p
1 g
F P
s
P
p
.002 w
.44497 .46749 m .41973 .46046 L .4115 .48634 L p
1 g
F P
s
P
p
.002 w
.47277 .36022 m .47885 .36675 L .50365 .3526 L p
1 g
F P
s
P
p
.002 w
.39849 .44544 m .41973 .46046 L .42982 .43418 L p
1 g
F P
s
P
p
.002 w
.42982 .43418 m .41548 .42389 L .39849 .44544 L p
1 g
F P
s
P
p
.002 w
.4055 .40923 m .41548 .42389 L .43432 .40274 L p
1 g
F P
s
P
p
.002 w
.43432 .40274 m .42935 .39531 L .4055 .40923 L p
1 g
F P
s
P
p
.002 w
.53974 .52521 m .57748 .49449 L .5585 .47671 L p
1 g
F P
s
P
p
.002 w
.5585 .47671 m .52564 .50343 L .53974 .52521 L p
1 g
F P
s
P
p
.002 w
.58193 .44154 m .5585 .47671 L .57748 .49449 L p
1 g
F P
s
P
p
.002 w
.50365 .3526 m .4917 .33959 L .47277 .36022 L p
1 g
F P
s
P
p
.002 w
.46475 .35614 m .47277 .36022 L .4917 .33959 L p
1 g
F P
s
P
p
.002 w
.58193 .44154 m .59353 .40132 L .56727 .39555 L p
1 g
F P
s
P
p
.002 w
.56577 .36137 m .56727 .39555 L .59353 .40132 L p
1 g
F P
s
P
p
.002 w
.56727 .39555 m .56577 .36137 L .53842 .36437 L p
1 g
F P
s
P
p
.002 w
.52858 .34023 m .53842 .36437 L .56577 .36137 L p
1 g
F P
s
P
p
.002 w
.53842 .36437 m .52858 .34023 L .50365 .3526 L p
1 g
F P
s
P
p
.002 w
.49486 .54327 m .53974 .52521 L .52564 .50343 L p
1 g
F P
s
P
p
.002 w
.52564 .50343 m .48655 .51904 L .49486 .54327 L p
1 g
F P
s
P
p
.002 w
.4917 .33959 m .50365 .3526 L .52858 .34023 L p
1 g
F P
s
P
p
.002 w
.40106 .39177 m .4055 .40923 L .42935 .39531 L p
1 g
F P
s
P
p
.002 w
.42935 .39531 m .42716 .38651 L .40106 .39177 L p
1 g
F P
s
P
p
.002 w
.4917 .33959 m .47584 .33138 L .46475 .35614 L p
1 g
F P
s
P
p
.002 w
.45566 .35497 m .46475 .35614 L .47584 .33138 L p
1 g
F P
s
P
p
.002 w
.57748 .49449 m .60447 .45411 L .58193 .44154 L p
1 g
F P
s
P
p
.002 w
.59353 .40132 m .58193 .44154 L .60447 .45411 L p
1 g
F P
s
P
p
.002 w
.38361 .42391 m .39849 .44544 L .41548 .42389 L p
1 g
F P
s
P
p
.002 w
.41548 .42389 m .4055 .40923 L .38361 .42391 L p
1 g
F P
s
P
p
.002 w
.4027 .3734 m .40106 .39177 L .42716 .38651 L p
1 g
F P
s
P
p
.002 w
.42716 .38651 m .42803 .37728 L .4027 .3734 L p
1 g
F P
s
P
p
.002 w
.40532 .51131 m .44505 .52186 L .44433 .49526 L p
1 g
F P
s
P
p
.002 w
.44433 .49526 m .4115 .48634 L .40532 .51131 L p
1 g
F P
s
P
p
.002 w
.38373 .467 m .4115 .48634 L .41973 .46046 L p
1 g
F P
s
P
p
.002 w
.41973 .46046 m .39849 .44544 L .38373 .467 L p
1 g
F P
s
P
p
.002 w
.47584 .33138 m .45778 .32896 L .45566 .35497 L p
1 g
F P
s
P
p
.002 w
.44649 .35685 m .45566 .35497 L .45778 .32896 L p
1 g
F P
s
P
p
.002 w
.4103 .35618 m .4027 .3734 L .42803 .37728 L p
1 g
F P
s
P
p
.002 w
.42803 .37728 m .43187 .36866 L .4103 .35618 L p
1 g
F P
s
P
p
.002 w
.44716 .54672 m .49486 .54327 L .48655 .51904 L p
1 g
F P
s
P
p
.002 w
.48655 .51904 m .44505 .52186 L .44716 .54672 L p
1 g
F P
s
P
p
.002 w
.45778 .32896 m .43949 .33264 L .44649 .35685 L p
1 g
F P
s
P
p
.002 w
.43826 .36159 m .44649 .35685 L .43949 .33264 L p
1 g
F P
s
P
p
.002 w
.52858 .34023 m .51111 .32091 L .4917 .33959 L p
1 g
F P
s
P
p
.002 w
.47584 .33138 m .4917 .33959 L .51111 .32091 L p
1 g
F P
s
P
p
.002 w
.42304 .34206 m .4103 .35618 L .43187 .36866 L p
1 g
F P
s
P
p
.002 w
.43187 .36866 m .43826 .36159 L .42304 .34206 L p
1 g
F P
s
P
p
.002 w
.43949 .33264 m .42304 .34206 L .43826 .36159 L p
1 g
F P
s
P
p
.002 w
.56577 .36137 m .55319 .32991 L .52858 .34023 L p
1 g
F P
s
P
p
.002 w
.51111 .32091 m .52858 .34023 L .55319 .32991 L p
1 g
F P
s
P
p
.002 w
.55319 .32991 m .56577 .36137 L .59194 .36003 L p
1 g
F P
s
P
p
.002 w
.59353 .40132 m .59194 .36003 L .56577 .36137 L p
1 g
F P
s
P
p
.002 w
.37688 .3981 m .38361 .42391 L .4055 .40923 L p
1 g
F P
s
P
p
.002 w
.4055 .40923 m .40106 .39177 L .37688 .3981 L p
1 g
F P
s
P
p
.002 w
.60447 .45411 m .61798 .40793 L .59353 .40132 L p
1 g
F P
s
P
p
.002 w
.59194 .36003 m .59353 .40132 L .61798 .40793 L p
1 g
F P
s
P
p
.002 w
.55317 .54512 m .59496 .51107 L .57748 .49449 L p
1 g
F P
s
P
p
.002 w
.57748 .49449 m .53974 .52521 L .55317 .54512 L p
1 g
F P
s
P
p
.002 w
.60447 .45411 m .57748 .49449 L .59496 .51107 L p
1 g
F P
s
P
p
.002 w
.51111 .32091 m .48775 .30863 L .47584 .33138 L p
1 g
F P
s
P
p
.002 w
.45778 .32896 m .47584 .33138 L .48775 .30863 L p
1 g
F P
s
P
p
.002 w
.36417 .43907 m .38373 .467 L .39849 .44544 L p
1 g
F P
s
P
p
.002 w
.39849 .44544 m .38361 .42391 L .36417 .43907 L p
1 g
F P
s
P
p
.002 w
.5035 .56525 m .55317 .54512 L .53974 .52521 L p
1 g
F P
s
P
p
.002 w
.53974 .52521 m .49486 .54327 L .5035 .56525 L p
1 g
F P
s
P
p
.002 w
.37157 .48813 m .40532 .51131 L .4115 .48634 L p
1 g
F P
s
P
p
.002 w
.4115 .48634 m .38373 .467 L .37157 .48813 L p
1 g
F P
s
P
p
.002 w
.3792 .37085 m .37688 .3981 L .40106 .39177 L p
1 g
F P
s
P
p
.002 w
.40106 .39177 m .4027 .3734 L .3792 .37085 L p
1 g
F P
s
P
p
.002 w
.40138 .53484 m .44716 .54672 L .44505 .52186 L p
1 g
F P
s
P
p
.002 w
.44505 .52186 m .40532 .51131 L .40138 .53484 L p
1 g
F P
s
P
p
.002 w
.59496 .51107 m .62493 .46639 L .60447 .45411 L p
1 g
F P
s
P
p
.002 w
.61798 .40793 m .60447 .45411 L .62493 .46639 L p
1 g
F P
s
P
p
.002 w
.48775 .30863 m .461 .3049 L .45778 .32896 L p
1 g
F P
s
P
p
.002 w
.43949 .33264 m .45778 .32896 L .461 .3049 L p
1 g
F P
s
P
p
.002 w
.55319 .32991 m .53061 .30461 L .51111 .32091 L p
1 g
F P
s
P
p
.002 w
.48775 .30863 m .51111 .32091 L .53061 .30461 L p
1 g
F P
s
P
p
.002 w
.39044 .34525 m .3792 .37085 L .4027 .3734 L p
1 g
F P
s
P
p
.002 w
.4027 .3734 m .4103 .35618 L .39044 .34525 L p
1 g
F P
s
P
p
.002 w
.45066 .56929 m .5035 .56525 L .49486 .54327 L p
1 g
F P
s
P
p
.002 w
.49486 .54327 m .44716 .54672 L .45066 .56929 L p
1 g
F P
s
P
p
.002 w
.59194 .36003 m .57698 .3219 L .55319 .32991 L p
1 g
F P
s
P
p
.002 w
.53061 .30461 m .55319 .32991 L .57698 .3219 L p
1 g
F P
s
P
p
.002 w
.461 .3049 m .43383 .31027 L .43949 .33264 L p
1 g
F P
s
P
p
.002 w
.42304 .34206 m .43949 .33264 L .43383 .31027 L p
1 g
F P
s
P
p
.002 w
.57698 .3219 m .59194 .36003 L .61639 .36043 L p
1 g
F P
s
P
p
.002 w
.61798 .40793 m .61639 .36043 L .59194 .36003 L p
1 g
F P
s
P
p
.002 w
.40937 .32425 m .39044 .34525 L .4103 .35618 L p
1 g
F P
s
P
p
.002 w
.4103 .35618 m .42304 .34206 L .40937 .32425 L p
1 g
F P
s
P
p
.002 w
.3552 .40543 m .36417 .43907 L .38361 .42391 L p
1 g
F P
s
P
p
.002 w
.38361 .42391 m .37688 .3981 L .3552 .40543 L p
1 g
F P
s
P
p
.002 w
.43383 .31027 m .40937 .32425 L .42304 .34206 L p
1 g
F P
s
P
p
.002 w
.62493 .46639 m .64006 .41528 L .61798 .40793 L p
1 g
F P
s
P
p
.002 w
.61639 .36043 m .61798 .40793 L .64006 .41528 L p
1 g
F P
s
P
p
.002 w
.34766 .45443 m .37157 .48813 L .38373 .467 L p
1 g
F P
s
P
p
.002 w
.38373 .467 m .36417 .43907 L .34766 .45443 L p
1 g
F P
s
P
p
.002 w
.53061 .30461 m .50024 .28841 L .48775 .30863 L p
1 g
F P
s
P
p
.002 w
.461 .3049 m .48775 .30863 L .50024 .28841 L p
1 g
F P
s
P
p
.002 w
.36236 .50837 m .40138 .53484 L .40532 .51131 L p
1 g
F P
s
P
p
.002 w
.40532 .51131 m .37157 .48813 L .36236 .50837 L p
1 g
F P
s
P
p
.002 w
.56563 .56269 m .61053 .52608 L .59496 .51107 L p
1 g
F P
s
P
p
.002 w
.59496 .51107 m .55317 .54512 L .56563 .56269 L p
1 g
F P
s
P
p
.002 w
.62493 .46639 m .59496 .51107 L .61053 .52608 L p
1 g
F P
s
P
p
.002 w
.5123 .58444 m .56563 .56269 L .55317 .54512 L p
1 g
F P
s
P
p
.002 w
.55317 .54512 m .5035 .56525 L .5123 .58444 L p
1 g
F P
s
P
p
.002 w
.3581 .36976 m .3552 .40543 L .37688 .3981 L p
1 g
F P
s
P
p
.002 w
.37688 .3981 m .3792 .37085 L .3581 .36976 L p
1 g
F P
s
P
p
.002 w
.39985 .55637 m .45066 .56929 L .44716 .54672 L p
1 g
F P
s
P
p
.002 w
.44716 .54672 m .40138 .53484 L .39985 .55637 L p
1 g
F P
s
P
p
.002 w
.57698 .3219 m .54983 .29109 L .53061 .30461 L p
1 g
F P
s
P
p
.002 w
.50024 .28841 m .53061 .30461 L .54983 .29109 L p
1 g
F P
s
P
p
.002 w
.61053 .52608 m .6428 .47811 L .62493 .46639 L p
1 g
F P
s
P
p
.002 w
.64006 .41528 m .62493 .46639 L .6428 .47811 L p
1 g
F P
s
P
p
.002 w
.50024 .28841 m .4653 .28337 L .461 .3049 L p
1 g
F P
s
P
p
.002 w
.43383 .31027 m .461 .3049 L .4653 .28337 L p
1 g
F P
s
P
p
.002 w
.61639 .36043 m .59942 .31644 L .57698 .3219 L p
1 g
F P
s
P
p
.002 w
.54983 .29109 m .57698 .3219 L .59942 .31644 L p
1 g
F P
s
P
p
.002 w
.37276 .33616 m .3581 .36976 L .3792 .37085 L p
1 g
F P
s
P
p
.002 w
.3792 .37085 m .39044 .34525 L .37276 .33616 L p
1 g
F P
s
P
p
.002 w
.45554 .58898 m .5123 .58444 L .5035 .56525 L p
1 g
F P
s
P
p
.002 w
.5035 .56525 m .45066 .56929 L .45554 .58898 L p
1 g
F P
s
P
p
.002 w
.59942 .31644 m .61639 .36043 L .63854 .36263 L p
1 g
F P
s
P
p
.002 w
.64006 .41528 m .63854 .36263 L .61639 .36043 L p
1 g
F P
s
P
p
.002 w
.33657 .41362 m .34766 .45443 L .36417 .43907 L p
1 g
F P
s
P
p
.002 w
.36417 .43907 m .3552 .40543 L .33657 .41362 L p
1 g
F P
s
P
p
.002 w
.4653 .28337 m .4297 .29031 L .43383 .31027 L p
1 g
F P
s
P
p
.002 w
.40937 .32425 m .43383 .31027 L .4297 .29031 L p
1 g
F P
s
P
p
.002 w
.39759 .30859 m .37276 .33616 L .39044 .34525 L p
1 g
F P
s
P
p
.002 w
.39044 .34525 m .40937 .32425 L .39759 .30859 L p
1 g
F P
s
P
p
.002 w
.4297 .29031 m .39759 .30859 L .40937 .32425 L p
1 g
F P
s
P
p
.002 w
.33458 .46964 m .36236 .50837 L .37157 .48813 L p
1 g
F P
s
P
p
.002 w
.37157 .48813 m .34766 .45443 L .33458 .46964 L p
1 g
F P
s
P
p
.002 w
.6428 .47811 m .65922 .42324 L .64006 .41528 L p
1 g
F P
s
P
p
.002 w
.63854 .36263 m .64006 .41528 L .65922 .42324 L p
1 g
F P
s
P
p
.002 w
.54983 .29109 m .51309 .27124 L .50024 .28841 L p
1 g
F P
s
P
p
.002 w
.4653 .28337 m .50024 .28841 L .51309 .27124 L p
1 g
F P
s
P
p
.002 w
.35643 .52724 m .39985 .55637 L .40138 .53484 L p
1 g
F P
s
P
p
.002 w
.40138 .53484 m .36236 .50837 L .35643 .52724 L p
1 g
F P
s
P
p
.002 w
.57681 .57744 m .62376 .53912 L .61053 .52608 L p
1 g
F P
s
P
p
.002 w
.61053 .52608 m .56563 .56269 L .57681 .57744 L p
1 g
F P
s
P
p
.002 w
.6428 .47811 m .61053 .52608 L .62376 .53912 L p
1 g
F P
s
P
p
.002 w
.33997 .3702 m .33657 .41362 L .3552 .40543 L p
1 g
F P
s
P
p
.002 w
.3552 .40543 m .3581 .36976 L .33997 .3702 L p
1 g
F P
s
P
p
.002 w
.40089 .57533 m .45554 .58898 L .45066 .56929 L p
1 g
F P
s
P
p
.002 w
.45066 .56929 m .39985 .55637 L .40089 .57533 L p
1 g
F P
s
P
p
.002 w
.52108 .60029 m .57681 .57744 L .56563 .56269 L p
1 g
F P
s
P
p
.002 w
.56563 .56269 m .5123 .58444 L .52108 .60029 L p
1 g
F P
s
P
p
.002 w
.59942 .31644 m .56833 .28076 L .54983 .29109 L p
1 g
F P
s
P
p
.002 w
.51309 .27124 m .54983 .29109 L .56833 .28076 L p
1 g
F P
s
P
p
.002 w
.62376 .53912 m .65757 .48899 L .6428 .47811 L p
1 g
F P
s
P
p
.002 w
.65922 .42324 m .6428 .47811 L .65757 .48899 L p
1 g
F P
s
P
p
.002 w
.51309 .27124 m .47063 .26494 L .4653 .28337 L p
1 g
F P
s
P
p
.002 w
.4297 .29031 m .4653 .28337 L .47063 .26494 L p
1 g
F P
s
P
p
.002 w
.63854 .36263 m .61998 .31376 L .59942 .31644 L p
1 g
F P
s
P
p
.002 w
.56833 .28076 m .59942 .31644 L .61998 .31376 L p
1 g
F P
s
P
p
.002 w
.32158 .42254 m .33458 .46964 L .34766 .45443 L p
1 g
F P
s
P
p
.002 w
.34766 .45443 m .33657 .41362 L .32158 .42254 L p
1 g
F P
s
P
p
.002 w
.61998 .31376 m .63854 .36263 L .65781 .36666 L p
1 g
F P
s
P
p
.002 w
.65922 .42324 m .65781 .36666 L .63854 .36263 L p
1 g
F P
s
P
p
.002 w
.35777 .32921 m .33997 .3702 L .3581 .36976 L p
1 g
F P
s
P
p
.002 w
.3581 .36976 m .37276 .33616 L .35777 .32921 L p
1 g
F P
s
P
p
.002 w
.46176 .6052 m .52108 .60029 L .5123 .58444 L p
1 g
F P
s
P
p
.002 w
.5123 .58444 m .45554 .58898 L .46176 .6052 L p
1 g
F P
s
P
p
.002 w
.47063 .26494 m .42725 .27329 L .4297 .29031 L p
1 g
F P
s
P
p
.002 w
.39759 .30859 m .4297 .29031 L .42725 .27329 L p
1 g
F P
s
P
p
.002 w
.3254 .48436 m .35643 .52724 L .36236 .50837 L p
1 g
F P
s
P
p
.002 w
.36236 .50837 m .33458 .46964 L .3254 .48436 L p
1 g
F P
s
P
p
.002 w
.38805 .29556 m .35777 .32921 L .37276 .33616 L p
1 g
F P
s
P
p
.002 w
.37276 .33616 m .39759 .30859 L .38805 .29556 L p
1 g
F P
s
P
p
.002 w
.42725 .27329 m .38805 .29556 L .39759 .30859 L p
1 g
F P
s
P
p
.002 w
.65757 .48899 m .67488 .43166 L .65922 .42324 L p
1 g
F P
s
P
p
.002 w
.65781 .36666 m .65922 .42324 L .67488 .43166 L p
1 g
F P
s
P
p
.002 w
.56833 .28076 m .52603 .25765 L .51309 .27124 L p
1 g
F P
s
P
p
.002 w
.47063 .26494 m .51309 .27124 L .52603 .25765 L p
1 g
F P
s
P
p
.002 w
.35409 .54421 m .40089 .57533 L .39985 .55637 L p
1 g
F P
s
P
p
.002 w
.39985 .55637 m .35643 .52724 L .35409 .54421 L p
1 g
F P
s
P
p
.002 w
.32539 .37225 m .32158 .42254 L .33657 .41362 L p
1 g
F P
s
P
p
.002 w
.33657 .41362 m .33997 .3702 L .32539 .37225 L p
1 g
F P
s
P
p
.002 w
.4046 .59113 m .46176 .6052 L .45554 .58898 L p
1 g
F P
s
P
p
.002 w
.45554 .58898 m .40089 .57533 L .4046 .59113 L p
1 g
F P
s
P
p
.002 w
.61998 .31376 m .58567 .27401 L .56833 .28076 L p
1 g
F P
s
P
p
.002 w
.52603 .25765 m .56833 .28076 L .58567 .27401 L p
1 g
F P
s
P
p
.002 w
.58639 .58887 m .63424 .5498 L .62376 .53912 L p
1 g
F P
s
P
p
.002 w
.62376 .53912 m .57681 .57744 L .58639 .58887 L p
1 g
F P
s
P
p
.002 w
.65757 .48899 m .62376 .53912 L .63424 .5498 L p
1 g
F P
s
P
p
.002 w
.52964 .61224 m .58639 .58887 L .57681 .57744 L p
1 g
F P
s
P
p
.002 w
.57681 .57744 m .52108 .60029 L .52964 .61224 L p
1 g
F P
s
P
p
.002 w
.65781 .36666 m .63808 .31406 L .61998 .31376 L p
1 g
F P
s
P
p
.002 w
.58567 .27401 m .61998 .31376 L .63808 .31406 L p
1 g
F P
s
P
p
.002 w
.63424 .5498 m .66874 .49873 L .65757 .48899 L p
1 g
F P
s
P
p
.002 w
.67488 .43166 m .65757 .48899 L .66874 .49873 L p
1 g
F P
s
P
p
.002 w
.52603 .25765 m .47693 .25021 L .47063 .26494 L p
1 g
F P
s
P
p
.002 w
.42725 .27329 m .47063 .26494 L .47693 .25021 L p
1 g
F P
s
P
p
.002 w
.31079 .43201 m .3254 .48436 L .33458 .46964 L p
1 g
F P
s
P
p
.002 w
.33458 .46964 m .32158 .42254 L .31079 .43201 L p
1 g
F P
s
P
p
.002 w
.63808 .31406 m .65781 .36666 L .6736 .37252 L p
1 g
F P
s
P
p
.002 w
.67488 .43166 m .6736 .37252 L .65781 .36666 L p
1 g
F P
s
P
p
.002 w
.34597 .32467 m .32539 .37225 L .33997 .3702 L p
1 g
F P
s
P
p
.002 w
.33997 .3702 m .35777 .32921 L .34597 .32467 L p
1 g
F P
s
P
p
.002 w
.46924 .61738 m .52964 .61224 L .52108 .60029 L p
1 g
F P
s
P
p
.002 w
.52108 .60029 m .46176 .6052 L .46924 .61738 L p
1 g
F P
s
P
p
.002 w
.32057 .4982 m .35409 .54421 L .35643 .52724 L p
1 g
F P
s
P
p
.002 w
.35643 .52724 m .3254 .48436 L .32057 .4982 L p
1 g
F P
s
P
p
.002 w
.47693 .25021 m .42663 .25979 L .42725 .27329 L p
1 g
F P
s
P
p
.002 w
.38805 .29556 m .42725 .27329 L .42663 .25979 L p
1 g
F P
s
P
p
.002 w
.38112 .2856 m .34597 .32467 L .35777 .32921 L p
1 g
F P
s
P
p
.002 w
.35777 .32921 m .38805 .29556 L .38112 .2856 L p
1 g
F P
s
P
p
.002 w
.58567 .27401 m .53875 .24815 L .52603 .25765 L p
1 g
F P
s
P
p
.002 w
.47693 .25021 m .52603 .25765 L .53875 .24815 L p
1 g
F P
s
P
p
.002 w
.66874 .49873 m .68649 .44036 L .67488 .43166 L p
1 g
F P
s
P
p
.002 w
.6736 .37252 m .67488 .43166 L .68649 .44036 L p
1 g
F P
s
P
p
.002 w
.42663 .25979 m .38112 .2856 L .38805 .29556 L p
1 g
F P
s
P
p
.002 w
.35561 .55876 m .4046 .59113 L .40089 .57533 L p
1 g
F P
s
P
p
.002 w
.40089 .57533 m .35409 .54421 L .35561 .55876 L p
1 g
F P
s
P
p
.002 w
.63808 .31406 m .60136 .27118 L .58567 .27401 L p
1 g
F P
s
P
p
.002 w
.53875 .24815 m .58567 .27401 L .60136 .27118 L p
1 g
F P
s
P
p
.002 w
.31492 .37595 m .31079 .43201 L .32158 .42254 L p
1 g
F P
s
P
p
.002 w
.32158 .42254 m .32539 .37225 L .31492 .37595 L p
1 g
F P
s
P
p
.002 w
.41105 .6032 m .46924 .61738 L .46176 .6052 L p
1 g
F P
s
P
p
.002 w
.46176 .6052 m .4046 .59113 L .41105 .6032 L p
1 g
F P
s
P
p
.002 w
.59404 .59652 m .64154 .55771 L .63424 .5498 L p
1 g
F P
s
P
p
.002 w
.63424 .5498 m .58639 .58887 L .59404 .59652 L p
1 g
F P
s
P
p
.002 w
.66874 .49873 m .63424 .5498 L .64154 .55771 L p
1 g
F P
s
P
p
.002 w
.53774 .61977 m .59404 .59652 L .58639 .58887 L p
1 g
F P
s
P
p
.002 w
.58639 .58887 m .52964 .61224 L .53774 .61977 L p
1 g
F P
s
P
p
.002 w
.6736 .37252 m .65317 .31749 L .63808 .31406 L p
1 g
F P
s
P
p
.002 w
.60136 .27118 m .63808 .31406 L .65317 .31749 L p
1 g
F P
s
P
p
.002 w
.53875 .24815 m .48411 .23973 L .47693 .25021 L p
1 g
F P
s
P
p
.002 w
.42663 .25979 m .47693 .25021 L .48411 .23973 L p
1 g
F P
s
P
p
.002 w
.64154 .55771 m .67583 .50704 L .66874 .49873 L p
1 g
F P
s
P
p
.002 w
.68649 .44036 m .66874 .49873 L .67583 .50704 L p
1 g
F P
s
P
p
.002 w
.30471 .44183 m .32057 .4982 L .3254 .48436 L p
1 g
F P
s
P
p
.002 w
.3254 .48436 m .31079 .43201 L .30471 .44183 L p
1 g
F P
s
P
p
.002 w
.65317 .31749 m .6736 .37252 L .68533 .38016 L p
1 g
F P
s
P
p
.002 w
.68649 .44036 m .68533 .38016 L .6736 .37252 L p
1 g
F P
s
P
p
.002 w
.33786 .32282 m .31492 .37595 L .32539 .37225 L p
1 g
F P
s
P
p
.002 w
.32539 .37225 m .34597 .32467 L .33786 .32282 L p
1 g
F P
s
P
p
.002 w
.47786 .62495 m .53774 .61977 L .52964 .61224 L p
1 g
F P
s
P
p
.002 w
.52964 .61224 m .46924 .61738 L .47786 .62495 L p
1 g
F P
s
P
p
.002 w
.32046 .51073 m .35561 .55876 L .35409 .54421 L p
1 g
F P
s
P
p
.002 w
.35409 .54421 m .32057 .4982 L .32046 .51073 L p
1 g
F P
s
P
p
.002 w
.48411 .23973 m .42797 .25035 L .42663 .25979 L p
1 g
F P
s
P
p
.002 w
.38112 .2856 m .42663 .25979 L .42797 .25035 L p
1 g
F P
s
P
p
.002 w
.60136 .27118 m .55092 .24322 L .53875 .24815 L p
1 g
F P
s
P
p
.002 w
.48411 .23973 m .53875 .24815 L .55092 .24322 L p
1 g
F P
s
P
p
.002 w
.67583 .50704 m .69351 .44916 L .68649 .44036 L p
1 g
F P
s
P
p
.002 w
.68533 .38016 m .68649 .44036 L .69351 .44916 L p
1 g
F P
s
P
p
.002 w
.36116 .57037 m .41105 .6032 L .4046 .59113 L p
1 g
F P
s
P
p
.002 w
.4046 .59113 m .35561 .55876 L .36116 .57037 L p
1 g
F P
s
P
p
.002 w
.37713 .27916 m .33786 .32282 L .34597 .32467 L p
1 g
F P
s
P
p
.002 w
.34597 .32467 m .38112 .2856 L .37713 .27916 L p
1 g
F P
s
P
p
.002 w
.42797 .25035 m .37713 .27916 L .38112 .2856 L p
1 g
F P
s
P
p
.002 w
.65317 .31749 m .61491 .27258 L .60136 .27118 L p
1 g
F P
s
P
p
.002 w
.55092 .24322 m .60136 .27118 L .61491 .27258 L p
1 g
F P
s
P
p
.002 w
.30912 .38132 m .30471 .44183 L .31079 .43201 L p
1 g
F P
s
P
p
.002 w
.31079 .43201 m .31492 .37595 L .30912 .38132 L p
1 g
F P
s
P
p
.002 w
.42021 .61099 m .47786 .62495 L .46924 .61738 L p
1 g
F P
s
P
p
.002 w
.46924 .61738 m .41105 .6032 L .42021 .61099 L p
1 g
F P
s
P
p
.002 w
.59944 .59994 m .64528 .56249 L .64154 .55771 L p
1 g
F P
s
P
p
.002 w
.64154 .55771 m .59404 .59652 L .59944 .59994 L p
1 g
F P
s
P
p
.002 w
.67583 .50704 m .64154 .55771 L .64528 .56249 L p
1 g
F P
s
P
p
.002 w
.68533 .38016 m .66467 .32414 L .65317 .31749 L p
1 g
F P
s
P
p
.002 w
.61491 .27258 m .65317 .31749 L .66467 .32414 L p
1 g
F P
s
P
p
.002 w
.54515 .6224 m .59944 .59994 L .59404 .59652 L p
1 g
F P
s
P
p
.002 w
.59404 .59652 m .53774 .61977 L .54515 .6224 L p
1 g
F P
s
P
p
.002 w
.55092 .24322 m .49201 .23406 L .48411 .23973 L p
1 g
F P
s
P
p
.002 w
.42797 .25035 m .48411 .23973 L .49201 .23406 L p
1 g
F P
s
P
p
.002 w
.64528 .56249 m .67839 .5136 L .67583 .50704 L p
1 g
F P
s
P
p
.002 w
.69351 .44916 m .67583 .50704 L .67839 .5136 L p
1 g
F P
s
P
p
.002 w
.30381 .45175 m .32046 .51073 L .32057 .4982 L p
1 g
F P
s
P
p
.002 w
.32057 .4982 m .30471 .44183 L .30381 .45175 L p
1 g
F P
s
P
p
.002 w
.66467 .32414 m .68533 .38016 L .69245 .3895 L p
1 g
F P
s
P
p
.002 w
.69351 .44916 m .69245 .3895 L .68533 .38016 L p
1 g
F P
s
P
p
.002 w
.33389 .32388 m .30912 .38132 L .31492 .37595 L p
1 g
F P
s
P
p
.002 w
.31492 .37595 m .33786 .32282 L .33389 .32388 L p
1 g
F P
s
P
p
.002 w
.48746 .62743 m .54515 .6224 L .53774 .61977 L p
1 g
F P
s
P
p
.002 w
.53774 .61977 m .47786 .62495 L .48746 .62743 L p
1 g
F P
s
P
p
.002 w
.32538 .52154 m .36116 .57037 L .35561 .55876 L p
1 g
F P
s
P
p
.002 w
.35561 .55876 m .32046 .51073 L .32538 .52154 L p
1 g
F P
s
P
p
.002 w
.49201 .23406 m .43137 .24549 L .42797 .25035 L p
1 g
F P
s
P
p
.002 w
.37713 .27916 m .42797 .25035 L .43137 .24549 L p
1 g
F P
s
P
p
.002 w
.61491 .27258 m .56219 .24326 L .55092 .24322 L p
1 g
F P
s
P
p
.002 w
.49201 .23406 m .55092 .24322 L .56219 .24326 L p
1 g
F P
s
P
p
.002 w
.37084 .57852 m .42021 .61099 L .41105 .6032 L p
1 g
F P
s
P
p
.002 w
.41105 .6032 m .36116 .57037 L .37084 .57852 L p
1 g
F P
s
P
p
.002 w
.67839 .5136 m .69547 .45781 L .69351 .44916 L p
1 g
F P
s
P
p
.002 w
.69245 .3895 m .69351 .44916 L .69547 .45781 L p
1 g
F P
s
P
p
.002 w
.37637 .27664 m .33389 .32388 L .33786 .32282 L p
1 g
F P
s
P
p
.002 w
.33786 .32282 m .37713 .27916 L .37637 .27664 L p
1 g
F P
s
P
p
.002 w
.43137 .24549 m .37637 .27664 L .37713 .27916 L p
1 g
F P
s
P
p
.002 w
.66467 .32414 m .62582 .27843 L .61491 .27258 L p
1 g
F P
s
P
p
.002 w
.56219 .24326 m .61491 .27258 L .62582 .27843 L p
1 g
F P
s
P
p
.002 w
.30843 .38831 m .30381 .45175 L .30471 .44183 L p
1 g
F P
s
P
p
.002 w
.30471 .44183 m .30912 .38132 L .30843 .38831 L p
1 g
F P
s
P
p
.004 w
.70418 .49238 m
.78496 .51686 L
s
P
p
.002 w
.43201 .614 m .48746 .62743 L .47786 .62495 L p
1 g
F P
s
P
p
.002 w
.47786 .62495 m .42021 .61099 L .43201 .614 L p
1 g
F P
s
P
p
.002 w
.69245 .3895 m .67205 .33404 L .66467 .32414 L p
1 g
F P
s
P
p
.002 w
.62582 .27843 m .66467 .32414 L .67205 .33404 L p
1 g
F P
s
P
p
.002 w
.6023 .59878 m .64513 .56378 L .64528 .56249 L p
1 g
F P
s
P
p
.002 w
.64528 .56249 m .59944 .59994 L .6023 .59878 L p
1 g
F P
s
P
p
.002 w
.67839 .5136 m .64528 .56249 L .64513 .56378 L p
1 g
F P
s
P
p
.002 w
.5516 .61974 m .6023 .59878 L .59944 .59994 L p
1 g
F P
s
P
p
.002 w
.59944 .59994 m .54515 .6224 L .5516 .61974 L p
1 g
F P
s
P
p
.002 w
.56219 .24326 m .50049 .23364 L .49201 .23406 L p
1 g
F P
s
P
p
.002 w
.43137 .24549 m .49201 .23406 L .50049 .23364 L p
1 g
F P
s
P
p
.002 w
.30846 .46148 m .32538 .52154 L .32046 .51073 L p
1 g
F P
s
P
p
.002 w
.32046 .51073 m .30381 .45175 L .30846 .46148 L p
1 g
F P
s
P
p
.002 w
.69547 .45781 m .69447 .40039 L .69245 .3895 L p
1 g
F P
s
P
p
.002 w
.67205 .33404 m .69245 .3895 L .69447 .40039 L p
1 g
F P
s
P
p
.002 w
.64513 .56378 m .67605 .51811 L .67839 .5136 L p
1 g
F P
s
P
p
.002 w
.69547 .45781 m .67839 .5136 L .67605 .51811 L p
1 g
F P
s
P
p
.002 w
.33549 .5302 m .37084 .57852 L .36116 .57037 L p
1 g
F P
s
P
p
.002 w
.36116 .57037 m .32538 .52154 L .33549 .5302 L p
1 g
F P
s
P
p
.002 w
.33446 .32801 m .30843 .38831 L .30912 .38132 L p
1 g
F P
s
P
p
.002 w
.30912 .38132 m .33389 .32388 L .33446 .32801 L p
1 g
F P
s
P
p
.002 w
.49783 .62441 m .5516 .61974 L .54515 .6224 L p
1 g
F P
s
P
p
.002 w
.54515 .6224 m .48746 .62743 L .49783 .62441 L p
1 g
F P
s
P
p
.002 w
.62582 .27843 m .57218 .24859 L .56219 .24326 L p
1 g
F P
s
P
p
.002 w
.50049 .23364 m .56219 .24326 L .57218 .24859 L p
1 g
F P
s
P
p
.002 w
.38463 .58277 m .43201 .614 L .42021 .61099 L p
1 g
F P
s
P
p
.002 w
.42021 .61099 m .37084 .57852 L .38463 .58277 L p
1 g
F P
s
P
p
.002 w
.50049 .23364 m .43686 .24565 L .43137 .24549 L p
1 g
F P
s
P
p
.002 w
.37637 .27664 m .43137 .24549 L .43686 .24565 L p
1 g
F P
s
P
p
.002 w
.67605 .51811 m .69198 .46606 L .69547 .45781 L p
1 g
F P
s
P
p
.004 w
.69232 .48879 m
.70418 .49238 L
s
P
p
.002 w
.69447 .40039 m .69547 .45781 L .69198 .46606 L p
1 g
F P
s
P
p
.002 w
.37909 .27838 m .33446 .32801 L .33389 .32388 L p
1 g
F P
s
P
p
.002 w
.33389 .32388 m .37637 .27664 L .37909 .27838 L p
1 g
F P
s
P
p
.002 w
.43686 .24565 m .37909 .27838 L .37637 .27664 L p
1 g
F P
s
P
p
.002 w
.67205 .33404 m .63361 .28883 L .62582 .27843 L p
1 g
F P
s
P
p
.002 w
.57218 .24859 m .62582 .27843 L .63361 .28883 L p
1 g
F P
s
P
p
.002 w
.31323 .39682 m .30846 .46148 L .30381 .45175 L p
1 g
F P
s
P
p
.002 w
.30381 .45175 m .30843 .38831 L .31323 .39682 L p
1 g
F P
s
P
p
.002 w
.44626 .61185 m .49783 .62441 L .48746 .62743 L p
1 g
F P
s
P
p
.002 w
.48746 .62743 m .43201 .614 L .44626 .61185 L p
1 g
F P
s
P
p
.002 w
.69447 .40039 m .67484 .34709 L .67205 .33404 L p
1 g
F P
s
P
p
.002 w
.63361 .28883 m .67205 .33404 L .67484 .34709 L p
1 g
F P
s
P
p
.002 w
.60235 .59274 m .64082 .56132 L .64513 .56378 L p
1 g
F P
s
P
p
.002 w
.64513 .56378 m .6023 .59878 L .60235 .59274 L p
1 g
F P
s
P
p
.002 w
.67605 .51811 m .64513 .56378 L .64082 .56132 L p
1 g
F P
s
P
p
.002 w
.31885 .47072 m .33549 .5302 L .32538 .52154 L p
1 g
F P
s
P
p
.002 w
.32538 .52154 m .30846 .46148 L .31885 .47072 L p
1 g
F P
s
P
p
.002 w
.55686 .61153 m .60235 .59274 L .6023 .59878 L p
1 g
F P
s
P
p
.002 w
.6023 .59878 m .5516 .61974 L .55686 .61153 L p
1 g
F P
s
P
p
.002 w
.57218 .24859 m .50931 .23884 L .50049 .23364 L p
1 g
F P
s
P
p
.002 w
.43686 .24565 m .50049 .23364 L .50931 .23884 L p
1 g
F P
s
P
p
.002 w
.69198 .46606 m .69101 .41258 L .69447 .40039 L p
1 g
F P
s
P
p
.002 w
.67484 .34709 m .69447 .40039 L .69101 .41258 L p
1 g
F P
s
P
p
.002 w
.64082 .56132 m .66857 .52032 L .67605 .51811 L p
1 g
F P
s
P
p
.002 w
.69198 .46606 m .67605 .51811 L .66857 .52032 L p
1 g
F P
s
P
p
.002 w
.3508 .53629 m .38463 .58277 L .37084 .57852 L p
1 g
F P
s
P
p
.002 w
.37084 .57852 m .33549 .5302 L .3508 .53629 L p
1 g
F P
s
P
p
.002 w
.33984 .33528 m .31323 .39682 L .30843 .38831 L p
1 g
F P
s
P
p
.002 w
.30843 .38831 m .33446 .32801 L .33984 .33528 L p
1 g
F P
s
P
p
.002 w
.50869 .61564 m .55686 .61153 L .5516 .61974 L p
1 g
F P
s
P
p
.002 w
.5516 .61974 m .49783 .62441 L .50869 .61564 L p
1 g
F P
s
P
p
.002 w
.63361 .28883 m .5805 .25938 L .57218 .24859 L p
1 g
F P
s
P
p
.002 w
.50931 .23884 m .57218 .24859 L .5805 .25938 L p
1 g
F P
s
P
p
.002 w
.40232 .58273 m .44626 .61185 L .43201 .614 L p
1 g
F P
s
P
p
.002 w
.43201 .614 m .38463 .58277 L .40232 .58273 L p
1 g
F P
s
P
p
.002 w
.50931 .23884 m .44441 .25115 L .43686 .24565 L p
1 g
F P
s
P
p
.002 w
.37909 .27838 m .43686 .24565 L .44441 .25115 L p
1 g
F P
s
P
p
.002 w
.66857 .52032 m .6828 .47364 L .69198 .46606 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.67938 .48487 L
s
P
p
.004 w
.68402 .48627 m
.68541 .48669 L
s
P
p
.004 w
.68541 .48669 m
.69232 .48879 L
s
P
p
.002 w
.69101 .41258 m .69198 .46606 L .6828 .47364 L p
1 g
F P
s
P
p
.002 w
.67484 .34709 m .63785 .30374 L .63361 .28883 L p
1 g
F P
s
P
p
.002 w
.5805 .25938 m .63361 .28883 L .63785 .30374 L p
1 g
F P
s
P
p
.002 w
.38544 .28461 m .33984 .33528 L .33446 .32801 L p
1 g
F P
s
P
p
.002 w
.33446 .32801 m .37909 .27838 L .38544 .28461 L p
1 g
F P
s
P
p
.002 w
.44441 .25115 m .38544 .28461 L .37909 .27838 L p
1 g
F P
s
P
p
.002 w
.3237 .40666 m .31885 .47072 L .30846 .46148 L p
1 g
F P
s
P
p
.002 w
.30846 .46148 m .31323 .39682 L .3237 .40666 L p
1 g
F P
s
P
p
.002 w
.46264 .6043 m .50869 .61564 L .49783 .62441 L p
1 g
F P
s
P
p
.002 w
.49783 .62441 m .44626 .61185 L .46264 .6043 L p
1 g
F P
s
P
p
.002 w
.69101 .41258 m .67267 .36308 L .67484 .34709 L p
1 g
F P
s
P
p
.002 w
.63785 .30374 m .67484 .34709 L .67267 .36308 L p
1 g
F P
s
P
p
.002 w
.335 .47914 m .3508 .53629 L .33549 .5302 L p
1 g
F P
s
P
p
.002 w
.33549 .5302 m .31885 .47072 L .335 .47914 L p
1 g
F P
s
P
p
.002 w
.59942 .58171 m .63221 .55493 L .64082 .56132 L p
1 g
F P
s
P
p
.002 w
.64082 .56132 m .60235 .59274 L .59942 .58171 L p
1 g
F P
s
P
p
.002 w
.66857 .52032 m .64082 .56132 L .63221 .55493 L p
1 g
F P
s
P
p
.002 w
.5805 .25938 m .51822 .24985 L .50931 .23884 L p
1 g
F P
s
P
p
.002 w
.44441 .25115 m .50931 .23884 L .51822 .24985 L p
1 g
F P
s
P
p
.002 w
.67267 .36308 m .69101 .41258 L .68184 .4258 L p
1 g
F P
s
P
p
.002 w
.6828 .47364 m .68184 .4258 L .69101 .41258 L p
1 g
F P
s
P
p
.002 w
.56066 .59766 m .59942 .58171 L .60235 .59274 L p
1 g
F P
s
P
p
.002 w
.60235 .59274 m .55686 .61153 L .56066 .59766 L p
1 g
F P
s
P
p
.002 w
.37111 .53948 m .40232 .58273 L .38463 .58277 L p
1 g
F P
s
P
p
.002 w
.38463 .58277 m .3508 .53629 L .37111 .53948 L p
1 g
F P
s
P
p
.002 w
.63221 .55493 m .65583 .51998 L .66857 .52032 L p
1 g
F P
s
P
p
.002 w
.6828 .47364 m .66857 .52032 L .65583 .51998 L p
1 g
F P
s
P
p
.002 w
.35019 .34568 m .3237 .40666 L .31323 .39682 L p
1 g
F P
s
P
p
.002 w
.31323 .39682 m .33984 .33528 L .35019 .34568 L p
1 g
F P
s
P
p
.002 w
.51972 .60106 m .56066 .59766 L .55686 .61153 L p
1 g
F P
s
P
p
.002 w
.55686 .61153 m .50869 .61564 L .51972 .60106 L p
1 g
F P
s
P
p
.002 w
.42357 .57816 m .46264 .6043 L .44626 .61185 L p
1 g
F P
s
P
p
.002 w
.44626 .61185 m .40232 .58273 L .42357 .57816 L p
1 g
F P
s
P
p
.002 w
.63785 .30374 m .5868 .27562 L .5805 .25938 L p
1 g
F P
s
P
p
.002 w
.51822 .24985 m .5805 .25938 L .5868 .27562 L p
1 g
F P
s
P
p
.002 w
.65583 .51998 m .66787 .48025 L .6828 .47364 L p
1 g
F P
s
P
p
.002 w
.68184 .4258 m .6828 .47364 L .66787 .48025 L p
1 g
F P
s
P
p
.002 w
.51822 .24985 m .45391 .26217 L .44441 .25115 L p
1 g
F P
s
P
p
.002 w
.38544 .28461 m .44441 .25115 L .45391 .26217 L p
1 g
F P
s
P
p
.002 w
.67267 .36308 m .6382 .32297 L .63785 .30374 L p
1 g
F P
s
P
p
.002 w
.5868 .27562 m .63785 .30374 L .6382 .32297 L p
1 g
F P
s
P
p
.002 w
.39544 .29541 m .35019 .34568 L .33984 .33528 L p
1 g
F P
s
P
p
.002 w
.33984 .33528 m .38544 .28461 L .39544 .29541 L p
1 g
F P
s
P
p
.002 w
.33985 .41761 m .335 .47914 L .31885 .47072 L p
1 g
F P
s
P
p
.002 w
.31885 .47072 m .3237 .40666 L .33985 .41761 L p
1 g
F P
s
P
p
.002 w
.45391 .26217 m .39544 .29541 L .38544 .28461 L p
1 g
F P
s
P
p
.002 w
.68184 .4258 m .66532 .38167 L .67267 .36308 L p
1 g
F P
s
P
p
.002 w
.6382 .32297 m .67267 .36308 L .66532 .38167 L p
1 g
F P
s
P
p
.002 w
.48072 .59128 m .51972 .60106 L .50869 .61564 L p
1 g
F P
s
P
p
.002 w
.50869 .61564 m .46264 .6043 L .48072 .59128 L p
1 g
F P
s
P
p
.002 w
.3567 .4864 m .37111 .53948 L .3508 .53629 L p
1 g
F P
s
P
p
.002 w
.3508 .53629 m .335 .47914 L .3567 .4864 L p
1 g
F P
s
P
p
.002 w
.66787 .48025 m .66692 .43965 L .68184 .4258 L p
1 g
F P
s
P
p
.002 w
.66532 .38167 m .68184 .4258 L .66692 .43965 L p
1 g
F P
s
P
p
.002 w
.5868 .27562 m .52695 .26666 L .51822 .24985 L p
1 g
F P
s
P
p
.002 w
.45391 .26217 m .51822 .24985 L .52695 .26666 L p
1 g
F P
s
P
p
.002 w
.5934 .56573 m .61931 .54458 L .63221 .55493 L p
1 g
F P
s
P
p
.002 w
.63221 .55493 m .59942 .58171 L .5934 .56573 L p
1 g
F P
s
P
p
.002 w
.65583 .51998 m .63221 .55493 L .61931 .54458 L p
1 g
F P
s
P
p
.002 w
.5628 .57826 m .5934 .56573 L .59942 .58171 L p
1 g
F P
s
P
p
.002 w
.59942 .58171 m .56066 .59766 L .5628 .57826 L p
1 g
F P
s
P
p
.002 w
.39599 .5395 m .42357 .57816 L .40232 .58273 L p
1 g
F P
s
P
p
.002 w
.40232 .58273 m .37111 .53948 L .39599 .5395 L p
1 g
F P
s
P
p
.002 w
.61931 .54458 m .63793 .51697 L .65583 .51998 L p
1 g
F P
s
P
p
.002 w
.66787 .48025 m .65583 .51998 L .63793 .51697 L p
1 g
F P
s
P
p
.002 w
.36543 .35903 m .33985 .41761 L .3237 .40666 L p
1 g
F P
s
P
p
.002 w
.3237 .40666 m .35019 .34568 L .36543 .35903 L p
1 g
F P
s
P
p
.002 w
.53056 .58082 m .5628 .57826 L .56066 .59766 L p
1 g
F P
s
P
p
.002 w
.56066 .59766 m .51972 .60106 L .53056 .58082 L p
1 g
F P
s
P
p
.002 w
.44782 .56899 m .48072 .59128 L .46264 .6043 L p
1 g
F P
s
P
p
.002 w
.46264 .6043 m .42357 .57816 L .44782 .56899 L p
1 g
F P
s
P
p
.002 w
.6382 .32297 m .59072 .29709 L .5868 .27562 L p
1 g
F P
s
P
p
.002 w
.52695 .26666 m .5868 .27562 L .59072 .29709 L p
1 g
F P
s
P
p
.002 w
.66532 .38167 m .63443 .34608 L .6382 .32297 L p
1 g
F P
s
P
p
.002 w
.59072 .29709 m .6382 .32297 L .63443 .34608 L p
1 g
F P
s
P
p
.002 w
.63793 .51697 m .64735 .48562 L .66787 .48025 L p
1 g
F P
s
P
p
.002 w
.66692 .43965 m .66787 .48025 L .64735 .48562 L p
1 g
F P
s
P
p
.002 w
.52695 .26666 m .46516 .27867 L .45391 .26217 L p
1 g
F P
s
P
p
.002 w
.39544 .29541 m .45391 .26217 L .46516 .27867 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.66692 .43965 m .65275 .40237 L .66532 .38167 L p
1 g
F P
s
P
p
.002 w
.63443 .34608 m .66532 .38167 L .65275 .40237 L p
1 g
F P
s
P
p
.002 w
.40898 .3107 m .36543 .35903 L .35019 .34568 L p
1 g
F P
s
P
p
.002 w
.35019 .34568 m .39544 .29541 L .40898 .3107 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.36143 .42932 m .3567 .4864 L .335 .47914 L p
1 g
F P
s
P
p
.002 w
.335 .47914 m .33985 .41761 L .36143 .42932 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53056 .58082 m .51972 .60106 L p
.50591 .58142 L 1 g
F P
s
P
p
.50591 .58142 m .50523 .58046 L .50998 .58053 L 1 g
F
P
p
.50591 .58142 m .50998 .58053 L .53056 .58082 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58032 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58032 L .52033 .57827 L 1 g
F
P
p
.002 w
.51092 .58032 m .51079 .57862 L p
.50109 .58056 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58053 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58053 L .49068 .58068 L 1 g
F
P
p
.48072 .59128 m .47864 .57955 L .48907 .58053 L 1 g
F
P
p
.002 w
.49177 .58078 m .4913 .58123 L p
.48907 .58053 L 1 g
F P
s
P
p
.002 w
.4913 .58123 m .48072 .59128 L p
.48907 .58053 L 1 g
F P
s
P
p
.002 w
.48907 .58053 m .48921 .57862 L p
.48082 .57793 L 1 g
F P
s
P
p
.51079 .57862 m .49068 .58068 L .50109 .58056 L 1 g
F
P
p
.49068 .58068 m .48904 .58085 L .49177 .58078 L 1 g
F
P
p
.49068 .58068 m .49177 .58078 L .50109 .58056 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46842 .57403 L p
1 g
F P
s
P
p
.47864 .57955 m .4782 .57711 L .48907 .58053 L 1 g
F
P
p
.48921 .57862 m .46842 .57403 L .48082 .57793 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48072 .59128 m .44782 .56899 L .45422 .56569 L p
1 g
F P
s
P
p
.002 w
.46842 .57403 m .46872 .57265 L p
.46043 .56934 L 1 g
F P
s
P
p
.48072 .59128 m .45422 .56569 L .47873 .58008 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45081 .56304 L p
1 g
F P
s
P
p
.44782 .56899 m .44938 .56192 L .45081 .56304 L 1 g
F
P
p
.002 w
.45422 .56569 m .45321 .56621 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.45321 .56621 m .44782 .56899 L p
.45081 .56304 L 1 g
F P
s
P
p
.002 w
.45081 .56304 m .45146 .56129 L p
.44572 .5563 L 1 g
F P
s
P
p
.46872 .57265 m .45081 .56304 L .45729 .56808 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4386 .54688 L p
1 g
F P
s
P
p
.45146 .56129 m .4386 .54688 L .44572 .5563 L 1 g
F
P
p
.45081 .56304 m .45652 .52955 L .45422 .56569 L 1 g
F
P
p
.44938 .56192 m .44951 .56132 L .45081 .56304 L 1 g
F
P
p
.44951 .56132 m .45652 .52955 L .45081 .56304 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44782 .56899 m .44511 .56514 L p
.45652 .52955 L 1 g
F P
s
P
p
.002 w
.44511 .56514 m .42476 .53619 L .43409 .53424 L p
1 g
F P
s
P
p
.002 w
.4386 .54688 m .43925 .54566 L p
.43557 .53838 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43266 .52851 L p
1 g
F P
s
P
p
.42476 .53619 m .43179 .52506 L .43266 .52851 L 1 g
F
P
p
.002 w
.43409 .53424 m .43217 .53464 L p
.43266 .52851 L 1 g
F P
s
P
p
.002 w
.43217 .53464 m .42476 .53619 L p
.43266 .52851 L 1 g
F P
s
P
p
.002 w
.43266 .52851 m .43346 .52734 L p
.43324 .52108 L 1 g
F P
s
P
p
.43925 .54566 m .43266 .52851 L .4347 .53666 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43419 .50904 L p
1 g
F P
s
P
p
.43346 .52734 m .43419 .50904 L .43324 .52108 L 1 g
F
P
p
.43266 .52851 m .44872 .49828 L .43409 .53424 L 1 g
F
P
p
.43179 .52506 m .43309 .52301 L .43266 .52851 L 1 g
F
P
p
.43309 .52301 m .44872 .49828 L .43266 .52851 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.42476 .53619 m .42362 .53176 L p
.44872 .49828 L 1 g
F P
s
P
p
.002 w
.42362 .53176 m .41445 .49622 L .43946 .49773 L p
1 g
F P
s
P
p
.002 w
.43419 .50904 m .43485 .50826 L p
.43819 .50046 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44264 .4913 L p
1 g
F P
s
P
p
.41445 .49622 m .45113 .47414 L .44264 .4913 L 1 g
F
P
p
.002 w
.43946 .49773 m .4362 .49753 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.4362 .49753 m .41445 .49622 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.44264 .4913 m .44166 .49233 L p
.4387 .49926 L 1 g
F P
s
P
p
.43485 .50826 m .44264 .4913 L .4387 .49926 L 1 g
F
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44264 .4913 m .44339 .4905 L p
.45055 .48364 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45014 .48404 m .45771 .47668 L .4874 .47548 L 1 g
F
P
p
.002 w
.45771 .47668 m .45826 .47608 L p
.4676 .47199 L 1 g
F P
s
P
p
.002 w
.4707 .47051 m .4874 .47548 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.49723 .45395 m .49511 .45858 L p
.45204 .46496 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.4874 .47548 m .4707 .47051 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.49211 .46517 m .4874 .47548 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.4874 .47548 m .49211 .46517 L p
.52817 .47373 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.49211 .46517 m .5 .46389 L .52817 .47373 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47674 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56609 .50937 L p
1 g
F P
s
P
p
.002 w
.5724 .52022 m .57142 .52062 L p
.56608 .50929 L 1 g
F P
s
P
p
.002 w
.55791 .49197 m .56592 .50758 L p
.56608 .50929 L 1 g
F P
s
P
p
.002 w
.56592 .50758 m .5724 .52022 L p
.56608 .50929 L 1 g
F P
s
P
p
.002 w
.56609 .50937 m .56515 .50826 L p
.56729 .52212 L 1 g
F P
s
P
p
.55661 .4905 m .56609 .50937 L .56224 .50127 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56752 .52877 L p
1 g
F P
s
P
p
.002 w
.5724 .52022 m .58434 .54506 L p
.56756 .53006 L 1 g
F P
s
P
p
.56756 .53006 m .56752 .52877 L .5724 .52022 L 1 g
F
P
p
.002 w
.5673 .52228 m .56987 .52124 L p
.56752 .52877 L 1 g
F P
s
P
p
.002 w
.56987 .52124 m .5724 .52022 L p
.56752 .52877 L 1 g
F P
s
P
p
.002 w
.56752 .52877 m .56654 .52734 L p
.56453 .53833 L 1 g
F P
s
P
p
.56515 .50826 m .56752 .52877 L .5674 .52508 L 1 g
F
P
p
.56515 .50826 m .56798 .52943 L .56729 .52212 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56166 .54738 L p
1 g
F P
s
P
p
.56654 .52734 m .56166 .54738 L .56182 .54689 L 1 g
F
P
p
.56311 .5537 m .56105 .54925 L .56166 .54738 L 1 g
F
P
p
.002 w
.56259 .54454 m .56267 .54596 L p
.56166 .54738 L 1 g
F P
s
P
p
.002 w
.56267 .54596 m .56311 .5537 L p
.56166 .54738 L 1 g
F P
s
P
p
.002 w
.56166 .54738 m .56075 .54566 L p
.55479 .55647 L 1 g
F P
s
P
p
.54861 .5635 m .54914 .5629 L .56311 .5537 L 1 g
F
P
p
.002 w
.55681 .55417 m .56244 .55375 L p
.54914 .5629 L 1 g
F P
s
P
p
.002 w
.56244 .55375 m .56311 .5537 L p
.54914 .5629 L 1 g
F P
s
P
p
.002 w
.56311 .5537 m .5628 .57826 L p
.54861 .5635 L 1 g
F P
s
P
p
.002 w
.54914 .5629 m .54854 .56129 L p
.54094 .56853 L 1 g
F P
s
P
p
.55479 .55647 m .55681 .55417 L .56166 .54738 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .57472 L p
1 g
F P
s
P
p
.54854 .56129 m .53173 .57472 L .53245 .57429 L 1 g
F
P
p
.53056 .58082 m .529 .57636 L .53173 .57472 L 1 g
F
P
p
.002 w
.53342 .5737 m .5332 .57426 L p
.53173 .57472 L 1 g
F P
s
P
p
.002 w
.5332 .57426 m .53056 .58082 L p
.53173 .57472 L 1 g
F P
s
P
p
.002 w
.53173 .57472 m .53128 .57265 L p
.52033 .57827 L 1 g
F P
s
P
p
.52033 .57827 m .52047 .57824 L .53173 .57472 L 1 g
F
P
p
.002 w
.49998 .57298 m .52047 .57824 L p
.50523 .58046 L 1 g
F P
s
P
p
.002 w
.52047 .57824 m .52709 .57993 L p
.51092 .58032 L 1 g
F P
s
P
p
.50523 .58046 m .52047 .57824 L .51092 .58032 L 1 g
F
P
p
.52033 .57827 m .52027 .5783 L .52047 .57824 L 1 g
F
P
p
.54854 .56129 m .53245 .57429 L .54094 .56853 L 1 g
F
P
p
.53245 .57429 m .53176 .57485 L .53342 .5737 L 1 g
F
P
p
.53245 .57429 m .53342 .5737 L .54094 .56853 L 1 g
F
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.529 .57636 m .51974 .54983 L .53342 .5737 L 1 g
F
P
p
.002 w
.5628 .57826 m .53056 .58082 L .5332 .57426 L p
1 g
F P
s
P
p
.002 w
.5332 .57426 m .53342 .5737 L p
.53425 .57383 L 1 g
F P
s
P
p
.5628 .57826 m .5332 .57426 L .53425 .57383 L 1 g
F
P
p
.002 w
.52709 .57993 m .53056 .58082 L p
.50523 .58046 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.53056 .58082 m .49998 .57298 L .51974 .54983 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .51319 .58239 L p
.53173 .57472 L 1 g
F P
s
P
p
.002 w
.51319 .58239 m .5322 .57686 L .53176 .57485 L p
1 g
F P
s
P
p
.002 w
.53176 .57485 m .53173 .57472 L p
.51319 .58239 L 1 g
F P
s
P
p
.52027 .5783 m .51111 .583 L .53173 .57472 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51974 .54983 m .5408 .55537 L .53342 .5737 L p
1 g
F P
s
P
p
.002 w
.53173 .57472 m .53176 .57485 L p
.53245 .57429 L 1 g
F P
s
P
p
.54861 .5635 m .53342 .5737 L .54847 .56335 L 1 g
F
P
p
.5628 .57826 m .53889 .57455 L .54861 .5635 L 1 g
F
P
p
.53889 .57455 m .53342 .5737 L .54861 .5635 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54914 .5629 L p
1 g
F P
s
P
p
.002 w
.54914 .5629 m .54998 .56518 L p
.55479 .55647 L 1 g
F P
s
P
p
.56075 .54566 m .54914 .5629 L .55479 .55647 L 1 g
F
P
p
.002 w
.53176 .57485 m .5322 .57686 L p
.54094 .56853 L 1 g
F P
s
P
p
.002 w
.53342 .5737 m .5408 .55537 L p
.54847 .56335 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5408 .55537 m .55681 .55417 L p
.54861 .5635 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54914 .5629 L p
1 g
F P
s
P
p
.54094 .56853 m .5322 .57686 L .54914 .5629 L 1 g
F
P
p
.55479 .55647 m .5535 .55881 L .55681 .55417 L 1 g
F
P
p
.56654 .52734 m .56182 .54689 L .56453 .53833 L 1 g
F
P
p
.56182 .54689 m .56169 .54743 L .56259 .54454 L 1 g
F
P
p
.56182 .54689 m .56259 .54454 L .56453 .53833 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56105 .54925 m .55004 .52543 L .56259 .54454 L 1 g
F
P
p
.002 w
.56311 .5537 m .5408 .55537 L .55004 .52543 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56166 .54738 L p
1 g
F P
s
P
p
.5535 .55881 m .54998 .56518 L .56166 .54738 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55004 .52543 m .56148 .52463 L .56259 .54454 L p
1 g
F P
s
P
p
.002 w
.56166 .54738 m .56169 .54743 L p
.56182 .54689 L 1 g
F P
s
P
p
.002 w
.58434 .54506 m .56311 .5537 L .56259 .54454 L p
1 g
F P
s
P
p
.58434 .54506 m .56259 .54454 L .56721 .52975 L 1 g
F
P
p
.002 w
.56169 .54743 m .56257 .5491 L p
.56453 .53833 L 1 g
F P
s
P
p
.002 w
.56259 .54454 m .56148 .52463 L p
.56721 .52975 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56148 .52463 m .5673 .52228 L p
.56756 .53006 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56752 .52877 L p
1 g
F P
s
P
p
.56453 .53833 m .56257 .5491 L .56752 .52877 L 1 g
F
P
p
.002 w
.56752 .52877 m .56798 .52943 L p
.5674 .52508 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55793 .4922 m .55791 .49197 L p
.57142 .52062 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56554 .50732 L p
.56161 .49991 L 1 g
F P
s
P
p
.55661 .4905 m .5624 .50157 L .56161 .49991 L 1 g
F
P
p
.5624 .50157 m .56713 .51061 L .56161 .49991 L 1 g
F
P
p
.55661 .4905 m .56184 .50036 L .55763 .49159 L 1 g
F
P
p
.002 w
.55763 .49158 m .55661 .4905 L p
.55763 .49159 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55763 .49158 L p
1 g
F P
s
P
p
.002 w
.55791 .49197 m .55767 .49167 L p
.55765 .49161 L 1 g
F P
s
P
p
.002 w
.55785 .4918 m .55791 .49197 L p
.55765 .49161 L 1 g
F P
s
P
p
.54174 .47608 m .55763 .49158 L .55752 .49148 L 1 g
F
P
p
.56184 .50036 m .55786 .49204 L .55763 .49159 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53042 .51616 m .52438 .50705 L .55784 .492 L p
1 g
F P
s
P
p
.002 w
.55784 .492 m .55791 .49197 L .55785 .49202 L p
1 g
F P
s
P
p
.002 w
.55785 .49202 m .53042 .51616 L p
.55784 .492 L 1 g
F P
s
P
p
.002 w
.52438 .50705 m .52185 .49613 L .55783 .49198 L p
1 g
F P
s
P
p
.002 w
.55783 .49198 m .55791 .49197 L .55784 .492 L p
1 g
F P
s
P
p
.002 w
.55784 .492 m .52438 .50705 L p
.55783 .49198 L 1 g
F P
s
P
p
.55784 .49201 m .55783 .49199 L .55783 .49198 L 1 g
F
P
p
.55785 .49202 m .55785 .49201 L .55784 .49201 L 1 g
F
P
p
.55785 .49201 m .55783 .49199 L .55784 .49201 L 1 g
F
P
p
.55786 .49204 m .55785 .49203 L .55785 .49202 L 1 g
F
P
p
.55785 .49203 m .55783 .49199 L .55785 .49202 L 1 g
F
P
p
.55786 .49204 m .55783 .49198 L .55763 .49159 L 1 g
F
P
p
.002 w
.5393 .52251 m .53042 .51616 L .55785 .49202 L p
1 g
F P
s
P
p
.002 w
.55785 .49202 m .55791 .49197 L .55786 .49204 L p
1 g
F P
s
P
p
.002 w
.55786 .49204 m .5393 .52251 L p
.55785 .49202 L 1 g
F P
s
P
p
.002 w
.55752 .49148 m .55767 .49167 L p
.54234 .47674 L 1 g
F P
s
P
p
.55069 .48485 m .55752 .49148 L .5508 .48495 L 1 g
F
P
p
.54174 .47608 m .55752 .49148 L .55069 .48485 L 1 g
F
P
p
.53049 .47118 m .54234 .47674 L .55767 .49167 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.53049 .47118 m .55767 .49167 L .55777 .49186 L 1 g
F
P
p
.002 w
.55786 .49204 m .55791 .49197 L .55788 .49208 L p
1 g
F P
s
P
p
.002 w
.55788 .49208 m .55791 .49197 L .55793 .4922 L p
1 g
F P
s
P
p
.002 w
.55767 .49167 m .55791 .49197 L p
.55777 .49186 L 1 g
F P
s
P
p
.002 w
.55791 .49197 m .52817 .47373 L .53049 .47118 L p
1 g
F P
s
P
p
.002 w
.58165 .51269 m .5724 .52022 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.58826 .50282 m .58165 .51269 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.59152 .49166 m .58826 .50282 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.59107 .48038 m .59152 .49166 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.58694 .47019 m .59107 .48038 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.57953 .4622 m .58694 .47019 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.55796 .4919 m .55791 .49197 L .55794 .49188 L p
1 g
F P
s
P
p
.002 w
.55829 .45606 m .56962 .4573 L .55794 .49188 L p
1 g
F P
s
P
p
.002 w
.55794 .49188 m .55791 .49197 L .55791 .49186 L p
1 g
F P
s
P
p
.002 w
.55791 .49186 m .55829 .45606 L p
.55794 .49188 L 1 g
F P
s
P
p
.002 w
.53634 .46474 m .54234 .46122 L p
.55763 .49158 L 1 g
F P
s
P
p
.002 w
.55767 .49167 m .55752 .49148 L p
.55763 .49158 L 1 g
F P
s
P
p
.002 w
.55752 .49148 m .53634 .46474 L p
.55763 .49158 L 1 g
F P
s
P
p
.002 w
.54234 .46122 m .54677 .45862 L p
.55767 .49167 L 1 g
F P
s
P
p
.002 w
.55763 .49158 m .55763 .49159 L p
.5508 .48495 L 1 g
F P
s
P
p
.002 w
.54677 .45862 m .55829 .45606 L .55791 .49197 L closepath p
1 g
F P
s
P
p
.002 w
.55769 .4917 m .55834 .49233 L .55763 .49159 L p
1 g
F P
s
P
p
.002 w
.55763 .49159 m .55763 .49158 L p
.55763 .49159 L 1 g
F P
s
P
p
.002 w
.55763 .49159 m .55834 .49233 L p
.55173 .48586 L 1 g
F P
s
P
p
.5508 .48495 m .55763 .49159 L .55173 .48586 L 1 g
F
P
p
.002 w
.52316 .4846 m .52817 .47373 L .55778 .49189 L p
1 g
F P
s
P
p
.002 w
.55778 .49189 m .55791 .49197 L .55781 .49195 L p
1 g
F P
s
P
p
.002 w
.55781 .49195 m .52316 .4846 L p
.55778 .49189 L 1 g
F P
s
P
p
.002 w
.52185 .49613 m .52316 .4846 L .55781 .49195 L p
1 g
F P
s
P
p
.002 w
.55781 .49195 m .55791 .49197 L .55783 .49198 L p
1 g
F P
s
P
p
.002 w
.55783 .49198 m .52185 .49613 L p
.55781 .49195 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .5577 .49171 L p
.56554 .50732 L 1 g
F P
s
P
p
.002 w
.5577 .49171 m .55769 .49171 L p
.55777 .49185 L 1 g
F P
s
P
p
.55777 .49185 m .56554 .50732 L .5577 .49171 L 1 g
F
P
p
.002 w
.55769 .49171 m .55769 .49171 L p
.55778 .49189 L 1 g
F P
s
P
p
.55778 .49189 m .56554 .50732 L .55769 .49171 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54264 .47707 L p
1 g
F P
s
P
p
.002 w
.54234 .47674 m .54174 .47608 L p
.55069 .48485 L 1 g
F P
s
P
p
.002 w
.53634 .46474 m .54792 .47935 L p
.54234 .47674 L 1 g
F P
s
P
p
.52214 .46667 m .54234 .47674 L .53432 .47298 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.52817 .47373 m .51667 .46639 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.53829 .47503 L 1 g
F P
s
P
p
.002 w
.53274 .4687 m .53049 .47118 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.53049 .47118 m .52817 .47373 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52247 .46722 L p
1 g
F P
s
P
p
.53829 .47503 m .54302 .47747 L .52247 .46722 L 1 g
F
P
p
.002 w
.53049 .47118 m .53336 .46802 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53336 .46802 m .53634 .46474 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.54264 .47707 m .54234 .47674 L p
.55232 .48644 L 1 g
F P
s
P
p
.55069 .48485 m .55232 .48644 L .54234 .47674 L 1 g
F
P
p
.55232 .48644 m .55834 .49233 L .54264 .47707 L 1 g
F
P
p
.002 w
.56962 .4573 m .57953 .4622 L .55796 .4919 L p
1 g
F P
s
P
p
.002 w
.55794 .49188 m .56962 .4573 L p
.55796 .4919 L 1 g
F P
s
P
p
.002 w
.54792 .47935 m .55752 .49148 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.54677 .45862 m .55785 .4918 L p
.55765 .49161 L 1 g
F P
s
P
p
.56184 .50036 m .56554 .50732 L .55783 .49199 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55004 .52543 m .5393 .52251 L .55786 .49204 L p
1 g
F P
s
P
p
.002 w
.55788 .49208 m .55004 .52543 L p
.55786 .49204 L 1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56148 .52463 m .55004 .52543 L .55788 .49208 L p
1 g
F P
s
P
p
.002 w
.55793 .4922 m .56148 .52463 L p
.55788 .49208 L 1 g
F P
s
P
p
.002 w
.56148 .52463 m .55793 .4922 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.57142 .52062 m .5673 .52228 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.5673 .52228 m .56148 .52463 L p
.56609 .50937 L 1 g
F P
s
P
p
.002 w
.56798 .52943 m .56854 .53025 L p
.56729 .52212 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56609 .50937 L p
1 g
F P
s
P
p
.56729 .52212 m .56854 .53025 L .56609 .50937 L 1 g
F
P
p
.002 w
.56609 .50937 m .56713 .51061 L p
.56224 .50127 L 1 g
F P
s
P
p
.002 w
.54234 .47674 m .54302 .47747 L p
.53432 .47298 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52249 .46726 L p
.52126 .46704 L 1 g
F P
s
P
p
.5 .4634 m .52247 .46722 L .52126 .46704 L 1 g
F
P
p
.002 w
.53634 .46474 m .53274 .4687 L p
.49723 .45395 L 1 g
F P
s
P
p
.5 .4634 m .52249 .46726 L .51153 .46562 L 1 g
F
P
p
.002 w
.51667 .46639 m .49723 .45395 L p
.53274 .4687 L 1 g
F P
s
P
p
.002 w
.51667 .46639 m .52817 .47373 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.51153 .46562 L 1 g
F P
s
P
p
.51153 .46562 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.49119 .46531 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .49211 .46517 L 1 g
F
P
p
.47786 .46667 m .49211 .46517 L .49055 .46538 L 1 g
F
P
p
.002 w
.47757 .46716 m .47786 .46667 L p
.49055 .46538 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47757 .46716 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.45204 .46496 m .49511 .45858 L .47757 .46716 L 1 g
F
P
p
.45826 .47608 m .47757 .46716 L .47453 .46864 L 1 g
F
P
p
.45826 .47608 m .47749 .46729 L .4676 .47199 L 1 g
F
P
p
.002 w
.4707 .47051 m .46514 .46886 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46514 .46886 m .45204 .46496 L p
.47757 .46716 L 1 g
F P
s
P
p
.49055 .46538 m .49211 .46517 L .49119 .46531 L 1 g
F
P
p
.002 w
.49723 .45395 m .5102 .46225 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.49211 .46517 m .49316 .46287 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.49316 .46287 m .49723 .45395 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.5102 .46225 m .51667 .46639 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.52249 .46726 m .52282 .46778 L p
.51153 .46562 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47733 .46755 L p
1 g
F P
s
P
p
.002 w
.47733 .46755 m .47757 .46716 L p
.48661 .46605 L 1 g
F P
s
P
p
.48661 .46605 m .5 .46442 L .47733 .46755 L 1 g
F
P
p
.49055 .46538 m .5 .46442 L .47757 .46716 L 1 g
F
P
p
.002 w
.49511 .45858 m .49211 .46517 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.47757 .46716 m .47749 .46729 L p
.47453 .46864 L 1 g
F P
s
P
p
.002 w
.47749 .46729 m .47718 .46778 L p
.4676 .47199 L 1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44872 .49828 m .43946 .49773 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45746 .47695 L p
1 g
F P
s
P
p
.44339 .4905 m .45746 .47695 L .45073 .48347 L 1 g
F
P
p
.45055 .48364 m .45014 .48404 L .44264 .4913 L 1 g
F
P
p
.002 w
.45113 .47414 m .45014 .48404 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.45014 .48404 m .44872 .49828 L p
.44264 .4913 L 1 g
F P
s
P
p
.002 w
.45746 .47695 m .45698 .47747 L p
.45073 .48347 L 1 g
F P
s
P
p
.002 w
.45204 .46496 m .46561 .469 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.45014 .48404 m .45053 .48009 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.45053 .48009 m .45204 .46496 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.46561 .469 m .4707 .47051 L p
.45771 .47668 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45771 .47668 L p
1 g
F P
s
P
p
.4676 .47199 m .47718 .46778 L .45771 .47668 L 1 g
F
P
p
.45055 .48364 m .45073 .48347 L .45014 .48404 L 1 g
F
P
p
.002 w
.44872 .49828 m .45014 .48404 L p
.4874 .47548 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44264 .4913 L p
1 g
F P
s
P
p
.45073 .48347 m .45698 .47747 L .44264 .4913 L 1 g
F
P
p
.002 w
.45204 .46496 m .45113 .47414 L p
.41445 .49622 L 1 g
F P
s
P
p
.002 w
.43946 .49773 m .44872 .49828 L p
.42362 .53176 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43419 .50904 L p
1 g
F P
s
P
p
.43819 .50046 m .44166 .49233 L .43419 .50904 L 1 g
F
P
p
.002 w
.43419 .50904 m .43287 .51061 L p
.43324 .52108 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43266 .52851 L p
1 g
F P
s
P
p
.43324 .52108 m .43287 .51061 L .43266 .52851 L 1 g
F
P
p
.002 w
.43266 .52851 m .43146 .53025 L p
.4347 .53666 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44872 .49828 m .45652 .52955 L .43409 .53424 L p
1 g
F P
s
P
p
.002 w
.43409 .53424 m .45652 .52955 L p
.44511 .56514 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4386 .54688 L p
1 g
F P
s
P
p
.43557 .53838 m .43146 .53025 L .4386 .54688 L 1 g
F
P
p
.002 w
.4386 .54688 m .43743 .5491 L p
.44572 .5563 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45081 .56304 L p
1 g
F P
s
P
p
.44572 .5563 m .43743 .5491 L .45081 .56304 L 1 g
F
P
p
.002 w
.45081 .56304 m .45002 .56518 L p
.45729 .56808 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45652 .52955 m .47433 .55534 L .45422 .56569 L p
1 g
F P
s
P
p
.002 w
.45422 .56569 m .47433 .55534 L p
.47873 .58008 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46842 .57403 L p
1 g
F P
s
P
p
.46043 .56934 m .45002 .56518 L .46842 .57403 L 1 g
F
P
p
.002 w
.46842 .57403 m .4678 .57686 L p
.48082 .57793 L 1 g
F P
s
P
p
.48907 .58053 m .47433 .55534 L .49177 .58078 L 1 g
F
P
p
.4782 .57711 m .47433 .55534 L .48907 .58053 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58053 L p
1 g
F P
s
P
p
.48082 .57793 m .4678 .57686 L .48907 .58053 L 1 g
F
P
p
.002 w
.47433 .55534 m .49998 .57298 L .49177 .58078 L p
1 g
F P
s
P
p
.002 w
.48907 .58053 m .48904 .58085 L p
.49068 .58068 L 1 g
F P
s
P
p
.002 w
.51972 .60106 m .48072 .59128 L .49177 .58078 L p
1 g
F P
s
P
p
.51972 .60106 m .49177 .58078 L .50523 .58046 L 1 g
F
P
p
.002 w
.48904 .58085 m .48889 .583 L p
.50109 .58056 L 1 g
F P
s
P
p
.002 w
.49177 .58078 m .49998 .57298 L p
.50523 .58046 L 1 g
F P
s
P
p
.002 w
.51092 .58032 m .51111 .583 L p
.52033 .57827 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58032 L p
1 g
F P
s
P
p
.50109 .58056 m .48889 .583 L .51092 .58032 L 1 g
F
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.46516 .27867 m .40898 .3107 L .39544 .29541 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53082 .46322 L
s
P
p
.002 w
.38344 .49219 m .39599 .5395 L .37111 .53948 L p
1 g
F P
s
P
p
.002 w
.37111 .53948 m .3567 .4864 L .38344 .49219 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.64735 .48562 m .64646 .4537 L .66692 .43965 L p
1 g
F P
s
P
p
.002 w
.65275 .40237 m .66692 .43965 L .64646 .4537 L p
1 g
F P
s
P
p
.002 w
.42476 .53619 m .44782 .56899 L .42357 .57816 L p
1 g
F P
s
P
p
.002 w
.42357 .57816 m .39599 .5395 L .42476 .53619 L p
1 g
F P
s
P
p
.002 w
.59072 .29709 m .53517 .28902 L .52695 .26666 L p
1 g
F P
s
P
p
.002 w
.46516 .27867 m .52695 .26666 L .53517 .28902 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.58434 .54506 m .60233 .5304 L .61931 .54458 L p
1 g
F P
s
P
p
.002 w
.61931 .54458 m .5934 .56573 L .58434 .54506 L p
1 g
F P
s
P
p
.002 w
.63793 .51697 m .61931 .54458 L .60233 .5304 L p
1 g
F P
s
P
p
.002 w
.56311 .5537 m .58434 .54506 L .5934 .56573 L p
1 g
F P
s
P
p
.002 w
.5934 .56573 m .5628 .57826 L .56311 .5537 L p
1 g
F P
s
P
p
.002 w
.60233 .5304 m .61522 .51122 L .63793 .51697 L p
1 g
F P
s
P
p
.002 w
.64735 .48562 m .63793 .51697 L .61522 .51122 L p
1 g
F P
s
P
p
.002 w
.63443 .34608 m .59203 .32329 L .59072 .29709 L p
1 g
F P
s
P
p
.002 w
.53517 .28902 m .59072 .29709 L .59203 .32329 L p
1 g
F P
s
P
p
.002 w
.38531 .37501 m .36143 .42932 L .33985 .41761 L p
1 g
F P
s
P
p
.002 w
.33985 .41761 m .36543 .35903 L .38531 .37501 L p
1 g
F P
s
P
p
.002 w
.65275 .40237 m .62646 .37247 L .63443 .34608 L p
1 g
F P
s
P
p
.002 w
.59203 .32329 m .63443 .34608 L .62646 .37247 L p
1 g
F P
s
P
p
.002 w
.61522 .51122 m .62166 .48949 L .64735 .48562 L p
1 g
F P
s
P
p
.002 w
.64646 .4537 m .64735 .48562 L .62166 .48949 L p
1 g
F P
s
P
p
.002 w
.53517 .28902 m .47786 .30035 L .46516 .27867 L p
1 g
F P
s
P
p
.002 w
.40898 .3107 m .46516 .27867 L .47786 .30035 L p
1 g
F P
s
P
p
.002 w
.64646 .4537 m .63516 .42454 L .65275 .40237 L p
1 g
F P
s
P
p
.002 w
.62646 .37247 m .65275 .40237 L .63516 .42454 L p
1 g
F P
s
P
p
.002 w
.3879 .44142 m .38344 .49219 L .3567 .4864 L p
1 g
F P
s
P
p
.002 w
.3567 .4864 m .36143 .42932 L .3879 .44142 L p
1 g
F P
s
P
p
.002 w
.42576 .33017 m .38531 .37501 L .36543 .35903 L p
1 g
F P
s
P
p
.002 w
.36543 .35903 m .40898 .3107 L .42576 .33017 L p
1 g
F P
s
P
p
.002 w
.41445 .49622 m .42476 .53619 L .39599 .5395 L p
1 g
F P
s
P
p
.002 w
.39599 .5395 m .38344 .49219 L .41445 .49622 L p
1 g
F P
s
P
p
.002 w
.47786 .30035 m .42576 .33017 L .40898 .3107 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62166 .48949 m .62093 .46745 L .64646 .4537 L p
1 g
F P
s
P
p
.002 w
.63516 .42454 m .64646 .4537 L .62093 .46745 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.59203 .32329 m .54255 .31639 L .53517 .28902 L p
1 g
F P
s
P
p
.002 w
.47786 .30035 m .53517 .28902 L .54255 .31639 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.5724 .52022 m .58165 .51269 L .60233 .5304 L p
1 g
F P
s
P
p
.002 w
.60233 .5304 m .58434 .54506 L .5724 .52022 L p
1 g
F P
s
P
p
.002 w
.61522 .51122 m .60233 .5304 L .58165 .51269 L p
1 g
F P
s
P
p
.002 w
.5022 .53754 m .51974 .54983 L .49998 .57298 L p
1 g
F P
s
P
p
.002 w
.49998 .57298 m .47433 .55534 L .5022 .53754 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.62646 .37247 m .59055 .3535 L .59203 .32329 L p
1 g
F P
s
P
p
.002 w
.54255 .31639 m .59203 .32329 L .59055 .3535 L p
1 g
F P
s
P
p
.002 w
.58165 .51269 m .58826 .50282 L .61522 .51122 L p
1 g
F P
s
P
p
.002 w
.62166 .48949 m .61522 .51122 L .58826 .50282 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.63516 .42454 m .61441 .40131 L .62646 .37247 L p
1 g
F P
s
P
p
.002 w
.59055 .3535 m .62646 .37247 L .61441 .40131 L p
1 g
F P
s
P
p
.002 w
.40929 .39316 m .3879 .44142 L .36143 .42932 L p
1 g
F P
s
P
p
.002 w
.36143 .42932 m .38531 .37501 L .40929 .39316 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.62093 .46745 m .61299 .44742 L .63516 .42454 L p
1 g
F P
s
P
p
.002 w
.61441 .40131 m .63516 .42454 L .61299 .44742 L p
1 g
F P
s
P
p
.002 w
.58826 .50282 m .59152 .49166 L .62166 .48949 L p
1 g
F P
s
P
p
.002 w
.62093 .46745 m .62166 .48949 L .59152 .49166 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.54255 .31639 m .49161 .32668 L .47786 .30035 L p
1 g
F P
s
P
p
.002 w
.42576 .33017 m .47786 .30035 L .49161 .32668 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.41845 .45345 m .41445 .49622 L .38344 .49219 L p
1 g
F P
s
P
p
.002 w
.38344 .49219 m .3879 .44142 L .41845 .45345 L p
1 g
F P
s
P
p
.002 w
.5393 .52251 m .55004 .52543 L .5408 .55537 L p
1 g
F P
s
P
p
.002 w
.5408 .55537 m .51974 .54983 L .5393 .52251 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.49014 .51973 m .5022 .53754 L .47433 .55534 L p
1 g
F P
s
P
p
.002 w
.47433 .55534 m .45652 .52955 L .49014 .51973 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.4453 .35329 m .40929 .39316 L .38531 .37501 L p
1 g
F P
s
P
p
.002 w
.38531 .37501 m .42576 .33017 L .4453 .35329 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.61299 .44742 m .62093 .46745 L .59107 .48038 L p
1 g
F P
s
P
p
.002 w
.59152 .49166 m .59107 .48038 L .62093 .46745 L p
1 g
F P
s
P
p
.002 w
.49161 .32668 m .4453 .35329 L .42576 .33017 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59055 .3535 m .5488 .34795 L .54255 .31639 L p
1 g
F P
s
P
p
.002 w
.49161 .32668 m .54255 .31639 L .5488 .34795 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53042 .51616 m .5393 .52251 L .51974 .54983 L p
1 g
F P
s
P
p
.002 w
.51974 .54983 m .5022 .53754 L .53042 .51616 L p
1 g
F P
s
P
p
.002 w
.61441 .40131 m .58624 .38672 L .59055 .3535 L p
1 g
F P
s
P
p
.002 w
.5488 .34795 m .59055 .3535 L .58624 .38672 L p
1 g
F P
s
P
p
.002 w
.61299 .44742 m .59859 .43159 L .61441 .40131 L p
1 g
F P
s
P
p
.002 w
.58624 .38672 m .61441 .40131 L .59859 .43159 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59107 .48038 m .58694 .47019 L .61299 .44742 L p
1 g
F P
s
P
p
.002 w
.59859 .43159 m .61299 .44742 L .58694 .47019 L p
1 g
F P
s
P
p
.002 w
.43661 .41286 m .41845 .45345 L .3879 .44142 L p
1 g
F P
s
P
p
.002 w
.3879 .44142 m .40929 .39316 L .43661 .41286 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.48498 .49826 m .49014 .51973 L .45652 .52955 L p
1 g
F P
s
P
p
.002 w
.45652 .52955 m .44872 .49828 L .48498 .49826 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.41445 .49622 m .41845 .45345 L .45204 .46496 L p
1 g
F P
s
P
p
.002 w
.52438 .50705 m .53042 .51616 L .5022 .53754 L p
1 g
F P
s
P
p
.002 w
.5022 .53754 m .49014 .51973 L .52438 .50705 L p
1 g
F P
s
P
p
.002 w
.5488 .34795 m .50592 .35681 L .49161 .32668 L p
1 g
F P
s
P
p
.002 w
.4453 .35329 m .49161 .32668 L .50592 .35681 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58694 .47019 m .57953 .4622 L .59859 .43159 L p
1 g
F P
s
P
p
.002 w
.57919 .42176 m .59859 .43159 L .57953 .4622 L p
1 g
F P
s
P
p
.002 w
.59859 .43159 m .57919 .42176 L .58624 .38672 L p
1 g
F P
s
P
p
.002 w
.46697 .37931 m .43661 .41286 L .40929 .39316 L p
1 g
F P
s
P
p
.002 w
.40929 .39316 m .4453 .35329 L .46697 .37931 L p
1 g
F P
s
P
p
.002 w
.55364 .38262 m .58624 .38672 L .57919 .42176 L p
1 g
F P
s
P
p
.002 w
.58624 .38672 m .55364 .38262 L .5488 .34795 L p
1 g
F P
s
P
p
.002 w
.50592 .35681 m .5488 .34795 L .55364 .38262 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50592 .35681 m .46697 .37931 L .4453 .35329 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.52185 .49613 m .52438 .50705 L .49014 .51973 L p
1 g
F P
s
P
p
.002 w
.49014 .51973 m .48498 .49826 L .52185 .49613 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57953 .4622 m .56962 .4573 L .57919 .42176 L p
1 g
F P
s
P
p
.002 w
.4874 .47548 m .48498 .49826 L .44872 .49828 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.46631 .43339 m .45204 .46496 L .41845 .45345 L p
1 g
F P
s
P
p
.002 w
.41845 .45345 m .43661 .41286 L .46631 .43339 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55685 .41913 m .57919 .42176 L .56962 .4573 L p
1 g
F P
s
P
p
.002 w
.57919 .42176 m .55685 .41913 L .55364 .38262 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56962 .4573 m .55829 .45606 L .55685 .41913 L p
1 g
F P
s
P
p
.002 w
.55364 .38262 m .52026 .3897 L .50592 .35681 L p
1 g
F P
s
P
p
.002 w
.46697 .37931 m .50592 .35681 L .52026 .3897 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52026 .3897 m .55364 .38262 L .55685 .41913 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52316 .4846 m .52185 .49613 L .48498 .49826 L p
1 g
F P
s
P
p
.002 w
.48498 .49826 m .4874 .47548 L .52316 .4846 L p
1 g
F P
s
P
p
.002 w
.48996 .40729 m .46631 .43339 L .43661 .41286 L p
1 g
F P
s
P
p
.002 w
.43661 .41286 m .46697 .37931 L .48996 .40729 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.55829 .45606 m .54677 .45862 L .53406 .42408 L p
1 g
F P
s
P
p
.002 w
.53406 .42408 m .55685 .41913 L .55829 .45606 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.52026 .3897 m .48996 .40729 L .46697 .37931 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.45204 .46496 m .46631 .43339 L .49723 .45395 L p
1 g
F P
s
P
p
.002 w
.52817 .47373 m .52316 .4846 L .4874 .47548 L p
1 g
F P
s
P
p
.002 w
.55685 .41913 m .53406 .42408 L .52026 .3897 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54677 .45862 m .53634 .46474 L .51339 .43614 L p
1 g
F P
s
P
p
.002 w
.51339 .43614 m .53406 .42408 L .54677 .45862 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49723 .45395 m .51339 .43614 L .53634 .46474 L p
1 g
F P
s
P
p
.002 w
.48996 .40729 m .52026 .3897 L .53406 .42408 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.53406 .42408 m .51339 .43614 L .48996 .40729 L p
1 g
F P
s
P
p
.002 w
.51339 .43614 m .49723 .45395 L .46631 .43339 L p
1 g
F P
s
P
p
.002 w
.46631 .43339 m .48996 .40729 L .51339 .43614 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.5783 .51361 m
.59333 .52956 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .78496 .51686 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .59333 .52956 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.439535)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.439535)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4869 .46088 m .51678 .4427 L .49867 .42061 L p
1 g
F P
s
P
p
.002 w
.49867 .42061 m .47552 .43466 L .4869 .46088 L p
1 g
F P
s
P
p
.002 w
.51689 .40069 m .49867 .42061 L .51678 .4427 L p
1 g
F P
s
P
p
.002 w
.47552 .43466 m .49867 .42061 L .48057 .39871 L p
1 g
F P
s
P
p
.002 w
.49867 .42061 m .51689 .40069 L .49299 .38506 L p
1 g
F P
s
P
p
.002 w
.49299 .38506 m .48057 .39871 L .49867 .42061 L p
1 g
F P
s
P
p
.002 w
.49864 .4865 m .53455 .4646 L .51678 .4427 L p
1 g
F P
s
P
p
.002 w
.51678 .4427 m .4869 .46088 L .49864 .4865 L p
1 g
F P
s
P
p
.002 w
.54036 .41703 m .51678 .4427 L .53455 .4646 L p
1 g
F P
s
P
p
.002 w
.51678 .4427 m .54036 .41703 L .51689 .40069 L p
1 g
F P
s
P
p
.002 w
.4536 .46977 m .4869 .46088 L .47552 .43466 L p
1 g
F P
s
P
p
.002 w
.47552 .43466 m .44973 .44143 L .4536 .46977 L p
1 g
F P
s
P
p
.002 w
.44973 .44143 m .47552 .43466 L .46473 .4083 L p
1 g
F P
s
P
p
.002 w
.48057 .39871 m .46473 .4083 L .47552 .43466 L p
1 g
F P
s
P
p
.002 w
.45863 .49736 m .49864 .4865 L .4869 .46088 L p
1 g
F P
s
P
p
.002 w
.4869 .46088 m .4536 .46977 L .45863 .49736 L p
1 g
F P
s
P
p
.002 w
.52831 .37686 m .51689 .40069 L .54036 .41703 L p
1 g
F P
s
P
p
.002 w
.51689 .40069 m .52831 .37686 L .50071 .36875 L p
1 g
F P
s
P
p
.002 w
.50071 .36875 m .49299 .38506 L .51689 .40069 L p
1 g
F P
s
P
p
.002 w
.46473 .4083 m .48057 .39871 L .46279 .37741 L p
1 g
F P
s
P
p
.002 w
.48057 .39871 m .49299 .38506 L .46911 .37044 L p
1 g
F P
s
P
p
.002 w
.46911 .37044 m .46279 .37741 L .48057 .39871 L p
1 g
F P
s
P
p
.002 w
.46473 .4083 m .44709 .41285 L .44973 .44143 L p
1 g
F P
s
P
p
.002 w
.44709 .41285 m .46473 .4083 L .45471 .38229 L p
1 g
F P
s
P
p
.002 w
.46279 .37741 m .45471 .38229 L .46473 .4083 L p
1 g
F P
s
P
p
.002 w
.53455 .4646 m .56298 .43378 L .54036 .41703 L p
1 g
F P
s
P
p
.002 w
.55529 .3863 m .54036 .41703 L .56298 .43378 L p
1 g
F P
s
P
p
.002 w
.54036 .41703 m .55529 .3863 L .52831 .37686 L p
1 g
F P
s
P
p
.002 w
.49299 .38506 m .50071 .36875 L .47299 .36212 L p
1 g
F P
s
P
p
.002 w
.47299 .36212 m .46911 .37044 L .49299 .38506 L p
1 g
F P
s
P
p
.002 w
.51056 .51103 m .55168 .4859 L .53455 .4646 L p
1 g
F P
s
P
p
.002 w
.53455 .4646 m .49864 .4865 L .51056 .51103 L p
1 g
F P
s
P
p
.002 w
.56298 .43378 m .53455 .4646 L .55168 .4859 L p
1 g
F P
s
P
p
.002 w
.42011 .46835 m .4536 .46977 L .44973 .44143 L p
1 g
F P
s
P
p
.002 w
.44973 .44143 m .42386 .44015 L .42011 .46835 L p
1 g
F P
s
P
p
.002 w
.42386 .44015 m .44973 .44143 L .44709 .41285 L p
1 g
F P
s
P
p
.002 w
.44709 .41285 m .42945 .41185 L .42386 .44015 L p
1 g
F P
s
P
p
.002 w
.42945 .41185 m .44709 .41285 L .44572 .38457 L p
1 g
F P
s
P
p
.002 w
.45471 .38229 m .44572 .38457 L .44709 .41285 L p
1 g
F P
s
P
p
.002 w
.46474 .52367 m .51056 .51103 L .49864 .4865 L p
1 g
F P
s
P
p
.002 w
.49864 .4865 m .45863 .49736 L .46474 .52367 L p
1 g
F P
s
P
p
.002 w
.53169 .35149 m .52831 .37686 L .55529 .3863 L p
1 g
F P
s
P
p
.002 w
.52831 .37686 m .53169 .35149 L .50287 .35144 L p
1 g
F P
s
P
p
.002 w
.50287 .35144 m .50071 .36875 L .52831 .37686 L p
1 g
F P
s
P
p
.002 w
.41829 .49594 m .45863 .49736 L .4536 .46977 L p
1 g
F P
s
P
p
.002 w
.4536 .46977 m .42011 .46835 L .41829 .49594 L p
1 g
F P
s
P
p
.002 w
.50071 .36875 m .50287 .35144 L .47401 .35332 L p
1 g
F P
s
P
p
.002 w
.47401 .35332 m .47299 .36212 L .50071 .36875 L p
1 g
F P
s
P
p
.002 w
.55168 .4859 m .58433 .45065 L .56298 .43378 L p
1 g
F P
s
P
p
.002 w
.58115 .3969 m .56298 .43378 L .58433 .45065 L p
1 g
F P
s
P
p
.002 w
.56298 .43378 m .58115 .3969 L .55529 .3863 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .45471 .38229 L .46279 .37741 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .46279 .37741 L .46911 .37044 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .44572 .38457 L .45471 .38229 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .46911 .37044 L .47299 .36212 L closepath p
1 g
F P
s
P
p
.002 w
.55993 .35348 m .55529 .3863 L .58115 .3969 L p
1 g
F P
s
P
p
.002 w
.55529 .3863 m .55993 .35348 L .53169 .35149 L p
1 g
F P
s
P
p
.002 w
.44572 .38457 m .43676 .38399 L .42945 .41185 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .43676 .38399 L .44572 .38457 L closepath p
1 g
F P
s
P
p
.002 w
.40058 .43079 m .42386 .44015 L .42945 .41185 L p
1 g
F P
s
P
p
.002 w
.42945 .41185 m .41366 .40533 L .40058 .43079 L p
1 g
F P
s
P
p
.002 w
.41366 .40533 m .42945 .41185 L .43676 .38399 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .47299 .36212 L .47401 .35332 L closepath p
1 g
F P
s
P
p
.002 w
.52241 .53401 m .56782 .5062 L .55168 .4859 L p
1 g
F P
s
P
p
.002 w
.55168 .4859 m .51056 .51103 L .52241 .53401 L p
1 g
F P
s
P
p
.002 w
.58433 .45065 m .55168 .4859 L .56782 .5062 L p
1 g
F P
s
P
p
.002 w
.38982 .45652 m .42011 .46835 L .42386 .44015 L p
1 g
F P
s
P
p
.002 w
.42386 .44015 m .40058 .43079 L .38982 .45652 L p
1 g
F P
s
P
p
.002 w
.43676 .38399 m .42878 .38061 L .41366 .40533 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .42878 .38061 L .43676 .38399 L closepath p
1 g
F P
s
P
p
.002 w
.41847 .52235 m .46474 .52367 L .45863 .49736 L p
1 g
F P
s
P
p
.002 w
.45863 .49736 m .41829 .49594 L .41847 .52235 L p
1 g
F P
s
P
p
.002 w
.49916 .33492 m .50287 .35144 L .53169 .35149 L p
1 g
F P
s
P
p
.002 w
.50287 .35144 m .49916 .33492 L .47205 .34497 L p
1 g
F P
s
P
p
.002 w
.47205 .34497 m .47401 .35332 L .50287 .35144 L p
1 g
F P
s
P
p
.002 w
.47184 .54817 m .52241 .53401 L .51056 .51103 L p
1 g
F P
s
P
p
.002 w
.51056 .51103 m .46474 .52367 L .47184 .54817 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .47401 .35332 L .47205 .34497 L closepath p
1 g
F P
s
P
p
.002 w
.52649 .32717 m .53169 .35149 L .55993 .35348 L p
1 g
F P
s
P
p
.002 w
.53169 .35149 m .52649 .32717 L .49916 .33492 L p
1 g
F P
s
P
p
.002 w
.56782 .5062 m .60397 .46733 L .58433 .45065 L p
1 g
F P
s
P
p
.002 w
.60537 .40848 m .58433 .45065 L .60397 .46733 L p
1 g
F P
s
P
p
.002 w
.58433 .45065 m .60537 .40848 L .58115 .3969 L p
1 g
F P
s
P
p
.002 w
.40143 .39388 m .41366 .40533 L .42878 .38061 L p
1 g
F P
s
P
p
.002 w
.42878 .38061 m .42266 .37475 L .40143 .39388 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .42266 .37475 L .42878 .38061 L closepath p
1 g
F P
s
P
p
.002 w
.58705 .35741 m .58115 .3969 L .60537 .40848 L p
1 g
F P
s
P
p
.002 w
.58115 .3969 m .58705 .35741 L .55993 .35348 L p
1 g
F P
s
P
p
.002 w
.38165 .482 m .41829 .49594 L .42011 .46835 L p
1 g
F P
s
P
p
.002 w
.42011 .46835 m .38982 .45652 L .38165 .482 L p
1 g
F P
s
P
p
.002 w
.3824 .41414 m .40058 .43079 L .41366 .40533 L p
1 g
F P
s
P
p
.002 w
.41366 .40533 m .40143 .39388 L .3824 .41414 L p
1 g
F P
s
P
p
.002 w
.46728 .33799 m .47205 .34497 L .49916 .33492 L p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .47205 .34497 L .46728 .33799 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .46728 .33799 L .4602 .33313 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .4602 .33313 L .45157 .33097 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .45157 .33097 L .44232 .33175 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .44232 .33175 L .43349 .3354 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .43349 .3354 L .42606 .34153 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .42606 .34153 L .42085 .34946 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .42085 .34946 L .41844 .35828 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .41844 .35828 L .41908 .36703 L closepath p
1 g
F P
s
P
p
.002 w
.44567 .3571 m .41908 .36703 L .42266 .37475 L closepath p
1 g
F P
s
P
p
.002 w
.39416 .37867 m .40143 .39388 L .42266 .37475 L p
1 g
F P
s
P
p
.002 w
.42266 .37475 m .41908 .36703 L .39416 .37867 L p
1 g
F P
s
P
p
.002 w
.48989 .321 m .49916 .33492 L .52649 .32717 L p
1 g
F P
s
P
p
.002 w
.49916 .33492 m .48989 .321 L .46728 .33799 L p
1 g
F P
s
P
p
.002 w
.55351 .32188 m .55993 .35348 L .58705 .35741 L p
1 g
F P
s
P
p
.002 w
.55993 .35348 m .55351 .32188 L .52649 .32717 L p
1 g
F P
s
P
p
.002 w
.4602 .33313 m .46728 .33799 L .48989 .321 L p
1 g
F P
s
P
p
.002 w
.36601 .43515 m .38982 .45652 L .40058 .43079 L p
1 g
F P
s
P
p
.002 w
.40058 .43079 m .3824 .41414 L .36601 .43515 L p
1 g
F P
s
P
p
.002 w
.42071 .54703 m .47184 .54817 L .46474 .52367 L p
1 g
F P
s
P
p
.002 w
.46474 .52367 m .41847 .52235 L .42071 .54703 L p
1 g
F P
s
P
p
.002 w
.53399 .55493 m .58263 .52507 L .56782 .5062 L p
1 g
F P
s
P
p
.002 w
.56782 .5062 m .52241 .53401 L .53399 .55493 L p
1 g
F P
s
P
p
.002 w
.60397 .46733 m .56782 .5062 L .58263 .52507 L p
1 g
F P
s
P
p
.002 w
.39275 .36129 m .39416 .37867 L .41908 .36703 L p
1 g
F P
s
P
p
.002 w
.41908 .36703 m .41844 .35828 L .39275 .36129 L p
1 g
F P
s
P
p
.002 w
.3763 .50672 m .41847 .52235 L .41829 .49594 L p
1 g
F P
s
P
p
.002 w
.41829 .49594 m .38165 .482 L .3763 .50672 L p
1 g
F P
s
P
p
.002 w
.37146 .39181 m .3824 .41414 L .40143 .39388 L p
1 g
F P
s
P
p
.002 w
.40143 .39388 m .39416 .37867 L .37146 .39181 L p
1 g
F P
s
P
p
.002 w
.48989 .321 m .47595 .31124 L .4602 .33313 L p
1 g
F P
s
P
p
.002 w
.45157 .33097 m .4602 .33313 L .47595 .31124 L p
1 g
F P
s
P
p
.002 w
.47983 .5703 m .53399 .55493 L .52241 .53401 L p
1 g
F P
s
P
p
.002 w
.52241 .53401 m .47184 .54817 L .47983 .5703 L p
1 g
F P
s
P
p
.002 w
.51305 .30652 m .52649 .32717 L .55351 .32188 L p
1 g
F P
s
P
p
.002 w
.52649 .32717 m .51305 .30652 L .48989 .321 L p
1 g
F P
s
P
p
.002 w
.60397 .46733 m .62744 .42084 L .60537 .40848 L p
1 g
F P
s
P
p
.002 w
.61248 .36324 m .60537 .40848 L .62744 .42084 L p
1 g
F P
s
P
p
.002 w
.60537 .40848 m .61248 .36324 L .58705 .35741 L p
1 g
F P
s
P
p
.002 w
.39745 .34367 m .39275 .36129 L .41844 .35828 L p
1 g
F P
s
P
p
.002 w
.41844 .35828 m .42085 .34946 L .39745 .34367 L p
1 g
F P
s
P
p
.002 w
.47595 .31124 m .48989 .321 L .51305 .30652 L p
1 g
F P
s
P
p
.002 w
.58263 .52507 m .62147 .48347 L .60397 .46733 L p
1 g
F P
s
P
p
.002 w
.62744 .42084 m .60397 .46733 L .62147 .48347 L p
1 g
F P
s
P
p
.002 w
.47595 .31124 m .4588 .3068 L .45157 .33097 L p
1 g
F P
s
P
p
.002 w
.44232 .33175 m .45157 .33097 L .4588 .3068 L p
1 g
F P
s
P
p
.002 w
.35266 .4565 m .38165 .482 L .38982 .45652 L p
1 g
F P
s
P
p
.002 w
.38982 .45652 m .36601 .43515 L .35266 .4565 L p
1 g
F P
s
P
p
.002 w
.4078 .32781 m .39745 .34367 L .42085 .34946 L p
1 g
F P
s
P
p
.002 w
.42085 .34946 m .42606 .34153 L .4078 .32781 L p
1 g
F P
s
P
p
.002 w
.57967 .31923 m .58705 .35741 L .61248 .36324 L p
1 g
F P
s
P
p
.002 w
.58705 .35741 m .57967 .31923 L .55351 .32188 L p
1 g
F P
s
P
p
.002 w
.4588 .3068 m .44035 .30826 L .44232 .33175 L p
1 g
F P
s
P
p
.002 w
.43349 .3354 m .44232 .33175 L .44035 .30826 L p
1 g
F P
s
P
p
.002 w
.42267 .31554 m .4078 .32781 L .42606 .34153 L p
1 g
F P
s
P
p
.002 w
.42606 .34153 m .43349 .3354 L .42267 .31554 L p
1 g
F P
s
P
p
.002 w
.44035 .30826 m .42267 .31554 L .43349 .3354 L p
1 g
F P
s
P
p
.002 w
.36916 .36612 m .37146 .39181 L .39416 .37867 L p
1 g
F P
s
P
p
.002 w
.39416 .37867 m .39275 .36129 L .36916 .36612 L p
1 g
F P
s
P
p
.002 w
.3515 .40624 m .36601 .43515 L .3824 .41414 L p
1 g
F P
s
P
p
.002 w
.3824 .41414 m .37146 .39181 L .3515 .40624 L p
1 g
F P
s
P
p
.002 w
.42504 .56939 m .47983 .5703 L .47184 .54817 L p
1 g
F P
s
P
p
.002 w
.47184 .54817 m .42071 .54703 L .42504 .56939 L p
1 g
F P
s
P
p
.002 w
.53633 .29488 m .55351 .32188 L .57967 .31923 L p
1 g
F P
s
P
p
.002 w
.55351 .32188 m .53633 .29488 L .51305 .30652 L p
1 g
F P
s
P
p
.002 w
.51305 .30652 m .49261 .29191 L .47595 .31124 L p
1 g
F P
s
P
p
.002 w
.4588 .3068 m .47595 .31124 L .49261 .29191 L p
1 g
F P
s
P
p
.002 w
.37398 .53012 m .42071 .54703 L .41847 .52235 L p
1 g
F P
s
P
p
.002 w
.41847 .52235 m .3763 .50672 L .37398 .53012 L p
1 g
F P
s
P
p
.002 w
.49261 .29191 m .51305 .30652 L .53633 .29488 L p
1 g
F P
s
P
p
.002 w
.54502 .57328 m .59578 .54208 L .58263 .52507 L p
1 g
F P
s
P
p
.002 w
.58263 .52507 m .53399 .55493 L .54502 .57328 L p
1 g
F P
s
P
p
.002 w
.62147 .48347 m .58263 .52507 L .59578 .54208 L p
1 g
F P
s
P
p
.002 w
.376 .33994 m .36916 .36612 L .39275 .36129 L p
1 g
F P
s
P
p
.002 w
.39275 .36129 m .39745 .34367 L .376 .33994 L p
1 g
F P
s
P
p
.002 w
.62147 .48347 m .64684 .43376 L .62744 .42084 L p
1 g
F P
s
P
p
.002 w
.63565 .37091 m .62744 .42084 L .64684 .43376 L p
1 g
F P
s
P
p
.002 w
.62744 .42084 m .63565 .37091 L .61248 .36324 L p
1 g
F P
s
P
p
.002 w
.48857 .5895 m .54502 .57328 L .53399 .55493 L p
1 g
F P
s
P
p
.002 w
.53399 .55493 m .47983 .5703 L .48857 .5895 L p
1 g
F P
s
P
p
.002 w
.34276 .47773 m .3763 .50672 L .38165 .482 L p
1 g
F P
s
P
p
.002 w
.38165 .482 m .35266 .4565 L .34276 .47773 L p
1 g
F P
s
P
p
.002 w
.49261 .29191 m .46727 .28515 L .4588 .3068 L p
1 g
F P
s
P
p
.002 w
.44035 .30826 m .4588 .3068 L .46727 .28515 L p
1 g
F P
s
P
p
.002 w
.60439 .31935 m .61248 .36324 L .63565 .37091 L p
1 g
F P
s
P
p
.002 w
.61248 .36324 m .60439 .31935 L .57967 .31923 L p
1 g
F P
s
P
p
.002 w
.59578 .54208 m .63638 .49873 L .62147 .48347 L p
1 g
F P
s
P
p
.002 w
.64684 .43376 m .62147 .48347 L .63638 .49873 L p
1 g
F P
s
P
p
.002 w
.33482 .42168 m .35266 .4565 L .36601 .43515 L p
1 g
F P
s
P
p
.002 w
.36601 .43515 m .3515 .40624 L .33482 .42168 L p
1 g
F P
s
P
p
.002 w
.34827 .37275 m .3515 .40624 L .37146 .39181 L p
1 g
F P
s
P
p
.002 w
.37146 .39181 m .36916 .36612 L .34827 .37275 L p
1 g
F P
s
P
p
.002 w
.39135 .31629 m .376 .33994 L .39745 .34367 L p
1 g
F P
s
P
p
.002 w
.39745 .34367 m .4078 .32781 L .39135 .31629 L p
1 g
F P
s
P
p
.002 w
.46727 .28515 m .43983 .28721 L .44035 .30826 L p
1 g
F P
s
P
p
.002 w
.42267 .31554 m .44035 .30826 L .43983 .28721 L p
1 g
F P
s
P
p
.002 w
.55923 .28643 m .57967 .31923 L .60439 .31935 L p
1 g
F P
s
P
p
.002 w
.57967 .31923 m .55923 .28643 L .53633 .29488 L p
1 g
F P
s
P
p
.002 w
.41349 .29799 m .39135 .31629 L .4078 .32781 L p
1 g
F P
s
P
p
.002 w
.4078 .32781 m .42267 .31554 L .41349 .29799 L p
1 g
F P
s
P
p
.002 w
.43983 .28721 m .41349 .29799 L .42267 .31554 L p
1 g
F P
s
P
p
.002 w
.53633 .29488 m .50987 .27563 L .49261 .29191 L p
1 g
F P
s
P
p
.002 w
.46727 .28515 m .49261 .29191 L .50987 .27563 L p
1 g
F P
s
P
p
.002 w
.50987 .27563 m .53633 .29488 L .55923 .28643 L p
1 g
F P
s
P
p
.002 w
.37488 .55162 m .42504 .56939 L .42071 .54703 L p
1 g
F P
s
P
p
.002 w
.42071 .54703 m .37398 .53012 L .37488 .55162 L p
1 g
F P
s
P
p
.002 w
.43145 .58883 m .48857 .5895 L .47983 .5703 L p
1 g
F P
s
P
p
.002 w
.47983 .5703 m .42504 .56939 L .43145 .58883 L p
1 g
F P
s
P
p
.002 w
.33667 .49836 m .37398 .53012 L .3763 .50672 L p
1 g
F P
s
P
p
.002 w
.3763 .50672 m .34276 .47773 L .33667 .49836 L p
1 g
F P
s
P
p
.002 w
.35706 .33843 m .34827 .37275 L .36916 .36612 L p
1 g
F P
s
P
p
.002 w
.36916 .36612 m .376 .33994 L .35706 .33843 L p
1 g
F P
s
P
p
.002 w
.63638 .49873 m .66305 .44698 L .64684 .43376 L p
1 g
F P
s
P
p
.002 w
.65596 .38032 m .64684 .43376 L .66305 .44698 L p
1 g
F P
s
P
p
.002 w
.64684 .43376 m .65596 .38032 L .63565 .37091 L p
1 g
F P
s
P
p
.002 w
.55527 .58856 m .60689 .55677 L .59578 .54208 L p
1 g
F P
s
P
p
.002 w
.59578 .54208 m .54502 .57328 L .55527 .58856 L p
1 g
F P
s
P
p
.002 w
.63638 .49873 m .59578 .54208 L .60689 .55677 L p
1 g
F P
s
P
p
.002 w
.62709 .32234 m .63565 .37091 L .65596 .38032 L p
1 g
F P
s
P
p
.002 w
.63565 .37091 m .62709 .32234 L .60439 .31935 L p
1 g
F P
s
P
p
.002 w
.50987 .27563 m .47683 .2666 L .46727 .28515 L p
1 g
F P
s
P
p
.002 w
.43983 .28721 m .46727 .28515 L .47683 .2666 L p
1 g
F P
s
P
p
.002 w
.32195 .43784 m .34276 .47773 L .35266 .4565 L p
1 g
F P
s
P
p
.002 w
.35266 .4565 m .33482 .42168 L .32195 .43784 L p
1 g
F P
s
P
p
.002 w
.49791 .6052 m .55527 .58856 L .54502 .57328 L p
1 g
F P
s
P
p
.002 w
.54502 .57328 m .48857 .5895 L .49791 .6052 L p
1 g
F P
s
P
p
.002 w
.33066 .38109 m .33482 .42168 L .3515 .40624 L p
1 g
F P
s
P
p
.002 w
.3515 .40624 m .34827 .37275 L .33066 .38109 L p
1 g
F P
s
P
p
.002 w
.60689 .55677 m .64826 .51274 L .63638 .49873 L p
1 g
F P
s
P
p
.002 w
.66305 .44698 m .63638 .49873 L .64826 .51274 L p
1 g
F P
s
P
p
.002 w
.58123 .28148 m .60439 .31935 L .62709 .32234 L p
1 g
F P
s
P
p
.002 w
.60439 .31935 m .58123 .28148 L .55923 .28643 L p
1 g
F P
s
P
p
.002 w
.37714 .30734 m .35706 .33843 L .376 .33994 L p
1 g
F P
s
P
p
.002 w
.376 .33994 m .39135 .31629 L .37714 .30734 L p
1 g
F P
s
P
p
.002 w
.55923 .28643 m .52739 .26289 L .50987 .27563 L p
1 g
F P
s
P
p
.002 w
.47683 .2666 m .50987 .27563 L .52739 .26289 L p
1 g
F P
s
P
p
.002 w
.47683 .2666 m .44087 .26917 L .43983 .28721 L p
1 g
F P
s
P
p
.002 w
.41349 .29799 m .43983 .28721 L .44087 .26917 L p
1 g
F P
s
P
p
.002 w
.52739 .26289 m .55923 .28643 L .58123 .28148 L p
1 g
F P
s
P
p
.002 w
.40624 .28328 m .37714 .30734 L .39135 .31629 L p
1 g
F P
s
P
p
.002 w
.39135 .31629 m .41349 .29799 L .40624 .28328 L p
1 g
F P
s
P
p
.002 w
.37912 .57063 m .43145 .58883 L .42504 .56939 L p
1 g
F P
s
P
p
.002 w
.42504 .56939 m .37488 .55162 L .37912 .57063 L p
1 g
F P
s
P
p
.002 w
.44087 .26917 m .40624 .28328 L .41349 .29799 L p
1 g
F P
s
P
p
.002 w
.4399 .60476 m .49791 .6052 L .48857 .5895 L p
1 g
F P
s
P
p
.002 w
.48857 .5895 m .43145 .58883 L .4399 .60476 L p
1 g
F P
s
P
p
.002 w
.33472 .51787 m .37488 .55162 L .37398 .53012 L p
1 g
F P
s
P
p
.002 w
.37398 .53012 m .33667 .49836 L .33472 .51787 L p
1 g
F P
s
P
p
.002 w
.34121 .33929 m .33066 .38109 L .34827 .37275 L p
1 g
F P
s
P
p
.002 w
.34827 .37275 m .35706 .33843 L .34121 .33929 L p
1 g
F P
s
P
p
.002 w
.66305 .44698 m .67285 .39135 L .65596 .38032 L p
1 g
F P
s
P
p
.002 w
.64716 .32826 m .65596 .38032 L .67285 .39135 L p
1 g
F P
s
P
p
.002 w
.65596 .38032 m .64716 .32826 L .62709 .32234 L p
1 g
F P
s
P
p
.002 w
.67285 .39135 m .66305 .44698 L .67553 .46022 L p
1 g
F P
s
P
p
.002 w
.64826 .51274 m .67553 .46022 L .66305 .44698 L p
1 g
F P
s
P
p
.002 w
.31338 .45436 m .33667 .49836 L .34276 .47773 L p
1 g
F P
s
P
p
.002 w
.34276 .47773 m .32195 .43784 L .31338 .45436 L p
1 g
F P
s
P
p
.002 w
.31692 .39106 m .32195 .43784 L .33482 .42168 L p
1 g
F P
s
P
p
.002 w
.33482 .42168 m .33066 .38109 L .31692 .39106 L p
1 g
F P
s
P
p
.002 w
.56443 .60025 m .6156 .5687 L .60689 .55677 L p
1 g
F P
s
P
p
.002 w
.60689 .55677 m .55527 .58856 L .56443 .60025 L p
1 g
F P
s
P
p
.002 w
.64826 .51274 m .60689 .55677 L .6156 .5687 L p
1 g
F P
s
P
p
.002 w
.52739 .26289 m .48732 .25172 L .47683 .2666 L p
1 g
F P
s
P
p
.002 w
.44087 .26917 m .47683 .2666 L .48732 .25172 L p
1 g
F P
s
P
p
.002 w
.60179 .28029 m .62709 .32234 L .64716 .32826 L p
1 g
F P
s
P
p
.002 w
.62709 .32234 m .60179 .28029 L .58123 .28148 L p
1 g
F P
s
P
p
.002 w
.50765 .61685 m .56443 .60025 L .55527 .58856 L p
1 g
F P
s
P
p
.002 w
.55527 .58856 m .49791 .6052 L .50765 .61685 L p
1 g
F P
s
P
p
.002 w
.6156 .5687 m .65666 .52509 L .64826 .51274 L p
1 g
F P
s
P
p
.002 w
.67553 .46022 m .64826 .51274 L .65666 .52509 L p
1 g
F P
s
P
p
.002 w
.54476 .25414 m .58123 .28148 L .60179 .28029 L p
1 g
F P
s
P
p
.002 w
.58123 .28148 m .54476 .25414 L .52739 .26289 L p
1 g
F P
s
P
p
.002 w
.48732 .25172 m .52739 .26289 L .54476 .25414 L p
1 g
F P
s
P
p
.002 w
.36564 .30131 m .34121 .33929 L .35706 .33843 L p
1 g
F P
s
P
p
.002 w
.35706 .33843 m .37714 .30734 L .36564 .30131 L p
1 g
F P
s
P
p
.002 w
.48732 .25172 m .4435 .25472 L .44087 .26917 L p
1 g
F P
s
P
p
.002 w
.40624 .28328 m .44087 .26917 L .4435 .25472 L p
1 g
F P
s
P
p
.002 w
.38677 .58654 m .4399 .60476 L .43145 .58883 L p
1 g
F P
s
P
p
.002 w
.43145 .58883 m .37912 .57063 L .38677 .58654 L p
1 g
F P
s
P
p
.002 w
.40119 .2719 m .36564 .30131 L .37714 .30734 L p
1 g
F P
s
P
p
.002 w
.37714 .30734 m .40624 .28328 L .40119 .2719 L p
1 g
F P
s
P
p
.002 w
.33717 .53572 m .37912 .57063 L .37488 .55162 L p
1 g
F P
s
P
p
.002 w
.37488 .55162 m .33472 .51787 L .33717 .53572 L p
1 g
F P
s
P
p
.002 w
.4435 .25472 m .40119 .2719 L .40624 .28328 L p
1 g
F P
s
P
p
.002 w
.45028 .61659 m .50765 .61685 L .49791 .6052 L p
1 g
F P
s
P
p
.002 w
.49791 .6052 m .4399 .60476 L .45028 .61659 L p
1 g
F P
s
P
p
.002 w
.329 .34265 m .31692 .39106 L .33066 .38109 L p
1 g
F P
s
P
p
.002 w
.33066 .38109 m .34121 .33929 L .329 .34265 L p
1 g
F P
s
P
p
.002 w
.30957 .47084 m .33472 .51787 L .33667 .49836 L p
1 g
F P
s
P
p
.002 w
.33667 .49836 m .31338 .45436 L .30957 .47084 L p
1 g
F P
s
P
p
.002 w
.67553 .46022 m .68572 .40381 L .67285 .39135 L p
1 g
F P
s
P
p
.002 w
.66399 .33711 m .67285 .39135 L .68572 .40381 L p
1 g
F P
s
P
p
.002 w
.67285 .39135 m .66399 .33711 L .64716 .32826 L p
1 g
F P
s
P
p
.002 w
.65666 .52509 m .6838 .47316 L .67553 .46022 L p
1 g
F P
s
P
p
.002 w
.68572 .40381 m .67553 .46022 L .6838 .47316 L p
1 g
F P
s
P
p
.002 w
.30762 .40247 m .31338 .45436 L .32195 .43784 L p
1 g
F P
s
P
p
.002 w
.32195 .43784 m .31692 .39106 L .30762 .40247 L p
1 g
F P
s
P
p
.002 w
.62033 .28308 m .64716 .32826 L .66399 .33711 L p
1 g
F P
s
P
p
.002 w
.64716 .32826 m .62033 .28308 L .60179 .28029 L p
1 g
F P
s
P
p
.002 w
.54476 .25414 m .49855 .24106 L .48732 .25172 L p
1 g
F P
s
P
p
.002 w
.4435 .25472 m .48732 .25172 L .49855 .24106 L p
1 g
F P
s
P
p
.002 w
.57224 .60785 m .62157 .57741 L .6156 .5687 L p
1 g
F P
s
P
p
.002 w
.6156 .5687 m .56443 .60025 L .57224 .60785 L p
1 g
F P
s
P
p
.002 w
.65666 .52509 m .6156 .5687 L .62157 .57741 L p
1 g
F P
s
P
p
.002 w
.56155 .24981 m .60179 .28029 L .62033 .28308 L p
1 g
F P
s
P
p
.002 w
.60179 .28029 m .56155 .24981 L .54476 .25414 L p
1 g
F P
s
P
p
.002 w
.51757 .62392 m .57224 .60785 L .56443 .60025 L p
1 g
F P
s
P
p
.002 w
.56443 .60025 m .50765 .61685 L .51757 .62392 L p
1 g
F P
s
P
p
.002 w
.49855 .24106 m .54476 .25414 L .56155 .24981 L p
1 g
F P
s
P
p
.002 w
.62157 .57741 m .66119 .5354 L .65666 .52509 L p
1 g
F P
s
P
p
.002 w
.6838 .47316 m .65666 .52509 L .66119 .5354 L p
1 g
F P
s
P
p
.002 w
.35731 .29853 m .329 .34265 L .34121 .33929 L p
1 g
F P
s
P
p
.002 w
.34121 .33929 m .36564 .30131 L .35731 .29853 L p
1 g
F P
s
P
p
.002 w
.39782 .59876 m .45028 .61659 L .4399 .60476 L p
1 g
F P
s
P
p
.002 w
.4399 .60476 m .38677 .58654 L .39782 .59876 L p
1 g
F P
s
P
p
.002 w
.49855 .24106 m .44777 .24443 L .4435 .25472 L p
1 g
F P
s
P
p
.002 w
.40119 .2719 m .4435 .25472 L .44777 .24443 L p
1 g
F P
s
P
p
.002 w
.34421 .55133 m .38677 .58654 L .37912 .57063 L p
1 g
F P
s
P
p
.002 w
.37912 .57063 m .33717 .53572 L .34421 .55133 L p
1 g
F P
s
P
p
.002 w
.39862 .26435 m .35731 .29853 L .36564 .30131 L p
1 g
F P
s
P
p
.002 w
.36564 .30131 m .40119 .2719 L .39862 .26435 L p
1 g
F P
s
P
p
.002 w
.46244 .62377 m .51757 .62392 L .50765 .61685 L p
1 g
F P
s
P
p
.002 w
.50765 .61685 m .45028 .61659 L .46244 .62377 L p
1 g
F P
s
P
p
.002 w
.44777 .24443 m .39862 .26435 L .40119 .2719 L p
1 g
F P
s
P
p
.002 w
.31087 .48684 m .33717 .53572 L .33472 .51787 L p
1 g
F P
s
P
p
.002 w
.33472 .51787 m .30957 .47084 L .31087 .48684 L p
1 g
F P
s
P
p
.002 w
.32098 .34856 m .30762 .40247 L .31692 .39106 L p
1 g
F P
s
P
p
.002 w
.31692 .39106 m .329 .34265 L .32098 .34856 L p
1 g
F P
s
P
p
.002 w
.6838 .47316 m .69404 .41745 L .68572 .40381 L p
1 g
F P
s
P
p
.002 w
.67697 .34882 m .68572 .40381 L .69404 .41745 L p
1 g
F P
s
P
p
.002 w
.68572 .40381 m .67697 .34882 L .66399 .33711 L p
1 g
F P
s
P
p
.002 w
.30327 .41512 m .30957 .47084 L .31338 .45436 L p
1 g
F P
s
P
p
.002 w
.31338 .45436 m .30762 .40247 L .30327 .41512 L p
1 g
F P
s
P
p
.002 w
.66119 .5354 m .6874 .48546 L .6838 .47316 L p
1 g
F P
s
P
p
.002 w
.69404 .41745 m .6838 .47316 L .6874 .48546 L p
1 g
F P
s
P
p
.002 w
.63627 .29 m .66399 .33711 L .67697 .34882 L p
1 g
F P
s
P
p
.002 w
.66399 .33711 m .63627 .29 L .62033 .28308 L p
1 g
F P
s
P
p
.002 w
.56155 .24981 m .51026 .23514 L .49855 .24106 L p
1 g
F P
s
P
p
.002 w
.44777 .24443 m .49855 .24106 L .51026 .23514 L p
1 g
F P
s
P
p
.002 w
.5773 .25026 m .62033 .28308 L .63627 .29 L p
1 g
F P
s
P
p
.002 w
.62033 .28308 m .5773 .25026 L .56155 .24981 L p
1 g
F P
s
P
p
.002 w
.57841 .61091 m .62447 .58247 L .62157 .57741 L p
1 g
F P
s
P
p
.002 w
.62157 .57741 m .57224 .60785 L .57841 .61091 L p
1 g
F P
s
P
p
.002 w
.66119 .5354 m .62157 .57741 L .62447 .58247 L p
1 g
F P
s
P
p
.002 w
.51026 .23514 m .56155 .24981 L .5773 .25026 L p
1 g
F P
s
P
p
.002 w
.52742 .62594 m .57841 .61091 L .57224 .60785 L p
1 g
F P
s
P
p
.002 w
.57224 .60785 m .51757 .62392 L .52742 .62594 L p
1 g
F P
s
P
p
.002 w
.35256 .29929 m .32098 .34856 L .329 .34265 L p
1 g
F P
s
P
p
.002 w
.329 .34265 m .35731 .29853 L .35256 .29929 L p
1 g
F P
s
P
p
.002 w
.62447 .58247 m .66148 .54326 L .66119 .5354 L p
1 g
F P
s
P
p
.002 w
.6874 .48546 m .66119 .5354 L .66148 .54326 L p
1 g
F P
s
P
p
.002 w
.41216 .60674 m .46244 .62377 L .45028 .61659 L p
1 g
F P
s
P
p
.002 w
.45028 .61659 m .39782 .59876 L .41216 .60674 L p
1 g
F P
s
P
p
.002 w
.35589 .56414 m .39782 .59876 L .38677 .58654 L p
1 g
F P
s
P
p
.002 w
.38677 .58654 m .34421 .55133 L .35589 .56414 L p
1 g
F P
s
P
p
.002 w
.51026 .23514 m .45367 .23884 L .44777 .24443 L p
1 g
F P
s
P
p
.002 w
.39862 .26435 m .44777 .24443 L .45367 .23884 L p
1 g
F P
s
P
p
.002 w
.31756 .50187 m .34421 .55133 L .33717 .53572 L p
1 g
F P
s
P
p
.002 w
.33717 .53572 m .31087 .48684 L .31756 .50187 L p
1 g
F P
s
P
p
.002 w
.47615 .62582 m .52742 .62594 L .51757 .62392 L p
1 g
F P
s
P
p
.002 w
.51757 .62392 m .46244 .62377 L .47615 .62582 L p
1 g
F P
s
P
p
.002 w
.39875 .26107 m .35256 .29929 L .35731 .29853 L p
1 g
F P
s
P
p
.002 w
.35731 .29853 m .39862 .26435 L .39875 .26107 L p
1 g
F P
s
P
p
.002 w
.31765 .35702 m .30327 .41512 L .30762 .40247 L p
1 g
F P
s
P
p
.002 w
.30762 .40247 m .32098 .34856 L .31765 .35702 L p
1 g
F P
s
P
p
.002 w
.6874 .48546 m .69732 .432 L .69404 .41745 L p
1 g
F P
s
P
p
.002 w
.68554 .36324 m .69404 .41745 L .69732 .432 L p
1 g
F P
s
P
p
.002 w
.69404 .41745 m .68554 .36324 L .67697 .34882 L p
1 g
F P
s
P
p
.002 w
.45367 .23884 m .39875 .26107 L .39862 .26435 L p
1 g
F P
s
P
p
.002 w
.30429 .42872 m .31087 .48684 L .30957 .47084 L p
1 g
F P
s
P
p
.002 w
.30957 .47084 m .30327 .41512 L .30429 .42872 L p
1 g
F P
s
P
p
.002 w
.64902 .30109 m .67697 .34882 L .68554 .36324 L p
1 g
F P
s
P
p
.002 w
.67697 .34882 m .64902 .30109 L .63627 .29 L p
1 g
F P
s
P
p
.002 w
.66148 .54326 m .68594 .49674 L .6874 .48546 L p
1 g
F P
s
P
p
.002 w
.69732 .432 m .6874 .48546 L .68594 .49674 L p
1 g
F P
s
P
p
.002 w
.5773 .25026 m .52217 .23442 L .51026 .23514 L p
1 g
F P
s
P
p
.002 w
.45367 .23884 m .51026 .23514 L .52217 .23442 L p
1 g
F P
s
P
p
.002 w
.63627 .29 m .59151 .25575 L .5773 .25026 L p
1 g
F P
s
P
p
.002 w
.59151 .25575 m .63627 .29 L .64902 .30109 L p
1 g
F P
s
P
p
.002 w
.52217 .23442 m .5773 .25026 L .59151 .25575 L p
1 g
F P
s
P
p
.002 w
.58264 .60904 m .62401 .5835 L .62447 .58247 L p
1 g
F P
s
P
p
.002 w
.62447 .58247 m .57841 .61091 L .58264 .60904 L p
1 g
F P
s
P
p
.002 w
.66148 .54326 m .62447 .58247 L .62401 .5835 L p
1 g
F P
s
P
p
.002 w
.53692 .62251 m .58264 .60904 L .57841 .61091 L p
1 g
F P
s
P
p
.002 w
.57841 .61091 m .52742 .62594 L .53692 .62251 L p
1 g
F P
s
P
p
.002 w
.37213 .57361 m .41216 .60674 L .39782 .59876 L p
1 g
F P
s
P
p
.002 w
.39782 .59876 m .35589 .56414 L .37213 .57361 L p
1 g
F P
s
P
p
.002 w
.42956 .60999 m .47615 .62582 L .46244 .62377 L p
1 g
F P
s
P
p
.002 w
.46244 .62377 m .41216 .60674 L .42956 .60999 L p
1 g
F P
s
P
p
.002 w
.35178 .3038 m .31765 .35702 L .32098 .34856 L p
1 g
F P
s
P
p
.002 w
.32098 .34856 m .35256 .29929 L .35178 .3038 L p
1 g
F P
s
P
p
.002 w
.62401 .5835 m .65724 .5483 L .66148 .54326 L p
1 g
F P
s
P
p
.004 w
.64764 .55846 m
.64852 .55922 L
s
P
p
.004 w
.5 .43051 m
.64743 .55828 L
s
P
p
.004 w
.64852 .55922 m
.65645 .5661 L
s
P
p
.004 w
.65645 .5661 m
.72508 .62558 L
s
P
p
.002 w
.68594 .49674 m .66148 .54326 L .65724 .5483 L p
1 g
F P
s
P
p
.002 w
.32975 .51542 m .35589 .56414 L .34421 .55133 L p
1 g
F P
s
P
p
.002 w
.34421 .55133 m .31756 .50187 L .32975 .51542 L p
1 g
F P
s
P
p
.002 w
.52217 .23442 m .46112 .23841 L .45367 .23884 L p
1 g
F P
s
P
p
.002 w
.39875 .26107 m .45367 .23884 L .46112 .23841 L p
1 g
F P
s
P
p
.002 w
.68594 .49674 m .69516 .44708 L .69732 .432 L p
1 g
F P
s
P
p
.002 w
.69732 .432 m .6892 .38011 L .68554 .36324 L p
1 g
F P
s
P
p
.002 w
.6892 .38011 m .69732 .432 L .69516 .44708 L p
1 g
F P
s
P
p
.002 w
.3194 .36796 m .30429 .42872 L .30327 .41512 L p
1 g
F P
s
P
p
.002 w
.30327 .41512 m .31765 .35702 L .3194 .36796 L p
1 g
F P
s
P
p
.002 w
.31099 .44292 m .31756 .50187 L .31087 .48684 L p
1 g
F P
s
P
p
.002 w
.31087 .48684 m .30429 .42872 L .31099 .44292 L p
1 g
F P
s
P
p
.002 w
.49108 .62237 m .53692 .62251 L .52742 .62594 L p
1 g
F P
s
P
p
.002 w
.52742 .62594 m .47615 .62582 L .49108 .62237 L p
1 g
F P
s
P
p
.002 w
.68554 .36324 m .65804 .31627 L .64902 .30109 L p
1 g
F P
s
P
p
.002 w
.65804 .31627 m .68554 .36324 L .6892 .38011 L p
1 g
F P
s
P
p
.002 w
.40175 .26246 m .35178 .3038 L .35256 .29929 L p
1 g
F P
s
P
p
.002 w
.35256 .29929 m .39875 .26107 L .40175 .26246 L p
1 g
F P
s
P
p
.002 w
.46112 .23841 m .40175 .26246 L .39875 .26107 L p
1 g
F P
s
P
p
.002 w
.65724 .5483 m .67914 .50661 L .68594 .49674 L p
1 g
F P
s
P
p
.002 w
.69516 .44708 m .68594 .49674 L .67914 .50661 L p
1 g
F P
s
P
p
.002 w
.60369 .26642 m .64902 .30109 L .65804 .31627 L p
1 g
F P
s
P
p
.002 w
.64902 .30109 m .60369 .26642 L .59151 .25575 L p
1 g
F P
s
P
p
.002 w
.59151 .25575 m .53394 .23923 L .52217 .23442 L p
1 g
F P
s
P
p
.002 w
.46112 .23841 m .52217 .23442 L .53394 .23923 L p
1 g
F P
s
P
p
.002 w
.53394 .23923 m .59151 .25575 L .60369 .26642 L p
1 g
F P
s
P
p
.002 w
.58469 .60198 m .61998 .58019 L .62401 .5835 L p
1 g
F P
s
P
p
.002 w
.62401 .5835 m .58264 .60904 L .58469 .60198 L p
1 g
F P
s
P
p
.002 w
.65724 .5483 m .62401 .5835 L .61998 .58019 L p
1 g
F P
s
P
p
.002 w
.39268 .57925 m .42956 .60999 L .41216 .60674 L p
1 g
F P
s
P
p
.002 w
.41216 .60674 m .37213 .57361 L .39268 .57925 L p
1 g
F P
s
P
p
.002 w
.44965 .60816 m .49108 .62237 L .47615 .62582 L p
1 g
F P
s
P
p
.002 w
.47615 .62582 m .42956 .60999 L .44965 .60816 L p
1 g
F P
s
P
p
.002 w
.54575 .61341 m .58469 .60198 L .58264 .60904 L p
1 g
F P
s
P
p
.002 w
.58264 .60904 m .53692 .62251 L .54575 .61341 L p
1 g
F P
s
P
p
.002 w
.35526 .31217 m .3194 .36796 L .31765 .35702 L p
1 g
F P
s
P
p
.002 w
.31765 .35702 m .35178 .3038 L .35526 .31217 L p
1 g
F P
s
P
p
.002 w
.34736 .52698 m .37213 .57361 L .35589 .56414 L p
1 g
F P
s
P
p
.002 w
.35589 .56414 m .32975 .51542 L .34736 .52698 L p
1 g
F P
s
P
p
.002 w
.61998 .58019 m .6483 .55017 L .65724 .5483 L p
1 g
F P
s
P
p
.002 w
.67914 .50661 m .65724 .5483 L .6483 .55017 L p
1 g
F P
s
P
p
.002 w
.53394 .23923 m .47002 .24349 L .46112 .23841 L p
1 g
F P
s
P
p
.002 w
.40175 .26246 m .46112 .23841 L .47002 .24349 L p
1 g
F P
s
P
p
.002 w
.32349 .4573 m .32975 .51542 L .31756 .50187 L p
1 g
F P
s
P
p
.002 w
.31756 .50187 m .31099 .44292 L .32349 .4573 L p
1 g
F P
s
P
p
.002 w
.67914 .50661 m .68731 .46227 L .69516 .44708 L p
1 g
F P
s
P
p
.002 w
.68757 .39905 m .69516 .44708 L .68731 .46227 L p
1 g
F P
s
P
p
.002 w
.69516 .44708 m .68757 .39905 L .6892 .38011 L p
1 g
F P
s
P
p
.002 w
.66283 .3353 m .6892 .38011 L .68757 .39905 L p
1 g
F P
s
P
p
.002 w
.6892 .38011 m .66283 .3353 L .65804 .31627 L p
1 g
F P
s
P
p
.002 w
.32651 .38117 m .31099 .44292 L .30429 .42872 L p
1 g
F P
s
P
p
.002 w
.30429 .42872 m .3194 .36796 L .32651 .38117 L p
1 g
F P
s
P
p
.002 w
.50686 .61319 m .54575 .61341 L .53692 .62251 L p
1 g
F P
s
P
p
.002 w
.53692 .62251 m .49108 .62237 L .50686 .61319 L p
1 g
F P
s
P
p
.002 w
.61332 .28225 m .65804 .31627 L .66283 .3353 L p
1 g
F P
s
P
p
.002 w
.65804 .31627 m .61332 .28225 L .60369 .26642 L p
1 g
F P
s
P
p
.002 w
.40773 .26877 m .35526 .31217 L .35178 .3038 L p
1 g
F P
s
P
p
.002 w
.35178 .3038 m .40175 .26246 L .40773 .26877 L p
1 g
F P
s
P
p
.002 w
.47002 .24349 m .40773 .26877 L .40175 .26246 L p
1 g
F P
s
P
p
.002 w
.6483 .55017 m .66688 .51469 L .67914 .50661 L p
1 g
F P
s
P
p
.002 w
.68731 .46227 m .67914 .50661 L .66688 .51469 L p
1 g
F P
s
P
p
.002 w
.60369 .26642 m .54521 .24978 L .53394 .23923 L p
1 g
F P
s
P
p
.002 w
.47002 .24349 m .53394 .23923 L .54521 .24978 L p
1 g
F P
s
P
p
.002 w
.54521 .24978 m .60369 .26642 L .61332 .28225 L p
1 g
F P
s
P
p
.002 w
.41708 .58068 m .44965 .60816 L .42956 .60999 L p
1 g
F P
s
P
p
.002 w
.42956 .60999 m .39268 .57925 L .41708 .58068 L p
1 g
F P
s
P
p
.002 w
.47191 .60101 m .50686 .61319 L .49108 .62237 L p
1 g
F P
s
P
p
.002 w
.49108 .62237 m .44965 .60816 L .47191 .60101 L p
1 g
F P
s
P
p
.002 w
.37009 .53607 m .39268 .57925 L .37213 .57361 L p
1 g
F P
s
P
p
.002 w
.37213 .57361 m .34736 .52698 L .37009 .53607 L p
1 g
F P
s
P
p
.002 w
.58435 .58959 m .61227 .57237 L .61998 .58019 L p
1 g
F P
s
P
p
.002 w
.61998 .58019 m .58469 .60198 L .58435 .58959 L p
1 g
F P
s
P
p
.002 w
.6483 .55017 m .61998 .58019 L .61227 .57237 L p
1 g
F P
s
P
p
.002 w
.55359 .59856 m .58435 .58959 L .58469 .60198 L p
1 g
F P
s
P
p
.002 w
.58469 .60198 m .54575 .61341 L .55359 .59856 L p
1 g
F P
s
P
p
.002 w
.36315 .32439 m .32651 .38117 L .3194 .36796 L p
1 g
F P
s
P
p
.002 w
.3194 .36796 m .35526 .31217 L .36315 .32439 L p
1 g
F P
s
P
p
.002 w
.61227 .57237 m .63464 .54862 L .6483 .55017 L p
1 g
F P
s
P
p
.002 w
.66688 .51469 m .6483 .55017 L .63464 .54862 L p
1 g
F P
s
P
p
.002 w
.34169 .47139 m .34736 .52698 L .32975 .51542 L p
1 g
F P
s
P
p
.002 w
.32975 .51542 m .32349 .4573 L .34169 .47139 L p
1 g
F P
s
P
p
.002 w
.68731 .46227 m .68039 .4196 L .68757 .39905 L p
1 g
F P
s
P
p
.002 w
.66302 .35779 m .68757 .39905 L .68039 .4196 L p
1 g
F P
s
P
p
.002 w
.68757 .39905 m .66302 .35779 L .66283 .3353 L p
1 g
F P
s
P
p
.002 w
.66688 .51469 m .67368 .4771 L .68731 .46227 L p
1 g
F P
s
P
p
.002 w
.68039 .4196 m .68731 .46227 L .67368 .4771 L p
1 g
F P
s
P
p
.002 w
.33905 .39636 m .32349 .4573 L .31099 .44292 L p
1 g
F P
s
P
p
.002 w
.31099 .44292 m .32651 .38117 L .33905 .39636 L p
1 g
F P
s
P
p
.002 w
.54521 .24978 m .48016 .25427 L .47002 .24349 L p
1 g
F P
s
P
p
.002 w
.40773 .26877 m .47002 .24349 L .48016 .25427 L p
1 g
F P
s
P
p
.002 w
.61997 .30302 m .66283 .3353 L .66302 .35779 L p
1 g
F P
s
P
p
.002 w
.66283 .3353 m .61997 .30302 L .61332 .28225 L p
1 g
F P
s
P
p
.002 w
.523 .59827 m .55359 .59856 L .54575 .61341 L p
1 g
F P
s
P
p
.002 w
.54575 .61341 m .50686 .61319 L .523 .59827 L p
1 g
F P
s
P
p
.002 w
.41669 .28013 m .36315 .32439 L .35526 .31217 L p
1 g
F P
s
P
p
.002 w
.35526 .31217 m .40773 .26877 L .41669 .28013 L p
1 g
F P
s
P
p
.002 w
.63464 .54862 m .64922 .5206 L .66688 .51469 L p
1 g
F P
s
P
p
.002 w
.67368 .4771 m .66688 .51469 L .64922 .5206 L p
1 g
F P
s
P
p
.002 w
.55558 .26607 m .61332 .28225 L .61997 .30302 L p
1 g
F P
s
P
p
.002 w
.61332 .28225 m .55558 .26607 L .54521 .24978 L p
1 g
F P
s
P
p
.002 w
.48016 .25427 m .54521 .24978 L .55558 .26607 L p
1 g
F P
s
P
p
.002 w
.48016 .25427 m .41669 .28013 L .40773 .26877 L p
1 g
F P
s
P
p
.002 w
.44469 .57765 m .47191 .60101 L .44965 .60816 L p
1 g
F P
s
P
p
.002 w
.44965 .60816 m .41708 .58068 L .44469 .57765 L p
1 g
F P
s
P
p
.002 w
.3974 .54224 m .41708 .58068 L .39268 .57925 L p
1 g
F P
s
P
p
.002 w
.39268 .57925 m .37009 .53607 L .3974 .54224 L p
1 g
F P
s
P
p
.002 w
.4957 .58854 m .523 .59827 L .50686 .61319 L p
1 g
F P
s
P
p
.002 w
.50686 .61319 m .47191 .60101 L .4957 .58854 L p
1 g
F P
s
P
p
.002 w
.58148 .57197 m .6009 .56001 L .61227 .57237 L p
1 g
F P
s
P
p
.002 w
.61227 .57237 m .58435 .58959 L .58148 .57197 L p
1 g
F P
s
P
p
.002 w
.63464 .54862 m .61227 .57237 L .6009 .56001 L p
1 g
F P
s
P
p
.002 w
.67368 .4771 m .66762 .44114 L .68039 .4196 L p
1 g
F P
s
P
p
.002 w
.65837 .38316 m .68039 .4196 L .66762 .44114 L p
1 g
F P
s
P
p
.002 w
.68039 .4196 m .65837 .38316 L .66302 .35779 L p
1 g
F P
s
P
p
.002 w
.36524 .48468 m .37009 .53607 L .34736 .52698 L p
1 g
F P
s
P
p
.002 w
.34736 .52698 m .34169 .47139 L .36524 .48468 L p
1 g
F P
s
P
p
.002 w
.37546 .34026 m .33905 .39636 L .32651 .38117 L p
1 g
F P
s
P
p
.002 w
.32651 .38117 m .36315 .32439 L .37546 .34026 L p
1 g
F P
s
P
p
.002 w
.56012 .57813 m .58148 .57197 L .58435 .58959 L p
1 g
F P
s
P
p
.002 w
.58435 .58959 m .55359 .59856 L .56012 .57813 L p
1 g
F P
s
P
p
.002 w
.64922 .5206 m .65442 .49106 L .67368 .4771 L p
1 g
F P
s
P
p
.002 w
.66762 .44114 m .67368 .4771 L .65442 .49106 L p
1 g
F P
s
P
p
.002 w
.6009 .56001 m .61643 .54348 L .63464 .54862 L p
1 g
F P
s
P
p
.002 w
.64922 .5206 m .63464 .54862 L .61643 .54348 L p
1 g
F P
s
P
p
.002 w
.3569 .41311 m .34169 .47139 L .32349 .4573 L p
1 g
F P
s
P
p
.002 w
.32349 .4573 m .33905 .39636 L .3569 .41311 L p
1 g
F P
s
P
p
.002 w
.62324 .32827 m .66302 .35779 L .65837 .38316 L p
1 g
F P
s
P
p
.002 w
.66302 .35779 m .62324 .32827 L .61997 .30302 L p
1 g
F P
s
P
p
.002 w
.55558 .26607 m .49129 .27073 L .48016 .25427 L p
1 g
F P
s
P
p
.002 w
.41669 .28013 m .48016 .25427 L .49129 .27073 L p
1 g
F P
s
P
p
.002 w
.53898 .57782 m .56012 .57813 L .55359 .59856 L p
1 g
F P
s
P
p
.002 w
.55359 .59856 m .523 .59827 L .53898 .57782 L p
1 g
F P
s
P
p
.002 w
.56465 .28786 m .61997 .30302 L .62324 .32827 L p
1 g
F P
s
P
p
.002 w
.61997 .30302 m .56465 .28786 L .55558 .26607 L p
1 g
F P
s
P
p
.002 w
.61643 .54348 m .62646 .52402 L .64922 .5206 L p
1 g
F P
s
P
p
.002 w
.65442 .49106 m .64922 .5206 L .62646 .52402 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.49129 .27073 m .55558 .26607 L .56465 .28786 L p
1 g
F P
s
P
p
.002 w
.4285 .29646 m .37546 .34026 L .36315 .32439 L p
1 g
F P
s
P
p
.002 w
.36315 .32439 m .41669 .28013 L .4285 .29646 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.4957 .58854 m .47191 .60101 L p
.47385 .57921 L 1 g
F P
s
P
p
.47385 .57921 m .47411 .57629 L .48058 .57996 L 1 g
F
P
p
.47385 .57921 m .48058 .57996 L .4957 .58854 L 1 g
F
P
p
.002 w
.48587 .57992 m .48669 .58064 L p
.47411 .57629 L 1 g
F P
s
P
p
.002 w
.48669 .58064 m .4957 .58854 L p
.48058 .57996 L 1 g
F P
s
P
p
.47411 .57629 m .48669 .58064 L .48058 .57996 L 1 g
F
P
p
.002 w
.523 .59827 m .4957 .58854 L .50648 .58082 L p
1 g
F P
s
P
p
.002 w
.51093 .58053 m .51079 .57862 L p
.50007 .58076 L 1 g
F P
s
P
p
.002 w
.50648 .58082 m .4957 .58854 L p
.49834 .58075 L 1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4957 .58854 m .48669 .58064 L p
.48906 .58066 L 1 g
F P
s
P
p
.49769 .58267 m .48906 .58066 L .49834 .58075 L 1 g
F
P
p
.4957 .58854 m .48906 .58066 L .49769 .58267 L 1 g
F
P
p
.48921 .57862 m .47892 .57778 L .48587 .57992 L 1 g
F
P
p
.002 w
.48906 .58066 m .48921 .57862 L p
.48587 .57992 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58066 L p
1 g
F P
s
P
p
.002 w
.48906 .58066 m .48889 .583 L p
.50007 .58076 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58066 L .50007 .58076 L 1 g
F
P
p
.002 w
.48669 .58064 m .48587 .57992 L p
.48906 .58066 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47191 .60101 m .44469 .57765 L .46332 .57295 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46832 .5745 L p
1 g
F P
s
P
p
.48921 .57862 m .46832 .5745 L .47892 .57778 L 1 g
F
P
p
.002 w
.46332 .57295 m .46483 .57258 L p
.46832 .5745 L 1 g
F P
s
P
p
.47191 .60101 m .46332 .57295 L .47411 .57629 L 1 g
F
P
p
.002 w
.46483 .57258 m .44469 .57765 L p
.45229 .56346 L 1 g
F P
s
P
p
.002 w
.46832 .5745 m .46872 .57265 L p
.45503 .56718 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .451 .56253 L p
1 g
F P
s
P
p
.002 w
.44469 .57765 m .42928 .54674 L p
.451 .56253 L 1 g
F P
s
P
p
.45208 .56385 m .451 .56253 L .45229 .56346 L 1 g
F
P
p
.44469 .57765 m .451 .56253 L .45208 .56385 L 1 g
F
P
p
.002 w
.451 .56253 m .45146 .56129 L p
.4463 .55681 L 1 g
F P
s
P
p
.46872 .57265 m .451 .56253 L .4603 .56929 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.45229 .56346 m .45088 .56238 L .46237 .54464 L 1 g
F
P
p
.002 w
.4285 .54517 m .43664 .54505 L p
.43842 .54722 L 1 g
F P
s
P
p
.4417 .55532 m .4285 .54517 L .43842 .54722 L 1 g
F
P
p
.002 w
.43842 .54722 m .43925 .54566 L p
.43572 .53868 L 1 g
F P
s
P
p
.002 w
.43754 .54503 m .4285 .54517 L p
.43564 .5384 L 1 g
F P
s
P
p
.002 w
.4285 .54517 m .42566 .50685 L .42667 .50708 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.4285 .54517 m .42667 .50708 L .43276 .52835 L 1 g
F
P
p
.43197 .54188 m .43276 .52835 L .43564 .5384 L 1 g
F
P
p
.4285 .54517 m .43276 .52835 L .43197 .54188 L 1 g
F
P
p
.002 w
.43276 .52835 m .43346 .52734 L p
.43322 .52053 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43276 .52835 L p
1 g
F P
s
P
p
.002 w
.43276 .52835 m .43146 .53025 L p
.43572 .53868 L 1 g
F P
s
P
p
.43925 .54566 m .43276 .52835 L .43572 .53868 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50942 L p
1 g
F P
s
P
p
.002 w
.42667 .50708 m .43392 .50873 L p
.43388 .50942 L 1 g
F P
s
P
p
.43276 .52835 m .42986 .5182 L .43388 .50942 L 1 g
F
P
p
.42986 .5182 m .42667 .50708 L .43388 .50942 L 1 g
F
P
p
.002 w
.43388 .50942 m .43485 .50826 L p
.43777 .50144 L 1 g
F P
s
P
p
.002 w
.43416 .50879 m .42566 .50685 L p
.43837 .50021 L 1 g
F P
s
P
p
.002 w
.42566 .50685 m .43704 .46697 L .45109 .47426 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.42566 .50685 m .45109 .47426 L .44285 .49108 L 1 g
F
P
p
.42761 .50583 m .44285 .49108 L .43837 .50021 L 1 g
F
P
p
.42566 .50685 m .44285 .49108 L .42761 .50583 L 1 g
F
P
p
.002 w
.44325 .49079 m .44166 .49233 L p
.43485 .50826 L 1 g
F P
s
P
p
.002 w
.44334 .4906 m .44339 .4905 L p
.44285 .49108 L 1 g
F P
s
P
p
.002 w
.44285 .49108 m .44339 .4905 L p
.4486 .48551 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43837 .50021 m .44285 .49108 L .46964 .48388 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45767 .47673 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45767 .47673 m .45826 .47608 L p
.46682 .47233 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46716 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45857 .47629 m .47756 .46716 L .46964 .48388 L 1 g
F
P
p
.002 w
.47756 .46716 m .47786 .46667 L p
.48904 .46553 L 1 g
F P
s
P
p
.002 w
.49859 .46411 m .51643 .47992 L p
.48133 .46668 L 1 g
F P
s
P
p
.48904 .46553 m .49554 .46487 L .48133 .46668 L 1 g
F
P
p
.48904 .46553 m .48133 .46668 L .47756 .46716 L 1 g
F
P
p
.002 w
.46964 .48388 m .48133 .46668 L p
.51643 .47992 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47674 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56609 .50937 L p
1 g
F P
s
P
p
.55661 .4905 m .56609 .50937 L .56608 .50936 L 1 g
F
P
p
.002 w
.55806 .49246 m .56343 .49012 L .56586 .50702 L p
1 g
F P
s
P
p
.002 w
.56586 .50702 m .56625 .50972 L p
.56609 .50937 L 1 g
F P
s
P
p
.55806 .49246 m .56586 .50702 L .56609 .50937 L 1 g
F
P
p
.002 w
.56609 .50937 m .56515 .50826 L p
.56729 .52217 L 1 g
F P
s
P
p
.56729 .52217 m .56728 .52197 L .56609 .50937 L 1 g
F
P
p
.5673 .5222 m .56718 .5209 L .56609 .50937 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56727 .52186 m .5681 .52252 L .5673 .52226 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56756 .52883 L p
1 g
F P
s
P
p
.002 w
.56754 .52801 m .5681 .52252 L p
.56813 .52701 L 1 g
F P
s
P
p
.56834 .55161 m .56756 .52883 L .56813 .52701 L 1 g
F
P
p
.56756 .52883 m .56754 .52801 L .56813 .52701 L 1 g
F
P
p
.002 w
.5681 .52252 m .57604 .54942 L .56834 .55161 L p
1 g
F P
s
P
p
.002 w
.56756 .52883 m .56654 .52734 L p
.56449 .53859 L 1 g
F P
s
P
p
.002 w
.56504 .55255 m .56011 .55245 L p
.56169 .54744 L 1 g
F P
s
P
p
.002 w
.5674 .52936 m .56624 .54077 L p
.56169 .54744 L 1 g
F P
s
P
p
.002 w
.56624 .54077 m .56504 .55255 L p
.56169 .54744 L 1 g
F P
s
P
p
.002 w
.56169 .54744 m .56075 .54566 L p
.55469 .55665 L 1 g
F P
s
P
p
.002 w
.56504 .55255 m .56012 .57813 L p
.55509 .55618 L 1 g
F P
s
P
p
.002 w
.5583 .55241 m .56504 .55255 L p
.55509 .55618 L 1 g
F P
s
P
p
.55469 .55665 m .5583 .55241 L .56169 .54744 L 1 g
F
P
p
.002 w
.56012 .57813 m .53898 .57782 L .54438 .56877 L p
1 g
F P
s
P
p
.002 w
.54438 .56877 m .5467 .56489 L p
.54921 .56309 L 1 g
F P
s
P
p
.56012 .57813 m .54438 .56877 L .55509 .55618 L 1 g
F
P
p
.002 w
.53898 .57782 m .523 .59827 L p
.5212 .58037 L 1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58053 L p
1 g
F P
s
P
p
.5212 .58037 m .52095 .57786 L .53155 .5751 L 1 g
F
P
p
.53128 .57265 m .51093 .58053 L .52131 .57776 L 1 g
F
P
p
.50007 .58076 m .50648 .58082 L .51093 .58053 L 1 g
F
P
p
.002 w
.50648 .58082 m .52025 .57096 L p
.52095 .57786 L 1 g
F P
s
P
p
.52115 .57985 m .51093 .58053 L .52095 .57786 L 1 g
F
P
p
.51093 .58053 m .50648 .58082 L .52095 .57786 L 1 g
F
P
p
.002 w
.53146 .57506 m .53155 .5751 L p
.52095 .57786 L 1 g
F P
s
P
p
.002 w
.53155 .5751 m .53898 .57782 L p
.5212 .58037 L 1 g
F P
s
P
p
.523 .59827 m .50648 .58082 L .52115 .57985 L 1 g
F
P
p
.54016 .57177 m .53669 .57163 L .54072 .56892 L 1 g
F
P
p
.002 w
.54921 .56309 m .54854 .56129 L p
.54009 .56934 L 1 g
F P
s
P
p
.54009 .56934 m .5467 .56489 L .54921 .56309 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53178 .57494 L p
1 g
F P
s
P
p
.002 w
.53898 .57782 m .53155 .5751 L p
.54016 .57177 L 1 g
F P
s
P
p
.53155 .5751 m .53178 .57494 L .54016 .57177 L 1 g
F
P
p
.54854 .56129 m .53178 .57494 L .54009 .56934 L 1 g
F
P
p
.53128 .57265 m .52131 .57776 L .53146 .57506 L 1 g
F
P
p
.002 w
.53178 .57494 m .53128 .57265 L p
.53146 .57506 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53146 .57506 m .52025 .57096 L p
.53669 .57163 L 1 g
F P
s
P
p
.53178 .57494 m .53669 .57163 L .54016 .57177 L 1 g
F
P
p
.53146 .57506 m .53669 .57163 L .53178 .57494 L 1 g
F
P
p
.002 w
.5467 .56489 m .53898 .57782 L p
.54072 .56892 L 1 g
F P
s
P
p
.53892 .57046 m .5322 .57686 L .54843 .56373 L 1 g
F
P
p
.5467 .56489 m .54843 .56373 L .54921 .56309 L 1 g
F
P
p
.53892 .57046 m .54843 .56373 L .5467 .56489 L 1 g
F
P
p
.002 w
.53178 .57494 m .5322 .57686 L p
.54009 .56934 L 1 g
F P
s
P
p
.002 w
.53155 .5751 m .53146 .57506 L p
.53178 .57494 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54984 .56479 L p
1 g
F P
s
P
p
.56075 .54566 m .54984 .56479 L .55169 .56209 L 1 g
F
P
p
.56449 .53859 m .5674 .52936 L .56756 .52883 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56169 .54744 m .5542 .55232 L .5674 .52936 L 1 g
F
P
p
.002 w
.56011 .55245 m .5583 .55241 L p
.56169 .54744 L 1 g
F P
s
P
p
.002 w
.5583 .55241 m .5542 .55232 L p
.56169 .54744 L 1 g
F P
s
P
p
.002 w
.54984 .56479 m .54998 .56518 L p
.55169 .56209 L 1 g
F P
s
P
p
.002 w
.54468 .54871 m .5542 .55232 L .5467 .56489 L p
1 g
F P
s
P
p
.54072 .56892 m .54468 .54871 L .5467 .56489 L 1 g
F
P
p
.54009 .56934 m .53892 .57046 L .5467 .56489 L 1 g
F
P
p
.002 w
.54998 .56518 m .54924 .56318 L p
.5392 .57119 L 1 g
F P
s
P
p
.002 w
.54924 .56318 m .54921 .56309 L p
.54843 .56373 L 1 g
F P
s
P
p
.54843 .56373 m .5392 .57119 L .54924 .56318 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.52025 .57096 m .54468 .54871 L p
.54072 .56892 L 1 g
F P
s
P
p
.53669 .57163 m .52025 .57096 L .54072 .56892 L 1 g
F
P
p
.002 w
.53179 .57497 m .53178 .57494 L p
.53146 .57506 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53179 .57497 L p
1 g
F P
s
P
p
.52131 .57776 m .51111 .583 L .53179 .57497 L 1 g
F
P
p
.002 w
.51093 .58053 m .51111 .583 L p
.52131 .57776 L 1 g
F P
s
P
p
.002 w
.52025 .57096 m .53146 .57506 L p
.52095 .57786 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54646 .56749 L p
.5392 .57119 L 1 g
F P
s
P
p
.002 w
.54646 .56749 m .54998 .56518 L p
.5392 .57119 L 1 g
F P
s
P
p
.55509 .55618 m .54921 .56309 L .5542 .55232 L 1 g
F
P
p
.002 w
.5467 .56489 m .5542 .55232 L p
.54921 .56309 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56201 .54804 L p
1 g
F P
s
P
p
.002 w
.56201 .54804 m .56169 .54744 L p
.5588 .55181 L 1 g
F P
s
P
p
.5588 .55181 m .54998 .56518 L .56201 .54804 L 1 g
F
P
p
.55469 .55665 m .55169 .56209 L .5583 .55241 L 1 g
F
P
p
.002 w
.5542 .55232 m .5583 .55241 L p
.55509 .55618 L 1 g
F P
s
P
p
.55169 .56209 m .54998 .56518 L .56169 .54744 L 1 g
F
P
p
.56449 .53859 m .56444 .53881 L .5674 .52936 L 1 g
F
P
p
.002 w
.5674 .52402 m .5681 .52252 L .56754 .52801 L p
1 g
F P
s
P
p
.56745 .52539 m .56754 .52801 L .56799 .52946 L 1 g
F
P
p
.002 w
.56756 .52883 m .56757 .52883 L p
.56754 .52801 L 1 g
F P
s
P
p
.002 w
.56757 .52883 m .56799 .52946 L p
.56754 .52801 L 1 g
F P
s
P
p
.56515 .50826 m .56756 .52883 L .56745 .52539 L 1 g
F
P
p
.56515 .50826 m .56745 .52542 L .56732 .5225 L 1 g
F
P
p
.002 w
.5673 .52226 m .5681 .52252 L .56732 .52253 L p
1 g
F P
s
P
p
.5673 .52219 m .56732 .5225 L .56731 .52228 L 1 g
F
P
p
.56515 .50826 m .56732 .5225 L .5673 .52219 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53312 .52278 m .53645 .51219 L .5673 .52226 L p
1 g
F P
s
P
p
.002 w
.56732 .52253 m .53312 .52278 L p
.5673 .52226 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5335 .53313 m .53312 .52278 L .56732 .52253 L p
1 g
F P
s
P
p
.002 w
.56732 .52253 m .5681 .52252 L .56734 .52275 L p
1 g
F P
s
P
p
.56745 .52542 m .56733 .52265 L .56732 .52249 L 1 g
F
P
p
.002 w
.56734 .52275 m .5335 .53313 L p
.56732 .52253 L 1 g
F P
s
P
p
.56745 .52542 m .56737 .52334 L .56733 .52265 L 1 g
F
P
p
.56732 .52249 m .56733 .52265 L .56731 .52228 L 1 g
F
P
p
.002 w
.56734 .52275 m .5681 .52252 L .56735 .523 L p
1 g
F P
s
P
p
.56737 .52334 m .56734 .52255 L .56732 .52242 L 1 g
F
P
p
.56737 .52334 m .56732 .52242 L .56731 .52228 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54468 .54871 m .53751 .54209 L .56735 .523 L p
1 g
F P
s
P
p
.002 w
.56735 .523 m .5681 .52252 L .56737 .52334 L p
1 g
F P
s
P
p
.002 w
.56737 .52334 m .54468 .54871 L p
.56735 .523 L 1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.53751 .54209 m .5335 .53313 L .56734 .52275 L p
1 g
F P
s
P
p
.002 w
.56735 .523 m .53751 .54209 L p
.56734 .52275 L 1 g
F P
s
P
p
.56731 .52227 m .56731 .52228 L .56731 .52228 L 1 g
F
P
p
.56515 .50826 m .56731 .52228 L .56731 .52227 L 1 g
F
P
p
.002 w
.56737 .52334 m .5681 .52252 L .5674 .52402 L p
1 g
F P
s
P
p
.56745 .52542 m .56799 .52946 L .56734 .52255 L 1 g
F
P
p
.002 w
.5542 .55232 m .54468 .54871 L .56737 .52334 L p
1 g
F P
s
P
p
.002 w
.5674 .52402 m .5542 .55232 L p
.56737 .52334 L 1 g
F P
s
P
p
.002 w
.5542 .55232 m .5674 .52402 L p
.5674 .52936 L 1 g
F P
s
P
p
.002 w
.56754 .52801 m .5674 .52936 L p
.5674 .52402 L 1 g
F P
s
P
p
.002 w
.56834 .55161 m .56504 .55255 L .56754 .52801 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56756 .52883 L p
1 g
F P
s
P
p
.56444 .53881 m .56257 .5491 L .56756 .52883 L 1 g
F
P
p
.56222 .50123 m .56609 .50937 L .56234 .50146 L 1 g
F
P
p
.55661 .4905 m .56608 .50936 L .56222 .50123 L 1 g
F
P
p
.56608 .50936 m .56609 .50937 L .56222 .50123 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56625 .50972 m .56586 .50702 L p
.56933 .51622 L 1 g
F P
s
P
p
.002 w
.56586 .50702 m .56343 .49012 L p
.56485 .49642 L 1 g
F P
s
P
p
.56485 .49642 m .56933 .51622 L .56586 .50702 L 1 g
F
P
p
.002 w
.5681 .52252 m .56718 .5209 L p
.56703 .51933 L 1 g
F P
s
P
p
.002 w
.56718 .5209 m .5681 .52252 L .56727 .52186 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55765 .4916 m .55661 .4905 L p
.56222 .50123 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55759 .49154 L p
1 g
F P
s
P
p
.5426 .47699 m .55341 .48748 L .5525 .49488 L 1 g
F
P
p
.002 w
.56343 .49012 m .55839 .49232 L p
.55383 .48407 L 1 g
F P
s
P
p
.002 w
.55839 .49232 m .55806 .49246 L p
.55759 .49154 L 1 g
F P
s
P
p
.55383 .48407 m .55839 .49232 L .55759 .49154 L 1 g
F
P
p
.002 w
.5525 .49488 m .54181 .47649 L p
.5426 .47699 L 1 g
F P
s
P
p
.54174 .47608 m .55759 .49154 L .55045 .48461 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55806 .49246 m .5525 .49488 L p
.55383 .48407 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .55765 .4916 L p
.56003 .49638 L 1 g
F P
s
P
p
.56222 .50123 m .56713 .51061 L .55765 .4916 L 1 g
F
P
p
.002 w
.54234 .47674 m .54174 .47608 L p
.55045 .48461 L 1 g
F P
s
P
p
.5551 .48269 m .56343 .49012 L .54181 .47649 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54234 .47674 L p
1 g
F P
s
P
p
.55045 .48461 m .55834 .49233 L .54234 .47674 L 1 g
F
P
p
.002 w
.55759 .49154 m .55834 .49233 L p
.55045 .48461 L 1 g
F P
s
P
p
.5426 .47699 m .55383 .48407 L .55341 .48748 L 1 g
F
P
p
.002 w
.56713 .51061 m .56557 .50738 L p
.56003 .49638 L 1 g
F P
s
P
p
.002 w
.56557 .50738 m .55834 .49233 L p
.56003 .49638 L 1 g
F P
s
P
p
.002 w
.56625 .50972 m .5681 .52252 L p
.55806 .49246 L 1 g
F P
s
P
p
.002 w
.56933 .51622 m .5681 .52252 L .56625 .50972 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56609 .50937 L p
1 g
F P
s
P
p
.002 w
.56609 .50937 m .56609 .50937 L p
.56609 .50942 L 1 g
F P
s
P
p
.56609 .50942 m .56854 .53025 L .56609 .50937 L 1 g
F
P
p
.002 w
.5525 .49488 m .55806 .49246 L p
.56703 .51933 L 1 g
F P
s
P
p
.002 w
.56718 .5209 m .5525 .49488 L p
.56703 .51933 L 1 g
F P
s
P
p
.002 w
.56799 .52946 m .56854 .53025 L p
.56731 .52228 L 1 g
F P
s
P
p
.002 w
.53645 .51219 m .54316 .50252 L .56727 .52186 L p
1 g
F P
s
P
p
.002 w
.5673 .52226 m .53645 .51219 L p
.56727 .52186 L 1 g
F P
s
P
p
.56729 .52217 m .5673 .5222 L .56728 .52197 L 1 g
F
P
p
.5673 .5222 m .56731 .52228 L .56718 .5209 L 1 g
F
P
p
.002 w
.54316 .50252 m .5525 .49488 L .56718 .5209 L p
1 g
F P
s
P
p
.002 w
.56727 .52186 m .54316 .50252 L p
.56718 .5209 L 1 g
F P
s
P
p
.56731 .52228 m .56854 .53025 L .56609 .50937 L 1 g
F
P
p
.002 w
.56609 .50937 m .56609 .50937 L p
.56608 .50936 L 1 g
F P
s
P
p
.002 w
.56609 .50937 m .56713 .51061 L p
.56234 .50146 L 1 g
F P
s
P
p
.002 w
.56343 .49012 m .57471 .48877 L .56933 .51622 L p
1 g
F P
s
P
p
.002 w
.51643 .47992 m .52838 .47013 L p
.5525 .49488 L 1 g
F P
s
P
p
.002 w
.54181 .47649 m .5525 .49488 L p
.52838 .47013 L 1 g
F P
s
P
p
.52214 .46667 m .54234 .47674 L .53472 .47318 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52838 .47013 m .51643 .47992 L p
.51682 .46636 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46719 L .51061 .46544 L 1 g
F
P
p
.51687 .46442 m .52245 .46719 L .51682 .46636 L 1 g
F
P
p
.52245 .46719 m .52838 .47013 L .51682 .46636 L 1 g
F
P
p
.002 w
.51643 .47992 m .49859 .46411 L p
.50198 .46417 L 1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .4634 L p
.51061 .46544 L 1 g
F P
s
P
p
.50198 .46417 m .51687 .46442 L .51682 .46636 L 1 g
F
P
p
.50198 .46417 m .51682 .46636 L .51643 .47992 L 1 g
F
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.51672 .46108 m .53497 .46472 L .49859 .46411 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.51061 .46544 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.002 w
.52245 .46719 m .52282 .46778 L p
.51061 .46544 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.53934 .47557 L 1 g
F P
s
P
p
.53934 .47557 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.53497 .46472 m .52838 .47013 L p
.51687 .46442 L 1 g
F P
s
P
p
.002 w
.52838 .47013 m .53497 .46472 L .54181 .47649 L p
1 g
F P
s
P
p
.53472 .47318 m .54181 .47649 L .54302 .47747 L 1 g
F
P
p
.002 w
.54234 .47674 m .54235 .47674 L p
.54181 .47649 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.54181 .47649 L 1 g
F P
s
P
p
.002 w
.54181 .47649 m .53497 .46472 L p
.5551 .48269 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46387 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46387 L .49288 .46506 L 1 g
F
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.49859 .46411 m .48891 .45553 L p
.51672 .46108 L 1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .4643 L p
.49288 .46506 L 1 g
F P
s
P
p
.002 w
.5 .4643 m .5 .46442 L p
.49554 .46487 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4643 L .49554 .46487 L 1 g
F
P
p
.002 w
.48891 .45553 m .48268 .4647 L p
.47756 .46716 L 1 g
F P
s
P
p
.45826 .47608 m .47756 .46716 L .46682 .47233 L 1 g
F
P
p
.45857 .47629 m .47063 .46804 L .47756 .46716 L 1 g
F
P
p
.47063 .46804 m .48891 .45553 L .47756 .46716 L 1 g
F
P
p
.002 w
.48133 .46668 m .48891 .45553 L .49859 .46411 L p
1 g
F P
s
P
p
.002 w
.48268 .4647 m .48133 .46668 L p
.47756 .46716 L 1 g
F P
s
P
p
.002 w
.48133 .46668 m .46964 .48388 L p
.47756 .46716 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46716 L p
1 g
F P
s
P
p
.49554 .46487 m .5 .46442 L .47756 .46716 L 1 g
F
P
p
.002 w
.47756 .46716 m .47718 .46778 L p
.46682 .47233 L 1 g
F P
s
P
p
.002 w
.46964 .48388 m .45704 .47734 L p
.45857 .47629 L 1 g
F P
s
P
p
.47663 .45824 m .48891 .45553 L .45857 .47629 L 1 g
F
P
p
.45767 .47673 m .45857 .47629 L .45704 .47734 L 1 g
F
P
p
.47663 .45824 m .45857 .47629 L .45767 .47673 L 1 g
F
P
p
.002 w
.45704 .47734 m .46964 .48388 L p
.44285 .49108 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45767 .47673 L p
1 g
F P
s
P
p
.46682 .47233 m .47718 .46778 L .45767 .47673 L 1 g
F
P
p
.002 w
.45767 .47673 m .45763 .47676 L p
.45724 .47714 L 1 g
F P
s
P
p
.44339 .4905 m .45767 .47673 L .45724 .47714 L 1 g
F
P
p
.44339 .4905 m .45763 .47676 L .4486 .48551 L 1 g
F
P
p
.002 w
.45704 .47734 m .43704 .46697 L p
.47663 .45824 L 1 g
F P
s
P
p
.002 w
.45109 .47426 m .45704 .47734 L p
.44285 .49108 L 1 g
F P
s
P
p
.002 w
.45763 .47676 m .45698 .47747 L p
.4486 .48551 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44285 .49108 L p
1 g
F P
s
P
p
.4486 .48551 m .45698 .47747 L .44285 .49108 L 1 g
F
P
p
.43346 .52734 m .43388 .50942 L .43322 .52053 L 1 g
F
P
p
.43276 .52835 m .43388 .50942 L .46052 .5148 L 1 g
F
P
p
.002 w
.43392 .50873 m .43416 .50879 L p
.43388 .50942 L 1 g
F P
s
P
p
.43777 .50144 m .43416 .50879 L .43388 .50942 L 1 g
F
P
p
.002 w
.43416 .50879 m .46052 .5148 L p
.43388 .50942 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43383 .50948 L p
1 g
F P
s
P
p
.002 w
.43383 .50948 m .43388 .50942 L p
.43415 .50882 L 1 g
F P
s
P
p
.43415 .50882 m .44166 .49233 L .43383 .50948 L 1 g
F
P
p
.43777 .50144 m .44127 .49327 L .43416 .50879 L 1 g
F
P
p
.002 w
.46964 .48388 m .46052 .5148 L .43416 .50879 L p
1 g
F P
s
P
p
.43837 .50021 m .46964 .48388 L .43416 .50879 L 1 g
F
P
p
.44127 .49327 m .44166 .49233 L .43388 .50942 L 1 g
F
P
p
.002 w
.43388 .50942 m .43287 .51061 L p
.43322 .52053 L 1 g
F P
s
P
p
.43564 .5384 m .43276 .52835 L .46052 .5148 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43276 .52835 L p
1 g
F P
s
P
p
.43322 .52053 m .43287 .51061 L .43276 .52835 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43842 .54722 L p
1 g
F P
s
P
p
.45146 .56129 m .43842 .54722 L .4463 .55681 L 1 g
F
P
p
.45088 .56238 m .43842 .54722 L .46237 .54464 L 1 g
F
P
p
.002 w
.43664 .54505 m .43754 .54503 L p
.43842 .54722 L 1 g
F P
s
P
p
.43572 .53868 m .43754 .54503 L .43842 .54722 L 1 g
F
P
p
.002 w
.43754 .54503 m .46237 .54464 L p
.43842 .54722 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43826 .54753 L p
1 g
F P
s
P
p
.002 w
.43826 .54753 m .43842 .54722 L p
.43757 .54515 L 1 g
F P
s
P
p
.43757 .54515 m .43146 .53025 L .43826 .54753 L 1 g
F
P
p
.43572 .53868 m .43201 .53133 L .43754 .54503 L 1 g
F
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.46052 .5148 m .46237 .54464 L .43754 .54503 L p
1 g
F P
s
P
p
.43564 .5384 m .46052 .5148 L .43754 .54503 L 1 g
F
P
p
.43201 .53133 m .43146 .53025 L .43842 .54722 L 1 g
F
P
p
.45088 .56238 m .4417 .55532 L .43842 .54722 L 1 g
F
P
p
.002 w
.43842 .54722 m .43743 .5491 L p
.4463 .55681 L 1 g
F P
s
P
p
.002 w
.42928 .54674 m .4285 .54517 L p
.45229 .56346 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .451 .56253 L p
1 g
F P
s
P
p
.4463 .55681 m .43743 .5491 L .451 .56253 L 1 g
F
P
p
.002 w
.451 .56253 m .45002 .56518 L p
.4603 .56929 L 1 g
F P
s
P
p
.002 w
.46237 .54464 m .47466 .5701 L .46483 .57258 L p
1 g
F P
s
P
p
.45229 .56346 m .46237 .54464 L .46483 .57258 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4682 .57503 L p
1 g
F P
s
P
p
.002 w
.4682 .57503 m .46832 .5745 L p
.46549 .57306 L 1 g
F P
s
P
p
.46549 .57306 m .45002 .56518 L .4682 .57503 L 1 g
F
P
p
.45503 .56718 m .45002 .56518 L .46832 .5745 L 1 g
F
P
p
.47411 .57629 m .46832 .5745 L .47466 .5701 L 1 g
F
P
p
.002 w
.46483 .57258 m .47466 .5701 L p
.46832 .5745 L 1 g
F P
s
P
p
.002 w
.46832 .5745 m .4678 .57686 L p
.47892 .57778 L 1 g
F P
s
P
p
.48587 .57992 m .4678 .57686 L .48904 .5809 L 1 g
F
P
p
.47892 .57778 m .47537 .57748 L .48587 .57992 L 1 g
F
P
p
.47537 .57748 m .4678 .57686 L .48587 .57992 L 1 g
F
P
p
.48906 .58066 m .47466 .5701 L .49834 .58075 L 1 g
F
P
p
.002 w
.48587 .57992 m .47466 .5701 L p
.48906 .58066 L 1 g
F P
s
P
p
.002 w
.48904 .5809 m .48906 .58066 L p
.48587 .57992 L 1 g
F P
s
P
p
.002 w
.47466 .5701 m .50597 .55813 L p
.49834 .58075 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51096 .58086 L p
.49568 .58164 L 1 g
F P
s
P
p
.002 w
.51096 .58086 m .51093 .58053 L p
.50684 .58083 L 1 g
F P
s
P
p
.50684 .58083 m .49568 .58164 L .51096 .58086 L 1 g
F
P
p
.50007 .58076 m .49646 .58149 L .50648 .58082 L 1 g
F
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.50597 .55813 m .52025 .57096 L .50648 .58082 L p
1 g
F P
s
P
p
.49834 .58075 m .50597 .55813 L .50648 .58082 L 1 g
F
P
p
.49646 .58149 m .49568 .58164 L .51093 .58053 L 1 g
F
P
p
.002 w
.48889 .583 m .5079 .583 L p
.49568 .58164 L 1 g
F P
s
P
p
.002 w
.5079 .583 m .51111 .583 L p
.49568 .58164 L 1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51114 .58336 L p
1 g
F P
s
P
p
.002 w
.51114 .58336 m .51111 .583 L p
.50995 .58322 L 1 g
F P
s
P
p
.50995 .58322 m .48857 .5874 L .51114 .58336 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .5809 L p
1 g
F P
s
P
p
.002 w
.47466 .5701 m .48587 .57992 L p
.47411 .57629 L 1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5232 .46186 L
s
P
p
.004 w
.54549 .49197 m
.54947 .49736 L
s
P
p
.002 w
.49129 .27073 m .4285 .29646 L .41669 .28013 L p
1 g
F P
s
P
p
.002 w
.4285 .54517 m .44469 .57765 L .41708 .58068 L p
1 g
F P
s
P
p
.002 w
.41708 .58068 m .3974 .54224 L .4285 .54517 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.65442 .49106 m .64945 .46297 L .66762 .44114 L p
1 g
F P
s
P
p
.002 w
.64881 .41066 m .66762 .44114 L .64945 .46297 L p
1 g
F P
s
P
p
.002 w
.66762 .44114 m .64881 .41066 L .65837 .38316 L p
1 g
F P
s
P
p
.002 w
.39353 .49667 m .3974 .54224 L .37009 .53607 L p
1 g
F P
s
P
p
.002 w
.37009 .53607 m .36524 .48468 L .39353 .49667 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.62646 .52402 m .62992 .50361 L .65442 .49106 L p
1 g
F P
s
P
p
.002 w
.64945 .46297 m .65442 .49106 L .62992 .50361 L p
1 g
F P
s
P
p
.002 w
.62288 .35734 m .65837 .38316 L .64881 .41066 L p
1 g
F P
s
P
p
.002 w
.65837 .38316 m .62288 .35734 L .62324 .32827 L p
1 g
F P
s
P
p
.002 w
.39199 .35943 m .3569 .41311 L .33905 .39636 L p
1 g
F P
s
P
p
.002 w
.33905 .39636 m .37546 .34026 L .39199 .35943 L p
1 g
F P
s
P
p
.002 w
.57604 .54942 m .58606 .54326 L .6009 .56001 L p
1 g
F P
s
P
p
.002 w
.6009 .56001 m .58148 .57197 L .57604 .54942 L p
1 g
F P
s
P
p
.002 w
.61643 .54348 m .6009 .56001 L .58606 .54326 L p
1 g
F P
s
P
p
.002 w
.37966 .43089 m .36524 .48468 L .34169 .47139 L p
1 g
F P
s
P
p
.002 w
.34169 .47139 m .3569 .41311 L .37966 .43089 L p
1 g
F P
s
P
p
.002 w
.56504 .55255 m .57604 .54942 L .58148 .57197 L p
1 g
F P
s
P
p
.002 w
.58148 .57197 m .56012 .57813 L .56504 .55255 L p
1 g
F P
s
P
p
.002 w
.58606 .54326 m .59404 .53473 L .61643 .54348 L p
1 g
F P
s
P
p
.002 w
.62646 .52402 m .61643 .54348 L .59404 .53473 L p
1 g
F P
s
P
p
.002 w
.57202 .31465 m .62324 .32827 L .62288 .35734 L p
1 g
F P
s
P
p
.002 w
.62324 .32827 m .57202 .31465 L .56465 .28786 L p
1 g
F P
s
P
p
.002 w
.56465 .28786 m .50307 .29262 L .49129 .27073 L p
1 g
F P
s
P
p
.002 w
.4285 .29646 m .49129 .27073 L .50307 .29262 L p
1 g
F P
s
P
p
.002 w
.62992 .50361 m .62646 .52402 L .59915 .52471 L p
1 g
F P
s
P
p
.002 w
.59404 .53473 m .59915 .52471 L .62646 .52402 L p
1 g
F P
s
P
p
.002 w
.50307 .29262 m .56465 .28786 L .57202 .31465 L p
1 g
F P
s
P
p
.002 w
.4429 .31743 m .39199 .35943 L .37546 .34026 L p
1 g
F P
s
P
p
.002 w
.37546 .34026 m .4285 .29646 L .4429 .31743 L p
1 g
F P
s
P
p
.002 w
.62992 .50361 m .6263 .48435 L .64945 .46297 L p
1 g
F P
s
P
p
.002 w
.63451 .43939 m .64945 .46297 L .6263 .48435 L p
1 g
F P
s
P
p
.002 w
.64945 .46297 m .63451 .43939 L .64881 .41066 L p
1 g
F P
s
P
p
.002 w
.50307 .29262 m .4429 .31743 L .4285 .29646 L p
1 g
F P
s
P
p
.002 w
.42566 .50685 m .4285 .54517 L .3974 .54224 L p
1 g
F P
s
P
p
.002 w
.3974 .54224 m .39353 .49667 L .42566 .50685 L p
1 g
F P
s
P
p
.002 w
.61875 .3893 m .64881 .41066 L .63451 .43939 L p
1 g
F P
s
P
p
.002 w
.64881 .41066 m .61875 .3893 L .62288 .35734 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59915 .52471 m .60084 .51425 L .62992 .50361 L p
1 g
F P
s
P
p
.002 w
.6263 .48435 m .62992 .50361 L .60084 .51425 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40668 .44907 m .39353 .49667 L .36524 .48468 L p
1 g
F P
s
P
p
.002 w
.36524 .48468 m .37966 .43089 L .40668 .44907 L p
1 g
F P
s
P
p
.002 w
.41233 .38134 m .37966 .43089 L .3569 .41311 L p
1 g
F P
s
P
p
.002 w
.3569 .41311 m .39199 .35943 L .41233 .38134 L p
1 g
F P
s
P
p
.002 w
.57737 .34567 m .62288 .35734 L .61875 .3893 L p
1 g
F P
s
P
p
.002 w
.62288 .35734 m .57737 .34567 L .57202 .31465 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.53751 .54209 m .54468 .54871 L .52025 .57096 L p
1 g
F P
s
P
p
.002 w
.52025 .57096 m .50597 .55813 L .53751 .54209 L p
1 g
F P
s
P
p
.002 w
.49781 .54059 m .50597 .55813 L .47466 .5701 L p
1 g
F P
s
P
p
.002 w
.47466 .5701 m .46237 .54464 L .49781 .54059 L p
1 g
F P
s
P
p
.002 w
.58606 .54326 m .57604 .54942 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.59404 .53473 m .58606 .54326 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59915 .52471 m .59404 .53473 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57202 .31465 m .51509 .31938 L .50307 .29262 L p
1 g
F P
s
P
p
.002 w
.4429 .31743 m .50307 .29262 L .51509 .31938 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60084 .51425 m .59888 .50445 L .6263 .48435 L p
1 g
F P
s
P
p
.002 w
.61586 .46832 m .6263 .48435 L .59888 .50445 L p
1 g
F P
s
P
p
.002 w
.6263 .48435 m .61586 .46832 L .63451 .43939 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60084 .51425 m .59915 .52471 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.51509 .31938 m .57202 .31465 L .57737 .34567 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.6109 .42305 m .63451 .43939 L .61586 .46832 L p
1 g
F P
s
P
p
.002 w
.63451 .43939 m .6109 .42305 L .61875 .3893 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59888 .50445 m .60084 .51425 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.45947 .3425 m .41233 .38134 L .39199 .35943 L p
1 g
F P
s
P
p
.002 w
.39199 .35943 m .4429 .31743 L .45947 .3425 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5335 .53313 m .53751 .54209 L .50597 .55813 L p
1 g
F P
s
P
p
.002 w
.50597 .55813 m .49781 .54059 L .5335 .53313 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51509 .31938 m .45947 .3425 L .4429 .31743 L p
1 g
F P
s
P
p
.002 w
.58042 .37988 m .61875 .3893 L .6109 .42305 L p
1 g
F P
s
P
p
.002 w
.61875 .3893 m .58042 .37988 L .57737 .34567 L p
1 g
F P
s
P
p
.002 w
.43704 .46697 m .42566 .50685 L .39353 .49667 L p
1 g
F P
s
P
p
.002 w
.39353 .49667 m .40668 .44907 L .43704 .46697 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59345 .49639 m .59888 .50445 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.59888 .50445 m .59345 .49639 L .61586 .46832 L p
1 g
F P
s
P
p
.002 w
.59955 .45737 m .61586 .46832 L .59345 .49639 L p
1 g
F P
s
P
p
.002 w
.61586 .46832 m .59955 .45737 L .6109 .42305 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.43584 .40527 m .40668 .44907 L .37966 .43089 L p
1 g
F P
s
P
p
.002 w
.37966 .43089 m .41233 .38134 L .43584 .40527 L p
1 g
F P
s
P
p
.002 w
.4968 .52018 m .49781 .54059 L .46237 .54464 L p
1 g
F P
s
P
p
.002 w
.46237 .54464 m .46052 .5148 L .4968 .52018 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.5851 .49095 m .59345 .49639 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.57471 .48877 m .5851 .49095 L .5681 .52252 L closepath p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52692 .35019 m .57737 .34567 L .58042 .37988 L p
1 g
F P
s
P
p
.002 w
.57737 .34567 m .52692 .35019 L .51509 .31938 L p
1 g
F P
s
P
p
.002 w
.59345 .49639 m .5851 .49095 L .59955 .45737 L p
1 g
F P
s
P
p
.002 w
.45947 .3425 m .51509 .31938 L .52692 .35019 L p
1 g
F P
s
P
p
.002 w
.58101 .41606 m .6109 .42305 L .59955 .45737 L p
1 g
F P
s
P
p
.002 w
.6109 .42305 m .58101 .41606 L .58042 .37988 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.53312 .52278 m .5335 .53313 L .49781 .54059 L p
1 g
F P
s
P
p
.002 w
.49781 .54059 m .4968 .52018 L .53312 .52278 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5851 .49095 m .57471 .48877 L .57908 .45283 L p
1 g
F P
s
P
p
.002 w
.57908 .45283 m .59955 .45737 L .5851 .49095 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.59955 .45737 m .57908 .45283 L .58101 .41606 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.47766 .37085 m .43584 .40527 L .41233 .38134 L p
1 g
F P
s
P
p
.002 w
.41233 .38134 m .45947 .3425 L .47766 .37085 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53645 .51219 m .53312 .52278 L .4968 .52018 L p
1 g
F P
s
P
p
.002 w
.52692 .35019 m .47766 .37085 L .45947 .3425 L p
1 g
F P
s
P
p
.002 w
.46169 .43032 m .43704 .46697 L .40668 .44907 L p
1 g
F P
s
P
p
.002 w
.40668 .44907 m .43584 .40527 L .46169 .43032 L p
1 g
F P
s
P
p
.002 w
.53809 .38399 m .58042 .37988 L .58101 .41606 L p
1 g
F P
s
P
p
.002 w
.58042 .37988 m .53809 .38399 L .52692 .35019 L p
1 g
F P
s
P
p
.002 w
.57471 .48877 m .56343 .49012 L .5567 .45535 L p
1 g
F P
s
P
p
.002 w
.5567 .45535 m .57908 .45283 L .57471 .48877 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50321 .49915 m .4968 .52018 L .46052 .5148 L p
1 g
F P
s
P
p
.002 w
.46052 .5148 m .46964 .48388 L .50321 .49915 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.4968 .52018 m .50321 .49915 L .53645 .51219 L p
1 g
F P
s
P
p
.002 w
.54316 .50252 m .53645 .51219 L .50321 .49915 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53497 .46472 m .5567 .45535 L .56343 .49012 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.47766 .37085 m .52692 .35019 L .53809 .38399 L p
1 g
F P
s
P
p
.002 w
.5525 .49488 m .54316 .50252 L .51643 .47992 L p
1 g
F P
s
P
p
.002 w
.50321 .49915 m .51643 .47992 L .54316 .50252 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54815 .4195 m .58101 .41606 L .57908 .45283 L p
1 g
F P
s
P
p
.002 w
.58101 .41606 m .54815 .4195 L .53809 .38399 L p
1 g
F P
s
P
p
.002 w
.57908 .45283 m .5567 .45535 L .54815 .4195 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.43704 .46697 m .46169 .43032 L .48891 .45553 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49681 .40147 m .46169 .43032 L .43584 .40527 L p
1 g
F P
s
P
p
.002 w
.43584 .40527 m .47766 .37085 L .49681 .40147 L p
1 g
F P
s
P
p
.002 w
.51643 .47992 m .50321 .49915 L .46964 .48388 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.53809 .38399 m .49681 .40147 L .47766 .37085 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.5567 .45535 m .53497 .46472 L .51617 .43317 L p
1 g
F P
s
P
p
.002 w
.51617 .43317 m .54815 .4195 L .5567 .45535 L p
1 g
F P
s
P
p
.002 w
.49681 .40147 m .53809 .38399 L .54815 .4195 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54815 .4195 m .51617 .43317 L .49681 .40147 L p
1 g
F P
s
P
p
.002 w
.48891 .45553 m .51617 .43317 L .53497 .46472 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51617 .43317 m .48891 .45553 L .46169 .43032 L p
1 g
F P
s
P
p
.002 w
.46169 .43032 m .49681 .40147 L .51617 .43317 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59079 .55318 m
.60905 .57786 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .72508 .62558 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60905 .57786 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.444961)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.444961)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48201 .46544 m .5209 .44976 L .50701 .42484 L p
1 g
F P
s
P
p
.002 w
.50701 .42484 m .47458 .43788 L .48201 .46544 L p
1 g
F P
s
P
p
.002 w
.5348 .40403 m .50701 .42484 L .5209 .44976 L p
1 g
F P
s
P
p
.002 w
.47458 .43788 m .50701 .42484 L .49295 .40006 L p
1 g
F P
s
P
p
.002 w
.50701 .42484 m .5348 .40403 L .51446 .38385 L p
1 g
F P
s
P
p
.002 w
.51446 .38385 m .49295 .40006 L .50701 .42484 L p
1 g
F P
s
P
p
.002 w
.44119 .47045 m .48201 .46544 L .47458 .43788 L p
1 g
F P
s
P
p
.002 w
.47458 .43788 m .44056 .44189 L .44119 .47045 L p
1 g
F P
s
P
p
.002 w
.44056 .44189 m .47458 .43788 L .46776 .41015 L p
1 g
F P
s
P
p
.002 w
.49295 .40006 m .46776 .41015 L .47458 .43788 L p
1 g
F P
s
P
p
.002 w
.48992 .49233 m .53436 .47436 L .5209 .44976 L p
1 g
F P
s
P
p
.002 w
.5209 .44976 m .48201 .46544 L .48992 .49233 L p
1 g
F P
s
P
p
.002 w
.55431 .42489 m .5209 .44976 L .53436 .47436 L p
1 g
F P
s
P
p
.002 w
.5209 .44976 m .55431 .42489 L .5348 .40403 L p
1 g
F P
s
P
p
.002 w
.46776 .41015 m .49295 .40006 L .47896 .37584 L p
1 g
F P
s
P
p
.002 w
.49295 .40006 m .51446 .38385 L .49367 .36469 L p
1 g
F P
s
P
p
.002 w
.49367 .36469 m .47896 .37584 L .49295 .40006 L p
1 g
F P
s
P
p
.002 w
.46776 .41015 m .44137 .41313 L .44056 .44189 L p
1 g
F P
s
P
p
.002 w
.44137 .41313 m .46776 .41015 L .46169 .38275 L p
1 g
F P
s
P
p
.002 w
.47896 .37584 m .46169 .38275 L .46776 .41015 L p
1 g
F P
s
P
p
.002 w
.44327 .49828 m .48992 .49233 L .48201 .46544 L p
1 g
F P
s
P
p
.002 w
.48201 .46544 m .44119 .47045 L .44327 .49828 L p
1 g
F P
s
P
p
.002 w
.55524 .37735 m .5348 .40403 L .55431 .42489 L p
1 g
F P
s
P
p
.002 w
.5348 .40403 m .55524 .37735 L .53016 .36306 L p
1 g
F P
s
P
p
.002 w
.53016 .36306 m .51446 .38385 L .5348 .40403 L p
1 g
F P
s
P
p
.002 w
.51446 .38385 m .53016 .36306 L .50431 .35041 L p
1 g
F P
s
P
p
.002 w
.50431 .35041 m .49367 .36469 L .51446 .38385 L p
1 g
F P
s
P
p
.002 w
.57908 .39301 m .55431 .42489 L .57265 .44603 L p
1 g
F P
s
P
p
.002 w
.53436 .47436 m .57265 .44603 L .55431 .42489 L p
1 g
F P
s
P
p
.002 w
.55431 .42489 m .57908 .39301 L .55524 .37735 L p
1 g
F P
s
P
p
.002 w
.49818 .51804 m .54716 .49819 L .53436 .47436 L p
1 g
F P
s
P
p
.002 w
.53436 .47436 m .48992 .49233 L .49818 .51804 L p
1 g
F P
s
P
p
.002 w
.57265 .44603 m .53436 .47436 L .54716 .49819 L p
1 g
F P
s
P
p
.002 w
.46169 .38275 m .47896 .37584 L .46531 .35266 L p
1 g
F P
s
P
p
.002 w
.47896 .37584 m .49367 .36469 L .4728 .34694 L p
1 g
F P
s
P
p
.002 w
.4728 .34694 m .46531 .35266 L .47896 .37584 L p
1 g
F P
s
P
p
.002 w
.40226 .46409 m .44119 .47045 L .44056 .44189 L p
1 g
F P
s
P
p
.002 w
.44056 .44189 m .4082 .43632 L .40226 .46409 L p
1 g
F P
s
P
p
.002 w
.4082 .43632 m .44056 .44189 L .44137 .41313 L p
1 g
F P
s
P
p
.002 w
.44137 .41313 m .41636 .4086 L .4082 .43632 L p
1 g
F P
s
P
p
.002 w
.41636 .4086 m .44137 .41313 L .44361 .3847 L p
1 g
F P
s
P
p
.002 w
.46169 .38275 m .44361 .3847 L .44137 .41313 L p
1 g
F P
s
P
p
.002 w
.44361 .3847 m .46169 .38275 L .45648 .35618 L p
1 g
F P
s
P
p
.002 w
.46531 .35266 m .45648 .35618 L .46169 .38275 L p
1 g
F P
s
P
p
.002 w
.44679 .52484 m .49818 .51804 L .48992 .49233 L p
1 g
F P
s
P
p
.002 w
.48992 .49233 m .44327 .49828 L .44679 .52484 L p
1 g
F P
s
P
p
.002 w
.49367 .36469 m .50431 .35041 L .47818 .33962 L p
1 g
F P
s
P
p
.002 w
.47818 .33962 m .4728 .34694 L .49367 .36469 L p
1 g
F P
s
P
p
.002 w
.39866 .49137 m .44327 .49828 L .44119 .47045 L p
1 g
F P
s
P
p
.002 w
.44119 .47045 m .40226 .46409 L .39866 .49137 L p
1 g
F P
s
P
p
.002 w
.44361 .3847 m .42655 .38145 L .41636 .4086 L p
1 g
F P
s
P
p
.002 w
.42655 .38145 m .44361 .3847 L .44725 .35713 L p
1 g
F P
s
P
p
.002 w
.45648 .35618 m .44725 .35713 L .44361 .3847 L p
1 g
F P
s
P
p
.002 w
.53836 .33971 m .53016 .36306 L .55524 .37735 L p
1 g
F P
s
P
p
.002 w
.53016 .36306 m .53836 .33971 L .50974 .33441 L p
1 g
F P
s
P
p
.002 w
.50974 .33441 m .50431 .35041 L .53016 .36306 L p
1 g
F P
s
P
p
.002 w
.54716 .49819 m .58945 .46707 L .57265 .44603 L p
1 g
F P
s
P
p
.002 w
.60122 .40975 m .57265 .44603 L .58945 .46707 L p
1 g
F P
s
P
p
.002 w
.57265 .44603 m .60122 .40975 L .57908 .39301 L p
1 g
F P
s
P
p
.002 w
.56615 .34728 m .55524 .37735 L .57908 .39301 L p
1 g
F P
s
P
p
.002 w
.55524 .37735 m .56615 .34728 L .53836 .33971 L p
1 g
F P
s
P
p
.002 w
.50431 .35041 m .50974 .33441 L .48085 .33147 L p
1 g
F P
s
P
p
.002 w
.48085 .33147 m .47818 .33962 L .50431 .35041 L p
1 g
F P
s
P
p
.002 w
.50664 .54207 m .55902 .52078 L .54716 .49819 L p
1 g
F P
s
P
p
.002 w
.54716 .49819 m .49818 .51804 L .50664 .54207 L p
1 g
F P
s
P
p
.002 w
.58945 .46707 m .54716 .49819 L .55902 .52078 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .45648 .35618 L .46531 .35266 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .46531 .35266 L .4728 .34694 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .44725 .35713 L .45648 .35618 L closepath p
1 g
F P
s
P
p
.002 w
.38079 .42144 m .4082 .43632 L .41636 .4086 L p
1 g
F P
s
P
p
.002 w
.41636 .4086 m .3953 .39684 L .38079 .42144 L p
1 g
F P
s
P
p
.002 w
.3953 .39684 m .41636 .4086 L .42655 .38145 L p
1 g
F P
s
P
p
.002 w
.59258 .35699 m .57908 .39301 L .60122 .40975 L p
1 g
F P
s
P
p
.002 w
.57908 .39301 m .59258 .35699 L .56615 .34728 L p
1 g
F P
s
P
p
.002 w
.4517 .54957 m .50664 .54207 L .49818 .51804 L p
1 g
F P
s
P
p
.002 w
.49818 .51804 m .44679 .52484 L .4517 .54957 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .4728 .34694 L .47818 .33962 L closepath p
1 g
F P
s
P
p
.002 w
.42655 .38145 m .41229 .37327 L .3953 .39684 L p
1 g
F P
s
P
p
.002 w
.41229 .37327 m .42655 .38145 L .43858 .3554 L p
1 g
F P
s
P
p
.002 w
.44725 .35713 m .43858 .3554 L .42655 .38145 L p
1 g
F P
s
P
p
.002 w
.39755 .51761 m .44679 .52484 L .44327 .49828 L p
1 g
F P
s
P
p
.002 w
.44327 .49828 m .39866 .49137 L .39755 .51761 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .43858 .3554 L .44725 .35713 L closepath p
1 g
F P
s
P
p
.002 w
.36907 .44657 m .40226 .46409 L .4082 .43632 L p
1 g
F P
s
P
p
.002 w
.4082 .43632 m .38079 .42144 L .36907 .44657 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .47818 .33962 L .48085 .33147 L closepath p
1 g
F P
s
P
p
.002 w
.5093 .31835 m .50974 .33441 L .53836 .33971 L p
1 g
F P
s
P
p
.002 w
.50974 .33441 m .5093 .31835 L .48052 .32333 L p
1 g
F P
s
P
p
.002 w
.48052 .32333 m .48085 .33147 L .50974 .33441 L p
1 g
F P
s
P
p
.002 w
.55902 .52078 m .60435 .48761 L .58945 .46707 L p
1 g
F P
s
P
p
.002 w
.6212 .42728 m .58945 .46707 L .60435 .48761 L p
1 g
F P
s
P
p
.002 w
.58945 .46707 m .6212 .42728 L .60122 .40975 L p
1 g
F P
s
P
p
.002 w
.43858 .3554 m .4314 .35116 L .41229 .37327 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .4314 .35116 L .43858 .3554 L closepath p
1 g
F P
s
P
p
.002 w
.53802 .31613 m .53836 .33971 L .56615 .34728 L p
1 g
F P
s
P
p
.002 w
.53836 .33971 m .53802 .31613 L .5093 .31835 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .48085 .33147 L .48052 .32333 L closepath p
1 g
F P
s
P
p
.002 w
.61708 .36868 m .60122 .40975 L .6212 .42728 L p
1 g
F P
s
P
p
.002 w
.60122 .40975 m .61708 .36868 L .59258 .35699 L p
1 g
F P
s
P
p
.002 w
.36046 .47175 m .39866 .49137 L .40226 .46409 L p
1 g
F P
s
P
p
.002 w
.40226 .46409 m .36907 .44657 L .36046 .47175 L p
1 g
F P
s
P
p
.002 w
.38053 .37888 m .3953 .39684 L .41229 .37327 L p
1 g
F P
s
P
p
.002 w
.41229 .37327 m .40241 .3609 L .38053 .37888 L p
1 g
F P
s
P
p
.002 w
.40241 .3609 m .41229 .37327 L .4314 .35116 L p
1 g
F P
s
P
p
.002 w
.4314 .35116 m .42649 .34483 L .40241 .3609 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .42649 .34483 L .4314 .35116 L closepath p
1 g
F P
s
P
p
.002 w
.56611 .31675 m .56615 .34728 L .59258 .35699 L p
1 g
F P
s
P
p
.002 w
.56615 .34728 m .56611 .31675 L .53802 .31613 L p
1 g
F P
s
P
p
.002 w
.51514 .56388 m .56969 .54166 L .55902 .52078 L p
1 g
F P
s
P
p
.002 w
.55902 .52078 m .50664 .54207 L .51514 .56388 L p
1 g
F P
s
P
p
.002 w
.60435 .48761 m .55902 .52078 L .56969 .54166 L p
1 g
F P
s
P
p
.002 w
.39901 .54224 m .4517 .54957 L .44679 .52484 L p
1 g
F P
s
P
p
.002 w
.44679 .52484 m .39755 .51761 L .39901 .54224 L p
1 g
F P
s
P
p
.002 w
.47718 .31609 m .48052 .32333 L .5093 .31835 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .48052 .32333 L .47718 .31609 L closepath p
1 g
F P
s
P
p
.002 w
.36134 .39843 m .38079 .42144 L .3953 .39684 L p
1 g
F P
s
P
p
.002 w
.3953 .39684 m .38053 .37888 L .36134 .39843 L p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .43603 .3139 L .42942 .3207 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .42942 .3207 L .42541 .32872 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .42541 .32872 L .4244 .33707 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .4244 .33707 L .42649 .34483 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .47718 .31609 L .47116 .31055 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .47116 .31055 L .46309 .30733 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .46309 .30733 L .45386 .30683 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .45386 .30683 L .44449 .3091 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .33095 m .44449 .3091 L .43603 .3139 L closepath p
1 g
F P
s
P
p
.002 w
.45796 .57192 m .51514 .56388 L .50664 .54207 L p
1 g
F P
s
P
p
.002 w
.50664 .54207 m .4517 .54957 L .45796 .57192 L p
1 g
F P
s
P
p
.002 w
.50289 .30395 m .5093 .31835 L .53802 .31613 L p
1 g
F P
s
P
p
.002 w
.5093 .31835 m .50289 .30395 L .47718 .31609 L p
1 g
F P
s
P
p
.002 w
.39807 .34561 m .40241 .3609 L .42649 .34483 L p
1 g
F P
s
P
p
.002 w
.42649 .34483 m .4244 .33707 L .39807 .34561 L p
1 g
F P
s
P
p
.002 w
.47116 .31055 m .47718 .31609 L .50289 .30395 L p
1 g
F P
s
P
p
.002 w
.35523 .49642 m .39755 .51761 L .39866 .49137 L p
1 g
F P
s
P
p
.002 w
.39866 .49137 m .36046 .47175 L .35523 .49642 L p
1 g
F P
s
P
p
.002 w
.59299 .32025 m .59258 .35699 L .61708 .36868 L p
1 g
F P
s
P
p
.002 w
.59258 .35699 m .59299 .32025 L .56611 .31675 L p
1 g
F P
s
P
p
.002 w
.56969 .54166 m .61699 .50723 L .60435 .48761 L p
1 g
F P
s
P
p
.002 w
.63855 .44527 m .60435 .48761 L .61699 .50723 L p
1 g
F P
s
P
p
.002 w
.60435 .48761 m .63855 .44527 L .6212 .42728 L p
1 g
F P
s
P
p
.002 w
.34531 .41918 m .36907 .44657 L .38079 .42144 L p
1 g
F P
s
P
p
.002 w
.38079 .42144 m .36134 .39843 L .34531 .41918 L p
1 g
F P
s
P
p
.002 w
.37386 .35645 m .38053 .37888 L .40241 .3609 L p
1 g
F P
s
P
p
.002 w
.40241 .3609 m .39807 .34561 L .37386 .35645 L p
1 g
F P
s
P
p
.002 w
.39989 .32902 m .39807 .34561 L .4244 .33707 L p
1 g
F P
s
P
p
.002 w
.4244 .33707 m .42541 .32872 L .39989 .32902 L p
1 g
F P
s
P
p
.002 w
.5289 .29482 m .53802 .31613 L .56611 .31675 L p
1 g
F P
s
P
p
.002 w
.53802 .31613 m .5289 .29482 L .50289 .30395 L p
1 g
F P
s
P
p
.002 w
.6391 .38218 m .6212 .42728 L .63855 .44527 L p
1 g
F P
s
P
p
.002 w
.6212 .42728 m .6391 .38218 L .61708 .36868 L p
1 g
F P
s
P
p
.002 w
.50289 .30395 m .4911 .29282 L .47116 .31055 L p
1 g
F P
s
P
p
.002 w
.46309 .30733 m .47116 .31055 L .4911 .29282 L p
1 g
F P
s
P
p
.002 w
.40779 .31297 m .39989 .32902 L .42541 .32872 L p
1 g
F P
s
P
p
.002 w
.42541 .32872 m .42942 .3207 L .40779 .31297 L p
1 g
F P
s
P
p
.002 w
.4911 .29282 m .50289 .30395 L .5289 .29482 L p
1 g
F P
s
P
p
.002 w
.40311 .56465 m .45796 .57192 L .4517 .54957 L p
1 g
F P
s
P
p
.002 w
.4517 .54957 m .39901 .54224 L .40311 .56465 L p
1 g
F P
s
P
p
.002 w
.4911 .29282 m .47511 .28628 L .46309 .30733 L p
1 g
F P
s
P
p
.002 w
.45386 .30683 m .46309 .30733 L .47511 .28628 L p
1 g
F P
s
P
p
.002 w
.35233 .36943 m .36134 .39843 L .38053 .37888 L p
1 g
F P
s
P
p
.002 w
.38053 .37888 m .37386 .35645 L .35233 .36943 L p
1 g
F P
s
P
p
.002 w
.42095 .29932 m .40779 .31297 L .42942 .3207 L p
1 g
F P
s
P
p
.002 w
.42942 .3207 m .43603 .3139 L .42095 .29932 L p
1 g
F P
s
P
p
.002 w
.5235 .58294 m .5789 .56032 L .56969 .54166 L p
1 g
F P
s
P
p
.002 w
.56969 .54166 m .51514 .56388 L .5235 .58294 L p
1 g
F P
s
P
p
.002 w
.61699 .50723 m .56969 .54166 L .5789 .56032 L p
1 g
F P
s
P
p
.002 w
.55465 .28897 m .56611 .31675 L .59299 .32025 L p
1 g
F P
s
P
p
.002 w
.56611 .31675 m .55465 .28897 L .5289 .29482 L p
1 g
F P
s
P
p
.002 w
.3329 .44071 m .36046 .47175 L .36907 .44657 L p
1 g
F P
s
P
p
.002 w
.36907 .44657 m .34531 .41918 L .3329 .44071 L p
1 g
F P
s
P
p
.002 w
.47511 .28628 m .45668 .28517 L .45386 .30683 L p
1 g
F P
s
P
p
.002 w
.44449 .3091 m .45386 .30683 L .45668 .28517 L p
1 g
F P
s
P
p
.002 w
.61804 .32664 m .61708 .36868 L .6391 .38218 L p
1 g
F P
s
P
p
.002 w
.61708 .36868 m .61804 .32664 L .59299 .32025 L p
1 g
F P
s
P
p
.002 w
.3763 .33191 m .37386 .35645 L .39807 .34561 L p
1 g
F P
s
P
p
.002 w
.39807 .34561 m .39989 .32902 L .3763 .33191 L p
1 g
F P
s
P
p
.002 w
.4379 .28968 m .42095 .29932 L .43603 .3139 L p
1 g
F P
s
P
p
.002 w
.43603 .3139 m .44449 .3091 L .4379 .28968 L p
1 g
F P
s
P
p
.002 w
.45668 .28517 m .4379 .28968 L .44449 .3091 L p
1 g
F P
s
P
p
.002 w
.46549 .5913 m .5235 .58294 L .51514 .56388 L p
1 g
F P
s
P
p
.002 w
.51514 .56388 m .45796 .57192 L .46549 .5913 L p
1 g
F P
s
P
p
.002 w
.35362 .52003 m .39901 .54224 L .39755 .51761 L p
1 g
F P
s
P
p
.002 w
.39755 .51761 m .35523 .49642 L .35362 .52003 L p
1 g
F P
s
P
p
.002 w
.5289 .29482 m .5117 .27821 L .4911 .29282 L p
1 g
F P
s
P
p
.002 w
.47511 .28628 m .4911 .29282 L .5117 .27821 L p
1 g
F P
s
P
p
.002 w
.5117 .27821 m .5289 .29482 L .55465 .28897 L p
1 g
F P
s
P
p
.002 w
.61699 .50723 m .65282 .46334 L .63855 .44527 L p
1 g
F P
s
P
p
.002 w
.65808 .39724 m .63855 .44527 L .65282 .46334 L p
1 g
F P
s
P
p
.002 w
.63855 .44527 m .65808 .39724 L .6391 .38218 L p
1 g
F P
s
P
p
.002 w
.5789 .56032 m .62701 .52546 L .61699 .50723 L p
1 g
F P
s
P
p
.002 w
.65282 .46334 m .61699 .50723 L .62701 .52546 L p
1 g
F P
s
P
p
.002 w
.33407 .38434 m .34531 .41918 L .36134 .39843 L p
1 g
F P
s
P
p
.002 w
.36134 .39843 m .35233 .36943 L .33407 .38434 L p
1 g
F P
s
P
p
.002 w
.38787 .30803 m .3763 .33191 L .39989 .32902 L p
1 g
F P
s
P
p
.002 w
.39989 .32902 m .40779 .31297 L .38787 .30803 L p
1 g
F P
s
P
p
.002 w
.57959 .28663 m .59299 .32025 L .61804 .32664 L p
1 g
F P
s
P
p
.002 w
.59299 .32025 m .57959 .28663 L .55465 .28897 L p
1 g
F P
s
P
p
.002 w
.32453 .46256 m .35523 .49642 L .36046 .47175 L p
1 g
F P
s
P
p
.002 w
.36046 .47175 m .3329 .44071 L .32453 .46256 L p
1 g
F P
s
P
p
.002 w
.35523 .33745 m .35233 .36943 L .37386 .35645 L p
1 g
F P
s
P
p
.002 w
.37386 .35645 m .3763 .33191 L .35523 .33745 L p
1 g
F P
s
P
p
.002 w
.5117 .27821 m .48811 .26834 L .47511 .28628 L p
1 g
F P
s
P
p
.002 w
.45668 .28517 m .47511 .28628 L .48811 .26834 L p
1 g
F P
s
P
p
.002 w
.64065 .33588 m .6391 .38218 L .65808 .39724 L p
1 g
F P
s
P
p
.002 w
.6391 .38218 m .64065 .33588 L .61804 .32664 L p
1 g
F P
s
P
p
.002 w
.40988 .58426 m .46549 .5913 L .45796 .57192 L p
1 g
F P
s
P
p
.002 w
.45796 .57192 m .40311 .56465 L .40988 .58426 L p
1 g
F P
s
P
p
.002 w
.40741 .28765 m .38787 .30803 L .40779 .31297 L p
1 g
F P
s
P
p
.002 w
.40779 .31297 m .42095 .29932 L .40741 .28765 L p
1 g
F P
s
P
p
.002 w
.35582 .54198 m .40311 .56465 L .39901 .54224 L p
1 g
F P
s
P
p
.002 w
.39901 .54224 m .35362 .52003 L .35582 .54198 L p
1 g
F P
s
P
p
.002 w
.48811 .26834 m .46071 .26657 L .45668 .28517 L p
1 g
F P
s
P
p
.002 w
.4379 .28968 m .45668 .28517 L .46071 .26657 L p
1 g
F P
s
P
p
.002 w
.53253 .26715 m .55465 .28897 L .57959 .28663 L p
1 g
F P
s
P
p
.002 w
.55465 .28897 m .53253 .26715 L .5117 .27821 L p
1 g
F P
s
P
p
.002 w
.53154 .59869 m .58638 .57627 L .5789 .56032 L p
1 g
F P
s
P
p
.002 w
.5789 .56032 m .5235 .58294 L .53154 .59869 L p
1 g
F P
s
P
p
.002 w
.62701 .52546 m .5789 .56032 L .58638 .57627 L p
1 g
F P
s
P
p
.002 w
.48811 .26834 m .5117 .27821 L .53253 .26715 L p
1 g
F P
s
P
p
.002 w
.43269 .27324 m .40741 .28765 L .42095 .29932 L p
1 g
F P
s
P
p
.002 w
.42095 .29932 m .4379 .28968 L .43269 .27324 L p
1 g
F P
s
P
p
.002 w
.46071 .26657 m .43269 .27324 L .4379 .28968 L p
1 g
F P
s
P
p
.002 w
.47419 .60713 m .53154 .59869 L .5235 .58294 L p
1 g
F P
s
P
p
.002 w
.5235 .58294 m .46549 .5913 L .47419 .60713 L p
1 g
F P
s
P
p
.002 w
.31964 .40091 m .3329 .44071 L .34531 .41918 L p
1 g
F P
s
P
p
.002 w
.34531 .41918 m .33407 .38434 L .31964 .40091 L p
1 g
F P
s
P
p
.002 w
.62701 .52546 m .66357 .48112 L .65282 .46334 L p
1 g
F P
s
P
p
.002 w
.67349 .41359 m .65282 .46334 L .66357 .48112 L p
1 g
F P
s
P
p
.002 w
.65282 .46334 m .67349 .41359 L .65808 .39724 L p
1 g
F P
s
P
p
.002 w
.60312 .28798 m .61804 .32664 L .64065 .33588 L p
1 g
F P
s
P
p
.002 w
.61804 .32664 m .60312 .28798 L .57959 .28663 L p
1 g
F P
s
P
p
.002 w
.3702 .30614 m .35523 .33745 L .3763 .33191 L p
1 g
F P
s
P
p
.002 w
.3763 .33191 m .38787 .30803 L .3702 .30614 L p
1 g
F P
s
P
p
.002 w
.58638 .57627 m .63407 .54184 L .62701 .52546 L p
1 g
F P
s
P
p
.002 w
.66357 .48112 m .62701 .52546 L .63407 .54184 L p
1 g
F P
s
P
p
.002 w
.32057 .48422 m .35362 .52003 L .35523 .49642 L p
1 g
F P
s
P
p
.002 w
.35523 .49642 m .32453 .46256 L .32057 .48422 L p
1 g
F P
s
P
p
.002 w
.3373 .34564 m .33407 .38434 L .35233 .36943 L p
1 g
F P
s
P
p
.002 w
.35233 .36943 m .35523 .33745 L .3373 .34564 L p
1 g
F P
s
P
p
.002 w
.6602 .34786 m .65808 .39724 L .67349 .41359 L p
1 g
F P
s
P
p
.002 w
.65808 .39724 m .6602 .34786 L .64065 .33588 L p
1 g
F P
s
P
p
.002 w
.53253 .26715 m .50183 .25406 L .48811 .26834 L p
1 g
F P
s
P
p
.002 w
.46071 .26657 m .48811 .26834 L .50183 .25406 L p
1 g
F P
s
P
p
.002 w
.55313 .26004 m .57959 .28663 L .60312 .28798 L p
1 g
F P
s
P
p
.002 w
.57959 .28663 m .55313 .26004 L .53253 .26715 L p
1 g
F P
s
P
p
.002 w
.41928 .60043 m .47419 .60713 L .46549 .5913 L p
1 g
F P
s
P
p
.002 w
.46549 .5913 m .40988 .58426 L .41928 .60043 L p
1 g
F P
s
P
p
.002 w
.36196 .56166 m .40988 .58426 L .40311 .56465 L p
1 g
F P
s
P
p
.002 w
.40311 .56465 m .35582 .54198 L .36196 .56166 L p
1 g
F P
s
P
p
.002 w
.3958 .2793 m .3702 .30614 L .38787 .30803 L p
1 g
F P
s
P
p
.002 w
.38787 .30803 m .40741 .28765 L .3958 .2793 L p
1 g
F P
s
P
p
.002 w
.50183 .25406 m .53253 .26715 L .55313 .26004 L p
1 g
F P
s
P
p
.002 w
.30958 .41882 m .32453 .46256 L .3329 .44071 L p
1 g
F P
s
P
p
.002 w
.3329 .44071 m .31964 .40091 L .30958 .41882 L p
1 g
F P
s
P
p
.002 w
.50183 .25406 m .46593 .2516 L .46071 .26657 L p
1 g
F P
s
P
p
.002 w
.43269 .27324 m .46071 .26657 L .46593 .2516 L p
1 g
F P
s
P
p
.002 w
.53906 .6106 m .59187 .58897 L .58638 .57627 L p
1 g
F P
s
P
p
.002 w
.58638 .57627 m .53154 .59869 L .53906 .6106 L p
1 g
F P
s
P
p
.002 w
.63407 .54184 m .58638 .57627 L .59187 .58897 L p
1 g
F P
s
P
p
.002 w
.62462 .29315 m .64065 .33588 L .6602 .34786 L p
1 g
F P
s
P
p
.002 w
.64065 .33588 m .62462 .29315 L .60312 .28798 L p
1 g
F P
s
P
p
.002 w
.42907 .26033 m .3958 .2793 L .40741 .28765 L p
1 g
F P
s
P
p
.002 w
.40741 .28765 m .43269 .27324 L .42907 .26033 L p
1 g
F P
s
P
p
.002 w
.46593 .2516 m .42907 .26033 L .43269 .27324 L p
1 g
F P
s
P
p
.002 w
.48389 .61884 m .53906 .6106 L .53154 .59869 L p
1 g
F P
s
P
p
.002 w
.53154 .59869 m .47419 .60713 L .48389 .61884 L p
1 g
F P
s
P
p
.002 w
.63407 .54184 m .67036 .49817 L .66357 .48112 L p
1 g
F P
s
P
p
.002 w
.6848 .43091 m .66357 .48112 L .67036 .49817 L p
1 g
F P
s
P
p
.002 w
.66357 .48112 m .6848 .43091 L .67349 .41359 L p
1 g
F P
s
P
p
.002 w
.32134 .50513 m .35582 .54198 L .35362 .52003 L p
1 g
F P
s
P
p
.002 w
.35362 .52003 m .32057 .48422 L .32134 .50513 L p
1 g
F P
s
P
p
.002 w
.35534 .3075 m .3373 .34564 L .35523 .33745 L p
1 g
F P
s
P
p
.002 w
.35523 .33745 m .3702 .30614 L .35534 .3075 L p
1 g
F P
s
P
p
.002 w
.3231 .35639 m .31964 .40091 L .33407 .38434 L p
1 g
F P
s
P
p
.002 w
.33407 .38434 m .3373 .34564 L .3231 .35639 L p
1 g
F P
s
P
p
.002 w
.59187 .58897 m .63783 .55589 L .63407 .54184 L p
1 g
F P
s
P
p
.002 w
.67036 .49817 m .63407 .54184 L .63783 .55589 L p
1 g
F P
s
P
p
.002 w
.67609 .36242 m .67349 .41359 L .6848 .43091 L p
1 g
F P
s
P
p
.002 w
.67349 .41359 m .67609 .36242 L .6602 .34786 L p
1 g
F P
s
P
p
.002 w
.57299 .25724 m .60312 .28798 L .62462 .29315 L p
1 g
F P
s
P
p
.002 w
.60312 .28798 m .57299 .25724 L .55313 .26004 L p
1 g
F P
s
P
p
.002 w
.55313 .26004 m .516 .24397 L .50183 .25406 L p
1 g
F P
s
P
p
.002 w
.46593 .2516 m .50183 .25406 L .516 .24397 L p
1 g
F P
s
P
p
.002 w
.37207 .57844 m .41928 .60043 L .40988 .58426 L p
1 g
F P
s
P
p
.002 w
.40988 .58426 m .36196 .56166 L .37207 .57844 L p
1 g
F P
s
P
p
.002 w
.30436 .43766 m .32057 .48422 L .32453 .46256 L p
1 g
F P
s
P
p
.002 w
.32453 .46256 m .30958 .41882 L .30436 .43766 L p
1 g
F P
s
P
p
.002 w
.43122 .61259 m .48389 .61884 L .47419 .60713 L p
1 g
F P
s
P
p
.002 w
.47419 .60713 m .41928 .60043 L .43122 .61259 L p
1 g
F P
s
P
p
.002 w
.516 .24397 m .55313 .26004 L .57299 .25724 L p
1 g
F P
s
P
p
.002 w
.38653 .27469 m .35534 .3075 L .3702 .30614 L p
1 g
F P
s
P
p
.002 w
.3702 .30614 m .3958 .2793 L .38653 .27469 L p
1 g
F P
s
P
p
.002 w
.64346 .30219 m .6602 .34786 L .67609 .36242 L p
1 g
F P
s
P
p
.002 w
.6602 .34786 m .64346 .30219 L .62462 .29315 L p
1 g
F P
s
P
p
.002 w
.516 .24397 m .47226 .24085 L .46593 .2516 L p
1 g
F P
s
P
p
.002 w
.42907 .26033 m .46593 .2516 L .47226 .24085 L p
1 g
F P
s
P
p
.002 w
.32704 .5247 m .36196 .56166 L .35582 .54198 L p
1 g
F P
s
P
p
.002 w
.35582 .54198 m .32134 .50513 L .32704 .5247 L p
1 g
F P
s
P
p
.002 w
.31322 .36958 m .30958 .41882 L .31964 .40091 L p
1 g
F P
s
P
p
.002 w
.31964 .40091 m .3231 .35639 L .31322 .36958 L p
1 g
F P
s
P
p
.002 w
.54582 .61813 m .59511 .59793 L .59187 .58897 L p
1 g
F P
s
P
p
.002 w
.59187 .58897 m .53906 .6106 L .54582 .61813 L p
1 g
F P
s
P
p
.002 w
.63783 .55589 m .59187 .58897 L .59511 .59793 L p
1 g
F P
s
P
p
.002 w
.63783 .55589 m .67282 .51404 L .67036 .49817 L p
1 g
F P
s
P
p
.002 w
.69151 .44882 m .67036 .49817 L .67282 .51404 L p
1 g
F P
s
P
p
.002 w
.67036 .49817 m .69151 .44882 L .6848 .43091 L p
1 g
F P
s
P
p
.002 w
.34383 .31228 m .3231 .35639 L .3373 .34564 L p
1 g
F P
s
P
p
.002 w
.3373 .34564 m .35534 .3075 L .34383 .31228 L p
1 g
F P
s
P
p
.002 w
.42721 .25148 m .38653 .27469 L .3958 .2793 L p
1 g
F P
s
P
p
.002 w
.3958 .2793 m .42907 .26033 L .42721 .25148 L p
1 g
F P
s
P
p
.002 w
.49443 .62589 m .54582 .61813 L .53906 .6106 L p
1 g
F P
s
P
p
.002 w
.53906 .6106 m .48389 .61884 L .49443 .62589 L p
1 g
F P
s
P
p
.002 w
.47226 .24085 m .42721 .25148 L .42907 .26033 L p
1 g
F P
s
P
p
.002 w
.68772 .37932 m .6848 .43091 L .69151 .44882 L p
1 g
F P
s
P
p
.002 w
.6848 .43091 m .68772 .37932 L .67609 .36242 L p
1 g
F P
s
P
p
.002 w
.59156 .25904 m .62462 .29315 L .64346 .30219 L p
1 g
F P
s
P
p
.002 w
.62462 .29315 m .59156 .25904 L .57299 .25724 L p
1 g
F P
s
P
p
.002 w
.67282 .51404 m .63783 .55589 L .63801 .56711 L p
1 g
F P
s
P
p
.002 w
.59511 .59793 m .63801 .56711 L .63783 .55589 L p
1 g
F P
s
P
p
.002 w
.57299 .25724 m .53027 .23855 L .516 .24397 L p
1 g
F P
s
P
p
.002 w
.47226 .24085 m .516 .24397 L .53027 .23855 L p
1 g
F P
s
P
p
.002 w
.3044 .45698 m .32134 .50513 L .32057 .48422 L p
1 g
F P
s
P
p
.002 w
.32057 .48422 m .30436 .43766 L .3044 .45698 L p
1 g
F P
s
P
p
.002 w
.53027 .23855 m .57299 .25724 L .59156 .25904 L p
1 g
F P
s
P
p
.002 w
.38609 .59171 m .43122 .61259 L .41928 .60043 L p
1 g
F P
s
P
p
.002 w
.41928 .60043 m .37207 .57844 L .38609 .59171 L p
1 g
F P
s
P
p
.002 w
.65901 .31505 m .67609 .36242 L .68772 .37932 L p
1 g
F P
s
P
p
.002 w
.67609 .36242 m .65901 .31505 L .64346 .30219 L p
1 g
F P
s
P
p
.002 w
.44552 .62017 m .49443 .62589 L .48389 .61884 L p
1 g
F P
s
P
p
.002 w
.48389 .61884 m .43122 .61259 L .44552 .62017 L p
1 g
F P
s
P
p
.002 w
.37998 .27418 m .34383 .31228 L .35534 .3075 L p
1 g
F P
s
P
p
.002 w
.35534 .3075 m .38653 .27469 L .37998 .27418 L p
1 g
F P
s
P
p
.002 w
.33779 .54231 m .37207 .57844 L .36196 .56166 L p
1 g
F P
s
P
p
.002 w
.36196 .56166 m .32704 .5247 L .33779 .54231 L p
1 g
F P
s
P
p
.002 w
.30817 .38498 m .30436 .43766 L .30958 .41882 L p
1 g
F P
s
P
p
.002 w
.30958 .41882 m .31322 .36958 L .30817 .38498 L p
1 g
F P
s
P
p
.002 w
.53027 .23855 m .47963 .23486 L .47226 .24085 L p
1 g
F P
s
P
p
.002 w
.42721 .25148 m .47226 .24085 L .47963 .23486 L p
1 g
F P
s
P
p
.002 w
.3362 .32055 m .31322 .36958 L .3231 .35639 L p
1 g
F P
s
P
p
.002 w
.3231 .35639 m .34383 .31228 L .3362 .32055 L p
1 g
F P
s
P
p
.002 w
.63801 .56711 m .67063 .52823 L .67282 .51404 L p
1 g
F P
s
P
p
.002 w
.69321 .46688 m .67282 .51404 L .67063 .52823 L p
1 g
F P
s
P
p
.002 w
.67282 .51404 m .69321 .46688 L .69151 .44882 L p
1 g
F P
s
P
p
.002 w
.69457 .39821 m .69151 .44882 L .69321 .46688 L p
1 g
F P
s
P
p
.002 w
.69151 .44882 m .69457 .39821 L .68772 .37932 L p
1 g
F P
s
P
p
.002 w
.60829 .26564 m .64346 .30219 L .65901 .31505 L p
1 g
F P
s
P
p
.002 w
.64346 .30219 m .60829 .26564 L .59156 .25904 L p
1 g
F P
s
P
p
.002 w
.55162 .62082 m .59587 .60267 L .59511 .59793 L p
1 g
F P
s
P
p
.002 w
.59511 .59793 m .54582 .61813 L .55162 .62082 L p
1 g
F P
s
P
p
.002 w
.63801 .56711 m .59511 .59793 L .59587 .60267 L p
1 g
F P
s
P
p
.002 w
.42727 .24719 m .37998 .27418 L .38653 .27469 L p
1 g
F P
s
P
p
.002 w
.38653 .27469 m .42721 .25148 L .42727 .24719 L p
1 g
F P
s
P
p
.002 w
.50556 .6278 m .55162 .62082 L .54582 .61813 L p
1 g
F P
s
P
p
.002 w
.54582 .61813 m .49443 .62589 L .50556 .6278 L p
1 g
F P
s
P
p
.002 w
.47963 .23486 m .42727 .24719 L .42721 .25148 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.57813 .6062 L
s
P
p
.004 w
.57954 .60937 m
.58282 .61675 L
s
P
p
.004 w
.58282 .61675 m
.61815 .69619 L
s
P
p
.002 w
.30996 .47624 m .32704 .5247 L .32134 .50513 L p
1 g
F P
s
P
p
.002 w
.32134 .50513 m .3044 .45698 L .30996 .47624 L p
1 g
F P
s
P
p
.002 w
.59587 .60267 m .63438 .57503 L .63801 .56711 L p
1 g
F P
s
P
p
.002 w
.67063 .52823 m .63801 .56711 L .63438 .57503 L p
1 g
F P
s
P
p
.002 w
.59156 .25904 m .54427 .23823 L .53027 .23855 L p
1 g
F P
s
P
p
.002 w
.47963 .23486 m .53027 .23855 L .54427 .23823 L p
1 g
F P
s
P
p
.002 w
.54427 .23823 m .59156 .25904 L .60829 .26564 L p
1 g
F P
s
P
p
.002 w
.67066 .33159 m .68772 .37932 L .69457 .39821 L p
1 g
F P
s
P
p
.002 w
.68772 .37932 m .67066 .33159 L .65901 .31505 L p
1 g
F P
s
P
p
.002 w
.40382 .60091 m .44552 .62017 L .43122 .61259 L p
1 g
F P
s
P
p
.002 w
.43122 .61259 m .38609 .59171 L .40382 .60091 L p
1 g
F P
s
P
p
.002 w
.46191 .6227 m .50556 .6278 L .49443 .62589 L p
1 g
F P
s
P
p
.002 w
.49443 .62589 m .44552 .62017 L .46191 .6227 L p
1 g
F P
s
P
p
.002 w
.35352 .55735 m .38609 .59171 L .37207 .57844 L p
1 g
F P
s
P
p
.002 w
.37207 .57844 m .33779 .54231 L .35352 .55735 L p
1 g
F P
s
P
p
.002 w
.30839 .40227 m .3044 .45698 L .30436 .43766 L p
1 g
F P
s
P
p
.002 w
.30436 .43766 m .30817 .38498 L .30839 .40227 L p
1 g
F P
s
P
p
.002 w
.37653 .27805 m .3362 .32055 L .34383 .31228 L p
1 g
F P
s
P
p
.002 w
.34383 .31228 m .37998 .27418 L .37653 .27805 L p
1 g
F P
s
P
p
.002 w
.3329 .3323 m .30817 .38498 L .31322 .36958 L p
1 g
F P
s
P
p
.002 w
.31322 .36958 m .3362 .32055 L .3329 .3323 L p
1 g
F P
s
P
p
.002 w
.65901 .31505 m .6226 .27713 L .60829 .26564 L p
1 g
F P
s
P
p
.002 w
.6226 .27713 m .65901 .31505 L .67066 .33159 L p
1 g
F P
s
P
p
.002 w
.67063 .52823 m .68958 .48458 L .69321 .46688 L p
1 g
F P
s
P
p
.002 w
.69321 .46688 m .6962 .41867 L .69457 .39821 L p
1 g
F P
s
P
p
.002 w
.6962 .41867 m .69321 .46688 L .68958 .48458 L p
1 g
F P
s
P
p
.002 w
.63438 .57503 m .66359 .54026 L .67063 .52823 L p
1 g
F P
s
P
p
.002 w
.68958 .48458 m .67063 .52823 L .66359 .54026 L p
1 g
F P
s
P
p
.002 w
.54427 .23823 m .48788 .2341 L .47963 .23486 L p
1 g
F P
s
P
p
.002 w
.42727 .24719 m .47963 .23486 L .48788 .2341 L p
1 g
F P
s
P
p
.002 w
.32119 .49486 m .33779 .54231 L .32704 .5247 L p
1 g
F P
s
P
p
.002 w
.32704 .5247 m .30996 .47624 L .32119 .49486 L p
1 g
F P
s
P
p
.002 w
.55621 .61825 m .59397 .60277 L .59587 .60267 L p
1 g
F P
s
P
p
.002 w
.59587 .60267 m .55162 .62082 L .55621 .61825 L p
1 g
F P
s
P
p
.002 w
.63438 .57503 m .59587 .60267 L .59397 .60277 L p
1 g
F P
s
P
p
.002 w
.4294 .24787 m .37653 .27805 L .37998 .27418 L p
1 g
F P
s
P
p
.002 w
.37998 .27418 m .42727 .24719 L .4294 .24787 L p
1 g
F P
s
P
p
.002 w
.517 .62418 m .55621 .61825 L .55162 .62082 L p
1 g
F P
s
P
p
.002 w
.55162 .62082 m .50556 .6278 L .517 .62418 L p
1 g
F P
s
P
p
.002 w
.48788 .2341 m .4294 .24787 L .42727 .24719 L p
1 g
F P
s
P
p
.002 w
.69457 .39821 m .67788 .3515 L .67066 .33159 L p
1 g
F P
s
P
p
.002 w
.67788 .3515 m .69457 .39821 L .6962 .41867 L p
1 g
F P
s
P
p
.002 w
.60829 .26564 m .55759 .24331 L .54427 .23823 L p
1 g
F P
s
P
p
.002 w
.55759 .24331 m .60829 .26564 L .6226 .27713 L p
1 g
F P
s
P
p
.002 w
.48788 .2341 m .54427 .23823 L .55759 .24331 L p
1 g
F P
s
P
p
.002 w
.42494 .60553 m .46191 .6227 L .44552 .62017 L p
1 g
F P
s
P
p
.002 w
.44552 .62017 m .40382 .60091 L .42494 .60553 L p
1 g
F P
s
P
p
.002 w
.59397 .60277 m .6268 .5792 L .63438 .57503 L p
1 g
F P
s
P
p
.002 w
.66359 .54026 m .63438 .57503 L .6268 .5792 L p
1 g
F P
s
P
p
.002 w
.374 .56921 m .40382 .60091 L .38609 .59171 L p
1 g
F P
s
P
p
.002 w
.38609 .59171 m .35352 .55735 L .374 .56921 L p
1 g
F P
s
P
p
.002 w
.31416 .42103 m .30996 .47624 L .3044 .45698 L p
1 g
F P
s
P
p
.002 w
.3044 .45698 m .30839 .40227 L .31416 .42103 L p
1 g
F P
s
P
p
.002 w
.48001 .61981 m .517 .62418 L .50556 .6278 L p
1 g
F P
s
P
p
.002 w
.50556 .6278 m .46191 .6227 L .48001 .61981 L p
1 g
F P
s
P
p
.002 w
.37647 .28647 m .3329 .3323 L .3362 .32055 L p
1 g
F P
s
P
p
.002 w
.3362 .32055 m .37653 .27805 L .37647 .28647 L p
1 g
F P
s
P
p
.002 w
.63392 .29343 m .67066 .33159 L .67788 .3515 L p
1 g
F P
s
P
p
.002 w
.67066 .33159 m .63392 .29343 L .6226 .27713 L p
1 g
F P
s
P
p
.002 w
.33432 .34737 m .30839 .40227 L .30817 .38498 L p
1 g
F P
s
P
p
.002 w
.30817 .38498 m .3329 .3323 L .33432 .34737 L p
1 g
F P
s
P
p
.002 w
.66359 .54026 m .68043 .50141 L .68958 .48458 L p
1 g
F P
s
P
p
.002 w
.69228 .44017 m .68958 .48458 L .68043 .50141 L p
1 g
F P
s
P
p
.002 w
.68958 .48458 m .69228 .44017 L .6962 .41867 L p
1 g
F P
s
P
p
.002 w
.338 .51221 m .35352 .55735 L .33779 .54231 L p
1 g
F P
s
P
p
.002 w
.33779 .54231 m .32119 .49486 L .338 .51221 L p
1 g
F P
s
P
p
.002 w
.6268 .5792 m .65159 .54965 L .66359 .54026 L p
1 g
F P
s
P
p
.002 w
.68043 .50141 m .66359 .54026 L .65159 .54965 L p
1 g
F P
s
P
p
.002 w
.55759 .24331 m .49684 .23893 L .48788 .2341 L p
1 g
F P
s
P
p
.002 w
.4294 .24787 m .48788 .2341 L .49684 .23893 L p
1 g
F P
s
P
p
.002 w
.68022 .37436 m .6962 .41867 L .69228 .44017 L p
1 g
F P
s
P
p
.002 w
.6962 .41867 m .68022 .37436 L .67788 .3515 L p
1 g
F P
s
P
p
.002 w
.56978 .25398 m .6226 .27713 L .63392 .29343 L p
1 g
F P
s
P
p
.002 w
.6226 .27713 m .56978 .25398 L .55759 .24331 L p
1 g
F P
s
P
p
.002 w
.55939 .61017 m .58927 .59792 L .59397 .60277 L p
1 g
F P
s
P
p
.002 w
.59397 .60277 m .55621 .61825 L .55939 .61017 L p
1 g
F P
s
P
p
.002 w
.6268 .5792 m .59397 .60277 L .58927 .59792 L p
1 g
F P
s
P
p
.002 w
.43365 .25386 m .37647 .28647 L .37653 .27805 L p
1 g
F P
s
P
p
.002 w
.37653 .27805 m .4294 .24787 L .43365 .25386 L p
1 g
F P
s
P
p
.002 w
.52841 .61481 m .55939 .61017 L .55621 .61825 L p
1 g
F P
s
P
p
.002 w
.55621 .61825 m .517 .62418 L .52841 .61481 L p
1 g
F P
s
P
p
.002 w
.44895 .6052 m .48001 .61981 L .46191 .6227 L p
1 g
F P
s
P
p
.002 w
.46191 .6227 m .42494 .60553 L .44895 .6052 L p
1 g
F P
s
P
p
.002 w
.49684 .23893 m .55759 .24331 L .56978 .25398 L p
1 g
F P
s
P
p
.002 w
.49684 .23893 m .43365 .25386 L .4294 .24787 L p
1 g
F P
s
P
p
.002 w
.3988 .57737 m .42494 .60553 L .40382 .60091 L p
1 g
F P
s
P
p
.002 w
.40382 .60091 m .374 .56921 L .3988 .57737 L p
1 g
F P
s
P
p
.002 w
.32562 .44072 m .32119 .49486 L .30996 .47624 L p
1 g
F P
s
P
p
.002 w
.30996 .47624 m .31416 .42103 L .32562 .44072 L p
1 g
F P
s
P
p
.002 w
.58927 .59792 m .61523 .57926 L .6268 .5792 L p
1 g
F P
s
P
p
.002 w
.65159 .54965 m .6268 .5792 L .61523 .57926 L p
1 g
F P
s
P
p
.002 w
.64173 .31429 m .67788 .3515 L .68022 .37436 L p
1 g
F P
s
P
p
.002 w
.67788 .3515 m .64173 .31429 L .63392 .29343 L p
1 g
F P
s
P
p
.002 w
.49936 .61127 m .52841 .61481 L .517 .62418 L p
1 g
F P
s
P
p
.002 w
.517 .62418 m .48001 .61981 L .49936 .61127 L p
1 g
F P
s
P
p
.002 w
.65159 .54965 m .66572 .51678 L .68043 .50141 L p
1 g
F P
s
P
p
.002 w
.68265 .4621 m .68043 .50141 L .66572 .51678 L p
1 g
F P
s
P
p
.002 w
.68043 .50141 m .68265 .4621 L .69228 .44017 L p
1 g
F P
s
P
p
.002 w
.38004 .29948 m .33432 .34737 L .3329 .3323 L p
1 g
F P
s
P
p
.002 w
.3329 .3323 m .37647 .28647 L .38004 .29948 L p
1 g
F P
s
P
p
.002 w
.36011 .52766 m .374 .56921 L .35352 .55735 L p
1 g
F P
s
P
p
.002 w
.35352 .55735 m .338 .51221 L .36011 .52766 L p
1 g
F P
s
P
p
.002 w
.34069 .36548 m .31416 .42103 L .30839 .40227 L p
1 g
F P
s
P
p
.002 w
.30839 .40227 m .33432 .34737 L .34069 .36548 L p
1 g
F P
s
P
p
.002 w
.61523 .57926 m .63471 .55593 L .65159 .54965 L p
1 g
F P
s
P
p
.002 w
.66572 .51678 m .65159 .54965 L .63471 .55593 L p
1 g
F P
s
P
p
.002 w
.67735 .39959 m .69228 .44017 L .68265 .4621 L p
1 g
F P
s
P
p
.002 w
.69228 .44017 m .67735 .39959 L .68022 .37436 L p
1 g
F P
s
P
p
.002 w
.58039 .27023 m .63392 .29343 L .64173 .31429 L p
1 g
F P
s
P
p
.002 w
.63392 .29343 m .58039 .27023 L .56978 .25398 L p
1 g
F P
s
P
p
.002 w
.56978 .25398 m .50626 .24955 L .49684 .23893 L p
1 g
F P
s
P
p
.002 w
.43365 .25386 m .49684 .23893 L .50626 .24955 L p
1 g
F P
s
P
p
.002 w
.42728 .58139 m .44895 .6052 L .42494 .60553 L p
1 g
F P
s
P
p
.002 w
.42494 .60553 m .3988 .57737 L .42728 .58139 L p
1 g
F P
s
P
p
.002 w
.47519 .59969 m .49936 .61127 L .48001 .61981 L p
1 g
F P
s
P
p
.002 w
.48001 .61981 m .44895 .6052 L .47519 .59969 L p
1 g
F P
s
P
p
.002 w
.34264 .46073 m .338 .51221 L .32119 .49486 L p
1 g
F P
s
P
p
.002 w
.32119 .49486 m .32562 .44072 L .34264 .46073 L p
1 g
F P
s
P
p
.002 w
.50626 .24955 m .56978 .25398 L .58039 .27023 L p
1 g
F P
s
P
p
.002 w
.44003 .26529 m .38004 .29948 L .37647 .28647 L p
1 g
F P
s
P
p
.002 w
.37647 .28647 m .43365 .25386 L .44003 .26529 L p
1 g
F P
s
P
p
.002 w
.56095 .59647 m .58176 .58795 L .58927 .59792 L p
1 g
F P
s
P
p
.002 w
.58927 .59792 m .55939 .61017 L .56095 .59647 L p
1 g
F P
s
P
p
.002 w
.61523 .57926 m .58927 .59792 L .58176 .58795 L p
1 g
F P
s
P
p
.002 w
.53944 .59964 m .56095 .59647 L .55939 .61017 L p
1 g
F P
s
P
p
.002 w
.55939 .61017 m .52841 .61481 L .53944 .59964 L p
1 g
F P
s
P
p
.002 w
.64561 .33925 m .68022 .37436 L .67735 .39959 L p
1 g
F P
s
P
p
.002 w
.68022 .37436 m .64561 .33925 L .64173 .31429 L p
1 g
F P
s
P
p
.002 w
.50626 .24955 m .44003 .26529 L .43365 .25386 L p
1 g
F P
s
P
p
.002 w
.63471 .55593 m .61523 .57926 L .5998 .57495 L p
1 g
F P
s
P
p
.002 w
.58176 .58795 m .5998 .57495 L .61523 .57926 L p
1 g
F P
s
P
p
.002 w
.38698 .54059 m .3988 .57737 L .374 .56921 L p
1 g
F P
s
P
p
.002 w
.374 .56921 m .36011 .52766 L .38698 .54059 L p
1 g
F P
s
P
p
.002 w
.63471 .55593 m .64565 .53012 L .66572 .51678 L p
1 g
F P
s
P
p
.002 w
.66735 .48375 m .66572 .51678 L .64565 .53012 L p
1 g
F P
s
P
p
.002 w
.66572 .51678 m .66735 .48375 L .68265 .4621 L p
1 g
F P
s
P
p
.002 w
.51937 .59709 m .53944 .59964 L .52841 .61481 L p
1 g
F P
s
P
p
.002 w
.52841 .61481 m .49936 .61127 L .51937 .59709 L p
1 g
F P
s
P
p
.002 w
.35207 .38619 m .32562 .44072 L .31416 .42103 L p
1 g
F P
s
P
p
.002 w
.31416 .42103 m .34069 .36548 L .35207 .38619 L p
1 g
F P
s
P
p
.002 w
.38734 .31691 m .34069 .36548 L .33432 .34737 L p
1 g
F P
s
P
p
.002 w
.33432 .34737 m .38004 .29948 L .38734 .31691 L p
1 g
F P
s
P
p
.002 w
.66915 .42643 m .68265 .4621 L .66735 .48375 L p
1 g
F P
s
P
p
.002 w
.68265 .4621 m .66915 .42643 L .67735 .39959 L p
1 g
F P
s
P
p
.002 w
.5998 .57495 m .61324 .55873 L .63471 .55593 L p
1 g
F P
s
P
p
.002 w
.64565 .53012 m .63471 .55593 L .61324 .55873 L p
1 g
F P
s
P
p
.002 w
.58898 .29182 m .64173 .31429 L .64561 .33925 L p
1 g
F P
s
P
p
.002 w
.64173 .31429 m .58898 .29182 L .58039 .27023 L p
1 g
F P
s
P
p
.002 w
.45859 .58098 m .47519 .59969 L .44895 .6052 L p
1 g
F P
s
P
p
.002 w
.44895 .6052 m .42728 .58139 L .45859 .58098 L p
1 g
F P
s
P
p
.002 w
.36489 .48036 m .36011 .52766 L .338 .51221 L p
1 g
F P
s
P
p
.002 w
.338 .51221 m .34264 .46073 L .36489 .48036 L p
1 g
F P
s
P
p
.002 w
.58039 .27023 m .51586 .26598 L .50626 .24955 L p
1 g
F P
s
P
p
.002 w
.44003 .26529 m .50626 .24955 L .51586 .26598 L p
1 g
F P
s
P
p
.002 w
.50286 .58898 m .51937 .59709 L .49936 .61127 L p
1 g
F P
s
P
p
.002 w
.49936 .61127 m .47519 .59969 L .50286 .58898 L p
1 g
F P
s
P
p
.002 w
.64523 .36766 m .67735 .39959 L .66915 .42643 L p
1 g
F P
s
P
p
.002 w
.67735 .39959 m .64523 .36766 L .64561 .33925 L p
1 g
F P
s
P
p
.002 w
.51586 .26598 m .58039 .27023 L .58898 .29182 L p
1 g
F P
s
P
p
.002 w
.41783 .55048 m .42728 .58139 L .3988 .57737 L p
1 g
F P
s
P
p
.002 w
.3988 .57737 m .38698 .54059 L .41783 .55048 L p
1 g
F P
s
P
p
.002 w
.44847 .28213 m .38734 .31691 L .38004 .29948 L p
1 g
F P
s
P
p
.002 w
.38004 .29948 m .44003 .26529 L .44847 .28213 L p
1 g
F P
s
P
p
.002 w
.56075 .57726 m .5715 .57287 L .58176 .58795 L p
1 g
F P
s
P
p
.002 w
.58176 .58795 m .56095 .59647 L .56075 .57726 L p
1 g
F P
s
P
p
.002 w
.5998 .57495 m .58176 .58795 L .5715 .57287 L p
1 g
F P
s
P
p
.002 w
.54967 .57886 m .56075 .57726 L .56095 .59647 L p
1 g
F P
s
P
p
.002 w
.56095 .59647 m .53944 .59964 L .54967 .57886 L p
1 g
F P
s
P
p
.002 w
.61324 .55873 m .62064 .5409 L .64565 .53012 L p
1 g
F P
s
P
p
.002 w
.64667 .5044 m .64565 .53012 L .62064 .5409 L p
1 g
F P
s
P
p
.002 w
.64565 .53012 m .64667 .5044 L .66735 .48375 L p
1 g
F P
s
P
p
.002 w
.51586 .26598 m .44847 .28213 L .44003 .26529 L p
1 g
F P
s
P
p
.002 w
.65569 .45405 m .66735 .48375 L .64667 .5044 L p
1 g
F P
s
P
p
.002 w
.66735 .48375 m .65569 .45405 L .66915 .42643 L p
1 g
F P
s
P
p
.002 w
.5715 .57287 m .5808 .56614 L .5998 .57495 L p
1 g
F P
s
P
p
.002 w
.61324 .55873 m .5998 .57495 L .5808 .56614 L p
1 g
F P
s
P
p
.002 w
.3683 .40887 m .34264 .46073 L .32562 .44072 L p
1 g
F P
s
P
p
.002 w
.32562 .44072 m .35207 .38619 L .3683 .40887 L p
1 g
F P
s
P
p
.002 w
.53939 .57748 m .54967 .57886 L .53944 .59964 L p
1 g
F P
s
P
p
.002 w
.53944 .59964 m .51937 .59709 L .53939 .57748 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.39831 .33841 m .35207 .38619 L .34069 .36548 L p
1 g
F P
s
P
p
.002 w
.34069 .36548 m .38734 .31691 L .39831 .33841 L p
1 g
F P
s
P
p
.002 w
.59515 .31826 m .64561 .33925 L .64523 .36766 L p
1 g
F P
s
P
p
.002 w
.64561 .33925 m .59515 .31826 L .58898 .29182 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.5808 .56614 m .58766 .55777 L .61324 .55873 L p
1 g
F P
s
P
p
.002 w
.62064 .5409 m .61324 .55873 L .58766 .55777 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50286 .58898 m .47519 .59969 L p
.48847 .58065 L 1 g
F P
s
P
p
.48847 .58065 m .48854 .58055 L .48874 .58067 L 1 g
F
P
p
.48847 .58065 m .48874 .58067 L .50286 .58898 L 1 g
F
P
p
.002 w
.48906 .58069 m .48921 .57862 L p
.47813 .57771 L 1 g
F P
s
P
p
.45859 .58098 m .46766 .57418 L .46834 .57441 L 1 g
F
P
p
.002 w
.47882 .57794 m .47496 .57852 L p
.46834 .57441 L 1 g
F P
s
P
p
.002 w
.47496 .57852 m .45859 .58098 L p
.46834 .57441 L 1 g
F P
s
P
p
.002 w
.46834 .57441 m .46872 .57265 L p
.45973 .56906 L 1 g
F P
s
P
p
.47813 .57771 m .47882 .57794 L .48906 .58069 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .57441 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45859 .58098 m .42728 .58139 L p
.44774 .56082 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56309 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56309 L .4525 .56436 L 1 g
F
P
p
.44774 .56082 m .45079 .56309 L .45859 .58098 L 1 g
F
P
p
.002 w
.45417 .5656 m .45483 .5679 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.45483 .5679 m .45859 .58098 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44386 .55469 L 1 g
F P
s
P
p
.41783 .55048 m .43474 .54125 L .43858 .54691 L 1 g
F
P
p
.002 w
.44441 .5555 m .4411 .55487 L p
.43858 .54691 L 1 g
F P
s
P
p
.002 w
.4411 .55487 m .41783 .55048 L p
.43858 .54691 L 1 g
F P
s
P
p
.002 w
.43858 .54691 m .43925 .54566 L p
.43643 .54009 L 1 g
F P
s
P
p
.44386 .55469 m .44441 .5555 L .45079 .56309 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43805 .54792 L p
1 g
F P
s
P
p
.45146 .56129 m .43805 .54792 L .44338 .55427 L 1 g
F
P
p
.46872 .57265 m .4525 .56436 L .45973 .56906 L 1 g
F
P
p
.4525 .56436 m .45067 .56342 L .45417 .5656 L 1 g
F
P
p
.4525 .56436 m .45417 .5656 L .45973 .56906 L 1 g
F
P
p
.002 w
.45167 .55687 m .45417 .5656 L p
.45079 .56309 L 1 g
F P
s
P
p
.44774 .56082 m .44836 .56019 L .45079 .56309 L 1 g
F
P
p
.44836 .56019 m .45167 .55687 L .45079 .56309 L 1 g
F
P
p
.002 w
.43805 .54792 m .43743 .5491 L p
.44338 .55427 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43858 .54691 m .4556 .52986 L .44441 .5555 L 1 g
F
P
p
.43474 .54125 m .4365 .54029 L .43858 .54691 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43274 .52839 L p
1 g
F P
s
P
p
.43925 .54566 m .43274 .52839 L .43643 .54009 L 1 g
F
P
p
.4365 .54029 m .4556 .52986 L .43858 .54691 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.41783 .55048 m .42235 .51562 L .43302 .52019 L p
1 g
F P
s
P
p
.002 w
.43274 .52839 m .43346 .52734 L p
.43316 .51878 L 1 g
F P
s
P
p
.002 w
.43302 .52019 m .42235 .51562 L p
.43377 .51262 L 1 g
F P
s
P
p
.43316 .51878 m .43312 .51746 L .43302 .52019 L 1 g
F
P
p
.43316 .51878 m .43302 .52019 L .43274 .52839 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43412 .50913 L p
1 g
F P
s
P
p
.002 w
.42235 .51562 m .43601 .49002 L p
.43412 .50913 L 1 g
F P
s
P
p
.43226 .51301 m .43412 .50913 L .43377 .51262 L 1 g
F
P
p
.42235 .51562 m .43412 .50913 L .43226 .51301 L 1 g
F
P
p
.002 w
.43412 .50913 m .43485 .50826 L p
.43747 .50212 L 1 g
F P
s
P
p
.43346 .52734 m .43412 .50913 L .43316 .51878 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44268 .49125 L p
1 g
F P
s
P
p
.43485 .50826 m .44268 .49125 L .43747 .50212 L 1 g
F
P
p
.43377 .51262 m .43495 .5074 L .47034 .50301 L 1 g
F
P
p
.43495 .5074 m .43745 .49631 L .44268 .49125 L 1 g
F
P
p
.002 w
.44268 .49125 m .44339 .4905 L p
.45023 .48395 L 1 g
F P
s
P
p
.45379 .48048 m .49443 .47954 L .448 .48611 L 1 g
F
P
p
.45023 .48395 m .45241 .48185 L .448 .48611 L 1 g
F
P
p
.45023 .48395 m .448 .48611 L .44268 .49125 L 1 g
F
P
p
.002 w
.49443 .47954 m .47034 .50301 L .448 .48611 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43495 .5074 m .44268 .49125 L .47034 .50301 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47657 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45379 .48048 m .45782 .47657 L .49443 .47954 L 1 g
F
P
p
.002 w
.45782 .47657 m .45826 .47608 L p
.46515 .47306 L 1 g
F P
s
P
p
.45782 .47657 m .4776 .46711 L .49443 .47954 L 1 g
F
P
p
.002 w
.4776 .46711 m .47786 .46667 L p
.4883 .46561 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46724 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.51762 .46656 m .52248 .46724 L .53779 .49546 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54224 .47663 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56604 .50931 L p
1 g
F P
s
P
p
.55661 .4905 m .56604 .50931 L .56503 .5072 L 1 g
F
P
p
.002 w
.5605 .49762 m .56049 .48944 L p
.56562 .50497 L 1 g
F P
s
P
p
.56562 .50497 m .5694 .51641 L .56604 .50931 L 1 g
F
P
p
.56562 .50497 m .56604 .50931 L .5605 .49762 L 1 g
F
P
p
.002 w
.56604 .50931 m .56515 .50826 L p
.56723 .52178 L 1 g
F P
s
P
p
.56209 .50098 m .5662 .50951 L .56233 .50144 L 1 g
F
P
p
.55661 .4905 m .56503 .5072 L .56209 .50098 L 1 g
F
P
p
.56503 .5072 m .5662 .50951 L .56209 .50098 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56756 .52883 L p
1 g
F P
s
P
p
.56515 .50826 m .56756 .52883 L .56744 .52544 L 1 g
F
P
p
.002 w
.57157 .52297 m .56768 .53202 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.56735 .52296 m .56941 .52296 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.56941 .52296 m .57157 .52297 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.56756 .52883 m .56654 .52734 L p
.56448 .53864 L 1 g
F P
s
P
p
.56515 .50826 m .56744 .52544 L .56723 .52178 L 1 g
F
P
p
.56744 .52544 m .56797 .52942 L .56735 .52296 L 1 g
F
P
p
.56744 .52544 m .56735 .52296 L .56723 .52178 L 1 g
F
P
p
.002 w
.55995 .55002 m .5587 .55292 L p
.55924 .55106 L 1 g
F P
s
P
p
.002 w
.54967 .57886 m .53939 .57748 L .55247 .56085 L p
1 g
F P
s
P
p
.002 w
.55247 .56085 m .5587 .55292 L .55708 .55759 L p
1 g
F P
s
P
p
.002 w
.55708 .55759 m .54967 .57886 L p
.55247 .56085 L 1 g
F P
s
P
p
.002 w
.53939 .57748 m .51937 .59709 L p
.52958 .5762 L 1 g
F P
s
P
p
.52958 .5762 m .52989 .57557 L .5318 .57503 L 1 g
F
P
p
.002 w
.53315 .57432 m .53939 .57748 L p
.52958 .5762 L 1 g
F P
s
P
p
.002 w
.5318 .57503 m .53128 .57265 L p
.5207 .57808 L 1 g
F P
s
P
p
.002 w
.5238 .57728 m .51841 .58029 L p
.51145 .58046 L 1 g
F P
s
P
p
.002 w
.51841 .58029 m .50286 .58898 L p
.51133 .58058 L 1 g
F P
s
P
p
.51133 .58058 m .51145 .58046 L .51841 .58029 L 1 g
F
P
p
.002 w
.51094 .5806 m .51079 .57862 L p
.4983 .58112 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58069 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58069 L .49298 .58097 L 1 g
F
P
p
.002 w
.49618 .58121 m .49774 .58302 L p
.48906 .58069 L 1 g
F P
s
P
p
.51079 .57862 m .49298 .58097 L .4983 .58112 L 1 g
F
P
p
.002 w
.49774 .58302 m .50286 .58898 L p
.48874 .58067 L 1 g
F P
s
P
p
.48906 .58069 m .49774 .58302 L .48874 .58067 L 1 g
F
P
p
.49298 .58097 m .489 .5815 L .49618 .58121 L 1 g
F
P
p
.49298 .58097 m .49618 .58121 L .4983 .58112 L 1 g
F
P
p
.48854 .58055 m .48906 .58069 L .48874 .58067 L 1 g
F
P
p
.002 w
.49171 .57601 m .49618 .58121 L p
.48854 .58055 L 1 g
F P
s
P
p
.48854 .58055 m .49618 .58121 L .48906 .58069 L 1 g
F
P
p
.002 w
.48906 .58069 m .489 .5815 L p
.49298 .58097 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .5806 L p
1 g
F P
s
P
p
.51133 .58058 m .51116 .58054 L .51145 .58046 L 1 g
F
P
p
.002 w
.50286 .58898 m .49618 .58121 L p
.51133 .58058 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .5806 L .5207 .57808 L 1 g
F
P
p
.002 w
.49618 .58121 m .49171 .57601 L p
.51133 .58058 L 1 g
F P
s
P
p
.002 w
.51094 .5806 m .51111 .583 L p
.5207 .57808 L 1 g
F P
s
P
p
.002 w
.49171 .57601 m .52549 .56656 L p
.51145 .58046 L 1 g
F P
s
P
p
.51116 .58054 m .49171 .57601 L .51145 .58046 L 1 g
F
P
p
.002 w
.489 .5815 m .48889 .583 L p
.4983 .58112 L 1 g
F P
s
P
p
.002 w
.51106 .58228 m .51094 .5806 L p
.49741 .58129 L 1 g
F P
s
P
p
.4983 .58112 m .49741 .58129 L .51094 .5806 L 1 g
F
P
p
.5207 .57808 m .52039 .57824 L .5238 .57728 L 1 g
F
P
p
.5207 .57808 m .5238 .57728 L .5318 .57503 L 1 g
F
P
p
.002 w
.52549 .56656 m .53103 .57324 L .5238 .57728 L p
1 g
F P
s
P
p
.51145 .58046 m .52549 .56656 L .5238 .57728 L 1 g
F
P
p
.002 w
.51937 .59709 m .50286 .58898 L .53103 .57324 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5318 .57503 L p
1 g
F P
s
P
p
.52039 .57824 m .51111 .583 L .5318 .57503 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53184 .57523 L p
1 g
F P
s
P
p
.002 w
.55247 .56085 m .53939 .57748 L .53767 .57661 L p
1 g
F P
s
P
p
.002 w
.53767 .57661 m .53315 .57432 L p
.54922 .56312 L 1 g
F P
s
P
p
.53767 .57661 m .54922 .56312 L .55247 .56085 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54922 .56312 L p
1 g
F P
s
P
p
.56075 .54566 m .54922 .56312 L .55458 .55685 L 1 g
F
P
p
.54854 .56129 m .53184 .57523 L .53955 .56986 L 1 g
F
P
p
.002 w
.54923 .56314 m .54854 .56129 L p
.53899 .57039 L 1 g
F P
s
P
p
.002 w
.58104 .52607 m .56073 .55048 L p
.5614 .54837 L 1 g
F P
s
P
p
.56075 .54566 m .55458 .55685 L .56157 .54763 L 1 g
F
P
p
.002 w
.5617 .54744 m .56075 .54566 L p
.56157 .54763 L 1 g
F P
s
P
p
.002 w
.57706 .52477 m .58104 .52607 L p
.5614 .54837 L 1 g
F P
s
P
p
.5617 .54744 m .5614 .54837 L .55995 .55002 L 1 g
F
P
p
.57706 .52477 m .5614 .54837 L .5617 .54744 L 1 g
F
P
p
.5602 .54944 m .55995 .55002 L .5617 .54745 L 1 g
F
P
p
.55458 .55685 m .55995 .55002 L .5602 .54944 L 1 g
F
P
p
.55458 .55685 m .55665 .55443 L .55995 .55002 L 1 g
F
P
p
.55665 .55443 m .55751 .55341 L .55995 .55002 L 1 g
F
P
p
.55751 .55341 m .55781 .55305 L .55995 .55002 L 1 g
F
P
p
.55781 .55305 m .55792 .55291 L .55995 .55002 L 1 g
F
P
p
.5579 .55294 m .55815 .55262 L .55995 .55002 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.52341 .55813 m .52508 .54885 L .55798 .55283 L p
1 g
F P
s
P
p
.002 w
.55798 .55283 m .5587 .55292 L .55781 .55305 L p
1 g
F P
s
P
p
.002 w
.55781 .55305 m .52341 .55813 L p
.55798 .55283 L 1 g
F P
s
P
p
.55781 .55305 m .5579 .55294 L .55792 .55291 L 1 g
F
P
p
.002 w
.55812 .55265 m .5587 .55292 L .55798 .55283 L p
1 g
F P
s
P
p
.5579 .55294 m .55806 .55275 L .55815 .55262 L 1 g
F
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.52508 .54885 m .53036 .53973 L .55812 .55265 L p
1 g
F P
s
P
p
.002 w
.55798 .55283 m .52508 .54885 L p
.55812 .55265 L 1 g
F P
s
P
p
.55806 .55275 m .55835 .55234 L .55995 .55002 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.53868 .53181 m .54912 .526 L .55845 .55221 L p
1 g
F P
s
P
p
.002 w
.55845 .55221 m .5587 .55292 L .55827 .55246 L p
1 g
F P
s
P
p
.002 w
.55827 .55246 m .53868 .53181 L p
.55845 .55221 L 1 g
F P
s
P
p
.002 w
.55827 .55246 m .5587 .55292 L .55812 .55265 L p
1 g
F P
s
P
p
.55806 .55275 m .55813 .55266 L .55835 .55234 L 1 g
F
P
p
.55813 .55266 m .5582 .55258 L .55877 .55174 L 1 g
F
P
p
.55813 .55266 m .55877 .55174 L .55995 .55002 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.54912 .526 m .56052 .52294 L .55877 .55174 L p
1 g
F P
s
P
p
.002 w
.55877 .55174 m .5587 .55292 L .55845 .55221 L p
1 g
F P
s
P
p
.002 w
.55845 .55221 m .54912 .526 L p
.55877 .55174 L 1 g
F P
s
P
p
.002 w
.53036 .53973 m .53868 .53181 L .55827 .55246 L p
1 g
F P
s
P
p
.002 w
.55812 .55265 m .53036 .53973 L p
.55827 .55246 L 1 g
F P
s
P
p
.55799 .55284 m .55813 .55267 L .5582 .55258 L 1 g
F
P
p
.002 w
.55781 .55305 m .5587 .55292 L .55751 .55341 L p
1 g
F P
s
P
p
.55751 .55341 m .55791 .55294 L .55799 .55284 L 1 g
F
P
p
.55791 .55294 m .55813 .55267 L .55799 .55284 L 1 g
F
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52549 .56656 m .52341 .55813 L .55781 .55305 L p
1 g
F P
s
P
p
.002 w
.55751 .55341 m .52549 .56656 L p
.55781 .55305 L 1 g
F P
s
P
p
.002 w
.53103 .57324 m .52549 .56656 L .55751 .55341 L p
1 g
F P
s
P
p
.002 w
.55751 .55341 m .5587 .55292 L .55665 .55443 L p
1 g
F P
s
P
p
.002 w
.55665 .55443 m .53103 .57324 L p
.55751 .55341 L 1 g
F P
s
P
p
.55665 .55443 m .55807 .55277 L .55813 .55267 L 1 g
F
P
p
.002 w
.57157 .52297 m .57706 .52477 L p
.5617 .54744 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5617 .54744 L p
1 g
F P
s
P
p
.56654 .52734 m .5617 .54744 L .56173 .54733 L 1 g
F
P
p
.002 w
.56349 .54178 m .56768 .53202 L p
.5617 .54744 L 1 g
F P
s
P
p
.002 w
.56768 .53202 m .57157 .52297 L p
.5677 .53256 L 1 g
F P
s
P
p
.5677 .53256 m .5617 .54744 L .56768 .53202 L 1 g
F
P
p
.002 w
.57157 .52297 m .56735 .52296 L p
.56616 .51059 L 1 g
F P
s
P
p
.002 w
.56797 .52942 m .56854 .53025 L p
.56738 .52274 L 1 g
F P
s
P
p
.56723 .52178 m .56741 .5236 L .56738 .52274 L 1 g
F
P
p
.56741 .5236 m .56797 .52942 L .56738 .52274 L 1 g
F
P
p
.56654 .52734 m .5617 .54745 L .56448 .53864 L 1 g
F
P
p
.002 w
.55995 .55002 m .56349 .54178 L p
.5617 .54744 L 1 g
F P
s
P
p
.002 w
.5617 .54744 m .5617 .54745 L p
.56173 .54733 L 1 g
F P
s
P
p
.002 w
.56768 .53202 m .56349 .54178 L p
.56756 .52883 L 1 g
F P
s
P
p
.002 w
.58104 .52607 m .58791 .53186 L .56032 .55175 L p
1 g
F P
s
P
p
.002 w
.56032 .55175 m .5587 .55292 L .56073 .55048 L p
1 g
F P
s
P
p
.002 w
.56073 .55048 m .58104 .52607 L p
.56032 .55175 L 1 g
F P
s
P
p
.002 w
.5617 .54745 m .56171 .54747 L p
.56448 .53864 L 1 g
F P
s
P
p
.002 w
.56171 .54747 m .56257 .5491 L p
.56436 .53927 L 1 g
F P
s
P
p
.56448 .53864 m .56171 .54747 L .56436 .53927 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56735 .52296 m .56756 .52883 L .55995 .55002 L 1 g
F
P
p
.002 w
.56349 .54178 m .55995 .55002 L p
.56756 .52883 L 1 g
F P
s
P
p
.56448 .53864 m .56447 .53868 L .56756 .52883 L 1 g
F
P
p
.56447 .53868 m .56257 .5491 L .56749 .52915 L 1 g
F
P
p
.56447 .53868 m .56749 .52915 L .56756 .52883 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56758 .52885 L p
1 g
F P
s
P
p
.002 w
.56758 .52885 m .56756 .52883 L p
.56749 .52915 L 1 g
F P
s
P
p
.56749 .52915 m .56257 .5491 L .56758 .52885 L 1 g
F
P
p
.002 w
.5587 .55292 m .55995 .55002 L p
.5614 .54837 L 1 g
F P
s
P
p
.002 w
.56073 .55048 m .5587 .55292 L p
.5614 .54837 L 1 g
F P
s
P
p
.002 w
.5617 .54745 m .5617 .54744 L p
.56157 .54763 L 1 g
F P
s
P
p
.002 w
.5587 .55292 m .55247 .56085 L p
.54988 .56235 L 1 g
F P
s
P
p
.002 w
.55665 .55443 m .5587 .55292 L p
.54988 .56235 L 1 g
F P
s
P
p
.002 w
.53315 .57432 m .53103 .57324 L p
.55247 .56085 L 1 g
F P
s
P
p
.55458 .55685 m .55163 .56219 L .55807 .55277 L 1 g
F
P
p
.002 w
.53103 .57324 m .55665 .55443 L p
.54988 .56235 L 1 g
F P
s
P
p
.002 w
.54922 .56312 m .54998 .56518 L p
.55458 .55685 L 1 g
F P
s
P
p
.002 w
.53184 .57523 m .5322 .57686 L p
.53955 .56986 L 1 g
F P
s
P
p
.002 w
.53103 .57324 m .53315 .57432 L p
.5318 .57503 L 1 g
F P
s
P
p
.52989 .57557 m .53103 .57324 L .5318 .57503 L 1 g
F
P
p
.002 w
.54998 .56518 m .54923 .56314 L p
.53949 .57099 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54773 .56666 L p
.53949 .57099 L 1 g
F P
s
P
p
.002 w
.54773 .56666 m .54998 .56518 L p
.53949 .57099 L 1 g
F P
s
P
p
.53899 .57039 m .5322 .57686 L .54923 .56314 L 1 g
F
P
p
.002 w
.5587 .55292 m .56052 .52294 L .56735 .52296 L p
1 g
F P
s
P
p
.002 w
.5715 .57287 m .56075 .57726 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.5808 .56614 m .5715 .57287 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.56075 .57726 m .54967 .57886 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.58766 .55777 m .5808 .56614 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.59136 .54863 m .58766 .55777 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.59146 .53967 m .59136 .54863 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.58791 .53186 m .59146 .53967 L .5587 .55292 L closepath p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5617 .54745 L p
1 g
F P
s
P
p
.55163 .56219 m .54998 .56518 L .5617 .54745 L 1 g
F
P
p
.56735 .52296 m .55995 .55002 L .55924 .55106 L 1 g
F
P
p
.002 w
.56756 .52883 m .56797 .52942 L p
.56744 .52544 L 1 g
F P
s
P
p
.002 w
.56049 .49434 m .5605 .49762 L p
.55757 .49152 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55757 .49152 L p
1 g
F P
s
P
p
.002 w
.55757 .49152 m .55661 .4905 L p
.56233 .50144 L 1 g
F P
s
P
p
.56233 .50144 m .56713 .51061 L .55757 .49152 L 1 g
F
P
p
.002 w
.56049 .48944 m .56049 .49434 L p
.55757 .49152 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55757 .49152 L p
1 g
F P
s
P
p
.54174 .47608 m .55757 .49152 L .55696 .49093 L 1 g
F
P
p
.002 w
.55651 .4905 m .55701 .49036 L p
.55757 .49152 L 1 g
F P
s
P
p
.002 w
.55701 .49036 m .56049 .48944 L p
.55757 .49152 L 1 g
F P
s
P
p
.002 w
.56052 .52294 m .5605 .49762 L p
.56616 .51059 L 1 g
F P
s
P
p
.002 w
.56735 .52296 m .56052 .52294 L p
.56616 .51059 L 1 g
F P
s
P
p
.5694 .51641 m .57157 .52297 L .5605 .49762 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56604 .50931 L p
1 g
F P
s
P
p
.56723 .52178 m .56854 .53025 L .56604 .50931 L 1 g
F
P
p
.002 w
.56604 .50931 m .5662 .50951 L p
.56503 .5072 L 1 g
F P
s
P
p
.002 w
.5662 .50951 m .56713 .51061 L p
.56233 .50144 L 1 g
F P
s
P
p
.55651 .4905 m .55757 .49152 L .56052 .52294 L 1 g
F
P
p
.002 w
.5605 .49762 m .56052 .52294 L p
.55757 .49152 L 1 g
F P
s
P
p
.002 w
.55757 .49152 m .55764 .49159 L p
.55696 .49093 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53779 .49546 m .55651 .4905 L p
.56052 .52294 L 1 g
F P
s
P
p
.54174 .47608 m .55764 .49159 L .54996 .48413 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54224 .47663 m .54723 .48147 L .52797 .4699 L 1 g
F
P
p
.002 w
.53779 .49546 m .52797 .4699 L p
.54723 .48147 L 1 g
F P
s
P
p
.002 w
.55651 .4905 m .53779 .49546 L p
.54723 .48147 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54224 .47663 L p
1 g
F P
s
P
p
.002 w
.54224 .47663 m .54174 .47608 L p
.54996 .48413 L 1 g
F P
s
P
p
.54996 .48413 m .55834 .49233 L .54224 .47663 L 1 g
F
P
p
.002 w
.56049 .48944 m .55651 .4905 L p
.54723 .48147 L 1 g
F P
s
P
p
.5461 .47845 m .56049 .48944 L .54723 .48147 L 1 g
F
P
p
.5461 .47845 m .54723 .48147 L .54224 .47663 L 1 g
F
P
p
.002 w
.55764 .49159 m .55834 .49233 L p
.54996 .48413 L 1 g
F P
s
P
p
.002 w
.54224 .47663 m .54256 .47698 L p
.53656 .47395 L 1 g
F P
s
P
p
.52214 .46667 m .54224 .47663 L .53656 .47395 L 1 g
F
P
p
.52214 .46667 m .54256 .47698 L .53447 .47305 L 1 g
F
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52797 .4699 m .53779 .49546 L p
.52248 .46724 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52248 .46724 L p
1 g
F P
s
P
p
.002 w
.52248 .46724 m .52214 .46667 L p
.53447 .47305 L 1 g
F P
s
P
p
.53447 .47305 m .54302 .47747 L .52248 .46724 L 1 g
F
P
p
.002 w
.52508 .46238 m .5272 .4679 L p
.52248 .46724 L 1 g
F P
s
P
p
.5 .4634 m .52248 .46724 L .51995 .46688 L 1 g
F
P
p
.5 .4634 m .52254 .46734 L .51084 .46548 L 1 g
F
P
p
.002 w
.51762 .46656 m .51922 .46566 L p
.52248 .46724 L 1 g
F P
s
P
p
.002 w
.51922 .46566 m .52508 .46238 L p
.52248 .46724 L 1 g
F P
s
P
p
.002 w
.52797 .4699 m .52508 .46238 L p
.5461 .47845 L 1 g
F P
s
P
p
.002 w
.5272 .4679 m .52797 .4699 L p
.52248 .46724 L 1 g
F P
s
P
p
.002 w
.54256 .47698 m .54302 .47747 L p
.53447 .47305 L 1 g
F P
s
P
p
.002 w
.52248 .46724 m .52254 .46734 L p
.51995 .46688 L 1 g
F P
s
P
p
.002 w
.49443 .47954 m .51762 .46656 L p
.53779 .49546 L 1 g
F P
s
P
p
.5 .46377 m .5039 .46439 L .48419 .46626 L 1 g
F
P
p
.002 w
.49443 .47954 m .48419 .46626 L p
.5039 .46439 L 1 g
F P
s
P
p
.002 w
.51762 .46656 m .49443 .47954 L p
.5039 .46439 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46377 L p
1 g
F P
s
P
p
.002 w
.5 .46377 m .5 .4634 L p
.51084 .46548 L 1 g
F P
s
P
p
.51084 .46548 m .52282 .46778 L .5 .46377 L 1 g
F
P
p
.002 w
.52508 .46238 m .51762 .46656 L p
.5039 .46439 L 1 g
F P
s
P
p
.51845 .46087 m .52508 .46238 L .5039 .46439 L 1 g
F
P
p
.51845 .46087 m .5039 .46439 L .5 .46377 L 1 g
F
P
p
.002 w
.52254 .46734 m .52282 .46778 L p
.51084 .46548 L 1 g
F P
s
P
p
.4883 .46561 m .49251 .46518 L .48419 .46626 L 1 g
F
P
p
.4883 .46561 m .48419 .46626 L .4776 .46711 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46421 L p
1 g
F P
s
P
p
.002 w
.5 .46421 m .5 .46442 L p
.49251 .46518 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46421 L .49251 .46518 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .46711 L p
1 g
F P
s
P
p
.002 w
.4776 .46711 m .47718 .46778 L p
.46515 .47306 L 1 g
F P
s
P
p
.45826 .47608 m .4776 .46711 L .46515 .47306 L 1 g
F
P
p
.002 w
.47743 .45748 m .48289 .46457 L p
.4776 .46711 L 1 g
F P
s
P
p
.45782 .47657 m .46599 .46861 L .4776 .46711 L 1 g
F
P
p
.46599 .46861 m .47743 .45748 L .4776 .46711 L 1 g
F
P
p
.002 w
.48419 .46626 m .47186 .45026 L p
.51845 .46087 L 1 g
F P
s
P
p
.002 w
.48289 .46457 m .48419 .46626 L p
.4776 .46711 L 1 g
F P
s
P
p
.002 w
.48419 .46626 m .49443 .47954 L p
.4776 .46711 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .46711 L p
1 g
F P
s
P
p
.49251 .46518 m .5 .46442 L .4776 .46711 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45782 .47657 L p
1 g
F P
s
P
p
.46515 .47306 m .47718 .46778 L .45782 .47657 L 1 g
F
P
p
.002 w
.45782 .47657 m .45725 .47718 L p
.45169 .48253 L 1 g
F P
s
P
p
.44339 .4905 m .45782 .47657 L .45169 .48253 L 1 g
F
P
p
.002 w
.44095 .48078 m .47186 .45026 L .47743 .45748 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.44095 .48078 m .47743 .45748 L .45379 .48048 L 1 g
F
P
p
.44339 .4905 m .45725 .47718 L .45241 .48185 L 1 g
F
P
p
.002 w
.4459 .48453 m .448 .48611 L p
.44268 .49125 L 1 g
F P
s
P
p
.002 w
.448 .48611 m .47034 .50301 L p
.44268 .49125 L 1 g
F P
s
P
p
.002 w
.45725 .47718 m .45698 .47747 L p
.45241 .48185 L 1 g
F P
s
P
p
.002 w
.448 .48611 m .44095 .48078 L p
.45379 .48048 L 1 g
F P
s
P
p
.002 w
.44268 .49125 m .44166 .49233 L p
.43747 .50212 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44268 .49125 L p
1 g
F P
s
P
p
.45241 .48185 m .45698 .47747 L .44268 .49125 L 1 g
F
P
p
.002 w
.44095 .48078 m .4459 .48453 L p
.44268 .49125 L 1 g
F P
s
P
p
.43745 .49631 m .44095 .48078 L .44268 .49125 L 1 g
F
P
p
.002 w
.43601 .49002 m .44095 .48078 L p
.43377 .51262 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43412 .50913 L p
1 g
F P
s
P
p
.43747 .50212 m .44166 .49233 L .43412 .50913 L 1 g
F
P
p
.002 w
.43412 .50913 m .43287 .51061 L p
.43316 .51878 L 1 g
F P
s
P
p
.002 w
.47034 .50301 m .4556 .52986 L .43302 .52019 L p
1 g
F P
s
P
p
.43377 .51262 m .47034 .50301 L .43302 .52019 L 1 g
F
P
p
.002 w
.43302 .52019 m .4556 .52986 L p
.43226 .54261 L 1 g
F P
s
P
p
.41783 .55048 m .43302 .52019 L .43226 .54261 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43274 .52839 L p
1 g
F P
s
P
p
.43312 .51746 m .43287 .51061 L .43274 .52839 L 1 g
F
P
p
.002 w
.43274 .52839 m .43146 .53025 L p
.43643 .54009 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43858 .54691 L p
1 g
F P
s
P
p
.43643 .54009 m .43146 .53025 L .43858 .54691 L 1 g
F
P
p
.44386 .55469 m .44338 .55427 L .44441 .5555 L 1 g
F
P
p
.002 w
.4556 .52986 m .45167 .55687 L .44441 .5555 L p
1 g
F P
s
P
p
.002 w
.42728 .58139 m .41783 .55048 L .45167 .55687 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56309 L p
1 g
F P
s
P
p
.44338 .55427 m .43743 .5491 L .45079 .56309 L 1 g
F
P
p
.002 w
.45079 .56309 m .45067 .56342 L p
.4525 .56436 L 1 g
F P
s
P
p
.002 w
.45545 .57006 m .45167 .55687 L p
.46766 .57418 L 1 g
F P
s
P
p
.002 w
.45067 .56342 m .45002 .56518 L p
.45973 .56906 L 1 g
F P
s
P
p
.002 w
.45167 .55687 m .48729 .55946 L p
.4678 .57407 L 1 g
F P
s
P
p
.46766 .57418 m .46724 .57372 L .4678 .57407 L 1 g
F
P
p
.46724 .57372 m .45167 .55687 L .4678 .57407 L 1 g
F
P
p
.002 w
.45859 .58098 m .45545 .57006 L p
.46766 .57418 L 1 g
F P
s
P
p
.002 w
.46834 .57441 m .46819 .57509 L p
.47251 .57581 L 1 g
F P
s
P
p
.48921 .57862 m .46834 .57441 L .47251 .57581 L 1 g
F
P
p
.002 w
.46819 .57509 m .4678 .57686 L p
.47787 .57769 L 1 g
F P
s
P
p
.48921 .57862 m .46819 .57509 L .47787 .57769 L 1 g
F
P
p
.002 w
.47519 .59969 m .45859 .58098 L .47882 .57794 L p
1 g
F P
s
P
p
.002 w
.47882 .57794 m .49171 .57601 L p
.48854 .58055 L 1 g
F P
s
P
p
.47519 .59969 m .47882 .57794 L .48854 .58055 L 1 g
F
P
p
.46766 .57418 m .48729 .55946 L .47882 .57794 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .57441 L p
1 g
F P
s
P
p
.45973 .56906 m .45002 .56518 L .46834 .57441 L 1 g
F
P
p
.47813 .57771 m .47787 .57769 L .47882 .57794 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48729 .55946 m .49171 .57601 L .47882 .57794 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58228 L p
1 g
F P
s
P
p
.49741 .58129 m .48889 .583 L .51106 .58228 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .58069 L p
1 g
F P
s
P
p
.47787 .57769 m .4678 .57686 L .48906 .58069 L 1 g
F
P
p
.002 w
.39175 .4989 m .38698 .54059 L .36011 .52766 L p
1 g
F P
s
P
p
.002 w
.36011 .52766 m .36489 .48036 L .39175 .4989 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51381 .4593 L
s
P
p
.004 w
.52973 .4925 m
.54563 .52566 L
s
P
p
.002 w
.64046 .39864 m .66915 .42643 L .65569 .45405 L p
1 g
F P
s
P
p
.002 w
.66915 .42643 m .64046 .39864 L .64523 .36766 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.58898 .29182 m .52532 .28796 L .51586 .26598 L p
1 g
F P
s
P
p
.002 w
.44847 .28213 m .51586 .26598 L .52532 .28796 L p
1 g
F P
s
P
p
.002 w
.52532 .28796 m .58898 .29182 L .59515 .31826 L p
1 g
F P
s
P
p
.002 w
.62064 .5409 m .62112 .52328 L .64667 .5044 L p
1 g
F P
s
P
p
.002 w
.63726 .48149 m .64667 .5044 L .62112 .52328 L p
1 g
F P
s
P
p
.002 w
.64667 .5044 m .63726 .48149 L .65569 .45405 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.58766 .55777 m .59136 .54863 L .62064 .5409 L p
1 g
F P
s
P
p
.002 w
.62112 .52328 m .62064 .5409 L .59136 .54863 L p
1 g
F P
s
P
p
.002 w
.38898 .43278 m .36489 .48036 L .34264 .46073 L p
1 g
F P
s
P
p
.002 w
.34264 .46073 m .3683 .40887 L .38898 .43278 L p
1 g
F P
s
P
p
.002 w
.45877 .30408 m .39831 .33841 L .38734 .31691 L p
1 g
F P
s
P
p
.002 w
.38734 .31691 m .44847 .28213 L .45877 .30408 L p
1 g
F P
s
P
p
.002 w
.59857 .34882 m .64523 .36766 L .64046 .39864 L p
1 g
F P
s
P
p
.002 w
.64523 .36766 m .59857 .34882 L .59515 .31826 L p
1 g
F P
s
P
p
.002 w
.42235 .51562 m .41783 .55048 L .38698 .54059 L p
1 g
F P
s
P
p
.002 w
.38698 .54059 m .39175 .4989 L .42235 .51562 L p
1 g
F P
s
P
p
.002 w
.63131 .43116 m .65569 .45405 L .63726 .48149 L p
1 g
F P
s
P
p
.002 w
.65569 .45405 m .63131 .43116 L .64046 .39864 L p
1 g
F P
s
P
p
.002 w
.52532 .28796 m .45877 .30408 L .44847 .28213 L p
1 g
F P
s
P
p
.002 w
.41275 .36339 m .3683 .40887 L .35207 .38619 L p
1 g
F P
s
P
p
.002 w
.35207 .38619 m .39831 .33841 L .41275 .36339 L p
1 g
F P
s
P
p
.002 w
.59136 .54863 m .59146 .53967 L .62112 .52328 L p
1 g
F P
s
P
p
.002 w
.61441 .50775 m .62112 .52328 L .59146 .53967 L p
1 g
F P
s
P
p
.002 w
.62112 .52328 m .61441 .50775 L .63726 .48149 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.53429 .31497 m .59515 .31826 L .59857 .34882 L p
1 g
F P
s
P
p
.002 w
.59515 .31826 m .53429 .31497 L .52532 .28796 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.61804 .46404 m .63726 .48149 L .61441 .50775 L p
1 g
F P
s
P
p
.002 w
.63726 .48149 m .61804 .46404 L .63131 .43116 L p
1 g
F P
s
P
p
.002 w
.52341 .55813 m .52549 .56656 L .49171 .57601 L p
1 g
F P
s
P
p
.002 w
.49171 .57601 m .48729 .55946 L .52341 .55813 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.45877 .30408 m .52532 .28796 L .53429 .31497 L p
1 g
F P
s
P
p
.002 w
.59903 .38249 m .64046 .39864 L .63131 .43116 L p
1 g
F P
s
P
p
.002 w
.64046 .39864 m .59903 .38249 L .59857 .34882 L p
1 g
F P
s
P
p
.002 w
.41348 .45706 m .39175 .4989 L .36489 .48036 L p
1 g
F P
s
P
p
.002 w
.36489 .48036 m .38898 .43278 L .41348 .45706 L p
1 g
F P
s
P
p
.002 w
.59146 .53967 m .58791 .53186 L .61441 .50775 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60108 .49608 m .61441 .50775 L .58791 .53186 L p
1 g
F P
s
P
p
.002 w
.61441 .50775 m .60108 .49608 L .61804 .46404 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.47065 .33059 m .41275 .36339 L .39831 .33841 L p
1 g
F P
s
P
p
.002 w
.39831 .33841 m .45877 .30408 L .47065 .33059 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49028 .54108 m .48729 .55946 L .45167 .55687 L p
1 g
F P
s
P
p
.002 w
.45167 .55687 m .4556 .52986 L .49028 .54108 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.58791 .53186 m .58104 .52607 L .60108 .49608 L p
1 g
F P
s
P
p
.002 w
.43023 .39104 m .38898 .43278 L .3683 .40887 L p
1 g
F P
s
P
p
.002 w
.3683 .40887 m .41275 .36339 L .43023 .39104 L p
1 g
F P
s
P
p
.002 w
.53429 .31497 m .47065 .33059 L .45877 .30408 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59643 .41809 m .63131 .43116 L .61804 .46404 L p
1 g
F P
s
P
p
.002 w
.63131 .43116 m .59643 .41809 L .59903 .38249 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52508 .54885 m .52341 .55813 L .48729 .55946 L p
1 g
F P
s
P
p
.002 w
.48729 .55946 m .49028 .54108 L .52508 .54885 L p
1 g
F P
s
P
p
.002 w
.44095 .48078 m .42235 .51562 L .39175 .4989 L p
1 g
F P
s
P
p
.002 w
.39175 .4989 m .41348 .45706 L .44095 .48078 L p
1 g
F P
s
P
p
.002 w
.54241 .3462 m .59857 .34882 L .59903 .38249 L p
1 g
F P
s
P
p
.002 w
.59857 .34882 m .54241 .3462 L .53429 .31497 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58104 .52607 m .57157 .52297 L .58242 .48969 L p
1 g
F P
s
P
p
.002 w
.58242 .48969 m .60108 .49608 L .58104 .52607 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59082 .45429 m .61804 .46404 L .60108 .49608 L p
1 g
F P
s
P
p
.002 w
.61804 .46404 m .59082 .45429 L .59643 .41809 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53036 .53973 m .52508 .54885 L .49028 .54108 L p
1 g
F P
s
P
p
.002 w
.47065 .33059 m .53429 .31497 L .54241 .3462 L p
1 g
F P
s
P
p
.002 w
.60108 .49608 m .58242 .48969 L .59082 .45429 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.56049 .48944 m .58242 .48969 L .57157 .52297 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53868 .53181 m .53036 .53973 L .50053 .52291 L p
1 g
F P
s
P
p
.002 w
.49028 .54108 m .50053 .52291 L .53036 .53973 L p
1 g
F P
s
P
p
.002 w
.45019 .42037 m .41348 .45706 L .38898 .43278 L p
1 g
F P
s
P
p
.002 w
.38898 .43278 m .43023 .39104 L .45019 .42037 L p
1 g
F P
s
P
p
.002 w
.50053 .52291 m .49028 .54108 L .4556 .52986 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56052 .52294 m .54912 .526 L .53779 .49546 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.48372 .36082 m .43023 .39104 L .41275 .36339 L p
1 g
F P
s
P
p
.002 w
.41275 .36339 m .47065 .33059 L .48372 .36082 L p
1 g
F P
s
P
p
.002 w
.54935 .3806 m .59903 .38249 L .59643 .41809 L p
1 g
F P
s
P
p
.002 w
.59903 .38249 m .54935 .3806 L .54241 .3462 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.4556 .52986 m .47034 .50301 L .50053 .52291 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.54912 .526 m .53868 .53181 L .51699 .50707 L p
1 g
F P
s
P
p
.002 w
.50053 .52291 m .51699 .50707 L .53868 .53181 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51699 .50707 m .53779 .49546 L .54912 .526 L p
1 g
F P
s
P
p
.002 w
.54241 .3462 m .48372 .36082 L .47065 .33059 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58242 .48969 m .56049 .48944 L .55857 .45363 L p
1 g
F P
s
P
p
.002 w
.55857 .45363 m .59082 .45429 L .58242 .48969 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55481 .41687 m .59643 .41809 L .59082 .45429 L p
1 g
F P
s
P
p
.002 w
.59643 .41809 m .55481 .41687 L .54935 .3806 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.48372 .36082 m .54241 .3462 L .54935 .3806 L p
1 g
F P
s
P
p
.002 w
.59082 .45429 m .55857 .45363 L .55481 .41687 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.51699 .50707 m .50053 .52291 L .47034 .50301 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47186 .45026 m .44095 .48078 L .41348 .45706 L p
1 g
F P
s
P
p
.002 w
.41348 .45706 m .45019 .42037 L .47186 .45026 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52508 .46238 m .55857 .45363 L .56049 .48944 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.4975 .39371 m .45019 .42037 L .43023 .39104 L p
1 g
F P
s
P
p
.002 w
.43023 .39104 m .48372 .36082 L .4975 .39371 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.53779 .49546 m .51699 .50707 L .49443 .47954 L p
1 g
F P
s
P
p
.002 w
.47034 .50301 m .49443 .47954 L .51699 .50707 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54935 .3806 m .4975 .39371 L .48372 .36082 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.4975 .39371 m .54935 .3806 L .55481 .41687 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.55857 .45363 m .52508 .46238 L .51147 .42801 L p
1 g
F P
s
P
p
.002 w
.51147 .42801 m .55481 .41687 L .55857 .45363 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55481 .41687 m .51147 .42801 L .4975 .39371 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51147 .42801 m .47186 .45026 L .45019 .42037 L p
1 g
F P
s
P
p
.002 w
.45019 .42037 m .4975 .39371 L .51147 .42801 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.47186 .45026 m .51147 .42801 L .52508 .46238 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.57857 .59434 m
.58289 .60336 L
s
P
p
.004 w
.58289 .60336 m
.59341 .6253 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .61815 .69619 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .59341 .6253 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.450388)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.450388)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.55512 .42171 m .51752 .43909 L .5259 .46617 L p
1 g
F P
s
P
p
.002 w
.47893 .47528 m .5259 .46617 L .51752 .43909 L p
1 g
F P
s
P
p
.002 w
.51752 .43909 m .47636 .44705 L .47893 .47528 L p
1 g
F P
s
P
p
.002 w
.51752 .43909 m .55512 .42171 L .54006 .39726 L p
1 g
F P
s
P
p
.002 w
.54006 .39726 m .50874 .41189 L .51752 .43909 L p
1 g
F P
s
P
p
.002 w
.47636 .44705 m .51752 .43909 L .50874 .41189 L p
1 g
F P
s
P
p
.002 w
.50874 .41189 m .47438 .41852 L .47636 .44705 L p
1 g
F P
s
P
p
.002 w
.50874 .41189 m .54006 .39726 L .52402 .3736 L p
1 g
F P
s
P
p
.002 w
.52402 .3736 m .49972 .38505 L .50874 .41189 L p
1 g
F P
s
P
p
.002 w
.47438 .41852 m .50874 .41189 L .49972 .38505 L p
1 g
F P
s
P
p
.002 w
.43537 .44485 m .47636 .44705 L .47438 .41852 L p
1 g
F P
s
P
p
.002 w
.47438 .41852 m .44018 .41651 L .43537 .44485 L p
1 g
F P
s
P
p
.002 w
.44018 .41651 m .47438 .41852 L .47301 .39018 L p
1 g
F P
s
P
p
.002 w
.49972 .38505 m .47301 .39018 L .47438 .41852 L p
1 g
F P
s
P
p
.002 w
.4321 .473 m .47893 .47528 L .47636 .44705 L p
1 g
F P
s
P
p
.002 w
.47636 .44705 m .43537 .44485 L .4321 .473 L p
1 g
F P
s
P
p
.002 w
.48203 .50269 m .53372 .49262 L .5259 .46617 L p
1 g
F P
s
P
p
.002 w
.5259 .46617 m .47893 .47528 L .48203 .50269 L p
1 g
F P
s
P
p
.002 w
.5689 .44648 m .5259 .46617 L .53372 .49262 L p
1 g
F P
s
P
p
.002 w
.5259 .46617 m .5689 .44648 L .55512 .42171 L p
1 g
F P
s
P
p
.002 w
.49972 .38505 m .52402 .3736 L .50726 .35114 L p
1 g
F P
s
P
p
.002 w
.50726 .35114 m .49062 .35906 L .49972 .38505 L p
1 g
F P
s
P
p
.002 w
.47301 .39018 m .49972 .38505 L .49062 .35906 L p
1 g
F P
s
P
p
.002 w
.47301 .39018 m .44646 .38849 L .44018 .41651 L p
1 g
F P
s
P
p
.002 w
.44646 .38849 m .47301 .39018 L .47228 .36257 L p
1 g
F P
s
P
p
.002 w
.49062 .35906 m .47228 .36257 L .47301 .39018 L p
1 g
F P
s
P
p
.002 w
.43047 .50042 m .48203 .50269 L .47893 .47528 L p
1 g
F P
s
P
p
.002 w
.47893 .47528 m .4321 .473 L .43047 .50042 L p
1 g
F P
s
P
p
.002 w
.56536 .37592 m .54006 .39726 L .55512 .42171 L p
1 g
F P
s
P
p
.002 w
.54006 .39726 m .56536 .37592 L .5435 .35688 L p
1 g
F P
s
P
p
.002 w
.5435 .35688 m .52402 .3736 L .54006 .39726 L p
1 g
F P
s
P
p
.002 w
.58566 .39634 m .55512 .42171 L .5689 .44648 L p
1 g
F P
s
P
p
.002 w
.55512 .42171 m .58566 .39634 L .56536 .37592 L p
1 g
F P
s
P
p
.002 w
.39831 .43247 m .43537 .44485 L .44018 .41651 L p
1 g
F P
s
P
p
.002 w
.44018 .41651 m .40941 .40591 L .39831 .43247 L p
1 g
F P
s
P
p
.002 w
.40941 .40591 m .44018 .41651 L .44646 .38849 L p
1 g
F P
s
P
p
.002 w
.52402 .3736 m .5435 .35688 L .52051 .33959 L p
1 g
F P
s
P
p
.002 w
.52051 .33959 m .50726 .35114 L .52402 .3736 L p
1 g
F P
s
P
p
.002 w
.38964 .45924 m .4321 .473 L .43537 .44485 L p
1 g
F P
s
P
p
.002 w
.43537 .44485 m .39831 .43247 L .38964 .45924 L p
1 g
F P
s
P
p
.002 w
.44646 .38849 m .42267 .38006 L .40941 .40591 L p
1 g
F P
s
P
p
.002 w
.42267 .38006 m .44646 .38849 L .45408 .36133 L p
1 g
F P
s
P
p
.002 w
.47228 .36257 m .45408 .36133 L .44646 .38849 L p
1 g
F P
s
P
p
.002 w
.58114 .47112 m .53372 .49262 L .54084 .51797 L p
1 g
F P
s
P
p
.002 w
.48562 .52875 m .54084 .51797 L .53372 .49262 L p
1 g
F P
s
P
p
.002 w
.53372 .49262 m .48203 .50269 L .48562 .52875 L p
1 g
F P
s
P
p
.002 w
.53372 .49262 m .58114 .47112 L .5689 .44648 L p
1 g
F P
s
P
p
.002 w
.60403 .41778 m .5689 .44648 L .58114 .47112 L p
1 g
F P
s
P
p
.002 w
.5689 .44648 m .60403 .41778 L .58566 .39634 L p
1 g
F P
s
P
p
.002 w
.49062 .35906 m .50726 .35114 L .4901 .33033 L p
1 g
F P
s
P
p
.002 w
.4901 .33033 m .48161 .33441 L .49062 .35906 L p
1 g
F P
s
P
p
.002 w
.47228 .36257 m .49062 .35906 L .48161 .33441 L p
1 g
F P
s
P
p
.002 w
.45408 .36133 m .47228 .36257 L .47223 .3362 L p
1 g
F P
s
P
p
.002 w
.48161 .33441 m .47223 .3362 L .47228 .36257 L p
1 g
F P
s
P
p
.002 w
.43054 .52657 m .48562 .52875 L .48203 .50269 L p
1 g
F P
s
P
p
.002 w
.48203 .50269 m .43047 .50042 L .43054 .52657 L p
1 g
F P
s
P
p
.002 w
.50726 .35114 m .52051 .33959 L .49681 .32439 L p
1 g
F P
s
P
p
.002 w
.49681 .32439 m .4901 .33033 L .50726 .35114 L p
1 g
F P
s
P
p
.002 w
.38359 .48568 m .43047 .50042 L .4321 .473 L p
1 g
F P
s
P
p
.002 w
.4321 .473 m .38964 .45924 L .38359 .48568 L p
1 g
F P
s
P
p
.002 w
.45408 .36133 m .43786 .3554 L .42267 .38006 L p
1 g
F P
s
P
p
.002 w
.43786 .3554 m .45408 .36133 L .46293 .33552 L p
1 g
F P
s
P
p
.002 w
.47223 .3362 m .46293 .33552 L .45408 .36133 L p
1 g
F P
s
P
p
.002 w
.58199 .34974 m .56536 .37592 L .58566 .39634 L p
1 g
F P
s
P
p
.002 w
.56536 .37592 m .58199 .34974 L .55613 .33646 L p
1 g
F P
s
P
p
.002 w
.55613 .33646 m .5435 .35688 L .56536 .37592 L p
1 g
F P
s
P
p
.002 w
.5435 .35688 m .55613 .33646 L .52896 .32554 L p
1 g
F P
s
P
p
.002 w
.52896 .32554 m .52051 .33959 L .5435 .35688 L p
1 g
F P
s
P
p
.002 w
.54084 .51797 m .59157 .49517 L .58114 .47112 L p
1 g
F P
s
P
p
.002 w
.62005 .43983 m .58114 .47112 L .59157 .49517 L p
1 g
F P
s
P
p
.002 w
.58114 .47112 m .62005 .43983 L .60403 .41778 L p
1 g
F P
s
P
p
.002 w
.60603 .36515 m .58566 .39634 L .60403 .41778 L p
1 g
F P
s
P
p
.002 w
.58566 .39634 m .60603 .36515 L .58199 .34974 L p
1 g
F P
s
P
p
.002 w
.38517 .38749 m .40941 .40591 L .42267 .38006 L p
1 g
F P
s
P
p
.002 w
.42267 .38006 m .40412 .36556 L .38517 .38749 L p
1 g
F P
s
P
p
.002 w
.40412 .36556 m .42267 .38006 L .43786 .3554 L p
1 g
F P
s
P
p
.002 w
.52051 .33959 m .52896 .32554 L .50102 .3172 L p
1 g
F P
s
P
p
.002 w
.50102 .3172 m .49681 .32439 L .52051 .33959 L p
1 g
F P
s
P
p
.002 w
.36892 .41073 m .39831 .43247 L .40941 .40591 L p
1 g
F P
s
P
p
.002 w
.40941 .40591 m .38517 .38749 L .36892 .41073 L p
1 g
F P
s
P
p
.002 w
.48965 .55292 m .5471 .54167 L .54084 .51797 L p
1 g
F P
s
P
p
.002 w
.54084 .51797 m .48562 .52875 L .48965 .55292 L p
1 g
F P
s
P
p
.002 w
.59157 .49517 m .54084 .51797 L .5471 .54167 L p
1 g
F P
s
P
p
.002 w
.43786 .3554 m .42533 .34534 L .40412 .36556 L p
1 g
F P
s
P
p
.002 w
.42533 .34534 m .43786 .3554 L .45469 .33243 L p
1 g
F P
s
P
p
.002 w
.46293 .33552 m .45469 .33243 L .43786 .3554 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .48161 .33441 L .4901 .33033 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .47223 .3362 L .48161 .33441 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .46293 .33552 L .47223 .3362 L closepath p
1 g
F P
s
P
p
.002 w
.38037 .51125 m .43054 .52657 L .43047 .50042 L p
1 g
F P
s
P
p
.002 w
.43047 .50042 m .38359 .48568 L .38037 .51125 L p
1 g
F P
s
P
p
.002 w
.43236 .5509 m .48965 .55292 L .48562 .52875 L p
1 g
F P
s
P
p
.002 w
.48562 .52875 m .43054 .52657 L .43236 .5509 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .4901 .33033 L .49681 .32439 L closepath p
1 g
F P
s
P
p
.002 w
.35573 .43482 m .38964 .45924 L .39831 .43247 L p
1 g
F P
s
P
p
.002 w
.39831 .43247 m .36892 .41073 L .35573 .43482 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .45469 .33243 L .46293 .33552 L closepath p
1 g
F P
s
P
p
.002 w
.62772 .3824 m .60403 .41778 L .62005 .43983 L p
1 g
F P
s
P
p
.002 w
.60403 .41778 m .62772 .3824 L .60603 .36515 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .49681 .32439 L .50102 .3172 L closepath p
1 g
F P
s
P
p
.002 w
.45469 .33243 m .4484 .32724 L .42533 .34534 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .4484 .32724 L .45469 .33243 L closepath p
1 g
F P
s
P
p
.002 w
.53163 .3104 m .52896 .32554 L .55613 .33646 L p
1 g
F P
s
P
p
.002 w
.52896 .32554 m .53163 .3104 L .50225 .30951 L p
1 g
F P
s
P
p
.002 w
.50225 .30951 m .50102 .3172 L .52896 .32554 L p
1 g
F P
s
P
p
.002 w
.56039 .31431 m .55613 .33646 L .58199 .34974 L p
1 g
F P
s
P
p
.002 w
.55613 .33646 m .56039 .31431 L .53163 .3104 L p
1 g
F P
s
P
p
.002 w
.5471 .54167 m .59994 .51813 L .59157 .49517 L p
1 g
F P
s
P
p
.002 w
.63336 .46205 m .59157 .49517 L .59994 .51813 L p
1 g
F P
s
P
p
.002 w
.59157 .49517 m .63336 .46205 L .62005 .43983 L p
1 g
F P
s
P
p
.002 w
.39288 .3463 m .40412 .36556 L .42533 .34534 L p
1 g
F P
s
P
p
.002 w
.42533 .34534 m .41789 .3321 L .39288 .3463 L p
1 g
F P
s
P
p
.002 w
.41789 .3321 m .42533 .34534 L .4484 .32724 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .50102 .3172 L .50225 .30951 L closepath p
1 g
F P
s
P
p
.002 w
.34597 .45926 m .38359 .48568 L .38964 .45924 L p
1 g
F P
s
P
p
.002 w
.38964 .45924 m .35573 .43482 L .34597 .45926 L p
1 g
F P
s
P
p
.002 w
.58794 .32119 m .58199 .34974 L .60603 .36515 L p
1 g
F P
s
P
p
.002 w
.58199 .34974 m .58794 .32119 L .56039 .31431 L p
1 g
F P
s
P
p
.002 w
.4484 .32724 m .44474 .32047 L .41789 .3321 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .44474 .32047 L .4484 .32724 L closepath p
1 g
F P
s
P
p
.002 w
.37025 .36282 m .38517 .38749 L .40412 .36556 L p
1 g
F P
s
P
p
.002 w
.40412 .36556 m .39288 .3463 L .37025 .36282 L p
1 g
F P
s
P
p
.002 w
.38013 .53538 m .43236 .5509 L .43054 .52657 L p
1 g
F P
s
P
p
.002 w
.43054 .52657 m .38037 .51125 L .38013 .53538 L p
1 g
F P
s
P
p
.002 w
.64655 .40118 m .62005 .43983 L .63336 .46205 L p
1 g
F P
s
P
p
.002 w
.62005 .43983 m .64655 .40118 L .62772 .3824 L p
1 g
F P
s
P
p
.002 w
.49405 .57466 m .55234 .56322 L .5471 .54167 L p
1 g
F P
s
P
p
.002 w
.5471 .54167 m .48965 .55292 L .49405 .57466 L p
1 g
F P
s
P
p
.002 w
.59994 .51813 m .5471 .54167 L .55234 .56322 L p
1 g
F P
s
P
p
.002 w
.50034 .30214 m .50225 .30951 L .53163 .3104 L p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .50225 .30951 L .50034 .30214 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .50034 .30214 L .49544 .2959 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .49544 .2959 L .48808 .2915 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .48808 .2915 L .47904 .28944 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .47904 .28944 L .46932 .28998 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .46932 .28998 L .46003 .29306 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .46003 .29306 L .45221 .29832 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .45221 .29832 L .44672 .30517 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .44672 .30517 L .44414 .31284 L closepath p
1 g
F P
s
P
p
.002 w
.47286 .31162 m .44414 .31284 L .44474 .32047 L closepath p
1 g
F P
s
P
p
.002 w
.35054 .38135 m .36892 .41073 L .38517 .38749 L p
1 g
F P
s
P
p
.002 w
.38517 .38749 m .37025 .36282 L .35054 .38135 L p
1 g
F P
s
P
p
.002 w
.43595 .57282 m .49405 .57466 L .48965 .55292 L p
1 g
F P
s
P
p
.002 w
.48965 .55292 m .43236 .5509 L .43595 .57282 L p
1 g
F P
s
P
p
.002 w
.41647 .31704 m .41789 .3321 L .44474 .32047 L p
1 g
F P
s
P
p
.002 w
.44474 .32047 m .44414 .31284 L .41647 .31704 L p
1 g
F P
s
P
p
.002 w
.52809 .29578 m .53163 .3104 L .56039 .31431 L p
1 g
F P
s
P
p
.002 w
.53163 .3104 m .52809 .29578 L .50034 .30214 L p
1 g
F P
s
P
p
.002 w
.61369 .33095 m .60603 .36515 L .62772 .3824 L p
1 g
F P
s
P
p
.002 w
.60603 .36515 m .61369 .33095 L .58794 .32119 L p
1 g
F P
s
P
p
.002 w
.39045 .3242 m .39288 .3463 L .41789 .3321 L p
1 g
F P
s
P
p
.002 w
.41789 .3321 m .41647 .31704 L .39045 .3242 L p
1 g
F P
s
P
p
.002 w
.49544 .2959 m .50034 .30214 L .52809 .29578 L p
1 g
F P
s
P
p
.002 w
.33997 .48353 m .38037 .51125 L .38359 .48568 L p
1 g
F P
s
P
p
.002 w
.38359 .48568 m .34597 .45926 L .33997 .48353 L p
1 g
F P
s
P
p
.002 w
.42138 .30178 m .41647 .31704 L .44414 .31284 L p
1 g
F P
s
P
p
.002 w
.44414 .31284 m .44672 .30517 L .42138 .30178 L p
1 g
F P
s
P
p
.002 w
.55553 .29275 m .56039 .31431 L .58794 .32119 L p
1 g
F P
s
P
p
.002 w
.56039 .31431 m .55553 .29275 L .52809 .29578 L p
1 g
F P
s
P
p
.002 w
.33428 .40156 m .35573 .43482 L .36892 .41073 L p
1 g
F P
s
P
p
.002 w
.36892 .41073 m .35054 .38135 L .33428 .40156 L p
1 g
F P
s
P
p
.002 w
.55234 .56322 m .606 .53949 L .59994 .51813 L p
1 g
F P
s
P
p
.002 w
.6436 .48401 m .59994 .51813 L .606 .53949 L p
1 g
F P
s
P
p
.002 w
.59994 .51813 m .6436 .48401 L .63336 .46205 L p
1 g
F P
s
P
p
.002 w
.52809 .29578 m .51856 .2833 L .49544 .2959 L p
1 g
F P
s
P
p
.002 w
.48808 .2915 m .49544 .2959 L .51856 .2833 L p
1 g
F P
s
P
p
.002 w
.43222 .28804 m .42138 .30178 L .44672 .30517 L p
1 g
F P
s
P
p
.002 w
.44672 .30517 m .45221 .29832 L .43222 .28804 L p
1 g
F P
s
P
p
.002 w
.36669 .33424 m .37025 .36282 L .39288 .3463 L p
1 g
F P
s
P
p
.002 w
.39288 .3463 m .39045 .3242 L .36669 .33424 L p
1 g
F P
s
P
p
.002 w
.63701 .34346 m .62772 .3824 L .64655 .40118 L p
1 g
F P
s
P
p
.002 w
.62772 .3824 m .63701 .34346 L .61369 .33095 L p
1 g
F P
s
P
p
.002 w
.66205 .42114 m .63336 .46205 L .6436 .48401 L p
1 g
F P
s
P
p
.002 w
.63336 .46205 m .66205 .42114 L .64655 .40118 L p
1 g
F P
s
P
p
.002 w
.51856 .2833 m .52809 .29578 L .55553 .29275 L p
1 g
F P
s
P
p
.002 w
.383 .55747 m .43595 .57282 L .43236 .5509 L p
1 g
F P
s
P
p
.002 w
.43236 .5509 m .38013 .53538 L .383 .55747 L p
1 g
F P
s
P
p
.002 w
.51856 .2833 m .50399 .27441 L .48808 .2915 L p
1 g
F P
s
P
p
.002 w
.47904 .28944 m .48808 .2915 L .50399 .27441 L p
1 g
F P
s
P
p
.002 w
.58208 .29319 m .58794 .32119 L .61369 .33095 L p
1 g
F P
s
P
p
.002 w
.58794 .32119 m .58208 .29319 L .55553 .29275 L p
1 g
F P
s
P
p
.002 w
.44783 .27744 m .43222 .28804 L .45221 .29832 L p
1 g
F P
s
P
p
.002 w
.45221 .29832 m .46003 .29306 L .44783 .27744 L p
1 g
F P
s
P
p
.002 w
.39744 .30161 m .39045 .3242 L .41647 .31704 L p
1 g
F P
s
P
p
.002 w
.41647 .31704 m .42138 .30178 L .39744 .30161 L p
1 g
F P
s
P
p
.002 w
.50399 .27441 m .48594 .27021 L .47904 .28944 L p
1 g
F P
s
P
p
.002 w
.46932 .28998 m .47904 .28944 L .48594 .27021 L p
1 g
F P
s
P
p
.002 w
.49874 .59338 m .5564 .58204 L .55234 .56322 L p
1 g
F P
s
P
p
.002 w
.55234 .56322 m .49405 .57466 L .49874 .59338 L p
1 g
F P
s
P
p
.002 w
.606 .53949 m .55234 .56322 L .5564 .58204 L p
1 g
F P
s
P
p
.002 w
.46646 .27125 m .44783 .27744 L .46003 .29306 L p
1 g
F P
s
P
p
.002 w
.46003 .29306 m .46932 .28998 L .46646 .27125 L p
1 g
F P
s
P
p
.002 w
.48594 .27021 m .46646 .27125 L .46932 .28998 L p
1 g
F P
s
P
p
.002 w
.44132 .59175 m .49874 .59338 L .49405 .57466 L p
1 g
F P
s
P
p
.002 w
.49405 .57466 m .43595 .57282 L .44132 .59175 L p
1 g
F P
s
P
p
.002 w
.338 .50706 m .38013 .53538 L .38037 .51125 L p
1 g
F P
s
P
p
.002 w
.38037 .51125 m .33997 .48353 L .338 .50706 L p
1 g
F P
s
P
p
.002 w
.32195 .42302 m .34597 .45926 L .35573 .43482 L p
1 g
F P
s
P
p
.002 w
.35573 .43482 m .33428 .40156 L .32195 .42302 L p
1 g
F P
s
P
p
.002 w
.34582 .34705 m .35054 .38135 L .37025 .36282 L p
1 g
F P
s
P
p
.002 w
.37025 .36282 m .36669 .33424 L .34582 .34705 L p
1 g
F P
s
P
p
.002 w
.55553 .29275 m .54174 .27418 L .51856 .2833 L p
1 g
F P
s
P
p
.002 w
.50399 .27441 m .51856 .2833 L .54174 .27418 L p
1 g
F P
s
P
p
.002 w
.54174 .27418 m .55553 .29275 L .58208 .29319 L p
1 g
F P
s
P
p
.002 w
.65731 .35852 m .64655 .40118 L .66205 .42114 L p
1 g
F P
s
P
p
.002 w
.64655 .40118 m .65731 .35852 L .63701 .34346 L p
1 g
F P
s
P
p
.002 w
.41336 .28113 m .39744 .30161 L .42138 .30178 L p
1 g
F P
s
P
p
.002 w
.42138 .30178 m .43222 .28804 L .41336 .28113 L p
1 g
F P
s
P
p
.002 w
.6071 .2972 m .61369 .33095 L .63701 .34346 L p
1 g
F P
s
P
p
.002 w
.61369 .33095 m .6071 .2972 L .58208 .29319 L p
1 g
F P
s
P
p
.002 w
.5564 .58204 m .60951 .55871 L .606 .53949 L p
1 g
F P
s
P
p
.002 w
.65041 .5052 m .606 .53949 L .60951 .55871 L p
1 g
F P
s
P
p
.002 w
.606 .53949 m .65041 .5052 L .6436 .48401 L p
1 g
F P
s
P
p
.002 w
.37548 .3048 m .36669 .33424 L .39045 .3242 L p
1 g
F P
s
P
p
.002 w
.39045 .3242 m .39744 .30161 L .37548 .3048 L p
1 g
F P
s
P
p
.002 w
.67373 .44186 m .6436 .48401 L .65041 .5052 L p
1 g
F P
s
P
p
.002 w
.6436 .48401 m .67373 .44186 L .66205 .42114 L p
1 g
F P
s
P
p
.002 w
.38905 .57691 m .44132 .59175 L .43595 .57282 L p
1 g
F P
s
P
p
.002 w
.43595 .57282 m .383 .55747 L .38905 .57691 L p
1 g
F P
s
P
p
.002 w
.54174 .27418 m .52028 .26085 L .50399 .27441 L p
1 g
F P
s
P
p
.002 w
.48594 .27021 m .50399 .27441 L .52028 .26085 L p
1 g
F P
s
P
p
.002 w
.31401 .44527 m .33997 .48353 L .34597 .45926 L p
1 g
F P
s
P
p
.002 w
.34597 .45926 m .32195 .42302 L .31401 .44527 L p
1 g
F P
s
P
p
.002 w
.32844 .36243 m .33428 .40156 L .35054 .38135 L p
1 g
F P
s
P
p
.002 w
.35054 .38135 m .34582 .34705 L .32844 .36243 L p
1 g
F P
s
P
p
.002 w
.43656 .26527 m .41336 .28113 L .43222 .28804 L p
1 g
F P
s
P
p
.002 w
.43222 .28804 m .44783 .27744 L .43656 .26527 L p
1 g
F P
s
P
p
.002 w
.34029 .52926 m .383 .55747 L .38013 .53538 L p
1 g
F P
s
P
p
.002 w
.38013 .53538 m .338 .50706 L .34029 .52926 L p
1 g
F P
s
P
p
.002 w
.56445 .26889 m .58208 .29319 L .6071 .2972 L p
1 g
F P
s
P
p
.002 w
.58208 .29319 m .56445 .26889 L .54174 .27418 L p
1 g
F P
s
P
p
.002 w
.52028 .26085 m .49345 .25449 L .48594 .27021 L p
1 g
F P
s
P
p
.002 w
.46646 .27125 m .48594 .27021 L .49345 .25449 L p
1 g
F P
s
P
p
.002 w
.60951 .55871 m .5564 .58204 L .55913 .59758 L p
1 g
F P
s
P
p
.002 w
.50364 .60852 m .55913 .59758 L .5564 .58204 L p
1 g
F P
s
P
p
.002 w
.5564 .58204 m .49874 .59338 L .50364 .60852 L p
1 g
F P
s
P
p
.002 w
.46437 .256 m .43656 .26527 L .44783 .27744 L p
1 g
F P
s
P
p
.002 w
.44783 .27744 m .46646 .27125 L .46437 .256 L p
1 g
F P
s
P
p
.002 w
.52028 .26085 m .54174 .27418 L .56445 .26889 L p
1 g
F P
s
P
p
.002 w
.67401 .37588 m .66205 .42114 L .67373 .44186 L p
1 g
F P
s
P
p
.002 w
.66205 .42114 m .67401 .37588 L .65731 .35852 L p
1 g
F P
s
P
p
.002 w
.62997 .30482 m .63701 .34346 L .65731 .35852 L p
1 g
F P
s
P
p
.002 w
.63701 .34346 m .62997 .30482 L .6071 .2972 L p
1 g
F P
s
P
p
.002 w
.49345 .25449 m .46437 .256 L .46646 .27125 L p
1 g
F P
s
P
p
.002 w
.44843 .6071 m .50364 .60852 L .49874 .59338 L p
1 g
F P
s
P
p
.002 w
.49874 .59338 m .44132 .59175 L .44843 .6071 L p
1 g
F P
s
P
p
.002 w
.35612 .31144 m .34582 .34705 L .36669 .33424 L p
1 g
F P
s
P
p
.002 w
.36669 .33424 m .37548 .3048 L .35612 .31144 L p
1 g
F P
s
P
p
.002 w
.39612 .27794 m .37548 .3048 L .39744 .30161 L p
1 g
F P
s
P
p
.002 w
.39744 .30161 m .41336 .28113 L .39612 .27794 L p
1 g
F P
s
P
p
.002 w
.60951 .55871 m .65349 .52511 L .65041 .5052 L p
1 g
F P
s
P
p
.002 w
.68116 .4629 m .65041 .5052 L .65349 .52511 L p
1 g
F P
s
P
p
.002 w
.65041 .5052 m .68116 .4629 L .67373 .44186 L p
1 g
F P
s
P
p
.002 w
.31513 .38011 m .32195 .42302 L .33428 .40156 L p
1 g
F P
s
P
p
.002 w
.33428 .40156 m .32844 .36243 L .31513 .38011 L p
1 g
F P
s
P
p
.002 w
.31084 .4678 m .338 .50706 L .33997 .48353 L p
1 g
F P
s
P
p
.002 w
.33997 .48353 m .31401 .44527 L .31084 .4678 L p
1 g
F P
s
P
p
.002 w
.55913 .59758 m .61026 .57525 L .60951 .55871 L p
1 g
F P
s
P
p
.002 w
.65349 .52511 m .60951 .55871 L .61026 .57525 L p
1 g
F P
s
P
p
.002 w
.56445 .26889 m .53658 .25132 L .52028 .26085 L p
1 g
F P
s
P
p
.002 w
.49345 .25449 m .52028 .26085 L .53658 .25132 L p
1 g
F P
s
P
p
.002 w
.58615 .26772 m .6071 .2972 L .62997 .30482 L p
1 g
F P
s
P
p
.002 w
.6071 .2972 m .58615 .26772 L .56445 .26889 L p
1 g
F P
s
P
p
.002 w
.3983 .59309 m .44843 .6071 L .44132 .59175 L p
1 g
F P
s
P
p
.002 w
.44132 .59175 m .38905 .57691 L .3983 .59309 L p
1 g
F P
s
P
p
.002 w
.34697 .5495 m .38905 .57691 L .383 .55747 L p
1 g
F P
s
P
p
.002 w
.383 .55747 m .34029 .52926 L .34697 .5495 L p
1 g
F P
s
P
p
.002 w
.42654 .25703 m .39612 .27794 L .41336 .28113 L p
1 g
F P
s
P
p
.002 w
.41336 .28113 m .43656 .26527 L .42654 .25703 L p
1 g
F P
s
P
p
.002 w
.65004 .31602 m .65731 .35852 L .67401 .37588 L p
1 g
F P
s
P
p
.002 w
.65731 .35852 m .65004 .31602 L .62997 .30482 L p
1 g
F P
s
P
p
.002 w
.53658 .25132 m .56445 .26889 L .58615 .26772 L p
1 g
F P
s
P
p
.002 w
.68653 .3952 m .67373 .44186 L .68116 .4629 L p
1 g
F P
s
P
p
.002 w
.67373 .44186 m .68653 .3952 L .67401 .37588 L p
1 g
F P
s
P
p
.002 w
.33998 .32153 m .32844 .36243 L .34582 .34705 L p
1 g
F P
s
P
p
.002 w
.34582 .34705 m .35612 .31144 L .33998 .32153 L p
1 g
F P
s
P
p
.002 w
.53658 .25132 m .50142 .24286 L .49345 .25449 L p
1 g
F P
s
P
p
.002 w
.46437 .256 m .49345 .25449 L .50142 .24286 L p
1 g
F P
s
P
p
.002 w
.38104 .27874 m .35612 .31144 L .37548 .3048 L p
1 g
F P
s
P
p
.002 w
.37548 .3048 m .39612 .27794 L .38104 .27874 L p
1 g
F P
s
P
p
.002 w
.46315 .24481 m .42654 .25703 L .43656 .26527 L p
1 g
F P
s
P
p
.002 w
.43656 .26527 m .46437 .256 L .46315 .24481 L p
1 g
F P
s
P
p
.002 w
.50863 .6195 m .56039 .60929 L .55913 .59758 L p
1 g
F P
s
P
p
.002 w
.55913 .59758 m .50364 .60852 L .50863 .6195 L p
1 g
F P
s
P
p
.002 w
.61026 .57525 m .55913 .59758 L .56039 .60929 L p
1 g
F P
s
P
p
.002 w
.45721 .61828 m .50863 .6195 L .50364 .60852 L p
1 g
F P
s
P
p
.002 w
.50364 .60852 m .44843 .6071 L .45721 .61828 L p
1 g
F P
s
P
p
.002 w
.50142 .24286 m .46315 .24481 L .46437 .256 L p
1 g
F P
s
P
p
.002 w
.30645 .39974 m .31401 .44527 L .32195 .42302 L p
1 g
F P
s
P
p
.002 w
.32195 .42302 m .31513 .38011 L .30645 .39974 L p
1 g
F P
s
P
p
.002 w
.31277 .49002 m .34029 .52926 L .338 .50706 L p
1 g
F P
s
P
p
.002 w
.338 .50706 m .31084 .4678 L .31277 .49002 L p
1 g
F P
s
P
p
.002 w
.61026 .57525 m .65257 .54318 L .65349 .52511 L p
1 g
F P
s
P
p
.002 w
.68397 .48374 m .65349 .52511 L .65257 .54318 L p
1 g
F P
s
P
p
.002 w
.65349 .52511 m .68397 .48374 L .68116 .4629 L p
1 g
F P
s
P
p
.002 w
.60625 .27088 m .62997 .30482 L .65004 .31602 L p
1 g
F P
s
P
p
.002 w
.62997 .30482 m .60625 .27088 L .58615 .26772 L p
1 g
F P
s
P
p
.002 w
.56039 .60929 m .60808 .58854 L .61026 .57525 L p
1 g
F P
s
P
p
.002 w
.65257 .54318 m .61026 .57525 L .60808 .58854 L p
1 g
F P
s
P
p
.002 w
.66666 .33067 m .67401 .37588 L .68653 .3952 L p
1 g
F P
s
P
p
.002 w
.67401 .37588 m .66666 .33067 L .65004 .31602 L p
1 g
F P
s
P
p
.002 w
.58615 .26772 m .55249 .24625 L .53658 .25132 L p
1 g
F P
s
P
p
.002 w
.50142 .24286 m .53658 .25132 L .55249 .24625 L p
1 g
F P
s
P
p
.002 w
.35809 .56714 m .3983 .59309 L .38905 .57691 L p
1 g
F P
s
P
p
.002 w
.38905 .57691 m .34697 .5495 L .35809 .56714 L p
1 g
F P
s
P
p
.002 w
.41067 .60542 m .45721 .61828 L .44843 .6071 L p
1 g
F P
s
P
p
.002 w
.44843 .6071 m .3983 .59309 L .41067 .60542 L p
1 g
F P
s
P
p
.002 w
.69438 .41609 m .68116 .4629 L .68397 .48374 L p
1 g
F P
s
P
p
.002 w
.68116 .4629 m .69438 .41609 L .68653 .3952 L p
1 g
F P
s
P
p
.002 w
.55249 .24625 m .58615 .26772 L .60625 .27088 L p
1 g
F P
s
P
p
.002 w
.32767 .33499 m .31513 .38011 L .32844 .36243 L p
1 g
F P
s
P
p
.002 w
.32844 .36243 m .33998 .32153 L .32767 .33499 L p
1 g
F P
s
P
p
.002 w
.4181 .25317 m .38104 .27874 L .39612 .27794 L p
1 g
F P
s
P
p
.002 w
.39612 .27794 m .42654 .25703 L .4181 .25317 L p
1 g
F P
s
P
p
.002 w
.30285 .42088 m .31084 .4678 L .31401 .44527 L p
1 g
F P
s
P
p
.002 w
.31401 .44527 m .30645 .39974 L .30285 .42088 L p
1 g
F P
s
P
p
.002 w
.36862 .28375 m .33998 .32153 L .35612 .31144 L p
1 g
F P
s
P
p
.002 w
.35612 .31144 m .38104 .27874 L .36862 .28375 L p
1 g
F P
s
P
p
.002 w
.55249 .24625 m .50968 .23585 L .50142 .24286 L p
1 g
F P
s
P
p
.002 w
.46315 .24481 m .50142 .24286 L .50968 .23585 L p
1 g
F P
s
P
p
.002 w
.31996 .51129 m .34697 .5495 L .34029 .52926 L p
1 g
F P
s
P
p
.002 w
.34029 .52926 m .31277 .49002 L .31996 .51129 L p
1 g
F P
s
P
p
.002 w
.46289 .2382 m .4181 .25317 L .42654 .25703 L p
1 g
F P
s
P
p
.002 w
.42654 .25703 m .46315 .24481 L .46289 .2382 L p
1 g
F P
s
P
p
.002 w
.5136 .62579 m .56006 .61662 L .56039 .60929 L p
1 g
F P
s
P
p
.002 w
.56039 .60929 m .50863 .6195 L .5136 .62579 L p
1 g
F P
s
P
p
.002 w
.60808 .58854 m .56039 .60929 L .56006 .61662 L p
1 g
F P
s
P
p
.002 w
.62414 .27852 m .65004 .31602 L .66666 .33067 L p
1 g
F P
s
P
p
.002 w
.65004 .31602 m .62414 .27852 L .60625 .27088 L p
1 g
F P
s
P
p
.002 w
.46752 .62475 m .5136 .62579 L .50863 .6195 L p
1 g
F P
s
P
p
.002 w
.50863 .6195 m .45721 .61828 L .46752 .62475 L p
1 g
F P
s
P
p
.002 w
.50968 .23585 m .46289 .2382 L .46315 .24481 L p
1 g
F P
s
P
p
.002 w
.60808 .58854 m .64746 .55886 L .65257 .54318 L p
1 g
F P
s
P
p
.002 w
.68184 .50383 m .65257 .54318 L .64746 .55886 L p
1 g
F P
s
P
p
.002 w
.65257 .54318 m .68184 .50383 L .68397 .48374 L p
1 g
F P
s
P
p
.002 w
.67923 .34854 m .68653 .3952 L .69438 .41609 L p
1 g
F P
s
P
p
.002 w
.68653 .3952 m .67923 .34854 L .66666 .33067 L p
1 g
F P
s
P
p
.004 w
.49209 .62072 m
.5 .43051 L
s
P
p
.004 w
.48809 .71718 m
.4919 .6253 L
s
P
p
.002 w
.56006 .61662 m .60285 .59805 L .60808 .58854 L p
1 g
F P
s
P
p
.002 w
.64746 .55886 m .60808 .58854 L .60285 .59805 L p
1 g
F P
s
P
p
.002 w
.6971 .43805 m .68397 .48374 L .68184 .50383 L p
1 g
F P
s
P
p
.002 w
.68397 .48374 m .6971 .43805 L .69438 .41609 L p
1 g
F P
s
P
p
.002 w
.60625 .27088 m .56758 .24604 L .55249 .24625 L p
1 g
F P
s
P
p
.002 w
.50968 .23585 m .55249 .24625 L .56758 .24604 L p
1 g
F P
s
P
p
.002 w
.31973 .35162 m .30645 .39974 L .31513 .38011 L p
1 g
F P
s
P
p
.002 w
.31513 .38011 m .32767 .33499 L .31973 .35162 L p
1 g
F P
s
P
p
.002 w
.56758 .24604 m .60625 .27088 L .62414 .27852 L p
1 g
F P
s
P
p
.002 w
.37356 .58156 m .41067 .60542 L .3983 .59309 L p
1 g
F P
s
P
p
.002 w
.3983 .59309 m .35809 .56714 L .37356 .58156 L p
1 g
F P
s
P
p
.002 w
.426 .61332 m .46752 .62475 L .45721 .61828 L p
1 g
F P
s
P
p
.002 w
.45721 .61828 m .41067 .60542 L .426 .61332 L p
1 g
F P
s
P
p
.002 w
.3047 .443 m .31277 .49002 L .31084 .4678 L p
1 g
F P
s
P
p
.002 w
.31084 .4678 m .30285 .42088 L .3047 .443 L p
1 g
F P
s
P
p
.002 w
.41158 .25407 m .36862 .28375 L .38104 .27874 L p
1 g
F P
s
P
p
.002 w
.38104 .27874 m .4181 .25317 L .41158 .25407 L p
1 g
F P
s
P
p
.002 w
.35939 .29308 m .32767 .33499 L .33998 .32153 L p
1 g
F P
s
P
p
.002 w
.33998 .32153 m .36862 .28375 L .35939 .29308 L p
1 g
F P
s
P
p
.002 w
.33248 .53097 m .35809 .56714 L .34697 .5495 L p
1 g
F P
s
P
p
.002 w
.34697 .5495 m .31996 .51129 L .33248 .53097 L p
1 g
F P
s
P
p
.002 w
.63921 .29067 m .66666 .33067 L .67923 .34854 L p
1 g
F P
s
P
p
.002 w
.66666 .33067 m .63921 .29067 L .62414 .27852 L p
1 g
F P
s
P
p
.002 w
.56758 .24604 m .51802 .23395 L .50968 .23585 L p
1 g
F P
s
P
p
.002 w
.46289 .2382 m .50968 .23585 L .51802 .23395 L p
1 g
F P
s
P
p
.002 w
.69438 .41609 m .68719 .3693 L .67923 .34854 L p
1 g
F P
s
P
p
.002 w
.68719 .3693 m .69438 .41609 L .6971 .43805 L p
1 g
F P
s
P
p
.002 w
.46364 .23667 m .41158 .25407 L .4181 .25317 L p
1 g
F P
s
P
p
.002 w
.4181 .25317 m .46289 .2382 L .46364 .23667 L p
1 g
F P
s
P
p
.002 w
.60285 .59805 m .63805 .57158 L .64746 .55886 L p
1 g
F P
s
P
p
.002 w
.67458 .52258 m .64746 .55886 L .63805 .57158 L p
1 g
F P
s
P
p
.002 w
.64746 .55886 m .67458 .52258 L .68184 .50383 L p
1 g
F P
s
P
p
.002 w
.5184 .62692 m .55805 .61909 L .56006 .61662 L p
1 g
F P
s
P
p
.002 w
.56006 .61662 m .5136 .62579 L .5184 .62692 L p
1 g
F P
s
P
p
.002 w
.60285 .59805 m .56006 .61662 L .55805 .61909 L p
1 g
F P
s
P
p
.004 w
.54632 .63343 m
.55213 .65888 L
s
P
p
.002 w
.47917 .62603 m .5184 .62692 L .5136 .62579 L p
1 g
F P
s
P
p
.002 w
.5136 .62579 m .46752 .62475 L .47917 .62603 L p
1 g
F P
s
P
p
.002 w
.51802 .23395 m .46364 .23667 L .46289 .2382 L p
1 g
F P
s
P
p
.002 w
.31665 .37112 m .30285 .42088 L .30645 .39974 L p
1 g
F P
s
P
p
.002 w
.30645 .39974 m .31973 .35162 L .31665 .37112 L p
1 g
F P
s
P
p
.002 w
.68184 .50383 m .69439 .46051 L .6971 .43805 L p
1 g
F P
s
P
p
.002 w
.69439 .46051 m .68184 .50383 L .67458 .52258 L p
1 g
F P
s
P
p
.002 w
.62414 .27852 m .58138 .25097 L .56758 .24604 L p
1 g
F P
s
P
p
.002 w
.58138 .25097 m .62414 .27852 L .63921 .29067 L p
1 g
F P
s
P
p
.002 w
.39315 .59217 m .426 .61332 L .41067 .60542 L p
1 g
F P
s
P
p
.002 w
.41067 .60542 m .37356 .58156 L .39315 .59217 L p
1 g
F P
s
P
p
.002 w
.51802 .23395 m .56758 .24604 L .58138 .25097 L p
1 g
F P
s
P
p
.002 w
.31221 .46548 m .31996 .51129 L .31277 .49002 L p
1 g
F P
s
P
p
.002 w
.31277 .49002 m .3047 .443 L .31221 .46548 L p
1 g
F P
s
P
p
.002 w
.55805 .61909 m .59451 .60327 L .60285 .59805 L p
1 g
F P
s
P
p
.002 w
.63805 .57158 m .60285 .59805 L .59451 .60327 L p
1 g
F P
s
P
p
.002 w
.44401 .61633 m .47917 .62603 L .46752 .62475 L p
1 g
F P
s
P
p
.002 w
.46752 .62475 m .426 .61332 L .44401 .61633 L p
1 g
F P
s
P
p
.002 w
.40728 .26004 m .35939 .29308 L .36862 .28375 L p
1 g
F P
s
P
p
.002 w
.36862 .28375 m .41158 .25407 L .40728 .26004 L p
1 g
F P
s
P
p
.002 w
.3502 .54837 m .37356 .58156 L .35809 .56714 L p
1 g
F P
s
P
p
.002 w
.35809 .56714 m .33248 .53097 L .3502 .54837 L p
1 g
F P
s
P
p
.002 w
.35381 .30673 m .31973 .35162 L .32767 .33499 L p
1 g
F P
s
P
p
.002 w
.32767 .33499 m .35939 .29308 L .35381 .30673 L p
1 g
F P
s
P
p
.002 w
.67923 .34854 m .65087 .30721 L .63921 .29067 L p
1 g
F P
s
P
p
.002 w
.65087 .30721 m .67923 .34854 L .68719 .3693 L p
1 g
F P
s
P
p
.002 w
.69009 .39247 m .6971 .43805 L .69439 .46051 L p
1 g
F P
s
P
p
.002 w
.6971 .43805 m .69009 .39247 L .68719 .3693 L p
1 g
F P
s
P
p
.002 w
.58138 .25097 m .52621 .23753 L .51802 .23395 L p
1 g
F P
s
P
p
.002 w
.46364 .23667 m .51802 .23395 L .52621 .23753 L p
1 g
F P
s
P
p
.002 w
.31878 .39302 m .3047 .443 L .30285 .42088 L p
1 g
F P
s
P
p
.002 w
.30285 .42088 m .31665 .37112 L .31878 .39302 L p
1 g
F P
s
P
p
.002 w
.59451 .60327 m .62437 .58081 L .63805 .57158 L p
1 g
F P
s
P
p
.002 w
.63805 .57158 m .66212 .53938 L .67458 .52258 L p
1 g
F P
s
P
p
.002 w
.66212 .53938 m .63805 .57158 L .62437 .58081 L p
1 g
F P
s
P
p
.002 w
.68605 .48283 m .67458 .52258 L .66212 .53938 L p
1 g
F P
s
P
p
.002 w
.67458 .52258 m .68605 .48283 L .69439 .46051 L p
1 g
F P
s
P
p
.002 w
.46547 .2406 m .40728 .26004 L .41158 .25407 L p
1 g
F P
s
P
p
.002 w
.41158 .25407 m .46364 .23667 L .46547 .2406 L p
1 g
F P
s
P
p
.002 w
.32541 .48762 m .33248 .53097 L .31996 .51129 L p
1 g
F P
s
P
p
.002 w
.31996 .51129 m .31221 .46548 L .32541 .48762 L p
1 g
F P
s
P
p
.002 w
.59341 .26122 m .63921 .29067 L .65087 .30721 L p
1 g
F P
s
P
p
.002 w
.63921 .29067 m .59341 .26122 L .58138 .25097 L p
1 g
F P
s
P
p
.002 w
.59451 .60327 m .55805 .61909 L .55429 .61629 L p
1 g
F P
s
P
p
.002 w
.5229 .62249 m .55429 .61629 L .55805 .61909 L p
1 g
F P
s
P
p
.002 w
.55805 .61909 m .5184 .62692 L .5229 .62249 L p
1 g
F P
s
P
p
.002 w
.49191 .62177 m .5229 .62249 L .5184 .62692 L p
1 g
F P
s
P
p
.002 w
.5184 .62692 m .47917 .62603 L .49191 .62177 L p
1 g
F P
s
P
p
.002 w
.41646 .59845 m .44401 .61633 L .426 .61332 L p
1 g
F P
s
P
p
.002 w
.426 .61332 m .39315 .59217 L .41646 .59845 L p
1 g
F P
s
P
p
.002 w
.52621 .23753 m .46547 .2406 L .46364 .23667 L p
1 g
F P
s
P
p
.002 w
.52621 .23753 m .58138 .25097 L .59341 .26122 L p
1 g
F P
s
P
p
.002 w
.37278 .56284 m .39315 .59217 L .37356 .58156 L p
1 g
F P
s
P
p
.002 w
.37356 .58156 m .3502 .54837 L .37278 .56284 L p
1 g
F P
s
P
p
.002 w
.65859 .32788 m .68719 .3693 L .69009 .39247 L p
1 g
F P
s
P
p
.002 w
.68719 .3693 m .65859 .32788 L .65087 .30721 L p
1 g
F P
s
P
p
.002 w
.55429 .61629 m .58311 .60377 L .59451 .60327 L p
1 g
F P
s
P
p
.002 w
.62437 .58081 m .59451 .60327 L .58311 .60377 L p
1 g
F P
s
P
p
.002 w
.35228 .32453 m .31665 .37112 L .31973 .35162 L p
1 g
F P
s
P
p
.002 w
.31973 .35162 m .35381 .30673 L .35228 .32453 L p
1 g
F P
s
P
p
.002 w
.68758 .41746 m .69439 .46051 L .68605 .48283 L p
1 g
F P
s
P
p
.002 w
.69439 .46051 m .68758 .41746 L .69009 .39247 L p
1 g
F P
s
P
p
.002 w
.4643 .61408 m .49191 .62177 L .47917 .62603 L p
1 g
F P
s
P
p
.002 w
.47917 .62603 m .44401 .61633 L .4643 .61408 L p
1 g
F P
s
P
p
.002 w
.40549 .2712 m .35381 .30673 L .35939 .29308 L p
1 g
F P
s
P
p
.002 w
.35939 .29308 m .40728 .26004 L .40549 .2712 L p
1 g
F P
s
P
p
.002 w
.32632 .41673 m .31221 .46548 L .3047 .443 L p
1 g
F P
s
P
p
.002 w
.3047 .443 m .31878 .39302 L .32632 .41673 L p
1 g
F P
s
P
p
.002 w
.34412 .50869 m .3502 .54837 L .33248 .53097 L p
1 g
F P
s
P
p
.002 w
.33248 .53097 m .32541 .48762 L .34412 .50869 L p
1 g
F P
s
P
p
.002 w
.62437 .58081 m .64459 .55363 L .66212 .53938 L p
1 g
F P
s
P
p
.002 w
.67208 .50432 m .66212 .53938 L .64459 .55363 L p
1 g
F P
s
P
p
.002 w
.66212 .53938 m .67208 .50432 L .68605 .48283 L p
1 g
F P
s
P
p
.002 w
.58311 .60377 m .60659 .58605 L .62437 .58081 L p
1 g
F P
s
P
p
.002 w
.64459 .55363 m .62437 .58081 L .60659 .58605 L p
1 g
F P
s
P
p
.002 w
.60319 .27677 m .65087 .30721 L .65859 .32788 L p
1 g
F P
s
P
p
.002 w
.65087 .30721 m .60319 .27677 L .59341 .26122 L p
1 g
F P
s
P
p
.002 w
.59341 .26122 m .53399 .24686 L .52621 .23753 L p
1 g
F P
s
P
p
.002 w
.46547 .2406 m .52621 .23753 L .53399 .24686 L p
1 g
F P
s
P
p
.002 w
.44292 .59999 m .4643 .61408 L .44401 .61633 L p
1 g
F P
s
P
p
.002 w
.44401 .61633 m .41646 .59845 L .44292 .59999 L p
1 g
F P
s
P
p
.002 w
.46839 .25023 m .40549 .2712 L .40728 .26004 L p
1 g
F P
s
P
p
.002 w
.40728 .26004 m .46547 .2406 L .46839 .25023 L p
1 g
F P
s
P
p
.002 w
.66192 .35223 m .69009 .39247 L .68758 .41746 L p
1 g
F P
s
P
p
.002 w
.69009 .39247 m .66192 .35223 L .65859 .32788 L p
1 g
F P
s
P
p
.002 w
.3997 .57379 m .41646 .59845 L .39315 .59217 L p
1 g
F P
s
P
p
.002 w
.39315 .59217 m .37278 .56284 L .3997 .57379 L p
1 g
F P
s
P
p
.002 w
.58311 .60377 m .55429 .61629 L .54879 .60798 L p
1 g
F P
s
P
p
.002 w
.52692 .61229 m .54879 .60798 L .55429 .61629 L p
1 g
F P
s
P
p
.002 w
.55429 .61629 m .5229 .62249 L .52692 .61229 L p
1 g
F P
s
P
p
.002 w
.53399 .24686 m .59341 .26122 L .60319 .27677 L p
1 g
F P
s
P
p
.002 w
.50539 .61175 m .52692 .61229 L .5229 .62249 L p
1 g
F P
s
P
p
.002 w
.5229 .62249 m .49191 .62177 L .50539 .61175 L p
1 g
F P
s
P
p
.002 w
.67952 .44354 m .68605 .48283 L .67208 .50432 L p
1 g
F P
s
P
p
.002 w
.68605 .48283 m .67952 .44354 L .68758 .41746 L p
1 g
F P
s
P
p
.002 w
.53399 .24686 m .46839 .25023 L .46547 .2406 L p
1 g
F P
s
P
p
.002 w
.35507 .34612 m .31878 .39302 L .31665 .37112 L p
1 g
F P
s
P
p
.002 w
.31665 .37112 m .35228 .32453 L .35507 .34612 L p
1 g
F P
s
P
p
.002 w
.54879 .60798 m .56883 .59924 L .58311 .60377 L p
1 g
F P
s
P
p
.002 w
.60659 .58605 m .58311 .60377 L .56883 .59924 L p
1 g
F P
s
P
p
.002 w
.40642 .28753 m .35228 .32453 L .35381 .30673 L p
1 g
F P
s
P
p
.002 w
.35381 .30673 m .40549 .2712 L .40642 .28753 L p
1 g
F P
s
P
p
.002 w
.48634 .60635 m .50539 .61175 L .49191 .62177 L p
1 g
F P
s
P
p
.002 w
.49191 .62177 m .4643 .61408 L .48634 .60635 L p
1 g
F P
s
P
p
.002 w
.33927 .44155 m .32541 .48762 L .31221 .46548 L p
1 g
F P
s
P
p
.002 w
.31221 .46548 m .32632 .41673 L .33927 .44155 L p
1 g
F P
s
P
p
.002 w
.36791 .52794 m .37278 .56284 L .3502 .54837 L p
1 g
F P
s
P
p
.002 w
.3502 .54837 m .34412 .50869 L .36791 .52794 L p
1 g
F P
s
P
p
.002 w
.60659 .58605 m .62227 .56473 L .64459 .55363 L p
1 g
F P
s
P
p
.002 w
.65268 .52423 m .64459 .55363 L .62227 .56473 L p
1 g
F P
s
P
p
.002 w
.64459 .55363 m .65268 .52423 L .67208 .50432 L p
1 g
F P
s
P
p
.002 w
.61028 .29742 m .65859 .32788 L .66192 .35223 L p
1 g
F P
s
P
p
.002 w
.65859 .32788 m .61028 .29742 L .60319 .27677 L p
1 g
F P
s
P
p
.002 w
.56883 .59924 m .58503 .58691 L .60659 .58605 L p
1 g
F P
s
P
p
.002 w
.62227 .56473 m .60659 .58605 L .58503 .58691 L p
1 g
F P
s
P
p
.002 w
.66055 .37961 m .68758 .41746 L .67952 .44354 L p
1 g
F P
s
P
p
.002 w
.68758 .41746 m .66055 .37961 L .66192 .35223 L p
1 g
F P
s
P
p
.002 w
.4302 .58072 m .44292 .59999 L .41646 .59845 L p
1 g
F P
s
P
p
.002 w
.41646 .59845 m .3997 .57379 L .4302 .58072 L p
1 g
F P
s
P
p
.002 w
.66594 .46989 m .67208 .50432 L .65268 .52423 L p
1 g
F P
s
P
p
.002 w
.67208 .50432 m .66594 .46989 L .67952 .44354 L p
1 g
F P
s
P
p
.002 w
.47177 .59655 m .48634 .60635 L .4643 .61408 L p
1 g
F P
s
P
p
.002 w
.4643 .61408 m .44292 .59999 L .47177 .59655 L p
1 g
F P
s
P
p
.002 w
.60319 .27677 m .54109 .26198 L .53399 .24686 L p
1 g
F P
s
P
p
.002 w
.46839 .25023 m .53399 .24686 L .54109 .26198 L p
1 g
F P
s
P
p
.002 w
.47236 .26562 m .40642 .28753 L .40549 .2712 L p
1 g
F P
s
P
p
.002 w
.40549 .2712 m .46839 .25023 L .47236 .26562 L p
1 g
F P
s
P
p
.002 w
.54109 .26198 m .60319 .27677 L .61028 .29742 L p
1 g
F P
s
P
p
.002 w
.36233 .37095 m .32632 .41673 L .31878 .39302 L p
1 g
F P
s
P
p
.002 w
.31878 .39302 m .35507 .34612 L .36233 .37095 L p
1 g
F P
s
P
p
.002 w
.56883 .59924 m .54879 .60798 L .54161 .59405 L p
1 g
F P
s
P
p
.002 w
.53031 .59628 m .54161 .59405 L .54879 .60798 L p
1 g
F P
s
P
p
.002 w
.54879 .60798 m .52692 .61229 L .53031 .59628 L p
1 g
F P
s
P
p
.002 w
.51921 .59597 m .53031 .59628 L .52692 .61229 L p
1 g
F P
s
P
p
.002 w
.52692 .61229 m .50539 .61175 L .51921 .59597 L p
1 g
F P
s
P
p
.002 w
.35739 .46663 m .34412 .50869 L .32541 .48762 L p
1 g
F P
s
P
p
.002 w
.32541 .48762 m .33927 .44155 L .35739 .46663 L p
1 g
F P
s
P
p
.002 w
.39614 .54463 m .3997 .57379 L .37278 .56284 L p
1 g
F P
s
P
p
.002 w
.37278 .56284 m .36791 .52794 L .39614 .54463 L p
1 g
F P
s
P
p
.002 w
.54109 .26198 m .47236 .26562 L .46839 .25023 L p
1 g
F P
s
P
p
.002 w
.54161 .59405 m .55195 .58952 L .56883 .59924 L p
1 g
F P
s
P
p
.002 w
.58503 .58691 m .56883 .59924 L .55195 .58952 L p
1 g
F P
s
P
p
.002 w
.4102 .30878 m .35507 .34612 L .35228 .32453 L p
1 g
F P
s
P
p
.002 w
.35228 .32453 m .40642 .28753 L .4102 .30878 L p
1 g
F P
s
P
p
.002 w
.58503 .58691 m .59569 .57218 L .62227 .56473 L p
1 g
F P
s
P
p
.002 w
.62828 .54186 m .62227 .56473 L .59569 .57218 L p
1 g
F P
s
P
p
.002 w
.62227 .56473 m .62828 .54186 L .65268 .52423 L p
1 g
F P
s
P
p
.002 w
.50946 .59314 m .51921 .59597 L .50539 .61175 L p
1 g
F P
s
P
p
.002 w
.50539 .61175 m .48634 .60635 L .50946 .59314 L p
1 g
F P
s
P
p
.002 w
.65432 .4092 m .67952 .44354 L .66594 .46989 L p
1 g
F P
s
P
p
.002 w
.67952 .44354 m .65432 .4092 L .66055 .37961 L p
1 g
F P
s
P
p
.002 w
.6143 .32273 m .66192 .35223 L .66055 .37961 L p
1 g
F P
s
P
p
.002 w
.66192 .35223 m .6143 .32273 L .61028 .29742 L p
1 g
F P
s
P
p
.002 w
.64712 .49562 m .65268 .52423 L .62828 .54186 L p
1 g
F P
s
P
p
.002 w
.65268 .52423 m .64712 .49562 L .66594 .46989 L p
1 g
F P
s
P
p
.002 w
.46332 .58327 m .47177 .59655 L .44292 .59999 L p
1 g
F P
s
P
p
.002 w
.44292 .59999 m .4302 .58072 L .46332 .58327 L p
1 g
F P
s
P
p
.002 w
.55195 .58952 m .56023 .58315 L .58503 .58691 L p
1 g
F P
s
P
p
.002 w
.59569 .57218 m .58503 .58691 L .56023 .58315 L p
1 g
F P
s
P
p
.002 w
.50211 .58806 m .50946 .59314 L .48634 .60635 L p
1 g
F P
s
P
p
.002 w
.48634 .60635 m .47177 .59655 L .50211 .58806 L p
1 g
F P
s
P
p
.002 w
.42789 .5581 m .4302 .58072 L .3997 .57379 L p
1 g
F P
s
P
p
.002 w
.3997 .57379 m .39614 .54463 L .42789 .5581 L p
1 g
F P
s
P
p
.002 w
.38019 .4911 m .36791 .52794 L .34412 .50869 L p
1 g
F P
s
P
p
.002 w
.34412 .50869 m .35739 .46663 L .38019 .4911 L p
1 g
F P
s
P
p
.002 w
.37398 .3983 m .33927 .44155 L .32632 .41673 L p
1 g
F P
s
P
p
.002 w
.32632 .41673 m .36233 .37095 L .37398 .3983 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.61028 .29742 m .54721 .28272 L .54109 .26198 L p
1 g
F P
s
P
p
.002 w
.47236 .26562 m .54109 .26198 L .54721 .28272 L p
1 g
F P
s
P
p
.002 w
.54721 .28272 m .61028 .29742 L .6143 .32273 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52575 .5433 L
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.56023 .58315 m .56559 .57558 L .59569 .57218 L p
1 g
F P
s
P
p
.002 w
.59956 .55652 m .59569 .57218 L .56559 .57558 L p
1 g
F P
s
P
p
.002 w
.59569 .57218 m .59956 .55652 L .62828 .54186 L p
1 g
F P
s
P
p
.002 w
.47732 .28656 m .4102 .30878 L .40642 .28753 L p
1 g
F P
s
P
p
.002 w
.40642 .28753 m .47236 .26562 L .47732 .28656 L p
1 g
F P
s
P
p
.002 w
.64329 .44005 m .66594 .46989 L .64712 .49562 L p
1 g
F P
s
P
p
.002 w
.66594 .46989 m .64329 .44005 L .65432 .4092 L p
1 g
F P
s
P
p
.002 w
.62357 .51981 m .62828 .54186 L .59956 .55652 L p
1 g
F P
s
P
p
.002 w
.62828 .54186 m .62357 .51981 L .64712 .49562 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55195 .58952 m .54161 .59405 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.54161 .59405 m .53031 .59628 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.53031 .59628 m .51921 .59597 L .53281 .57483 L p
1 g
F P
s
P
p
.002 w
.51921 .59597 m .50946 .59314 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.53291 .57467 m .50946 .59314 L .50425 .58954 L p
1 g
F P
s
P
p
.002 w
.50425 .58954 m .50211 .58806 L .53134 .57535 L p
1 g
F P
s
P
p
.002 w
.53134 .57535 m .53291 .57467 L p
.50425 .58954 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53182 .5751 L p
1 g
F P
s
P
p
.54854 .56129 m .53182 .5751 L .53182 .5751 L 1 g
F
P
p
.54854 .56129 m .53182 .5751 L .53226 .57487 L 1 g
F
P
p
.002 w
.56545 .56008 m .53291 .57467 L .53501 .57305 L p
1 g
F P
s
P
p
.002 w
.56088 .55498 m .56545 .56008 L p
.54398 .56923 L 1 g
F P
s
P
p
.54922 .56312 m .54398 .56923 L .53501 .57305 L 1 g
F
P
p
.56088 .55498 m .54398 .56923 L .54922 .56312 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54922 .56312 L p
1 g
F P
s
P
p
.56075 .54566 m .54922 .56312 L .55195 .55995 L 1 g
F
P
p
.002 w
.55794 .5529 m .55985 .55383 L .55195 .55995 L p
1 g
F P
s
P
p
.55458 .55685 m .55195 .55995 L .55453 .55694 L 1 g
F
P
p
.56075 .54566 m .55195 .55995 L .55458 .55685 L 1 g
F
P
p
.54854 .56129 m .53226 .57487 L .53265 .57466 L 1 g
F
P
p
.002 w
.53273 .57462 m .53291 .57467 L .53265 .57466 L p
1 g
F P
s
P
p
.5327 .57463 m .53265 .57466 L .53269 .57464 L 1 g
F
P
p
.54854 .56129 m .53265 .57466 L .5327 .57463 L 1 g
F
P
p
.54854 .56129 m .53269 .57464 L .53273 .57461 L 1 g
F
P
p
.002 w
.50211 .58806 m .4995 .58378 L p
.51095 .58071 L 1 g
F P
s
P
p
.52009 .58018 m .51095 .58071 L .53147 .57519 L 1 g
F
P
p
.50211 .58806 m .51095 .58071 L .52009 .58018 L 1 g
F
P
p
.002 w
.51095 .58071 m .51079 .57862 L p
.497 .58138 L 1 g
F P
s
P
p
.002 w
.50211 .58806 m .47177 .59655 L p
.49767 .58142 L 1 g
F P
s
P
p
.002 w
.49808 .58145 m .50211 .58806 L p
.49767 .58142 L 1 g
F P
s
P
p
.497 .58138 m .49808 .58145 L .51095 .58071 L 1 g
F
P
p
.002 w
.47177 .59655 m .46332 .58327 L .49187 .58161 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58078 L p
1 g
F P
s
P
p
.002 w
.49642 .58134 m .49187 .58161 L p
.49227 .58102 L 1 g
F P
s
P
p
.002 w
.49187 .58161 m .46332 .58327 L p
.48058 .5783 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58078 L .49697 .58138 L 1 g
F
P
p
.002 w
.48905 .58078 m .48921 .57862 L p
.47876 .57776 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46828 .57469 L p
1 g
F P
s
P
p
.002 w
.46332 .58327 m .4625 .573 L p
.46828 .57469 L 1 g
F P
s
P
p
.47672 .57941 m .46828 .57469 L .48058 .5783 L 1 g
F
P
p
.46332 .58327 m .46828 .57469 L .47672 .57941 L 1 g
F
P
p
.002 w
.46828 .57469 m .46872 .57265 L p
.4581 .56841 L 1 g
F P
s
P
p
.002 w
.46332 .58327 m .4302 .58072 L p
.45903 .56906 L 1 g
F P
s
P
p
.002 w
.46238 .57139 m .46332 .58327 L p
.45903 .56906 L 1 g
F P
s
P
p
.4581 .56841 m .46238 .57139 L .46828 .57469 L 1 g
F
P
p
.002 w
.4302 .58072 m .42789 .5581 L .4523 .56504 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56308 L p
1 g
F P
s
P
p
.002 w
.45393 .5655 m .4523 .56504 L p
.4528 .56463 L 1 g
F P
s
P
p
.002 w
.4523 .56504 m .42789 .5581 L p
.44493 .55548 L 1 g
F P
s
P
p
.4302 .58072 m .45393 .5655 L .45903 .56906 L 1 g
F
P
p
.46872 .57265 m .45079 .56308 L .45728 .56808 L 1 g
F
P
p
.002 w
.45079 .56308 m .45146 .56129 L p
.44524 .55589 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43848 .54711 L p
1 g
F P
s
P
p
.002 w
.42789 .5581 m .43413 .54147 L p
.43848 .54711 L 1 g
F P
s
P
p
.44176 .55597 m .43848 .54711 L .44493 .55548 L 1 g
F
P
p
.42789 .5581 m .43848 .54711 L .44176 .55597 L 1 g
F
P
p
.002 w
.43848 .54711 m .43925 .54566 L p
.43473 .53672 L 1 g
F P
s
P
p
.002 w
.43527 .53844 m .42789 .5581 L p
.43424 .53516 L 1 g
F P
s
P
p
.43473 .53672 m .43435 .53597 L .43527 .53844 L 1 g
F
P
p
.43473 .53672 m .43527 .53844 L .43848 .54711 L 1 g
F
P
p
.002 w
.42789 .5581 m .39614 .54463 L p
.43424 .53516 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4325 .52874 L p
1 g
F P
s
P
p
.43925 .54566 m .4325 .52874 L .43288 .53034 L 1 g
F
P
p
.40695 .51402 m .42889 .51346 L .4325 .52874 L 1 g
F
P
p
.002 w
.43332 .53219 m .43226 .53146 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.43226 .53146 m .40695 .51402 L p
.4325 .52874 L 1 g
F P
s
P
p
.002 w
.4325 .52874 m .43346 .52734 L p
.43322 .52047 L 1 g
F P
s
P
p
.43925 .54566 m .43288 .53034 L .43365 .53327 L 1 g
F
P
p
.43288 .53034 m .43232 .529 L .43332 .53219 L 1 g
F
P
p
.43288 .53034 m .43332 .53219 L .43365 .53327 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43422 .50901 L p
1 g
F P
s
P
p
.42889 .51346 m .43384 .51333 L .4325 .52874 L 1 g
F
P
p
.43346 .52734 m .43422 .50901 L .43322 .52047 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.40695 .51402 m .43161 .48557 L .44056 .49549 L p
1 g
F P
s
P
p
.002 w
.43422 .50901 m .43485 .50826 L p
.43775 .50147 L 1 g
F P
s
P
p
.40695 .51402 m .44056 .49549 L .43217 .51337 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44266 .49128 L p
1 g
F P
s
P
p
.43161 .48557 m .44432 .48796 L .44266 .49128 L 1 g
F
P
p
.002 w
.44056 .49549 m .43952 .49433 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.43952 .49433 m .43161 .48557 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.44266 .49128 m .44166 .49233 L p
.43884 .49893 L 1 g
F P
s
P
p
.43485 .50826 m .44266 .49128 L .43884 .49893 L 1 g
F
P
p
.002 w
.44266 .49128 m .44339 .4905 L p
.44876 .48535 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44266 .49128 m .48414 .49545 L .44056 .49549 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4578 .47658 L p
1 g
F P
s
P
p
.44339 .4905 m .4578 .47658 L .44876 .48535 L 1 g
F
P
p
.44432 .48796 m .44579 .48824 L .44266 .49128 L 1 g
F
P
p
.44579 .48824 m .48414 .49545 L .44266 .49128 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47136 .47023 m .48414 .49545 L p
.43661 .48651 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47758 .46714 L p
1 g
F P
s
P
p
.002 w
.51743 .48483 m .48414 .49545 L .47136 .47023 L p
1 g
F P
s
P
p
.47743 .46721 m .51743 .48483 L .47136 .47023 L 1 g
F
P
p
.45826 .47608 m .47758 .46714 L .46943 .47118 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.46764 .4629 m .51075 .44906 L .51312 .46177 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .566 .50927 L p
1 g
F P
s
P
p
.002 w
.58341 .48797 m .56977 .5171 L p
.566 .50927 L 1 g
F P
s
P
p
.55736 .4913 m .56486 .49854 L .566 .50927 L 1 g
F
P
p
.55661 .4905 m .566 .50927 L .5612 .49928 L 1 g
F
P
p
.002 w
.566 .50927 m .56515 .50826 L p
.56725 .52189 L 1 g
F P
s
P
p
.56725 .52189 m .56725 .52187 L .566 .50927 L 1 g
F
P
p
.56726 .52191 m .56721 .5206 L .566 .50927 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56716 .52015 m .56825 .52034 L .56726 .52204 L p
1 g
F P
s
P
p
.002 w
.56726 .52204 m .56825 .52034 L p
.56733 .52401 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5675 .52873 L p
1 g
F P
s
P
p
.56825 .52034 m .56821 .52644 L .56733 .52401 L 1 g
F
P
p
.56821 .52644 m .5681 .54578 L .5675 .52873 L 1 g
F
P
p
.56821 .52644 m .5675 .52873 L .56733 .52401 L 1 g
F
P
p
.002 w
.56825 .52034 m .58526 .52901 L .5681 .54578 L p
1 g
F P
s
P
p
.002 w
.5675 .52873 m .56654 .52734 L p
.56459 .53802 L 1 g
F P
s
P
p
.56515 .50826 m .5675 .52873 L .56731 .52359 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56166 .54738 L p
1 g
F P
s
P
p
.56154 .54778 m .5681 .54578 L .56069 .55047 L 1 g
F
P
p
.56654 .52734 m .56166 .54738 L .56459 .53802 L 1 g
F
P
p
.002 w
.55985 .55383 m .56088 .55498 L p
.54922 .56312 L 1 g
F P
s
P
p
.54854 .56129 m .53283 .57456 L .53946 .56995 L 1 g
F
P
p
.002 w
.53289 .5748 m .53031 .59628 L p
.53281 .57483 L 1 g
F P
s
P
p
.002 w
.56023 .58315 m .55195 .58952 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.56559 .57558 m .56023 .58315 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.56741 .56761 m .56559 .57558 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.56545 .56008 m .56741 .56761 L .53291 .57467 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54923 .56314 L p
1 g
F P
s
P
p
.002 w
.54923 .56314 m .54854 .56129 L p
.53946 .56995 L 1 g
F P
s
P
p
.53946 .56995 m .5322 .57686 L .54923 .56314 L 1 g
F
P
p
.002 w
.56166 .54738 m .56075 .54566 L p
.55453 .55694 L 1 g
F P
s
P
p
.55453 .55694 m .55772 .55322 L .56166 .54738 L 1 g
F
P
p
.54854 .56129 m .53273 .57462 L .53276 .5746 L 1 g
F
P
p
.54854 .56129 m .53276 .5746 L .53279 .57458 L 1 g
F
P
p
.54854 .56129 m .53278 .57459 L .53282 .57456 L 1 g
F
P
p
.54854 .56129 m .53281 .57458 L .53285 .57454 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55195 .55995 m .53501 .57305 L p
.55794 .5529 L 1 g
F P
s
P
p
.002 w
.53501 .57305 m .53291 .57467 L p
.53384 .57386 L 1 g
F P
s
P
p
.55794 .5529 m .53501 .57305 L .53384 .57386 L 1 g
F
P
p
.002 w
.53501 .57305 m .55195 .55995 L p
.54922 .56312 L 1 g
F P
s
P
p
.002 w
.55195 .55995 m .55985 .55383 L p
.54922 .56312 L 1 g
F P
s
P
p
.55453 .55694 m .55143 .56255 L .55772 .55322 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56733 .52401 m .56783 .53822 L .56135 .54783 L 1 g
F
P
p
.56783 .53822 m .5681 .54578 L .56135 .54783 L 1 g
F
P
p
.002 w
.56166 .54738 m .56257 .5491 L p
.56459 .53802 L 1 g
F P
s
P
p
.002 w
.5681 .54578 m .55985 .55383 L p
.56069 .55047 L 1 g
F P
s
P
p
.56135 .54783 m .56154 .54778 L .56069 .55047 L 1 g
F
P
p
.56515 .50826 m .56818 .52973 L .56756 .52387 L 1 g
F
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55985 .55383 m .55119 .54958 L .56726 .52204 L p
1 g
F P
s
P
p
.56733 .52401 m .55985 .55383 L .56726 .52204 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56166 .54738 L p
1 g
F P
s
P
p
.55143 .56255 m .54998 .56518 L .56166 .54738 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5675 .52873 L p
1 g
F P
s
P
p
.56459 .53802 m .56257 .5491 L .5675 .52873 L 1 g
F
P
p
.002 w
.5675 .52873 m .56818 .52973 L p
.56731 .52359 L 1 g
F P
s
P
p
.002 w
.56335 .48433 m .58341 .48797 L p
.566 .50927 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .4913 L p
1 g
F P
s
P
p
.54174 .47608 m .55736 .4913 L .55165 .48578 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55193 .48226 m .55312 .48248 L p
.56679 .51669 L 1 g
F P
s
P
p
.56683 .51702 m .56679 .51669 L .56825 .52034 L 1 g
F
P
p
.55193 .48226 m .56679 .51669 L .56683 .51702 L 1 g
F
P
p
.002 w
.56818 .52973 m .56854 .53025 L p
.56756 .52387 L 1 g
F P
s
P
p
.002 w
.54684 .51666 m .56716 .52015 L p
.55119 .54958 L 1 g
F P
s
P
p
.002 w
.56726 .52204 m .55119 .54958 L p
.56716 .52015 L 1 g
F P
s
P
p
.56725 .52189 m .56726 .52191 L .56725 .52187 L 1 g
F
P
p
.56726 .52191 m .56756 .52387 L .56721 .5206 L 1 g
F
P
p
.002 w
.56977 .5171 m .56825 .52034 L p
.55312 .48248 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56825 .52034 m .54684 .51666 L .55144 .48558 L p
1 g
F P
s
P
p
.55471 .48874 m .56825 .52034 L .55144 .48558 L 1 g
F
P
p
.002 w
.51743 .48483 m .51391 .46598 L p
.54495 .47927 L 1 g
F P
s
P
p
.54174 .47608 m .55165 .48578 L .55144 .48558 L 1 g
F
P
p
.002 w
.55144 .48558 m .54684 .51666 L p
.5483 .48253 L 1 g
F P
s
P
p
.54923 .48344 m .55144 .48558 L .5498 .484 L 1 g
F
P
p
.54174 .47608 m .55144 .48558 L .54923 .48344 L 1 g
F
P
p
.002 w
.51743 .48483 m .5483 .48253 L p
.54684 .51666 L 1 g
F P
s
P
p
.002 w
.54227 .47666 m .54174 .47608 L p
.5498 .484 L 1 g
F P
s
P
p
.002 w
.5483 .48253 m .55193 .48226 L .55144 .48558 L p
1 g
F P
s
P
p
.002 w
.55193 .48226 m .5483 .48253 L p
.54495 .47927 L 1 g
F P
s
P
p
.002 w
.5483 .48253 m .51743 .48483 L p
.54495 .47927 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.53517 .46875 m .55193 .48226 L .54495 .47927 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54227 .47666 L p
1 g
F P
s
P
p
.54227 .47666 m .54495 .47927 L .52239 .46708 L 1 g
F
P
p
.002 w
.54227 .47666 m .54302 .47747 L p
.53028 .47089 L 1 g
F P
s
P
p
.52214 .46667 m .54227 .47666 L .53028 .47089 L 1 g
F
P
p
.52239 .46708 m .54495 .47927 L .51391 .46598 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52239 .46708 L p
1 g
F P
s
P
p
.002 w
.52239 .46708 m .52214 .46667 L p
.53028 .47089 L 1 g
F P
s
P
p
.53028 .47089 m .54302 .47747 L .52239 .46708 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46708 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.51075 .44906 m .53517 .46875 L .52239 .46708 L 1 g
F
P
p
.5 .4634 m .52239 .46708 L .51685 .46636 L 1 g
F
P
p
.5 .4634 m .52256 .46736 L .51094 .4655 L 1 g
F
P
p
.002 w
.51391 .46598 m .51329 .4627 L p
.52239 .46708 L 1 g
F P
s
P
p
.002 w
.51329 .4627 m .51075 .44906 L p
.52239 .46708 L 1 g
F P
s
P
p
.53399 .46859 m .54227 .47666 L .52239 .46708 L 1 g
F
P
p
.53517 .46875 m .54495 .47927 L .53399 .46859 L 1 g
F
P
p
.5498 .484 m .55834 .49233 L .54281 .47725 L 1 g
F
P
p
.55165 .48578 m .55523 .48929 L .5498 .484 L 1 g
F
P
p
.55523 .48929 m .55834 .49233 L .5498 .484 L 1 g
F
P
p
.002 w
.54281 .47725 m .54227 .47666 L p
.5498 .484 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54281 .47725 L p
1 g
F P
s
P
p
.002 w
.55312 .48248 m .56335 .48433 L p
.56486 .49854 L 1 g
F P
s
P
p
.55312 .48248 m .56486 .49854 L .55736 .4913 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .566 .50927 L p
1 g
F P
s
P
p
.56756 .52387 m .56854 .53025 L .566 .50927 L 1 g
F
P
p
.002 w
.566 .50927 m .56713 .51061 L p
.5612 .49928 L 1 g
F P
s
P
p
.002 w
.55736 .4913 m .55834 .49233 L p
.55165 .48578 L 1 g
F P
s
P
p
.002 w
.55144 .48558 m .55193 .48226 L p
.55471 .48874 L 1 g
F P
s
P
p
.002 w
.52239 .46708 m .52256 .46736 L p
.51685 .46636 L 1 g
F P
s
P
p
.002 w
.51391 .46598 m .51743 .48483 L p
.5 .46375 L 1 g
F P
s
P
p
.002 w
.52256 .46736 m .52282 .46778 L p
.51094 .4655 L 1 g
F P
s
P
p
.47734 .46717 m .5 .46375 L .51743 .48483 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .4634 L p
.51094 .4655 L 1 g
F P
s
P
p
.51094 .4655 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.47758 .46714 m .47786 .46667 L p
.48649 .46579 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.46764 .4629 m .49105 .46232 L .47734 .46717 L 1 g
F
P
p
.49105 .46232 m .51312 .46177 L .5 .46375 L 1 g
F
P
p
.49105 .46232 m .5 .46375 L .47734 .46717 L 1 g
F
P
p
.002 w
.51312 .46177 m .51391 .46598 L p
.5 .46375 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47758 .46714 L p
1 g
F P
s
P
p
.48649 .46579 m .5 .46442 L .47758 .46714 L 1 g
F
P
p
.002 w
.47758 .46714 m .47718 .46778 L p
.46943 .47118 L 1 g
F P
s
P
p
.002 w
.47136 .47023 m .46764 .4629 L p
.47743 .46721 L 1 g
F P
s
P
p
.002 w
.43161 .48557 m .46764 .4629 L .47136 .47023 L p
1 g
F P
s
P
p
.002 w
.4578 .47658 m .45826 .47608 L p
.46767 .47195 L 1 g
F P
s
P
p
.43161 .48557 m .47136 .47023 L .43661 .48651 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .4578 .47658 L p
1 g
F P
s
P
p
.46767 .47195 m .47718 .46778 L .4578 .47658 L 1 g
F
P
p
.002 w
.4578 .47658 m .45698 .47747 L p
.44876 .48535 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44266 .49128 L p
1 g
F P
s
P
p
.44876 .48535 m .45698 .47747 L .44266 .49128 L 1 g
F
P
p
.002 w
.48414 .49545 m .45615 .51276 L .44056 .49549 L p
1 g
F P
s
P
p
.002 w
.44056 .49549 m .45615 .51276 L p
.43217 .51337 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43422 .50901 L p
1 g
F P
s
P
p
.43775 .50147 m .44166 .49233 L .43422 .50901 L 1 g
F
P
p
.002 w
.43422 .50901 m .43287 .51061 L p
.43322 .52047 L 1 g
F P
s
P
p
.4325 .52874 m .45615 .51276 L .43332 .53219 L 1 g
F
P
p
.43384 .51333 m .45615 .51276 L .4325 .52874 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52874 L p
1 g
F P
s
P
p
.43322 .52047 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.002 w
.45615 .51276 m .43673 .53454 L .43332 .53219 L p
1 g
F P
s
P
p
.002 w
.4325 .52874 m .43232 .529 L p
.43288 .53034 L 1 g
F P
s
P
p
.002 w
.39614 .54463 m .40695 .51402 L .43332 .53219 L p
1 g
F P
s
P
p
.39614 .54463 m .43332 .53219 L .43424 .53516 L 1 g
F
P
p
.002 w
.43232 .529 m .43196 .52952 L p
.43365 .53327 L 1 g
F P
s
P
p
.43925 .54566 m .43196 .52952 L .43435 .53597 L 1 g
F
P
p
.002 w
.43332 .53219 m .43673 .53454 L p
.43424 .53516 L 1 g
F P
s
P
p
.45146 .56129 m .43848 .54711 L .44524 .55589 L 1 g
F
P
p
.43848 .54711 m .43673 .53454 L .44493 .55548 L 1 g
F
P
p
.002 w
.43413 .54147 m .43527 .53844 L p
.43848 .54711 L 1 g
F P
s
P
p
.002 w
.43527 .53844 m .43673 .53454 L p
.43848 .54711 L 1 g
F P
s
P
p
.002 w
.43196 .52952 m .43146 .53025 L p
.43435 .53597 L 1 g
F P
s
P
p
.002 w
.43673 .53454 m .43527 .53844 L p
.43424 .53516 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43848 .54711 L p
1 g
F P
s
P
p
.43435 .53597 m .43146 .53025 L .43848 .54711 L 1 g
F
P
p
.002 w
.43848 .54711 m .43743 .5491 L p
.44524 .55589 L 1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43673 .53454 m .46845 .55187 L p
.44493 .55548 L 1 g
F P
s
P
p
.44493 .55548 m .46845 .55187 L .4523 .56504 L 1 g
F
P
p
.002 w
.4523 .56504 m .45393 .5655 L p
.45316 .566 L 1 g
F P
s
P
p
.4302 .58072 m .4523 .56504 L .45316 .566 L 1 g
F
P
p
.002 w
.45079 .56308 m .45002 .56518 L p
.45728 .56808 L 1 g
F P
s
P
p
.002 w
.46845 .55187 m .46209 .56782 L .45393 .5655 L p
1 g
F P
s
P
p
.4528 .56463 m .46845 .55187 L .45393 .5655 L 1 g
F
P
p
.002 w
.45073 .56327 m .45079 .56308 L p
.44056 .55182 L 1 g
F P
s
P
p
.44524 .55589 m .44056 .55182 L .45079 .56308 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45073 .56327 L p
1 g
F P
s
P
p
.44056 .55182 m .43743 .5491 L .45073 .56327 L 1 g
F
P
p
.002 w
.45393 .5655 m .46209 .56782 L p
.45903 .56906 L 1 g
F P
s
P
p
.48921 .57862 m .46828 .57469 L .47876 .57776 L 1 g
F
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.46828 .57469 m .46209 .56782 L .48058 .5783 L 1 g
F
P
p
.002 w
.4625 .573 m .46238 .57139 L p
.46828 .57469 L 1 g
F P
s
P
p
.002 w
.46238 .57139 m .46209 .56782 L p
.46828 .57469 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46812 .5754 L p
1 g
F P
s
P
p
.002 w
.46812 .5754 m .46828 .57469 L p
.46366 .57228 L 1 g
F P
s
P
p
.46366 .57228 m .45002 .56518 L .46812 .5754 L 1 g
F
P
p
.4581 .56841 m .45439 .56693 L .46238 .57139 L 1 g
F
P
p
.002 w
.46209 .56782 m .46238 .57139 L p
.45903 .56906 L 1 g
F P
s
P
p
.45439 .56693 m .45002 .56518 L .46828 .57469 L 1 g
F
P
p
.002 w
.46828 .57469 m .4678 .57686 L p
.47876 .57776 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46209 .56782 m .49753 .57341 L p
.48058 .5783 L 1 g
F P
s
P
p
.48058 .5783 m .49753 .57341 L .49187 .58161 L 1 g
F
P
p
.002 w
.49187 .58161 m .49642 .58134 L p
.49477 .58236 L 1 g
F P
s
P
p
.47177 .59655 m .49187 .58161 L .49477 .58236 L 1 g
F
P
p
.47177 .59655 m .49642 .58134 L .49767 .58142 L 1 g
F
P
p
.002 w
.48905 .58078 m .48889 .583 L p
.49697 .58138 L 1 g
F P
s
P
p
.002 w
.49753 .57341 m .49796 .58125 L .49642 .58134 L p
1 g
F P
s
P
p
.49227 .58102 m .49753 .57341 L .49642 .58134 L 1 g
F
P
p
.002 w
.48904 .58087 m .48905 .58078 L p
.47629 .57756 L 1 g
F P
s
P
p
.47876 .57776 m .47629 .57756 L .48905 .58078 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58087 L p
1 g
F P
s
P
p
.47629 .57756 m .4678 .57686 L .48904 .58087 L 1 g
F
P
p
.002 w
.49642 .58134 m .49796 .58125 L p
.49767 .58142 L 1 g
F P
s
P
p
.002 w
.53182 .5751 m .53128 .57265 L p
.52066 .5781 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.51095 .58071 m .49796 .58125 L .53147 .57519 L 1 g
F
P
p
.002 w
.4995 .58378 m .49808 .58145 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.49808 .58145 m .49796 .58125 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58227 L p
1 g
F P
s
P
p
.002 w
.51106 .58227 m .51095 .58071 L p
.50164 .58167 L 1 g
F P
s
P
p
.50164 .58167 m .48889 .583 L .51106 .58227 L 1 g
F
P
p
.497 .58138 m .49607 .58156 L .49808 .58145 L 1 g
F
P
p
.002 w
.49796 .58125 m .49808 .58145 L p
.49767 .58142 L 1 g
F P
s
P
p
.49607 .58156 m .48889 .583 L .51095 .58071 L 1 g
F
P
p
.002 w
.53134 .57535 m .50211 .58806 L p
.53248 .57475 L 1 g
F P
s
P
p
.002 w
.53182 .57513 m .53182 .5751 L p
.51871 .5791 L 1 g
F P
s
P
p
.52066 .5781 m .51871 .5791 L .53182 .5751 L 1 g
F
P
p
.002 w
.49796 .58125 m .53248 .57475 L p
.53147 .57519 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49753 .57341 m .5009 .56539 L .53273 .57462 L p
1 g
F P
s
P
p
.002 w
.53265 .57466 m .49753 .57341 L p
.53273 .57462 L 1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.5009 .56539 m .50777 .55809 L .53278 .57459 L p
1 g
F P
s
P
p
.002 w
.53278 .57459 m .53291 .57467 L .53273 .57462 L p
1 g
F P
s
P
p
.002 w
.53273 .57462 m .5009 .56539 L p
.53278 .57459 L 1 g
F P
s
P
p
.53273 .57461 m .53269 .57464 L .53273 .57462 L 1 g
F
P
p
.53276 .5746 m .53273 .57462 L .53276 .5746 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.50777 .55809 m .51739 .55232 L .53283 .57456 L p
1 g
F P
s
P
p
.002 w
.53283 .57456 m .53291 .57467 L .53278 .57459 L p
1 g
F P
s
P
p
.002 w
.53278 .57459 m .50777 .55809 L p
.53283 .57456 L 1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51739 .55232 m .5287 .54876 L .53288 .57452 L p
1 g
F P
s
P
p
.002 w
.53288 .57452 m .53291 .57467 L .53283 .57456 L p
1 g
F P
s
P
p
.002 w
.53283 .57456 m .51739 .55232 L p
.53288 .57452 L 1 g
F P
s
P
p
.53279 .57458 m .53276 .5746 L .53278 .57459 L 1 g
F
P
p
.53282 .57456 m .53278 .57459 L .53281 .57458 L 1 g
F
P
p
.002 w
.5287 .54876 m .54041 .54781 L .53296 .57447 L p
1 g
F P
s
P
p
.002 w
.53296 .57447 m .53291 .57467 L .53288 .57452 L p
1 g
F P
s
P
p
.002 w
.53288 .57452 m .5287 .54876 L p
.53296 .57447 L 1 g
F P
s
P
p
.002 w
.54041 .54781 m .55119 .54958 L .53315 .57434 L p
1 g
F P
s
P
p
.002 w
.53315 .57434 m .53291 .57467 L .53296 .57447 L p
1 g
F P
s
P
p
.002 w
.53296 .57447 m .54041 .54781 L p
.53315 .57434 L 1 g
F P
s
P
p
.53285 .57454 m .53281 .57458 L .53283 .57456 L 1 g
F
P
p
.002 w
.53291 .57467 m .53315 .57434 L p
.53384 .57386 L 1 g
F P
s
P
p
.53946 .56995 m .53283 .57456 L .53693 .57236 L 1 g
F
P
p
.002 w
.55119 .54958 m .55794 .5529 L p
.53384 .57386 L 1 g
F P
s
P
p
.002 w
.53315 .57434 m .55119 .54958 L p
.53384 .57386 L 1 g
F P
s
P
p
.002 w
.54922 .56312 m .54998 .56518 L p
.55453 .55694 L 1 g
F P
s
P
p
.53693 .57236 m .53286 .57455 L .53677 .57251 L 1 g
F
P
p
.002 w
.53265 .57466 m .53291 .57467 L .53248 .57475 L p
1 g
F P
s
P
p
.53286 .57455 m .53226 .57487 L .53281 .57458 L 1 g
F
P
p
.53286 .57455 m .53281 .57458 L .53677 .57251 L 1 g
F
P
p
.002 w
.49796 .58125 m .49753 .57341 L .53265 .57466 L p
1 g
F P
s
P
p
.002 w
.53248 .57475 m .49796 .58125 L p
.53265 .57466 L 1 g
F P
s
P
p
.002 w
.53248 .57475 m .53291 .57467 L .53134 .57535 L p
1 g
F P
s
P
p
.002 w
.53182 .5751 m .53182 .5751 L p
.53182 .5751 L 1 g
F P
s
P
p
.002 w
.53281 .57483 m .53291 .57467 L .53289 .5748 L p
1 g
F P
s
P
p
.002 w
.53182 .5751 m .5322 .57686 L p
.53677 .57251 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53182 .57513 L p
1 g
F P
s
P
p
.51871 .5791 m .51111 .583 L .53182 .57513 L 1 g
F
P
p
.002 w
.61496 .35203 m .66055 .37961 L .65432 .4092 L p
1 g
F P
s
P
p
.002 w
.66055 .37961 m .61496 .35203 L .6143 .32273 L p
1 g
F P
s
P
p
.002 w
.41685 .33444 m .36233 .37095 L .35507 .34612 L p
1 g
F P
s
P
p
.002 w
.35507 .34612 m .4102 .30878 L .41685 .33444 L p
1 g
F P
s
P
p
.002 w
.54721 .28272 m .47732 .28656 L .47236 .26562 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.40695 .51402 m .39614 .54463 L .36791 .52794 L p
1 g
F P
s
P
p
.002 w
.36791 .52794 m .38019 .4911 L .40695 .51402 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.38977 .42722 m .35739 .46663 L .33927 .44155 L p
1 g
F P
s
P
p
.002 w
.33927 .44155 m .37398 .3983 L .38977 .42722 L p
1 g
F P
s
P
p
.002 w
.62775 .47105 m .64712 .49562 L .62357 .51981 L p
1 g
F P
s
P
p
.002 w
.64712 .49562 m .62775 .47105 L .64329 .44005 L p
1 g
F P
s
P
p
.002 w
.56559 .57558 m .56741 .56761 L .59956 .55652 L p
1 g
F P
s
P
p
.002 w
.59603 .54157 m .59956 .55652 L .56741 .56761 L p
1 g
F P
s
P
p
.002 w
.59956 .55652 m .59603 .54157 L .62357 .51981 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.55209 .30864 m .6143 .32273 L .61496 .35203 L p
1 g
F P
s
P
p
.002 w
.6143 .32273 m .55209 .30864 L .54721 .28272 L p
1 g
F P
s
P
p
.002 w
.61211 .38438 m .65432 .4092 L .64329 .44005 L p
1 g
F P
s
P
p
.002 w
.65432 .4092 m .61211 .38438 L .61496 .35203 L p
1 g
F P
s
P
p
.002 w
.47732 .28656 m .54721 .28272 L .55209 .30864 L p
1 g
F P
s
P
p
.002 w
.56741 .56761 m .56545 .56008 L .59603 .54157 L p
1 g
F P
s
P
p
.002 w
.60817 .50108 m .62357 .51981 L .59603 .54157 L p
1 g
F P
s
P
p
.002 w
.62357 .51981 m .60817 .50108 L .62775 .47105 L p
1 g
F P
s
P
p
.002 w
.48313 .31261 m .41685 .33444 L .4102 .30878 L p
1 g
F P
s
P
p
.002 w
.4102 .30878 m .47732 .28656 L .48313 .31261 L p
1 g
F P
s
P
p
.002 w
.42625 .36376 m .37398 .3983 L .36233 .37095 L p
1 g
F P
s
P
p
.002 w
.36233 .37095 m .41685 .33444 L .42625 .36376 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.4092 .45669 m .38019 .4911 L .35739 .46663 L p
1 g
F P
s
P
p
.002 w
.35739 .46663 m .38977 .42722 L .4092 .45669 L p
1 g
F P
s
P
p
.002 w
.58526 .52901 m .59603 .54157 L .56545 .56008 L p
1 g
F P
s
P
p
.002 w
.59603 .54157 m .58526 .52901 L .60817 .50108 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55209 .30864 m .48313 .31261 L .47732 .28656 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.56545 .56008 m .55985 .55383 L .58526 .52901 L p
1 g
F P
s
P
p
.002 w
.60576 .41867 m .64329 .44005 L .62775 .47105 L p
1 g
F P
s
P
p
.002 w
.64329 .44005 m .60576 .41867 L .61211 .38438 L p
1 g
F P
s
P
p
.002 w
.5009 .56539 m .49753 .57341 L .46209 .56782 L p
1 g
F P
s
P
p
.002 w
.46209 .56782 m .46845 .55187 L .5009 .56539 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.55551 .33901 m .61496 .35203 L .61211 .38438 L p
1 g
F P
s
P
p
.002 w
.61496 .35203 m .55551 .33901 L .55209 .30864 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50777 .55809 m .5009 .56539 L .46845 .55187 L p
1 g
F P
s
P
p
.002 w
.43161 .48557 m .40695 .51402 L .38019 .4911 L p
1 g
F P
s
P
p
.002 w
.38019 .4911 m .4092 .45669 L .43161 .48557 L p
1 g
F P
s
P
p
.002 w
.59608 .45364 m .62775 .47105 L .60817 .50108 L p
1 g
F P
s
P
p
.002 w
.62775 .47105 m .59608 .45364 L .60576 .41867 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.48313 .31261 m .55209 .30864 L .55551 .33901 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.58526 .52901 m .56825 .52034 L .58341 .48797 L p
1 g
F P
s
P
p
.002 w
.58341 .48797 m .60817 .50108 L .58526 .52901 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43814 .39575 m .38977 .42722 L .37398 .3983 L p
1 g
F P
s
P
p
.002 w
.37398 .3983 m .42625 .36376 L .43814 .39575 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.55119 .54958 m .54041 .54781 L .54684 .51666 L p
1 g
F P
s
P
p
.002 w
.60817 .50108 m .58341 .48797 L .59608 .45364 L p
1 g
F P
s
P
p
.002 w
.51739 .55232 m .50777 .55809 L .48186 .53722 L p
1 g
F P
s
P
p
.002 w
.46845 .55187 m .48186 .53722 L .50777 .55809 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48962 .343 m .42625 .36376 L .41685 .33444 L p
1 g
F P
s
P
p
.002 w
.41685 .33444 m .48313 .31261 L .48962 .343 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48186 .53722 m .46845 .55187 L .43673 .53454 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.54041 .54781 m .5287 .54876 L .52348 .51848 L p
1 g
F P
s
P
p
.002 w
.52348 .51848 m .54684 .51666 L .54041 .54781 L p
1 g
F P
s
P
p
.002 w
.5287 .54876 m .51739 .55232 L .50093 .52562 L p
1 g
F P
s
P
p
.002 w
.48186 .53722 m .50093 .52562 L .51739 .55232 L p
1 g
F P
s
P
p
.002 w
.43673 .53454 m .45615 .51276 L .48186 .53722 L p
1 g
F P
s
P
p
.002 w
.50093 .52562 m .52348 .51848 L .5287 .54876 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55726 .37285 m .61211 .38438 L .60576 .41867 L p
1 g
F P
s
P
p
.002 w
.61211 .38438 m .55726 .37285 L .55551 .33901 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55551 .33901 m .48962 .343 L .48313 .31261 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45211 .42923 m .4092 .45669 L .38977 .42722 L p
1 g
F P
s
P
p
.002 w
.38977 .42722 m .43814 .39575 L .45211 .42923 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.50093 .52562 m .48186 .53722 L .45615 .51276 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.48962 .343 m .55551 .33901 L .55726 .37285 L p
1 g
F P
s
P
p
.002 w
.55725 .40894 m .60576 .41867 L .59608 .45364 L p
1 g
F P
s
P
p
.002 w
.60576 .41867 m .55725 .40894 L .55726 .37285 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58341 .48797 m .55193 .48226 L .55545 .44589 L p
1 g
F P
s
P
p
.002 w
.55545 .44589 m .59608 .45364 L .58341 .48797 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49657 .37673 m .43814 .39575 L .42625 .36376 L p
1 g
F P
s
P
p
.002 w
.42625 .36376 m .48962 .343 L .49657 .37673 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.59608 .45364 m .55545 .44589 L .55725 .40894 L p
1 g
F P
s
P
p
.002 w
.54684 .51666 m .52348 .51848 L .51743 .48483 L p
1 g
F P
s
P
p
.002 w
.52348 .51848 m .50093 .52562 L .48414 .49545 L p
1 g
F P
s
P
p
.002 w
.45615 .51276 m .48414 .49545 L .50093 .52562 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.46764 .4629 m .43161 .48557 L .4092 .45669 L p
1 g
F P
s
P
p
.002 w
.4092 .45669 m .45211 .42923 L .46764 .4629 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.48414 .49545 m .51743 .48483 L .52348 .51848 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55726 .37285 m .49657 .37673 L .48962 .343 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49657 .37673 m .55726 .37285 L .55725 .40894 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51075 .44906 m .55545 .44589 L .55193 .48226 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.54414 .62386 m
.54632 .63343 L
s
P
p
.002 w
.5037 .41255 m .45211 .42923 L .43814 .39575 L p
1 g
F P
s
P
p
.002 w
.43814 .39575 m .49657 .37673 L .5037 .41255 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.5037 .41255 m .55725 .40894 L .55545 .44589 L p
1 g
F P
s
P
p
.002 w
.55725 .40894 m .5037 .41255 L .49657 .37673 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55545 .44589 m .51075 .44906 L .5037 .41255 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51075 .44906 m .46764 .4629 L .45211 .42923 L p
1 g
F P
s
P
p
.002 w
.45211 .42923 m .5037 .41255 L .51075 .44906 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .48809 .71718 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .55213 .65888 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.455814)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.455814)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47465 .46559 m .52247 .46641 L .51999 .4381 L p
1 g
F P
s
P
p
.002 w
.51999 .4381 m .47808 .43738 L .47465 .46559 L p
1 g
F P
s
P
p
.002 w
.56023 .42909 m .51999 .4381 L .52247 .46641 L p
1 g
F P
s
P
p
.002 w
.47808 .43738 m .51999 .4381 L .51704 .40967 L p
1 g
F P
s
P
p
.002 w
.51999 .4381 m .56023 .42909 L .5506 .402 L p
1 g
F P
s
P
p
.002 w
.5506 .402 m .51704 .40967 L .51999 .4381 L p
1 g
F P
s
P
p
.002 w
.42913 .45391 m .47465 .46559 L .47808 .43738 L p
1 g
F P
s
P
p
.002 w
.47808 .43738 m .43824 .42696 L .42913 .45391 L p
1 g
F P
s
P
p
.002 w
.51704 .40967 m .48203 .40906 L .47808 .43738 L p
1 g
F P
s
P
p
.002 w
.43824 .42696 m .47808 .43738 L .48203 .40906 L p
1 g
F P
s
P
p
.002 w
.48203 .40906 m .51704 .40967 L .51366 .38163 L p
1 g
F P
s
P
p
.002 w
.51704 .40967 m .5506 .402 L .53971 .37555 L p
1 g
F P
s
P
p
.002 w
.53971 .37555 m .51366 .38163 L .51704 .40967 L p
1 g
F P
s
P
p
.002 w
.48203 .40906 m .44881 .40022 L .43824 .42696 L p
1 g
F P
s
P
p
.002 w
.51366 .38163 m .48643 .38115 L .48203 .40906 L p
1 g
F P
s
P
p
.002 w
.44881 .40022 m .48203 .40906 L .48643 .38115 L p
1 g
F P
s
P
p
.002 w
.47181 .49318 m .52442 .49409 L .52247 .46641 L p
1 g
F P
s
P
p
.002 w
.52247 .46641 m .47465 .46559 L .47181 .49318 L p
1 g
F P
s
P
p
.002 w
.56843 .45632 m .52247 .46641 L .52442 .49409 L p
1 g
F P
s
P
p
.002 w
.52247 .46641 m .56843 .45632 L .56023 .42909 L p
1 g
F P
s
P
p
.002 w
.42167 .48055 m .47181 .49318 L .47465 .46559 L p
1 g
F P
s
P
p
.002 w
.47465 .46559 m .42913 .45391 L .42167 .48055 L p
1 g
F P
s
P
p
.002 w
.48643 .38115 m .51366 .38163 L .50991 .35448 L p
1 g
F P
s
P
p
.002 w
.51366 .38163 m .53971 .37555 L .52777 .35023 L p
1 g
F P
s
P
p
.002 w
.52777 .35023 m .50991 .35448 L .51366 .38163 L p
1 g
F P
s
P
p
.002 w
.48643 .38115 m .46065 .37416 L .44881 .40022 L p
1 g
F P
s
P
p
.002 w
.50991 .35448 m .49121 .35415 L .48643 .38115 L p
1 g
F P
s
P
p
.002 w
.46065 .37416 m .48643 .38115 L .49121 .35415 L p
1 g
F P
s
P
p
.002 w
.57951 .38664 m .5506 .402 L .56023 .42909 L p
1 g
F P
s
P
p
.002 w
.5506 .402 m .57951 .38664 L .56204 .36344 L p
1 g
F P
s
P
p
.002 w
.56204 .36344 m .53971 .37555 L .5506 .402 L p
1 g
F P
s
P
p
.002 w
.40417 .40764 m .43824 .42696 L .44881 .40022 L p
1 g
F P
s
P
p
.002 w
.44881 .40022 m .42056 .38385 L .40417 .40764 L p
1 g
F P
s
P
p
.002 w
.42056 .38385 m .44881 .40022 L .46065 .37416 L p
1 g
F P
s
P
p
.002 w
.59508 .41097 m .56023 .42909 L .56843 .45632 L p
1 g
F P
s
P
p
.002 w
.56023 .42909 m .59508 .41097 L .57951 .38664 L p
1 g
F P
s
P
p
.002 w
.39003 .43219 m .42913 .45391 L .43824 .42696 L p
1 g
F P
s
P
p
.002 w
.43824 .42696 m .40417 .40764 L .39003 .43219 L p
1 g
F P
s
P
p
.002 w
.53971 .37555 m .56204 .36344 L .54299 .34181 L p
1 g
F P
s
P
p
.002 w
.54299 .34181 m .52777 .35023 L .53971 .37555 L p
1 g
F P
s
P
p
.002 w
.46962 .51964 m .5258 .5206 L .52442 .49409 L p
1 g
F P
s
P
p
.002 w
.52442 .49409 m .47181 .49318 L .46962 .51964 L p
1 g
F P
s
P
p
.002 w
.57504 .4832 m .52442 .49409 L .5258 .5206 L p
1 g
F P
s
P
p
.002 w
.52442 .49409 m .57504 .4832 L .56843 .45632 L p
1 g
F P
s
P
p
.002 w
.41603 .50638 m .46962 .51964 L .47181 .49318 L p
1 g
F P
s
P
p
.002 w
.47181 .49318 m .42167 .48055 L .41603 .50638 L p
1 g
F P
s
P
p
.002 w
.46065 .37416 m .43885 .36126 L .42056 .38385 L p
1 g
F P
s
P
p
.002 w
.43885 .36126 m .46065 .37416 L .47354 .34928 L p
1 g
F P
s
P
p
.002 w
.49121 .35415 m .47354 .34928 L .46065 .37416 L p
1 g
F P
s
P
p
.002 w
.60841 .43598 m .56843 .45632 L .57504 .4832 L p
1 g
F P
s
P
p
.002 w
.56843 .45632 m .60841 .43598 L .59508 .41097 L p
1 g
F P
s
P
p
.002 w
.37844 .45702 m .42167 .48055 L .42913 .45391 L p
1 g
F P
s
P
p
.002 w
.42913 .45391 m .39003 .43219 L .37844 .45702 L p
1 g
F P
s
P
p
.002 w
.49121 .35415 m .50991 .35448 L .50586 .32875 L p
1 g
F P
s
P
p
.002 w
.50991 .35448 m .52777 .35023 L .51498 .32655 L p
1 g
F P
s
P
p
.002 w
.51498 .32655 m .50586 .32875 L .50991 .35448 L p
1 g
F P
s
P
p
.002 w
.50586 .32875 m .49628 .32858 L .49121 .35415 L p
1 g
F P
s
P
p
.002 w
.47354 .34928 m .49121 .35415 L .49628 .32858 L p
1 g
F P
s
P
p
.002 w
.52777 .35023 m .54299 .34181 L .5227 .32219 L p
1 g
F P
s
P
p
.002 w
.5227 .32219 m .51498 .32655 L .52777 .35023 L p
1 g
F P
s
P
p
.002 w
.47354 .34928 m .45869 .34032 L .43885 .36126 L p
1 g
F P
s
P
p
.002 w
.45869 .34032 m .47354 .34928 L .48726 .32605 L p
1 g
F P
s
P
p
.002 w
.49628 .32858 m .48726 .32605 L .47354 .34928 L p
1 g
F P
s
P
p
.002 w
.60084 .36485 m .57951 .38664 L .59508 .41097 L p
1 g
F P
s
P
p
.002 w
.57951 .38664 m .60084 .36485 L .57833 .34635 L p
1 g
F P
s
P
p
.002 w
.57833 .34635 m .56204 .36344 L .57951 .38664 L p
1 g
F P
s
P
p
.002 w
.56204 .36344 m .57833 .34635 L .55395 .33 L p
1 g
F P
s
P
p
.002 w
.55395 .33 m .54299 .34181 L .56204 .36344 L p
1 g
F P
s
P
p
.002 w
.5258 .5206 m .5799 .50919 L .57504 .4832 L p
1 g
F P
s
P
p
.002 w
.61922 .46119 m .57504 .4832 L .5799 .50919 L p
1 g
F P
s
P
p
.002 w
.57504 .4832 m .61922 .46119 L .60841 .43598 L p
1 g
F P
s
P
p
.002 w
.37933 .38091 m .40417 .40764 L .42056 .38385 L p
1 g
F P
s
P
p
.002 w
.42056 .38385 m .40016 .36132 L .37933 .38091 L p
1 g
F P
s
P
p
.002 w
.40016 .36132 m .42056 .38385 L .43885 .36126 L p
1 g
F P
s
P
p
.002 w
.43885 .36126 m .4233 .34361 L .40016 .36132 L p
1 g
F P
s
P
p
.002 w
.4233 .34361 m .43885 .36126 L .45869 .34032 L p
1 g
F P
s
P
p
.002 w
.36969 .48165 m .41603 .50638 L .42167 .48055 L p
1 g
F P
s
P
p
.002 w
.42167 .48055 m .37844 .45702 L .36969 .48165 L p
1 g
F P
s
P
p
.002 w
.46814 .54443 m .52657 .54542 L .5258 .5206 L p
1 g
F P
s
P
p
.002 w
.5258 .5206 m .46962 .51964 L .46814 .54443 L p
1 g
F P
s
P
p
.002 w
.5799 .50919 m .5258 .5206 L .52657 .54542 L p
1 g
F P
s
P
p
.002 w
.41237 .53086 m .46814 .54443 L .46962 .51964 L p
1 g
F P
s
P
p
.002 w
.46962 .51964 m .41603 .50638 L .41237 .53086 L p
1 g
F P
s
P
p
.002 w
.62102 .38515 m .59508 .41097 L .60841 .43598 L p
1 g
F P
s
P
p
.002 w
.59508 .41097 m .62102 .38515 L .60084 .36485 L p
1 g
F P
s
P
p
.002 w
.36126 .40202 m .39003 .43219 L .40417 .40764 L p
1 g
F P
s
P
p
.002 w
.40417 .40764 m .37933 .38091 L .36126 .40202 L p
1 g
F P
s
P
p
.002 w
.54299 .34181 m .55395 .33 L .52819 .31611 L p
1 g
F P
s
P
p
.002 w
.52819 .31611 m .5227 .32219 L .54299 .34181 L p
1 g
F P
s
P
p
.002 w
.45869 .34032 m .44824 .32812 L .4233 .34361 L p
1 g
F P
s
P
p
.002 w
.44824 .32812 m .45869 .34032 L .47973 .32142 L p
1 g
F P
s
P
p
.002 w
.48726 .32605 m .47973 .32142 L .45869 .34032 L p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .49628 .32858 L .50586 .32875 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .50586 .32875 L .51498 .32655 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .48726 .32605 L .49628 .32858 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .51498 .32655 L .5227 .32219 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .47973 .32142 L .48726 .32605 L closepath p
1 g
F P
s
P
p
.002 w
.63842 .40687 m .60841 .43598 L .61922 .46119 L p
1 g
F P
s
P
p
.002 w
.60841 .43598 m .63842 .40687 L .62102 .38515 L p
1 g
F P
s
P
p
.002 w
.34639 .42423 m .37844 .45702 L .39003 .43219 L p
1 g
F P
s
P
p
.002 w
.39003 .43219 m .36126 .40202 L .34639 .42423 L p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .5227 .32219 L .52819 .31611 L closepath p
1 g
F P
s
P
p
.002 w
.47973 .32142 m .4745 .31516 L .44824 .32812 L p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .4745 .31516 L .47973 .32142 L closepath p
1 g
F P
s
P
p
.002 w
.52657 .54542 m .58286 .53378 L .5799 .50919 L p
1 g
F P
s
P
p
.002 w
.62723 .48608 m .5799 .50919 L .58286 .53378 L p
1 g
F P
s
P
p
.002 w
.5799 .50919 m .62723 .48608 L .61922 .46119 L p
1 g
F P
s
P
p
.002 w
.36406 .50554 m .41237 .53086 L .41603 .50638 L p
1 g
F P
s
P
p
.002 w
.41603 .50638 m .36969 .48165 L .36406 .50554 L p
1 g
F P
s
P
p
.002 w
.55942 .31596 m .55395 .33 L .57833 .34635 L p
1 g
F P
s
P
p
.002 w
.55395 .33 m .55942 .31596 L .53084 .30895 L p
1 g
F P
s
P
p
.002 w
.53084 .30895 m .52819 .31611 L .55395 .33 L p
1 g
F P
s
P
p
.002 w
.41581 .32287 m .4233 .34361 L .44824 .32812 L p
1 g
F P
s
P
p
.002 w
.44824 .32812 m .44338 .3139 L .41581 .32287 L p
1 g
F P
s
P
p
.002 w
.44338 .3139 m .44824 .32812 L .4745 .31516 L p
1 g
F P
s
P
p
.002 w
.58669 .3259 m .57833 .34635 L .60084 .36485 L p
1 g
F P
s
P
p
.002 w
.57833 .34635 m .58669 .3259 L .55942 .31596 L p
1 g
F P
s
P
p
.002 w
.39004 .33466 m .40016 .36132 L .4233 .34361 L p
1 g
F P
s
P
p
.002 w
.4233 .34361 m .41581 .32287 L .39004 .33466 L p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .52819 .31611 L .53084 .30895 L closepath p
1 g
F P
s
P
p
.002 w
.46742 .567 m .52669 .568 L .52657 .54542 L p
1 g
F P
s
P
p
.002 w
.52657 .54542 m .46814 .54443 L .46742 .567 L p
1 g
F P
s
P
p
.002 w
.58286 .53378 m .52657 .54542 L .52669 .568 L p
1 g
F P
s
P
p
.002 w
.4745 .31516 m .47216 .30791 L .44338 .3139 L p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .47216 .30791 L .4745 .31516 L closepath p
1 g
F P
s
P
p
.002 w
.41084 .55345 m .46742 .567 L .46814 .54443 L p
1 g
F P
s
P
p
.002 w
.46814 .54443 m .41237 .53086 L .41084 .55345 L p
1 g
F P
s
P
p
.002 w
.61209 .33859 m .60084 .36485 L .62102 .38515 L p
1 g
F P
s
P
p
.002 w
.60084 .36485 m .61209 .33859 L .58669 .3259 L p
1 g
F P
s
P
p
.002 w
.36667 .34909 m .37933 .38091 L .40016 .36132 L p
1 g
F P
s
P
p
.002 w
.40016 .36132 m .39004 .33466 L .36667 .34909 L p
1 g
F P
s
P
p
.002 w
.65261 .42956 m .61922 .46119 L .62723 .48608 L p
1 g
F P
s
P
p
.002 w
.61922 .46119 m .65261 .42956 L .63842 .40687 L p
1 g
F P
s
P
p
.002 w
.33516 .4471 m .36969 .48165 L .37844 .45702 L p
1 g
F P
s
P
p
.002 w
.37844 .45702 m .34639 .42423 L .33516 .4471 L p
1 g
F P
s
P
p
.002 w
.53033 .30147 m .53084 .30895 L .55942 .31596 L p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .53084 .30895 L .53033 .30147 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .53033 .30147 L .52668 .29448 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .52668 .29448 L .52024 .28875 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .52024 .28875 L .51171 .28495 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .51171 .28495 L .50204 .28351 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .50204 .28351 L .49231 .2846 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .49231 .2846 L .48363 .2881 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .48363 .2881 L .47695 .29359 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .47695 .29359 L .47299 .30045 L closepath p
1 g
F P
s
P
p
.002 w
.50156 .30499 m .47299 .30045 L .47216 .30791 L closepath p
1 g
F P
s
P
p
.002 w
.44476 .29913 m .44338 .3139 L .47216 .30791 L p
1 g
F P
s
P
p
.002 w
.47216 .30791 m .47299 .30045 L .44476 .29913 L p
1 g
F P
s
P
p
.002 w
.55867 .30117 m .55942 .31596 L .58669 .3259 L p
1 g
F P
s
P
p
.002 w
.55942 .31596 m .55867 .30117 L .53033 .30147 L p
1 g
F P
s
P
p
.002 w
.63503 .35383 m .62102 .38515 L .63842 .40687 L p
1 g
F P
s
P
p
.002 w
.62102 .38515 m .63503 .35383 L .61209 .33859 L p
1 g
F P
s
P
p
.002 w
.41749 .30114 m .41581 .32287 L .44338 .3139 L p
1 g
F P
s
P
p
.002 w
.44338 .3139 m .44476 .29913 L .41749 .30114 L p
1 g
F P
s
P
p
.002 w
.34628 .36591 m .36126 .40202 L .37933 .38091 L p
1 g
F P
s
P
p
.002 w
.37933 .38091 m .36667 .34909 L .34628 .36591 L p
1 g
F P
s
P
p
.002 w
.52669 .568 m .58379 .55639 L .58286 .53378 L p
1 g
F P
s
P
p
.002 w
.63218 .51014 m .58286 .53378 L .58379 .55639 L p
1 g
F P
s
P
p
.002 w
.58286 .53378 m .63218 .51014 L .62723 .48608 L p
1 g
F P
s
P
p
.002 w
.52668 .29448 m .53033 .30147 L .55867 .30117 L p
1 g
F P
s
P
p
.002 w
.45242 .28544 m .44476 .29913 L .47299 .30045 L p
1 g
F P
s
P
p
.002 w
.47299 .30045 m .47695 .29359 L .45242 .28544 L p
1 g
F P
s
P
p
.002 w
.3618 .52815 m .41084 .55345 L .41237 .53086 L p
1 g
F P
s
P
p
.002 w
.41237 .53086 m .36406 .50554 L .3618 .52815 L p
1 g
F P
s
P
p
.002 w
.58595 .30415 m .58669 .3259 L .61209 .33859 L p
1 g
F P
s
P
p
.002 w
.58669 .3259 m .58595 .30415 L .55867 .30117 L p
1 g
F P
s
P
p
.002 w
.39178 .30653 m .39004 .33466 L .41581 .32287 L p
1 g
F P
s
P
p
.002 w
.41581 .32287 m .41749 .30114 L .39178 .30653 L p
1 g
F P
s
P
p
.002 w
.55867 .30117 m .55161 .28721 L .52668 .29448 L p
1 g
F P
s
P
p
.002 w
.52024 .28875 m .52668 .29448 L .55161 .28721 L p
1 g
F P
s
P
p
.002 w
.66318 .45279 m .62723 .48608 L .63218 .51014 L p
1 g
F P
s
P
p
.002 w
.62723 .48608 m .66318 .45279 L .65261 .42956 L p
1 g
F P
s
P
p
.002 w
.46562 .2744 m .45242 .28544 L .47695 .29359 L p
1 g
F P
s
P
p
.002 w
.47695 .29359 m .48363 .2881 L .46562 .2744 L p
1 g
F P
s
P
p
.002 w
.32794 .47012 m .36406 .50554 L .36969 .48165 L p
1 g
F P
s
P
p
.002 w
.36969 .48165 m .33516 .4471 L .32794 .47012 L p
1 g
F P
s
P
p
.002 w
.46752 .58677 m .52613 .58776 L .52669 .568 L p
1 g
F P
s
P
p
.002 w
.52669 .568 m .46742 .567 L .46752 .58677 L p
1 g
F P
s
P
p
.002 w
.58379 .55639 m .52669 .568 L .52613 .58776 L p
1 g
F P
s
P
p
.002 w
.41157 .57356 m .46752 .58677 L .46742 .567 L p
1 g
F P
s
P
p
.002 w
.46742 .567 m .41084 .55345 L .41157 .57356 L p
1 g
F P
s
P
p
.002 w
.65493 .37134 m .63842 .40687 L .65261 .42956 L p
1 g
F P
s
P
p
.002 w
.63842 .40687 m .65493 .37134 L .63503 .35383 L p
1 g
F P
s
P
p
.002 w
.32942 .38481 m .34639 .42423 L .36126 .40202 L p
1 g
F P
s
P
p
.002 w
.36126 .40202 m .34628 .36591 L .32942 .38481 L p
1 g
F P
s
P
p
.002 w
.55161 .28721 m .55867 .30117 L .58595 .30415 L p
1 g
F P
s
P
p
.002 w
.42851 .28083 m .41749 .30114 L .44476 .29913 L p
1 g
F P
s
P
p
.002 w
.44476 .29913 m .45242 .28544 L .42851 .28083 L p
1 g
F P
s
P
p
.002 w
.55161 .28721 m .5389 .27571 L .52024 .28875 L p
1 g
F P
s
P
p
.002 w
.51171 .28495 m .52024 .28875 L .5389 .27571 L p
1 g
F P
s
P
p
.002 w
.48297 .26733 m .46562 .2744 L .48363 .2881 L p
1 g
F P
s
P
p
.002 w
.48363 .2881 m .49231 .2846 L .48297 .26733 L p
1 g
F P
s
P
p
.002 w
.61156 .31044 m .61209 .33859 L .63503 .35383 L p
1 g
F P
s
P
p
.002 w
.61209 .33859 m .61156 .31044 L .58595 .30415 L p
1 g
F P
s
P
p
.002 w
.36829 .31527 m .36667 .34909 L .39004 .33466 L p
1 g
F P
s
P
p
.002 w
.39004 .33466 m .39178 .30653 L .36829 .31527 L p
1 g
F P
s
P
p
.002 w
.5389 .27571 m .52187 .26802 L .51171 .28495 L p
1 g
F P
s
P
p
.002 w
.50204 .28351 m .51171 .28495 L .52187 .26802 L p
1 g
F P
s
P
p
.002 w
.50248 .26511 m .48297 .26733 L .49231 .2846 L p
1 g
F P
s
P
p
.002 w
.49231 .2846 m .50204 .28351 L .50248 .26511 L p
1 g
F P
s
P
p
.002 w
.52187 .26802 m .50248 .26511 L .50204 .28351 L p
1 g
F P
s
P
p
.002 w
.52613 .58776 m .58258 .57645 L .58379 .55639 L p
1 g
F P
s
P
p
.002 w
.63385 .5328 m .58379 .55639 L .58258 .57645 L p
1 g
F P
s
P
p
.002 w
.58379 .55639 m .63385 .5328 L .63218 .51014 L p
1 g
F P
s
P
p
.002 w
.3631 .5489 m .41157 .57356 L .41084 .55345 L p
1 g
F P
s
P
p
.002 w
.41084 .55345 m .3618 .52815 L .3631 .5489 L p
1 g
F P
s
P
p
.002 w
.58595 .30415 m .57582 .28347 L .55161 .28721 L p
1 g
F P
s
P
p
.002 w
.5389 .27571 m .55161 .28721 L .57582 .28347 L p
1 g
F P
s
P
p
.002 w
.67126 .39081 m .65261 .42956 L .66318 .45279 L p
1 g
F P
s
P
p
.002 w
.65261 .42956 m .67126 .39081 L .65493 .37134 L p
1 g
F P
s
P
p
.002 w
.44795 .26433 m .42851 .28083 L .45242 .28544 L p
1 g
F P
s
P
p
.002 w
.45242 .28544 m .46562 .2744 L .44795 .26433 L p
1 g
F P
s
P
p
.002 w
.57582 .28347 m .58595 .30415 L .61156 .31044 L p
1 g
F P
s
P
p
.002 w
.40581 .28001 m .39178 .30653 L .41749 .30114 L p
1 g
F P
s
P
p
.002 w
.41749 .30114 m .42851 .28083 L .40581 .28001 L p
1 g
F P
s
P
p
.002 w
.31663 .40542 m .33516 .4471 L .34639 .42423 L p
1 g
F P
s
P
p
.002 w
.34639 .42423 m .32942 .38481 L .31663 .40542 L p
1 g
F P
s
P
p
.002 w
.66977 .47602 m .63218 .51014 L .63385 .5328 L p
1 g
F P
s
P
p
.002 w
.63218 .51014 m .66977 .47602 L .66318 .45279 L p
1 g
F P
s
P
p
.002 w
.32508 .49276 m .3618 .52815 L .36406 .50554 L p
1 g
F P
s
P
p
.002 w
.36406 .50554 m .32794 .47012 L .32508 .49276 L p
1 g
F P
s
P
p
.002 w
.63488 .32001 m .63503 .35383 L .65493 .37134 L p
1 g
F P
s
P
p
.002 w
.63503 .35383 m .63488 .32001 L .61156 .31044 L p
1 g
F P
s
P
p
.002 w
.34764 .32729 m .34628 .36591 L .36667 .34909 L p
1 g
F P
s
P
p
.002 w
.36667 .34909 m .36829 .31527 L .34764 .32729 L p
1 g
F P
s
P
p
.002 w
.46847 .60317 m .52487 .60412 L .52613 .58776 L p
1 g
F P
s
P
p
.002 w
.52613 .58776 m .46752 .58677 L .46847 .60317 L p
1 g
F P
s
P
p
.002 w
.58258 .57645 m .52613 .58776 L .52487 .60412 L p
1 g
F P
s
P
p
.002 w
.41465 .59061 m .46847 .60317 L .46752 .58677 L p
1 g
F P
s
P
p
.002 w
.46752 .58677 m .41157 .57356 L .41465 .59061 L p
1 g
F P
s
P
p
.002 w
.57582 .28347 m .55712 .26629 L .5389 .27571 L p
1 g
F P
s
P
p
.002 w
.52187 .26802 m .5389 .27571 L .55712 .26629 L p
1 g
F P
s
P
p
.002 w
.47373 .25371 m .44795 .26433 L .46562 .2744 L p
1 g
F P
s
P
p
.002 w
.46562 .2744 m .48297 .26733 L .47373 .25371 L p
1 g
F P
s
P
p
.002 w
.59872 .28346 m .61156 .31044 L .63488 .32001 L p
1 g
F P
s
P
p
.002 w
.61156 .31044 m .59872 .28346 L .57582 .28347 L p
1 g
F P
s
P
p
.002 w
.55712 .26629 m .53183 .25475 L .52187 .26802 L p
1 g
F P
s
P
p
.002 w
.50248 .26511 m .52187 .26802 L .53183 .25475 L p
1 g
F P
s
P
p
.002 w
.50287 .25037 m .47373 .25371 L .48297 .26733 L p
1 g
F P
s
P
p
.002 w
.48297 .26733 m .50248 .26511 L .50287 .25037 L p
1 g
F P
s
P
p
.002 w
.38489 .28316 m .36829 .31527 L .39178 .30653 L p
1 g
F P
s
P
p
.002 w
.39178 .30653 m .40581 .28001 L .38489 .28316 L p
1 g
F P
s
P
p
.002 w
.68349 .41184 m .66318 .45279 L .66977 .47602 L p
1 g
F P
s
P
p
.002 w
.66318 .45279 m .68349 .41184 L .67126 .39081 L p
1 g
F P
s
P
p
.002 w
.53183 .25475 m .50287 .25037 L .50248 .26511 L p
1 g
F P
s
P
p
.002 w
.55712 .26629 m .57582 .28347 L .59872 .28346 L p
1 g
F P
s
P
p
.002 w
.3084 .42731 m .32794 .47012 L .33516 .4471 L p
1 g
F P
s
P
p
.002 w
.33516 .4471 m .31663 .40542 L .3084 .42731 L p
1 g
F P
s
P
p
.002 w
.65525 .33275 m .65493 .37134 L .67126 .39081 L p
1 g
F P
s
P
p
.002 w
.65493 .37134 m .65525 .33275 L .63488 .32001 L p
1 g
F P
s
P
p
.002 w
.43104 .25832 m .40581 .28001 L .42851 .28083 L p
1 g
F P
s
P
p
.002 w
.42851 .28083 m .44795 .26433 L .43104 .25832 L p
1 g
F P
s
P
p
.002 w
.33047 .34244 m .32942 .38481 L .34628 .36591 L p
1 g
F P
s
P
p
.002 w
.34628 .36591 m .34764 .32729 L .33047 .34244 L p
1 g
F P
s
P
p
.002 w
.52487 .60412 m .57917 .59339 L .58258 .57645 L p
1 g
F P
s
P
p
.002 w
.63206 .55348 m .58258 .57645 L .57917 .59339 L p
1 g
F P
s
P
p
.002 w
.58258 .57645 m .63206 .55348 L .63385 .5328 L p
1 g
F P
s
P
p
.002 w
.36811 .5672 m .41465 .59061 L .41157 .57356 L p
1 g
F P
s
P
p
.002 w
.41157 .57356 m .3631 .5489 L .36811 .5672 L p
1 g
F P
s
P
p
.002 w
.67205 .49872 m .63385 .5328 L .63206 .55348 L p
1 g
F P
s
P
p
.002 w
.63385 .5328 m .67205 .49872 L .66977 .47602 L p
1 g
F P
s
P
p
.002 w
.32683 .51443 m .3631 .5489 L .3618 .52815 L p
1 g
F P
s
P
p
.002 w
.3618 .52815 m .32508 .49276 L .32683 .51443 L p
1 g
F P
s
P
p
.002 w
.59872 .28346 m .57446 .2609 L .55712 .26629 L p
1 g
F P
s
P
p
.002 w
.53183 .25475 m .55712 .26629 L .57446 .2609 L p
1 g
F P
s
P
p
.002 w
.46484 .24428 m .43104 .25832 L .44795 .26433 L p
1 g
F P
s
P
p
.002 w
.44795 .26433 m .47373 .25371 L .46484 .24428 L p
1 g
F P
s
P
p
.002 w
.6197 .28736 m .63488 .32001 L .65525 .33275 L p
1 g
F P
s
P
p
.002 w
.63488 .32001 m .6197 .28736 L .59872 .28346 L p
1 g
F P
s
P
p
.002 w
.36638 .29041 m .34764 .32729 L .36829 .31527 L p
1 g
F P
s
P
p
.002 w
.36829 .31527 m .38489 .28316 L .36638 .29041 L p
1 g
F P
s
P
p
.002 w
.47029 .61563 m .52289 .61651 L .52487 .60412 L p
1 g
F P
s
P
p
.002 w
.52487 .60412 m .46847 .60317 L .47029 .61563 L p
1 g
F P
s
P
p
.002 w
.57917 .59339 m .52487 .60412 L .52289 .61651 L p
1 g
F P
s
P
p
.002 w
.42014 .60402 m .47029 .61563 L .46847 .60317 L p
1 g
F P
s
P
p
.002 w
.46847 .60317 m .41465 .59061 L .42014 .60402 L p
1 g
F P
s
P
p
.002 w
.69114 .43397 m .66977 .47602 L .67205 .49872 L p
1 g
F P
s
P
p
.002 w
.66977 .47602 m .69114 .43397 L .68349 .41184 L p
1 g
F P
s
P
p
.002 w
.67206 .34848 m .67126 .39081 L .68349 .41184 L p
1 g
F P
s
P
p
.002 w
.67126 .39081 m .67206 .34848 L .65525 .33275 L p
1 g
F P
s
P
p
.002 w
.30514 .44995 m .32508 .49276 L .32794 .47012 L p
1 g
F P
s
P
p
.002 w
.32794 .47012 m .3084 .42731 L .30514 .44995 L p
1 g
F P
s
P
p
.002 w
.31739 .36047 m .31663 .40542 L .32942 .38481 L p
1 g
F P
s
P
p
.002 w
.32942 .38481 m .33047 .34244 L .31739 .36047 L p
1 g
F P
s
P
p
.002 w
.57446 .2609 m .59872 .28346 L .6197 .28736 L p
1 g
F P
s
P
p
.002 w
.41536 .25673 m .38489 .28316 L .40581 .28001 L p
1 g
F P
s
P
p
.002 w
.40581 .28001 m .43104 .25832 L .41536 .25673 L p
1 g
F P
s
P
p
.002 w
.57446 .2609 m .54132 .24566 L .53183 .25475 L p
1 g
F P
s
P
p
.002 w
.50287 .25037 m .53183 .25475 L .54132 .24566 L p
1 g
F P
s
P
p
.002 w
.5032 .23985 m .46484 .24428 L .47373 .25371 L p
1 g
F P
s
P
p
.002 w
.47373 .25371 m .50287 .25037 L .5032 .23985 L p
1 g
F P
s
P
p
.002 w
.54132 .24566 m .5032 .23985 L .50287 .25037 L p
1 g
F P
s
P
p
.002 w
.57917 .59339 m .62667 .57158 L .63206 .55348 L p
1 g
F P
s
P
p
.002 w
.66976 .5203 m .63206 .55348 L .62667 .57158 L p
1 g
F P
s
P
p
.002 w
.63206 .55348 m .66976 .5203 L .67205 .49872 L p
1 g
F P
s
P
p
.002 w
.3334 .53452 m .36811 .5672 L .3631 .5489 L p
1 g
F P
s
P
p
.002 w
.3631 .5489 m .32683 .51443 L .3334 .53452 L p
1 g
F P
s
P
p
.002 w
.52289 .61651 m .57349 .6066 L .57917 .59339 L p
1 g
F P
s
P
p
.002 w
.62667 .57158 m .57917 .59339 L .57349 .6066 L p
1 g
F P
s
P
p
.002 w
.37689 .58243 m .42014 .60402 L .41465 .59061 L p
1 g
F P
s
P
p
.002 w
.41465 .59061 m .36811 .5672 L .37689 .58243 L p
1 g
F P
s
P
p
.002 w
.63816 .29526 m .65525 .33275 L .67206 .34848 L p
1 g
F P
s
P
p
.002 w
.65525 .33275 m .63816 .29526 L .6197 .28736 L p
1 g
F P
s
P
p
.002 w
.3509 .30177 m .33047 .34244 L .34764 .32729 L p
1 g
F P
s
P
p
.002 w
.34764 .32729 m .36638 .29041 L .3509 .30177 L p
1 g
F P
s
P
p
.002 w
.6847 .36694 m .68349 .41184 L .69114 .43397 L p
1 g
F P
s
P
p
.002 w
.68349 .41184 m .6847 .36694 L .67206 .34848 L p
1 g
F P
s
P
p
.002 w
.69382 .45669 m .67205 .49872 L .66976 .5203 L p
1 g
F P
s
P
p
.002 w
.67205 .49872 m .69382 .45669 L .69114 .43397 L p
1 g
F P
s
P
p
.002 w
.30894 .38102 m .3084 .42731 L .31663 .40542 L p
1 g
F P
s
P
p
.002 w
.31663 .40542 m .31739 .36047 L .30894 .38102 L p
1 g
F P
s
P
p
.002 w
.6197 .28736 m .59044 .25988 L .57446 .2609 L p
1 g
F P
s
P
p
.002 w
.54132 .24566 m .57446 .2609 L .59044 .25988 L p
1 g
F P
s
P
p
.002 w
.45654 .23955 m .41536 .25673 L .43104 .25832 L p
1 g
F P
s
P
p
.002 w
.43104 .25832 m .46484 .24428 L .45654 .23955 L p
1 g
F P
s
P
p
.002 w
.30719 .47277 m .32683 .51443 L .32508 .49276 L p
1 g
F P
s
P
p
.002 w
.32508 .49276 m .30514 .44995 L .30719 .47277 L p
1 g
F P
s
P
p
.002 w
.59044 .25988 m .6197 .28736 L .63816 .29526 L p
1 g
F P
s
P
p
.002 w
.40139 .25987 m .36638 .29041 L .38489 .28316 L p
1 g
F P
s
P
p
.002 w
.38489 .28316 m .41536 .25673 L .40139 .25987 L p
1 g
F P
s
P
p
.002 w
.473 .62357 m .52021 .62436 L .52289 .61651 L p
1 g
F P
s
P
p
.002 w
.52289 .61651 m .47029 .61563 L .473 .62357 L p
1 g
F P
s
P
p
.002 w
.57349 .6066 m .52289 .61651 L .52021 .62436 L p
1 g
F P
s
P
p
.002 w
.42804 .61322 m .473 .62357 L .47029 .61563 L p
1 g
F P
s
P
p
.002 w
.47029 .61563 m .42014 .60402 L .42804 .61322 L p
1 g
F P
s
P
p
.002 w
.59044 .25988 m .55008 .24124 L .54132 .24566 L p
1 g
F P
s
P
p
.002 w
.5032 .23985 m .54132 .24566 L .55008 .24124 L p
1 g
F P
s
P
p
.002 w
.50345 .23411 m .45654 .23955 L .46484 .24428 L p
1 g
F P
s
P
p
.002 w
.46484 .24428 m .5032 .23985 L .50345 .23411 L p
1 g
F P
s
P
p
.002 w
.57349 .6066 m .61764 .5865 L .62667 .57158 L p
1 g
F P
s
P
p
.002 w
.66276 .54014 m .62667 .57158 L .61764 .5865 L p
1 g
F P
s
P
p
.002 w
.62667 .57158 m .66276 .54014 L .66976 .5203 L p
1 g
F P
s
P
p
.002 w
.34482 .55239 m .37689 .58243 L .36811 .5672 L p
1 g
F P
s
P
p
.002 w
.36811 .5672 m .3334 .53452 L .34482 .55239 L p
1 g
F P
s
P
p
.002 w
.65347 .30716 m .67206 .34848 L .6847 .36694 L p
1 g
F P
s
P
p
.002 w
.67206 .34848 m .65347 .30716 L .63816 .29526 L p
1 g
F P
s
P
p
.002 w
.55008 .24124 m .50345 .23411 L .5032 .23985 L p
1 g
F P
s
P
p
.002 w
.52021 .62436 m .56558 .61553 L .57349 .6066 L p
1 g
F P
s
P
p
.002 w
.61764 .5865 m .57349 .6066 L .56558 .61553 L p
1 g
F P
s
P
p
.002 w
.38943 .59402 m .42804 .61322 L .42014 .60402 L p
1 g
F P
s
P
p
.002 w
.42014 .60402 m .37689 .58243 L .38943 .59402 L p
1 g
F P
s
P
p
.002 w
.33903 .31714 m .31739 .36047 L .33047 .34244 L p
1 g
F P
s
P
p
.002 w
.33047 .34244 m .3509 .30177 L .33903 .31714 L p
1 g
F P
s
P
p
.002 w
.69264 .38776 m .69114 .43397 L .69382 .45669 L p
1 g
F P
s
P
p
.002 w
.69114 .43397 m .69264 .38776 L .6847 .36694 L p
1 g
F P
s
P
p
.002 w
.30559 .40363 m .30514 .44995 L .3084 .42731 L p
1 g
F P
s
P
p
.002 w
.3084 .42731 m .30894 .38102 L .30559 .40363 L p
1 g
F P
s
P
p
.002 w
.69121 .4794 m .66976 .5203 L .66276 .54014 L p
1 g
F P
s
P
p
.002 w
.66976 .5203 m .69121 .4794 L .69382 .45669 L p
1 g
F P
s
P
p
.002 w
.31474 .49511 m .3334 .53452 L .32683 .51443 L p
1 g
F P
s
P
p
.002 w
.32683 .51443 m .30719 .47277 L .31474 .49511 L p
1 g
F P
s
P
p
.002 w
.63816 .29526 m .60456 .26352 L .59044 .25988 L p
1 g
F P
s
P
p
.002 w
.55008 .24124 m .59044 .25988 L .60456 .26352 L p
1 g
F P
s
P
p
.002 w
.44909 .23994 m .40139 .25987 L .41536 .25673 L p
1 g
F P
s
P
p
.002 w
.41536 .25673 m .45654 .23955 L .44909 .23994 L p
1 g
F P
s
P
p
.002 w
.60456 .26352 m .63816 .29526 L .65347 .30716 L p
1 g
F P
s
P
p
.002 w
.38963 .26794 m .3509 .30177 L .36638 .29041 L p
1 g
F P
s
P
p
.002 w
.36638 .29041 m .40139 .25987 L .38963 .26794 L p
1 g
F P
s
P
p
.004 w
.40728 .59897 m
.5 .43051 L
s
P
p
.004 w
.39761 .61654 m
.40559 .60205 L
s
P
p
.004 w
.35979 .68526 m
.39761 .61654 L
s
P
p
.002 w
.47657 .6265 m .51686 .62718 L .52021 .62436 L p
1 g
F P
s
P
p
.002 w
.52021 .62436 m .473 .62357 L .47657 .6265 L p
1 g
F P
s
P
p
.002 w
.56558 .61553 m .52021 .62436 L .51686 .62718 L p
1 g
F P
s
P
p
.002 w
.43829 .6177 m .47657 .6265 L .473 .62357 L p
1 g
F P
s
P
p
.002 w
.473 .62357 m .42804 .61322 L .43829 .6177 L p
1 g
F P
s
P
p
.002 w
.6847 .36694 m .66503 .32294 L .65347 .30716 L p
1 g
F P
s
P
p
.002 w
.66503 .32294 m .6847 .36694 L .69264 .38776 L p
1 g
F P
s
P
p
.002 w
.56558 .61553 m .605 .59766 L .61764 .5865 L p
1 g
F P
s
P
p
.002 w
.65099 .55759 m .61764 .5865 L .605 .59766 L p
1 g
F P
s
P
p
.002 w
.61764 .5865 m .65099 .55759 L .66276 .54014 L p
1 g
F P
s
P
p
.002 w
.36102 .56741 m .38943 .59402 L .37689 .58243 L p
1 g
F P
s
P
p
.002 w
.37689 .58243 m .34482 .55239 L .36102 .56741 L p
1 g
F P
s
P
p
.002 w
.69382 .45669 m .69543 .41044 L .69264 .38776 L p
1 g
F P
s
P
p
.002 w
.69543 .41044 m .69382 .45669 L .69121 .4794 L p
1 g
F P
s
P
p
.002 w
.33133 .33629 m .30894 .38102 L .31739 .36047 L p
1 g
F P
s
P
p
.002 w
.31739 .36047 m .33903 .31714 L .33133 .33629 L p
1 g
F P
s
P
p
.004 w
.49701 .67012 m
.49735 .64351 L
s
P
p
.002 w
.60456 .26352 m .55782 .2419 L .55008 .24124 L p
1 g
F P
s
P
p
.002 w
.50345 .23411 m .55008 .24124 L .55782 .2419 L p
1 g
F P
s
P
p
.002 w
.3077 .42771 m .30719 .47277 L .30514 .44995 L p
1 g
F P
s
P
p
.002 w
.30514 .44995 m .30559 .40363 L .3077 .42771 L p
1 g
F P
s
P
p
.002 w
.50362 .23361 m .44909 .23994 L .45654 .23955 L p
1 g
F P
s
P
p
.002 w
.45654 .23955 m .50345 .23411 L .50362 .23361 L p
1 g
F P
s
P
p
.002 w
.66276 .54014 m .68314 .50144 L .69121 .4794 L p
1 g
F P
s
P
p
.002 w
.68314 .50144 m .66276 .54014 L .65099 .55759 L p
1 g
F P
s
P
p
.002 w
.51686 .62718 m .5555 .61966 L .56558 .61553 L p
1 g
F P
s
P
p
.002 w
.605 .59766 m .56558 .61553 L .5555 .61966 L p
1 g
F P
s
P
p
.002 w
.40557 .60142 m .43829 .6177 L .42804 .61322 L p
1 g
F P
s
P
p
.002 w
.42804 .61322 m .38943 .59402 L .40557 .60142 L p
1 g
F P
s
P
p
.002 w
.32781 .51629 m .34482 .55239 L .3334 .53452 L p
1 g
F P
s
P
p
.002 w
.3334 .53452 m .31474 .49511 L .32781 .51629 L p
1 g
F P
s
P
p
.002 w
.55782 .2419 m .50362 .23361 L .50345 .23411 L p
1 g
F P
s
P
p
.002 w
.65347 .30716 m .61631 .272 L .60456 .26352 L p
1 g
F P
s
P
p
.002 w
.61631 .272 m .65347 .30716 L .66503 .32294 L p
1 g
F P
s
P
p
.002 w
.38057 .28098 m .33903 .31714 L .3509 .30177 L p
1 g
F P
s
P
p
.002 w
.3509 .30177 m .38963 .26794 L .38057 .28098 L p
1 g
F P
s
P
p
.002 w
.55782 .2419 m .60456 .26352 L .61631 .272 L p
1 g
F P
s
P
p
.002 w
.44276 .24577 m .38963 .26794 L .40139 .25987 L p
1 g
F P
s
P
p
.002 w
.40139 .25987 m .44909 .23994 L .44276 .24577 L p
1 g
F P
s
P
p
.002 w
.6723 .34233 m .69264 .38776 L .69543 .41044 L p
1 g
F P
s
P
p
.002 w
.69264 .38776 m .6723 .34233 L .66503 .32294 L p
1 g
F P
s
P
p
.002 w
.69272 .43442 m .69121 .4794 L .68314 .50144 L p
1 g
F P
s
P
p
.002 w
.69121 .4794 m .69272 .43442 L .69543 .41044 L p
1 g
F P
s
P
p
.002 w
.32826 .35883 m .30559 .40363 L .30894 .38102 L p
1 g
F P
s
P
p
.002 w
.30894 .38102 m .33133 .33629 L .32826 .35883 L p
1 g
F P
s
P
p
.002 w
.31545 .4526 m .31474 .49511 L .30719 .47277 L p
1 g
F P
s
P
p
.002 w
.30719 .47277 m .3077 .42771 L .31545 .4526 L p
1 g
F P
s
P
p
.002 w
.5555 .61966 m .58891 .60451 L .605 .59766 L p
1 g
F P
s
P
p
.002 w
.605 .59766 m .63455 .57204 L .65099 .55759 L p
1 g
F P
s
P
p
.002 w
.63455 .57204 m .605 .59766 L .58891 .60451 L p
1 g
F P
s
P
p
.002 w
.38175 .57898 m .40557 .60142 L .38943 .59402 L p
1 g
F P
s
P
p
.002 w
.38943 .59402 m .36102 .56741 L .38175 .57898 L p
1 g
F P
s
P
p
.002 w
.48097 .62399 m .51287 .62453 L .51686 .62718 L p
1 g
F P
s
P
p
.002 w
.51686 .62718 m .47657 .6265 L .48097 .62399 L p
1 g
F P
s
P
p
.002 w
.5555 .61966 m .51686 .62718 L .51287 .62453 L p
1 g
F P
s
P
p
.002 w
.45072 .61702 m .48097 .62399 L .47657 .6265 L p
1 g
F P
s
P
p
.002 w
.47657 .6265 m .43829 .6177 L .45072 .61702 L p
1 g
F P
s
P
p
.002 w
.6696 .52214 m .65099 .55759 L .63455 .57204 L p
1 g
F P
s
P
p
.002 w
.65099 .55759 m .6696 .52214 L .68314 .50144 L p
1 g
F P
s
P
p
.002 w
.34624 .53559 m .36102 .56741 L .34482 .55239 L p
1 g
F P
s
P
p
.002 w
.34482 .55239 m .32781 .51629 L .34624 .53559 L p
1 g
F P
s
P
p
.002 w
.61631 .272 m .56425 .24796 L .55782 .2419 L p
1 g
F P
s
P
p
.002 w
.50362 .23361 m .55782 .2419 L .56425 .24796 L p
1 g
F P
s
P
p
.002 w
.5037 .23873 m .44276 .24577 L .44909 .23994 L p
1 g
F P
s
P
p
.002 w
.44909 .23994 m .50362 .23361 L .5037 .23873 L p
1 g
F P
s
P
p
.002 w
.51287 .62453 m .54341 .61858 L .5555 .61966 L p
1 g
F P
s
P
p
.002 w
.58891 .60451 m .5555 .61966 L .54341 .61858 L p
1 g
F P
s
P
p
.002 w
.42502 .60418 m .45072 .61702 L .43829 .6177 L p
1 g
F P
s
P
p
.002 w
.43829 .6177 m .40557 .60142 L .42502 .60418 L p
1 g
F P
s
P
p
.002 w
.62519 .28535 m .66503 .32294 L .6723 .34233 L p
1 g
F P
s
P
p
.002 w
.66503 .32294 m .62519 .28535 L .61631 .272 L p
1 g
F P
s
P
p
.002 w
.56425 .24796 m .5037 .23873 L .50362 .23361 L p
1 g
F P
s
P
p
.002 w
.37464 .29888 m .33133 .33629 L .33903 .31714 L p
1 g
F P
s
P
p
.002 w
.33903 .31714 m .38057 .28098 L .37464 .29888 L p
1 g
F P
s
P
p
.002 w
.56425 .24796 m .61631 .272 L .62519 .28535 L p
1 g
F P
s
P
p
.002 w
.43783 .25722 m .38057 .28098 L .38963 .26794 L p
1 g
F P
s
P
p
.002 w
.38963 .26794 m .44276 .24577 L .43783 .25722 L p
1 g
F P
s
P
p
.002 w
.67482 .36494 m .69543 .41044 L .69272 .43442 L p
1 g
F P
s
P
p
.002 w
.69543 .41044 m .67482 .36494 L .6723 .34233 L p
1 g
F P
s
P
p
.002 w
.68435 .45899 m .68314 .50144 L .6696 .52214 L p
1 g
F P
s
P
p
.002 w
.68314 .50144 m .68435 .45899 L .69272 .43442 L p
1 g
F P
s
P
p
.002 w
.33014 .38419 m .3077 .42771 L .30559 .40363 L p
1 g
F P
s
P
p
.002 w
.30559 .40363 m .32826 .35883 L .33014 .38419 L p
1 g
F P
s
P
p
.002 w
.32882 .47751 m .32781 .51629 L .31474 .49511 L p
1 g
F P
s
P
p
.002 w
.31474 .49511 m .31545 .4526 L .32882 .47751 L p
1 g
F P
s
P
p
.002 w
.54341 .61858 m .56966 .60661 L .58891 .60451 L p
1 g
F P
s
P
p
.002 w
.61371 .5829 m .58891 .60451 L .56966 .60661 L p
1 g
F P
s
P
p
.002 w
.58891 .60451 m .61371 .5829 L .63455 .57204 L p
1 g
F P
s
P
p
.002 w
.65075 .54079 m .63455 .57204 L .61371 .5829 L p
1 g
F P
s
P
p
.002 w
.63455 .57204 m .65075 .54079 L .6696 .52214 L p
1 g
F P
s
P
p
.002 w
.40655 .58657 m .42502 .60418 L .40557 .60142 L p
1 g
F P
s
P
p
.002 w
.40557 .60142 m .38175 .57898 L .40655 .58657 L p
1 g
F P
s
P
p
.002 w
.36966 .55232 m .38175 .57898 L .36102 .56741 L p
1 g
F P
s
P
p
.002 w
.36102 .56741 m .34624 .53559 L .36966 .55232 L p
1 g
F P
s
P
p
.002 w
.48611 .61577 m .50834 .61614 L .51287 .62453 L p
1 g
F P
s
P
p
.002 w
.51287 .62453 m .48097 .62399 L .48611 .61577 L p
1 g
F P
s
P
p
.002 w
.54341 .61858 m .51287 .62453 L .50834 .61614 L p
1 g
F P
s
P
p
.002 w
.46509 .61089 m .48611 .61577 L .48097 .62399 L p
1 g
F P
s
P
p
.002 w
.48097 .62399 m .45072 .61702 L .46509 .61089 L p
1 g
F P
s
P
p
.002 w
.63076 .30345 m .6723 .34233 L .67482 .36494 L p
1 g
F P
s
P
p
.002 w
.6723 .34233 m .63076 .30345 L .62519 .28535 L p
1 g
F P
s
P
p
.002 w
.62519 .28535 m .56908 .25958 L .56425 .24796 L p
1 g
F P
s
P
p
.002 w
.5037 .23873 m .56425 .24796 L .56908 .25958 L p
1 g
F P
s
P
p
.002 w
.50366 .24967 m .43783 .25722 L .44276 .24577 L p
1 g
F P
s
P
p
.002 w
.44276 .24577 m .5037 .23873 L .50366 .24967 L p
1 g
F P
s
P
p
.002 w
.37223 .32133 m .32826 .35883 L .33133 .33629 L p
1 g
F P
s
P
p
.002 w
.33133 .33629 m .37464 .29888 L .37223 .32133 L p
1 g
F P
s
P
p
.002 w
.50834 .61614 m .52957 .61197 L .54341 .61858 L p
1 g
F P
s
P
p
.002 w
.56966 .60661 m .54341 .61858 L .52957 .61197 L p
1 g
F P
s
P
p
.002 w
.44736 .60194 m .46509 .61089 L .45072 .61702 L p
1 g
F P
s
P
p
.002 w
.45072 .61702 m .42502 .60418 L .44736 .60194 L p
1 g
F P
s
P
p
.002 w
.67035 .4834 m .6696 .52214 L .65075 .54079 L p
1 g
F P
s
P
p
.002 w
.6696 .52214 m .67035 .4834 L .68435 .45899 L p
1 g
F P
s
P
p
.002 w
.6723 .39019 m .69272 .43442 L .68435 .45899 L p
1 g
F P
s
P
p
.002 w
.69272 .43442 m .6723 .39019 L .67482 .36494 L p
1 g
F P
s
P
p
.002 w
.34758 .50162 m .34624 .53559 L .32781 .51629 L p
1 g
F P
s
P
p
.002 w
.32781 .51629 m .32882 .47751 L .34758 .50162 L p
1 g
F P
s
P
p
.002 w
.33713 .41164 m .31545 .4526 L .3077 .42771 L p
1 g
F P
s
P
p
.002 w
.3077 .42771 m .33014 .38419 L .33713 .41164 L p
1 g
F P
s
P
p
.002 w
.56908 .25958 m .50366 .24967 L .5037 .23873 L p
1 g
F P
s
P
p
.002 w
.56908 .25958 m .62519 .28535 L .63076 .30345 L p
1 g
F P
s
P
p
.002 w
.43455 .27427 m .37464 .29888 L .38057 .28098 L p
1 g
F P
s
P
p
.002 w
.38057 .28098 m .43783 .25722 L .43455 .27427 L p
1 g
F P
s
P
p
.002 w
.56966 .60661 m .58891 .58965 L .61371 .5829 L p
1 g
F P
s
P
p
.002 w
.627 .5567 m .61371 .5829 L .58891 .58965 L p
1 g
F P
s
P
p
.002 w
.61371 .5829 m .627 .5567 L .65075 .54079 L p
1 g
F P
s
P
p
.002 w
.39747 .56582 m .40655 .58657 L .38175 .57898 L p
1 g
F P
s
P
p
.002 w
.38175 .57898 m .36966 .55232 L .39747 .56582 L p
1 g
F P
s
P
p
.002 w
.52957 .61197 m .54769 .60363 L .56966 .60661 L p
1 g
F P
s
P
p
.002 w
.58891 .58965 m .56966 .60661 L .54769 .60363 L p
1 g
F P
s
P
p
.002 w
.4348 .58976 m .44736 .60194 L .42502 .60418 L p
1 g
F P
s
P
p
.002 w
.42502 .60418 m .40655 .58657 L .4348 .58976 L p
1 g
F P
s
P
p
.002 w
.65096 .50683 m .65075 .54079 L .627 .5567 L p
1 g
F P
s
P
p
.002 w
.65075 .54079 m .65096 .50683 L .67035 .4834 L p
1 g
F P
s
P
p
.002 w
.63265 .32596 m .67482 .36494 L .6723 .39019 L p
1 g
F P
s
P
p
.002 w
.67482 .36494 m .63265 .32596 L .63076 .30345 L p
1 g
F P
s
P
p
.002 w
.66457 .41736 m .68435 .45899 L .67035 .4834 L p
1 g
F P
s
P
p
.002 w
.68435 .45899 m .66457 .41736 L .6723 .39019 L p
1 g
F P
s
P
p
.002 w
.37127 .52406 m .36966 .55232 L .34624 .53559 L p
1 g
F P
s
P
p
.002 w
.34624 .53559 m .34758 .50162 L .37127 .52406 L p
1 g
F P
s
P
p
.002 w
.37358 .34778 m .33014 .38419 L .32826 .35883 L p
1 g
F P
s
P
p
.002 w
.32826 .35883 m .37223 .32133 L .37358 .34778 L p
1 g
F P
s
P
p
.002 w
.3492 .44031 m .32882 .47751 L .31545 .4526 L p
1 g
F P
s
P
p
.002 w
.31545 .4526 m .33713 .41164 L .3492 .44031 L p
1 g
F P
s
P
p
.002 w
.49188 .60173 m .50337 .60192 L .50834 .61614 L p
1 g
F P
s
P
p
.002 w
.50834 .61614 m .48611 .61577 L .49188 .60173 L p
1 g
F P
s
P
p
.002 w
.52957 .61197 m .50834 .61614 L .50337 .60192 L p
1 g
F P
s
P
p
.002 w
.48104 .59918 m .49188 .60173 L .48611 .61577 L p
1 g
F P
s
P
p
.002 w
.48611 .61577 m .46509 .61089 L .48104 .59918 L p
1 g
F P
s
P
p
.002 w
.63076 .30345 m .57206 .27674 L .56908 .25958 L p
1 g
F P
s
P
p
.002 w
.50366 .24967 m .56908 .25958 L .57206 .27674 L p
1 g
F P
s
P
p
.002 w
.50352 .26644 m .43455 .27427 L .43783 .25722 L p
1 g
F P
s
P
p
.002 w
.43783 .25722 m .50366 .24967 L .50352 .26644 L p
1 g
F P
s
P
p
.002 w
.50337 .60192 m .51432 .59974 L .52957 .61197 L p
1 g
F P
s
P
p
.002 w
.54769 .60363 m .52957 .61197 L .51432 .59974 L p
1 g
F P
s
P
p
.002 w
.47197 .59454 m .48104 .59918 L .46509 .61089 L p
1 g
F P
s
P
p
.002 w
.46509 .61089 m .44736 .60194 L .47197 .59454 L p
1 g
F P
s
P
p
.002 w
.57206 .27674 m .63076 .30345 L .63265 .32596 L p
1 g
F P
s
P
p
.002 w
.54769 .60363 m .5608 .59188 L .58891 .58965 L p
1 g
F P
s
P
p
.002 w
.59894 .56923 m .58891 .58965 L .5608 .59188 L p
1 g
F P
s
P
p
.002 w
.58891 .58965 m .59894 .56923 L .627 .5567 L p
1 g
F P
s
P
p
.002 w
.42885 .57552 m .4348 .58976 L .40655 .58657 L p
1 g
F P
s
P
p
.002 w
.40655 .58657 m .39747 .56582 L .42885 .57552 L p
1 g
F P
s
P
p
.002 w
.43312 .29665 m .37223 .32133 L .37464 .29888 L p
1 g
F P
s
P
p
.002 w
.37464 .29888 m .43455 .27427 L .43312 .29665 L p
1 g
F P
s
P
p
.002 w
.57206 .27674 m .50352 .26644 L .50366 .24967 L p
1 g
F P
s
P
p
.002 w
.51432 .59974 m .5236 .59541 L .54769 .60363 L p
1 g
F P
s
P
p
.002 w
.5608 .59188 m .54769 .60363 L .5236 .59541 L p
1 g
F P
s
P
p
.002 w
.46565 .58826 m .47197 .59454 L .44736 .60194 L p
1 g
F P
s
P
p
.002 w
.44736 .60194 m .4348 .58976 L .46565 .58826 L p
1 g
F P
s
P
p
.002 w
.62669 .52843 m .627 .5567 L .59894 .56923 L p
1 g
F P
s
P
p
.002 w
.627 .5567 m .62669 .52843 L .65096 .50683 L p
1 g
F P
s
P
p
.002 w
.39916 .54401 m .39747 .56582 L .36966 .55232 L p
1 g
F P
s
P
p
.002 w
.36966 .55232 m .37127 .52406 L .39916 .54401 L p
1 g
F P
s
P
p
.002 w
.65172 .44556 m .67035 .4834 L .65096 .50683 L p
1 g
F P
s
P
p
.002 w
.67035 .4834 m .65172 .44556 L .66457 .41736 L p
1 g
F P
s
P
p
.002 w
.36606 .46921 m .34758 .50162 L .32882 .47751 L p
1 g
F P
s
P
p
.002 w
.32882 .47751 m .3492 .44031 L .36606 .46921 L p
1 g
F P
s
P
p
.002 w
.63061 .35232 m .6723 .39019 L .66457 .41736 L p
1 g
F P
s
P
p
.002 w
.6723 .39019 m .63061 .35232 L .63265 .32596 L p
1 g
F P
s
P
p
.002 w
.37882 .37746 m .33713 .41164 L .33014 .38419 L p
1 g
F P
s
P
p
.002 w
.33014 .38419 m .37358 .34778 L .37882 .37746 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.49853 .54865 m
.5 .43051 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.5236 .59541 m .5302 .58935 L .5608 .59188 L p
1 g
F P
s
P
p
.002 w
.5674 .57786 m .5608 .59188 L .5302 .58935 L p
1 g
F P
s
P
p
.002 w
.5608 .59188 m .5674 .57786 L .59894 .56923 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.46278 .581 m .46565 .58826 L .4348 .58976 L p
1 g
F P
s
P
p
.002 w
.4348 .58976 m .42885 .57552 L .46278 .581 L p
1 g
F P
s
P
p
.002 w
.50337 .60192 m .49188 .60173 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.51432 .59974 m .50337 .60192 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.49188 .60173 m .48104 .59918 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.59825 .5474 m .59894 .56923 L .5674 .57786 L p
1 g
F P
s
P
p
.002 w
.59894 .56923 m .59825 .5474 L .62669 .52843 L p
1 g
F P
s
P
p
.002 w
.5236 .59541 m .51432 .59974 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.63265 .32596 m .57298 .29915 L .57206 .27674 L p
1 g
F P
s
P
p
.002 w
.50352 .26644 m .57206 .27674 L .57298 .29915 L p
1 g
F P
s
P
p
.002 w
.43035 .5607 m .42885 .57552 L .39747 .56582 L p
1 g
F P
s
P
p
.002 w
.39747 .56582 m .39916 .54401 L .43035 .5607 L p
1 g
F P
s
P
p
.002 w
.48104 .59918 m .47197 .59454 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.50327 .28881 m .43312 .29665 L .43455 .27427 L p
1 g
F P
s
P
p
.002 w
.43455 .27427 m .50352 .26644 L .50327 .28881 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63402 .47384 m .65096 .50683 L .62669 .52843 L p
1 g
F P
s
P
p
.002 w
.65096 .50683 m .63402 .47384 L .65172 .44556 L p
1 g
F P
s
P
p
.002 w
.57298 .29915 m .63265 .32596 L .63061 .35232 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.38722 .4973 m .37127 .52406 L .34758 .50162 L p
1 g
F P
s
P
p
.002 w
.34758 .50162 m .36606 .46921 L .38722 .4973 L p
1 g
F P
s
P
p
.002 w
.43369 .32384 m .37358 .34778 L .37223 .32133 L p
1 g
F P
s
P
p
.002 w
.37223 .32133 m .43312 .29665 L .43369 .32384 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.5302 .58935 m .5236 .59541 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.47197 .59454 m .46565 .58826 L .49811 .58199 L closepath p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.62454 .38177 m .66457 .41736 L .65172 .44556 L p
1 g
F P
s
P
p
.002 w
.66457 .41736 m .62454 .38177 L .63061 .35232 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.57298 .29915 m .50327 .28881 L .50352 .26644 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.38789 .40938 m .3492 .44031 L .33713 .41164 L p
1 g
F P
s
P
p
.002 w
.33713 .41164 m .37882 .37746 L .38789 .40938 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.5302 .58935 m .5334 .58219 L .5674 .57786 L p
1 g
F P
s
P
p
.002 w
.56659 .56301 m .5674 .57786 L .5334 .58219 L p
1 g
F P
s
P
p
.002 w
.5674 .57786 m .56659 .56301 L .59825 .5474 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58071 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .58071 L .5113 .58061 L 1 g
F
P
p
.002 w
.5334 .58219 m .50599 .58204 L p
.51095 .58071 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53182 .57511 L p
1 g
F P
s
P
p
.002 w
.53282 .57484 m .53318 .57942 L p
.52242 .58004 L 1 g
F P
s
P
p
.53282 .57484 m .52242 .58004 L .53182 .57511 L 1 g
F
P
p
.54854 .56129 m .53182 .57511 L .53249 .57475 L 1 g
F
P
p
.002 w
.56659 .56301 m .5328 .57469 L p
.53317 .57432 L 1 g
F P
s
P
p
.002 w
.56142 .55433 m .56659 .56301 L p
.5422 .57126 L 1 g
F P
s
P
p
.54917 .563 m .5422 .57126 L .53317 .57432 L 1 g
F
P
p
.56142 .55433 m .5422 .57126 L .54917 .563 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54917 .563 L p
1 g
F P
s
P
p
.56075 .54566 m .54917 .563 L .55499 .5561 L 1 g
F
P
p
.54854 .56129 m .53249 .57475 L .53276 .57461 L 1 g
F
P
p
.54854 .56129 m .53276 .57461 L .53977 .56965 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.52841 .56765 m .55822 .54895 L p
.53317 .57432 L 1 g
F P
s
P
p
.002 w
.5328 .57469 m .53276 .57461 L p
.53317 .57432 L 1 g
F P
s
P
p
.002 w
.53276 .57461 m .52841 .56765 L p
.53317 .57432 L 1 g
F P
s
P
p
.002 w
.5328 .57469 m .53282 .57484 L p
.53201 .575 L 1 g
F P
s
P
p
.002 w
.46278 .581 m .46304 .57895 L p
.49111 .58139 L 1 g
F P
s
P
p
.002 w
.49272 .58184 m .46278 .581 L p
.49111 .58139 L 1 g
F P
s
P
p
.002 w
.48905 .5808 m .48921 .57862 L p
.4781 .57771 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46822 .57492 L p
1 g
F P
s
P
p
.48921 .57862 m .46822 .57492 L .4781 .57771 L 1 g
F
P
p
.002 w
.49811 .58199 m .49272 .58184 L p
.49111 .58139 L 1 g
F P
s
P
p
.002 w
.495 .58123 m .49811 .58199 L p
.46304 .57895 L 1 g
F P
s
P
p
.002 w
.46565 .58826 m .46278 .581 L .49272 .58184 L p
1 g
F P
s
P
p
.002 w
.49272 .58184 m .49811 .58199 L .49528 .58254 L p
1 g
F P
s
P
p
.002 w
.49528 .58254 m .46565 .58826 L p
.49272 .58184 L 1 g
F P
s
P
p
.002 w
.46304 .57895 m .46371 .57364 L p
.46822 .57492 L 1 g
F P
s
P
p
.47759 .57999 m .46822 .57492 L .48905 .5808 L 1 g
F
P
p
.46304 .57895 m .46822 .57492 L .47759 .57999 L 1 g
F
P
p
.002 w
.45755 .57115 m .43035 .5607 L p
.45166 .56402 L 1 g
F P
s
P
p
.002 w
.43035 .5607 m .39916 .54401 L p
.43764 .5468 L 1 g
F P
s
P
p
.43764 .5468 m .4382 .54764 L .43035 .5607 L 1 g
F
P
p
.002 w
.43856 .54816 m .43844 .54835 L p
.4382 .54764 L 1 g
F P
s
P
p
.002 w
.43844 .54835 m .43035 .5607 L p
.4382 .54764 L 1 g
F P
s
P
p
.002 w
.4382 .54764 m .43925 .54566 L p
.43536 .53798 L 1 g
F P
s
P
p
.002 w
.43741 .54526 m .43199 .54062 L p
.43298 .52951 L 1 g
F P
s
P
p
.002 w
.43199 .54062 m .41195 .52353 L p
.43263 .52941 L 1 g
F P
s
P
p
.43263 .52941 m .43298 .52951 L .43199 .54062 L 1 g
F
P
p
.002 w
.43269 .52847 m .43346 .52734 L p
.43319 .51968 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43269 .52847 L p
1 g
F P
s
P
p
.43925 .54566 m .43269 .52847 L .43536 .53798 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43378 .50954 L p
1 g
F P
s
P
p
.002 w
.428 .51183 m .43389 .50753 L p
.43378 .50954 L 1 g
F P
s
P
p
.42981 .51826 m .43378 .50954 L .43269 .52847 L 1 g
F
P
p
.428 .51183 m .43378 .50954 L .42981 .51826 L 1 g
F
P
p
.4164 .47533 m .44468 .48734 L .44273 .4912 L 1 g
F
P
p
.002 w
.43482 .50686 m .43184 .50175 L p
.44273 .4912 L 1 g
F P
s
P
p
.002 w
.43184 .50175 m .4164 .47533 L p
.44273 .4912 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43504 .50678 m .43482 .50686 L p
.44468 .48734 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44219 .49178 L p
1 g
F P
s
P
p
.002 w
.44219 .49178 m .44166 .49233 L p
.43939 .49764 L 1 g
F P
s
P
p
.43485 .50826 m .44219 .49178 L .43939 .49764 L 1 g
F
P
p
.43485 .50826 m .43829 .50023 L .43777 .50127 L 1 g
F
P
p
.002 w
.43378 .50954 m .43485 .50826 L p
.44043 .49491 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.46536 .49612 m .47588 .52868 L p
.43496 .50693 L 1 g
F P
s
P
p
.002 w
.43482 .50686 m .43504 .50678 L p
.43496 .50693 L 1 g
F P
s
P
p
.002 w
.43504 .50678 m .46536 .49612 L p
.43496 .50693 L 1 g
F P
s
P
p
.002 w
.4428 .49113 m .44339 .4905 L p
.44854 .48556 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46536 .49612 m .43504 .50678 L p
.4428 .49113 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4577 .47669 L p
1 g
F P
s
P
p
.44339 .4905 m .4577 .47669 L .44854 .48556 L 1 g
F
P
p
.44468 .48734 m .44609 .48794 L .4428 .49113 L 1 g
F
P
p
.44609 .48794 m .46536 .49612 L .4428 .49113 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4577 .47669 m .45826 .47608 L p
.46644 .47249 L 1 g
F P
s
P
p
.46956 .47098 m .49996 .49278 L .45978 .47573 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.46956 .47098 m .47829 .46695 L .49996 .49278 L 1 g
F
P
p
.47829 .46695 m .5 .46392 L .49996 .49278 L 1 g
F
P
p
.002 w
.5 .46392 m .5 .4634 L p
.50963 .46527 L 1 g
F P
s
P
p
.50755 .46498 m .53438 .4973 L .5005 .464 L 1 g
F
P
p
.50963 .46527 m .5005 .464 L .5 .46392 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.50063 .45665 m .54523 .46265 L .54296 .46991 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56438 .50908 m .53438 .4973 L .54101 .47611 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54232 .47671 L p
1 g
F P
s
P
p
.52214 .46667 m .54232 .47671 L .54145 .47631 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56626 .50958 L p
1 g
F P
s
P
p
.58389 .47822 m .56698 .51114 L .56626 .50958 L 1 g
F
P
p
.002 w
.56532 .50758 m .56598 .50655 L p
.56626 .50958 L 1 g
F P
s
P
p
.002 w
.56598 .50655 m .58389 .47822 L p
.56626 .50958 L 1 g
F P
s
P
p
.002 w
.58643 .52652 m .56698 .51114 L p
.58389 .47822 L 1 g
F P
s
P
p
.002 w
.56626 .50958 m .56515 .50826 L p
.5668 .51898 L 1 g
F P
s
P
p
.002 w
.58643 .52652 m .568 .54117 L p
.56731 .52847 L 1 g
F P
s
P
p
.002 w
.56635 .51064 m .57132 .51457 L p
.56731 .52847 L 1 g
F P
s
P
p
.002 w
.57132 .51457 m .58643 .52652 L p
.56731 .52847 L 1 g
F P
s
P
p
.002 w
.56731 .52847 m .56654 .52734 L p
.56464 .53774 L 1 g
F P
s
P
p
.5668 .51898 m .56635 .51064 L .56626 .50958 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55938 .5509 m .56142 .55433 L p
.54917 .563 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .55275 .56165 L p
.5563 .55455 L 1 g
F P
s
P
p
.56075 .54566 m .55499 .5561 L .5563 .55455 L 1 g
F
P
p
.55499 .5561 m .54998 .56518 L .5563 .55455 L 1 g
F
P
p
.002 w
.56659 .56301 m .56013 .55217 L p
.58643 .52652 L 1 g
F P
s
P
p
.002 w
.56013 .55217 m .55938 .5509 L p
.5611 .54935 L 1 g
F P
s
P
p
.58643 .52652 m .56013 .55217 L .5611 .54935 L 1 g
F
P
p
.002 w
.56379 .54451 m .58643 .52652 L p
.5611 .54935 L 1 g
F P
s
P
p
.5611 .54935 m .55938 .5509 L .56173 .5475 L 1 g
F
P
p
.5611 .54935 m .56173 .5475 L .56379 .54451 L 1 g
F
P
p
.002 w
.56173 .5475 m .56075 .54566 L p
.55485 .55745 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56173 .5475 L p
1 g
F P
s
P
p
.002 w
.56236 .54566 m .56379 .54451 L p
.56173 .5475 L 1 g
F P
s
P
p
.002 w
.56173 .5475 m .56179 .54762 L p
.56202 .54666 L 1 g
F P
s
P
p
.56654 .52734 m .56173 .5475 L .56202 .54666 L 1 g
F
P
p
.56654 .52734 m .56179 .54762 L .56464 .53774 L 1 g
F
P
p
.002 w
.55938 .5509 m .55822 .54895 L .56236 .54566 L p
1 g
F P
s
P
p
.56173 .5475 m .55938 .5509 L .56236 .54566 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.56635 .51064 m .56731 .52847 L .55822 .54895 L 1 g
F
P
p
.56731 .52847 m .56784 .53824 L .56292 .54372 L 1 g
F
P
p
.56731 .52847 m .56292 .54372 L .55822 .54895 L 1 g
F
P
p
.002 w
.56379 .54451 m .55822 .54895 L p
.56784 .53824 L 1 g
F P
s
P
p
.002 w
.56179 .54762 m .56257 .5491 L p
.56464 .53774 L 1 g
F P
s
P
p
.56464 .53774 m .56416 .54037 L .56731 .52847 L 1 g
F
P
p
.56416 .54037 m .56257 .5491 L .56544 .53662 L 1 g
F
P
p
.56416 .54037 m .56544 .53662 L .56731 .52847 L 1 g
F
P
p
.002 w
.568 .54117 m .56379 .54451 L p
.56784 .53824 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56792 .52935 L p
1 g
F P
s
P
p
.002 w
.56792 .52935 m .56731 .52847 L p
.56544 .53662 L 1 g
F P
s
P
p
.56544 .53662 m .56257 .5491 L .56792 .52935 L 1 g
F
P
p
.002 w
.56179 .54762 m .56173 .5475 L p
.55275 .56165 L 1 g
F P
s
P
p
.55485 .55745 m .55275 .56165 L .56173 .5475 L 1 g
F
P
p
.002 w
.55822 .54895 m .55938 .5509 L p
.53317 .57432 L 1 g
F P
s
P
p
.002 w
.5334 .58219 m .5328 .57469 L .56659 .56301 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54854 .56129 L p
1 g
F P
s
P
p
.55938 .5509 m .54917 .563 L .53317 .57432 L 1 g
F
P
p
.002 w
.55275 .56165 m .56257 .5491 L .56179 .54762 L p
1 g
F P
s
P
p
.5668 .51898 m .5676 .52417 L .56635 .51064 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56438 .50908 m .56635 .51064 L p
.55822 .54895 L 1 g
F P
s
P
p
.55661 .4905 m .56626 .50958 L .56566 .50829 L 1 g
F
P
p
.55661 .4905 m .5664 .50974 L .56162 .50009 L 1 g
F
P
p
.002 w
.56698 .51114 m .56438 .50908 L .56532 .50758 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56626 .50958 L p
1 g
F P
s
P
p
.5676 .52417 m .56854 .53025 L .56626 .50958 L 1 g
F
P
p
.002 w
.56626 .50958 m .5664 .50974 L p
.56566 .50829 L 1 g
F P
s
P
p
.002 w
.54523 .46265 m .58389 .47822 L .56532 .50758 L p
1 g
F P
s
P
p
.54523 .46265 m .55855 .49244 L .55588 .48848 L 1 g
F
P
p
.55855 .49244 m .56532 .50758 L .55718 .49111 L 1 g
F
P
p
.55855 .49244 m .55718 .49111 L .55588 .48848 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55718 .49111 L p
1 g
F P
s
P
p
.002 w
.55718 .49111 m .55661 .4905 L p
.56162 .50009 L 1 g
F P
s
P
p
.56162 .50009 m .56713 .51061 L .55718 .49111 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55718 .49111 L p
1 g
F P
s
P
p
.54174 .47608 m .55718 .49111 L .54844 .48264 L 1 g
F
P
p
.002 w
.56532 .50758 m .56438 .50908 L p
.55588 .48848 L 1 g
F P
s
P
p
.55615 .49011 m .56438 .50908 L .54232 .47671 L 1 g
F
P
p
.55588 .48848 m .56438 .50908 L .55233 .4813 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54232 .47671 L p
1 g
F P
s
P
p
.002 w
.54232 .47671 m .54174 .47608 L p
.54844 .48264 L 1 g
F P
s
P
p
.54844 .48264 m .55834 .49233 L .54232 .47671 L 1 g
F
P
p
.002 w
.55718 .49111 m .55834 .49233 L p
.54844 .48264 L 1 g
F P
s
P
p
.54232 .47671 m .56438 .50908 L .54101 .47611 L 1 g
F
P
p
.55233 .4813 m .55615 .49011 L .54232 .47671 L 1 g
F
P
p
.55306 .48163 m .55588 .48848 L .55233 .4813 L 1 g
F
P
p
.002 w
.5664 .50974 m .56713 .51061 L p
.56162 .50009 L 1 g
F P
s
P
p
.52214 .46667 m .54238 .47678 L .53058 .47104 L 1 g
F
P
p
.002 w
.54101 .47611 m .54523 .46265 L p
.55306 .48163 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54238 .47678 L p
.54145 .47631 L 1 g
F P
s
P
p
.002 w
.54101 .47611 m .53438 .4973 L p
.52236 .46705 L 1 g
F P
s
P
p
.002 w
.54238 .47678 m .54302 .47747 L p
.53058 .47104 L 1 g
F P
s
P
p
.50755 .46498 m .52236 .46705 L .53438 .4973 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52236 .46705 L p
1 g
F P
s
P
p
.002 w
.52236 .46705 m .52214 .46667 L p
.53058 .47104 L 1 g
F P
s
P
p
.53058 .47104 m .54302 .47747 L .52236 .46705 L 1 g
F
P
p
.5 .4634 m .51004 .46533 L .50963 .46527 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52282 .46778 L p
1 g
F P
s
P
p
.50063 .45665 m .50162 .45696 L .50755 .46498 L 1 g
F
P
p
.50162 .45696 m .54296 .46991 L .52236 .46705 L 1 g
F
P
p
.50162 .45696 m .52236 .46705 L .50755 .46498 L 1 g
F
P
p
.002 w
.54296 .46991 m .54101 .47611 L p
.52236 .46705 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5217 .46762 L p
.50963 .46527 L 1 g
F P
s
P
p
.51004 .46533 m .52282 .46778 L .50963 .46527 L 1 g
F
P
p
.50963 .46527 m .5217 .46762 L .5005 .464 L 1 g
F
P
p
.002 w
.53438 .4973 m .49996 .49278 L .5005 .464 L p
1 g
F P
s
P
p
.002 w
.5005 .464 m .50063 .45665 L p
.50755 .46498 L 1 g
F P
s
P
p
.002 w
.5005 .46385 m .5005 .464 L p
.5 .46392 L 1 g
F P
s
P
p
.002 w
.5005 .464 m .49996 .49278 L p
.5 .46392 L 1 g
F P
s
P
p
.002 w
.5217 .46762 m .5 .46442 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48684 .46576 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46392 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46392 L .48684 .46576 L 1 g
F
P
p
.002 w
.49856 .45686 m .50063 .45665 L p
.47829 .46695 L 1 g
F P
s
P
p
.47764 .46704 m .47829 .46695 L .46956 .47098 L 1 g
F
P
p
.49856 .45686 m .47829 .46695 L .47764 .46704 L 1 g
F
P
p
.002 w
.5 .46392 m .5 .46442 L p
.48684 .46576 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48684 .46576 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.50063 .45665 m .5005 .46385 L p
.47829 .46695 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.45578 .4611 m .49856 .45686 L p
.46956 .47098 L 1 g
F P
s
P
p
.002 w
.49996 .49278 m .46536 .49612 L .45978 .47573 L p
1 g
F P
s
P
p
.002 w
.45978 .47573 m .46536 .49612 L p
.43939 .48509 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45761 .47679 L p
1 g
F P
s
P
p
.002 w
.45761 .47679 m .4577 .47669 L p
.45964 .4758 L 1 g
F P
s
P
p
.45964 .4758 m .47718 .46778 L .45761 .47679 L 1 g
F
P
p
.46644 .47249 m .47531 .4686 L .45978 .47573 L 1 g
F
P
p
.46644 .47249 m .45978 .47573 L .4577 .47669 L 1 g
F
P
p
.002 w
.45978 .47573 m .45578 .4611 L p
.46956 .47098 L 1 g
F P
s
P
p
.002 w
.4164 .47533 m .45578 .4611 L .45978 .47573 L p
1 g
F P
s
P
p
.4164 .47533 m .45978 .47573 L .43939 .48509 L 1 g
F
P
p
.47531 .4686 m .47718 .46778 L .4577 .47669 L 1 g
F
P
p
.002 w
.4577 .47669 m .45698 .47747 L p
.44854 .48556 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4428 .49113 L p
1 g
F P
s
P
p
.44854 .48556 m .45698 .47747 L .4428 .49113 L 1 g
F
P
p
.43777 .50127 m .43939 .49764 L .43852 .49948 L 1 g
F
P
p
.43829 .50023 m .43939 .49764 L .43777 .50127 L 1 g
F
P
p
.002 w
.47588 .52868 m .45511 .5358 L .43493 .50701 L p
1 g
F P
s
P
p
.002 w
.43493 .50701 m .43482 .50686 L p
.43496 .50693 L 1 g
F P
s
P
p
.43496 .50693 m .47588 .52868 L .43493 .50701 L 1 g
F
P
p
.002 w
.44166 .49233 m .44043 .49491 L p
.43852 .49948 L 1 g
F P
s
P
p
.43939 .49764 m .44166 .49233 L .43852 .49948 L 1 g
F
P
p
.43346 .52734 m .43378 .50954 L .43319 .51968 L 1 g
F
P
p
.43269 .52847 m .43482 .50686 L .43298 .52951 L 1 g
F
P
p
.002 w
.43389 .50753 m .43482 .50686 L p
.43269 .52847 L 1 g
F P
s
P
p
.002 w
.43482 .50686 m .45511 .5358 L p
.43298 .52951 L 1 g
F P
s
P
p
.002 w
.43482 .50686 m .41195 .52353 L .38722 .4973 L p
1 g
F P
s
P
p
.002 w
.38722 .4973 m .4164 .47533 L .43482 .50686 L p
1 g
F P
s
P
p
.002 w
.44043 .49491 m .43287 .51061 L .43378 .50954 L p
1 g
F P
s
P
p
.002 w
.43378 .50954 m .43287 .51061 L p
.43319 .51968 L 1 g
F P
s
P
p
.002 w
.41195 .52353 m .428 .51183 L p
.43298 .52951 L 1 g
F P
s
P
p
.002 w
.43269 .52847 m .43146 .53025 L p
.43536 .53798 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43269 .52847 L p
1 g
F P
s
P
p
.43319 .51968 m .43287 .51061 L .43269 .52847 L 1 g
F
P
p
.43536 .53798 m .43431 .5359 L .43741 .54526 L 1 g
F
P
p
.43536 .53798 m .43741 .54526 L .4382 .54764 L 1 g
F
P
p
.002 w
.39916 .54401 m .41195 .52353 L .43548 .5436 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4382 .54764 L p
1 g
F P
s
P
p
.002 w
.43548 .5436 m .43937 .54693 L p
.43764 .5468 L 1 g
F P
s
P
p
.39916 .54401 m .43548 .5436 L .43764 .5468 L 1 g
F
P
p
.002 w
.43035 .5607 m .43592 .5522 L p
.45166 .56402 L 1 g
F P
s
P
p
.002 w
.43592 .5522 m .43856 .54816 L p
.45082 .563 L 1 g
F P
s
P
p
.43592 .5522 m .45082 .563 L .45166 .56402 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45082 .563 L p
1 g
F P
s
P
p
.46872 .57265 m .45082 .563 L .4585 .56857 L 1 g
F
P
p
.45146 .56129 m .4382 .54764 L .43856 .54816 L 1 g
F
P
p
.43885 .54852 m .43856 .54816 L .43868 .54835 L 1 g
F
P
p
.45146 .56129 m .43856 .54816 L .43885 .54852 L 1 g
F
P
p
.45146 .56129 m .43813 .54778 L .44083 .55206 L 1 g
F
P
p
.002 w
.45082 .563 m .45146 .56129 L p
.44418 .55496 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43937 .54693 m .46845 .56663 L p
.45166 .56402 L 1 g
F P
s
P
p
.002 w
.43856 .54816 m .43937 .54693 L p
.45166 .56402 L 1 g
F P
s
P
p
.002 w
.46373 .57352 m .45755 .57115 L p
.45238 .56413 L 1 g
F P
s
P
p
.45166 .56402 m .45238 .56413 L .45755 .57115 L 1 g
F
P
p
.002 w
.46426 .57274 m .46373 .57352 L p
.45238 .56413 L 1 g
F P
s
P
p
.002 w
.45082 .563 m .45002 .56518 L p
.4585 .56857 L 1 g
F P
s
P
p
.43868 .54835 m .43856 .54816 L .43813 .54778 L 1 g
F
P
p
.002 w
.4382 .54764 m .43817 .54769 L p
.43856 .54816 L 1 g
F P
s
P
p
.002 w
.43817 .54769 m .43813 .54778 L p
.43856 .54816 L 1 g
F P
s
P
p
.002 w
.43813 .54778 m .43743 .5491 L p
.44083 .55206 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45511 .5358 m .43937 .54693 L .43741 .54526 L p
1 g
F P
s
P
p
.43298 .52951 m .45511 .5358 L .43741 .54526 L 1 g
F
P
p
.002 w
.43937 .54693 m .43856 .54816 L p
.43764 .5468 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4382 .54764 L p
1 g
F P
s
P
p
.43431 .5359 m .43146 .53025 L .4382 .54764 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45003 .56514 L p
1 g
F P
s
P
p
.002 w
.45003 .56514 m .45082 .563 L p
.44333 .55522 L 1 g
F P
s
P
p
.44333 .55522 m .43743 .5491 L .45003 .56514 L 1 g
F
P
p
.44418 .55496 m .43743 .5491 L .45082 .563 L 1 g
F
P
p
.002 w
.46822 .57492 m .46872 .57265 L p
.4585 .56857 L 1 g
F P
s
P
p
.4585 .56857 m .46422 .57271 L .46822 .57492 L 1 g
F
P
p
.45192 .56594 m .46723 .57438 L .46822 .57492 L 1 g
F
P
p
.002 w
.46845 .56663 m .46426 .57274 L p
.45238 .56413 L 1 g
F P
s
P
p
.4585 .56857 m .45192 .56594 L .46422 .57271 L 1 g
F
P
p
.002 w
.46723 .57438 m .46373 .57352 L .46426 .57274 L p
1 g
F P
s
P
p
.45192 .56594 m .45084 .56551 L .46723 .57438 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58084 L p
1 g
F P
s
P
p
.002 w
.49687 .58135 m .49811 .58199 L .495 .58123 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58084 L .49707 .58136 L 1 g
F
P
p
.002 w
.51095 .58071 m .51079 .57862 L p
.49705 .58137 L 1 g
F P
s
P
p
.002 w
.49748 .58138 m .49811 .58199 L .49687 .58135 L p
1 g
F P
s
P
p
.49705 .58137 m .49702 .58137 L .49709 .58137 L 1 g
F
P
p
.49705 .58137 m .49709 .58137 L .51095 .58071 L 1 g
F
P
p
.49702 .58137 m .49723 .58139 L .51095 .58071 L 1 g
F
P
p
.49723 .58139 m .49768 .58139 L .51095 .58071 L 1 g
F
P
p
.49748 .5814 m .49798 .5814 L .51095 .58071 L 1 g
F
P
p
.49767 .58142 m .49836 .5814 L .51095 .58071 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48694 .55762 m .49868 .55655 L .49813 .5814 L p
1 g
F P
s
P
p
.002 w
.49813 .5814 m .49811 .58199 L .49784 .5814 L p
1 g
F P
s
P
p
.002 w
.49784 .5814 m .48694 .55762 L p
.49813 .5814 L 1 g
F P
s
P
p
.49723 .58139 m .49748 .5814 L .49768 .58139 L 1 g
F
P
p
.002 w
.49784 .5814 m .49811 .58199 L .49748 .58138 L p
1 g
F P
s
P
p
.49748 .5814 m .49767 .58142 L .49798 .5814 L 1 g
F
P
p
.002 w
.49842 .5814 m .49811 .58199 L .49813 .5814 L p
1 g
F P
s
P
p
.49784 .58143 m .49875 .58139 L .51095 .58071 L 1 g
F
P
p
.002 w
.49868 .55655 m .51036 .55802 L .49842 .5814 L p
1 g
F P
s
P
p
.002 w
.49813 .5814 m .49868 .55655 L p
.49842 .5814 L 1 g
F P
s
P
p
.002 w
.49879 .58139 m .49811 .58199 L .49842 .5814 L p
1 g
F P
s
P
p
.49621 .58153 m .50167 .58124 L .51095 .58071 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51036 .55802 m .52065 .56187 L .49879 .58139 L p
1 g
F P
s
P
p
.002 w
.49842 .5814 m .51036 .55802 L p
.49879 .58139 L 1 g
F P
s
P
p
.49767 .58142 m .49784 .58143 L .49836 .5814 L 1 g
F
P
p
.49784 .58143 m .49794 .58144 L .49875 .58139 L 1 g
F
P
p
.002 w
.52065 .56187 m .52841 .56765 L .49945 .58136 L p
1 g
F P
s
P
p
.002 w
.49945 .58136 m .49811 .58199 L .49879 .58139 L p
1 g
F P
s
P
p
.002 w
.49879 .58139 m .52065 .56187 L p
.49945 .58136 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47648 .56112 m .48694 .55762 L .49784 .5814 L p
1 g
F P
s
P
p
.002 w
.49748 .58138 m .47648 .56112 L p
.49784 .5814 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.46845 .56663 m .47648 .56112 L .49748 .58138 L p
1 g
F P
s
P
p
.002 w
.49687 .58135 m .46845 .56663 L p
.49748 .58138 L 1 g
F P
s
P
p
.49707 .58136 m .49687 .58135 L .48889 .583 L 1 g
F
P
p
.002 w
.48905 .58084 m .48904 .58093 L p
.49687 .58135 L 1 g
F P
s
P
p
.002 w
.48904 .58093 m .48889 .583 L p
.49687 .58135 L 1 g
F P
s
P
p
.002 w
.46845 .56663 m .49687 .58135 L p
.46723 .57438 L 1 g
F P
s
P
p
.002 w
.495 .58123 m .46723 .57438 L p
.49687 .58135 L 1 g
F P
s
P
p
.002 w
.46426 .57274 m .46845 .56663 L p
.46723 .57438 L 1 g
F P
s
P
p
.002 w
.46373 .57352 m .495 .58123 L p
.48905 .5808 L 1 g
F P
s
P
p
.002 w
.46371 .57364 m .46373 .57352 L p
.48905 .5808 L 1 g
F P
s
P
p
.002 w
.46373 .57352 m .46278 .581 L .42885 .57552 L p
1 g
F P
s
P
p
.002 w
.42885 .57552 m .43035 .5607 L .46373 .57352 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46822 .57492 L p
1 g
F P
s
P
p
.45084 .56551 m .45002 .56518 L .46822 .57492 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58083 L p
1 g
F P
s
P
p
.002 w
.48905 .58083 m .48905 .5808 L p
.4887 .58074 L 1 g
F P
s
P
p
.4887 .58074 m .4678 .57686 L .48905 .58083 L 1 g
F
P
p
.002 w
.46822 .57492 m .4678 .57686 L p
.4781 .57771 L 1 g
F P
s
P
p
.4781 .57771 m .4678 .57686 L .48905 .5808 L 1 g
F
P
p
.49702 .58137 m .49621 .58153 L .49794 .58144 L 1 g
F
P
p
.53182 .57511 m .52242 .58004 L .51095 .58071 L 1 g
F
P
p
.002 w
.53318 .57942 m .5334 .58219 L p
.51095 .58071 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58075 L .51103 .58073 L 1 g
F
P
p
.52054 .57816 m .51103 .58073 L .52012 .57837 L 1 g
F
P
p
.53128 .57265 m .51103 .58073 L .52054 .57816 L 1 g
F
P
p
.002 w
.5334 .58219 m .5302 .58935 L .50238 .58297 L p
1 g
F P
s
P
p
.002 w
.50599 .58204 m .5334 .58219 L p
.50238 .58297 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53249 .57475 m .50167 .58124 L p
.53276 .57461 L 1 g
F P
s
P
p
.002 w
.50167 .58124 m .49811 .58199 L p
.50161 .58125 L 1 g
F P
s
P
p
.53276 .57461 m .50167 .58124 L .50161 .58125 L 1 g
F
P
p
.002 w
.49811 .58199 m .49945 .58136 L p
.50161 .58125 L 1 g
F P
s
P
p
.002 w
.49811 .58199 m .53249 .57475 L p
.53201 .575 L 1 g
F P
s
P
p
.002 w
.50599 .58204 m .49811 .58199 L p
.53282 .57484 L 1 g
F P
s
P
p
.002 w
.50238 .58297 m .49811 .58199 L .50599 .58204 L p
1 g
F P
s
P
p
.49602 .58157 m .48889 .583 L .51005 .5808 L 1 g
F
P
p
.50167 .58124 m .51005 .5808 L .51095 .58071 L 1 g
F
P
p
.49602 .58157 m .51005 .5808 L .50167 .58124 L 1 g
F
P
p
.49621 .58153 m .49602 .58157 L .50167 .58124 L 1 g
F
P
p
.002 w
.52841 .56765 m .53276 .57461 L p
.50161 .58125 L 1 g
F P
s
P
p
.002 w
.49945 .58136 m .52841 .56765 L p
.50161 .58125 L 1 g
F P
s
P
p
.002 w
.53249 .57475 m .5328 .57469 L p
.53201 .575 L 1 g
F P
s
P
p
.53678 .5725 m .53274 .57462 L .5322 .57686 L 1 g
F
P
p
.002 w
.53182 .57511 m .53185 .57525 L p
.53274 .57462 L 1 g
F P
s
P
p
.002 w
.53276 .57461 m .5328 .57469 L .53249 .57475 L p
1 g
F P
s
P
p
.002 w
.53185 .57525 m .5322 .57686 L p
.53274 .57462 L 1 g
F P
s
P
p
.53977 .56965 m .53276 .57461 L .53689 .57239 L 1 g
F
P
p
.002 w
.54917 .563 m .54998 .56518 L p
.55499 .5561 L 1 g
F P
s
P
p
.53689 .57239 m .53276 .57461 L .53678 .5725 L 1 g
F
P
p
.53276 .57461 m .53249 .57475 L .53274 .57462 L 1 g
F
P
p
.53276 .57461 m .53274 .57462 L .53678 .5725 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58071 L p
1 g
F P
s
P
p
.002 w
.51095 .58071 m .51095 .58075 L p
.5113 .58061 L 1 g
F P
s
P
p
.002 w
.51095 .58075 m .51111 .583 L p
.52012 .57837 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.61201 .50117 m .62669 .52843 L .59825 .5474 L p
1 g
F P
s
P
p
.002 w
.62669 .52843 m .61201 .50117 L .63402 .47384 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.41195 .52353 m .39916 .54401 L .37127 .52406 L p
1 g
F P
s
P
p
.002 w
.37127 .52406 m .38722 .4973 L .41195 .52353 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.58643 .52652 m .59825 .5474 L .56659 .56301 L p
1 g
F P
s
P
p
.002 w
.59825 .5474 m .58643 .52652 L .61201 .50117 L p
1 g
F P
s
P
p
.002 w
.61452 .41334 m .65172 .44556 L .63402 .47384 L p
1 g
F P
s
P
p
.002 w
.65172 .44556 m .61452 .41334 L .62454 .38177 L p
1 g
F P
s
P
p
.002 w
.5717 .32629 m .63061 .35232 L .62454 .38177 L p
1 g
F P
s
P
p
.002 w
.63061 .35232 m .5717 .32629 L .57298 .29915 L p
1 g
F P
s
P
p
.002 w
.40056 .44242 m .36606 .46921 L .3492 .44031 L p
1 g
F P
s
P
p
.002 w
.3492 .44031 m .38789 .40938 L .40056 .44242 L p
1 g
F P
s
P
p
.002 w
.43632 .35502 m .37882 .37746 L .37358 .34778 L p
1 g
F P
s
P
p
.002 w
.37358 .34778 m .43369 .32384 L .43632 .35502 L p
1 g
F P
s
P
p
.002 w
.50327 .28881 m .57298 .29915 L .5717 .32629 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.50291 .31624 m .43369 .32384 L .43312 .29665 L p
1 g
F P
s
P
p
.002 w
.43312 .29665 m .50327 .28881 L .50291 .31624 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.5717 .32629 m .50291 .31624 L .50327 .28881 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60082 .4459 m .63402 .47384 L .61201 .50117 L p
1 g
F P
s
P
p
.002 w
.63402 .47384 m .60082 .4459 L .61452 .41334 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52841 .56765 m .52065 .56187 L .54302 .5373 L p
1 g
F P
s
P
p
.002 w
.54302 .5373 m .55822 .54895 L .52841 .56765 L p
1 g
F P
s
P
p
.002 w
.47648 .56112 m .46845 .56663 L .43937 .54693 L p
1 g
F P
s
P
p
.002 w
.4164 .47533 m .38722 .4973 L .36606 .46921 L p
1 g
F P
s
P
p
.002 w
.36606 .46921 m .40056 .44242 L .4164 .47533 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.56817 .35735 m .62454 .38177 L .61452 .41334 L p
1 g
F P
s
P
p
.002 w
.62454 .38177 m .56817 .35735 L .5717 .32629 L p
1 g
F P
s
P
p
.002 w
.52065 .56187 m .51036 .55802 L .5226 .52948 L p
1 g
F P
s
P
p
.002 w
.5226 .52948 m .54302 .5373 L .52065 .56187 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.48694 .55762 m .47648 .56112 L .45511 .5358 L p
1 g
F P
s
P
p
.002 w
.43937 .54693 m .45511 .5358 L .47648 .56112 L p
1 g
F P
s
P
p
.002 w
.58389 .47822 m .61201 .50117 L .58643 .52652 L p
1 g
F P
s
P
p
.002 w
.61201 .50117 m .58389 .47822 L .60082 .4459 L p
1 g
F P
s
P
p
.002 w
.44099 .38916 m .38789 .40938 L .37882 .37746 L p
1 g
F P
s
P
p
.002 w
.37882 .37746 m .43632 .35502 L .44099 .38916 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.55822 .54895 m .54302 .5373 L .56438 .50908 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51036 .55802 m .49868 .55655 L .4993 .52648 L p
1 g
F P
s
P
p
.002 w
.4993 .52648 m .5226 .52948 L .51036 .55802 L p
1 g
F P
s
P
p
.002 w
.49868 .55655 m .48694 .55762 L .47588 .52868 L p
1 g
F P
s
P
p
.002 w
.45511 .5358 m .47588 .52868 L .48694 .55762 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.50291 .31624 m .5717 .32629 L .56817 .35735 L p
1 g
F P
s
P
p
.002 w
.47588 .52868 m .4993 .52648 L .49868 .55655 L p
1 g
F P
s
P
p
.002 w
.50245 .34792 m .43632 .35502 L .43369 .32384 L p
1 g
F P
s
P
p
.002 w
.43369 .32384 m .50291 .31624 L .50245 .34792 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.004 w
.49771 .61446 m
.49771 .61431 L
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.56245 .39129 m .61452 .41334 L .60082 .4459 L p
1 g
F P
s
P
p
.002 w
.61452 .41334 m .56245 .39129 L .56817 .35735 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.54302 .5373 m .5226 .52948 L .53438 .4973 L p
1 g
F P
s
P
p
.002 w
.53438 .4973 m .56438 .50908 L .54302 .5373 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56817 .35735 m .50245 .34792 L .50291 .31624 L p
1 g
F P
s
P
p
.002 w
.44755 .42498 m .40056 .44242 L .38789 .40938 L p
1 g
F P
s
P
p
.002 w
.38789 .40938 m .44099 .38916 L .44755 .42498 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.55471 .42684 m .60082 .4459 L .58389 .47822 L p
1 g
F P
s
P
p
.002 w
.60082 .4459 m .55471 .42684 L .56245 .39129 L p
1 g
F P
s
P
p
.002 w
.5226 .52948 m .4993 .52648 L .49996 .49278 L p
1 g
F P
s
P
p
.002 w
.49996 .49278 m .53438 .4973 L .5226 .52948 L p
1 g
F P
s
P
p
.002 w
.4993 .52648 m .47588 .52868 L .46536 .49612 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.45578 .4611 m .4164 .47533 L .40056 .44242 L p
1 g
F P
s
P
p
.002 w
.40056 .44242 m .44755 .42498 L .45578 .4611 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50245 .34792 m .56817 .35735 L .56245 .39129 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5019 .38277 m .44099 .38916 L .43632 .35502 L p
1 g
F P
s
P
p
.002 w
.43632 .35502 m .50245 .34792 L .5019 .38277 L p
1 g
F P
s
P
p
.002 w
.58389 .47822 m .54523 .46265 L .55471 .42684 L p
1 g
F P
s
P
p
.002 w
.46536 .49612 m .49996 .49278 L .4993 .52648 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.49735 .64351 m
.49748 .63276 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56245 .39129 m .5019 .38277 L .50245 .34792 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.5019 .38277 m .56245 .39129 L .55471 .42684 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.50129 .41949 m .44755 .42498 L .44099 .38916 L p
1 g
F P
s
P
p
.002 w
.44099 .38916 m .5019 .38277 L .50129 .41949 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54523 .46265 m .50063 .45665 L .50129 .41949 L p
1 g
F P
s
P
p
.002 w
.50129 .41949 m .55471 .42684 L .54523 .46265 L p
1 g
F P
s
P
p
.002 w
.55471 .42684 m .50129 .41949 L .5019 .38277 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.50063 .45665 m .45578 .4611 L .44755 .42498 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.44755 .42498 m .50129 .41949 L .50063 .45665 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .35979 .68526 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .49701 .67012 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.46124)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.46124)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44344 .42037 m .48036 .43906 L .49007 .41218 L p
1 g
F P
s
P
p
.002 w
.49007 .41218 m .45932 .39646 L .44344 .42037 L p
1 g
F P
s
P
p
.002 w
.52419 .41998 m .49007 .41218 L .48036 .43906 L p
1 g
F P
s
P
p
.002 w
.45932 .39646 m .49007 .41218 L .50005 .38565 L p
1 g
F P
s
P
p
.002 w
.49007 .41218 m .52419 .41998 L .52657 .39171 L p
1 g
F P
s
P
p
.002 w
.52657 .39171 m .50005 .38565 L .49007 .41218 L p
1 g
F P
s
P
p
.002 w
.42885 .44464 m .47109 .46583 L .48036 .43906 L p
1 g
F P
s
P
p
.002 w
.48036 .43906 m .44344 .42037 L .42885 .44464 L p
1 g
F P
s
P
p
.002 w
.52123 .44843 m .48036 .43906 L .47109 .46583 L p
1 g
F P
s
P
p
.002 w
.48036 .43906 m .52123 .44843 L .52419 .41998 L p
1 g
F P
s
P
p
.002 w
.55849 .41913 m .52419 .41998 L .52123 .44843 L p
1 g
F P
s
P
p
.002 w
.52419 .41998 m .55849 .41913 L .55321 .39092 L p
1 g
F P
s
P
p
.002 w
.55321 .39092 m .52657 .39171 L .52419 .41998 L p
1 g
F P
s
P
p
.002 w
.47109 .46583 m .51774 .47654 L .52123 .44843 L p
1 g
F P
s
P
p
.002 w
.56235 .4476 m .52123 .44843 L .51774 .47654 L p
1 g
F P
s
P
p
.002 w
.52123 .44843 m .56235 .4476 L .55849 .41913 L p
1 g
F P
s
P
p
.002 w
.50005 .38565 m .47621 .37335 L .45932 .39646 L p
1 g
F P
s
P
p
.002 w
.47621 .37335 m .50005 .38565 L .51012 .35997 L p
1 g
F P
s
P
p
.002 w
.50005 .38565 m .52657 .39171 L .52833 .36412 L p
1 g
F P
s
P
p
.002 w
.52833 .36412 m .51012 .35997 L .50005 .38565 L p
1 g
F P
s
P
p
.002 w
.41585 .46884 m .46244 .49199 L .47109 .46583 L p
1 g
F P
s
P
p
.002 w
.47109 .46583 m .42885 .44464 L .41585 .46884 L p
1 g
F P
s
P
p
.002 w
.51774 .47654 m .47109 .46583 L .46244 .49199 L p
1 g
F P
s
P
p
.002 w
.52657 .39171 m .55321 .39092 L .54659 .3635 L p
1 g
F P
s
P
p
.002 w
.54659 .3635 m .52833 .36412 L .52657 .39171 L p
1 g
F P
s
P
p
.002 w
.46244 .49199 m .51379 .5038 L .51774 .47654 L p
1 g
F P
s
P
p
.002 w
.56471 .47581 m .51774 .47654 L .51379 .5038 L p
1 g
F P
s
P
p
.002 w
.51774 .47654 m .56471 .47581 L .56235 .4476 L p
1 g
F P
s
P
p
.002 w
.41392 .3939 m .44344 .42037 L .45932 .39646 L p
1 g
F P
s
P
p
.002 w
.45932 .39646 m .4349 .3742 L .41392 .3939 L p
1 g
F P
s
P
p
.002 w
.4349 .3742 m .45932 .39646 L .47621 .37335 L p
1 g
F P
s
P
p
.002 w
.39488 .41468 m .42885 .44464 L .44344 .42037 L p
1 g
F P
s
P
p
.002 w
.44344 .42037 m .41392 .3939 L .39488 .41468 L p
1 g
F P
s
P
p
.002 w
.58973 .40956 m .55849 .41913 L .56235 .4476 L p
1 g
F P
s
P
p
.002 w
.55849 .41913 m .58973 .40956 L .57736 .38328 L p
1 g
F P
s
P
p
.002 w
.57736 .38328 m .55321 .39092 L .55849 .41913 L p
1 g
F P
s
P
p
.002 w
.47621 .37335 m .45741 .35593 L .4349 .3742 L p
1 g
F P
s
P
p
.002 w
.51012 .35997 m .49381 .35147 L .47621 .37335 L p
1 g
F P
s
P
p
.002 w
.45741 .35593 m .47621 .37335 L .49381 .35147 L p
1 g
F P
s
P
p
.002 w
.59994 .43645 m .56235 .4476 L .56471 .47581 L p
1 g
F P
s
P
p
.002 w
.56235 .4476 m .59994 .43645 L .58973 .40956 L p
1 g
F P
s
P
p
.002 w
.55321 .39092 m .57736 .38328 L .56307 .35812 L p
1 g
F P
s
P
p
.002 w
.56307 .35812 m .54659 .3635 L .55321 .39092 L p
1 g
F P
s
P
p
.002 w
.49381 .35147 m .51012 .35997 L .52011 .33563 L p
1 g
F P
s
P
p
.002 w
.51012 .35997 m .52833 .36412 L .52942 .33775 L p
1 g
F P
s
P
p
.002 w
.52942 .33775 m .52011 .33563 L .51012 .35997 L p
1 g
F P
s
P
p
.002 w
.40472 .49249 m .45458 .51705 L .46244 .49199 L p
1 g
F P
s
P
p
.002 w
.46244 .49199 m .41585 .46884 L .40472 .49249 L p
1 g
F P
s
P
p
.002 w
.51379 .5038 m .46244 .49199 L .45458 .51705 L p
1 g
F P
s
P
p
.002 w
.52833 .36412 m .54659 .3635 L .53875 .33739 L p
1 g
F P
s
P
p
.002 w
.53875 .33739 m .52942 .33775 L .52833 .36412 L p
1 g
F P
s
P
p
.002 w
.37819 .43614 m .41585 .46884 L .42885 .44464 L p
1 g
F P
s
P
p
.002 w
.42885 .44464 m .39488 .41468 L .37819 .43614 L p
1 g
F P
s
P
p
.002 w
.45458 .51705 m .50944 .52969 L .51379 .5038 L p
1 g
F P
s
P
p
.002 w
.5655 .50323 m .51379 .5038 L .50944 .52969 L p
1 g
F P
s
P
p
.002 w
.51379 .5038 m .5655 .50323 L .56471 .47581 L p
1 g
F P
s
P
p
.002 w
.60777 .46345 m .56471 .47581 L .5655 .50323 L p
1 g
F P
s
P
p
.002 w
.56471 .47581 m .60777 .46345 L .59994 .43645 L p
1 g
F P
s
P
p
.002 w
.49381 .35147 m .48103 .33945 L .45741 .35593 L p
1 g
F P
s
P
p
.002 w
.52011 .33563 m .51178 .33125 L .49381 .35147 L p
1 g
F P
s
P
p
.002 w
.48103 .33945 m .49381 .35147 L .51178 .33125 L p
1 g
F P
s
P
p
.002 w
.54659 .3635 m .56307 .35812 L .54712 .33458 L p
1 g
F P
s
P
p
.002 w
.54712 .33458 m .53875 .33739 L .54659 .3635 L p
1 g
F P
s
P
p
.002 w
.41936 .34739 m .4349 .3742 L .45741 .35593 L p
1 g
F P
s
P
p
.002 w
.45741 .35593 m .44564 .33503 L .41936 .34739 L p
1 g
F P
s
P
p
.002 w
.44564 .33503 m .45741 .35593 L .48103 .33945 L p
1 g
F P
s
P
p
.002 w
.39486 .36193 m .41392 .3939 L .4349 .3742 L p
1 g
F P
s
P
p
.002 w
.4349 .3742 m .41936 .34739 L .39486 .36193 L p
1 g
F P
s
P
p
.002 w
.59653 .3694 m .57736 .38328 L .58973 .40956 L p
1 g
F P
s
P
p
.002 w
.57736 .38328 m .59653 .3694 L .57603 .34848 L p
1 g
F P
s
P
p
.002 w
.57603 .34848 m .56307 .35812 L .57736 .38328 L p
1 g
F P
s
P
p
.002 w
.61474 .39194 m .58973 .40956 L .59994 .43645 L p
1 g
F P
s
P
p
.002 w
.58973 .40956 m .61474 .39194 L .59653 .3694 L p
1 g
F P
s
P
p
.002 w
.36425 .45787 m .40472 .49249 L .41585 .46884 L p
1 g
F P
s
P
p
.002 w
.41585 .46884 m .37819 .43614 L .36425 .45787 L p
1 g
F P
s
P
p
.002 w
.48103 .33945 m .47317 .32508 L .44564 .33503 L p
1 g
F P
s
P
p
.002 w
.47317 .32508 m .48103 .33945 L .50532 .32507 L p
1 g
F P
s
P
p
.002 w
.51178 .33125 m .50532 .32507 L .48103 .33945 L p
1 g
F P
s
P
p
.002 w
.37266 .37839 m .39488 .41468 L .41392 .3939 L p
1 g
F P
s
P
p
.002 w
.41392 .3939 m .39486 .36193 L .37266 .37839 L p
1 g
F P
s
P
p
.002 w
.56307 .35812 m .57603 .34848 L .55364 .32959 L p
1 g
F P
s
P
p
.002 w
.55364 .32959 m .54712 .33458 L .56307 .35812 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .51178 .33125 L .52011 .33563 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .52011 .33563 L .52942 .33775 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .52942 .33775 L .53875 .33739 L closepath p
1 g
F P
s
P
p
.002 w
.39572 .51512 m .44768 .5405 L .45458 .51705 L p
1 g
F P
s
P
p
.002 w
.45458 .51705 m .40472 .49249 L .39572 .51512 L p
1 g
F P
s
P
p
.002 w
.50944 .52969 m .45458 .51705 L .44768 .5405 L p
1 g
F P
s
P
p
.002 w
.50944 .52969 m .56468 .52932 L .5655 .50323 L p
1 g
F P
s
P
p
.002 w
.61303 .49003 m .5655 .50323 L .56468 .52932 L p
1 g
F P
s
P
p
.002 w
.5655 .50323 m .61303 .49003 L .60777 .46345 L p
1 g
F P
s
P
p
.002 w
.44768 .5405 m .50475 .55367 L .50944 .52969 L p
1 g
F P
s
P
p
.002 w
.56468 .52932 m .50944 .52969 L .50475 .55367 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .50532 .32507 L .51178 .33125 L closepath p
1 g
F P
s
P
p
.002 w
.63026 .41567 m .59994 .43645 L .60777 .46345 L p
1 g
F P
s
P
p
.002 w
.59994 .43645 m .63026 .41567 L .61474 .39194 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .53875 .33739 L .54712 .33458 L closepath p
1 g
F P
s
P
p
.002 w
.50532 .32507 m .50141 .31772 L .47317 .32508 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .50141 .31772 L .50532 .32507 L closepath p
1 g
F P
s
P
p
.002 w
.3533 .39648 m .37819 .43614 L .39488 .41468 L p
1 g
F P
s
P
p
.002 w
.39488 .41468 m .37266 .37839 L .3533 .39648 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .54712 .33458 L .55364 .32959 L closepath p
1 g
F P
s
P
p
.002 w
.44232 .3127 m .44564 .33503 L .47317 .32508 L p
1 g
F P
s
P
p
.002 w
.47317 .32508 m .47115 .30983 L .44232 .3127 L p
1 g
F P
s
P
p
.002 w
.47115 .30983 m .47317 .32508 L .50141 .31772 L p
1 g
F P
s
P
p
.002 w
.41462 .31857 m .41936 .34739 L .44564 .33503 L p
1 g
F P
s
P
p
.002 w
.44564 .33503 m .44232 .3127 L .41462 .31857 L p
1 g
F P
s
P
p
.002 w
.58403 .33548 m .57603 .34848 L .59653 .3694 L p
1 g
F P
s
P
p
.002 w
.57603 .34848 m .58403 .33548 L .55758 .32294 L p
1 g
F P
s
P
p
.002 w
.55758 .32294 m .55364 .32959 L .57603 .34848 L p
1 g
F P
s
P
p
.002 w
.64271 .44013 m .60777 .46345 L .61303 .49003 L p
1 g
F P
s
P
p
.002 w
.60777 .46345 m .64271 .44013 L .63026 .41567 L p
1 g
F P
s
P
p
.002 w
.50141 .31772 m .50051 .30998 L .47115 .30983 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .50051 .30998 L .50141 .31772 L closepath p
1 g
F P
s
P
p
.002 w
.35343 .47943 m .39572 .51512 L .40472 .49249 L p
1 g
F P
s
P
p
.002 w
.40472 .49249 m .36425 .45787 L .35343 .47943 L p
1 g
F P
s
P
p
.002 w
.60858 .35051 m .59653 .3694 L .61474 .39194 L p
1 g
F P
s
P
p
.002 w
.59653 .3694 m .60858 .35051 L .58403 .33548 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .55364 .32959 L .55758 .32294 L closepath p
1 g
F P
s
P
p
.002 w
.38866 .32738 m .39486 .36193 L .41936 .34739 L p
1 g
F P
s
P
p
.002 w
.41936 .34739 m .41462 .31857 L .38866 .32738 L p
1 g
F P
s
P
p
.002 w
.50475 .55367 m .56222 .55352 L .56468 .52932 L p
1 g
F P
s
P
p
.002 w
.61553 .51563 m .56468 .52932 L .56222 .55352 L p
1 g
F P
s
P
p
.002 w
.56468 .52932 m .61553 .51563 L .61303 .49003 L p
1 g
F P
s
P
p
.002 w
.47532 .29531 m .47115 .30983 L .50051 .30998 L p
1 g
F P
s
P
p
.002 w
.50051 .30998 m .50274 .30266 L .47532 .29531 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .50274 .30266 L .50051 .30998 L closepath p
1 g
F P
s
P
p
.002 w
.6307 .36775 m .61474 .39194 L .63026 .41567 L p
1 g
F P
s
P
p
.002 w
.61474 .39194 m .6307 .36775 L .60858 .35051 L p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .55758 .32294 L .5585 .31532 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .5585 .31532 L .55626 .30756 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .5079 .29659 L .50274 .30266 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .55626 .30756 L .55105 .30051 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .55105 .30051 L .54345 .29497 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .54345 .29497 L .53429 .29157 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .53429 .29157 L .52459 .29069 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .52459 .29069 L .51546 .29244 L closepath p
1 g
F P
s
P
p
.002 w
.5298 .31312 m .51546 .29244 L .5079 .29659 L closepath p
1 g
F P
s
P
p
.002 w
.38913 .53622 m .44191 .5618 L .44768 .5405 L p
1 g
F P
s
P
p
.002 w
.44768 .5405 m .39572 .51512 L .38913 .53622 L p
1 g
F P
s
P
p
.002 w
.50475 .55367 m .44768 .5405 L .44191 .5618 L p
1 g
F P
s
P
p
.002 w
.33726 .41585 m .36425 .45787 L .37819 .43614 L p
1 g
F P
s
P
p
.002 w
.37819 .43614 m .3533 .39648 L .33726 .41585 L p
1 g
F P
s
P
p
.002 w
.5585 .31532 m .55758 .32294 L .58403 .33548 L p
1 g
F P
s
P
p
.002 w
.44191 .5618 m .49982 .57519 L .50475 .55367 L p
1 g
F P
s
P
p
.002 w
.56222 .55352 m .50475 .55367 L .49982 .57519 L p
1 g
F P
s
P
p
.002 w
.44811 .29127 m .44232 .3127 L .47115 .30983 L p
1 g
F P
s
P
p
.002 w
.47115 .30983 m .47532 .29531 L .44811 .29127 L p
1 g
F P
s
P
p
.002 w
.36504 .33902 m .37266 .37839 L .39486 .36193 L p
1 g
F P
s
P
p
.002 w
.39486 .36193 m .38866 .32738 L .36504 .33902 L p
1 g
F P
s
P
p
.002 w
.58609 .32045 m .58403 .33548 L .60858 .35051 L p
1 g
F P
s
P
p
.002 w
.58403 .33548 m .58609 .32045 L .5585 .31532 L p
1 g
F P
s
P
p
.002 w
.65177 .46482 m .61303 .49003 L .61553 .51563 L p
1 g
F P
s
P
p
.002 w
.61303 .49003 m .65177 .46482 L .64271 .44013 L p
1 g
F P
s
P
p
.002 w
.48538 .28313 m .47532 .29531 L .50274 .30266 L p
1 g
F P
s
P
p
.002 w
.50274 .30266 m .5079 .29659 L .48538 .28313 L p
1 g
F P
s
P
p
.002 w
.55626 .30756 m .5585 .31532 L .58609 .32045 L p
1 g
F P
s
P
p
.002 w
.64987 .38689 m .63026 .41567 L .64271 .44013 L p
1 g
F P
s
P
p
.002 w
.63026 .41567 m .64987 .38689 L .6307 .36775 L p
1 g
F P
s
P
p
.002 w
.42171 .29072 m .41462 .31857 L .44232 .3127 L p
1 g
F P
s
P
p
.002 w
.44232 .3127 m .44811 .29127 L .42171 .29072 L p
1 g
F P
s
P
p
.002 w
.50035 .27474 m .48538 .28313 L .5079 .29659 L p
1 g
F P
s
P
p
.002 w
.5079 .29659 m .51546 .29244 L .50035 .27474 L p
1 g
F P
s
P
p
.002 w
.34609 .50033 m .38913 .53622 L .39572 .51512 L p
1 g
F P
s
P
p
.002 w
.39572 .51512 m .35343 .47943 L .34609 .50033 L p
1 g
F P
s
P
p
.002 w
.61195 .32847 m .60858 .35051 L .6307 .36775 L p
1 g
F P
s
P
p
.002 w
.60858 .35051 m .61195 .32847 L .58609 .32045 L p
1 g
F P
s
P
p
.002 w
.58609 .32045 m .58182 .30501 L .55626 .30756 L p
1 g
F P
s
P
p
.002 w
.55105 .30051 m .55626 .30756 L .58182 .30501 L p
1 g
F P
s
P
p
.002 w
.46272 .27315 m .44811 .29127 L .47532 .29531 L p
1 g
F P
s
P
p
.002 w
.47532 .29531 m .48538 .28313 L .46272 .27315 L p
1 g
F P
s
P
p
.002 w
.34437 .35331 m .3533 .39648 L .37266 .37839 L p
1 g
F P
s
P
p
.002 w
.37266 .37839 m .36504 .33902 L .34437 .35331 L p
1 g
F P
s
P
p
.002 w
.49982 .57519 m .55809 .57525 L .56222 .55352 L p
1 g
F P
s
P
p
.002 w
.61515 .53968 m .56222 .55352 L .55809 .57525 L p
1 g
F P
s
P
p
.002 w
.56222 .55352 m .61515 .53968 L .61553 .51563 L p
1 g
F P
s
P
p
.002 w
.32505 .43612 m .35343 .47943 L .36425 .45787 L p
1 g
F P
s
P
p
.002 w
.36425 .45787 m .33726 .41585 L .32505 .43612 L p
1 g
F P
s
P
p
.002 w
.5186 .27117 m .50035 .27474 L .51546 .29244 L p
1 g
F P
s
P
p
.002 w
.51546 .29244 m .52459 .29069 L .5186 .27117 L p
1 g
F P
s
P
p
.002 w
.58182 .30501 m .57158 .29088 L .55105 .30051 L p
1 g
F P
s
P
p
.002 w
.54345 .29497 m .55105 .30051 L .57158 .29088 L p
1 g
F P
s
P
p
.002 w
.58182 .30501 m .58609 .32045 L .61195 .32847 L p
1 g
F P
s
P
p
.002 w
.39672 .29378 m .38866 .32738 L .41462 .31857 L p
1 g
F P
s
P
p
.002 w
.41462 .31857 m .42171 .29072 L .39672 .29378 L p
1 g
F P
s
P
p
.002 w
.53804 .27289 m .5186 .27117 L .52459 .29069 L p
1 g
F P
s
P
p
.002 w
.52459 .29069 m .53429 .29157 L .53804 .27289 L p
1 g
F P
s
P
p
.002 w
.57158 .29088 m .55641 .27973 L .54345 .29497 L p
1 g
F P
s
P
p
.002 w
.53429 .29157 m .54345 .29497 L .55641 .27973 L p
1 g
F P
s
P
p
.002 w
.66557 .40756 m .64271 .44013 L .65177 .46482 L p
1 g
F P
s
P
p
.002 w
.64271 .44013 m .66557 .40756 L .64987 .38689 L p
1 g
F P
s
P
p
.002 w
.55641 .27973 m .53804 .27289 L .53429 .29157 L p
1 g
F P
s
P
p
.002 w
.65712 .4892 m .61553 .51563 L .61515 .53968 L p
1 g
F P
s
P
p
.002 w
.61553 .51563 m .65712 .4892 L .65177 .46482 L p
1 g
F P
s
P
p
.002 w
.3852 .55527 m .43745 .58042 L .44191 .5618 L p
1 g
F P
s
P
p
.002 w
.44191 .5618 m .38913 .53622 L .3852 .55527 L p
1 g
F P
s
P
p
.002 w
.49982 .57519 m .44191 .5618 L .43745 .58042 L p
1 g
F P
s
P
p
.002 w
.43745 .58042 m .49474 .59368 L .49982 .57519 L p
1 g
F P
s
P
p
.002 w
.55809 .57525 m .49982 .57519 L .49474 .59368 L p
1 g
F P
s
P
p
.002 w
.63547 .33927 m .6307 .36775 L .64987 .38689 L p
1 g
F P
s
P
p
.002 w
.6307 .36775 m .63547 .33927 L .61195 .32847 L p
1 g
F P
s
P
p
.002 w
.48478 .26055 m .46272 .27315 L .48538 .28313 L p
1 g
F P
s
P
p
.002 w
.48538 .28313 m .50035 .27474 L .48478 .26055 L p
1 g
F P
s
P
p
.002 w
.44041 .26699 m .42171 .29072 L .44811 .29127 L p
1 g
F P
s
P
p
.002 w
.44811 .29127 m .46272 .27315 L .44041 .26699 L p
1 g
F P
s
P
p
.002 w
.61195 .32847 m .60592 .30562 L .58182 .30501 L p
1 g
F P
s
P
p
.002 w
.57158 .29088 m .58182 .30501 L .60592 .30562 L p
1 g
F P
s
P
p
.002 w
.32726 .37003 m .33726 .41585 L .3533 .39648 L p
1 g
F P
s
P
p
.002 w
.3533 .39648 m .34437 .35331 L .32726 .37003 L p
1 g
F P
s
P
p
.002 w
.60592 .30562 m .61195 .32847 L .63547 .33927 L p
1 g
F P
s
P
p
.002 w
.37378 .30053 m .36504 .33902 L .38866 .32738 L p
1 g
F P
s
P
p
.002 w
.38866 .32738 m .39672 .29378 L .37378 .30053 L p
1 g
F P
s
P
p
.002 w
.34257 .52007 m .3852 .55527 L .38913 .53622 L p
1 g
F P
s
P
p
.002 w
.38913 .53622 m .34609 .50033 L .34257 .52007 L p
1 g
F P
s
P
p
.002 w
.3171 .45684 m .34609 .50033 L .35343 .47943 L p
1 g
F P
s
P
p
.002 w
.35343 .47943 m .32505 .43612 L .3171 .45684 L p
1 g
F P
s
P
p
.002 w
.67733 .42934 m .65177 .46482 L .65712 .4892 L p
1 g
F P
s
P
p
.002 w
.65177 .46482 m .67733 .42934 L .66557 .40756 L p
1 g
F P
s
P
p
.002 w
.51191 .25512 m .48478 .26055 L .50035 .27474 L p
1 g
F P
s
P
p
.002 w
.50035 .27474 m .5186 .27117 L .51191 .25512 L p
1 g
F P
s
P
p
.002 w
.49474 .59368 m .55233 .59391 L .55809 .57525 L p
1 g
F P
s
P
p
.002 w
.61176 .56158 m .55809 .57525 L .55233 .59391 L p
1 g
F P
s
P
p
.002 w
.55809 .57525 m .61176 .56158 L .61515 .53968 L p
1 g
F P
s
P
p
.002 w
.65605 .35272 m .64987 .38689 L .66557 .40756 L p
1 g
F P
s
P
p
.002 w
.64987 .38689 m .65605 .35272 L .63547 .33927 L p
1 g
F P
s
P
p
.002 w
.60592 .30562 m .59088 .28458 L .57158 .29088 L p
1 g
F P
s
P
p
.002 w
.55641 .27973 m .57158 .29088 L .59088 .28458 L p
1 g
F P
s
P
p
.002 w
.6585 .5127 m .61515 .53968 L .61176 .56158 L p
1 g
F P
s
P
p
.002 w
.61515 .53968 m .6585 .5127 L .65712 .4892 L p
1 g
F P
s
P
p
.002 w
.41899 .26497 m .39672 .29378 L .42171 .29072 L p
1 g
F P
s
P
p
.002 w
.42171 .29072 m .44041 .26699 L .41899 .26497 L p
1 g
F P
s
P
p
.002 w
.54093 .25765 m .51191 .25512 L .5186 .27117 L p
1 g
F P
s
P
p
.002 w
.5186 .27117 m .53804 .27289 L .54093 .25765 L p
1 g
F P
s
P
p
.002 w
.59088 .28458 m .56835 .2679 L .55641 .27973 L p
1 g
F P
s
P
p
.002 w
.53804 .27289 m .55641 .27973 L .56835 .2679 L p
1 g
F P
s
P
p
.002 w
.46909 .25037 m .44041 .26699 L .46272 .27315 L p
1 g
F P
s
P
p
.002 w
.46272 .27315 m .48478 .26055 L .46909 .25037 L p
1 g
F P
s
P
p
.002 w
.56835 .2679 m .54093 .25765 L .53804 .27289 L p
1 g
F P
s
P
p
.002 w
.38416 .5717 m .43446 .5958 L .43745 .58042 L p
1 g
F P
s
P
p
.002 w
.43745 .58042 m .3852 .55527 L .38416 .5717 L p
1 g
F P
s
P
p
.002 w
.49474 .59368 m .43745 .58042 L .43446 .5958 L p
1 g
F P
s
P
p
.002 w
.35354 .31094 m .34437 .35331 L .36504 .33902 L p
1 g
F P
s
P
p
.002 w
.36504 .33902 m .37378 .30053 L .35354 .31094 L p
1 g
F P
s
P
p
.002 w
.43446 .5958 m .48961 .60857 L .49474 .59368 L p
1 g
F P
s
P
p
.002 w
.55233 .59391 m .49474 .59368 L .48961 .60857 L p
1 g
F P
s
P
p
.002 w
.62794 .30951 m .63547 .33927 L .65605 .35272 L p
1 g
F P
s
P
p
.002 w
.63547 .33927 m .62794 .30951 L .60592 .30562 L p
1 g
F P
s
P
p
.002 w
.31427 .38885 m .32505 .43612 L .33726 .41585 L p
1 g
F P
s
P
p
.002 w
.33726 .41585 m .32726 .37003 L .31427 .38885 L p
1 g
F P
s
P
p
.002 w
.59088 .28458 m .60592 .30562 L .62794 .30951 L p
1 g
F P
s
P
p
.002 w
.67308 .3686 m .66557 .40756 L .67733 .42934 L p
1 g
F P
s
P
p
.002 w
.66557 .40756 m .67308 .3686 L .65605 .35272 L p
1 g
F P
s
P
p
.002 w
.68471 .45176 m .65712 .4892 L .6585 .5127 L p
1 g
F P
s
P
p
.002 w
.65712 .4892 m .68471 .45176 L .67733 .42934 L p
1 g
F P
s
P
p
.002 w
.31382 .47752 m .34257 .52007 L .34609 .50033 L p
1 g
F P
s
P
p
.002 w
.34609 .50033 m .3171 .45684 L .31382 .47752 L p
1 g
F P
s
P
p
.002 w
.34314 .53811 m .38416 .5717 L .3852 .55527 L p
1 g
F P
s
P
p
.002 w
.3852 .55527 m .34257 .52007 L .34314 .53811 L p
1 g
F P
s
P
p
.002 w
.50464 .24313 m .46909 .25037 L .48478 .26055 L p
1 g
F P
s
P
p
.002 w
.48478 .26055 m .51191 .25512 L .50464 .24313 L p
1 g
F P
s
P
p
.002 w
.39904 .26733 m .37378 .30053 L .39672 .29378 L p
1 g
F P
s
P
p
.002 w
.39672 .29378 m .41899 .26497 L .39904 .26733 L p
1 g
F P
s
P
p
.002 w
.48961 .60857 m .54498 .60893 L .55233 .59391 L p
1 g
F P
s
P
p
.002 w
.60531 .58073 m .55233 .59391 L .54498 .60893 L p
1 g
F P
s
P
p
.002 w
.55233 .59391 m .60531 .58073 L .61176 .56158 L p
1 g
F P
s
P
p
.002 w
.62794 .30951 m .60845 .28192 L .59088 .28458 L p
1 g
F P
s
P
p
.002 w
.56835 .2679 m .59088 .28458 L .60845 .28192 L p
1 g
F P
s
P
p
.002 w
.6557 .53472 m .61176 .56158 L .60531 .58073 L p
1 g
F P
s
P
p
.002 w
.61176 .56158 m .6557 .53472 L .6585 .5127 L p
1 g
F P
s
P
p
.002 w
.33663 .32493 m .32726 .37003 L .34437 .35331 L p
1 g
F P
s
P
p
.002 w
.34437 .35331 m .35354 .31094 L .33663 .32493 L p
1 g
F P
s
P
p
.002 w
.45364 .24465 m .41899 .26497 L .44041 .26699 L p
1 g
F P
s
P
p
.002 w
.44041 .26699 m .46909 .25037 L .45364 .24465 L p
1 g
F P
s
P
p
.002 w
.64727 .31674 m .65605 .35272 L .67308 .3686 L p
1 g
F P
s
P
p
.002 w
.65605 .35272 m .64727 .31674 L .62794 .30951 L p
1 g
F P
s
P
p
.002 w
.30593 .40941 m .3171 .45684 L .32505 .43612 L p
1 g
F P
s
P
p
.002 w
.32505 .43612 m .31427 .38885 L .30593 .40941 L p
1 g
F P
s
P
p
.002 w
.54285 .24642 m .50464 .24313 L .51191 .25512 L p
1 g
F P
s
P
p
.002 w
.51191 .25512 m .54093 .25765 L .54285 .24642 L p
1 g
F P
s
P
p
.002 w
.60845 .28192 m .62794 .30951 L .64727 .31674 L p
1 g
F P
s
P
p
.002 w
.60845 .28192 m .57894 .25993 L .56835 .2679 L p
1 g
F P
s
P
p
.002 w
.54093 .25765 m .56835 .2679 L .57894 .25993 L p
1 g
F P
s
P
p
.002 w
.68598 .38663 m .67733 .42934 L .68471 .45176 L p
1 g
F P
s
P
p
.002 w
.67733 .42934 m .68598 .38663 L .67308 .3686 L p
1 g
F P
s
P
p
.002 w
.57894 .25993 m .54285 .24642 L .54093 .25765 L p
1 g
F P
s
P
p
.002 w
.38619 .58499 m .4331 .60737 L .43446 .5958 L p
1 g
F P
s
P
p
.002 w
.43446 .5958 m .38416 .5717 L .38619 .58499 L p
1 g
F P
s
P
p
.002 w
.48961 .60857 m .43446 .5958 L .4331 .60737 L p
1 g
F P
s
P
p
.002 w
.4331 .60737 m .48455 .6193 L .48961 .60857 L p
1 g
F P
s
P
p
.002 w
.54498 .60893 m .48961 .60857 L .48455 .6193 L p
1 g
F P
s
P
p
.002 w
.68734 .47428 m .6585 .5127 L .6557 .53472 L p
1 g
F P
s
P
p
.002 w
.6585 .5127 m .68734 .47428 L .68471 .45176 L p
1 g
F P
s
P
p
.002 w
.31552 .49762 m .34314 .53811 L .34257 .52007 L p
1 g
F P
s
P
p
.002 w
.34257 .52007 m .31382 .47752 L .31552 .49762 L p
1 g
F P
s
P
p
.002 w
.38115 .27425 m .35354 .31094 L .37378 .30053 L p
1 g
F P
s
P
p
.002 w
.37378 .30053 m .39904 .26733 L .38115 .27425 L p
1 g
F P
s
P
p
.002 w
.34801 .55389 m .38619 .58499 L .38416 .5717 L p
1 g
F P
s
P
p
.002 w
.38416 .5717 m .34314 .53811 L .34801 .55389 L p
1 g
F P
s
P
p
.002 w
.49696 .23573 m .45364 .24465 L .46909 .25037 L p
1 g
F P
s
P
p
.002 w
.46909 .25037 m .50464 .24313 L .49696 .23573 L p
1 g
F P
s
P
p
.002 w
.32368 .34229 m .31427 .38885 L .32726 .37003 L p
1 g
F P
s
P
p
.002 w
.32726 .37003 m .33663 .32493 L .32368 .34229 L p
1 g
F P
s
P
p
.002 w
.54498 .60893 m .5958 .59651 L .60531 .58073 L p
1 g
F P
s
P
p
.002 w
.6486 .55463 m .60531 .58073 L .5958 .59651 L p
1 g
F P
s
P
p
.002 w
.60531 .58073 m .6486 .55463 L .6557 .53472 L p
1 g
F P
s
P
p
.002 w
.66329 .32729 m .67308 .3686 L .68598 .38663 L p
1 g
F P
s
P
p
.002 w
.67308 .3686 m .66329 .32729 L .64727 .31674 L p
1 g
F P
s
P
p
.002 w
.64727 .31674 m .62377 .28316 L .60845 .28192 L p
1 g
F P
s
P
p
.002 w
.57894 .25993 m .60845 .28192 L .62377 .28316 L p
1 g
F P
s
P
p
.002 w
.48455 .6193 m .53613 .61973 L .54498 .60893 L p
1 g
F P
s
P
p
.002 w
.5958 .59651 m .54498 .60893 L .53613 .61973 L p
1 g
F P
s
P
p
.002 w
.43887 .2438 m .39904 .26733 L .41899 .26497 L p
1 g
F P
s
P
p
.002 w
.41899 .26497 m .45364 .24465 L .43887 .2438 L p
1 g
F P
s
P
p
.002 w
.30268 .43121 m .31382 .47752 L .3171 .45684 L p
1 g
F P
s
P
p
.002 w
.3171 .45684 m .30593 .40941 L .30268 .43121 L p
1 g
F P
s
P
p
.002 w
.69423 .40644 m .68471 .45176 L .68734 .47428 L p
1 g
F P
s
P
p
.002 w
.68471 .45176 m .69423 .40644 L .68598 .38663 L p
1 g
F P
s
P
p
.002 w
.62377 .28316 m .64727 .31674 L .66329 .32729 L p
1 g
F P
s
P
p
.002 w
.68493 .49632 m .6557 .53472 L .6486 .55463 L p
1 g
F P
s
P
p
.002 w
.6557 .53472 m .68493 .49632 L .68734 .47428 L p
1 g
F P
s
P
p
.002 w
.54368 .23973 m .49696 .23573 L .50464 .24313 L p
1 g
F P
s
P
p
.002 w
.50464 .24313 m .54285 .24642 L .54368 .23973 L p
1 g
F P
s
P
p
.002 w
.62377 .28316 m .58782 .25628 L .57894 .25993 L p
1 g
F P
s
P
p
.002 w
.54285 .24642 m .57894 .25993 L .58782 .25628 L p
1 g
F P
s
P
p
.002 w
.58782 .25628 m .54368 .23973 L .54285 .24642 L p
1 g
F P
s
P
p
.002 w
.36593 .28577 m .33663 .32493 L .35354 .31094 L p
1 g
F P
s
P
p
.002 w
.35354 .31094 m .38115 .27425 L .36593 .28577 L p
1 g
F P
s
P
p
.002 w
.39143 .59458 m .43351 .61461 L .4331 .60737 L p
1 g
F P
s
P
p
.002 w
.4331 .60737 m .38619 .58499 L .39143 .59458 L p
1 g
F P
s
P
p
.002 w
.48455 .6193 m .4331 .60737 L .43351 .61461 L p
1 g
F P
s
P
p
.002 w
.43351 .61461 m .4797 .62532 L .48455 .6193 L p
1 g
F P
s
P
p
.002 w
.53613 .61973 m .48455 .6193 L .4797 .62532 L p
1 g
F P
s
P
p
.002 w
.32242 .51655 m .34801 .55389 L .34314 .53811 L p
1 g
F P
s
P
p
.002 w
.34314 .53811 m .31552 .49762 L .32242 .51655 L p
1 g
F P
s
P
p
.002 w
.31524 .36269 m .30593 .40941 L .31427 .38885 L p
1 g
F P
s
P
p
.002 w
.31427 .38885 m .32368 .34229 L .31524 .36269 L p
1 g
F P
s
P
p
.002 w
.6754 .34106 m .68598 .38663 L .69423 .40644 L p
1 g
F P
s
P
p
.002 w
.68598 .38663 m .6754 .34106 L .66329 .32729 L p
1 g
F P
s
P
p
.002 w
.48903 .23343 m .43887 .2438 L .45364 .24465 L p
1 g
F P
s
P
p
.002 w
.45364 .24465 m .49696 .23573 L .48903 .23343 L p
1 g
F P
s
P
p
.002 w
.53613 .61973 m .58332 .60833 L .5958 .59651 L p
1 g
F P
s
P
p
.002 w
.63718 .5718 m .5958 .59651 L .58332 .60833 L p
1 g
F P
s
P
p
.002 w
.5958 .59651 m .63718 .5718 L .6486 .55463 L p
1 g
F P
s
P
p
.002 w
.35729 .56684 m .39143 .59458 L .38619 .58499 L p
1 g
F P
s
P
p
.002 w
.38619 .58499 m .34801 .55389 L .35729 .56684 L p
1 g
F P
s
P
p
.002 w
.42522 .24813 m .38115 .27425 L .39904 .26733 L p
1 g
F P
s
P
p
.002 w
.39904 .26733 m .43887 .2438 L .42522 .24813 L p
1 g
F P
s
P
p
.002 w
.30488 .4537 m .31552 .49762 L .31382 .47752 L p
1 g
F P
s
P
p
.002 w
.31382 .47752 m .30268 .43121 L .30488 .4537 L p
1 g
F P
s
P
p
.002 w
.69736 .42758 m .68734 .47428 L .68493 .49632 L p
1 g
F P
s
P
p
.002 w
.68734 .47428 m .69736 .42758 L .69423 .40644 L p
1 g
F P
s
P
p
.002 w
.66329 .32729 m .6363 .28849 L .62377 .28316 L p
1 g
F P
s
P
p
.002 w
.58782 .25628 m .62377 .28316 L .6363 .28849 L p
1 g
F P
s
P
p
.002 w
.4797 .62532 m .52593 .62575 L .53613 .61973 L p
1 g
F P
s
P
p
.002 w
.58332 .60833 m .53613 .61973 L .52593 .62575 L p
1 g
F P
s
P
p
.002 w
.6363 .28849 m .66329 .32729 L .6754 .34106 L p
1 g
F P
s
P
p
.002 w
.67729 .51724 m .6486 .55463 L .63718 .5718 L p
1 g
F P
s
P
p
.002 w
.6486 .55463 m .67729 .51724 L .68493 .49632 L p
1 g
F P
s
P
p
.002 w
.35397 .30181 m .32368 .34229 L .33663 .32493 L p
1 g
F P
s
P
p
.002 w
.33663 .32493 m .36593 .28577 L .35397 .30181 L p
1 g
F P
s
P
p
.002 w
.54332 .23806 m .48903 .23343 L .49696 .23573 L p
1 g
F P
s
P
p
.002 w
.49696 .23573 m .54368 .23973 L .54332 .23806 L p
1 g
F P
s
P
p
.002 w
.6363 .28849 m .59465 .2573 L .58782 .25628 L p
1 g
F P
s
P
p
.002 w
.54368 .23973 m .58782 .25628 L .59465 .2573 L p
1 g
F P
s
P
p
.002 w
.31179 .38569 m .30268 .43121 L .30593 .40941 L p
1 g
F P
s
P
p
.002 w
.30593 .40941 m .31524 .36269 L .31179 .38569 L p
1 g
F P
s
P
p
.002 w
.69423 .40644 m .68304 .35784 L .6754 .34106 L p
1 g
F P
s
P
p
.002 w
.68304 .35784 m .69423 .40644 L .69736 .42758 L p
1 g
F P
s
P
p
.002 w
.59465 .2573 m .54332 .23806 L .54368 .23973 L p
1 g
F P
s
P
p
.002 w
.39994 .59997 m .4358 .61703 L .43351 .61461 L p
1 g
F P
s
P
p
.002 w
.43351 .61461 m .39143 .59458 L .39994 .59997 L p
1 g
F P
s
P
p
.002 w
.4797 .62532 m .43351 .61461 L .4358 .61703 L p
1 g
F P
s
P
p
.004 w
.44268 .65632 m
.44907 .63113 L
s
P
p
.002 w
.3346 .53371 m .35729 .56684 L .34801 .55389 L p
1 g
F P
s
P
p
.002 w
.34801 .55389 m .32242 .51655 L .3346 .53371 L p
1 g
F P
s
P
p
.004 w
.34185 .54429 m
.5 .43051 L
s
P
p
.004 w
.34048 .54528 m
.34164 .54444 L
s
P
p
.004 w
.33583 .54863 m
.34048 .54528 L
s
P
p
.004 w
.3347 .54944 m
.33583 .54863 L
s
P
p
.004 w
.25827 .60443 m
.3347 .54944 L
s
P
p
.002 w
.4358 .61703 m .4752 .62618 L .4797 .62532 L p
1 g
F P
s
P
p
.002 w
.52593 .62575 m .4797 .62532 L .4752 .62618 L p
1 g
F P
s
P
p
.002 w
.68493 .49632 m .69504 .44951 L .69736 .42758 L p
1 g
F P
s
P
p
.002 w
.69504 .44951 m .68493 .49632 L .67729 .51724 L p
1 g
F P
s
P
p
.002 w
.31271 .47625 m .32242 .51655 L .31552 .49762 L p
1 g
F P
s
P
p
.002 w
.31552 .49762 m .30488 .4537 L .31271 .47625 L p
1 g
F P
s
P
p
.002 w
.41315 .25784 m .36593 .28577 L .38115 .27425 L p
1 g
F P
s
P
p
.002 w
.38115 .27425 m .42522 .24813 L .41315 .25784 L p
1 g
F P
s
P
p
.002 w
.52593 .62575 m .56803 .61563 L .58332 .60833 L p
1 g
F P
s
P
p
.002 w
.58332 .60833 m .62152 .58561 L .63718 .5718 L p
1 g
F P
s
P
p
.002 w
.62152 .58561 m .58332 .60833 L .56803 .61563 L p
1 g
F P
s
P
p
.002 w
.48106 .23661 m .42522 .24813 L .43887 .2438 L p
1 g
F P
s
P
p
.002 w
.43887 .2438 m .48903 .23343 L .48106 .23661 L p
1 g
F P
s
P
p
.002 w
.37099 .57643 m .39994 .59997 L .39143 .59458 L p
1 g
F P
s
P
p
.002 w
.39143 .59458 m .35729 .56684 L .37099 .57643 L p
1 g
F P
s
P
p
.002 w
.6754 .34106 m .64551 .29803 L .6363 .28849 L p
1 g
F P
s
P
p
.002 w
.59465 .2573 m .6363 .28849 L .64551 .29803 L p
1 g
F P
s
P
p
.002 w
.64551 .29803 m .6754 .34106 L .68304 .35784 L p
1 g
F P
s
P
p
.002 w
.63718 .5718 m .66439 .53638 L .67729 .51724 L p
1 g
F P
s
P
p
.002 w
.66439 .53638 m .63718 .5718 L .62152 .58561 L p
1 g
F P
s
P
p
.002 w
.4752 .62618 m .51457 .62655 L .52593 .62575 L p
1 g
F P
s
P
p
.002 w
.56803 .61563 m .52593 .62575 L .51457 .62655 L p
1 g
F P
s
P
p
.002 w
.3458 .32211 m .31524 .36269 L .32368 .34229 L p
1 g
F P
s
P
p
.002 w
.32368 .34229 m .35397 .30181 L .3458 .32211 L p
1 g
F P
s
P
p
.002 w
.31367 .4107 m .30488 .4537 L .30268 .43121 L p
1 g
F P
s
P
p
.002 w
.30268 .43121 m .31179 .38569 L .31367 .4107 L p
1 g
F P
s
P
p
.002 w
.68574 .3773 m .69736 .42758 L .69504 .44951 L p
1 g
F P
s
P
p
.002 w
.69736 .42758 m .68574 .3773 L .68304 .35784 L p
1 g
F P
s
P
p
.002 w
.54172 .24181 m .48106 .23661 L .48903 .23343 L p
1 g
F P
s
P
p
.002 w
.48903 .23343 m .54332 .23806 L .54172 .24181 L p
1 g
F P
s
P
p
.002 w
.64551 .29803 m .59908 .2633 L .59465 .2573 L p
1 g
F P
s
P
p
.002 w
.54332 .23806 m .59465 .2573 L .59908 .2633 L p
1 g
F P
s
P
p
.002 w
.68705 .47161 m .67729 .51724 L .66439 .53638 L p
1 g
F P
s
P
p
.002 w
.67729 .51724 m .68705 .47161 L .69504 .44951 L p
1 g
F P
s
P
p
.002 w
.35194 .54847 m .37099 .57643 L .35729 .56684 L p
1 g
F P
s
P
p
.002 w
.35729 .56684 m .3346 .53371 L .35194 .54847 L p
1 g
F P
s
P
p
.002 w
.32621 .49815 m .3346 .53371 L .32242 .51655 L p
1 g
F P
s
P
p
.002 w
.32242 .51655 m .31271 .47625 L .32621 .49815 L p
1 g
F P
s
P
p
.002 w
.40314 .27294 m .35397 .30181 L .36593 .28577 L p
1 g
F P
s
P
p
.002 w
.36593 .28577 m .41315 .25784 L .40314 .27294 L p
1 g
F P
s
P
p
.002 w
.59908 .2633 m .54172 .24181 L .54332 .23806 L p
1 g
F P
s
P
p
.002 w
.41166 .60074 m .44001 .61425 L .4358 .61703 L p
1 g
F P
s
P
p
.002 w
.4358 .61703 m .39994 .59997 L .41166 .60074 L p
1 g
F P
s
P
p
.002 w
.4752 .62618 m .4358 .61703 L .44001 .61425 L p
1 g
F P
s
P
p
.002 w
.44001 .61425 m .47121 .62149 L .4752 .62618 L p
1 g
F P
s
P
p
.002 w
.51457 .62655 m .4752 .62618 L .47121 .62149 L p
1 g
F P
s
P
p
.002 w
.51457 .62655 m .55024 .61795 L .56803 .61563 L p
1 g
F P
s
P
p
.002 w
.60187 .59547 m .56803 .61563 L .55024 .61795 L p
1 g
F P
s
P
p
.002 w
.56803 .61563 m .60187 .59547 L .62152 .58561 L p
1 g
F P
s
P
p
.002 w
.47331 .24554 m .41315 .25784 L .42522 .24813 L p
1 g
F P
s
P
p
.002 w
.42522 .24813 m .48106 .23661 L .47331 .24554 L p
1 g
F P
s
P
p
.002 w
.64638 .55309 m .62152 .58561 L .60187 .59547 L p
1 g
F P
s
P
p
.002 w
.62152 .58561 m .64638 .55309 L .66439 .53638 L p
1 g
F P
s
P
p
.002 w
.65094 .31174 m .68304 .35784 L .68574 .3773 L p
1 g
F P
s
P
p
.002 w
.68304 .35784 m .65094 .31174 L .64551 .29803 L p
1 g
F P
s
P
p
.002 w
.34188 .34626 m .31179 .38569 L .31524 .36269 L p
1 g
F P
s
P
p
.002 w
.31524 .36269 m .3458 .32211 L .34188 .34626 L p
1 g
F P
s
P
p
.002 w
.38892 .58218 m .41166 .60074 L .39994 .59997 L p
1 g
F P
s
P
p
.002 w
.39994 .59997 m .37099 .57643 L .38892 .58218 L p
1 g
F P
s
P
p
.002 w
.59908 .2633 m .64551 .29803 L .65094 .31174 L p
1 g
F P
s
P
p
.002 w
.47121 .62149 m .50232 .62176 L .51457 .62655 L p
1 g
F P
s
P
p
.002 w
.55024 .61795 m .51457 .62655 L .50232 .62176 L p
1 g
F P
s
P
p
.002 w
.32107 .43701 m .31271 .47625 L .30488 .4537 L p
1 g
F P
s
P
p
.002 w
.30488 .4537 m .31367 .4107 L .32107 .43701 L p
1 g
F P
s
P
p
.002 w
.68316 .39899 m .69504 .44951 L .68705 .47161 L p
1 g
F P
s
P
p
.002 w
.69504 .44951 m .68316 .39899 L .68574 .3773 L p
1 g
F P
s
P
p
.002 w
.67339 .49319 m .66439 .53638 L .64638 .55309 L p
1 g
F P
s
P
p
.002 w
.66439 .53638 m .67339 .49319 L .68705 .47161 L p
1 g
F P
s
P
p
.002 w
.34517 .51868 m .35194 .54847 L .3346 .53371 L p
1 g
F P
s
P
p
.002 w
.3346 .53371 m .32621 .49815 L .34517 .51868 L p
1 g
F P
s
P
p
.002 w
.53884 .25121 m .47331 .24554 L .48106 .23661 L p
1 g
F P
s
P
p
.002 w
.48106 .23661 m .54172 .24181 L .53884 .25121 L p
1 g
F P
s
P
p
.002 w
.37416 .56025 m .38892 .58218 L .37099 .57643 L p
1 g
F P
s
P
p
.002 w
.37099 .57643 m .35194 .54847 L .37416 .56025 L p
1 g
F P
s
P
p
.002 w
.39562 .29323 m .3458 .32211 L .35397 .30181 L p
1 g
F P
s
P
p
.002 w
.35397 .30181 m .40314 .27294 L .39562 .29323 L p
1 g
F P
s
P
p
.002 w
.65094 .31174 m .60083 .27439 L .59908 .2633 L p
1 g
F P
s
P
p
.002 w
.54172 .24181 m .59908 .2633 L .60083 .27439 L p
1 g
F P
s
P
p
.002 w
.50232 .62176 m .53033 .61493 L .55024 .61795 L p
1 g
F P
s
P
p
.002 w
.57864 .60089 m .55024 .61795 L .53033 .61493 L p
1 g
F P
s
P
p
.002 w
.55024 .61795 m .57864 .60089 L .60187 .59547 L p
1 g
F P
s
P
p
.002 w
.62358 .56672 m .60187 .59547 L .57864 .60089 L p
1 g
F P
s
P
p
.002 w
.60187 .59547 m .62358 .56672 L .64638 .55309 L p
1 g
F P
s
P
p
.002 w
.34254 .37362 m .31367 .4107 L .31179 .38569 L p
1 g
F P
s
P
p
.002 w
.31179 .38569 m .34188 .34626 L .34254 .37362 L p
1 g
F P
s
P
p
.002 w
.42645 .59658 m .44616 .606 L .44001 .61425 L p
1 g
F P
s
P
p
.002 w
.44001 .61425 m .41166 .60074 L .42645 .59658 L p
1 g
F P
s
P
p
.002 w
.47121 .62149 m .44001 .61425 L .44616 .606 L p
1 g
F P
s
P
p
.002 w
.46603 .26028 m .40314 .27294 L .41315 .25784 L p
1 g
F P
s
P
p
.002 w
.41315 .25784 m .47331 .24554 L .46603 .26028 L p
1 g
F P
s
P
p
.002 w
.60083 .27439 m .53884 .25121 L .54172 .24181 L p
1 g
F P
s
P
p
.002 w
.65217 .32945 m .68574 .3773 L .68316 .39899 L p
1 g
F P
s
P
p
.002 w
.68574 .3773 m .65217 .32945 L .65094 .31174 L p
1 g
F P
s
P
p
.002 w
.44616 .606 m .46789 .61104 L .47121 .62149 L p
1 g
F P
s
P
p
.002 w
.50232 .62176 m .47121 .62149 L .46789 .61104 L p
1 g
F P
s
P
p
.002 w
.33395 .46378 m .32621 .49815 L .31271 .47625 L p
1 g
F P
s
P
p
.002 w
.31271 .47625 m .32107 .43701 L .33395 .46378 L p
1 g
F P
s
P
p
.002 w
.60083 .27439 m .65094 .31174 L .65217 .32945 L p
1 g
F P
s
P
p
.002 w
.41076 .58367 m .42645 .59658 L .41166 .60074 L p
1 g
F P
s
P
p
.002 w
.41166 .60074 m .38892 .58218 L .41076 .58367 L p
1 g
F P
s
P
p
.002 w
.6751 .42232 m .68705 .47161 L .67339 .49319 L p
1 g
F P
s
P
p
.002 w
.68705 .47161 m .6751 .42232 L .68316 .39899 L p
1 g
F P
s
P
p
.002 w
.46789 .61104 m .48951 .61119 L .50232 .62176 L p
1 g
F P
s
P
p
.002 w
.53033 .61493 m .50232 .62176 L .48951 .61119 L p
1 g
F P
s
P
p
.002 w
.65423 .51353 m .64638 .55309 L .62358 .56672 L p
1 g
F P
s
P
p
.002 w
.64638 .55309 m .65423 .51353 L .67339 .49319 L p
1 g
F P
s
P
p
.002 w
.36918 .53708 m .37416 .56025 L .35194 .54847 L p
1 g
F P
s
P
p
.002 w
.35194 .54847 m .34517 .51868 L .36918 .53708 L p
1 g
F P
s
P
p
.002 w
.39099 .31831 m .34188 .34626 L .3458 .32211 L p
1 g
F P
s
P
p
.002 w
.3458 .32211 m .39562 .29323 L .39099 .31831 L p
1 g
F P
s
P
p
.002 w
.40074 .56853 m .41076 .58367 L .38892 .58218 L p
1 g
F P
s
P
p
.002 w
.38892 .58218 m .37416 .56025 L .40074 .56853 L p
1 g
F P
s
P
p
.002 w
.53033 .61493 m .5524 .60149 L .57864 .60089 L p
1 g
F P
s
P
p
.002 w
.59654 .5767 m .57864 .60089 L .5524 .60149 L p
1 g
F P
s
P
p
.002 w
.57864 .60089 m .59654 .5767 L .62358 .56672 L p
1 g
F P
s
P
p
.002 w
.34794 .40338 m .32107 .43701 L .31367 .4107 L p
1 g
F P
s
P
p
.002 w
.31367 .4107 m .34254 .37362 L .34794 .40338 L p
1 g
F P
s
P
p
.002 w
.48951 .61119 m .50885 .60639 L .53033 .61493 L p
1 g
F P
s
P
p
.002 w
.5524 .60149 m .53033 .61493 L .50885 .60639 L p
1 g
F P
s
P
p
.002 w
.53468 .26632 m .46603 .26028 L .47331 .24554 L p
1 g
F P
s
P
p
.002 w
.47331 .24554 m .53884 .25121 L .53468 .26632 L p
1 g
F P
s
P
p
.002 w
.35207 .49012 m .34517 .51868 L .32621 .49815 L p
1 g
F P
s
P
p
.002 w
.32621 .49815 m .33395 .46378 L .35207 .49012 L p
1 g
F P
s
P
p
.002 w
.64895 .35081 m .68316 .39899 L .6751 .42232 L p
1 g
F P
s
P
p
.002 w
.68316 .39899 m .64895 .35081 L .65217 .32945 L p
1 g
F P
s
P
p
.002 w
.65217 .32945 m .59968 .29056 L .60083 .27439 L p
1 g
F P
s
P
p
.002 w
.53884 .25121 m .60083 .27439 L .59968 .29056 L p
1 g
F P
s
P
p
.002 w
.45949 .28069 m .39562 .29323 L .40314 .27294 L p
1 g
F P
s
P
p
.002 w
.40314 .27294 m .46603 .26028 L .45949 .28069 L p
1 g
F P
s
P
p
.002 w
.66157 .44657 m .67339 .49319 L .65423 .51353 L p
1 g
F P
s
P
p
.002 w
.67339 .49319 m .66157 .44657 L .6751 .42232 L p
1 g
F P
s
P
p
.002 w
.63003 .53189 m .62358 .56672 L .59654 .5767 L p
1 g
F P
s
P
p
.002 w
.62358 .56672 m .63003 .53189 L .65423 .51353 L p
1 g
F P
s
P
p
.002 w
.44399 .58732 m .45415 .5922 L .44616 .606 L p
1 g
F P
s
P
p
.002 w
.44616 .606 m .42645 .59658 L .44399 .58732 L p
1 g
F P
s
P
p
.002 w
.46789 .61104 m .44616 .606 L .45415 .5922 L p
1 g
F P
s
P
p
.002 w
.59968 .29056 m .53468 .26632 L .53884 .25121 L p
1 g
F P
s
P
p
.002 w
.45415 .5922 m .46538 .5948 L .46789 .61104 L p
1 g
F P
s
P
p
.002 w
.48951 .61119 m .46789 .61104 L .46538 .5948 L p
1 g
F P
s
P
p
.002 w
.59968 .29056 m .65217 .32945 L .64895 .35081 L p
1 g
F P
s
P
p
.002 w
.43597 .58065 m .44399 .58732 L .42645 .59658 L p
1 g
F P
s
P
p
.002 w
.42645 .59658 m .41076 .58367 L .43597 .58065 L p
1 g
F P
s
P
p
.002 w
.46538 .5948 m .47653 .59485 L .48951 .61119 L p
1 g
F P
s
P
p
.002 w
.50885 .60639 m .48951 .61119 L .47653 .59485 L p
1 g
F P
s
P
p
.002 w
.39759 .55267 m .40074 .56853 L .37416 .56025 L p
1 g
F P
s
P
p
.002 w
.37416 .56025 m .36918 .53708 L .39759 .55267 L p
1 g
F P
s
P
p
.002 w
.38953 .34751 m .34254 .37362 L .34188 .34626 L p
1 g
F P
s
P
p
.002 w
.34188 .34626 m .39099 .31831 L .38953 .34751 L p
1 g
F P
s
P
p
.002 w
.35806 .43457 m .33395 .46378 L .32107 .43701 L p
1 g
F P
s
P
p
.002 w
.32107 .43701 m .34794 .40338 L .35806 .43457 L p
1 g
F P
s
P
p
.002 w
.50885 .60639 m .5239 .59702 L .5524 .60149 L p
1 g
F P
s
P
p
.002 w
.56603 .58256 m .5524 .60149 L .5239 .59702 L p
1 g
F P
s
P
p
.002 w
.5524 .60149 m .56603 .58256 L .59654 .5767 L p
1 g
F P
s
P
p
.002 w
.37494 .51509 m .36918 .53708 L .34517 .51868 L p
1 g
F P
s
P
p
.002 w
.34517 .51868 m .35207 .49012 L .37494 .51509 L p
1 g
F P
s
P
p
.002 w
.43095 .57287 m .43597 .58065 L .41076 .58367 L p
1 g
F P
s
P
p
.002 w
.41076 .58367 m .40074 .56853 L .43095 .57287 L p
1 g
F P
s
P
p
.002 w
.47653 .59485 m .48644 .59233 L .50885 .60639 L p
1 g
F P
s
P
p
.002 w
.5239 .59702 m .50885 .60639 L .48644 .59233 L p
1 g
F P
s
P
p
.002 w
.64113 .37526 m .6751 .42232 L .66157 .44657 L p
1 g
F P
s
P
p
.002 w
.6751 .42232 m .64113 .37526 L .64895 .35081 L p
1 g
F P
s
P
p
.002 w
.60144 .54757 m .59654 .5767 L .56603 .58256 L p
1 g
F P
s
P
p
.002 w
.59654 .5767 m .60144 .54757 L .63003 .53189 L p
1 g
F P
s
P
p
.002 w
.64284 .47094 m .65423 .51353 L .63003 .53189 L p
1 g
F P
s
P
p
.002 w
.65423 .51353 m .64284 .47094 L .66157 .44657 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.52931 .28696 m .45949 .28069 L .46603 .26028 L p
1 g
F P
s
P
p
.002 w
.46603 .26028 m .53468 .26632 L .52931 .28696 L p
1 g
F P
s
P
p
.002 w
.45398 .30633 m .39099 .31831 L .39562 .29323 L p
1 g
F P
s
P
p
.002 w
.39562 .29323 m .45949 .28069 L .45398 .30633 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.47179 .54166 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.64895 .35081 m .59548 .31154 L .59968 .29056 L p
1 g
F P
s
P
p
.002 w
.53468 .26632 m .59968 .29056 L .59548 .31154 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.42949 .56481 m .43095 .57287 L .40074 .56853 L p
1 g
F P
s
P
p
.002 w
.40074 .56853 m .39759 .55267 L .42949 .56481 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.37266 .46609 m .35207 .49012 L .33395 .46378 L p
1 g
F P
s
P
p
.002 w
.33395 .46378 m .35806 .43457 L .37266 .46609 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.59548 .31154 m .64895 .35081 L .64113 .37526 L p
1 g
F P
s
P
p
.002 w
.40182 .53777 m .39759 .55267 L .36918 .53708 L p
1 g
F P
s
P
p
.002 w
.36918 .53708 m .37494 .51509 L .40182 .53777 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.48644 .59233 m .49404 .58747 L .5239 .59702 L p
1 g
F P
s
P
p
.002 w
.53298 .58396 m .5239 .59702 L .49404 .58747 L p
1 g
F P
s
P
p
.002 w
.5239 .59702 m .53298 .58396 L .56603 .58256 L p
1 g
F P
s
P
p
.002 w
.45415 .5922 m .44399 .58732 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.46538 .5948 m .45415 .5922 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.47653 .59485 m .46538 .5948 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.59548 .31154 m .52931 .28696 L .53468 .26632 L p
1 g
F P
s
P
p
.002 w
.39143 .3799 m .34794 .40338 L .34254 .37362 L p
1 g
F P
s
P
p
.002 w
.34254 .37362 m .38953 .34751 L .39143 .3799 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44399 .58732 m .43597 .58065 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.48644 .59233 m .47653 .59485 L .46427 .57376 L p
1 g
F P
s
P
p
.002 w
.46496 .57397 m .48644 .59233 L p
.46427 .57376 L 1 g
F P
s
P
p
.002 w
.48644 .59233 m .46496 .57397 L p
.47562 .57892 L 1 g
F P
s
P
p
.002 w
.46496 .57397 m .46383 .57301 L .46719 .57462 L p
1 g
F P
s
P
p
.002 w
.46719 .57462 m .49404 .58747 L p
.46496 .57397 L 1 g
F P
s
P
p
.002 w
.46427 .57376 m .46383 .57301 L .46496 .57397 L p
1 g
F P
s
P
p
.002 w
.43597 .58065 m .43095 .57287 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.43095 .57287 m .42949 .56481 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.49404 .58747 m .47135 .57661 L p
.47762 .57756 L 1 g
F P
s
P
p
.002 w
.49699 .58305 m .49404 .58747 L p
.48218 .58032 L 1 g
F P
s
P
p
.48905 .5808 m .48218 .58032 L .47762 .57756 L 1 g
F
P
p
.49699 .58305 m .48218 .58032 L .48905 .5808 L 1 g
F
P
p
.51079 .57862 m .49707 .58136 L .49807 .58143 L 1 g
F
P
p
.002 w
.50304 .58118 m .50762 .58161 L p
.49807 .58143 L 1 g
F P
s
P
p
.002 w
.50762 .58161 m .53298 .58396 L p
.50601 .58201 L 1 g
F P
s
P
p
.50601 .58201 m .49807 .58143 L .50762 .58161 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58068 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58068 L .51193 .5804 L 1 g
F
P
p
.002 w
.53298 .58396 m .50762 .58161 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53176 .57483 L p
1 g
F P
s
P
p
.002 w
.53421 .57414 m .53357 .57923 L p
.5224 .57994 L 1 g
F P
s
P
p
.53421 .57414 m .5224 .57994 L .53176 .57483 L 1 g
F
P
p
.54854 .56129 m .53176 .57483 L .5343 .57344 L 1 g
F
P
p
.002 w
.54537 .56591 m .5473 .56543 L p
.5343 .57344 L 1 g
F P
s
P
p
.002 w
.5473 .56543 m .56937 .55994 L p
.54312 .57004 L 1 g
F P
s
P
p
.54312 .57004 m .5343 .57344 L .5473 .56543 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56302 L p
1 g
F P
s
P
p
.56075 .54566 m .54918 .56302 L .55062 .56119 L 1 g
F
P
p
.002 w
.56937 .55994 m .5473 .56543 L p
.54918 .56302 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56157 .5472 L p
1 g
F P
s
P
p
.002 w
.56415 .54389 m .56619 .55016 L p
.55817 .55622 L 1 g
F P
s
P
p
.56415 .54389 m .55817 .55622 L .56157 .5472 L 1 g
F
P
p
.56654 .52734 m .56157 .5472 L .56353 .54197 L 1 g
F
P
p
.002 w
.56641 .53293 m .59201 .51653 L p
.56353 .54197 L 1 g
F P
s
P
p
.56432 .53948 m .56353 .54197 L .56419 .54021 L 1 g
F
P
p
.56654 .52734 m .56353 .54197 L .56432 .53948 L 1 g
F
P
p
.002 w
.56937 .55994 m .56353 .54197 L p
.59201 .51653 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.5616 .53602 m .56353 .54197 L p
.53492 .5685 L 1 g
F P
s
P
p
.002 w
.56353 .54197 m .56415 .54389 L p
.56219 .54554 L 1 g
F P
s
P
p
.56157 .5472 m .55817 .55622 L .54918 .56302 L 1 g
F
P
p
.002 w
.56619 .55016 m .56937 .55994 L p
.54918 .56302 L 1 g
F P
s
P
p
.55593 .5544 m .54927 .56325 L .55381 .55824 L 1 g
F
P
p
.56075 .54566 m .55062 .56119 L .55593 .5544 L 1 g
F
P
p
.55062 .56119 m .54927 .56325 L .55593 .5544 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.56353 .54197 m .56219 .54554 L .53492 .5685 L 1 g
F
P
p
.002 w
.54918 .56302 m .54854 .56129 L p
.53724 .57206 L 1 g
F P
s
P
p
.54854 .56129 m .5343 .57344 L .53951 .56989 L 1 g
F
P
p
.002 w
.5473 .56543 m .53492 .5685 L p
.56415 .54389 L 1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52866 L p
1 g
F P
s
P
p
.002 w
.56861 .48718 m .57538 .49567 L p
.56678 .52084 L 1 g
F P
s
P
p
.56861 .48718 m .56725 .51216 L .56567 .50766 L 1 g
F
P
p
.56725 .51216 m .56678 .52084 L .56578 .50901 L 1 g
F
P
p
.56725 .51216 m .56578 .50901 L .56567 .50766 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56578 .50901 L p
1 g
F P
s
P
p
.55661 .4905 m .56578 .50901 L .56151 .49987 L 1 g
F
P
p
.56515 .50826 m .56744 .52866 L .56641 .51644 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.57538 .49567 m .59201 .51653 L .56773 .53208 L p
1 g
F P
s
P
p
.57538 .49567 m .56773 .53208 L .56744 .52866 L 1 g
F
P
p
.56654 .52734 m .56419 .54021 L .5655 .53671 L 1 g
F
P
p
.002 w
.56744 .52866 m .56654 .52734 L p
.5655 .53671 L 1 g
F P
s
P
p
.002 w
.56641 .53293 m .5616 .53602 L p
.57538 .49567 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56578 .50901 L p
1 g
F P
s
P
p
.002 w
.56578 .50901 m .56515 .50826 L p
.56641 .51644 L 1 g
F P
s
P
p
.56641 .51644 m .56854 .53025 L .56578 .50901 L 1 g
F
P
p
.002 w
.56773 .53208 m .56641 .53293 L p
.56744 .52866 L 1 g
F P
s
P
p
.56567 .50766 m .56678 .52084 L .5616 .53602 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.55661 .4905 m .56151 .49987 L .55982 .49627 L 1 g
F
P
p
.002 w
.54842 .47339 m .56861 .48718 L .56111 .49494 L p
1 g
F P
s
P
p
.002 w
.56111 .49494 m .55982 .49627 L p
.55733 .49126 L 1 g
F P
s
P
p
.54842 .47339 m .56111 .49494 L .55733 .49126 L 1 g
F
P
p
.002 w
.55733 .49126 m .55661 .4905 L p
.55982 .49627 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55733 .49126 L p
1 g
F P
s
P
p
.002 w
.55763 .49159 m .55733 .49126 L p
.55982 .49627 L 1 g
F P
s
P
p
.54174 .47608 m .55733 .49126 L .54814 .48234 L 1 g
F
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55982 .49627 m .54315 .51353 L p
.54735 .48158 L 1 g
F P
s
P
p
.002 w
.5422 .47659 m .54174 .47608 L p
.54814 .48234 L 1 g
F P
s
P
p
.54842 .47339 m .55733 .49126 L .54735 .48158 L 1 g
F
P
p
.55733 .49126 m .55982 .49627 L .54735 .48158 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53357 .46325 m .54842 .47339 L p
.54767 .47914 L 1 g
F P
s
P
p
.53551 .47345 m .54767 .47914 L .54315 .51353 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5422 .47659 L p
1 g
F P
s
P
p
.52214 .46667 m .5422 .47659 L .53269 .47213 L 1 g
F
P
p
.53357 .46325 m .54767 .47914 L .53551 .47345 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54315 .51353 m .5159 .49524 L .52949 .47063 L p
1 g
F P
s
P
p
.52214 .46667 m .53269 .47213 L .52949 .47063 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52949 .47063 m .5159 .49524 L p
.49939 .46385 L 1 g
F P
s
P
p
.5 .46375 m .52949 .47063 L .49939 .46385 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.5 .4634 m .52241 .46712 L .50842 .46502 L 1 g
F
P
p
.52241 .46712 m .52949 .47063 L .5 .46375 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .4634 L p
.50842 .46502 L 1 g
F P
s
P
p
.50842 .46502 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .48878 .46556 L 1 g
F
P
p
.47786 .46667 m .48878 .46556 L .48699 .46585 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48699 .46585 m .48303 .48349 L p
.47099 .47028 L 1 g
F P
s
P
p
.47761 .46708 m .48699 .46585 L .47099 .47028 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47761 .46708 L p
1 g
F P
s
P
p
.45826 .47608 m .47761 .46708 L .4661 .47264 L 1 g
F
P
p
.002 w
.45768 .47671 m .45826 .47608 L p
.4661 .47264 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44855 .47976 m .44635 .44325 L p
.46783 .46682 L 1 g
F P
s
P
p
.002 w
.48303 .48349 m .45396 .48034 L p
.46783 .46682 L 1 g
F P
s
P
p
.002 w
.47567 .51697 m .45233 .51437 L .44913 .48503 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45754 .47687 L p
1 g
F P
s
P
p
.44339 .4905 m .45754 .47687 L .45352 .48076 L 1 g
F
P
p
.002 w
.45396 .48034 m .48303 .48349 L p
.45104 .48317 L 1 g
F P
s
P
p
.45122 .483 m .45726 .47717 L .45237 .48189 L 1 g
F
P
p
.44339 .4905 m .45352 .48076 L .45122 .483 L 1 g
F
P
p
.45352 .48076 m .45726 .47717 L .45122 .483 L 1 g
F
P
p
.002 w
.48303 .48349 m .47567 .51697 L p
.45104 .48317 L 1 g
F P
s
P
p
.002 w
.44855 .47976 m .45396 .48034 L p
.45104 .48317 L 1 g
F P
s
P
p
.45104 .48317 m .47567 .51697 L .44913 .48503 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43394 .50934 m .43485 .50826 L p
.43785 .50125 L 1 g
F P
s
P
p
.43437 .49928 m .44267 .49127 L .43752 .50193 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44267 .49127 L p
1 g
F P
s
P
p
.002 w
.44267 .49127 m .44166 .49233 L p
.43785 .50125 L 1 g
F P
s
P
p
.43485 .50826 m .44267 .49127 L .43785 .50125 L 1 g
F
P
p
.41671 .48444 m .44571 .48497 L .43437 .49928 L 1 g
F
P
p
.44339 .4905 m .45202 .48223 L .45172 .48252 L 1 g
F
P
p
.002 w
.44913 .48503 m .45233 .51437 L p
.43752 .50193 L 1 g
F P
s
P
p
.44267 .49127 m .44913 .48503 L .43752 .50193 L 1 g
F
P
p
.002 w
.44171 .49228 m .44267 .49127 L p
.45172 .48252 L 1 g
F P
s
P
p
.002 w
.44267 .49127 m .44339 .4905 L p
.45172 .48252 L 1 g
F P
s
P
p
.44571 .48497 m .44913 .48503 L .44267 .49127 L 1 g
F
P
p
.44571 .48497 m .44267 .49127 L .43437 .49928 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43068 .51736 m .41671 .48444 L p
.435 .49981 L 1 g
F P
s
P
p
.43346 .52734 m .4331 .51696 L .43309 .51703 L 1 g
F
P
p
.43346 .52734 m .43309 .51703 L .43301 .51852 L 1 g
F
P
p
.002 w
.43284 .52141 m .43068 .51736 L p
.43294 .51975 L 1 g
F P
s
P
p
.002 w
.43254 .52867 m .43346 .52734 L p
.43301 .51852 L 1 g
F P
s
P
p
.002 w
.43068 .51736 m .43309 .51703 L p
.43294 .51975 L 1 g
F P
s
P
p
.43301 .51852 m .43298 .51802 L .43284 .52141 L 1 g
F
P
p
.43301 .51852 m .43284 .52141 L .43254 .52867 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43309 .51703 m .43068 .51736 L p
.435 .49981 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.45233 .51437 m .4575 .54581 L p
.43294 .51975 L 1 g
F P
s
P
p
.002 w
.43309 .51703 m .45233 .51437 L p
.43294 .51975 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.4575 .54581 m .4466 .54723 L .43284 .52141 L p
1 g
F P
s
P
p
.43294 .51975 m .4575 .54581 L .43284 .52141 L 1 g
F
P
p
.43301 .51852 m .43309 .51703 L .43298 .51802 L 1 g
F
P
p
.002 w
.41322 .52551 m .43068 .51736 L .43284 .52141 L p
1 g
F P
s
P
p
.41322 .52551 m .43049 .5219 L .43217 .53784 L 1 g
F
P
p
.43049 .5219 m .43284 .52141 L .43254 .52867 L 1 g
F
P
p
.43049 .5219 m .43254 .52867 L .43217 .53784 L 1 g
F
P
p
.002 w
.43826 .54752 m .43925 .54566 L p
.43537 .53799 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43254 .52867 L p
1 g
F P
s
P
p
.43925 .54566 m .43254 .52867 L .43537 .53799 L 1 g
F
P
p
.002 w
.43284 .52141 m .4466 .54723 L p
.4361 .5404 L 1 g
F P
s
P
p
.43217 .53784 m .43254 .52867 L .4361 .5404 L 1 g
F
P
p
.43254 .52867 m .43284 .52141 L .4361 .5404 L 1 g
F
P
p
.002 w
.43254 .52867 m .43146 .53025 L p
.43537 .53799 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43772 .55122 m .41322 .52551 L p
.43167 .53752 L 1 g
F P
s
P
p
.002 w
.44002 .55019 m .43772 .55122 L p
.43167 .53752 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43809 .54786 L p
1 g
F P
s
P
p
.002 w
.44803 .55983 m .43772 .55122 L .44002 .55019 L p
1 g
F P
s
P
p
.002 w
.43809 .54786 m .43743 .5491 L p
.44351 .55438 L 1 g
F P
s
P
p
.45146 .56129 m .43809 .54786 L .44351 .55438 L 1 g
F
P
p
.002 w
.43181 .55731 m .43772 .55122 L .44803 .55983 L p
1 g
F P
s
P
p
.002 w
.45577 .56905 m .43181 .55731 L p
.44571 .55947 L 1 g
F P
s
P
p
.44571 .55947 m .44803 .55983 L .45078 .56311 L 1 g
F
P
p
.44571 .55947 m .45078 .56311 L .45577 .56905 L 1 g
F
P
p
.002 w
.46383 .57301 m .46535 .57335 L p
.46823 .57491 L 1 g
F P
s
P
p
.002 w
.47135 .57661 m .46719 .57462 L p
.46823 .57491 L 1 g
F P
s
P
p
.002 w
.46719 .57462 m .46383 .57301 L p
.46823 .57491 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46823 .57491 L p
1 g
F P
s
P
p
.48921 .57862 m .46823 .57491 L .46828 .57492 L 1 g
F
P
p
.48921 .57862 m .46828 .57492 L .47813 .57771 L 1 g
F
P
p
.002 w
.46823 .57491 m .46872 .57265 L p
.45825 .56847 L 1 g
F P
s
P
p
.002 w
.46383 .57301 m .45577 .56905 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.45924 .56918 m .46383 .57301 L p
.45078 .56311 L 1 g
F P
s
P
p
.45825 .56847 m .46239 .57144 L .46823 .57491 L 1 g
F
P
p
.002 w
.46313 .57195 m .46383 .57301 L .45924 .56918 L p
1 g
F P
s
P
p
.46239 .57144 m .46312 .57196 L .46321 .57202 L 1 g
F
P
p
.46239 .57144 m .46321 .57202 L .46823 .57491 L 1 g
F
P
p
.46312 .57196 m .46357 .57227 L .46823 .57491 L 1 g
F
P
p
.46346 .57221 m .4638 .57243 L .46823 .57491 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.4466 .54723 m .4575 .54581 L .46367 .57234 L p
1 g
F P
s
P
p
.002 w
.46367 .57234 m .46383 .57301 L .46313 .57195 L p
1 g
F P
s
P
p
.002 w
.46313 .57195 m .4466 .54723 L p
.46367 .57234 L 1 g
F P
s
P
p
.46367 .57236 m .464 .57256 L .46823 .57491 L 1 g
F
P
p
.002 w
.4575 .54581 m .4692 .54714 L .46393 .57251 L p
1 g
F P
s
P
p
.002 w
.46393 .57251 m .46383 .57301 L .46367 .57234 L p
1 g
F P
s
P
p
.002 w
.46367 .57234 m .4575 .54581 L p
.46393 .57251 L 1 g
F P
s
P
p
.46312 .57196 m .46346 .57221 L .46357 .57227 L 1 g
F
P
p
.46346 .57221 m .46367 .57236 L .4638 .57243 L 1 g
F
P
p
.46381 .57246 m .4642 .57269 L .46823 .57491 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.4692 .54714 m .48037 .55109 L .46411 .57263 L p
1 g
F P
s
P
p
.002 w
.46411 .57263 m .46383 .57301 L .46393 .57251 L p
1 g
F P
s
P
p
.002 w
.46393 .57251 m .4692 .54714 L p
.46411 .57263 L 1 g
F P
s
P
p
.46392 .57254 m .46453 .57289 L .46823 .57491 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48037 .55109 m .48975 .55719 L .46427 .57273 L p
1 g
F P
s
P
p
.002 w
.46427 .57273 m .46383 .57301 L .46411 .57263 L p
1 g
F P
s
P
p
.002 w
.46411 .57263 m .48037 .55109 L p
.46427 .57273 L 1 g
F P
s
P
p
.46367 .57236 m .46381 .57246 L .464 .57256 L 1 g
F
P
p
.46381 .57246 m .46392 .57254 L .4642 .57269 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48975 .55719 m .4963 .56475 L .46446 .57284 L p
1 g
F P
s
P
p
.002 w
.46446 .57284 m .46383 .57301 L .46427 .57273 L p
1 g
F P
s
P
p
.002 w
.46427 .57273 m .48975 .55719 L p
.46446 .57284 L 1 g
F P
s
P
p
.46402 .57261 m .46535 .57335 L .46823 .57491 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.4963 .56475 m .49931 .57291 L .46473 .573 L p
1 g
F P
s
P
p
.002 w
.46473 .573 m .46383 .57301 L .46446 .57284 L p
1 g
F P
s
P
p
.002 w
.46446 .57284 m .4963 .56475 L p
.46473 .573 L 1 g
F P
s
P
p
.46392 .57254 m .46402 .57261 L .46453 .57289 L 1 g
F
P
p
.46402 .57261 m .4641 .57267 L .46535 .57335 L 1 g
F
P
p
.002 w
.48905 .5808 m .48921 .57862 L p
.47813 .57771 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .5808 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .5808 L .49461 .58119 L 1 g
F
P
p
.002 w
.49807 .58143 m .49699 .58305 L p
.48905 .5808 L 1 g
F P
s
P
p
.51079 .57862 m .48895 .58209 L .49556 .58166 L 1 g
F
P
p
.002 w
.49851 .58076 m .49807 .58143 L p
.47762 .57756 L 1 g
F P
s
P
p
.49807 .58143 m .48905 .5808 L .47762 .57756 L 1 g
F
P
p
.002 w
.48905 .5808 m .48895 .58209 L p
.49461 .58119 L 1 g
F P
s
P
p
.002 w
.48895 .58209 m .48889 .583 L p
.49556 .58166 L 1 g
F P
s
P
p
.53176 .57483 m .5224 .57994 L .51094 .58068 L 1 g
F
P
p
.002 w
.53357 .57923 m .53298 .58396 L p
.51094 .58068 L 1 g
F P
s
P
p
.52131 .57777 m .51095 .58079 L .51951 .57869 L 1 g
F
P
p
.53128 .57265 m .51193 .5804 L .52131 .57777 L 1 g
F
P
p
.51193 .5804 m .51095 .58079 L .52131 .57777 L 1 g
F
P
p
.002 w
.50762 .58161 m .50304 .58118 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.51095 .58079 m .51079 .57862 L p
.49807 .58143 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.49404 .58747 m .49807 .58143 L p
.53298 .58396 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.53421 .57414 m .51094 .58068 L .49851 .58076 L 1 g
F
P
p
.002 w
.50304 .58118 m .49851 .58076 L p
.51094 .58068 L 1 g
F P
s
P
p
.002 w
.46535 .57335 m .49851 .58076 L p
.47762 .57756 L 1 g
F P
s
P
p
.47762 .57756 m .47135 .57661 L .46823 .57491 L 1 g
F
P
p
.47762 .57756 m .46823 .57491 L .46535 .57335 L 1 g
F
P
p
.002 w
.48902 .58121 m .48905 .5808 L p
.4771 .57763 L 1 g
F P
s
P
p
.47813 .57771 m .4771 .57763 L .48905 .5808 L 1 g
F
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49931 .57291 m .49851 .58076 L .46535 .57335 L p
1 g
F P
s
P
p
.002 w
.46535 .57335 m .46383 .57301 L .46473 .573 L p
1 g
F P
s
P
p
.002 w
.46473 .573 m .49931 .57291 L p
.46535 .57335 L 1 g
F P
s
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.44336 .55425 L 1 g
F P
s
P
p
.002 w
.4466 .54723 m .46313 .57195 L p
.44803 .55983 L 1 g
F P
s
P
p
.002 w
.45924 .56918 m .44803 .55983 L p
.46313 .57195 L 1 g
F P
s
P
p
.45924 .56918 m .45119 .56565 L .4641 .57267 L 1 g
F
P
p
.45825 .56847 m .45824 .56847 L .45924 .56918 L 1 g
F
P
p
.45824 .56847 m .45119 .56565 L .45924 .56918 L 1 g
F
P
p
.002 w
.44803 .55983 m .45924 .56918 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.46823 .57491 m .46823 .57491 L p
.46828 .57492 L 1 g
F P
s
P
p
.002 w
.46823 .57491 m .46823 .57491 L p
.46416 .5727 L 1 g
F P
s
P
p
.46416 .5727 m .45092 .56554 L .46418 .57272 L 1 g
F
P
p
.46416 .5727 m .46418 .57272 L .46823 .57491 L 1 g
F
P
p
.002 w
.45002 .56518 m .45078 .56311 L p
.44182 .55291 L 1 g
F P
s
P
p
.44336 .55425 m .44182 .55291 L .45078 .56311 L 1 g
F
P
p
.002 w
.44002 .55019 m .4466 .54723 L p
.44803 .55983 L 1 g
F P
s
P
p
.002 w
.4466 .54723 m .44002 .55019 L p
.43167 .53752 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .44931 .56428 L p
.44182 .55291 L 1 g
F P
s
P
p
.002 w
.44931 .56428 m .45002 .56518 L p
.44182 .55291 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43826 .54752 L p
1 g
F P
s
P
p
.43537 .53799 m .43146 .53025 L .43826 .54752 L 1 g
F
P
p
.002 w
.43166 .52997 m .43254 .52867 L p
.43298 .51802 L 1 g
F P
s
P
p
.002 w
.45233 .51437 m .43309 .51703 L p
.435 .49981 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43166 .52997 L p
1 g
F P
s
P
p
.4331 .51696 m .43287 .51061 L .43166 .52997 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43394 .50934 L p
1 g
F P
s
P
p
.43785 .50125 m .44166 .49233 L .43394 .50934 L 1 g
F
P
p
.002 w
.44913 .48503 m .44855 .47976 L p
.45104 .48317 L 1 g
F P
s
P
p
.002 w
.45754 .47687 m .45726 .47717 L p
.45352 .48076 L 1 g
F P
s
P
p
.002 w
.45726 .47717 m .45698 .47747 L p
.45237 .48189 L 1 g
F P
s
P
p
.002 w
.41671 .48444 m .44855 .47976 L .44913 .48503 L p
1 g
F P
s
P
p
.002 w
.45396 .48034 m .44855 .47976 L p
.46783 .46682 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44171 .49228 L p
1 g
F P
s
P
p
.45202 .48223 m .45698 .47747 L .44171 .49228 L 1 g
F
P
p
.002 w
.47761 .46708 m .47718 .46778 L p
.4661 .47264 L 1 g
F P
s
P
p
.44635 .44325 m .48382 .46408 L .46909 .4682 L 1 g
F
P
p
.002 w
.47761 .46708 m .47786 .46667 L p
.48699 .46585 L 1 g
F P
s
P
p
.48382 .46408 m .48699 .46585 L .47761 .46708 L 1 g
F
P
p
.48382 .46408 m .47761 .46708 L .46909 .4682 L 1 g
F
P
p
.46909 .4682 m .47761 .46708 L .47099 .47028 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45768 .47671 L p
1 g
F P
s
P
p
.4661 .47264 m .47718 .46778 L .45768 .47671 L 1 g
F
P
p
.002 w
.47743 .46739 m .47761 .46708 L p
.48699 .46585 L 1 g
F P
s
P
p
.002 w
.44635 .44325 m .49101 .44793 L .48699 .46585 L p
1 g
F P
s
P
p
.002 w
.5159 .49524 m .48303 .48349 L .49101 .44793 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .46442 L p
.48878 .46556 L 1 g
F P
s
P
p
.49359 .45283 m .51179 .46186 L .5 .46375 L 1 g
F
P
p
.49928 .46365 m .5 .46375 L .49939 .46385 L 1 g
F
P
p
.49359 .45283 m .5 .46375 L .49928 .46365 L 1 g
F
P
p
.51179 .46186 m .52241 .46712 L .5 .46375 L 1 g
F
P
p
.002 w
.52241 .46712 m .52282 .46778 L p
.50842 .46502 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47743 .46739 L p
1 g
F P
s
P
p
.48878 .46556 m .5 .46442 L .47743 .46739 L 1 g
F
P
p
.002 w
.52258 .4674 m .52241 .46712 L p
.52949 .47063 L 1 g
F P
s
P
p
.002 w
.52241 .46712 m .52214 .46667 L p
.52949 .47063 L 1 g
F P
s
P
p
.002 w
.49101 .44793 m .53357 .46325 L .52949 .47063 L p
1 g
F P
s
P
p
.49101 .44793 m .52949 .47063 L .49359 .45283 L 1 g
F
P
p
.002 w
.52949 .47063 m .53357 .46325 L p
.53551 .47345 L 1 g
F P
s
P
p
.53551 .47345 m .54315 .51353 L .52949 .47063 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52258 .4674 L p
1 g
F P
s
P
p
.53269 .47213 m .54302 .47747 L .52258 .4674 L 1 g
F
P
p
.002 w
.5422 .47659 m .54302 .47747 L p
.53269 .47213 L 1 g
F P
s
P
p
.002 w
.55982 .49627 m .56861 .48718 L p
.56555 .50851 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55763 .49159 L p
1 g
F P
s
P
p
.56151 .49987 m .56713 .51061 L .55763 .49159 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5422 .47659 L p
1 g
F P
s
P
p
.54814 .48234 m .55834 .49233 L .5422 .47659 L 1 g
F
P
p
.002 w
.55733 .49126 m .55834 .49233 L p
.54814 .48234 L 1 g
F P
s
P
p
.002 w
.5616 .53602 m .54315 .51353 L .55982 .49627 L p
1 g
F P
s
P
p
.56555 .50851 m .5616 .53602 L .55982 .49627 L 1 g
F
P
p
.002 w
.56578 .50901 m .56713 .51061 L p
.56151 .49987 L 1 g
F P
s
P
p
.002 w
.56744 .52866 m .56854 .53025 L p
.56641 .51644 L 1 g
F P
s
P
p
.002 w
.56815 .52968 m .56744 .52866 L p
.5655 .53671 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56815 .52968 L p
1 g
F P
s
P
p
.56419 .54021 m .56257 .5491 L .56815 .52968 L 1 g
F
P
p
.002 w
.56353 .54197 m .5616 .53602 L .56641 .53293 L p
1 g
F P
s
P
p
.002 w
.56157 .5472 m .56257 .5491 L p
.56419 .54021 L 1 g
F P
s
P
p
.002 w
.53298 .58396 m .5343 .57344 L p
.56937 .55994 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56302 L p
1 g
F P
s
P
p
.53724 .57206 m .5322 .57686 L .54918 .56302 L 1 g
F
P
p
.002 w
.54918 .56302 m .54927 .56325 L p
.55062 .56119 L 1 g
F P
s
P
p
.002 w
.54927 .56325 m .54998 .56518 L p
.55381 .55824 L 1 g
F P
s
P
p
.53951 .56989 m .5343 .57344 L .5378 .57153 L 1 g
F
P
p
.002 w
.5343 .57344 m .53492 .5685 L .54537 .56591 L p
1 g
F P
s
P
p
.002 w
.53492 .5685 m .53421 .57414 L p
.49851 .58076 L 1 g
F P
s
P
p
.002 w
.53176 .57483 m .5322 .57686 L p
.5378 .57153 L 1 g
F P
s
P
p
.002 w
.51106 .58234 m .51095 .58079 L p
.50304 .58118 L 1 g
F P
s
P
p
.50304 .58118 m .49807 .58143 L .4986 .58147 L 1 g
F
P
p
.50304 .58118 m .4986 .58147 L .51106 .58234 L 1 g
F
P
p
.002 w
.51094 .58068 m .51095 .58079 L p
.51193 .5804 L 1 g
F P
s
P
p
.002 w
.51095 .58079 m .51111 .583 L p
.51951 .57869 L 1 g
F P
s
P
p
.002 w
.49807 .58143 m .49851 .58076 L .50304 .58118 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51106 .58234 L p
1 g
F P
s
P
p
.49707 .58136 m .48889 .583 L .51106 .58234 L 1 g
F
P
p
.47813 .57771 m .46823 .57491 L .47783 .57769 L 1 g
F
P
p
.46828 .57492 m .46823 .57491 L .47813 .57771 L 1 g
F
P
p
.45119 .56565 m .45092 .56554 L .46823 .57491 L 1 g
F
P
p
.002 w
.42949 .56481 m .43181 .55731 L .46383 .57301 L closepath p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46823 .57491 L p
1 g
F P
s
P
p
.45092 .56554 m .45002 .56518 L .46823 .57491 L 1 g
F
P
p
.002 w
.49404 .58747 m .49283 .58824 L p
.47562 .57892 L 1 g
F P
s
P
p
.002 w
.49283 .58824 m .48644 .59233 L p
.47562 .57892 L 1 g
F P
s
P
p
.002 w
.46823 .57491 m .4678 .57686 L p
.47783 .57769 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58121 L p
1 g
F P
s
P
p
.4771 .57763 m .4678 .57686 L .48902 .58121 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.56937 .55994 m .56603 .58256 L .53298 .58396 L p
1 g
F P
s
P
p
.002 w
.56603 .58256 m .56937 .55994 L .60144 .54757 L p
1 g
F P
s
P
p
.002 w
.61941 .49456 m .63003 .53189 L .60144 .54757 L p
1 g
F P
s
P
p
.002 w
.63003 .53189 m .61941 .49456 L .64284 .47094 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.6288 .40208 m .66157 .44657 L .64284 .47094 L p
1 g
F P
s
P
p
.002 w
.66157 .44657 m .6288 .40208 L .64113 .37526 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.39126 .49678 m .37494 .51509 L .35207 .49012 L p
1 g
F P
s
P
p
.002 w
.35207 .49012 m .37266 .46609 L .39126 .49678 L p
1 g
F P
s
P
p
.002 w
.43181 .55731 m .42949 .56481 L .39759 .55267 L p
1 g
F P
s
P
p
.002 w
.39759 .55267 m .40182 .53777 L .43181 .55731 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.44973 .33649 m .38953 .34751 L .39099 .31831 L p
1 g
F P
s
P
p
.002 w
.39099 .31831 m .45398 .30633 L .44973 .33649 L p
1 g
F P
s
P
p
.002 w
.52287 .31268 m .45398 .30633 L .45949 .28069 L p
1 g
F P
s
P
p
.002 w
.45949 .28069 m .52931 .28696 L .52287 .31268 L p
1 g
F P
s
P
p
.002 w
.59201 .51653 m .60144 .54757 L .56937 .55994 L p
1 g
F P
s
P
p
.002 w
.60144 .54757 m .59201 .51653 L .61941 .49456 L p
1 g
F P
s
P
p
.002 w
.39672 .41438 m .35806 .43457 L .34794 .40338 L p
1 g
F P
s
P
p
.002 w
.34794 .40338 m .39143 .3799 L .39672 .41438 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.64113 .37526 m .58823 .33684 L .59548 .31154 L p
1 g
F P
s
P
p
.002 w
.52931 .28696 m .59548 .31154 L .58823 .33684 L p
1 g
F P
s
P
p
.002 w
.58823 .33684 m .64113 .37526 L .6288 .40208 L p
1 g
F P
s
P
p
.002 w
.41322 .52551 m .40182 .53777 L .37494 .51509 L p
1 g
F P
s
P
p
.002 w
.37494 .51509 m .39126 .49678 L .41322 .52551 L p
1 g
F P
s
P
p
.002 w
.49851 .58076 m .49931 .57291 L .53492 .5685 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61223 .43037 m .64284 .47094 L .61941 .49456 L p
1 g
F P
s
P
p
.002 w
.64284 .47094 m .61223 .43037 L .6288 .40208 L p
1 g
F P
s
P
p
.002 w
.58823 .33684 m .52287 .31268 L .52931 .28696 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.43772 .55122 m .43181 .55731 L .40182 .53777 L p
1 g
F P
s
P
p
.002 w
.40182 .53777 m .41322 .52551 L .43772 .55122 L p
1 g
F P
s
P
p
.002 w
.49931 .57291 m .4963 .56475 L .52929 .55229 L p
1 g
F P
s
P
p
.002 w
.52929 .55229 m .53492 .5685 L .49931 .57291 L p
1 g
F P
s
P
p
.002 w
.53492 .5685 m .52929 .55229 L .5616 .53602 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.40524 .44967 m .37266 .46609 L .35806 .43457 L p
1 g
F P
s
P
p
.002 w
.35806 .43457 m .39672 .41438 L .40524 .44967 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44696 .3702 m .39143 .3799 L .38953 .34751 L p
1 g
F P
s
P
p
.002 w
.38953 .34751 m .44973 .33649 L .44696 .3702 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59193 .4591 m .61941 .49456 L .59201 .51653 L p
1 g
F P
s
P
p
.002 w
.61941 .49456 m .59193 .4591 L .61223 .43037 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4963 .56475 m .48975 .55719 L .51652 .53715 L p
1 g
F P
s
P
p
.002 w
.51652 .53715 m .52929 .55229 L .4963 .56475 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.51555 .34275 m .44973 .33649 L .45398 .30633 L p
1 g
F P
s
P
p
.002 w
.45398 .30633 m .52287 .31268 L .51555 .34275 L p
1 g
F P
s
P
p
.002 w
.41671 .48444 m .39126 .49678 L .37266 .46609 L p
1 g
F P
s
P
p
.002 w
.37266 .46609 m .40524 .44967 L .41671 .48444 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57806 .36572 m .6288 .40208 L .61223 .43037 L p
1 g
F P
s
P
p
.002 w
.6288 .40208 m .57806 .36572 L .58823 .33684 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52287 .31268 m .58823 .33684 L .57806 .36572 L p
1 g
F P
s
P
p
.002 w
.43068 .51736 m .41322 .52551 L .39126 .49678 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.39126 .49678 m .41671 .48444 L .43068 .51736 L p
1 g
F P
s
P
p
.002 w
.48975 .55719 m .48037 .55109 L .49794 .52488 L p
1 g
F P
s
P
p
.002 w
.49794 .52488 m .51652 .53715 L .48975 .55719 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59201 .51653 m .56861 .48718 L .59193 .4591 L p
1 g
F P
s
P
p
.002 w
.52929 .55229 m .51652 .53715 L .54315 .51353 L p
1 g
F P
s
P
p
.002 w
.54315 .51353 m .5616 .53602 L .52929 .55229 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4692 .54714 m .4575 .54581 L .45233 .51437 L p
1 g
F P
s
P
p
.002 w
.48037 .55109 m .4692 .54714 L .47567 .51697 L p
1 g
F P
s
P
p
.002 w
.47567 .51697 m .49794 .52488 L .48037 .55109 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.45233 .51437 m .47567 .51697 L .4692 .54714 L p
1 g
F P
s
P
p
.002 w
.57806 .36572 m .51555 .34275 L .52287 .31268 L p
1 g
F P
s
P
p
.002 w
.44581 .40625 m .39672 .41438 L .39143 .3799 L p
1 g
F P
s
P
p
.002 w
.39143 .3799 m .44696 .3702 L .44581 .40625 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56525 .3972 m .61223 .43037 L .59193 .4591 L p
1 g
F P
s
P
p
.002 w
.61223 .43037 m .56525 .3972 L .57806 .36572 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51652 .53715 m .49794 .52488 L .5159 .49524 L p
1 g
F P
s
P
p
.002 w
.5159 .49524 m .54315 .51353 L .51652 .53715 L p
1 g
F P
s
P
p
.002 w
.5076 .37616 m .44696 .3702 L .44973 .33649 L p
1 g
F P
s
P
p
.002 w
.44973 .33649 m .51555 .34275 L .5076 .37616 L p
1 g
F P
s
P
p
.002 w
.44635 .44325 m .40524 .44967 L .39672 .41438 L p
1 g
F P
s
P
p
.002 w
.39672 .41438 m .44581 .40625 L .44635 .44325 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.51555 .34275 m .57806 .36572 L .56525 .3972 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44855 .47976 m .41671 .48444 L .40524 .44967 L p
1 g
F P
s
P
p
.002 w
.40524 .44967 m .44635 .44325 L .44855 .47976 L p
1 g
F P
s
P
p
.002 w
.55023 .43014 m .59193 .4591 L .56861 .48718 L p
1 g
F P
s
P
p
.002 w
.59193 .4591 m .55023 .43014 L .56525 .3972 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49794 .52488 m .47567 .51697 L .48303 .48349 L p
1 g
F P
s
P
p
.002 w
.48303 .48349 m .5159 .49524 L .49794 .52488 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56525 .3972 m .5076 .37616 L .51555 .34275 L p
1 g
F P
s
P
p
.002 w
.56861 .48718 m .53357 .46325 L .55023 .43014 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.004 w
.44907 .63113 m
.45162 .62112 L
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49931 .41168 m .44581 .40625 L .44696 .3702 L p
1 g
F P
s
P
p
.002 w
.44696 .3702 m .5076 .37616 L .49931 .41168 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5076 .37616 m .56525 .3972 L .55023 .43014 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49101 .44793 m .44635 .44325 L .44581 .40625 L p
1 g
F P
s
P
p
.002 w
.44581 .40625 m .49931 .41168 L .49101 .44793 L p
1 g
F P
s
P
p
.002 w
.55023 .43014 m .49931 .41168 L .5076 .37616 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49931 .41168 m .55023 .43014 L .53357 .46325 L p
1 g
F P
s
P
p
.002 w
.53357 .46325 m .49101 .44793 L .49931 .41168 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .25827 .60443 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .44268 .65632 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.466667)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.466667)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44372 .42405 m .47623 .45006 L .49092 .42563 L p
1 g
F P
s
P
p
.002 w
.49092 .42563 m .46389 .40387 L .44372 .42405 L p
1 g
F P
s
P
p
.002 w
.52291 .43972 m .49092 .42563 L .47623 .45006 L p
1 g
F P
s
P
p
.002 w
.46389 .40387 m .49092 .42563 L .50582 .40131 L p
1 g
F P
s
P
p
.002 w
.49092 .42563 m .52291 .43972 L .53066 .41223 L p
1 g
F P
s
P
p
.002 w
.53066 .41223 m .50582 .40131 L .49092 .42563 L p
1 g
F P
s
P
p
.002 w
.47623 .45006 m .51461 .46701 L .52291 .43972 L p
1 g
F P
s
P
p
.002 w
.55686 .44481 m .52291 .43972 L .51461 .46701 L p
1 g
F P
s
P
p
.002 w
.52291 .43972 m .55686 .44481 L .557 .41605 L p
1 g
F P
s
P
p
.002 w
.557 .41605 m .53066 .41223 L .52291 .43972 L p
1 g
F P
s
P
p
.002 w
.50582 .40131 m .48491 .38437 L .46389 .40387 L p
1 g
F P
s
P
p
.002 w
.48491 .38437 m .50582 .40131 L .52068 .37755 L p
1 g
F P
s
P
p
.002 w
.50582 .40131 m .53066 .41223 L .53771 .38503 L p
1 g
F P
s
P
p
.002 w
.53771 .38503 m .52068 .37755 L .50582 .40131 L p
1 g
F P
s
P
p
.002 w
.42475 .44454 m .46202 .47418 L .47623 .45006 L p
1 g
F P
s
P
p
.002 w
.47623 .45006 m .44372 .42405 L .42475 .44454 L p
1 g
F P
s
P
p
.002 w
.51461 .46701 m .47623 .45006 L .46202 .47418 L p
1 g
F P
s
P
p
.002 w
.53066 .41223 m .557 .41605 L .55575 .38756 L p
1 g
F P
s
P
p
.002 w
.55575 .38756 m .53771 .38503 L .53066 .41223 L p
1 g
F P
s
P
p
.002 w
.46202 .47418 m .50589 .49359 L .51461 .46701 L p
1 g
F P
s
P
p
.002 w
.55534 .4733 m .51461 .46701 L .50589 .49359 L p
1 g
F P
s
P
p
.002 w
.51461 .46701 m .55534 .4733 L .55686 .44481 L p
1 g
F P
s
P
p
.002 w
.42017 .39128 m .44372 .42405 L .46389 .40387 L p
1 g
F P
s
P
p
.002 w
.46389 .40387 m .44448 .37645 L .42017 .39128 L p
1 g
F P
s
P
p
.002 w
.44448 .37645 m .46389 .40387 L .48491 .38437 L p
1 g
F P
s
P
p
.002 w
.48491 .38437 m .47002 .36303 L .44448 .37645 L p
1 g
F P
s
P
p
.002 w
.47002 .36303 m .48491 .38437 L .50639 .36591 L p
1 g
F P
s
P
p
.002 w
.52068 .37755 m .50639 .36591 L .48491 .38437 L p
1 g
F P
s
P
p
.002 w
.39757 .40723 m .42475 .44454 L .44372 .42405 L p
1 g
F P
s
P
p
.002 w
.44372 .42405 m .42017 .39128 L .39757 .40723 L p
1 g
F P
s
P
p
.002 w
.50639 .36591 m .52068 .37755 L .53522 .3548 L p
1 g
F P
s
P
p
.002 w
.52068 .37755 m .53771 .38503 L .54392 .35861 L p
1 g
F P
s
P
p
.002 w
.54392 .35861 m .53522 .3548 L .52068 .37755 L p
1 g
F P
s
P
p
.002 w
.40738 .46498 m .44857 .49753 L .46202 .47418 L p
1 g
F P
s
P
p
.002 w
.46202 .47418 m .42475 .44454 L .40738 .46498 L p
1 g
F P
s
P
p
.002 w
.50589 .49359 m .46202 .47418 L .44857 .49753 L p
1 g
F P
s
P
p
.002 w
.58951 .44023 m .55686 .44481 L .55534 .4733 L p
1 g
F P
s
P
p
.002 w
.55686 .44481 m .58951 .44023 L .58225 .4123 L p
1 g
F P
s
P
p
.002 w
.58225 .4123 m .557 .41605 L .55686 .44481 L p
1 g
F P
s
P
p
.002 w
.557 .41605 m .58225 .4123 L .57298 .38485 L p
1 g
F P
s
P
p
.002 w
.57298 .38485 m .55575 .38756 L .557 .41605 L p
1 g
F P
s
P
p
.002 w
.53771 .38503 m .55575 .38756 L .55313 .35986 L p
1 g
F P
s
P
p
.002 w
.55313 .35986 m .54392 .35861 L .53771 .38503 L p
1 g
F P
s
P
p
.002 w
.44857 .49753 m .49692 .51897 L .50589 .49359 L p
1 g
F P
s
P
p
.002 w
.55244 .501 m .50589 .49359 L .49692 .51897 L p
1 g
F P
s
P
p
.002 w
.50589 .49359 m .55244 .501 L .55534 .4733 L p
1 g
F P
s
P
p
.002 w
.50639 .36591 m .49631 .35124 L .47002 .36303 L p
1 g
F P
s
P
p
.002 w
.49631 .35124 m .50639 .36591 L .52794 .34883 L p
1 g
F P
s
P
p
.002 w
.53522 .3548 m .52794 .34883 L .50639 .36591 L p
1 g
F P
s
P
p
.002 w
.59462 .46813 m .55534 .4733 L .55244 .501 L p
1 g
F P
s
P
p
.002 w
.55534 .4733 m .59462 .46813 L .58951 .44023 L p
1 g
F P
s
P
p
.002 w
.55575 .38756 m .57298 .38485 L .56188 .35841 L p
1 g
F P
s
P
p
.002 w
.56188 .35841 m .55313 .35986 L .55575 .38756 L p
1 g
F P
s
P
p
.002 w
.43477 .34594 m .44448 .37645 L .47002 .36303 L p
1 g
F P
s
P
p
.002 w
.47002 .36303 m .46276 .33935 L .43477 .34594 L p
1 g
F P
s
P
p
.002 w
.46276 .33935 m .47002 .36303 L .49631 .35124 L p
1 g
F P
s
P
p
.002 w
.37714 .42402 m .40738 .46498 L .42475 .44454 L p
1 g
F P
s
P
p
.002 w
.42475 .44454 m .39757 .40723 L .37714 .42402 L p
1 g
F P
s
P
p
.002 w
.40812 .3547 m .42017 .39128 L .44448 .37645 L p
1 g
F P
s
P
p
.002 w
.44448 .37645 m .43477 .34594 L .40812 .3547 L p
1 g
F P
s
P
p
.002 w
.49631 .35124 m .49152 .33503 L .46276 .33935 L p
1 g
F P
s
P
p
.002 w
.52794 .34883 m .52285 .34132 L .49631 .35124 L p
1 g
F P
s
P
p
.002 w
.49152 .33503 m .49631 .35124 L .52285 .34132 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .52794 .34883 L .53522 .3548 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .53522 .3548 L .54392 .35861 L closepath p
1 g
F P
s
P
p
.002 w
.60381 .40118 m .58225 .4123 L .58951 .44023 L p
1 g
F P
s
P
p
.002 w
.58225 .4123 m .60381 .40118 L .58759 .3771 L p
1 g
F P
s
P
p
.002 w
.58759 .3771 m .57298 .38485 L .58225 .4123 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .54392 .35861 L .55313 .35986 L closepath p
1 g
F P
s
P
p
.002 w
.39196 .48496 m .43613 .51967 L .44857 .49753 L p
1 g
F P
s
P
p
.002 w
.44857 .49753 m .40738 .46498 L .39196 .48496 L p
1 g
F P
s
P
p
.002 w
.49692 .51897 m .44857 .49753 L .43613 .51967 L p
1 g
F P
s
P
p
.002 w
.57298 .38485 m .58759 .3771 L .56926 .35439 L p
1 g
F P
s
P
p
.002 w
.56926 .35439 m .56188 .35841 L .57298 .38485 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .52285 .34132 L .52794 .34883 L closepath p
1 g
F P
s
P
p
.002 w
.49692 .51897 m .54821 .52736 L .55244 .501 L p
1 g
F P
s
P
p
.002 w
.59745 .49544 m .55244 .501 L .54821 .52736 L p
1 g
F P
s
P
p
.002 w
.55244 .501 m .59745 .49544 L .59462 .46813 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .55313 .35986 L .56188 .35841 L closepath p
1 g
F P
s
P
p
.002 w
.43613 .51967 m .48785 .54265 L .49692 .51897 L p
1 g
F P
s
P
p
.002 w
.54821 .52736 m .49692 .51897 L .48785 .54265 L p
1 g
F P
s
P
p
.002 w
.38336 .36549 m .39757 .40723 L .42017 .39128 L p
1 g
F P
s
P
p
.002 w
.42017 .39128 m .40812 .3547 L .38336 .36549 L p
1 g
F P
s
P
p
.002 w
.61758 .42618 m .58951 .44023 L .59462 .46813 L p
1 g
F P
s
P
p
.002 w
.58951 .44023 m .61758 .42618 L .60381 .40118 L p
1 g
F P
s
P
p
.002 w
.52285 .34132 m .5205 .33306 L .49152 .33503 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .5205 .33306 L .52285 .34132 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .56188 .35841 L .56926 .35439 L closepath p
1 g
F P
s
P
p
.002 w
.46408 .31572 m .46276 .33935 L .49152 .33503 L p
1 g
F P
s
P
p
.002 w
.49152 .33503 m .49263 .31895 L .46408 .31572 L p
1 g
F P
s
P
p
.002 w
.49263 .31895 m .49152 .33503 L .5205 .33306 L p
1 g
F P
s
P
p
.002 w
.43609 .31532 m .43477 .34594 L .46276 .33935 L p
1 g
F P
s
P
p
.002 w
.46276 .33935 m .46408 .31572 L .43609 .31532 L p
1 g
F P
s
P
p
.002 w
.35936 .44134 m .39196 .48496 L .40738 .46498 L p
1 g
F P
s
P
p
.002 w
.40738 .46498 m .37714 .42402 L .35936 .44134 L p
1 g
F P
s
P
p
.002 w
.5205 .33306 m .52117 .32492 L .49263 .31895 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .52117 .32492 L .5205 .33306 L closepath p
1 g
F P
s
P
p
.002 w
.62858 .4516 m .59462 .46813 L .59745 .49544 L p
1 g
F P
s
P
p
.002 w
.59462 .46813 m .62858 .4516 L .61758 .42618 L p
1 g
F P
s
P
p
.002 w
.59799 .36503 m .58759 .3771 L .60381 .40118 L p
1 g
F P
s
P
p
.002 w
.58759 .3771 m .59799 .36503 L .57444 .3482 L p
1 g
F P
s
P
p
.002 w
.57444 .3482 m .56926 .35439 L .58759 .3771 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .56926 .35439 L .57444 .3482 L closepath p
1 g
F P
s
P
p
.002 w
.36106 .37815 m .37714 .42402 L .39757 .40723 L p
1 g
F P
s
P
p
.002 w
.39757 .40723 m .38336 .36549 L .36106 .37815 L p
1 g
F P
s
P
p
.002 w
.40926 .31782 m .40812 .3547 L .43477 .34594 L p
1 g
F P
s
P
p
.002 w
.43477 .34594 m .43609 .31532 L .40926 .31782 L p
1 g
F P
s
P
p
.002 w
.49964 .30473 m .49263 .31895 L .52117 .32492 L p
1 g
F P
s
P
p
.002 w
.52117 .32492 m .52482 .31778 L .49964 .30473 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .52482 .31778 L .52117 .32492 L closepath p
1 g
F P
s
P
p
.002 w
.61934 .38366 m .60381 .40118 L .61758 .42618 L p
1 g
F P
s
P
p
.002 w
.60381 .40118 m .61934 .38366 L .59799 .36503 L p
1 g
F P
s
P
p
.002 w
.48785 .54265 m .54269 .55185 L .54821 .52736 L p
1 g
F P
s
P
p
.002 w
.59789 .52162 m .54821 .52736 L .54269 .55185 L p
1 g
F P
s
P
p
.002 w
.54821 .52736 m .59789 .52162 L .59745 .49544 L p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .57444 .3482 L .57684 .3405 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .57684 .3405 L .57617 .33211 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .57617 .33211 L .57248 .32394 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .57248 .32394 L .56614 .31692 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .56614 .31692 L .55786 .31183 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .55786 .31183 L .54857 .30925 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .54857 .30925 L .5393 .30946 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .5393 .30946 L .53108 .31242 L closepath p
1 g
F P
s
P
p
.002 w
.54915 .33349 m .53108 .31242 L .52482 .31778 L closepath p
1 g
F P
s
P
p
.002 w
.37888 .50407 m .42499 .54012 L .43613 .51967 L p
1 g
F P
s
P
p
.002 w
.43613 .51967 m .39196 .48496 L .37888 .50407 L p
1 g
F P
s
P
p
.002 w
.48785 .54265 m .43613 .51967 L .42499 .54012 L p
1 g
F P
s
P
p
.002 w
.57684 .3405 m .57444 .3482 L .59799 .36503 L p
1 g
F P
s
P
p
.002 w
.47411 .29465 m .46408 .31572 L .49263 .31895 L p
1 g
F P
s
P
p
.002 w
.49263 .31895 m .49964 .30473 L .47411 .29465 L p
1 g
F P
s
P
p
.002 w
.42499 .54012 m .47887 .56409 L .48785 .54265 L p
1 g
F P
s
P
p
.002 w
.54269 .55185 m .48785 .54265 L .47887 .56409 L p
1 g
F P
s
P
p
.002 w
.51193 .29396 m .49964 .30473 L .52482 .31778 L p
1 g
F P
s
P
p
.002 w
.52482 .31778 m .53108 .31242 L .51193 .29396 L p
1 g
F P
s
P
p
.002 w
.63652 .47694 m .59745 .49544 L .59789 .52162 L p
1 g
F P
s
P
p
.002 w
.59745 .49544 m .63652 .47694 L .62858 .4516 L p
1 g
F P
s
P
p
.002 w
.63798 .40374 m .61758 .42618 L .62858 .4516 L p
1 g
F P
s
P
p
.002 w
.61758 .42618 m .63798 .40374 L .61934 .38366 L p
1 g
F P
s
P
p
.002 w
.60296 .34985 m .59799 .36503 L .61934 .38366 L p
1 g
F P
s
P
p
.002 w
.59799 .36503 m .60296 .34985 L .57684 .3405 L p
1 g
F P
s
P
p
.002 w
.57617 .33211 m .57684 .3405 L .60296 .34985 L p
1 g
F P
s
P
p
.002 w
.38418 .32326 m .38336 .36549 L .40812 .3547 L p
1 g
F P
s
P
p
.002 w
.40812 .3547 m .40926 .31782 L .38418 .32326 L p
1 g
F P
s
P
p
.002 w
.44875 .28784 m .43609 .31532 L .46408 .31572 L p
1 g
F P
s
P
p
.002 w
.46408 .31572 m .47411 .29465 L .44875 .28784 L p
1 g
F P
s
P
p
.002 w
.34471 .45885 m .37888 .50407 L .39196 .48496 L p
1 g
F P
s
P
p
.002 w
.39196 .48496 m .35936 .44134 L .34471 .45885 L p
1 g
F P
s
P
p
.002 w
.52822 .28793 m .51193 .29396 L .53108 .31242 L p
1 g
F P
s
P
p
.002 w
.53108 .31242 m .5393 .30946 L .52822 .28793 L p
1 g
F P
s
P
p
.002 w
.34177 .39247 m .35936 .44134 L .37714 .42402 L p
1 g
F P
s
P
p
.002 w
.37714 .42402 m .36106 .37815 L .34177 .39247 L p
1 g
F P
s
P
p
.002 w
.60296 .34985 m .60181 .33318 L .57617 .33211 L p
1 g
F P
s
P
p
.002 w
.57248 .32394 m .57617 .33211 L .60181 .33318 L p
1 g
F P
s
P
p
.002 w
.49205 .27857 m .47411 .29465 L .49964 .30473 L p
1 g
F P
s
P
p
.002 w
.49964 .30473 m .51193 .29396 L .49205 .27857 L p
1 g
F P
s
P
p
.002 w
.54674 .28742 m .52822 .28793 L .5393 .30946 L p
1 g
F P
s
P
p
.002 w
.5393 .30946 m .54857 .30925 L .54674 .28742 L p
1 g
F P
s
P
p
.002 w
.62693 .36141 m .61934 .38366 L .63798 .40374 L p
1 g
F P
s
P
p
.002 w
.61934 .38366 m .62693 .36141 L .60296 .34985 L p
1 g
F P
s
P
p
.002 w
.47887 .56409 m .53595 .57389 L .54269 .55185 L p
1 g
F P
s
P
p
.002 w
.59585 .54608 m .54269 .55185 L .53595 .57389 L p
1 g
F P
s
P
p
.002 w
.54269 .55185 m .59585 .54608 L .59789 .52162 L p
1 g
F P
s
P
p
.002 w
.60181 .33318 m .59456 .31685 L .57248 .32394 L p
1 g
F P
s
P
p
.002 w
.56614 .31692 m .57248 .32394 L .59456 .31685 L p
1 g
F P
s
P
p
.002 w
.65348 .4249 m .62858 .4516 L .63652 .47694 L p
1 g
F P
s
P
p
.002 w
.62858 .4516 m .65348 .4249 L .63798 .40374 L p
1 g
F P
s
P
p
.002 w
.56536 .29255 m .54674 .28742 L .54857 .30925 L p
1 g
F P
s
P
p
.002 w
.54857 .30925 m .55786 .31183 L .56536 .29255 L p
1 g
F P
s
P
p
.002 w
.60181 .33318 m .60296 .34985 L .62693 .36141 L p
1 g
F P
s
P
p
.002 w
.59456 .31685 m .58194 .30276 L .56614 .31692 L p
1 g
F P
s
P
p
.002 w
.55786 .31183 m .56614 .31692 L .58194 .30276 L p
1 g
F P
s
P
p
.002 w
.42412 .28454 m .40926 .31782 L .43609 .31532 L p
1 g
F P
s
P
p
.002 w
.43609 .31532 m .44875 .28784 L .42412 .28454 L p
1 g
F P
s
P
p
.002 w
.58194 .30276 m .56536 .29255 L .55786 .31183 L p
1 g
F P
s
P
p
.002 w
.36852 .52187 m .41542 .55838 L .42499 .54012 L p
1 g
F P
s
P
p
.002 w
.42499 .54012 m .37888 .50407 L .36852 .52187 L p
1 g
F P
s
P
p
.002 w
.47887 .56409 m .42499 .54012 L .41542 .55838 L p
1 g
F P
s
P
p
.002 w
.36147 .33162 m .36106 .37815 L .38336 .36549 L p
1 g
F P
s
P
p
.002 w
.38336 .36549 m .38418 .32326 L .36147 .33162 L p
1 g
F P
s
P
p
.002 w
.64116 .50166 m .59789 .52162 L .59585 .54608 L p
1 g
F P
s
P
p
.002 w
.59789 .52162 m .64116 .50166 L .63652 .47694 L p
1 g
F P
s
P
p
.002 w
.41542 .55838 m .47015 .58277 L .47887 .56409 L p
1 g
F P
s
P
p
.002 w
.53595 .57389 m .47887 .56409 L .47015 .58277 L p
1 g
F P
s
P
p
.002 w
.51611 .26946 m .49205 .27857 L .51193 .29396 L p
1 g
F P
s
P
p
.002 w
.51193 .29396 m .52822 .28793 L .51611 .26946 L p
1 g
F P
s
P
p
.002 w
.47186 .2667 m .44875 .28784 L .47411 .29465 L p
1 g
F P
s
P
p
.002 w
.47411 .29465 m .49205 .27857 L .47186 .2667 L p
1 g
F P
s
P
p
.002 w
.64819 .37499 m .63798 .40374 L .65348 .4249 L p
1 g
F P
s
P
p
.002 w
.63798 .40374 m .64819 .37499 L .62693 .36141 L p
1 g
F P
s
P
p
.002 w
.62693 .36141 m .62548 .33676 L .60181 .33318 L p
1 g
F P
s
P
p
.002 w
.59456 .31685 m .60181 .33318 L .62548 .33676 L p
1 g
F P
s
P
p
.002 w
.32605 .4082 m .34471 .45885 L .35936 .44134 L p
1 g
F P
s
P
p
.002 w
.35936 .44134 m .34177 .39247 L .32605 .4082 L p
1 g
F P
s
P
p
.002 w
.33363 .47616 m .36852 .52187 L .37888 .50407 L p
1 g
F P
s
P
p
.002 w
.37888 .50407 m .34471 .45885 L .33363 .47616 L p
1 g
F P
s
P
p
.002 w
.66538 .44669 m .63652 .47694 L .64116 .50166 L p
1 g
F P
s
P
p
.002 w
.63652 .47694 m .66538 .44669 L .65348 .4249 L p
1 g
F P
s
P
p
.002 w
.62548 .33676 m .62693 .36141 L .64819 .37499 L p
1 g
F P
s
P
p
.002 w
.4008 .28496 m .38418 .32326 L .40926 .31782 L p
1 g
F P
s
P
p
.002 w
.40926 .31782 m .42412 .28454 L .4008 .28496 L p
1 g
F P
s
P
p
.002 w
.54364 .26858 m .51611 .26946 L .52822 .28793 L p
1 g
F P
s
P
p
.002 w
.52822 .28793 m .54674 .28742 L .54364 .26858 L p
1 g
F P
s
P
p
.002 w
.47015 .58277 m .52807 .59291 L .53595 .57389 L p
1 g
F P
s
P
p
.002 w
.59128 .56824 m .53595 .57389 L .52807 .59291 L p
1 g
F P
s
P
p
.002 w
.53595 .57389 m .59128 .56824 L .59585 .54608 L p
1 g
F P
s
P
p
.002 w
.62548 .33676 m .61488 .31248 L .59456 .31685 L p
1 g
F P
s
P
p
.002 w
.58194 .30276 m .59456 .31685 L .61488 .31248 L p
1 g
F P
s
P
p
.002 w
.34175 .34281 m .34177 .39247 L .36106 .37815 L p
1 g
F P
s
P
p
.002 w
.36106 .37815 m .36147 .33162 L .34175 .34281 L p
1 g
F P
s
P
p
.002 w
.64225 .52518 m .59585 .54608 L .59128 .56824 L p
1 g
F P
s
P
p
.002 w
.59585 .54608 m .64225 .52518 L .64116 .50166 L p
1 g
F P
s
P
p
.002 w
.57143 .27619 m .54364 .26858 L .54674 .28742 L p
1 g
F P
s
P
p
.002 w
.54674 .28742 m .56536 .29255 L .57143 .27619 L p
1 g
F P
s
P
p
.002 w
.4518 .25876 m .42412 .28454 L .44875 .28784 L p
1 g
F P
s
P
p
.002 w
.44875 .28784 m .47186 .2667 L .4518 .25876 L p
1 g
F P
s
P
p
.002 w
.61488 .31248 m .59616 .29143 L .58194 .30276 L p
1 g
F P
s
P
p
.002 w
.56536 .29255 m .58194 .30276 L .59616 .29143 L p
1 g
F P
s
P
p
.002 w
.50318 .2546 m .47186 .2667 L .49205 .27857 L p
1 g
F P
s
P
p
.002 w
.49205 .27857 m .51611 .26946 L .50318 .2546 L p
1 g
F P
s
P
p
.002 w
.59616 .29143 m .57143 .27619 L .56536 .29255 L p
1 g
F P
s
P
p
.002 w
.36122 .5379 m .40772 .57396 L .41542 .55838 L p
1 g
F P
s
P
p
.002 w
.41542 .55838 m .36852 .52187 L .36122 .5379 L p
1 g
F P
s
P
p
.002 w
.47015 .58277 m .41542 .55838 L .40772 .57396 L p
1 g
F P
s
P
p
.002 w
.66616 .39036 m .65348 .4249 L .66538 .44669 L p
1 g
F P
s
P
p
.002 w
.65348 .4249 m .66616 .39036 L .64819 .37499 L p
1 g
F P
s
P
p
.002 w
.40772 .57396 m .46191 .59814 L .47015 .58277 L p
1 g
F P
s
P
p
.002 w
.52807 .59291 m .47015 .58277 L .46191 .59814 L p
1 g
F P
s
P
p
.002 w
.64819 .37499 m .64658 .34288 L .62548 .33676 L p
1 g
F P
s
P
p
.002 w
.61488 .31248 m .62548 .33676 L .64658 .34288 L p
1 g
F P
s
P
p
.002 w
.3794 .28926 m .36147 .33162 L .38418 .32326 L p
1 g
F P
s
P
p
.002 w
.38418 .32326 m .4008 .28496 L .3794 .28926 L p
1 g
F P
s
P
p
.002 w
.31444 .42502 m .33363 .47616 L .34471 .45885 L p
1 g
F P
s
P
p
.002 w
.34471 .45885 m .32605 .4082 L .31444 .42502 L p
1 g
F P
s
P
p
.002 w
.67328 .46866 m .64116 .50166 L .64225 .52518 L p
1 g
F P
s
P
p
.002 w
.64116 .50166 m .67328 .46866 L .66538 .44669 L p
1 g
F P
s
P
p
.002 w
.64658 .34288 m .64819 .37499 L .66616 .39036 L p
1 g
F P
s
P
p
.002 w
.32658 .49287 m .36122 .5379 L .36852 .52187 L p
1 g
F P
s
P
p
.002 w
.36852 .52187 m .33363 .47616 L .32658 .49287 L p
1 g
F P
s
P
p
.002 w
.53928 .25332 m .50318 .2546 L .51611 .26946 L p
1 g
F P
s
P
p
.002 w
.51611 .26946 m .54364 .26858 L .53928 .25332 L p
1 g
F P
s
P
p
.002 w
.32565 .35671 m .32605 .4082 L .34177 .39247 L p
1 g
F P
s
P
p
.002 w
.34177 .39247 m .34175 .34281 L .32565 .35671 L p
1 g
F P
s
P
p
.002 w
.43236 .25513 m .4008 .28496 L .42412 .28454 L p
1 g
F P
s
P
p
.002 w
.42412 .28454 m .4518 .25876 L .43236 .25513 L p
1 g
F P
s
P
p
.002 w
.64658 .34288 m .63288 .31105 L .61488 .31248 L p
1 g
F P
s
P
p
.002 w
.59616 .29143 m .61488 .31248 L .63288 .31105 L p
1 g
F P
s
P
p
.002 w
.46191 .59814 m .51919 .60833 L .52807 .59291 L p
1 g
F P
s
P
p
.002 w
.58418 .58749 m .52807 .59291 L .51919 .60833 L p
1 g
F P
s
P
p
.002 w
.52807 .59291 m .58418 .58749 L .59128 .56824 L p
1 g
F P
s
P
p
.002 w
.63963 .54691 m .59128 .56824 L .58418 .58749 L p
1 g
F P
s
P
p
.002 w
.59128 .56824 m .63963 .54691 L .64225 .52518 L p
1 g
F P
s
P
p
.002 w
.68028 .40725 m .66538 .44669 L .67328 .46866 L p
1 g
F P
s
P
p
.002 w
.66538 .44669 m .68028 .40725 L .66616 .39036 L p
1 g
F P
s
P
p
.002 w
.48971 .24388 m .4518 .25876 L .47186 .2667 L p
1 g
F P
s
P
p
.002 w
.47186 .2667 m .50318 .2546 L .48971 .24388 L p
1 g
F P
s
P
p
.002 w
.57584 .26327 m .53928 .25332 L .54364 .26858 L p
1 g
F P
s
P
p
.002 w
.54364 .26858 m .57143 .27619 L .57584 .26327 L p
1 g
F P
s
P
p
.002 w
.63288 .31105 m .60836 .28335 L .59616 .29143 L p
1 g
F P
s
P
p
.002 w
.57143 .27619 m .59616 .29143 L .60836 .28335 L p
1 g
F P
s
P
p
.002 w
.60836 .28335 m .57584 .26327 L .57143 .27619 L p
1 g
F P
s
P
p
.002 w
.36055 .29751 m .34175 .34281 L .36147 .33162 L p
1 g
F P
s
P
p
.002 w
.36147 .33162 m .3794 .28926 L .36055 .29751 L p
1 g
F P
s
P
p
.002 w
.35734 .55168 m .40217 .58634 L .40772 .57396 L p
1 g
F P
s
P
p
.002 w
.40772 .57396 m .36122 .5379 L .35734 .55168 L p
1 g
F P
s
P
p
.002 w
.46191 .59814 m .40772 .57396 L .40217 .58634 L p
1 g
F P
s
P
p
.002 w
.66616 .39036 m .6645 .3515 L .64658 .34288 L p
1 g
F P
s
P
p
.002 w
.63288 .31105 m .64658 .34288 L .6645 .3515 L p
1 g
F P
s
P
p
.002 w
.67682 .49028 m .64225 .52518 L .63963 .54691 L p
1 g
F P
s
P
p
.002 w
.64225 .52518 m .67682 .49028 L .67328 .46866 L p
1 g
F P
s
P
p
.002 w
.6645 .3515 m .66616 .39036 L .68028 .40725 L p
1 g
F P
s
P
p
.002 w
.40217 .58634 m .45436 .60966 L .46191 .59814 L p
1 g
F P
s
P
p
.002 w
.51919 .60833 m .46191 .59814 L .45436 .60966 L p
1 g
F P
s
P
p
.002 w
.30743 .44258 m .32658 .49287 L .33363 .47616 L p
1 g
F P
s
P
p
.002 w
.33363 .47616 m .31444 .42502 L .30743 .44258 L p
1 g
F P
s
P
p
.002 w
.31374 .37307 m .31444 .42502 L .32605 .4082 L p
1 g
F P
s
P
p
.002 w
.32605 .4082 m .32565 .35671 L .31374 .37307 L p
1 g
F P
s
P
p
.002 w
.32393 .50851 m .35734 .55168 L .36122 .5379 L p
1 g
F P
s
P
p
.002 w
.36122 .5379 m .32658 .49287 L .32393 .50851 L p
1 g
F P
s
P
p
.002 w
.53369 .2422 m .48971 .24388 L .50318 .2546 L p
1 g
F P
s
P
p
.002 w
.50318 .2546 m .53928 .25332 L .53369 .2422 L p
1 g
F P
s
P
p
.002 w
.41406 .25613 m .3794 .28926 L .4008 .28496 L p
1 g
F P
s
P
p
.002 w
.4008 .28496 m .43236 .25513 L .41406 .25613 L p
1 g
F P
s
P
p
.002 w
.69004 .42531 m .67328 .46866 L .67682 .49028 L p
1 g
F P
s
P
p
.002 w
.67328 .46866 m .69004 .42531 L .68028 .40725 L p
1 g
F P
s
P
p
.002 w
.51919 .60833 m .57459 .60322 L .58418 .58749 L p
1 g
F P
s
P
p
.002 w
.63318 .56624 m .58418 .58749 L .57459 .60322 L p
1 g
F P
s
P
p
.002 w
.58418 .58749 m .63318 .56624 L .63963 .54691 L p
1 g
F P
s
P
p
.002 w
.47601 .23781 m .43236 .25513 L .4518 .25876 L p
1 g
F P
s
P
p
.002 w
.4518 .25876 m .48971 .24388 L .47601 .23781 L p
1 g
F P
s
P
p
.002 w
.6645 .3515 m .64801 .31275 L .63288 .31105 L p
1 g
F P
s
P
p
.002 w
.60836 .28335 m .63288 .31105 L .64801 .31275 L p
1 g
F P
s
P
p
.002 w
.45436 .60966 m .50945 .61958 L .51919 .60833 L p
1 g
F P
s
P
p
.002 w
.57459 .60322 m .51919 .60833 L .50945 .61958 L p
1 g
F P
s
P
p
.002 w
.34488 .30969 m .32565 .35671 L .34175 .34281 L p
1 g
F P
s
P
p
.002 w
.34175 .34281 m .36055 .29751 L .34488 .30969 L p
1 g
F P
s
P
p
.002 w
.57838 .25433 m .53369 .2422 L .53928 .25332 L p
1 g
F P
s
P
p
.002 w
.53928 .25332 m .57584 .26327 L .57838 .25433 L p
1 g
F P
s
P
p
.002 w
.67864 .36256 m .68028 .40725 L .69004 .42531 L p
1 g
F P
s
P
p
.002 w
.68028 .40725 m .67864 .36256 L .6645 .3515 L p
1 g
F P
s
P
p
.002 w
.6757 .51099 m .63963 .54691 L .63318 .56624 L p
1 g
F P
s
P
p
.002 w
.63963 .54691 m .6757 .51099 L .67682 .49028 L p
1 g
F P
s
P
p
.002 w
.64801 .31275 m .6645 .3515 L .67864 .36256 L p
1 g
F P
s
P
p
.002 w
.64801 .31275 m .61815 .2789 L .60836 .28335 L p
1 g
F P
s
P
p
.002 w
.57584 .26327 m .60836 .28335 L .61815 .2789 L p
1 g
F P
s
P
p
.002 w
.61815 .2789 m .57838 .25433 L .57584 .26327 L p
1 g
F P
s
P
p
.002 w
.35717 .56274 m .39902 .59503 L .40217 .58634 L p
1 g
F P
s
P
p
.002 w
.40217 .58634 m .35734 .55168 L .35717 .56274 L p
1 g
F P
s
P
p
.002 w
.45436 .60966 m .40217 .58634 L .39902 .59503 L p
1 g
F P
s
P
p
.002 w
.30546 .46044 m .32393 .50851 L .32658 .49287 L p
1 g
F P
s
P
p
.002 w
.32658 .49287 m .30743 .44258 L .30546 .46044 L p
1 g
F P
s
P
p
.002 w
.39902 .59503 m .44773 .61681 L .45436 .60966 L p
1 g
F P
s
P
p
.002 w
.50945 .61958 m .45436 .60966 L .44773 .61681 L p
1 g
F P
s
P
p
.002 w
.30656 .3916 m .30743 .44258 L .31444 .42502 L p
1 g
F P
s
P
p
.002 w
.31444 .42502 m .31374 .37307 L .30656 .3916 L p
1 g
F P
s
P
p
.002 w
.39746 .26199 m .36055 .29751 L .3794 .28926 L p
1 g
F P
s
P
p
.002 w
.3794 .28926 m .41406 .25613 L .39746 .26199 L p
1 g
F P
s
P
p
.002 w
.69496 .44413 m .67682 .49028 L .6757 .51099 L p
1 g
F P
s
P
p
.002 w
.67682 .49028 m .69496 .44413 L .69004 .42531 L p
1 g
F P
s
P
p
.002 w
.52694 .23579 m .47601 .23781 L .48971 .24388 L p
1 g
F P
s
P
p
.002 w
.48971 .24388 m .53369 .2422 L .52694 .23579 L p
1 g
F P
s
P
p
.002 w
.32602 .52263 m .35717 .56274 L .35734 .55168 L p
1 g
F P
s
P
p
.002 w
.35734 .55168 m .32393 .50851 L .32602 .52263 L p
1 g
F P
s
P
p
.002 w
.46242 .23683 m .41406 .25613 L .43236 .25513 L p
1 g
F P
s
P
p
.002 w
.43236 .25513 m .47601 .23781 L .46242 .23683 L p
1 g
F P
s
P
p
.002 w
.50945 .61958 m .56262 .61484 L .57459 .60322 L p
1 g
F P
s
P
p
.002 w
.62288 .58253 m .57459 .60322 L .56262 .61484 L p
1 g
F P
s
P
p
.002 w
.57459 .60322 m .62288 .58253 L .63318 .56624 L p
1 g
F P
s
P
p
.002 w
.67864 .36256 m .65971 .31773 L .64801 .31275 L p
1 g
F P
s
P
p
.002 w
.61815 .2789 m .64801 .31275 L .65971 .31773 L p
1 g
F P
s
P
p
.002 w
.44773 .61681 m .49907 .62613 L .50945 .61958 L p
1 g
F P
s
P
p
.002 w
.56262 .61484 m .50945 .61958 L .49907 .62613 L p
1 g
F P
s
P
p
.002 w
.33298 .32567 m .31374 .37307 L .32565 .35671 L p
1 g
F P
s
P
p
.002 w
.32565 .35671 m .34488 .30969 L .33298 .32567 L p
1 g
F P
s
P
p
.002 w
.68842 .37588 m .69004 .42531 L .69496 .44413 L p
1 g
F P
s
P
p
.002 w
.69004 .42531 m .68842 .37588 L .67864 .36256 L p
1 g
F P
s
P
p
.002 w
.6697 .5302 m .63318 .56624 L .62288 .58253 L p
1 g
F P
s
P
p
.002 w
.63318 .56624 m .6697 .5302 L .6757 .51099 L p
1 g
F P
s
P
p
.002 w
.65971 .31773 m .67864 .36256 L .68842 .37588 L p
1 g
F P
s
P
p
.002 w
.57888 .24986 m .52694 .23579 L .53369 .2422 L p
1 g
F P
s
P
p
.002 w
.53369 .2422 m .57838 .25433 L .57888 .24986 L p
1 g
F P
s
P
p
.002 w
.65971 .31773 m .62511 .27843 L .61815 .2789 L p
1 g
F P
s
P
p
.002 w
.57838 .25433 m .61815 .2789 L .62511 .27843 L p
1 g
F P
s
P
p
.002 w
.30886 .47813 m .32602 .52263 L .32393 .50851 L p
1 g
F P
s
P
p
.002 w
.32393 .50851 m .30546 .46044 L .30886 .47813 L p
1 g
F P
s
P
p
.002 w
.38312 .27281 m .34488 .30969 L .36055 .29751 L p
1 g
F P
s
P
p
.002 w
.36055 .29751 m .39746 .26199 L .38312 .27281 L p
1 g
F P
s
P
p
.002 w
.62511 .27843 m .57888 .24986 L .57838 .25433 L p
1 g
F P
s
P
p
.002 w
.30458 .41187 m .30546 .46044 L .30743 .44258 L p
1 g
F P
s
P
p
.002 w
.30743 .44258 m .30656 .3916 L .30458 .41187 L p
1 g
F P
s
P
p
.002 w
.36095 .5706 m .39852 .59957 L .39902 .59503 L p
1 g
F P
s
P
p
.002 w
.39902 .59503 m .35717 .56274 L .36095 .5706 L p
1 g
F P
s
P
p
.002 w
.44773 .61681 m .39902 .59503 L .39852 .59957 L p
1 g
F P
s
P
p
.002 w
.69465 .46325 m .6757 .51099 L .6697 .5302 L p
1 g
F P
s
P
p
.002 w
.6757 .51099 m .69465 .46325 L .69496 .44413 L p
1 g
F P
s
P
p
.002 w
.39852 .59957 m .44226 .61913 L .44773 .61681 L p
1 g
F P
s
P
p
.002 w
.49907 .62613 m .44773 .61681 L .44226 .61913 L p
1 g
F P
s
P
p
.002 w
.51915 .23455 m .46242 .23683 L .47601 .23781 L p
1 g
F P
s
P
p
.002 w
.47601 .23781 m .52694 .23579 L .51915 .23455 L p
1 g
F P
s
P
p
.002 w
.44933 .24126 m .39746 .26199 L .41406 .25613 L p
1 g
F P
s
P
p
.002 w
.41406 .25613 m .46242 .23683 L .44933 .24126 L p
1 g
F P
s
P
p
.002 w
.33308 .53474 m .36095 .5706 L .35717 .56274 L p
1 g
F P
s
P
p
.002 w
.35717 .56274 m .32602 .52263 L .33308 .53474 L p
1 g
F P
s
P
p
.002 w
.49907 .62613 m .54846 .62181 L .56262 .61484 L p
1 g
F P
s
P
p
.002 w
.6088 .5952 m .56262 .61484 L .54846 .62181 L p
1 g
F P
s
P
p
.002 w
.56262 .61484 m .6088 .5952 L .62288 .58253 L p
1 g
F P
s
P
p
.002 w
.32541 .34519 m .30656 .3916 L .31374 .37307 L p
1 g
F P
s
P
p
.002 w
.31374 .37307 m .33298 .32567 L .32541 .34519 L p
1 g
F P
s
P
p
.002 w
.69496 .44413 m .69333 .39124 L .68842 .37588 L p
1 g
F P
s
P
p
.002 w
.69333 .39124 m .69496 .44413 L .69465 .46325 L p
1 g
F P
s
P
p
.002 w
.62288 .58253 m .65876 .5473 L .6697 .5302 L p
1 g
F P
s
P
p
.002 w
.65876 .5473 m .62288 .58253 L .6088 .5952 L p
1 g
F P
s
P
p
.002 w
.68842 .37588 m .66745 .32606 L .65971 .31773 L p
1 g
F P
s
P
p
.002 w
.62511 .27843 m .65971 .31773 L .66745 .32606 L p
1 g
F P
s
P
p
.002 w
.44226 .61913 m .48828 .6275 L .49907 .62613 L p
1 g
F P
s
P
p
.002 w
.54846 .62181 m .49907 .62613 L .48828 .6275 L p
1 g
F P
s
P
p
.004 w
.29583 .47016 m
.30384 .4686 L
s
P
p
.004 w
.20745 .48732 m
.29583 .47016 L
s
P
p
.002 w
.66745 .32606 m .68842 .37588 L .69333 .39124 L p
1 g
F P
s
P
p
.002 w
.57718 .25027 m .51915 .23455 L .52694 .23579 L p
1 g
F P
s
P
p
.002 w
.52694 .23579 m .57888 .24986 L .57718 .25027 L p
1 g
F P
s
P
p
.002 w
.37161 .28855 m .33298 .32567 L .34488 .30969 L p
1 g
F P
s
P
p
.002 w
.34488 .30969 m .38312 .27281 L .37161 .28855 L p
1 g
F P
s
P
p
.002 w
.6697 .5302 m .68883 .48214 L .69465 .46325 L p
1 g
F P
s
P
p
.002 w
.68883 .48214 m .6697 .5302 L .65876 .5473 L p
1 g
F P
s
P
p
.002 w
.30812 .43337 m .30886 .47813 L .30546 .46044 L p
1 g
F P
s
P
p
.002 w
.30546 .46044 m .30458 .41187 L .30812 .43337 L p
1 g
F P
s
P
p
.002 w
.31784 .49512 m .33308 .53474 L .32602 .52263 L p
1 g
F P
s
P
p
.002 w
.32602 .52263 m .30886 .47813 L .31784 .49512 L p
1 g
F P
s
P
p
.002 w
.66745 .32606 m .62886 .28221 L .62511 .27843 L p
1 g
F P
s
P
p
.002 w
.57888 .24986 m .62511 .27843 L .62886 .28221 L p
1 g
F P
s
P
p
.002 w
.62886 .28221 m .57718 .25027 L .57888 .24986 L p
1 g
F P
s
P
p
.002 w
.36884 .57484 m .40086 .59953 L .39852 .59957 L p
1 g
F P
s
P
p
.002 w
.39852 .59957 m .36095 .5706 L .36884 .57484 L p
1 g
F P
s
P
p
.002 w
.44226 .61913 m .39852 .59957 L .40086 .59953 L p
1 g
F P
s
P
p
.002 w
.40086 .59953 m .43818 .61622 L .44226 .61913 L p
1 g
F P
s
P
p
.002 w
.48828 .6275 m .44226 .61913 L .43818 .61622 L p
1 g
F P
s
P
p
.002 w
.43718 .25132 m .38312 .27281 L .39746 .26199 L p
1 g
F P
s
P
p
.002 w
.39746 .26199 m .44933 .24126 L .43718 .25132 L p
1 g
F P
s
P
p
.002 w
.51047 .23887 m .44933 .24126 L .46242 .23683 L p
1 g
F P
s
P
p
.002 w
.46242 .23683 m .51915 .23455 L .51047 .23887 L p
1 g
F P
s
P
p
.002 w
.32263 .36783 m .30458 .41187 L .30656 .3916 L p
1 g
F P
s
P
p
.002 w
.30656 .3916 m .32541 .34519 L .32263 .36783 L p
1 g
F P
s
P
p
.002 w
.48828 .6275 m .53238 .62366 L .54846 .62181 L p
1 g
F P
s
P
p
.002 w
.54846 .62181 m .59115 .60368 L .6088 .5952 L p
1 g
F P
s
P
p
.002 w
.59115 .60368 m .54846 .62181 L .53238 .62366 L p
1 g
F P
s
P
p
.002 w
.34519 .54435 m .36884 .57484 L .36095 .5706 L p
1 g
F P
s
P
p
.002 w
.36095 .5706 m .33308 .53474 L .34519 .54435 L p
1 g
F P
s
P
p
.002 w
.69293 .40832 m .69465 .46325 L .68883 .48214 L p
1 g
F P
s
P
p
.002 w
.69465 .46325 m .69293 .40832 L .69333 .39124 L p
1 g
F P
s
P
p
.002 w
.64292 .56167 m .6088 .5952 L .59115 .60368 L p
1 g
F P
s
P
p
.002 w
.6088 .5952 m .64292 .56167 L .65876 .5473 L p
1 g
F P
s
P
p
.002 w
.69333 .39124 m .67076 .3377 L .66745 .32606 L p
1 g
F P
s
P
p
.002 w
.62886 .28221 m .66745 .32606 L .67076 .3377 L p
1 g
F P
s
P
p
.002 w
.43818 .61622 m .47737 .62334 L .48828 .6275 L p
1 g
F P
s
P
p
.002 w
.53238 .62366 m .48828 .6275 L .47737 .62334 L p
1 g
F P
s
P
p
.002 w
.67076 .3377 m .69333 .39124 L .69293 .40832 L p
1 g
F P
s
P
p
.002 w
.36342 .30897 m .32541 .34519 L .33298 .32567 L p
1 g
F P
s
P
p
.002 w
.33298 .32567 m .37161 .28855 L .36342 .30897 L p
1 g
F P
s
P
p
.002 w
.67739 .5002 m .65876 .5473 L .64292 .56167 L p
1 g
F P
s
P
p
.002 w
.65876 .5473 m .67739 .5002 L .68883 .48214 L p
1 g
F P
s
P
p
.002 w
.31735 .4555 m .31784 .49512 L .30886 .47813 L p
1 g
F P
s
P
p
.002 w
.30886 .47813 m .30812 .43337 L .31735 .4555 L p
1 g
F P
s
P
p
.004 w
.30384 .4686 m
.30954 .4675 L
s
P
p
.004 w
.30954 .4675 m
.31096 .46722 L
s
P
p
.002 w
.57317 .2559 m .51047 .23887 L .51915 .23455 L p
1 g
F P
s
P
p
.002 w
.51915 .23455 m .57718 .25027 L .57317 .2559 L p
1 g
F P
s
P
p
.002 w
.33241 .51084 m .34519 .54435 L .33308 .53474 L p
1 g
F P
s
P
p
.002 w
.33308 .53474 m .31784 .49512 L .33241 .51084 L p
1 g
F P
s
P
p
.002 w
.67076 .3377 m .62907 .29042 L .62886 .28221 L p
1 g
F P
s
P
p
.002 w
.57718 .25027 m .62886 .28221 L .62907 .29042 L p
1 g
F P
s
P
p
.002 w
.32495 .39303 m .30812 .43337 L .30458 .41187 L p
1 g
F P
s
P
p
.004 w
.31748 .46595 m
.5 .43051 L
s
P
p
.002 w
.30458 .41187 m .32263 .36783 L .32495 .39303 L p
1 g
F P
s
P
p
.002 w
.42641 .26701 m .37161 .28855 L .38312 .27281 L p
1 g
F P
s
P
p
.002 w
.38312 .27281 m .43718 .25132 L .42641 .26701 L p
1 g
F P
s
P
p
.002 w
.62907 .29042 m .57317 .2559 L .57718 .25027 L p
1 g
F P
s
P
p
.002 w
.38085 .57508 m .40616 .59463 L .40086 .59953 L p
1 g
F P
s
P
p
.002 w
.40086 .59953 m .36884 .57484 L .38085 .57508 L p
1 g
F P
s
P
p
.002 w
.43818 .61622 m .40086 .59953 L .40616 .59463 L p
1 g
F P
s
P
p
.002 w
.50112 .24896 m .43718 .25132 L .44933 .24126 L p
1 g
F P
s
P
p
.002 w
.44933 .24126 m .51047 .23887 L .50112 .24896 L p
1 g
F P
s
P
p
.002 w
.47737 .62334 m .51475 .62002 L .53238 .62366 L p
1 g
F P
s
P
p
.002 w
.57025 .60748 m .53238 .62366 L .51475 .62002 L p
1 g
F P
s
P
p
.002 w
.53238 .62366 m .57025 .60748 L .59115 .60368 L p
1 g
F P
s
P
p
.002 w
.68694 .42667 m .68883 .48214 L .67739 .5002 L p
1 g
F P
s
P
p
.002 w
.68883 .48214 m .68694 .42667 L .69293 .40832 L p
1 g
F P
s
P
p
.002 w
.40616 .59463 m .4357 .60783 L .43818 .61622 L p
1 g
F P
s
P
p
.002 w
.47737 .62334 m .43818 .61622 L .4357 .60783 L p
1 g
F P
s
P
p
.002 w
.62243 .57272 m .59115 .60368 L .57025 .60748 L p
1 g
F P
s
P
p
.002 w
.59115 .60368 m .62243 .57272 L .64292 .56167 L p
1 g
F P
s
P
p
.002 w
.36227 .55101 m .38085 .57508 L .36884 .57484 L p
1 g
F P
s
P
p
.002 w
.36884 .57484 m .34519 .54435 L .36227 .55101 L p
1 g
F P
s
P
p
.002 w
.69293 .40832 m .66926 .35251 L .67076 .3377 L p
1 g
F P
s
P
p
.002 w
.62907 .29042 m .67076 .3377 L .66926 .35251 L p
1 g
F P
s
P
p
.002 w
.35901 .33366 m .32263 .36783 L .32541 .34519 L p
1 g
F P
s
P
p
.002 w
.32541 .34519 m .36342 .30897 L .35901 .33366 L p
1 g
F P
s
P
p
.002 w
.66926 .35251 m .69293 .40832 L .68694 .42667 L p
1 g
F P
s
P
p
.002 w
.4357 .60783 m .46666 .61341 L .47737 .62334 L p
1 g
F P
s
P
p
.002 w
.51475 .62002 m .47737 .62334 L .46666 .61341 L p
1 g
F P
s
P
p
.002 w
.66039 .51684 m .64292 .56167 L .62243 .57272 L p
1 g
F P
s
P
p
.002 w
.64292 .56167 m .66039 .51684 L .67739 .5002 L p
1 g
F P
s
P
p
.002 w
.33225 .47756 m .33241 .51084 L .31784 .49512 L p
1 g
F P
s
P
p
.002 w
.31784 .49512 m .31735 .4555 L .33225 .47756 L p
1 g
F P
s
P
p
.002 w
.3524 .52471 m .36227 .55101 L .34519 .54435 L p
1 g
F P
s
P
p
.002 w
.34519 .54435 m .33241 .51084 L .3524 .52471 L p
1 g
F P
s
P
p
.002 w
.56685 .2669 m .50112 .24896 L .51047 .23887 L p
1 g
F P
s
P
p
.002 w
.51047 .23887 m .57317 .2559 L .56685 .2669 L p
1 g
F P
s
P
p
.002 w
.33253 .42005 m .31735 .4555 L .30812 .43337 L p
1 g
F P
s
P
p
.002 w
.30812 .43337 m .32495 .39303 L .33253 .42005 L p
1 g
F P
s
P
p
.002 w
.41744 .28812 m .36342 .30897 L .37161 .28855 L p
1 g
F P
s
P
p
.002 w
.37161 .28855 m .42641 .26701 L .41744 .28812 L p
1 g
F P
s
P
p
.002 w
.67523 .44579 m .67739 .5002 L .66039 .51684 L p
1 g
F P
s
P
p
.002 w
.67739 .5002 m .67523 .44579 L .68694 .42667 L p
1 g
F P
s
P
p
.002 w
.66926 .35251 m .6255 .30308 L .62907 .29042 L p
1 g
F P
s
P
p
.002 w
.57317 .2559 m .62907 .29042 L .6255 .30308 L p
1 g
F P
s
P
p
.002 w
.51475 .62002 m .5466 .60624 L .57025 .60748 L p
1 g
F P
s
P
p
.002 w
.59771 .57996 m .57025 .60748 L .5466 .60624 L p
1 g
F P
s
P
p
.002 w
.57025 .60748 m .59771 .57996 L .62243 .57272 L p
1 g
F P
s
P
p
.002 w
.46666 .61341 m .49604 .61071 L .51475 .62002 L p
1 g
F P
s
P
p
.002 w
.5466 .60624 m .51475 .62002 L .49604 .61071 L p
1 g
F P
s
P
p
.002 w
.49138 .26485 m .42641 .26701 L .43718 .25132 L p
1 g
F P
s
P
p
.002 w
.43718 .25132 m .50112 .24896 L .49138 .26485 L p
1 g
F P
s
P
p
.002 w
.6255 .30308 m .56685 .2669 L .57317 .2559 L p
1 g
F P
s
P
p
.002 w
.39686 .57107 m .41445 .58469 L .40616 .59463 L p
1 g
F P
s
P
p
.002 w
.40616 .59463 m .38085 .57508 L .39686 .57107 L p
1 g
F P
s
P
p
.002 w
.4357 .60783 m .40616 .59463 L .41445 .58469 L p
1 g
F P
s
P
p
.002 w
.41445 .58469 m .43501 .59388 L .4357 .60783 L p
1 g
F P
s
P
p
.004 w
.4036 .62081 m
.41448 .59934 L
s
P
p
.002 w
.46666 .61341 m .4357 .60783 L .43501 .59388 L p
1 g
F P
s
P
p
.002 w
.35871 .36196 m .32495 .39303 L .32263 .36783 L p
1 g
F P
s
P
p
.002 w
.32263 .36783 m .35901 .33366 L .35871 .36196 L p
1 g
F P
s
P
p
.002 w
.63814 .53142 m .62243 .57272 L .59771 .57996 L p
1 g
F P
s
P
p
.002 w
.62243 .57272 m .63814 .53142 L .66039 .51684 L p
1 g
F P
s
P
p
.002 w
.38406 .55435 m .39686 .57107 L .38085 .57508 L p
1 g
F P
s
P
p
.002 w
.38085 .57508 m .36227 .55101 L .38406 .55435 L p
1 g
F P
s
P
p
.002 w
.66271 .37019 m .68694 .42667 L .67523 .44579 L p
1 g
F P
s
P
p
.002 w
.68694 .42667 m .66271 .37019 L .66926 .35251 L p
1 g
F P
s
P
p
.002 w
.6255 .30308 m .66926 .35251 L .66271 .37019 L p
1 g
F P
s
P
p
.002 w
.43501 .59388 m .45652 .5977 L .46666 .61341 L p
1 g
F P
s
P
p
.002 w
.49604 .61071 m .46666 .61341 L .45652 .5977 L p
1 g
F P
s
P
p
.002 w
.35254 .49879 m .3524 .52471 L .33241 .51084 L p
1 g
F P
s
P
p
.002 w
.33241 .51084 m .33225 .47756 L .35254 .49879 L p
1 g
F P
s
P
p
.002 w
.34533 .44804 m .33225 .47756 L .31735 .4555 L p
1 g
F P
s
P
p
.002 w
.31735 .4555 m .33253 .42005 L .34533 .44804 L p
1 g
F P
s
P
p
.002 w
.3774 .53619 m .38406 .55435 L .36227 .55101 L p
1 g
F P
s
P
p
.002 w
.36227 .55101 m .3524 .52471 L .3774 .53619 L p
1 g
F P
s
P
p
.002 w
.41068 .3142 m .35901 .33366 L .36342 .30897 L p
1 g
F P
s
P
p
.002 w
.36342 .30897 m .41744 .28812 L .41068 .3142 L p
1 g
F P
s
P
p
.002 w
.65793 .46506 m .66039 .51684 L .63814 .53142 L p
1 g
F P
s
P
p
.002 w
.66039 .51684 m .65793 .46506 L .67523 .44579 L p
1 g
F P
s
P
p
.002 w
.49604 .61071 m .52085 .59977 L .5466 .60624 L p
1 g
F P
s
P
p
.002 w
.5694 .58295 m .5466 .60624 L .52085 .59977 L p
1 g
F P
s
P
p
.002 w
.5466 .60624 m .5694 .58295 L .59771 .57996 L p
1 g
F P
s
P
p
.002 w
.55828 .28323 m .49138 .26485 L .50112 .24896 L p
1 g
F P
s
P
p
.002 w
.50112 .24896 m .56685 .2669 L .55828 .28323 L p
1 g
F P
s
P
p
.002 w
.45652 .5977 m .47682 .59573 L .49604 .61071 L p
1 g
F P
s
P
p
.002 w
.52085 .59977 m .49604 .61071 L .47682 .59573 L p
1 g
F P
s
P
p
.002 w
.48154 .28631 m .41744 .28812 L .42641 .26701 L p
1 g
F P
s
P
p
.002 w
.42641 .26701 m .49138 .26485 L .48154 .28631 L p
1 g
F P
s
P
p
.002 w
.36267 .39301 m .33253 .42005 L .32495 .39303 L p
1 g
F P
s
P
p
.002 w
.32495 .39303 m .35871 .36196 L .36267 .39301 L p
1 g
F P
s
P
p
.002 w
.66271 .37019 m .61805 .32004 L .6255 .30308 L p
1 g
F P
s
P
p
.002 w
.56685 .2669 m .6255 .30308 L .61805 .32004 L p
1 g
F P
s
P
p
.002 w
.61116 .54337 m .59771 .57996 L .5694 .58295 L p
1 g
F P
s
P
p
.002 w
.59771 .57996 m .61116 .54337 L .63814 .53142 L p
1 g
F P
s
P
p
.002 w
.61805 .32004 m .55828 .28323 L .56685 .2669 L p
1 g
F P
s
P
p
.002 w
.41657 .5627 m .42562 .56974 L .41445 .58469 L p
1 g
F P
s
P
p
.002 w
.41445 .58469 m .39686 .57107 L .41657 .5627 L p
1 g
F P
s
P
p
.002 w
.43501 .59388 m .41445 .58469 L .42562 .56974 L p
1 g
F P
s
P
p
.002 w
.65105 .39031 m .67523 .44579 L .65793 .46506 L p
1 g
F P
s
P
p
.002 w
.67523 .44579 m .65105 .39031 L .66271 .37019 L p
1 g
F P
s
P
p
.002 w
.42562 .56974 m .43624 .57448 L .43501 .59388 L p
1 g
F P
s
P
p
.002 w
.45652 .5977 m .43501 .59388 L .43624 .57448 L p
1 g
F P
s
P
p
.002 w
.37771 .51844 m .3774 .53619 L .3524 .52471 L p
1 g
F P
s
P
p
.002 w
.3524 .52471 m .35254 .49879 L .37771 .51844 L p
1 g
F P
s
P
p
.002 w
.41003 .55407 m .41657 .5627 L .39686 .57107 L p
1 g
F P
s
P
p
.002 w
.39686 .57107 m .38406 .55435 L .41003 .55407 L p
1 g
F P
s
P
p
.002 w
.36304 .47603 m .35254 .49879 L .33225 .47756 L p
1 g
F P
s
P
p
.002 w
.33225 .47756 m .34533 .44804 L .36304 .47603 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.61805 .32004 m .66271 .37019 L .65105 .39031 L p
1 g
F P
s
P
p
.002 w
.43624 .57448 m .44733 .57641 L .45652 .5977 L p
1 g
F P
s
P
p
.002 w
.47682 .59573 m .45652 .5977 L .44733 .57641 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.63537 .48382 m .63814 .53142 L .61116 .54337 L p
1 g
F P
s
P
p
.002 w
.63814 .53142 m .63537 .48382 L .65793 .46506 L p
1 g
F P
s
P
p
.002 w
.40648 .34451 m .35871 .36196 L .35901 .33366 L p
1 g
F P
s
P
p
.002 w
.35901 .33366 m .41068 .3142 L .40648 .34451 L p
1 g
F P
s
P
p
.002 w
.47682 .59573 m .49379 .58805 L .52085 .59977 L p
1 g
F P
s
P
p
.002 w
.53835 .58144 m .52085 .59977 L .49379 .58805 L p
1 g
F P
s
P
p
.002 w
.52085 .59977 m .53835 .58144 L .5694 .58295 L p
1 g
F P
s
P
p
.002 w
.40672 .54476 m .41003 .55407 L .38406 .55435 L p
1 g
F P
s
P
p
.002 w
.38406 .55435 m .3774 .53619 L .40672 .54476 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45282 .52365 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37089 .42577 m .34533 .44804 L .33253 .42005 L p
1 g
F P
s
P
p
.002 w
.33253 .42005 m .36267 .39301 L .37089 .42577 L p
1 g
F P
s
P
p
.002 w
.58023 .55217 m .5694 .58295 L .53835 .58144 L p
1 g
F P
s
P
p
.002 w
.5694 .58295 m .58023 .55217 L .61116 .54337 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44733 .57641 m .45773 .57533 L .47682 .59573 L p
1 g
F P
s
P
p
.002 w
.49379 .58805 m .47682 .59573 L .45773 .57533 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.54762 .30462 m .48154 .28631 L .49138 .26485 L p
1 g
F P
s
P
p
.002 w
.49138 .26485 m .55828 .28323 L .54762 .30462 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47198 .31284 m .41068 .3142 L .41744 .28812 L p
1 g
F P
s
P
p
.002 w
.41744 .28812 m .48154 .28631 L .47198 .31284 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.38516 .50302 m .37771 .51844 L .35254 .49879 L p
1 g
F P
s
P
p
.002 w
.35254 .49879 m .36304 .47603 L .38516 .50302 L p
1 g
F P
s
P
p
.002 w
.40701 .53574 m .40672 .54476 L .3774 .53619 L p
1 g
F P
s
P
p
.002 w
.3774 .53619 m .37771 .51844 L .40701 .53574 L p
1 g
F P
s
P
p
.002 w
.65105 .39031 m .60676 .34096 L .61805 .32004 L p
1 g
F P
s
P
p
.002 w
.55828 .28323 m .61805 .32004 L .60676 .34096 L p
1 g
F P
s
P
p
.002 w
.63444 .41227 m .65793 .46506 L .63537 .48382 L p
1 g
F P
s
P
p
.002 w
.65793 .46506 m .63444 .41227 L .65105 .39031 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.60817 .50137 m .61116 .54337 L .58023 .55217 L p
1 g
F P
s
P
p
.002 w
.61116 .54337 m .60817 .50137 L .63537 .48382 L p
1 g
F P
s
P
p
.002 w
.60676 .34096 m .54762 .30462 L .55828 .28323 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.42562 .56974 m .41657 .5627 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.43624 .57448 m .42562 .56974 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.45773 .57533 m .46244 .57313 L p
.48369 .58325 L 1 g
F P
s
P
p
.49379 .58805 m .49021 .58679 L .48369 .58325 L 1 g
F
P
p
.49021 .58679 m .45773 .57533 L .48369 .58325 L 1 g
F
P
p
.002 w
.46824 .57484 m .46872 .57265 L p
.45832 .56849 L 1 g
F P
s
P
p
.002 w
.45773 .57533 m .44689 .56032 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.46387 .57247 m .46007 .57424 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.46007 .57424 m .45773 .57533 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.44349 .55437 L 1 g
F P
s
P
p
.45832 .56849 m .46387 .57247 L .46824 .57484 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56314 L p
1 g
F P
s
P
p
.002 w
.44689 .56032 m .45773 .57533 L p
.44132 .55627 L 1 g
F P
s
P
p
.002 w
.45077 .56314 m .45009 .56498 L p
.45748 .56802 L 1 g
F P
s
P
p
.46872 .57265 m .45077 .56314 L .45748 .56802 L 1 g
F
P
p
.002 w
.45773 .57533 m .44733 .57641 L .44132 .55627 L p
1 g
F P
s
P
p
.002 w
.44132 .55627 m .43946 .55002 L .44689 .56032 L p
1 g
F P
s
P
p
.46872 .57265 m .45009 .56498 L .4517 .56585 L 1 g
F
P
p
.002 w
.47577 .57707 m .48098 .58024 L p
.46244 .57313 L 1 g
F P
s
P
p
.002 w
.48098 .58024 m .49379 .58805 L p
.47652 .57983 L 1 g
F P
s
P
p
.47652 .57983 m .46244 .57313 L .48098 .58024 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4682 .57502 L p
1 g
F P
s
P
p
.002 w
.49832 .58316 m .49379 .58805 L .48098 .58024 L p
1 g
F P
s
P
p
.002 w
.48098 .58024 m .47577 .57707 L p
.48906 .58066 L 1 g
F P
s
P
p
.49832 .58316 m .48098 .58024 L .48906 .58066 L 1 g
F
P
p
.51079 .57862 m .49825 .58113 L .50012 .58122 L 1 g
F
P
p
.002 w
.49379 .58805 m .49752 .58402 L p
.53835 .58144 L 1 g
F P
s
P
p
.002 w
.49752 .58402 m .50012 .58122 L p
.50824 .58127 L 1 g
F P
s
P
p
.53835 .58144 m .49752 .58402 L .50824 .58127 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58057 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58057 L .5205 .57812 L 1 g
F
P
p
.002 w
.5418 .57112 m .53835 .58144 L .52447 .57886 L p
1 g
F P
s
P
p
.002 w
.52447 .57886 m .5205 .57812 L p
.53167 .57444 L 1 g
F P
s
P
p
.5418 .57112 m .52447 .57886 L .53167 .57444 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53167 .57444 L p
1 g
F P
s
P
p
.54854 .56129 m .53167 .57444 L .54026 .56918 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54854 .56129 m .54026 .56918 L .543 .5675 L 1 g
F
P
p
.002 w
.55965 .55536 m .58023 .55217 L p
.5466 .56602 L 1 g
F P
s
P
p
.5466 .56602 m .543 .5675 L .54918 .563 L 1 g
F
P
p
.5466 .56602 m .54918 .563 L .55965 .55536 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .563 L p
1 g
F P
s
P
p
.002 w
.53835 .58144 m .543 .5675 L p
.58023 .55217 L 1 g
F P
s
P
p
.56075 .54566 m .54918 .563 L .55487 .55632 L 1 g
F
P
p
.002 w
.54918 .563 m .54854 .56129 L p
.543 .5675 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.56075 .54566 m .55487 .55632 L .55509 .55606 L 1 g
F
P
p
.002 w
.57774 .52303 m .58023 .55217 L .55863 .55551 L p
1 g
F P
s
P
p
.002 w
.55863 .55551 m .55509 .55606 L p
.56139 .54687 L 1 g
F P
s
P
p
.57774 .52303 m .55863 .55551 L .56139 .54687 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56139 .54687 L p
1 g
F P
s
P
p
.56654 .52734 m .56139 .54687 L .56508 .5353 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.57722 .51702 m .57774 .52303 L p
.5643 .53776 L 1 g
F P
s
P
p
.002 w
.56728 .52842 m .56654 .52734 L p
.56508 .5353 L 1 g
F P
s
P
p
.5664 .53119 m .5643 .53776 L .54637 .55741 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56728 .52842 L p
1 g
F P
s
P
p
.57722 .51702 m .56742 .53275 L .56733 .52997 L 1 g
F
P
p
.56515 .50826 m .56728 .52842 L .56704 .521 L 1 g
F
P
p
.002 w
.56395 .48951 m .57722 .51702 L .57085 .51951 L p
1 g
F P
s
P
p
.002 w
.57085 .51951 m .56704 .521 L p
.56588 .50912 L 1 g
F P
s
P
p
.56395 .48951 m .57085 .51951 L .56588 .50912 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56588 .50912 L p
1 g
F P
s
P
p
.55661 .4905 m .56588 .50912 L .56082 .49855 L 1 g
F
P
p
.56515 .50826 m .56704 .521 L .56691 .51969 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54637 .55741 m .5436 .53016 L .56704 .521 L p
1 g
F P
s
P
p
.002 w
.56704 .521 m .57722 .51702 L p
.56733 .52997 L 1 g
F P
s
P
p
.56733 .52997 m .54637 .55741 L .56704 .521 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56669 .51009 L p
1 g
F P
s
P
p
.002 w
.56669 .51009 m .56515 .50826 L p
.56702 .5204 L 1 g
F P
s
P
p
.56702 .5204 m .56854 .53025 L .56669 .51009 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55733 .49127 m .55661 .4905 L p
.56082 .49855 L 1 g
F P
s
P
p
.002 w
.56704 .521 m .5436 .53016 L p
.56014 .49713 L 1 g
F P
s
P
p
.56395 .48951 m .56588 .50912 L .56014 .49713 L 1 g
F
P
p
.56588 .50912 m .56704 .521 L .56014 .49713 L 1 g
F
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56007 .48147 m .56395 .48951 L p
.5612 .49501 L 1 g
F P
s
P
p
.5569 .49085 m .5612 .49501 L .5436 .53016 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55733 .49127 L p
1 g
F P
s
P
p
.54174 .47608 m .55733 .49127 L .55263 .48673 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55263 .48673 m .52998 .50274 L p
.53022 .47084 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54217 .47655 L p
1 g
F P
s
P
p
.52214 .46667 m .54217 .47655 L .53004 .47076 L 1 g
F
P
p
.53026 .46496 m .54217 .47655 L .53022 .47084 L 1 g
F
P
p
.54217 .47655 m .55263 .48673 L .53022 .47084 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46712 L p
1 g
F P
s
P
p
.002 w
.52998 .50274 m .50682 .47843 L .51675 .46639 L p
1 g
F P
s
P
p
.51844 .46661 m .52998 .50274 L .51675 .46639 L 1 g
F
P
p
.5 .4634 m .52241 .46712 L .51675 .46639 L 1 g
F
P
p
.5 .4634 m .51675 .46639 L .51048 .46542 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.49156 .42632 m .53037 .44988 L .51675 .46639 L p
1 g
F P
s
P
p
.002 w
.51675 .46639 m .50682 .47843 L p
.50265 .4642 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.50265 .4642 m .50682 .47843 L .48634 .46597 L 1 g
F
P
p
.47786 .46667 m .48913 .46552 L .48626 .46598 L 1 g
F
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.47776 .46718 m .48322 .50528 L .47387 .469 L 1 g
F
P
p
.47776 .46718 m .47387 .469 L .47753 .46722 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46722 L p
1 g
F P
s
P
p
.002 w
.48322 .50528 m .46282 .49297 L .47282 .46951 L p
1 g
F P
s
P
p
.47387 .469 m .48322 .50528 L .47282 .46951 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47282 .46951 m .46282 .49297 L p
.45612 .47822 L 1 g
F P
s
P
p
.45775 .47664 m .47282 .46951 L .45612 .47822 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45775 .47664 L p
1 g
F P
s
P
p
.44339 .4905 m .45775 .47664 L .45046 .48373 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44249 .49145 L p
1 g
F P
s
P
p
.002 w
.43982 .49699 m .44025 .48624 L p
.44196 .49256 L 1 g
F P
s
P
p
.002 w
.41817 .48582 m .44025 .48624 L .43982 .49699 L p
1 g
F P
s
P
p
.41817 .48582 m .43542 .49471 L .43331 .51065 L 1 g
F
P
p
.43542 .49471 m .43982 .49699 L .43393 .50936 L 1 g
F
P
p
.43542 .49471 m .43393 .50936 L .43331 .51065 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43393 .50936 L p
1 g
F P
s
P
p
.43346 .52734 m .43393 .50936 L .43311 .51738 L 1 g
F
P
p
.43485 .50826 m .44249 .49145 L .43982 .49699 L 1 g
F
P
p
.43833 .50012 m .43982 .49699 L .43847 .49981 L 1 g
F
P
p
.43485 .50826 m .43982 .49699 L .43833 .50012 L 1 g
F
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42779 .51954 m .41817 .48582 L p
.43331 .51065 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43393 .50936 L p
1 g
F P
s
P
p
.002 w
.43393 .50936 m .43485 .50826 L p
.43833 .50012 L 1 g
F P
s
P
p
.43833 .50012 m .44166 .49233 L .43393 .50936 L 1 g
F
P
p
.43331 .51065 m .43373 .51133 L .42906 .51957 L 1 g
F
P
p
.002 w
.43288 .51968 m .42906 .51957 L p
.43373 .51133 L 1 g
F P
s
P
p
.002 w
.42906 .51957 m .42779 .51954 L p
.43331 .51065 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.41811 .52237 m .42098 .52153 L p
.43855 .54863 L 1 g
F P
s
P
p
.002 w
.43866 .549 m .41811 .52237 L p
.43855 .54863 L 1 g
F P
s
P
p
.002 w
.43823 .54758 m .43925 .54566 L p
.4352 .53764 L 1 g
F P
s
P
p
.43237 .53151 m .43299 .5304 L .43655 .54209 L 1 g
F
P
p
.4352 .53764 m .43707 .54379 L .43823 .54758 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43823 .54758 L p
1 g
F P
s
P
p
.45146 .56129 m .43823 .54758 L .43825 .54761 L 1 g
F
P
p
.002 w
.43892 .54862 m .43946 .55002 L p
.42098 .52153 L 1 g
F P
s
P
p
.002 w
.44689 .56032 m .43946 .55002 L p
.44123 .55165 L 1 g
F P
s
P
p
.45146 .56129 m .43823 .54759 L .43945 .54941 L 1 g
F
P
p
.002 w
.43961 .54965 m .43946 .55002 L .43945 .54941 L p
1 g
F P
s
P
p
.43955 .54956 m .43945 .54941 L .43954 .54955 L 1 g
F
P
p
.45146 .56129 m .43945 .54941 L .43955 .54956 L 1 g
F
P
p
.45146 .56129 m .43954 .54955 L .43962 .54966 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43891 .51984 m .45024 .52326 L .43961 .54965 L p
1 g
F P
s
P
p
.002 w
.43945 .54941 m .43891 .51984 L p
.43961 .54965 L 1 g
F P
s
P
p
.45146 .56129 m .43961 .54965 L .43967 .54974 L 1 g
F
P
p
.45146 .56129 m .43966 .54973 L .43972 .54981 L 1 g
F
P
p
.002 w
.45024 .52326 m .46049 .52942 L .4397 .54978 L p
1 g
F P
s
P
p
.002 w
.4397 .54978 m .43946 .55002 L .43961 .54965 L p
1 g
F P
s
P
p
.002 w
.43961 .54965 m .45024 .52326 L p
.4397 .54978 L 1 g
F P
s
P
p
.43962 .54966 m .43954 .54955 L .43961 .54965 L 1 g
F
P
p
.43967 .54974 m .43961 .54965 L .43966 .54973 L 1 g
F
P
p
.45146 .56129 m .4397 .54979 L .43976 .54987 L 1 g
F
P
p
.45146 .56129 m .43974 .54985 L .43981 .54993 L 1 g
F
P
p
.002 w
.46049 .52942 m .4685 .53763 L .43978 .54989 L p
1 g
F P
s
P
p
.002 w
.43978 .54989 m .43946 .55002 L .4397 .54978 L p
1 g
F P
s
P
p
.002 w
.4397 .54978 m .46049 .52942 L p
.43978 .54989 L 1 g
F P
s
P
p
.45146 .56129 m .43977 .5499 L .43985 .54999 L 1 g
F
P
p
.002 w
.4685 .53763 m .4734 .54695 L .43985 .54999 L p
1 g
F P
s
P
p
.002 w
.43985 .54999 m .43946 .55002 L .43978 .54989 L p
1 g
F P
s
P
p
.002 w
.43978 .54989 m .4685 .53763 L p
.43985 .54999 L 1 g
F P
s
P
p
.43972 .54981 m .43966 .54973 L .4397 .54979 L 1 g
F
P
p
.43976 .54987 m .4397 .54979 L .43974 .54985 L 1 g
F
P
p
.45146 .56129 m .43981 .54995 L .44349 .55437 L 1 g
F
P
p
.002 w
.4734 .54695 m .47466 .55634 L .43995 .55011 L p
1 g
F P
s
P
p
.002 w
.43995 .55011 m .43946 .55002 L .43985 .54999 L p
1 g
F P
s
P
p
.002 w
.43985 .54999 m .4734 .54695 L p
.43995 .55011 L 1 g
F P
s
P
p
.002 w
.47466 .55634 m .4722 .56476 L .44012 .55032 L p
1 g
F P
s
P
p
.002 w
.44012 .55032 m .43946 .55002 L .43995 .55011 L p
1 g
F P
s
P
p
.002 w
.43995 .55011 m .47466 .55634 L p
.44012 .55032 L 1 g
F P
s
P
p
.43981 .54993 m .43974 .54985 L .43977 .5499 L 1 g
F
P
p
.43985 .54999 m .43977 .5499 L .43981 .54995 L 1 g
F
P
p
.002 w
.4722 .56476 m .46633 .57132 L .44067 .55099 L p
1 g
F P
s
P
p
.002 w
.44067 .55099 m .43946 .55002 L .44012 .55032 L p
1 g
F P
s
P
p
.002 w
.44012 .55032 m .4722 .56476 L p
.44067 .55099 L 1 g
F P
s
P
p
.46387 .57247 m .45078 .56311 L .44123 .55165 L 1 g
F
P
p
.45078 .56311 m .44689 .56032 L .44123 .55165 L 1 g
F
P
p
.002 w
.46633 .57132 m .46387 .57247 L p
.44123 .55165 L 1 g
F P
s
P
p
.002 w
.43946 .55002 m .44067 .55099 L p
.44123 .55165 L 1 g
F P
s
P
p
.002 w
.44067 .55099 m .46633 .57132 L p
.44123 .55165 L 1 g
F P
s
P
p
.002 w
.43946 .55002 m .43866 .549 L p
.43855 .54863 L 1 g
F P
s
P
p
.002 w
.43945 .54941 m .43946 .55002 L .43892 .54862 L p
1 g
F P
s
P
p
.002 w
.44733 .57641 m .43624 .57448 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.41657 .5627 m .41003 .55407 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.41003 .55407 m .40672 .54476 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.40672 .54476 m .40701 .53574 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.40701 .53574 m .41094 .52799 L .43883 .54954 L p
1 g
F P
s
P
p
.002 w
.43883 .54954 m .43946 .55002 L .43891 .54978 L p
1 g
F P
s
P
p
.002 w
.43891 .54978 m .40701 .53574 L p
.43883 .54954 L 1 g
F P
s
P
p
.002 w
.42098 .52153 m .42779 .51954 L .43707 .54379 L p
1 g
F P
s
P
p
.002 w
.43707 .54379 m .43892 .54862 L p
.43823 .54758 L 1 g
F P
s
P
p
.42098 .52153 m .43707 .54379 L .43823 .54758 L 1 g
F
P
p
.002 w
.41094 .52799 m .41811 .52237 L .43946 .55002 L closepath p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43821 .54762 L p
1 g
F P
s
P
p
.002 w
.43821 .54762 m .43823 .54758 L p
.43805 .54712 L 1 g
F P
s
P
p
.43805 .54712 m .43146 .53025 L .43821 .54762 L 1 g
F
P
p
.44174 .55284 m .43981 .54995 L .43743 .5491 L 1 g
F
P
p
.002 w
.43823 .54759 m .43808 .54788 L p
.43981 .54995 L 1 g
F P
s
P
p
.002 w
.43808 .54788 m .43743 .5491 L p
.43981 .54995 L 1 g
F P
s
P
p
.44349 .55437 m .43981 .54995 L .44174 .55284 L 1 g
F
P
p
.002 w
.43892 .54862 m .43707 .54379 L p
.43945 .54941 L 1 g
F P
s
P
p
.002 w
.43707 .54379 m .43237 .53151 L p
.43655 .54209 L 1 g
F P
s
P
p
.43655 .54209 m .43945 .54941 L .43707 .54379 L 1 g
F
P
p
.43518 .53761 m .43146 .53025 L .43821 .54753 L 1 g
F
P
p
.43707 .54379 m .43821 .54753 L .43823 .54758 L 1 g
F
P
p
.43518 .53761 m .43821 .54753 L .43707 .54379 L 1 g
F
P
p
.4352 .53764 m .43518 .53761 L .43707 .54379 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43249 .52876 L p
1 g
F P
s
P
p
.002 w
.43237 .53151 m .42779 .51954 L .42969 .51959 L p
1 g
F P
s
P
p
.42969 .51959 m .43249 .52876 L .43237 .53151 L 1 g
F
P
p
.43925 .54566 m .43249 .52876 L .4352 .53764 L 1 g
F
P
p
.43346 .52734 m .43311 .51738 L .43288 .51968 L 1 g
F
P
p
.002 w
.43249 .52876 m .43346 .52734 L p
.43288 .51968 L 1 g
F P
s
P
p
.002 w
.43288 .51968 m .43891 .51984 L p
.43237 .53151 L 1 g
F P
s
P
p
.002 w
.43249 .52876 m .43146 .53025 L p
.4352 .53764 L 1 g
F P
s
P
p
.002 w
.42969 .51959 m .43288 .51968 L p
.43249 .52876 L 1 g
F P
s
P
p
.002 w
.43891 .51984 m .43945 .54941 L p
.43655 .54209 L 1 g
F P
s
P
p
.43299 .5304 m .43891 .51984 L .43655 .54209 L 1 g
F
P
p
.002 w
.43823 .54758 m .43823 .54759 L p
.43825 .54761 L 1 g
F P
s
P
p
.002 w
.43186 .52967 m .43249 .52876 L p
.43288 .51968 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43186 .52967 L p
1 g
F P
s
P
p
.43311 .51738 m .43287 .51061 L .43186 .52967 L 1 g
F
P
p
.002 w
.43891 .51984 m .43288 .51968 L p
.43373 .51133 L 1 g
F P
s
P
p
.002 w
.43982 .49699 m .43891 .51984 L p
.43331 .51065 L 1 g
F P
s
P
p
.002 w
.43393 .50936 m .43287 .51061 L p
.43311 .51738 L 1 g
F P
s
P
p
.43847 .49981 m .43982 .49699 L .44166 .49233 L 1 g
F
P
p
.44339 .4905 m .45046 .48373 L .44609 .48798 L 1 g
F
P
p
.002 w
.44609 .48798 m .46282 .49297 L p
.44183 .49209 L 1 g
F P
s
P
p
.002 w
.44226 .49171 m .44249 .49145 L p
.44609 .48798 L 1 g
F P
s
P
p
.002 w
.44249 .49145 m .44339 .4905 L p
.44609 .48798 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46282 .49297 m .45024 .52326 L p
.44183 .49209 L 1 g
F P
s
P
p
.002 w
.44025 .48624 m .44609 .48798 L p
.44183 .49209 L 1 g
F P
s
P
p
.002 w
.44249 .49145 m .44243 .49152 L p
.43982 .49699 L 1 g
F P
s
P
p
.002 w
.44243 .49152 m .44166 .49233 L p
.43982 .49699 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45024 .52326 m .43891 .51984 L .43982 .49699 L p
1 g
F P
s
P
p
.44196 .49256 m .45024 .52326 L .43982 .49699 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46282 .49297 m .44025 .48624 L .44348 .45043 L p
1 g
F P
s
P
p
.002 w
.45775 .47664 m .45698 .47747 L p
.45046 .48373 L 1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.44348 .45043 m .46818 .46649 L .45581 .47755 L 1 g
F
P
p
.45826 .47608 m .47753 .46722 L .47282 .46951 L 1 g
F
P
p
.46738 .47208 m .47282 .46951 L .46887 .47143 L 1 g
F
P
p
.45826 .47608 m .47282 .46951 L .46738 .47208 L 1 g
F
P
p
.002 w
.45742 .47699 m .45826 .47608 L p
.46887 .47143 L 1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.46818 .46649 m .47282 .46951 L .45775 .47664 L 1 g
F
P
p
.46818 .46649 m .45775 .47664 L .45581 .47755 L 1 g
F
P
p
.45581 .47755 m .45775 .47664 L .45612 .47822 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44226 .49171 L p
1 g
F P
s
P
p
.45046 .48373 m .45698 .47747 L .44226 .49171 L 1 g
F
P
p
.002 w
.44348 .45043 m .47677 .46024 L .47282 .46951 L p
1 g
F P
s
P
p
.46887 .47143 m .47282 .46951 L .47718 .46778 L 1 g
F
P
p
.002 w
.47753 .46722 m .47748 .4673 L p
.47282 .46951 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47718 .46778 L p
.47282 .46951 L 1 g
F P
s
P
p
.002 w
.47282 .46951 m .47356 .46778 L p
.47387 .469 L 1 g
F P
s
P
p
.47753 .46722 m .47387 .469 L .47356 .46778 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45742 .47699 L p
1 g
F P
s
P
p
.46887 .47143 m .47718 .46778 L .45742 .47699 L 1 g
F
P
p
.002 w
.47753 .46722 m .47786 .46667 L p
.48626 .46598 L 1 g
F P
s
P
p
.002 w
.50682 .47843 m .48322 .50528 L p
.47776 .46718 L 1 g
F P
s
P
p
.50265 .4642 m .48634 .46597 L .5 .46378 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46378 L p
1 g
F P
s
P
p
.002 w
.5 .46378 m .5 .46442 L p
.48913 .46552 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46378 L .48913 .46552 L 1 g
F
P
p
.002 w
.47677 .46024 m .4768 .46017 L p
.48634 .46597 L 1 g
F P
s
P
p
.002 w
.50682 .47843 m .48626 .46598 L p
.48634 .46597 L 1 g
F P
s
P
p
.002 w
.48626 .46598 m .47677 .46024 L p
.48634 .46597 L 1 g
F P
s
P
p
.002 w
.47677 .46024 m .48626 .46598 L p
.47776 .46718 L 1 g
F P
s
P
p
.002 w
.48626 .46598 m .50682 .47843 L p
.47776 .46718 L 1 g
F P
s
P
p
.48626 .46598 m .5 .46442 L .47742 .4674 L 1 g
F
P
p
.48913 .46552 m .4905 .46538 L .48626 .46598 L 1 g
F
P
p
.4905 .46538 m .5 .46442 L .48626 .46598 L 1 g
F
P
p
.002 w
.47742 .4674 m .47753 .46722 L p
.48626 .46598 L 1 g
F P
s
P
p
.002 w
.47356 .46778 m .47677 .46024 L p
.47776 .46718 L 1 g
F P
s
P
p
.5 .46378 m .48634 .46597 L .4768 .46017 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47742 .4674 L p
1 g
F P
s
P
p
.53022 .47084 m .52998 .50274 L .51844 .46661 L 1 g
F
P
p
.52241 .46712 m .51844 .46661 L .51792 .46497 L 1 g
F
P
p
.53022 .47084 m .51844 .46661 L .52241 .46712 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46424 L p
1 g
F P
s
P
p
.002 w
.5 .46424 m .5 .4634 L p
.51319 .46593 L 1 g
F P
s
P
p
.51319 .46593 m .52282 .46778 L .5 .46424 L 1 g
F
P
p
.49156 .42632 m .51675 .46639 L .50265 .4642 L 1 g
F
P
p
.51319 .46593 m .51675 .46639 L .52282 .46778 L 1 g
F
P
p
.002 w
.52241 .46712 m .52251 .46729 L p
.51675 .46639 L 1 g
F P
s
P
p
.002 w
.52251 .46729 m .52282 .46778 L p
.51675 .46639 L 1 g
F P
s
P
p
.51048 .46542 m .51675 .46639 L .51319 .46593 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.4768 .46017 m .49156 .42632 L p
.50265 .4642 L 1 g
F P
s
P
p
.002 w
.51675 .46639 m .51792 .46497 L p
.51844 .46661 L 1 g
F P
s
P
p
.002 w
.52241 .46712 m .52214 .46667 L p
.53004 .47076 L 1 g
F P
s
P
p
.002 w
.51792 .46497 m .53037 .44988 L p
.53022 .47084 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52241 .46712 L p
1 g
F P
s
P
p
.53004 .47076 m .54302 .47747 L .52241 .46712 L 1 g
F
P
p
.002 w
.54217 .47655 m .54302 .47747 L p
.53004 .47076 L 1 g
F P
s
P
p
.54993 .4841 m .55263 .48673 L .55137 .48551 L 1 g
F
P
p
.54174 .47608 m .55263 .48673 L .54993 .4841 L 1 g
F
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53037 .44988 m .56007 .48147 L .55263 .48673 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55733 .49127 L p
1 g
F P
s
P
p
.56082 .49855 m .56713 .51061 L .55733 .49127 L 1 g
F
P
p
.002 w
.5436 .53016 m .52998 .50274 L .55263 .48673 L p
1 g
F P
s
P
p
.5569 .49085 m .5436 .53016 L .55263 .48673 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54277 .47721 L p
1 g
F P
s
P
p
.002 w
.54277 .47721 m .54174 .47608 L p
.55137 .48551 L 1 g
F P
s
P
p
.55137 .48551 m .55834 .49233 L .54277 .47721 L 1 g
F
P
p
.002 w
.55263 .48673 m .56007 .48147 L p
.5569 .49085 L 1 g
F P
s
P
p
.53037 .44988 m .55263 .48673 L .53026 .46496 L 1 g
F
P
p
.56007 .48147 m .5612 .49501 L .5569 .49085 L 1 g
F
P
p
.002 w
.55733 .49127 m .55834 .49233 L p
.55137 .48551 L 1 g
F P
s
P
p
.002 w
.56588 .50912 m .56713 .51061 L p
.56082 .49855 L 1 g
F P
s
P
p
.56691 .51969 m .56704 .521 L .56702 .5204 L 1 g
F
P
p
.002 w
.56728 .52842 m .56854 .53025 L p
.56702 .5204 L 1 g
F P
s
P
p
.56733 .52997 m .5643 .53776 L .5664 .53119 L 1 g
F
P
p
.56742 .53275 m .5643 .53776 L .56733 .52997 L 1 g
F
P
p
.002 w
.56139 .54687 m .56075 .54566 L p
.55509 .55606 L 1 g
F P
s
P
p
.002 w
.55509 .55606 m .54637 .55741 L p
.57774 .52303 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56728 .52842 L p
1 g
F P
s
P
p
.56508 .5353 m .56257 .5491 L .56728 .52842 L 1 g
F
P
p
.002 w
.56139 .54687 m .56257 .5491 L p
.56508 .5353 L 1 g
F P
s
P
p
.002 w
.56198 .54799 m .56139 .54687 L p
.55509 .55606 L 1 g
F P
s
P
p
.002 w
.543 .5675 m .54637 .55741 L .55509 .55606 L p
1 g
F P
s
P
p
.002 w
.55509 .55606 m .55965 .55536 L p
.54918 .563 L 1 g
F P
s
P
p
.54918 .563 m .543 .5675 L .55509 .55606 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56198 .54799 L p
1 g
F P
s
P
p
.55487 .55632 m .54998 .56518 L .56198 .54799 L 1 g
F
P
p
.002 w
.54918 .563 m .54998 .56518 L p
.55487 .55632 L 1 g
F P
s
P
p
.002 w
.54939 .56358 m .54918 .563 L p
.543 .5675 L 1 g
F P
s
P
p
.002 w
.54637 .55741 m .543 .5675 L p
.50557 .57534 L 1 g
F P
s
P
p
.002 w
.543 .5675 m .5418 .57112 L p
.536 .57179 L 1 g
F P
s
P
p
.543 .5675 m .536 .57179 L .50557 .57534 L 1 g
F
P
p
.53128 .57265 m .5205 .57812 L .52085 .578 L 1 g
F
P
p
.002 w
.51094 .58057 m .51079 .57862 L p
.50012 .58122 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58066 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .58066 L .49825 .58113 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.50557 .57534 m .50012 .58122 L p
.46633 .57132 L 1 g
F P
s
P
p
.002 w
.50012 .58122 m .49832 .58316 L p
.49197 .58081 L 1 g
F P
s
P
p
.48921 .57862 m .4682 .57502 L .47816 .57771 L 1 g
F
P
p
.002 w
.48903 .58098 m .48921 .57862 L p
.47787 .57769 L 1 g
F P
s
P
p
.50012 .58122 m .49197 .58081 L .46633 .57132 L 1 g
F
P
p
.002 w
.47577 .57707 m .46633 .57132 L p
.49832 .58316 L 1 g
F P
s
P
p
.002 w
.48906 .58066 m .48889 .583 L p
.49825 .58113 L 1 g
F P
s
P
p
.002 w
.50012 .58122 m .50557 .57534 L .5205 .57812 L p
1 g
F P
s
P
p
.002 w
.5205 .57812 m .52816 .57954 L p
.51094 .58057 L 1 g
F P
s
P
p
.51094 .58057 m .50012 .58122 L .5205 .57812 L 1 g
F
P
p
.002 w
.52816 .57954 m .53835 .58144 L p
.50012 .58122 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53184 .5752 L p
1 g
F P
s
P
p
.002 w
.53184 .5752 m .53128 .57265 L p
.52075 .57805 L 1 g
F P
s
P
p
.52075 .57805 m .51111 .583 L .53184 .5752 L 1 g
F
P
p
.002 w
.5205 .57812 m .50557 .57534 L p
.5418 .57112 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54939 .56358 L p
1 g
F P
s
P
p
.54026 .56918 m .5322 .57686 L .54939 .56358 L 1 g
F
P
p
.002 w
.53167 .57444 m .5322 .57686 L p
.54026 .56918 L 1 g
F P
s
P
p
.52085 .578 m .5205 .57812 L .52075 .57805 L 1 g
F
P
p
.002 w
.51094 .58057 m .51111 .583 L p
.52075 .57805 L 1 g
F P
s
P
p
.002 w
.51102 .58178 m .51094 .58057 L p
.50012 .58122 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51102 .58178 L p
1 g
F P
s
P
p
.49825 .58113 m .48889 .583 L .51102 .58178 L 1 g
F
P
p
.002 w
.4682 .57502 m .4678 .57686 L p
.47816 .57771 L 1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .58302 L p
1 g
F P
s
P
p
.002 w
.51111 .58302 m .51111 .583 L p
.51104 .58301 L 1 g
F P
s
P
p
.51104 .58301 m .48857 .5874 L .51111 .58302 L 1 g
F
P
p
.002 w
.46633 .57132 m .47577 .57707 L p
.46824 .57484 L 1 g
F P
s
P
p
.002 w
.46244 .57313 m .46387 .57247 L p
.46824 .57484 L 1 g
F P
s
P
p
.002 w
.46387 .57247 m .46633 .57132 L p
.46824 .57484 L 1 g
F P
s
P
p
.002 w
.45009 .56498 m .45002 .56518 L p
.4517 .56585 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56311 L p
1 g
F P
s
P
p
.44349 .55437 m .43743 .5491 L .45078 .56311 L 1 g
F
P
p
.45832 .56849 m .4517 .56585 L .46387 .57247 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46824 .57484 L p
1 g
F P
s
P
p
.4517 .56585 m .45002 .56518 L .46824 .57484 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58098 L p
1 g
F P
s
P
p
.47787 .57769 m .4678 .57686 L .48903 .58098 L 1 g
F
P
p
.002 w
.40508 .37808 m .36267 .39301 L .35871 .36196 L p
1 g
F P
s
P
p
.002 w
.35871 .36196 m .40648 .34451 L .40508 .37808 L p
1 g
F P
s
P
p
.002 w
.60676 .34096 m .65105 .39031 L .63444 .41227 L p
1 g
F P
s
P
p
.002 w
.38318 .45907 m .36304 .47603 L .34533 .44804 L p
1 g
F P
s
P
p
.002 w
.34533 .44804 m .37089 .42577 L .38318 .45907 L p
1 g
F P
s
P
p
.002 w
.41094 .52799 m .40701 .53574 L .37771 .51844 L p
1 g
F P
s
P
p
.002 w
.37771 .51844 m .38516 .50302 L .41094 .52799 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.46304 .34367 m .40648 .34451 L .41068 .3142 L p
1 g
F P
s
P
p
.002 w
.41068 .3142 m .47198 .31284 L .46304 .34367 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.58023 .55217 m .57722 .51702 L .60817 .50137 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61327 .43535 m .63537 .48382 L .60817 .50137 L p
1 g
F P
s
P
p
.002 w
.63537 .48382 m .61327 .43535 L .63444 .41227 L p
1 g
F P
s
P
p
.002 w
.53518 .33054 m .47198 .31284 L .48154 .28631 L p
1 g
F P
s
P
p
.002 w
.48154 .28631 m .54762 .30462 L .53518 .33054 L p
1 g
F P
s
P
p
.002 w
.46633 .57132 m .4722 .56476 L .50557 .57534 L p
1 g
F P
s
P
p
.002 w
.51074 .55883 m .50557 .57534 L .4722 .56476 L p
1 g
F P
s
P
p
.002 w
.50557 .57534 m .51074 .55883 L .54637 .55741 L p
1 g
F P
s
P
p
.002 w
.39911 .49168 m .38516 .50302 L .36304 .47603 L p
1 g
F P
s
P
p
.002 w
.36304 .47603 m .38318 .45907 L .39911 .49168 L p
1 g
F P
s
P
p
.002 w
.40659 .41372 m .37089 .42577 L .36267 .39301 L p
1 g
F P
s
P
p
.002 w
.36267 .39301 m .40508 .37808 L .40659 .41372 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.63444 .41227 m .59183 .36527 L .60676 .34096 L p
1 g
F P
s
P
p
.002 w
.54762 .30462 m .60676 .34096 L .59183 .36527 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.4722 .56476 m .47466 .55634 L .51074 .55883 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41811 .52237 m .41094 .52799 L .38516 .50302 L p
1 g
F P
s
P
p
.002 w
.38516 .50302 m .39911 .49168 L .41811 .52237 L p
1 g
F P
s
P
p
.002 w
.59183 .36527 m .63444 .41227 L .61327 .43535 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5436 .53016 m .54637 .55741 L .51074 .55883 L p
1 g
F P
s
P
p
.002 w
.59183 .36527 m .53518 .33054 L .54762 .30462 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58819 .45871 m .60817 .50137 L .57722 .51702 L p
1 g
F P
s
P
p
.002 w
.60817 .50137 m .58819 .45871 L .61327 .43535 L p
1 g
F P
s
P
p
.002 w
.41101 .4501 m .38318 .45907 L .37089 .42577 L p
1 g
F P
s
P
p
.002 w
.37089 .42577 m .40659 .41372 L .41101 .4501 L p
1 g
F P
s
P
p
.002 w
.50855 .54026 m .51074 .55883 L .47466 .55634 L p
1 g
F P
s
P
p
.002 w
.51074 .55883 m .50855 .54026 L .5436 .53016 L p
1 g
F P
s
P
p
.002 w
.47466 .55634 m .4734 .54695 L .50855 .54026 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.45511 .37773 m .40508 .37808 L .40648 .34451 L p
1 g
F P
s
P
p
.002 w
.40648 .34451 m .46304 .34367 L .45511 .37773 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42779 .51954 m .41811 .52237 L .39911 .49168 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.52135 .36019 m .46304 .34367 L .47198 .31284 L p
1 g
F P
s
P
p
.002 w
.47198 .31284 m .53518 .33054 L .52135 .36019 L p
1 g
F P
s
P
p
.002 w
.41817 .48582 m .39911 .49168 L .38318 .45907 L p
1 g
F P
s
P
p
.002 w
.38318 .45907 m .41101 .4501 L .41817 .48582 L p
1 g
F P
s
P
p
.002 w
.4734 .54695 m .4685 .53763 L .49905 .52169 L p
1 g
F P
s
P
p
.002 w
.49905 .52169 m .50855 .54026 L .4734 .54695 L p
1 g
F P
s
P
p
.002 w
.39911 .49168 m .41817 .48582 L .42779 .51954 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57722 .51702 m .56007 .48147 L .58819 .45871 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.5737 .39219 m .61327 .43535 L .58819 .45871 L p
1 g
F P
s
P
p
.002 w
.61327 .43535 m .5737 .39219 L .59183 .36527 L p
1 g
F P
s
P
p
.002 w
.53518 .33054 m .59183 .36527 L .5737 .39219 L p
1 g
F P
s
P
p
.002 w
.4685 .53763 m .46049 .52942 L .48322 .50528 L p
1 g
F P
s
P
p
.002 w
.48322 .50528 m .49905 .52169 L .4685 .53763 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.50855 .54026 m .49905 .52169 L .52998 .50274 L p
1 g
F P
s
P
p
.002 w
.52998 .50274 m .5436 .53016 L .50855 .54026 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.4485 .41379 m .40659 .41372 L .40508 .37808 L p
1 g
F P
s
P
p
.002 w
.40508 .37808 m .45511 .37773 L .4485 .41379 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46049 .52942 m .45024 .52326 L .46282 .49297 L p
1 g
F P
s
P
p
.002 w
.46282 .49297 m .48322 .50528 L .46049 .52942 L p
1 g
F P
s
P
p
.002 w
.5737 .39219 m .52135 .36019 L .53518 .33054 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.44025 .48624 m .41817 .48582 L .41101 .4501 L p
1 g
F P
s
P
p
.002 w
.44348 .45043 m .41101 .4501 L .40659 .41372 L p
1 g
F P
s
P
p
.002 w
.40659 .41372 m .4485 .41379 L .44348 .45043 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50662 .39252 m .45511 .37773 L .46304 .34367 L p
1 g
F P
s
P
p
.002 w
.46304 .34367 m .52135 .36019 L .50662 .39252 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.55296 .42075 m .58819 .45871 L .56007 .48147 L p
1 g
F P
s
P
p
.002 w
.58819 .45871 m .55296 .42075 L .5737 .39219 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.49905 .52169 m .48322 .50528 L .50682 .47843 L p
1 g
F P
s
P
p
.002 w
.50682 .47843 m .52998 .50274 L .49905 .52169 L p
1 g
F P
s
P
p
.002 w
.41101 .4501 m .44348 .45043 L .44025 .48624 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52135 .36019 m .5737 .39219 L .55296 .42075 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56007 .48147 m .53037 .44988 L .55296 .42075 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.55296 .42075 m .50662 .39252 L .52135 .36019 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49156 .42632 m .4485 .41379 L .45511 .37773 L p
1 g
F P
s
P
p
.002 w
.45511 .37773 m .50662 .39252 L .49156 .42632 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.47677 .46024 m .44348 .45043 L .4485 .41379 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.004 w
.41448 .59934 m
.41872 .59095 L
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.4485 .41379 m .49156 .42632 L .47677 .46024 L p
1 g
F P
s
P
p
.002 w
.50662 .39252 m .55296 .42075 L .53037 .44988 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53037 .44988 m .49156 .42632 L .50662 .39252 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .20745 .48732 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4036 .62081 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.472093)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.472093)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45733 .41686 m .48004 .4433 L .49882 .42179 L p
1 g
F P
s
P
p
.002 w
.49882 .42179 m .48129 .40129 L .45733 .41686 L p
1 g
F P
s
P
p
.002 w
.52153 .43656 m .49882 .42179 L .48004 .4433 L p
1 g
F P
s
P
p
.002 w
.48129 .40129 m .49882 .42179 L .51765 .40047 L p
1 g
F P
s
P
p
.002 w
.49882 .42179 m .52153 .43656 L .53318 .41055 L p
1 g
F P
s
P
p
.002 w
.53318 .41055 m .51765 .40047 L .49882 .42179 L p
1 g
F P
s
P
p
.002 w
.48004 .4433 m .50936 .4624 L .52153 .43656 L p
1 g
F P
s
P
p
.002 w
.54716 .4441 m .52153 .43656 L .50936 .4624 L p
1 g
F P
s
P
p
.002 w
.52153 .43656 m .54716 .4441 L .55071 .41563 L p
1 g
F P
s
P
p
.002 w
.55071 .41563 m .53318 .41055 L .52153 .43656 L p
1 g
F P
s
P
p
.002 w
.43425 .43286 m .46165 .46461 L .48004 .4433 L p
1 g
F P
s
P
p
.002 w
.48004 .4433 m .45733 .41686 L .43425 .43286 L p
1 g
F P
s
P
p
.002 w
.50936 .4624 m .48004 .4433 L .46165 .46461 L p
1 g
F P
s
P
p
.002 w
.46165 .46461 m .4969 .48761 L .50936 .4624 L p
1 g
F P
s
P
p
.002 w
.54246 .47228 m .50936 .4624 L .4969 .48761 L p
1 g
F P
s
P
p
.002 w
.50936 .4624 m .54246 .47228 L .54716 .4441 L p
1 g
F P
s
P
p
.002 w
.4435 .38561 m .45733 .41686 L .48129 .40129 L p
1 g
F P
s
P
p
.002 w
.48129 .40129 m .47073 .37707 L .4435 .38561 L p
1 g
F P
s
P
p
.002 w
.47073 .37707 m .48129 .40129 L .5057 .38643 L p
1 g
F P
s
P
p
.002 w
.51765 .40047 m .5057 .38643 L .48129 .40129 L p
1 g
F P
s
P
p
.002 w
.5057 .38643 m .51765 .40047 L .53619 .37971 L p
1 g
F P
s
P
p
.002 w
.51765 .40047 m .53318 .41055 L .54411 .38484 L p
1 g
F P
s
P
p
.002 w
.54411 .38484 m .53619 .37971 L .51765 .40047 L p
1 g
F P
s
P
p
.002 w
.53318 .41055 m .55071 .41563 L .55305 .38739 L p
1 g
F P
s
P
p
.002 w
.55305 .38739 m .54411 .38484 L .53318 .41055 L p
1 g
F P
s
P
p
.002 w
.5057 .38643 m .49858 .36985 L .47073 .37707 L p
1 g
F P
s
P
p
.002 w
.49858 .36985 m .5057 .38643 L .53012 .37254 L p
1 g
F P
s
P
p
.002 w
.53619 .37971 m .53012 .37254 L .5057 .38643 L p
1 g
F P
s
P
p
.002 w
.41741 .39533 m .43425 .43286 L .45733 .41686 L p
1 g
F P
s
P
p
.002 w
.45733 .41686 m .4435 .38561 L .41741 .39533 L p
1 g
F P
s
P
p
.002 w
.57316 .44357 m .54716 .4441 L .54246 .47228 L p
1 g
F P
s
P
p
.002 w
.54716 .4441 m .57316 .44357 L .56845 .41515 L p
1 g
F P
s
P
p
.002 w
.56845 .41515 m .55071 .41563 L .54716 .4441 L p
1 g
F P
s
P
p
.002 w
.41251 .449 m .44399 .48532 L .46165 .46461 L p
1 g
F P
s
P
p
.002 w
.46165 .46461 m .43425 .43286 L .41251 .449 L p
1 g
F P
s
P
p
.002 w
.4969 .48761 m .46165 .46461 L .44399 .48532 L p
1 g
F P
s
P
p
.002 w
.55071 .41563 m .56845 .41515 L .56206 .38709 L p
1 g
F P
s
P
p
.002 w
.56206 .38709 m .55305 .38739 L .55071 .41563 L p
1 g
F P
s
P
p
.002 w
.44399 .48532 m .48437 .51172 L .4969 .48761 L p
1 g
F P
s
P
p
.002 w
.53668 .49966 m .4969 .48761 L .48437 .51172 L p
1 g
F P
s
P
p
.002 w
.4969 .48761 m .53668 .49966 L .54246 .47228 L p
1 g
F P
s
P
p
.002 w
.57612 .47183 m .54246 .47228 L .53668 .49966 L p
1 g
F P
s
P
p
.002 w
.54246 .47228 m .57612 .47183 L .57316 .44357 L p
1 g
F P
s
P
p
.002 w
.46832 .35154 m .47073 .37707 L .49858 .36985 L p
1 g
F P
s
P
p
.002 w
.49858 .36985 m .49708 .35244 L .46832 .35154 L p
1 g
F P
s
P
p
.002 w
.49708 .35244 m .49858 .36985 L .52654 .36409 L p
1 g
F P
s
P
p
.002 w
.53012 .37254 m .52654 .36409 L .49858 .36985 L p
1 g
F P
s
P
p
.002 w
.44011 .35257 m .4435 .38561 L .47073 .37707 L p
1 g
F P
s
P
p
.002 w
.47073 .37707 m .46832 .35154 L .44011 .35257 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .53012 .37254 L .53619 .37971 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .53619 .37971 L .54411 .38484 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .54411 .38484 L .55305 .38739 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .52654 .36409 L .53012 .37254 L closepath p
1 g
F P
s
P
p
.002 w
.39298 .40606 m .41251 .449 L .43425 .43286 L p
1 g
F P
s
P
p
.002 w
.43425 .43286 m .41741 .39533 L .39298 .40606 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .55305 .38739 L .56206 .38709 L closepath p
1 g
F P
s
P
p
.002 w
.58453 .40909 m .56845 .41515 L .57316 .44357 L p
1 g
F P
s
P
p
.002 w
.56845 .41515 m .58453 .40909 L .57018 .38394 L p
1 g
F P
s
P
p
.002 w
.57018 .38394 m .56206 .38709 L .56845 .41515 L p
1 g
F P
s
P
p
.002 w
.52654 .36409 m .52585 .35525 L .49708 .35244 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .52585 .35525 L .52654 .36409 L closepath p
1 g
F P
s
P
p
.002 w
.41302 .35555 m .41741 .39533 L .4435 .38561 L p
1 g
F P
s
P
p
.002 w
.4435 .38561 m .44011 .35257 L .41302 .35555 L p
1 g
F P
s
P
p
.002 w
.59687 .43489 m .57316 .44357 L .57612 .47183 L p
1 g
F P
s
P
p
.002 w
.57316 .44357 m .59687 .43489 L .58453 .40909 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .56206 .38709 L .57018 .38394 L closepath p
1 g
F P
s
P
p
.002 w
.47448 .32733 m .46832 .35154 L .49708 .35244 L p
1 g
F P
s
P
p
.002 w
.49708 .35244 m .50143 .33602 L .47448 .32733 L p
1 g
F P
s
P
p
.002 w
.50143 .33602 m .49708 .35244 L .52585 .35525 L p
1 g
F P
s
P
p
.002 w
.48437 .51172 m .52993 .52571 L .53668 .49966 L p
1 g
F P
s
P
p
.002 w
.57723 .49939 m .53668 .49966 L .52993 .52571 L p
1 g
F P
s
P
p
.002 w
.53668 .49966 m .57723 .49939 L .57612 .47183 L p
1 g
F P
s
P
p
.002 w
.39252 .46498 m .4274 .50505 L .44399 .48532 L p
1 g
F P
s
P
p
.002 w
.44399 .48532 m .41251 .449 L .39252 .46498 L p
1 g
F P
s
P
p
.002 w
.48437 .51172 m .44399 .48532 L .4274 .50505 L p
1 g
F P
s
P
p
.002 w
.52585 .35525 m .52814 .34695 L .50143 .33602 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .52814 .34695 L .52585 .35525 L closepath p
1 g
F P
s
P
p
.002 w
.4274 .50505 m .472 .53426 L .48437 .51172 L p
1 g
F P
s
P
p
.002 w
.52993 .52571 m .48437 .51172 L .472 .53426 L p
1 g
F P
s
P
p
.002 w
.57654 .37826 m .57018 .38394 L .58453 .40909 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .57018 .38394 L .57654 .37826 L closepath p
1 g
F P
s
P
p
.002 w
.4478 .3211 m .44011 .35257 L .46832 .35154 L p
1 g
F P
s
P
p
.002 w
.46832 .35154 m .47448 .32733 L .4478 .3211 L p
1 g
F P
s
P
p
.002 w
.60694 .46086 m .57612 .47183 L .57723 .49939 L p
1 g
F P
s
P
p
.002 w
.57612 .47183 m .60694 .46086 L .59687 .43489 L p
1 g
F P
s
P
p
.002 w
.59722 .398 m .58453 .40909 L .59687 .43489 L p
1 g
F P
s
P
p
.002 w
.58453 .40909 m .59722 .398 L .57654 .37826 L p
1 g
F P
s
P
p
.002 w
.51128 .32236 m .50143 .33602 L .52814 .34695 L p
1 g
F P
s
P
p
.002 w
.52814 .34695 m .53319 .3401 L .51128 .32236 L p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .53319 .3401 L .52814 .34695 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .57654 .37826 L .58043 .37064 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .58043 .37064 L .5814 .3619 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .5814 .3619 L .57932 .353 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .57932 .353 L .57441 .34491 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .57441 .34491 L .56719 .33855 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .56719 .33855 L .55847 .33462 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .55847 .33462 L .54922 .33356 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .54922 .33356 L .54048 .33546 L closepath p
1 g
F P
s
P
p
.002 w
.55411 .35991 m .54048 .33546 L .53319 .3401 L closepath p
1 g
F P
s
P
p
.002 w
.37072 .41763 m .39252 .46498 L .41251 .449 L p
1 g
F P
s
P
p
.002 w
.41251 .449 m .39298 .40606 L .37072 .41763 L p
1 g
F P
s
P
p
.002 w
.3876 .36047 m .39298 .40606 L .41741 .39533 L p
1 g
F P
s
P
p
.002 w
.41741 .39533 m .41302 .35555 L .3876 .36047 L p
1 g
F P
s
P
p
.002 w
.58043 .37064 m .57654 .37826 L .59722 .398 L p
1 g
F P
s
P
p
.002 w
.48877 .30707 m .47448 .32733 L .50143 .33602 L p
1 g
F P
s
P
p
.002 w
.50143 .33602 m .51128 .32236 L .48877 .30707 L p
1 g
F P
s
P
p
.002 w
.52564 .31302 m .51128 .32236 L .53319 .3401 L p
1 g
F P
s
P
p
.002 w
.53319 .3401 m .54048 .33546 L .52564 .31302 L p
1 g
F P
s
P
p
.002 w
.61571 .41876 m .59687 .43489 L .60694 .46086 L p
1 g
F P
s
P
p
.002 w
.59687 .43489 m .61571 .41876 L .59722 .398 L p
1 g
F P
s
P
p
.002 w
.42195 .3175 m .41302 .35555 L .44011 .35257 L p
1 g
F P
s
P
p
.002 w
.44011 .35257 m .4478 .3211 L .42195 .3175 L p
1 g
F P
s
P
p
.002 w
.472 .53426 m .5223 .54989 L .52993 .52571 L p
1 g
F P
s
P
p
.002 w
.57643 .5257 m .52993 .52571 L .5223 .54989 L p
1 g
F P
s
P
p
.002 w
.52993 .52571 m .57643 .5257 L .57723 .49939 L p
1 g
F P
s
P
p
.002 w
.59722 .398 m .60508 .38299 L .58043 .37064 L p
1 g
F P
s
P
p
.002 w
.5814 .3619 m .58043 .37064 L .60508 .38299 L p
1 g
F P
s
P
p
.002 w
.60508 .38299 m .59722 .398 L .61571 .41876 L p
1 g
F P
s
P
p
.002 w
.54301 .3091 m .52564 .31302 L .54048 .33546 L p
1 g
F P
s
P
p
.002 w
.54048 .33546 m .54922 .33356 L .54301 .3091 L p
1 g
F P
s
P
p
.002 w
.6145 .48648 m .57723 .49939 L .57643 .5257 L p
1 g
F P
s
P
p
.002 w
.57723 .49939 m .6145 .48648 L .60694 .46086 L p
1 g
F P
s
P
p
.002 w
.37476 .48048 m .41224 .52337 L .4274 .50505 L p
1 g
F P
s
P
p
.002 w
.4274 .50505 m .39252 .46498 L .37476 .48048 L p
1 g
F P
s
P
p
.002 w
.472 .53426 m .4274 .50505 L .41224 .52337 L p
1 g
F P
s
P
p
.002 w
.46612 .29458 m .4478 .3211 L .47448 .32733 L p
1 g
F P
s
P
p
.002 w
.47448 .32733 m .48877 .30707 L .46612 .29458 L p
1 g
F P
s
P
p
.002 w
.60508 .38299 m .60715 .36564 L .5814 .3619 L p
1 g
F P
s
P
p
.002 w
.57932 .353 m .5814 .3619 L .60715 .36564 L p
1 g
F P
s
P
p
.002 w
.41224 .52337 m .46004 .55473 L .472 .53426 L p
1 g
F P
s
P
p
.002 w
.5223 .54989 m .472 .53426 L .46004 .55473 L p
1 g
F P
s
P
p
.002 w
.56146 .31114 m .54301 .3091 L .54922 .33356 L p
1 g
F P
s
P
p
.002 w
.54922 .33356 m .55847 .33462 L .56146 .31114 L p
1 g
F P
s
P
p
.002 w
.50986 .29307 m .48877 .30707 L .51128 .32236 L p
1 g
F P
s
P
p
.002 w
.51128 .32236 m .52564 .31302 L .50986 .29307 L p
1 g
F P
s
P
p
.002 w
.36444 .36727 m .37072 .41763 L .39298 .40606 L p
1 g
F P
s
P
p
.002 w
.39298 .40606 m .3876 .36047 L .36444 .36727 L p
1 g
F P
s
P
p
.002 w
.60715 .36564 m .60311 .34787 L .57932 .353 L p
1 g
F P
s
P
p
.002 w
.57441 .34491 m .57932 .353 L .60311 .34787 L p
1 g
F P
s
P
p
.002 w
.63161 .44016 m .60694 .46086 L .6145 .48648 L p
1 g
F P
s
P
p
.002 w
.60694 .46086 m .63161 .44016 L .61571 .41876 L p
1 g
F P
s
P
p
.002 w
.57891 .31896 m .56146 .31114 L .55847 .33462 L p
1 g
F P
s
P
p
.002 w
.55847 .33462 m .56719 .33855 L .57891 .31896 L p
1 g
F P
s
P
p
.002 w
.35116 .42982 m .37476 .48048 L .39252 .46498 L p
1 g
F P
s
P
p
.002 w
.39252 .46498 m .37072 .41763 L .35116 .42982 L p
1 g
F P
s
P
p
.002 w
.60311 .34787 m .59334 .33169 L .57441 .34491 L p
1 g
F P
s
P
p
.002 w
.56719 .33855 m .57441 .34491 L .59334 .33169 L p
1 g
F P
s
P
p
.002 w
.59334 .33169 m .57891 .31896 L .56719 .33855 L p
1 g
F P
s
P
p
.002 w
.39748 .31669 m .3876 .36047 L .41302 .35555 L p
1 g
F P
s
P
p
.002 w
.41302 .35555 m .42195 .3175 L .39748 .31669 L p
1 g
F P
s
P
p
.002 w
.61571 .41876 m .62753 .39674 L .60508 .38299 L p
1 g
F P
s
P
p
.002 w
.60715 .36564 m .60508 .38299 L .62753 .39674 L p
1 g
F P
s
P
p
.002 w
.62753 .39674 m .61571 .41876 L .63161 .44016 L p
1 g
F P
s
P
p
.002 w
.53555 .2871 m .50986 .29307 L .52564 .31302 L p
1 g
F P
s
P
p
.002 w
.52564 .31302 m .54301 .3091 L .53555 .2871 L p
1 g
F P
s
P
p
.002 w
.44378 .28527 m .42195 .3175 L .4478 .3211 L p
1 g
F P
s
P
p
.002 w
.4478 .3211 m .46612 .29458 L .44378 .28527 L p
1 g
F P
s
P
p
.002 w
.46004 .55473 m .51391 .57167 L .5223 .54989 L p
1 g
F P
s
P
p
.002 w
.57369 .55019 m .5223 .54989 L .51391 .57167 L p
1 g
F P
s
P
p
.002 w
.5223 .54989 m .57369 .55019 L .57643 .5257 L p
1 g
F P
s
P
p
.002 w
.61933 .51123 m .57643 .5257 L .57369 .55019 L p
1 g
F P
s
P
p
.002 w
.57643 .5257 m .61933 .51123 L .6145 .48648 L p
1 g
F P
s
P
p
.002 w
.49344 .27613 m .46612 .29458 L .48877 .30707 L p
1 g
F P
s
P
p
.002 w
.48877 .30707 m .50986 .29307 L .49344 .27613 L p
1 g
F P
s
P
p
.002 w
.62753 .39674 m .6308 .37111 L .60715 .36564 L p
1 g
F P
s
P
p
.002 w
.60311 .34787 m .60715 .36564 L .6308 .37111 L p
1 g
F P
s
P
p
.002 w
.64452 .46178 m .6145 .48648 L .61933 .51123 L p
1 g
F P
s
P
p
.002 w
.6145 .48648 m .64452 .46178 L .63161 .44016 L p
1 g
F P
s
P
p
.002 w
.35967 .49516 m .39887 .53987 L .41224 .52337 L p
1 g
F P
s
P
p
.002 w
.41224 .52337 m .37476 .48048 L .35967 .49516 L p
1 g
F P
s
P
p
.002 w
.46004 .55473 m .41224 .52337 L .39887 .53987 L p
1 g
F P
s
P
p
.002 w
.56298 .29001 m .53555 .2871 L .54301 .3091 L p
1 g
F P
s
P
p
.002 w
.54301 .3091 m .56146 .31114 L .56298 .29001 L p
1 g
F P
s
P
p
.002 w
.3441 .3759 m .35116 .42982 L .37072 .41763 L p
1 g
F P
s
P
p
.002 w
.37072 .41763 m .36444 .36727 L .3441 .3759 L p
1 g
F P
s
P
p
.002 w
.39887 .53987 m .44875 .57264 L .46004 .55473 L p
1 g
F P
s
P
p
.002 w
.51391 .57167 m .46004 .55473 L .44875 .57264 L p
1 g
F P
s
P
p
.002 w
.63161 .44016 m .64724 .41165 L .62753 .39674 L p
1 g
F P
s
P
p
.002 w
.6308 .37111 m .62753 .39674 L .64724 .41165 L p
1 g
F P
s
P
p
.002 w
.64724 .41165 m .63161 .44016 L .64452 .46178 L p
1 g
F P
s
P
p
.002 w
.6308 .37111 m .62494 .34471 L .60311 .34787 L p
1 g
F P
s
P
p
.002 w
.59334 .33169 m .60311 .34787 L .62494 .34471 L p
1 g
F P
s
P
p
.002 w
.37498 .31881 m .36444 .36727 L .3876 .36047 L p
1 g
F P
s
P
p
.002 w
.3876 .36047 m .39748 .31669 L .37498 .31881 L p
1 g
F P
s
P
p
.002 w
.58898 .30161 m .56298 .29001 L .56146 .31114 L p
1 g
F P
s
P
p
.002 w
.56146 .31114 m .57891 .31896 L .58898 .30161 L p
1 g
F P
s
P
p
.002 w
.33484 .4424 m .35967 .49516 L .37476 .48048 L p
1 g
F P
s
P
p
.002 w
.37476 .48048 m .35116 .42982 L .33484 .4424 L p
1 g
F P
s
P
p
.002 w
.62494 .34471 m .61047 .32059 L .59334 .33169 L p
1 g
F P
s
P
p
.002 w
.57891 .31896 m .59334 .33169 L .61047 .32059 L p
1 g
F P
s
P
p
.002 w
.61047 .32059 m .58898 .30161 L .57891 .31896 L p
1 g
F P
s
P
p
.002 w
.42227 .27945 m .39748 .31669 L .42195 .3175 L p
1 g
F P
s
P
p
.002 w
.42195 .3175 m .44378 .28527 L .42227 .27945 L p
1 g
F P
s
P
p
.002 w
.52695 .26813 m .49344 .27613 L .50986 .29307 L p
1 g
F P
s
P
p
.002 w
.50986 .29307 m .53555 .2871 L .52695 .26813 L p
1 g
F P
s
P
p
.002 w
.4767 .26269 m .44378 .28527 L .46612 .29458 L p
1 g
F P
s
P
p
.002 w
.46612 .29458 m .49344 .27613 L .4767 .26269 L p
1 g
F P
s
P
p
.002 w
.51391 .57167 m .569 .57228 L .57369 .55019 L p
1 g
F P
s
P
p
.002 w
.62123 .53455 m .57369 .55019 L .569 .57228 L p
1 g
F P
s
P
p
.002 w
.57369 .55019 m .62123 .53455 L .61933 .51123 L p
1 g
F P
s
P
p
.002 w
.44875 .57264 m .50492 .59048 L .51391 .57167 L p
1 g
F P
s
P
p
.002 w
.569 .57228 m .51391 .57167 L .50492 .59048 L p
1 g
F P
s
P
p
.002 w
.64724 .41165 m .65174 .37825 L .6308 .37111 L p
1 g
F P
s
P
p
.002 w
.62494 .34471 m .6308 .37111 L .65174 .37825 L p
1 g
F P
s
P
p
.002 w
.65405 .48315 m .61933 .51123 L .62123 .53455 L p
1 g
F P
s
P
p
.002 w
.61933 .51123 m .65405 .48315 L .64452 .46178 L p
1 g
F P
s
P
p
.002 w
.56292 .27182 m .52695 .26813 L .53555 .2871 L p
1 g
F P
s
P
p
.002 w
.53555 .2871 m .56298 .29001 L .56292 .27182 L p
1 g
F P
s
P
p
.002 w
.66371 .42746 m .64452 .46178 L .65405 .48315 L p
1 g
F P
s
P
p
.002 w
.64452 .46178 m .66371 .42746 L .64724 .41165 L p
1 g
F P
s
P
p
.002 w
.65174 .37825 m .64724 .41165 L .66371 .42746 L p
1 g
F P
s
P
p
.002 w
.3272 .38624 m .33484 .4424 L .35116 .42982 L p
1 g
F P
s
P
p
.002 w
.35116 .42982 m .3441 .3759 L .3272 .38624 L p
1 g
F P
s
P
p
.002 w
.3477 .50866 m .38766 .55409 L .39887 .53987 L p
1 g
F P
s
P
p
.002 w
.39887 .53987 m .35967 .49516 L .3477 .50866 L p
1 g
F P
s
P
p
.002 w
.44875 .57264 m .39887 .53987 L .38766 .55409 L p
1 g
F P
s
P
p
.002 w
.35505 .32392 m .3441 .3759 L .36444 .36727 L p
1 g
F P
s
P
p
.002 w
.36444 .36727 m .37498 .31881 L .35505 .32392 L p
1 g
F P
s
P
p
.002 w
.38766 .55409 m .43841 .58747 L .44875 .57264 L p
1 g
F P
s
P
p
.002 w
.50492 .59048 m .44875 .57264 L .43841 .58747 L p
1 g
F P
s
P
p
.002 w
.65174 .37825 m .64424 .34366 L .62494 .34471 L p
1 g
F P
s
P
p
.002 w
.61047 .32059 m .62494 .34471 L .64424 .34366 L p
1 g
F P
s
P
p
.002 w
.40212 .27743 m .37498 .31881 L .39748 .31669 L p
1 g
F P
s
P
p
.002 w
.39748 .31669 m .42227 .27945 L .40212 .27743 L p
1 g
F P
s
P
p
.002 w
.59708 .28701 m .56292 .27182 L .56298 .29001 L p
1 g
F P
s
P
p
.002 w
.56298 .29001 m .58898 .30161 L .59708 .28701 L p
1 g
F P
s
P
p
.002 w
.3223 .4551 m .3477 .50866 L .35967 .49516 L p
1 g
F P
s
P
p
.002 w
.35967 .49516 m .33484 .4424 L .3223 .4551 L p
1 g
F P
s
P
p
.002 w
.51735 .25277 m .4767 .26269 L .49344 .27613 L p
1 g
F P
s
P
p
.002 w
.49344 .27613 m .52695 .26813 L .51735 .25277 L p
1 g
F P
s
P
p
.002 w
.46001 .25322 m .42227 .27945 L .44378 .28527 L p
1 g
F P
s
P
p
.002 w
.44378 .28527 m .4767 .26269 L .46001 .25322 L p
1 g
F P
s
P
p
.002 w
.64424 .34366 m .62532 .31196 L .61047 .32059 L p
1 g
F P
s
P
p
.002 w
.58898 .30161 m .61047 .32059 L .62532 .31196 L p
1 g
F P
s
P
p
.002 w
.62532 .31196 m .59708 .28701 L .58898 .30161 L p
1 g
F P
s
P
p
.002 w
.50492 .59048 m .56236 .59139 L .569 .57228 L p
1 g
F P
s
P
p
.002 w
.62003 .55586 m .569 .57228 L .56236 .59139 L p
1 g
F P
s
P
p
.002 w
.569 .57228 m .62003 .55586 L .62123 .53455 L p
1 g
F P
s
P
p
.002 w
.65984 .50379 m .62123 .53455 L .62003 .55586 L p
1 g
F P
s
P
p
.002 w
.62123 .53455 m .65984 .50379 L .65405 .48315 L p
1 g
F P
s
P
p
.002 w
.43841 .58747 m .4955 .60576 L .50492 .59048 L p
1 g
F P
s
P
p
.002 w
.56236 .59139 m .50492 .59048 L .4955 .60576 L p
1 g
F P
s
P
p
.002 w
.66371 .42746 m .66941 .38698 L .65174 .37825 L p
1 g
F P
s
P
p
.002 w
.64424 .34366 m .65174 .37825 L .66941 .38698 L p
1 g
F P
s
P
p
.002 w
.6764 .44383 m .65405 .48315 L .65984 .50379 L p
1 g
F P
s
P
p
.002 w
.65405 .48315 m .6764 .44383 L .66371 .42746 L p
1 g
F P
s
P
p
.002 w
.66941 .38698 m .66371 .42746 L .6764 .44383 L p
1 g
F P
s
P
p
.002 w
.56119 .25714 m .51735 .25277 L .52695 .26813 L p
1 g
F P
s
P
p
.002 w
.52695 .26813 m .56292 .27182 L .56119 .25714 L p
1 g
F P
s
P
p
.002 w
.33832 .33205 m .3272 .38624 L .3441 .3759 L p
1 g
F P
s
P
p
.002 w
.3441 .3759 m .35505 .32392 L .33832 .33205 L p
1 g
F P
s
P
p
.002 w
.3143 .39812 m .3223 .4551 L .33484 .4424 L p
1 g
F P
s
P
p
.002 w
.33484 .4424 m .3272 .38624 L .3143 .39812 L p
1 g
F P
s
P
p
.002 w
.33932 .5206 m .37898 .5656 L .38766 .55409 L p
1 g
F P
s
P
p
.002 w
.38766 .55409 m .3477 .50866 L .33932 .5206 L p
1 g
F P
s
P
p
.002 w
.43841 .58747 m .38766 .55409 L .37898 .5656 L p
1 g
F P
s
P
p
.002 w
.38389 .27944 m .35505 .32392 L .37498 .31881 L p
1 g
F P
s
P
p
.002 w
.37498 .31881 m .40212 .27743 L .38389 .27944 L p
1 g
F P
s
P
p
.002 w
.66941 .38698 m .66044 .34486 L .64424 .34366 L p
1 g
F P
s
P
p
.002 w
.62532 .31196 m .64424 .34366 L .66044 .34486 L p
1 g
F P
s
P
p
.002 w
.37898 .5656 m .4293 .59872 L .43841 .58747 L p
1 g
F P
s
P
p
.002 w
.4955 .60576 m .43841 .58747 L .4293 .59872 L p
1 g
F P
s
P
p
.002 w
.50693 .24157 m .46001 .25322 L .4767 .26269 L p
1 g
F P
s
P
p
.002 w
.4767 .26269 m .51735 .25277 L .50693 .24157 L p
1 g
F P
s
P
p
.002 w
.44379 .24816 m .40212 .27743 L .42227 .27945 L p
1 g
F P
s
P
p
.002 w
.42227 .27945 m .46001 .25322 L .44379 .24816 L p
1 g
F P
s
P
p
.002 w
.60293 .27564 m .56119 .25714 L .56292 .27182 L p
1 g
F P
s
P
p
.002 w
.56292 .27182 m .59708 .28701 L .60293 .27564 L p
1 g
F P
s
P
p
.002 w
.31403 .46762 m .33932 .5206 L .3477 .50866 L p
1 g
F P
s
P
p
.002 w
.3477 .50866 m .3223 .4551 L .31403 .46762 L p
1 g
F P
s
P
p
.002 w
.66044 .34486 m .63742 .30614 L .62532 .31196 L p
1 g
F P
s
P
p
.002 w
.59708 .28701 m .62532 .31196 L .63742 .30614 L p
1 g
F P
s
P
p
.002 w
.4955 .60576 m .55385 .6069 L .56236 .59139 L p
1 g
F P
s
P
p
.002 w
.61562 .57457 m .56236 .59139 L .55385 .6069 L p
1 g
F P
s
P
p
.002 w
.56236 .59139 m .61562 .57457 L .62003 .55586 L p
1 g
F P
s
P
p
.002 w
.63742 .30614 m .60293 .27564 L .59708 .28701 L p
1 g
F P
s
P
p
.002 w
.66159 .52318 m .62003 .55586 L .61562 .57457 L p
1 g
F P
s
P
p
.002 w
.62003 .55586 m .66159 .52318 L .65984 .50379 L p
1 g
F P
s
P
p
.002 w
.6764 .44383 m .68321 .39718 L .66941 .38698 L p
1 g
F P
s
P
p
.002 w
.66044 .34486 m .66941 .38698 L .68321 .39718 L p
1 g
F P
s
P
p
.002 w
.4293 .59872 m .48584 .61695 L .4955 .60576 L p
1 g
F P
s
P
p
.002 w
.55385 .6069 m .4955 .60576 L .48584 .61695 L p
1 g
F P
s
P
p
.002 w
.68484 .46042 m .65984 .50379 L .66159 .52318 L p
1 g
F P
s
P
p
.002 w
.65984 .50379 m .68484 .46042 L .6764 .44383 L p
1 g
F P
s
P
p
.002 w
.68321 .39718 m .6764 .44383 L .68484 .46042 L p
1 g
F P
s
P
p
.002 w
.32536 .34317 m .3143 .39812 L .3272 .38624 L p
1 g
F P
s
P
p
.002 w
.3272 .38624 m .33832 .33205 L .32536 .34317 L p
1 g
F P
s
P
p
.002 w
.55774 .24654 m .50693 .24157 L .51735 .25277 L p
1 g
F P
s
P
p
.002 w
.51735 .25277 m .56119 .25714 L .55774 .24654 L p
1 g
F P
s
P
p
.002 w
.30597 .41134 m .31403 .46762 L .3223 .4551 L p
1 g
F P
s
P
p
.002 w
.3223 .4551 m .3143 .39812 L .30597 .41134 L p
1 g
F P
s
P
p
.002 w
.36815 .28565 m .33832 .33205 L .35505 .32392 L p
1 g
F P
s
P
p
.002 w
.35505 .32392 m .38389 .27944 L .36815 .28565 L p
1 g
F P
s
P
p
.002 w
.33493 .5306 m .37321 .57395 L .37898 .5656 L p
1 g
F P
s
P
p
.002 w
.37898 .5656 m .33932 .5206 L .33493 .5306 L p
1 g
F P
s
P
p
.002 w
.4293 .59872 m .37898 .5656 L .37321 .57395 L p
1 g
F P
s
P
p
.002 w
.42849 .24789 m .38389 .27944 L .40212 .27743 L p
1 g
F P
s
P
p
.002 w
.40212 .27743 m .44379 .24816 L .42849 .24789 L p
1 g
F P
s
P
p
.002 w
.4959 .23508 m .44379 .24816 L .46001 .25322 L p
1 g
F P
s
P
p
.002 w
.46001 .25322 m .50693 .24157 L .4959 .23508 L p
1 g
F P
s
P
p
.002 w
.68321 .39718 m .67296 .34841 L .66044 .34486 L p
1 g
F P
s
P
p
.002 w
.63742 .30614 m .66044 .34486 L .67296 .34841 L p
1 g
F P
s
P
p
.002 w
.37321 .57395 m .42172 .60591 L .4293 .59872 L p
1 g
F P
s
P
p
.002 w
.48584 .61695 m .4293 .59872 L .42172 .60591 L p
1 g
F P
s
P
p
.002 w
.60624 .26799 m .55774 .24654 L .56119 .25714 L p
1 g
F P
s
P
p
.002 w
.56119 .25714 m .60293 .27564 L .60624 .26799 L p
1 g
F P
s
P
p
.002 w
.31051 .47963 m .33493 .5306 L .33932 .5206 L p
1 g
F P
s
P
p
.002 w
.33932 .5206 m .31403 .46762 L .31051 .47963 L p
1 g
F P
s
P
p
.002 w
.48584 .61695 m .54355 .61825 L .55385 .6069 L p
1 g
F P
s
P
p
.002 w
.60792 .59007 m .55385 .6069 L .54355 .61825 L p
1 g
F P
s
P
p
.002 w
.55385 .6069 m .60792 .59007 L .61562 .57457 L p
1 g
F P
s
P
p
.002 w
.65902 .54075 m .61562 .57457 L .60792 .59007 L p
1 g
F P
s
P
p
.002 w
.61562 .57457 m .65902 .54075 L .66159 .52318 L p
1 g
F P
s
P
p
.002 w
.67296 .34841 m .64631 .30344 L .63742 .30614 L p
1 g
F P
s
P
p
.002 w
.60293 .27564 m .63742 .30614 L .64631 .30344 L p
1 g
F P
s
P
p
.002 w
.64631 .30344 m .60624 .26799 L .60293 .27564 L p
1 g
F P
s
P
p
.002 w
.68484 .46042 m .69258 .40867 L .68321 .39718 L p
1 g
F P
s
P
p
.002 w
.67296 .34841 m .68321 .39718 L .69258 .40867 L p
1 g
F P
s
P
p
.002 w
.68858 .4768 m .66159 .52318 L .65902 .54075 L p
1 g
F P
s
P
p
.002 w
.66159 .52318 m .68858 .4768 L .68484 .46042 L p
1 g
F P
s
P
p
.002 w
.42172 .60591 m .47617 .62354 L .48584 .61695 L p
1 g
F P
s
P
p
.002 w
.54355 .61825 m .48584 .61695 L .47617 .62354 L p
1 g
F P
s
P
p
.002 w
.69258 .40867 m .68484 .46042 L .68858 .4768 L p
1 g
F P
s
P
p
.002 w
.31676 .35713 m .30597 .41134 L .3143 .39812 L p
1 g
F P
s
P
p
.002 w
.3143 .39812 m .32536 .34317 L .31676 .35713 L p
1 g
F P
s
P
p
.002 w
.55255 .24056 m .4959 .23508 L .50693 .24157 L p
1 g
F P
s
P
p
.002 w
.50693 .24157 m .55774 .24654 L .55255 .24056 L p
1 g
F P
s
P
p
.002 w
.35548 .29612 m .32536 .34317 L .33832 .33205 L p
1 g
F P
s
P
p
.002 w
.33832 .33205 m .36815 .28565 L .35548 .29612 L p
1 g
F P
s
P
p
.002 w
.30268 .42561 m .31051 .47963 L .31403 .46762 L p
1 g
F P
s
P
p
.002 w
.31403 .46762 m .30597 .41134 L .30268 .42561 L p
1 g
F P
s
P
p
.002 w
.41457 .2527 m .36815 .28565 L .38389 .27944 L p
1 g
F P
s
P
p
.002 w
.38389 .27944 m .42849 .24789 L .41457 .2527 L p
1 g
F P
s
P
p
.002 w
.48453 .23375 m .42849 .24789 L .44379 .24816 L p
1 g
F P
s
P
p
.002 w
.44379 .24816 m .4959 .23508 L .48453 .23375 L p
1 g
F P
s
P
p
.002 w
.3349 .53826 m .37066 .57872 L .37321 .57395 L p
1 g
F P
s
P
p
.002 w
.37321 .57395 m .33493 .5306 L .3349 .53826 L p
1 g
F P
s
P
p
.002 w
.42172 .60591 m .37321 .57395 L .37066 .57872 L p
1 g
F P
s
P
p
.002 w
.69258 .40867 m .68126 .35436 L .67296 .34841 L p
1 g
F P
s
P
p
.002 w
.64631 .30344 m .67296 .34841 L .68126 .35436 L p
1 g
F P
s
P
p
.002 w
.37066 .57872 m .41597 .60858 L .42172 .60591 L p
1 g
F P
s
P
p
.002 w
.47617 .62354 m .42172 .60591 L .41597 .60858 L p
1 g
F P
s
P
p
.002 w
.54355 .61825 m .59697 .60177 L .60792 .59007 L p
1 g
F P
s
P
p
.002 w
.65198 .55595 m .60792 .59007 L .59697 .60177 L p
1 g
F P
s
P
p
.002 w
.60792 .59007 m .65198 .55595 L .65902 .54075 L p
1 g
F P
s
P
p
.002 w
.47617 .62354 m .53165 .62488 L .54355 .61825 L p
1 g
F P
s
P
p
.002 w
.59697 .60177 m .54355 .61825 L .53165 .62488 L p
1 g
F P
s
P
p
.002 w
.60675 .26451 m .55255 .24056 L .55774 .24654 L p
1 g
F P
s
P
p
.002 w
.55774 .24654 m .60624 .26799 L .60675 .26451 L p
1 g
F P
s
P
p
.002 w
.31211 .49078 m .3349 .53826 L .33493 .5306 L p
1 g
F P
s
P
p
.002 w
.33493 .5306 m .31051 .47963 L .31211 .49078 L p
1 g
F P
s
P
p
.002 w
.68725 .49254 m .65902 .54075 L .65198 .55595 L p
1 g
F P
s
P
p
.002 w
.65902 .54075 m .68725 .49254 L .68858 .4768 L p
1 g
F P
s
P
p
.002 w
.68126 .35436 m .65153 .30414 L .64631 .30344 L p
1 g
F P
s
P
p
.002 w
.60624 .26799 m .64631 .30344 L .65153 .30414 L p
1 g
F P
s
P
p
.002 w
.68858 .4768 m .69701 .42123 L .69258 .40867 L p
1 g
F P
s
P
p
.002 w
.68126 .35436 m .69258 .40867 L .69701 .42123 L p
1 g
F P
s
P
p
.002 w
.65153 .30414 m .60675 .26451 L .60624 .26799 L p
1 g
F P
s
P
p
.002 w
.69701 .42123 m .68858 .4768 L .68725 .49254 L p
1 g
F P
s
P
p
.002 w
.41597 .60858 m .46675 .62506 L .47617 .62354 L p
1 g
F P
s
P
p
.002 w
.53165 .62488 m .47617 .62354 L .46675 .62506 L p
1 g
F P
s
P
p
.002 w
.31301 .37371 m .30268 .42561 L .30597 .41134 L p
1 g
F P
s
P
p
.002 w
.30597 .41134 m .31676 .35713 L .31301 .37371 L p
1 g
F P
s
P
p
.002 w
.34642 .31081 m .31676 .35713 L .32536 .34317 L p
1 g
F P
s
P
p
.002 w
.32536 .34317 m .35548 .29612 L .34642 .31081 L p
1 g
F P
s
P
p
.002 w
.54566 .23967 m .48453 .23375 L .4959 .23508 L p
1 g
F P
s
P
p
.002 w
.4959 .23508 m .55255 .24056 L .54566 .23967 L p
1 g
F P
s
P
p
.004 w
.22573 .35737 m
.29653 .37625 L
s
P
p
.002 w
.30484 .44058 m .31211 .49078 L .31051 .47963 L p
1 g
F P
s
P
p
.002 w
.31051 .47963 m .30268 .42561 L .30484 .44058 L p
1 g
F P
s
P
p
.002 w
.40254 .26276 m .35548 .29612 L .36815 .28565 L p
1 g
F P
s
P
p
.002 w
.36815 .28565 m .41457 .2527 L .40254 .26276 L p
1 g
F P
s
P
p
.002 w
.47312 .23796 m .41457 .2527 L .42849 .24789 L p
1 g
F P
s
P
p
.002 w
.42849 .24789 m .48453 .23375 L .47312 .23796 L p
1 g
F P
s
P
p
.002 w
.69701 .42123 m .68484 .3627 L .68126 .35436 L p
1 g
F P
s
P
p
.002 w
.65153 .30414 m .68126 .35436 L .68484 .3627 L p
1 g
F P
s
P
p
.002 w
.41597 .60858 m .37066 .57872 L .37163 .57955 L p
1 g
F P
s
P
p
.002 w
.33953 .54322 m .37163 .57955 L .37066 .57872 L p
1 g
F P
s
P
p
.002 w
.37066 .57872 m .3349 .53826 L .33953 .54322 L p
1 g
F P
s
P
p
.002 w
.53165 .62488 m .58288 .60914 L .59697 .60177 L p
1 g
F P
s
P
p
.002 w
.59697 .60177 m .64041 .56821 L .65198 .55595 L p
1 g
F P
s
P
p
.002 w
.64041 .56821 m .59697 .60177 L .58288 .60914 L p
1 g
F P
s
P
p
.002 w
.37163 .57955 m .41233 .60636 L .41597 .60858 L p
1 g
F P
s
P
p
.002 w
.46675 .62506 m .41597 .60858 L .41233 .60636 L p
1 g
F P
s
P
p
.002 w
.46675 .62506 m .51838 .62633 L .53165 .62488 L p
1 g
F P
s
P
p
.002 w
.58288 .60914 m .53165 .62488 L .51838 .62633 L p
1 g
F P
s
P
p
.002 w
.65198 .55595 m .6806 .50714 L .68725 .49254 L p
1 g
F P
s
P
p
.002 w
.6806 .50714 m .65198 .55595 L .64041 .56821 L p
1 g
F P
s
P
p
.002 w
.60426 .26557 m .54566 .23967 L .55255 .24056 L p
1 g
F P
s
P
p
.002 w
.55255 .24056 m .60675 .26451 L .60426 .26557 L p
1 g
F P
s
P
p
.002 w
.31913 .50068 m .33953 .54322 L .3349 .53826 L p
1 g
F P
s
P
p
.002 w
.3349 .53826 m .31211 .49078 L .31913 .50068 L p
1 g
F P
s
P
p
.002 w
.68725 .49254 m .69607 .43456 L .69701 .42123 L p
1 g
F P
s
P
p
.002 w
.68484 .3627 m .69701 .42123 L .69607 .43456 L p
1 g
F P
s
P
p
.002 w
.69607 .43456 m .68725 .49254 L .6806 .50714 L p
1 g
F P
s
P
p
.002 w
.68484 .3627 m .65271 .30845 L .65153 .30414 L p
1 g
F P
s
P
p
.002 w
.60675 .26451 m .65153 .30414 L .65271 .30845 L p
1 g
F P
s
P
p
.002 w
.65271 .30845 m .60426 .26557 L .60675 .26451 L p
1 g
F P
s
P
p
.002 w
.41233 .60636 m .45788 .62114 L .46675 .62506 L p
1 g
F P
s
P
p
.002 w
.51838 .62633 m .46675 .62506 L .45788 .62114 L p
1 g
F P
s
P
p
.002 w
.31449 .39255 m .30484 .44058 L .30268 .42561 L p
1 g
F P
s
P
p
.002 w
.30268 .42561 m .31301 .37371 L .31449 .39255 L p
1 g
F P
s
P
p
.004 w
.29653 .37625 m
.31104 .38012 L
s
P
p
.002 w
.34145 .32951 m .31301 .37371 L .31676 .35713 L p
1 g
F P
s
P
p
.002 w
.31676 .35713 m .34642 .31081 L .34145 .32951 L p
1 g
F P
s
P
p
.002 w
.53715 .24422 m .47312 .23796 L .48453 .23375 L p
1 g
F P
s
P
p
.002 w
.48453 .23375 m .54566 .23967 L .53715 .24422 L p
1 g
F P
s
P
p
.002 w
.39286 .27807 m .34642 .31081 L .35548 .29612 L p
1 g
F P
s
P
p
.002 w
.35548 .29612 m .40254 .26276 L .39286 .27807 L p
1 g
F P
s
P
p
.002 w
.31271 .45586 m .31913 .50068 L .31211 .49078 L p
1 g
F P
s
P
p
.002 w
.31211 .49078 m .30484 .44058 L .31271 .45586 L p
1 g
F P
s
P
p
.002 w
.46203 .24791 m .40254 .26276 L .41457 .2527 L p
1 g
F P
s
P
p
.002 w
.41457 .2527 m .47312 .23796 L .46203 .24791 L p
1 g
F P
s
P
p
.002 w
.51838 .62633 m .56587 .61169 L .58288 .60914 L p
1 g
F P
s
P
p
.002 w
.62438 .57699 m .58288 .60914 L .56587 .61169 L p
1 g
F P
s
P
p
.002 w
.58288 .60914 m .62438 .57699 L .64041 .56821 L p
1 g
F P
s
P
p
.002 w
.69607 .43456 m .68328 .37333 L .68484 .3627 L p
1 g
F P
s
P
p
.002 w
.65271 .30845 m .68484 .3627 L .68328 .37333 L p
1 g
F P
s
P
p
.002 w
.34897 .54515 m .37632 .57613 L .37163 .57955 L p
1 g
F P
s
P
p
.002 w
.37163 .57955 m .33953 .54322 L .34897 .54515 L p
1 g
F P
s
P
p
.002 w
.41233 .60636 m .37163 .57955 L .37632 .57613 L p
1 g
F P
s
P
p
.002 w
.45788 .62114 m .50405 .62223 L .51838 .62633 L p
1 g
F P
s
P
p
.002 w
.56587 .61169 m .51838 .62633 L .50405 .62223 L p
1 g
F P
s
P
p
.002 w
.66852 .52011 m .64041 .56821 L .62438 .57699 L p
1 g
F P
s
P
p
.002 w
.64041 .56821 m .66852 .52011 L .6806 .50714 L p
1 g
F P
s
P
p
.002 w
.37632 .57613 m .41104 .599 L .41233 .60636 L p
1 g
F P
s
P
p
.002 w
.45788 .62114 m .41233 .60636 L .41104 .599 L p
1 g
F P
s
P
p
.002 w
.59864 .27145 m .53715 .24422 L .54566 .23967 L p
1 g
F P
s
P
p
.002 w
.54566 .23967 m .60426 .26557 L .59864 .27145 L p
1 g
F P
s
P
p
.002 w
.68946 .44832 m .6806 .50714 L .66852 .52011 L p
1 g
F P
s
P
p
.002 w
.6806 .50714 m .68946 .44832 L .69607 .43456 L p
1 g
F P
s
P
p
.002 w
.68328 .37333 m .69607 .43456 L .68946 .44832 L p
1 g
F P
s
P
p
.002 w
.33168 .50895 m .34897 .54515 L .33953 .54322 L p
1 g
F P
s
P
p
.002 w
.33953 .54322 m .31913 .50068 L .33168 .50895 L p
1 g
F P
s
P
p
.002 w
.68328 .37333 m .64953 .31646 L .65271 .30845 L p
1 g
F P
s
P
p
.002 w
.60426 .26557 m .65271 .30845 L .64953 .31646 L p
1 g
F P
s
P
p
.002 w
.34097 .35183 m .31449 .39255 L .31301 .37371 L p
1 g
F P
s
P
p
.002 w
.31301 .37371 m .34145 .32951 L .34097 .35183 L p
1 g
F P
s
P
p
.002 w
.32147 .41317 m .31271 .45586 L .30484 .44058 L p
1 g
F P
s
P
p
.002 w
.30484 .44058 m .31449 .39255 L .32147 .41317 L p
1 g
F P
s
P
p
.002 w
.41104 .599 m .44984 .61155 L .45788 .62114 L p
1 g
F P
s
P
p
.002 w
.50405 .62223 m .45788 .62114 L .44984 .61155 L p
1 g
F P
s
P
p
.002 w
.64953 .31646 m .59864 .27145 L .60426 .26557 L p
1 g
F P
s
P
p
.002 w
.38598 .29842 m .34145 .32951 L .34642 .31081 L p
1 g
F P
s
P
p
.002 w
.34642 .31081 m .39286 .27807 L .38598 .29842 L p
1 g
F P
s
P
p
.002 w
.5272 .25443 m .46203 .24791 L .47312 .23796 L p
1 g
F P
s
P
p
.002 w
.47312 .23796 m .53715 .24422 L .5272 .25443 L p
1 g
F P
s
P
p
.002 w
.45162 .26363 m .39286 .27807 L .40254 .26276 L p
1 g
F P
s
P
p
.002 w
.40254 .26276 m .46203 .24791 L .45162 .26363 L p
1 g
F P
s
P
p
.002 w
.32637 .47095 m .33168 .50895 L .31913 .50068 L p
1 g
F P
s
P
p
.002 w
.31913 .50068 m .31271 .45586 L .32637 .47095 L p
1 g
F P
s
P
p
.002 w
.50405 .62223 m .54631 .60907 L .56587 .61169 L p
1 g
F P
s
P
p
.002 w
.60415 .58184 m .56587 .61169 L .54631 .60907 L p
1 g
F P
s
P
p
.002 w
.56587 .61169 m .60415 .58184 L .62438 .57699 L p
1 g
F P
s
P
p
.002 w
.65106 .53093 m .62438 .57699 L .60415 .58184 L p
1 g
F P
s
P
p
.002 w
.62438 .57699 m .65106 .53093 L .66852 .52011 L p
1 g
F P
s
P
p
.002 w
.68946 .44832 m .67631 .38607 L .68328 .37333 L p
1 g
F P
s
P
p
.002 w
.64953 .31646 m .68328 .37333 L .67631 .38607 L p
1 g
F P
s
P
p
.002 w
.44984 .61155 m .48903 .61239 L .50405 .62223 L p
1 g
F P
s
P
p
.002 w
.54631 .60907 m .50405 .62223 L .48903 .61239 L p
1 g
F P
s
P
p
.002 w
.36324 .5438 m .38484 .56831 L .37632 .57613 L p
1 g
F P
s
P
p
.002 w
.37632 .57613 m .34897 .54515 L .36324 .5438 L p
1 g
F P
s
P
p
.002 w
.41104 .599 m .37632 .57613 L .38484 .56831 L p
1 g
F P
s
P
p
.002 w
.67705 .46208 m .66852 .52011 L .65106 .53093 L p
1 g
F P
s
P
p
.002 w
.66852 .52011 m .67705 .46208 L .68946 .44832 L p
1 g
F P
s
P
p
.002 w
.38484 .56831 m .4123 .58639 L .41104 .599 L p
1 g
F P
s
P
p
.002 w
.44984 .61155 m .41104 .599 L .4123 .58639 L p
1 g
F P
s
P
p
.002 w
.67631 .38607 m .68946 .44832 L .67705 .46208 L p
1 g
F P
s
P
p
.002 w
.58988 .28227 m .5272 .25443 L .53715 .24422 L p
1 g
F P
s
P
p
.002 w
.53715 .24422 m .59864 .27145 L .58988 .28227 L p
1 g
F P
s
P
p
.002 w
.34968 .51522 m .36324 .5438 L .34897 .54515 L p
1 g
F P
s
P
p
.002 w
.34897 .54515 m .33168 .50895 L .34968 .51522 L p
1 g
F P
s
P
p
.002 w
.3452 .37721 m .32147 .41317 L .31449 .39255 L p
1 g
F P
s
P
p
.002 w
.31449 .39255 m .34097 .35183 L .3452 .37721 L p
1 g
F P
s
P
p
.004 w
.31104 .38012 m
.31866 .38215 L
s
P
p
.004 w
.31866 .38215 m
.32408 .3836 L
s
P
p
.004 w
.33846 .38743 m
.5 .43051 L
s
P
p
.004 w
.32408 .3836 m
.32543 .38396 L
s
P
p
.002 w
.33398 .43498 m .32637 .47095 L .31271 .45586 L p
1 g
F P
s
P
p
.002 w
.31271 .45586 m .32147 .41317 L .33398 .43498 L p
1 g
F P
s
P
p
.002 w
.67631 .38607 m .64181 .32817 L .64953 .31646 L p
1 g
F P
s
P
p
.002 w
.59864 .27145 m .64953 .31646 L .64181 .32817 L p
1 g
F P
s
P
p
.002 w
.38229 .3234 m .34097 .35183 L .34145 .32951 L p
1 g
F P
s
P
p
.002 w
.34145 .32951 m .38598 .29842 L .38229 .3234 L p
1 g
F P
s
P
p
.002 w
.4123 .58639 m .44296 .59624 L .44984 .61155 L p
1 g
F P
s
P
p
.002 w
.48903 .61239 m .44984 .61155 L .44296 .59624 L p
1 g
F P
s
P
p
.002 w
.64181 .32817 m .58988 .28227 L .59864 .27145 L p
1 g
F P
s
P
p
.002 w
.51605 .27029 m .45162 .26363 L .46203 .24791 L p
1 g
F P
s
P
p
.002 w
.46203 .24791 m .5272 .25443 L .51605 .27029 L p
1 g
F P
s
P
p
.002 w
.4423 .28492 m .38598 .29842 L .39286 .27807 L p
1 g
F P
s
P
p
.002 w
.39286 .27807 m .45162 .26363 L .4423 .28492 L p
1 g
F P
s
P
p
.002 w
.34566 .48536 m .34968 .51522 L .33168 .50895 L p
1 g
F P
s
P
p
.002 w
.33168 .50895 m .32637 .47095 L .34566 .48536 L p
1 g
F P
s
P
p
.002 w
.48903 .61239 m .52471 .60109 L .54631 .60907 L p
1 g
F P
s
P
p
.002 w
.58015 .58237 m .54631 .60907 L .52471 .60109 L p
1 g
F P
s
P
p
.002 w
.54631 .60907 m .58015 .58237 L .60415 .58184 L p
1 g
F P
s
P
p
.002 w
.62853 .53915 m .60415 .58184 L .58015 .58237 L p
1 g
F P
s
P
p
.002 w
.60415 .58184 m .62853 .53915 L .65106 .53093 L p
1 g
F P
s
P
p
.002 w
.44296 .59624 m .4738 .59678 L .48903 .61239 L p
1 g
F P
s
P
p
.002 w
.52471 .60109 m .48903 .61239 L .4738 .59678 L p
1 g
F P
s
P
p
.002 w
.67705 .46208 m .66383 .40063 L .67631 .38607 L p
1 g
F P
s
P
p
.002 w
.64181 .32817 m .67631 .38607 L .66383 .40063 L p
1 g
F P
s
P
p
.002 w
.65893 .4754 m .65106 .53093 L .62853 .53915 L p
1 g
F P
s
P
p
.002 w
.65106 .53093 m .65893 .4754 L .67705 .46208 L p
1 g
F P
s
P
p
.002 w
.66383 .40063 m .67705 .46208 L .65893 .4754 L p
1 g
F P
s
P
p
.002 w
.38216 .53901 m .39714 .55606 L .38484 .56831 L p
1 g
F P
s
P
p
.002 w
.38484 .56831 m .36324 .5438 L .38216 .53901 L p
1 g
F P
s
P
p
.002 w
.4123 .58639 m .38484 .56831 L .39714 .55606 L p
1 g
F P
s
P
p
.002 w
.35423 .40491 m .33398 .43498 L .32147 .41317 L p
1 g
F P
s
P
p
.002 w
.32147 .41317 m .3452 .37721 L .35423 .40491 L p
1 g
F P
s
P
p
.002 w
.39714 .55606 m .41624 .56862 L .4123 .58639 L p
1 g
F P
s
P
p
.002 w
.44296 .59624 m .4123 .58639 L .41624 .56862 L p
1 g
F P
s
P
p
.002 w
.35184 .45728 m .34566 .48536 L .32637 .47095 L p
1 g
F P
s
P
p
.002 w
.32637 .47095 m .33398 .43498 L .35184 .45728 L p
1 g
F P
s
P
p
.002 w
.57807 .29797 m .51605 .27029 L .5272 .25443 L p
1 g
F P
s
P
p
.002 w
.5272 .25443 m .58988 .28227 L .57807 .29797 L p
1 g
F P
s
P
p
.002 w
.37283 .51917 m .38216 .53901 L .36324 .5438 L p
1 g
F P
s
P
p
.002 w
.36324 .5438 m .34968 .51522 L .37283 .51917 L p
1 g
F P
s
P
p
.002 w
.38206 .35234 m .3452 .37721 L .34097 .35183 L p
1 g
F P
s
P
p
.002 w
.34097 .35183 m .38229 .3234 L .38206 .35234 L p
1 g
F P
s
P
p
.002 w
.41624 .56862 m .43753 .5754 L .44296 .59624 L p
1 g
F P
s
P
p
.002 w
.4738 .59678 m .44296 .59624 L .43753 .5754 L p
1 g
F P
s
P
p
.002 w
.66383 .40063 m .62954 .34341 L .64181 .32817 L p
1 g
F P
s
P
p
.002 w
.58988 .28227 m .64181 .32817 L .62954 .34341 L p
1 g
F P
s
P
p
.002 w
.43444 .31129 m .38229 .3234 L .38598 .29842 L p
1 g
F P
s
P
p
.002 w
.38598 .29842 m .4423 .28492 L .43444 .31129 L p
1 g
F P
s
P
p
.002 w
.50403 .29157 m .4423 .28492 L .45162 .26363 L p
1 g
F P
s
P
p
.002 w
.45162 .26363 m .51605 .27029 L .50403 .29157 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.62954 .34341 m .57807 .29797 L .58988 .28227 L p
1 g
F P
s
P
p
.002 w
.37019 .49855 m .37283 .51917 L .34968 .51522 L p
1 g
F P
s
P
p
.002 w
.34968 .51522 m .34566 .48536 L .37019 .49855 L p
1 g
F P
s
P
p
.002 w
.4738 .59678 m .50169 .58774 L .52471 .60109 L p
1 g
F P
s
P
p
.002 w
.55304 .57837 m .52471 .60109 L .50169 .58774 L p
1 g
F P
s
P
p
.002 w
.52471 .60109 m .55304 .57837 L .58015 .58237 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.60146 .54435 m .58015 .58237 L .55304 .57837 L p
1 g
F P
s
P
p
.002 w
.58015 .58237 m .60146 .54435 L .62853 .53915 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.43753 .5754 m .45885 .57567 L .4738 .59678 L p
1 g
F P
s
P
p
.002 w
.50169 .58774 m .4738 .59678 L .45885 .57567 L p
1 g
F P
s
P
p
.002 w
.63543 .48779 m .62853 .53915 L .60146 .54435 L p
1 g
F P
s
P
p
.002 w
.62853 .53915 m .63543 .48779 L .65893 .4754 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.65893 .4754 m .64596 .4166 L .66383 .40063 L p
1 g
F P
s
P
p
.002 w
.62954 .34341 m .66383 .40063 L .64596 .4166 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.3679 .43401 m .35184 .45728 L .33398 .43498 L p
1 g
F P
s
P
p
.002 w
.33398 .43498 m .35423 .40491 L .3679 .43401 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.64596 .4166 m .65893 .4754 L .63543 .48779 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.37464 .47929 m .37019 .49855 L .34566 .48536 L p
1 g
F P
s
P
p
.002 w
.34566 .48536 m .35184 .45728 L .37464 .47929 L p
1 g
F P
s
P
p
.002 w
.38543 .38433 m .35423 .40491 L .3452 .37721 L p
1 g
F P
s
P
p
.002 w
.3452 .37721 m .38206 .35234 L .38543 .38433 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.4053 .53076 m .41301 .53956 L .39714 .55606 L p
1 g
F P
s
P
p
.002 w
.39714 .55606 m .38216 .53901 L .4053 .53076 L p
1 g
F P
s
P
p
.002 w
.41624 .56862 m .39714 .55606 L .41301 .53956 L p
1 g
F P
s
P
p
.002 w
.41301 .53956 m .42285 .54602 L .41624 .56862 L p
1 g
F P
s
P
p
.002 w
.43753 .5754 m .41624 .56862 L .42285 .54602 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.56348 .31825 m .50403 .29157 L .51605 .27029 L p
1 g
F P
s
P
p
.002 w
.51605 .27029 m .57807 .29797 L .56348 .31825 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.40056 .52054 m .4053 .53076 L .38216 .53901 L p
1 g
F P
s
P
p
.002 w
.38216 .53901 m .37283 .51917 L .40056 .52054 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.42839 .34199 m .38206 .35234 L .38229 .3234 L p
1 g
F P
s
P
p
.002 w
.38229 .3234 m .43444 .31129 L .42839 .34199 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.004 w
.4478 .49862 m
.5 .43051 L
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.42285 .54602 m .43382 .54948 L .43753 .5754 L p
1 g
F P
s
P
p
.002 w
.45885 .57567 m .43753 .5754 L .43382 .54948 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.45885 .57567 m .43753 .55335 L .45079 .56308 L 1 g
F
P
p
.002 w
.45289 .56462 m .45442 .56746 L p
.45079 .56308 L 1 g
F P
s
P
p
.002 w
.45442 .56746 m .45885 .57567 L p
.45079 .56308 L 1 g
F P
s
P
p
.002 w
.45079 .56308 m .45146 .56129 L p
.44375 .55459 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56308 L p
1 g
F P
s
P
p
.002 w
.46565 .5734 m .45885 .57567 L .45289 .56462 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56308 L .45801 .56837 L 1 g
F
P
p
.46872 .57265 m .45801 .56837 L .45803 .56838 L 1 g
F
P
p
.002 w
.46826 .57477 m .46872 .57265 L p
.45005 .5652 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.47801 .56928 m .46565 .5734 L p
.44475 .54954 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43824 .54757 L p
1 g
F P
s
P
p
.45146 .56129 m .43824 .54757 L .43897 .54866 L 1 g
F
P
p
.002 w
.43382 .54948 m .43327 .54014 L p
.43824 .54757 L 1 g
F P
s
P
p
.002 w
.43953 .54951 m .43883 .5495 L p
.43824 .54757 L 1 g
F P
s
P
p
.002 w
.43883 .5495 m .43382 .54948 L p
.43824 .54757 L 1 g
F P
s
P
p
.002 w
.43824 .54757 m .43925 .54566 L p
.43521 .53767 L 1 g
F P
s
P
p
.45146 .56129 m .43897 .54866 L .44375 .55459 L 1 g
F
P
p
.43897 .54866 m .43812 .5478 L .43953 .54951 L 1 g
F
P
p
.43897 .54866 m .43953 .54951 L .44375 .55459 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.42285 .54602 m .43074 .52298 L p
.43221 .53559 L 1 g
F P
s
P
p
.002 w
.43249 .52876 m .43346 .52734 L p
.4331 .51715 L 1 g
F P
s
P
p
.002 w
.43307 .51752 m .43205 .51918 L .43383 .50953 L p
1 g
F P
s
P
p
.002 w
.43383 .50953 m .43392 .50899 L p
.43388 .50941 L 1 g
F P
s
P
p
.43388 .50941 m .43307 .51752 L .43383 .50953 L 1 g
F
P
p
.002 w
.43388 .50941 m .43485 .50826 L p
.4384 .49997 L 1 g
F P
s
P
p
.4331 .51715 m .4331 .51717 L .43249 .52876 L 1 g
F
P
p
.4331 .51714 m .43309 .51727 L .43249 .52876 L 1 g
F
P
p
.4331 .51707 m .43308 .51736 L .43249 .52876 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4267 .48511 m .4362 .48652 L p
.43307 .51111 L 1 g
F P
s
P
p
.002 w
.43135 .51473 m .4267 .48511 L p
.43307 .51111 L 1 g
F P
s
P
p
.002 w
.4362 .48652 m .43802 .48679 L .43392 .50899 L p
1 g
F P
s
P
p
.002 w
.43392 .50899 m .43205 .51918 L p
.4362 .48652 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50941 L p
1 g
F P
s
P
p
.43346 .52734 m .43388 .50941 L .43332 .51493 L 1 g
F
P
p
.43346 .52734 m .43327 .51014 L .43305 .51547 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43802 .48679 m .44347 .48935 L p
.44244 .49151 L 1 g
F P
s
P
p
.43631 .49743 m .44244 .49151 L .43462 .50786 L 1 g
F
P
p
.43802 .48679 m .44244 .49151 L .43631 .49743 L 1 g
F
P
p
.002 w
.44325 .49079 m .44166 .49233 L p
.43485 .50826 L 1 g
F P
s
P
p
.002 w
.44331 .49067 m .44339 .4905 L p
.44244 .49151 L 1 g
F P
s
P
p
.002 w
.44244 .49151 m .44339 .4905 L p
.4507 .48349 L 1 g
F P
s
P
p
.002 w
.44884 .49188 m .44428 .48973 L p
.4484 .48573 L 1 g
F P
s
P
p
.4507 .48349 m .44428 .48973 L .44244 .49151 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.44603 .45214 m .46753 .46217 L .45948 .47497 L p
1 g
F P
s
P
p
.4484 .48573 m .45767 .47673 L .44884 .49188 L 1 g
F
P
p
.002 w
.45867 .47626 m .44884 .49188 L p
.45767 .47673 L 1 g
F P
s
P
p
.002 w
.45794 .49982 m .44884 .49188 L .45867 .47626 L p
1 g
F P
s
P
p
.46467 .47341 m .45794 .49982 L .45867 .47626 L 1 g
F
P
p
.002 w
.45767 .47673 m .45826 .47608 L p
.46833 .47166 L 1 g
F P
s
P
p
.002 w
.48558 .47795 m .45794 .49982 L p
.46467 .47341 L 1 g
F P
s
P
p
.002 w
.47485 .46857 m .48558 .47795 L p
.46467 .47341 L 1 g
F P
s
P
p
.46833 .47166 m .47041 .47075 L .45867 .47626 L 1 g
F
P
p
.46833 .47166 m .45867 .47626 L .45767 .47673 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46753 .46217 m .48742 .43118 L p
.48618 .46292 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48558 .47795 m .47485 .46857 L p
.47752 .46723 L 1 g
F P
s
P
p
.48606 .46595 m .48558 .47795 L .47752 .46723 L 1 g
F
P
p
.002 w
.47752 .46723 m .47786 .46667 L p
.48847 .46559 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48742 .43118 m .51394 .4544 L .5031 .4634 L p
1 g
F P
s
P
p
.002 w
.4981 .49763 m .48558 .47795 L .50212 .46421 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53217 .48339 m .52195 .46714 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47672 L p
1 g
F P
s
P
p
.52214 .46667 m .54233 .47672 L .53195 .47175 L 1 g
F
P
p
.53411 .47278 m .53217 .48339 L .52246 .4672 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.56518 .46753 m .57502 .50785 L .5662 .50957 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56613 .50943 L p
1 g
F P
s
P
p
.55661 .4905 m .56613 .50943 L .566 .50915 L 1 g
F
P
p
.56596 .4996 m .5662 .50957 L .56613 .50943 L 1 g
F
P
p
.56482 .4985 m .56613 .50943 L .55715 .49108 L 1 g
F
P
p
.56596 .4996 m .56613 .50943 L .56482 .4985 L 1 g
F
P
p
.56515 .50826 m .56663 .51785 L .56659 .51714 L 1 g
F
P
p
.002 w
.56613 .50943 m .56515 .50826 L p
.56659 .51714 L 1 g
F P
s
P
p
.56836 .51428 m .56653 .51605 L .5662 .50957 L 1 g
F
P
p
.56653 .51605 m .56615 .50963 L .5662 .50957 L 1 g
F
P
p
.56659 .51714 m .56615 .50958 L .56613 .50943 L 1 g
F
P
p
.002 w
.57502 .50785 m .57062 .54622 L .56826 .5461 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .549 .56252 L p
1 g
F P
s
P
p
.002 w
.55304 .57837 m .53922 .57434 L p
.56644 .54997 L 1 g
F P
s
P
p
.002 w
.57062 .54622 m .56996 .54743 L p
.56644 .54997 L 1 g
F P
s
P
p
.002 w
.56996 .54743 m .55304 .57837 L p
.56644 .54997 L 1 g
F P
s
P
p
.002 w
.549 .56252 m .54854 .56129 L p
.54183 .56769 L 1 g
F P
s
P
p
.56075 .54566 m .549 .56252 L .55635 .55364 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53168 .57449 L p
1 g
F P
s
P
p
.55304 .57837 m .51004 .58622 L .53168 .57449 L 1 g
F
P
p
.002 w
.5345 .57296 m .53565 .5733 L p
.53168 .57449 L 1 g
F P
s
P
p
.002 w
.53565 .5733 m .55304 .57837 L p
.53168 .57449 L 1 g
F P
s
P
p
.002 w
.53168 .57449 m .53128 .57265 L p
.52208 .57737 L 1 g
F P
s
P
p
.54854 .56129 m .53168 .57449 L .53356 .57347 L 1 g
F
P
p
.54854 .56129 m .53178 .57492 L .54183 .56769 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58071 L p
1 g
F P
s
P
p
.52997 .575 m .51916 .57988 L .51999 .578 L 1 g
F
P
p
.002 w
.50169 .58774 m .51019 .58079 L p
.51916 .57988 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58071 L .52208 .57737 L 1 g
F
P
p
.002 w
.51095 .58071 m .51079 .57862 L p
.50468 .5808 L 1 g
F P
s
P
p
.002 w
.51019 .58079 m .50169 .58774 L .49283 .58083 L p
1 g
F P
s
P
p
.50468 .5808 m .50255 .58156 L .51019 .58079 L 1 g
F
P
p
.50468 .5808 m .51019 .58079 L .51095 .58071 L 1 g
F
P
p
.51079 .57862 m .49784 .58121 L .50255 .58156 L 1 g
F
P
p
.50169 .58774 m .4715 .57923 L .48103 .57995 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58055 L p
1 g
F P
s
P
p
.002 w
.49283 .58083 m .49435 .58202 L p
.48907 .58055 L 1 g
F P
s
P
p
.002 w
.49435 .58202 m .50169 .58774 L p
.4646 .57375 L 1 g
F P
s
P
p
.002 w
.48907 .58055 m .48889 .583 L p
.49784 .58121 L 1 g
F P
s
P
p
.51079 .57862 m .48907 .58055 L .49784 .58121 L 1 g
F
P
p
.002 w
.48907 .58055 m .48921 .57862 L p
.47915 .57779 L 1 g
F P
s
P
p
.002 w
.45885 .57567 m .4646 .57375 L p
.47071 .57606 L 1 g
F P
s
P
p
.48103 .57995 m .47643 .57906 L .47071 .57606 L 1 g
F
P
p
.47643 .57906 m .45885 .57567 L .47071 .57606 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4646 .57375 m .47801 .56928 L .49283 .58083 L p
1 g
F P
s
P
p
.48907 .58055 m .4646 .57375 L .49283 .58083 L 1 g
F
P
p
.002 w
.52362 .56979 m .51019 .58079 L p
.47801 .56928 L 1 g
F P
s
P
p
.002 w
.49283 .58083 m .47801 .56928 L p
.51019 .58079 L 1 g
F P
s
P
p
.002 w
.51019 .58079 m .52362 .56979 L p
.51916 .57988 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51111 .583 L p
.52208 .57737 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52362 .56979 m .5345 .57296 L p
.52997 .575 L 1 g
F P
s
P
p
.52997 .575 m .51999 .578 L .52362 .56979 L 1 g
F
P
p
.002 w
.51105 .5822 m .51095 .58071 L p
.50255 .58156 L 1 g
F P
s
P
p
.51004 .58622 m .50169 .58774 L .5345 .57296 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53168 .57449 L p
1 g
F P
s
P
p
.52208 .57737 m .51111 .583 L .53168 .57449 L 1 g
F
P
p
.002 w
.53168 .57449 m .53178 .57492 L p
.53356 .57347 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.57062 .54622 m .53922 .57434 L .55672 .55319 L 1 g
F
P
p
.56075 .54566 m .55635 .55364 L .55678 .55311 L 1 g
F
P
p
.002 w
.56281 .54583 m .57062 .54622 L p
.55984 .55162 L 1 g
F P
s
P
p
.55984 .55162 m .55672 .55319 L .56161 .54728 L 1 g
F
P
p
.55984 .55162 m .56161 .54728 L .56281 .54583 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56161 .54728 L p
1 g
F P
s
P
p
.56654 .52734 m .56161 .54728 L .56221 .5458 L 1 g
F
P
p
.56723 .52835 m .5678 .53818 L .56419 .53893 L 1 g
F
P
p
.56654 .52734 m .56221 .5458 L .56483 .53671 L 1 g
F
P
p
.002 w
.56281 .54583 m .56221 .5458 L p
.5678 .53818 L 1 g
F P
s
P
p
.002 w
.56079 .54574 m .56075 .54566 L p
.56071 .54573 L 1 g
F P
s
P
p
.56071 .54573 m .55117 .56367 L .56079 .54574 L 1 g
F
P
p
.002 w
.56172 .54749 m .56079 .54574 L p
.55117 .56367 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56221 .5458 m .53702 .54457 L p
.56419 .53893 L 1 g
F P
s
P
p
.5678 .53818 m .56221 .5458 L .56419 .53893 L 1 g
F
P
p
.002 w
.52362 .56979 m .53702 .54457 L .56221 .5458 L p
1 g
F P
s
P
p
.002 w
.56221 .5458 m .56281 .54583 L p
.562 .54633 L 1 g
F P
s
P
p
.562 .54633 m .52362 .56979 L .56221 .5458 L 1 g
F
P
p
.55672 .55319 m .52362 .56979 L .56281 .54583 L 1 g
F
P
p
.002 w
.56826 .5461 m .56281 .54583 L p
.5678 .53818 L 1 g
F P
s
P
p
.56395 .54151 m .56221 .5458 L .56257 .5491 L 1 g
F
P
p
.002 w
.56161 .54728 m .56172 .54749 L p
.56221 .5458 L 1 g
F P
s
P
p
.002 w
.56172 .54749 m .56257 .5491 L p
.56221 .5458 L 1 g
F P
s
P
p
.56483 .53671 m .56221 .5458 L .56395 .54151 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.57502 .50785 m .56826 .5461 L .56723 .52835 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56723 .52835 L p
1 g
F P
s
P
p
.002 w
.56723 .52835 m .56654 .52734 L p
.56483 .53671 L 1 g
F P
s
P
p
.56483 .53671 m .56257 .5491 L .56723 .52835 L 1 g
F
P
p
.57242 .51036 m .56723 .52835 L .56653 .51605 L 1 g
F
P
p
.57502 .50785 m .56723 .52835 L .57242 .51036 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56653 .51605 m .56723 .52835 L .53702 .54457 L 1 g
F
P
p
.56723 .52835 m .56419 .53893 L .53702 .54457 L 1 g
F
P
p
.002 w
.54998 .56518 m .55117 .56367 L p
.55678 .55311 L 1 g
F P
s
P
p
.55635 .55364 m .54998 .56518 L .55678 .55311 L 1 g
F
P
p
.002 w
.55117 .56367 m .56257 .5491 L .56172 .54749 L p
1 g
F P
s
P
p
.55672 .55319 m .549 .56252 L .52362 .56979 L 1 g
F
P
p
.002 w
.53922 .57434 m .5345 .57296 L p
.549 .56252 L 1 g
F P
s
P
p
.002 w
.5345 .57296 m .52362 .56979 L p
.549 .56252 L 1 g
F P
s
P
p
.002 w
.53178 .57492 m .5322 .57686 L p
.54183 .56769 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .549 .56252 L p
1 g
F P
s
P
p
.54183 .56769 m .5322 .57686 L .549 .56252 L 1 g
F
P
p
.002 w
.549 .56252 m .54998 .56518 L p
.55635 .55364 L 1 g
F P
s
P
p
.002 w
.56615 .50958 m .5662 .50957 L p
.56615 .50963 L 1 g
F P
s
P
p
.55661 .4905 m .56614 .50944 L .56359 .50386 L 1 g
F
P
p
.002 w
.5662 .50957 m .57502 .50785 L p
.56836 .51428 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55715 .49108 L p
1 g
F P
s
P
p
.54174 .47608 m .55715 .49108 L .54926 .48343 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.5662 .50957 m .5401 .51467 L p
.555 .48667 L 1 g
F P
s
P
p
.002 w
.5684 .52835 m .56713 .51061 L .56614 .50944 L p
1 g
F P
s
P
p
.002 w
.56614 .50944 m .56613 .50943 L p
.56615 .50958 L 1 g
F P
s
P
p
.56615 .50958 m .5684 .52835 L .56614 .50944 L 1 g
F
P
p
.56659 .51714 m .5684 .52835 L .56615 .50958 L 1 g
F
P
p
.56653 .51605 m .53702 .54457 L .56615 .50963 L 1 g
F
P
p
.002 w
.53702 .54457 m .5401 .51467 L .56615 .50958 L p
1 g
F P
s
P
p
.56615 .50963 m .53702 .54457 L .56615 .50958 L 1 g
F
P
p
.002 w
.56854 .53025 m .5684 .52835 L p
.56659 .51714 L 1 g
F P
s
P
p
.56663 .51785 m .56854 .53025 L .56659 .51714 L 1 g
F
P
p
.002 w
.5401 .51467 m .53217 .48339 L .54356 .47792 L p
1 g
F P
s
P
p
.54174 .47608 m .54926 .48343 L .54883 .48302 L 1 g
F
P
p
.55418 .4882 m .5401 .51467 L .54356 .47792 L 1 g
F
P
p
.002 w
.54356 .47792 m .53217 .48339 L p
.53474 .46932 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54356 .47792 m .56518 .46753 L p
.55418 .4882 L 1 g
F P
s
P
p
.54883 .48302 m .5582 .49219 L .55598 .49003 L 1 g
F
P
p
.54926 .48343 m .5582 .49219 L .54883 .48302 L 1 g
F
P
p
.002 w
.55715 .49108 m .5582 .49219 L p
.54926 .48343 L 1 g
F P
s
P
p
.56518 .46753 m .56596 .4996 L .555 .48667 L 1 g
F
P
p
.56596 .4996 m .55715 .49108 L .555 .48667 L 1 g
F
P
p
.002 w
.56613 .50943 m .56614 .50944 L p
.566 .50915 L 1 g
F P
s
P
p
.002 w
.56614 .50944 m .56713 .51061 L p
.56359 .50386 L 1 g
F P
s
P
p
.002 w
.54189 .43007 m .56518 .46753 L .54356 .47792 L p
1 g
F P
s
P
p
.54189 .43007 m .54356 .47792 L .53474 .46932 L 1 g
F
P
p
.002 w
.5582 .49219 m .55834 .49233 L p
.55598 .49003 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52246 .4672 L p
1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53195 .47175 L 1 g
F P
s
P
p
.53195 .47175 m .54302 .47747 L .52246 .4672 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.53484 .46875 m .52246 .4672 L .51394 .4544 L 1 g
F
P
p
.002 w
.52195 .46714 m .52179 .46688 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52179 .46688 m .51394 .4544 L p
.52246 .4672 L 1 g
F P
s
P
p
.53484 .46875 m .53411 .47278 L .52246 .4672 L 1 g
F
P
p
.002 w
.54233 .47672 m .54302 .47747 L p
.53195 .47175 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52247 .46721 L p
.52221 .46717 L 1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .52221 .46717 L 1 g
F
P
p
.002 w
.51394 .4544 m .54189 .43007 L p
.53484 .46875 L 1 g
F P
s
P
p
.5 .4634 m .52247 .46721 L .51313 .46584 L 1 g
F
P
p
.002 w
.52195 .46714 m .53217 .48339 L p
.50992 .46536 L 1 g
F P
s
P
p
.51117 .46555 m .52271 .46761 L .51709 .46668 L 1 g
F
P
p
.5 .4634 m .51313 .46584 L .51117 .46555 L 1 g
F
P
p
.51313 .46584 m .52271 .46761 L .51117 .46555 L 1 g
F
P
p
.002 w
.53217 .48339 m .4981 .49763 L p
.50992 .46536 L 1 g
F P
s
P
p
.50992 .46536 m .4981 .49763 L .50212 .46421 L 1 g
F
P
p
.002 w
.50212 .46421 m .48558 .47795 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51709 .46668 L 1 g
F P
s
P
p
.51709 .46668 m .52282 .46778 L .5 .46386 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46386 L p
1 g
F P
s
P
p
.48742 .43118 m .5031 .4634 L .5 .46386 L 1 g
F
P
p
.47786 .46667 m .5 .46386 L .48847 .46559 L 1 g
F
P
p
.48623 .46159 m .5 .46386 L .48606 .46595 L 1 g
F
P
p
.48742 .43118 m .5 .46386 L .48623 .46159 L 1 g
F
P
p
.002 w
.51394 .4544 m .52195 .46714 L p
.50992 .46536 L 1 g
F P
s
P
p
.002 w
.50212 .46421 m .51394 .4544 L p
.50992 .46536 L 1 g
F P
s
P
p
.002 w
.52247 .46721 m .52271 .46761 L p
.51313 .46584 L 1 g
F P
s
P
p
.002 w
.52271 .46761 m .52282 .46778 L p
.51709 .46668 L 1 g
F P
s
P
p
.48606 .46595 m .5 .46386 L .48558 .47795 L 1 g
F
P
p
.002 w
.5031 .4634 m .50212 .46421 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .46442 L p
.48847 .46559 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46723 L p
1 g
F P
s
P
p
.48847 .46559 m .5 .46442 L .47752 .46723 L 1 g
F
P
p
.48618 .46292 m .48606 .46595 L .47752 .46723 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47752 .46723 L p
1 g
F P
s
P
p
.45826 .47608 m .47752 .46723 L .47368 .46915 L 1 g
F
P
p
.002 w
.47485 .46857 m .46753 .46217 L p
.48618 .46292 L 1 g
F P
s
P
p
.002 w
.47752 .46723 m .47736 .46749 L p
.47368 .46915 L 1 g
F P
s
P
p
.002 w
.47736 .46749 m .47718 .46778 L p
.47041 .47075 L 1 g
F P
s
P
p
.45826 .47608 m .47736 .46749 L .47041 .47075 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.44244 .49151 m .44884 .49188 L .43462 .50786 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45699 .47747 L p
1 g
F P
s
P
p
.44339 .4905 m .45699 .47747 L .45682 .47763 L 1 g
F
P
p
.002 w
.44347 .48935 m .44428 .48973 L p
.44244 .49151 L 1 g
F P
s
P
p
.002 w
.44428 .48973 m .44884 .49188 L p
.44244 .49151 L 1 g
F P
s
P
p
.002 w
.45699 .47747 m .45698 .47747 L p
.45682 .47763 L 1 g
F P
s
P
p
.44603 .45214 m .45948 .47497 L .45767 .47673 L 1 g
F
P
p
.44808 .48122 m .45767 .47673 L .4484 .48573 L 1 g
F
P
p
.44603 .45214 m .45767 .47673 L .44808 .48122 L 1 g
F
P
p
.002 w
.46753 .46217 m .47485 .46857 L p
.46467 .47341 L 1 g
F P
s
P
p
.002 w
.45867 .47626 m .46753 .46217 L p
.46467 .47341 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45766 .47674 L p
1 g
F P
s
P
p
.002 w
.45766 .47674 m .45767 .47673 L p
.45805 .47655 L 1 g
F P
s
P
p
.45805 .47655 m .47718 .46778 L .45766 .47674 L 1 g
F
P
p
.47041 .47075 m .47718 .46778 L .45767 .47673 L 1 g
F
P
p
.002 w
.45948 .47497 m .45867 .47626 L p
.45767 .47673 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44231 .49165 L p
1 g
F P
s
P
p
.002 w
.44231 .49165 m .44244 .49151 L p
.44426 .48976 L 1 g
F P
s
P
p
.44426 .48976 m .45698 .47747 L .44231 .49165 L 1 g
F
P
p
.4507 .48349 m .45682 .47763 L .44428 .48973 L 1 g
F
P
p
.002 w
.43802 .48679 m .44603 .45214 L p
.4484 .48573 L 1 g
F P
s
P
p
.002 w
.44428 .48973 m .43802 .48679 L p
.4484 .48573 L 1 g
F P
s
P
p
.45682 .47763 m .45698 .47747 L .44244 .49151 L 1 g
F
P
p
.002 w
.44884 .49188 m .43307 .51752 L p
.43462 .50786 L 1 g
F P
s
P
p
.002 w
.43392 .50899 m .43802 .48679 L p
.43307 .51752 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43388 .50941 L p
1 g
F P
s
P
p
.002 w
.43388 .50941 m .43388 .50941 L p
.43389 .5094 L 1 g
F P
s
P
p
.43389 .5094 m .44166 .49233 L .43388 .50941 L 1 g
F
P
p
.002 w
.43205 .51918 m .43135 .51473 L p
.43307 .51111 L 1 g
F P
s
P
p
.002 w
.43388 .50941 m .43327 .51014 L p
.43332 .51493 L 1 g
F P
s
P
p
.002 w
.43327 .51014 m .43287 .51061 L p
.43305 .51547 L 1 g
F P
s
P
p
.4331 .51694 m .43305 .51748 L .43249 .52876 L 1 g
F
P
p
.002 w
.43297 .51849 m .43205 .51918 L .43307 .51752 L p
1 g
F P
s
P
p
.43309 .51674 m .43302 .51768 L .43249 .52876 L 1 g
F
P
p
.002 w
.43293 .51892 m .43205 .51918 L .43297 .51849 L p
1 g
F P
s
P
p
.43308 .51646 m .43298 .51809 L .43249 .52876 L 1 g
F
P
p
.43307 .51613 m .43292 .51896 L .43249 .52876 L 1 g
F
P
p
.002 w
.43291 .51921 m .43205 .51918 L .43293 .51892 L p
1 g
F P
s
P
p
.43306 .51577 m .43282 .52091 L .43249 .52876 L 1 g
F
P
p
.002 w
.43289 .51947 m .43205 .51918 L .43291 .51921 L p
1 g
F P
s
P
p
.002 w
.43287 .51975 m .43205 .51918 L .43289 .51947 L p
1 g
F P
s
P
p
.002 w
.43285 .52015 m .43205 .51918 L .43287 .51975 L p
1 g
F P
s
P
p
.43305 .51547 m .43254 .52757 L .43249 .52876 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43249 .52876 L p
1 g
F P
s
P
p
.43925 .54566 m .43249 .52876 L .43249 .52878 L 1 g
F
P
p
.43925 .54566 m .43249 .52876 L .43521 .53767 L 1 g
F
P
p
.002 w
.43263 .52924 m .43254 .52757 L p
.43824 .54757 L 1 g
F P
s
P
p
.002 w
.43254 .52757 m .43205 .51918 L p
.43275 .52242 L 1 g
F P
s
P
p
.43824 .54757 m .43254 .52757 L .43275 .52242 L 1 g
F
P
p
.4384 .49997 m .44166 .49233 L .43388 .50941 L 1 g
F
P
p
.4331 .51715 m .4331 .51714 L .4331 .51717 L 1 g
F
P
p
.002 w
.44884 .49188 m .45794 .49982 L .43297 .51849 L p
1 g
F P
s
P
p
.002 w
.43307 .51752 m .44884 .49188 L p
.43297 .51849 L 1 g
F P
s
P
p
.4331 .51714 m .4331 .51707 L .43309 .51727 L 1 g
F
P
p
.4331 .51707 m .4331 .51694 L .43308 .51736 L 1 g
F
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.45794 .49982 m .4643 .50971 L .43293 .51892 L p
1 g
F P
s
P
p
.002 w
.43297 .51849 m .45794 .49982 L p
.43293 .51892 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.4643 .50971 m .46722 .52044 L .43291 .51921 L p
1 g
F P
s
P
p
.002 w
.43293 .51892 m .4643 .50971 L p
.43291 .51921 L 1 g
F P
s
P
p
.4331 .51694 m .43309 .51674 L .43305 .51748 L 1 g
F
P
p
.43309 .51674 m .43308 .51646 L .43302 .51768 L 1 g
F
P
p
.002 w
.46722 .52044 m .46641 .53083 L .43289 .51947 L p
1 g
F P
s
P
p
.002 w
.43291 .51921 m .46722 .52044 L p
.43289 .51947 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.46641 .53083 m .462 .53972 L .43287 .51975 L p
1 g
F P
s
P
p
.002 w
.43289 .51947 m .46641 .53083 L p
.43287 .51975 L 1 g
F P
s
P
p
.43308 .51646 m .43307 .51613 L .43298 .51809 L 1 g
F
P
p
.43307 .51613 m .43306 .51577 L .43292 .51896 L 1 g
F
P
p
.002 w
.462 .53972 m .4545 .54618 L .43285 .52015 L p
1 g
F P
s
P
p
.002 w
.43287 .51975 m .462 .53972 L p
.43285 .52015 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.4545 .54618 m .44475 .54954 L .43281 .52101 L p
1 g
F P
s
P
p
.002 w
.43281 .52101 m .43205 .51918 L .43285 .52015 L p
1 g
F P
s
P
p
.002 w
.43285 .52015 m .4545 .54618 L p
.43281 .52101 L 1 g
F P
s
P
p
.43306 .51577 m .43305 .51547 L .43282 .52091 L 1 g
F
P
p
.002 w
.44475 .54954 m .43953 .54951 L p
.43277 .5221 L 1 g
F P
s
P
p
.002 w
.43205 .51918 m .43281 .52101 L p
.43277 .5221 L 1 g
F P
s
P
p
.002 w
.43281 .52101 m .44475 .54954 L p
.43277 .5221 L 1 g
F P
s
P
p
.43277 .5221 m .43275 .52242 L .43205 .51918 L 1 g
F
P
p
.002 w
.43074 .52298 m .43205 .51918 L .43254 .52757 L p
1 g
F P
s
P
p
.002 w
.43254 .52757 m .43263 .52924 L p
.43249 .52876 L 1 g
F P
s
P
p
.43249 .52876 m .43074 .52298 L .43254 .52757 L 1 g
F
P
p
.002 w
.43263 .52924 m .43382 .54948 L p
.43074 .52298 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43249 .52876 L p
1 g
F P
s
P
p
.002 w
.43249 .52876 m .43249 .52876 L p
.43249 .5287 L 1 g
F P
s
P
p
.43249 .5287 m .43287 .51061 L .43249 .52876 L 1 g
F
P
p
.43305 .51547 m .43304 .51532 L .43254 .52757 L 1 g
F
P
p
.43953 .54951 m .43824 .54757 L .43275 .52242 L 1 g
F
P
p
.43953 .54951 m .43275 .52242 L .43277 .5221 L 1 g
F
P
p
.43304 .51532 m .43287 .51061 L .43249 .52876 L 1 g
F
P
p
.002 w
.43382 .54948 m .43166 .5488 L p
.43221 .53559 L 1 g
F P
s
P
p
.002 w
.43166 .5488 m .42285 .54602 L p
.43221 .53559 L 1 g
F P
s
P
p
.002 w
.43249 .52876 m .43249 .52876 L p
.43249 .52878 L 1 g
F P
s
P
p
.002 w
.43327 .54014 m .43263 .52924 L p
.43824 .54757 L 1 g
F P
s
P
p
.002 w
.43249 .52876 m .43146 .53025 L p
.43521 .53767 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43824 .54757 L p
1 g
F P
s
P
p
.43521 .53767 m .43146 .53025 L .43824 .54757 L 1 g
F
P
p
.002 w
.43824 .54757 m .43812 .5478 L p
.43897 .54866 L 1 g
F P
s
P
p
.002 w
.43382 .54948 m .43953 .54951 L p
.45048 .56271 L 1 g
F P
s
P
p
.002 w
.43812 .5478 m .43743 .5491 L p
.44375 .55459 L 1 g
F P
s
P
p
.002 w
.44475 .54954 m .45289 .56462 L p
.45048 .56271 L 1 g
F P
s
P
p
.002 w
.43953 .54951 m .44475 .54954 L p
.45048 .56271 L 1 g
F P
s
P
p
.002 w
.45289 .56462 m .44475 .54954 L p
.46565 .5734 L 1 g
F P
s
P
p
.45801 .56837 m .45289 .56462 L .45002 .56518 L 1 g
F
P
p
.002 w
.45079 .56308 m .45077 .56316 L p
.45289 .56462 L 1 g
F P
s
P
p
.002 w
.45077 .56316 m .45002 .56518 L p
.45289 .56462 L 1 g
F P
s
P
p
.43753 .55335 m .43382 .54948 L .45289 .56462 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56308 L p
1 g
F P
s
P
p
.44375 .55459 m .43743 .5491 L .45079 .56308 L 1 g
F
P
p
.002 w
.45002 .56518 m .45005 .5652 L p
.45803 .56838 L 1 g
F P
s
P
p
.45801 .56837 m .45002 .56518 L .45803 .56838 L 1 g
F
P
p
.002 w
.45005 .5652 m .4678 .57686 L .46826 .57477 L p
1 g
F P
s
P
p
.4715 .57923 m .45885 .57567 L .48103 .57995 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51105 .5822 L p
1 g
F P
s
P
p
.49784 .58121 m .48889 .583 L .51105 .5822 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58055 L p
1 g
F P
s
P
p
.47915 .57779 m .4678 .57686 L .48907 .58055 L 1 g
F
P
p
.002 w
.55304 .57837 m .57062 .54622 L .60146 .54435 L p
1 g
F P
s
P
p
.002 w
.49152 .31775 m .43444 .31129 L .4423 .28492 L p
1 g
F P
s
P
p
.002 w
.4423 .28492 m .50403 .29157 L .49152 .31775 L p
1 g
F P
s
P
p
.002 w
.64596 .4166 m .61289 .36183 L .62954 .34341 L p
1 g
F P
s
P
p
.002 w
.57807 .29797 m .62954 .34341 L .61289 .36183 L p
1 g
F P
s
P
p
.002 w
.3993 .50998 m .40056 .52054 L .37283 .51917 L p
1 g
F P
s
P
p
.002 w
.37283 .51917 m .37019 .49855 L .3993 .50998 L p
1 g
F P
s
P
p
.002 w
.61289 .36183 m .56348 .31825 L .57807 .29797 L p
1 g
F P
s
P
p
.002 w
.60717 .49876 m .60146 .54435 L .57062 .54622 L p
1 g
F P
s
P
p
.002 w
.60146 .54435 m .60717 .49876 L .63543 .48779 L p
1 g
F P
s
P
p
.002 w
.38585 .46348 m .37464 .47929 L .35184 .45728 L p
1 g
F P
s
P
p
.002 w
.35184 .45728 m .3679 .43401 L .38585 .46348 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39239 .41828 m .3679 .43401 L .35423 .40491 L p
1 g
F P
s
P
p
.002 w
.35423 .40491 m .38543 .38433 L .39239 .41828 L p
1 g
F P
s
P
p
.002 w
.62309 .43348 m .63543 .48779 L .60717 .49876 L p
1 g
F P
s
P
p
.002 w
.63543 .48779 m .62309 .43348 L .64596 .4166 L p
1 g
F P
s
P
p
.002 w
.61289 .36183 m .64596 .4166 L .62309 .43348 L p
1 g
F P
s
P
p
.002 w
.40168 .50019 m .3993 .50998 L .37019 .49855 L p
1 g
F P
s
P
p
.002 w
.37019 .49855 m .37464 .47929 L .40168 .50019 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.42445 .37601 m .38543 .38433 L .38206 .35234 L p
1 g
F P
s
P
p
.002 w
.38206 .35234 m .42839 .34199 L .42445 .37601 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.47801 .56928 m .49291 .55678 L .52362 .56979 L p
1 g
F P
s
P
p
.002 w
.53702 .54457 m .52362 .56979 L .49291 .55678 L p
1 g
F P
s
P
p
.002 w
.44475 .54954 m .4545 .54618 L .47801 .56928 L p
1 g
F P
s
P
p
.002 w
.49291 .55678 m .47801 .56928 L .4545 .54618 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41301 .53956 m .4053 .53076 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.42285 .54602 m .41301 .53956 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.5465 .34259 m .49152 .31775 L .50403 .29157 L p
1 g
F P
s
P
p
.002 w
.50403 .29157 m .56348 .31825 L .5465 .34259 L p
1 g
F P
s
P
p
.002 w
.4053 .53076 m .40056 .52054 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.47899 .34803 m .42839 .34199 L .43444 .31129 L p
1 g
F P
s
P
p
.002 w
.43444 .31129 m .49152 .31775 L .47899 .34803 L p
1 g
F P
s
P
p
.002 w
.57062 .54622 m .57502 .50785 L .60717 .49876 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40749 .49224 m .40168 .50019 L .37464 .47929 L p
1 g
F P
s
P
p
.002 w
.37464 .47929 m .38585 .46348 L .40749 .49224 L p
1 g
F P
s
P
p
.002 w
.40056 .52054 m .3993 .50998 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.40275 .45294 m .38585 .46348 L .3679 .43401 L p
1 g
F P
s
P
p
.002 w
.3679 .43401 m .39239 .41828 L .40275 .45294 L p
1 g
F P
s
P
p
.002 w
.62309 .43348 m .59228 .3829 L .61289 .36183 L p
1 g
F P
s
P
p
.002 w
.56348 .31825 m .61289 .36183 L .59228 .3829 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59228 .3829 m .5465 .34259 L .56348 .31825 L p
1 g
F P
s
P
p
.002 w
.3993 .50998 m .40168 .50019 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.59586 .45067 m .60717 .49876 L .57502 .50785 L p
1 g
F P
s
P
p
.002 w
.60717 .49876 m .59586 .45067 L .62309 .43348 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.4545 .54618 m .462 .53972 L .49291 .55678 L p
1 g
F P
s
P
p
.002 w
.50185 .53939 m .49291 .55678 L .462 .53972 L p
1 g
F P
s
P
p
.002 w
.49291 .55678 m .50185 .53939 L .53702 .54457 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42282 .41213 m .39239 .41828 L .38543 .38433 L p
1 g
F P
s
P
p
.002 w
.38543 .38433 m .42445 .37601 L .42282 .41213 L p
1 g
F P
s
P
p
.002 w
.59228 .3829 m .62309 .43348 L .59586 .45067 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.40168 .50019 m .40749 .49224 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.5401 .51467 m .53702 .54457 L .50185 .53939 L p
1 g
F P
s
P
p
.002 w
.41614 .48701 m .40749 .49224 L .38585 .46348 L p
1 g
F P
s
P
p
.002 w
.38585 .46348 m .40275 .45294 L .41614 .48701 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.41614 .48701 m .4267 .48511 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.40749 .49224 m .41614 .48701 L .43205 .51918 L closepath p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.462 .53972 m .46641 .53083 L .50185 .53939 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.46692 .38138 m .42445 .37601 L .42839 .34199 L p
1 g
F P
s
P
p
.002 w
.42839 .34199 m .47899 .34803 L .46692 .38138 L p
1 g
F P
s
P
p
.002 w
.52769 .3702 m .47899 .34803 L .49152 .31775 L p
1 g
F P
s
P
p
.002 w
.49152 .31775 m .5465 .34259 L .52769 .3702 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.5037 .51893 m .50185 .53939 L .46641 .53083 L p
1 g
F P
s
P
p
.002 w
.50185 .53939 m .5037 .51893 L .5401 .51467 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.42358 .44897 m .40275 .45294 L .39239 .41828 L p
1 g
F P
s
P
p
.002 w
.39239 .41828 m .42282 .41213 L .42358 .44897 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57502 .50785 m .56518 .46753 L .59586 .45067 L p
1 g
F P
s
P
p
.002 w
.46641 .53083 m .46722 .52044 L .5037 .51893 L p
1 g
F P
s
P
p
.002 w
.59586 .45067 m .56833 .40593 L .59228 .3829 L p
1 g
F P
s
P
p
.002 w
.5465 .34259 m .59228 .3829 L .56833 .40593 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.4267 .48511 m .41614 .48701 L .40275 .45294 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.40275 .45294 m .42358 .44897 L .4267 .48511 L p
1 g
F P
s
P
p
.002 w
.56833 .40593 m .52769 .3702 L .5465 .34259 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56833 .40593 m .59586 .45067 L .56518 .46753 L p
1 g
F P
s
P
p
.002 w
.46722 .52044 m .4643 .50971 L .4981 .49763 L p
1 g
F P
s
P
p
.002 w
.4981 .49763 m .5037 .51893 L .46722 .52044 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.53217 .48339 m .5401 .51467 L .5037 .51893 L p
1 g
F P
s
P
p
.002 w
.45578 .41654 m .42282 .41213 L .42445 .37601 L p
1 g
F P
s
P
p
.002 w
.42445 .37601 m .46692 .38138 L .45578 .41654 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43802 .48679 m .4267 .48511 L .42358 .44897 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.5037 .51893 m .4981 .49763 L .53217 .48339 L p
1 g
F P
s
P
p
.002 w
.4643 .50971 m .45794 .49982 L .48558 .47795 L p
1 g
F P
s
P
p
.002 w
.48558 .47795 m .4981 .49763 L .4643 .50971 L p
1 g
F P
s
P
p
.002 w
.50775 .40012 m .46692 .38138 L .47899 .34803 L p
1 g
F P
s
P
p
.002 w
.47899 .34803 m .52769 .3702 L .50775 .40012 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.42358 .44897 m .44603 .45214 L .43802 .48679 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.44603 .45214 m .42358 .44897 L .42282 .41213 L p
1 g
F P
s
P
p
.002 w
.42282 .41213 m .45578 .41654 L .44603 .45214 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56518 .46753 m .54189 .43007 L .56833 .40593 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52769 .3702 m .56833 .40593 L .54189 .43007 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54189 .43007 m .50775 .40012 L .52769 .3702 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.48742 .43118 m .45578 .41654 L .46692 .38138 L p
1 g
F P
s
P
p
.002 w
.46692 .38138 m .50775 .40012 L .48742 .43118 L p
1 g
F P
s
P
p
.002 w
.46753 .46217 m .44603 .45214 L .45578 .41654 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45578 .41654 m .48742 .43118 L .46753 .46217 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50775 .40012 m .54189 .43007 L .51394 .4544 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51394 .4544 m .48742 .43118 L .50775 .40012 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.3911 .57261 m
.40951 .54859 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .22573 .35737 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .3911 .57261 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.477519)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.477519)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46462 .41639 m .47881 .43941 L .50051 .42085 L p
1 g
F P
s
P
p
.002 w
.50051 .42085 m .49087 .40515 L .46462 .41639 L p
1 g
F P
s
P
p
.002 w
.51452 .43291 m .50051 .42085 L .47881 .43941 L p
1 g
F P
s
P
p
.002 w
.49087 .40515 m .50051 .42085 L .52223 .4025 L p
1 g
F P
s
P
p
.002 w
.50051 .42085 m .51452 .43291 L .52936 .40862 L p
1 g
F P
s
P
p
.002 w
.52936 .40862 m .52223 .4025 L .50051 .42085 L p
1 g
F P
s
P
p
.002 w
.47881 .43941 m .49936 .45711 L .51452 .43291 L p
1 g
F P
s
P
p
.002 w
.53145 .44007 m .51452 .43291 L .49936 .45711 L p
1 g
F P
s
P
p
.002 w
.51452 .43291 m .53145 .44007 L .53796 .41223 L p
1 g
F P
s
P
p
.002 w
.53796 .41223 m .52936 .40862 L .51452 .43291 L p
1 g
F P
s
P
p
.002 w
.43907 .42805 m .45752 .45785 L .47881 .43941 L p
1 g
F P
s
P
p
.002 w
.47881 .43941 m .46462 .41639 L .43907 .42805 L p
1 g
F P
s
P
p
.002 w
.49936 .45711 m .47881 .43941 L .45752 .45785 L p
1 g
F P
s
P
p
.002 w
.45752 .45785 m .48414 .48079 L .49936 .45711 L p
1 g
F P
s
P
p
.002 w
.52418 .46768 m .49936 .45711 L .48414 .48079 L p
1 g
F P
s
P
p
.002 w
.49936 .45711 m .52418 .46768 L .53145 .44007 L p
1 g
F P
s
P
p
.002 w
.45827 .39039 m .46462 .41639 L .49087 .40515 L p
1 g
F P
s
P
p
.002 w
.49087 .40515 m .48662 .38743 L .45827 .39039 L p
1 g
F P
s
P
p
.002 w
.48662 .38743 m .49087 .40515 L .51735 .39451 L p
1 g
F P
s
P
p
.002 w
.52223 .4025 m .51735 .39451 L .49087 .40515 L p
1 g
F P
s
P
p
.002 w
.54953 .44154 m .53145 .44007 L .52418 .46768 L p
1 g
F P
s
P
p
.002 w
.53145 .44007 m .54953 .44154 L .54713 .41294 L p
1 g
F P
s
P
p
.002 w
.54713 .41294 m .53796 .41223 L .53145 .44007 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .51735 .39451 L .52223 .4025 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .52223 .4025 L .52936 .40862 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .52936 .40862 L .53796 .41223 L closepath p
1 g
F P
s
P
p
.002 w
.4307 .39436 m .43907 .42805 L .46462 .41639 L p
1 g
F P
s
P
p
.002 w
.46462 .41639 m .45827 .39039 L .4307 .39436 L p
1 g
F P
s
P
p
.002 w
.51735 .39451 m .51523 .38551 L .48662 .38743 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .51523 .38551 L .51735 .39451 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .53796 .41223 L .54713 .41294 L closepath p
1 g
F P
s
P
p
.002 w
.48414 .48079 m .51627 .49457 L .52418 .46768 L p
1 g
F P
s
P
p
.002 w
.55073 .46997 m .52418 .46768 L .51627 .49457 L p
1 g
F P
s
P
p
.002 w
.52418 .46768 m .55073 .46997 L .54953 .44154 L p
1 g
F P
s
P
p
.002 w
.46052 .36407 m .45827 .39039 L .48662 .38743 L p
1 g
F P
s
P
p
.002 w
.48662 .38743 m .48825 .36954 L .46052 .36407 L p
1 g
F P
s
P
p
.002 w
.48825 .36954 m .48662 .38743 L .51523 .38551 L p
1 g
F P
s
P
p
.002 w
.51523 .38551 m .51611 .37645 L .48825 .36954 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .51611 .37645 L .51523 .38551 L closepath p
1 g
F P
s
P
p
.002 w
.5559 .41066 m .54713 .41294 L .54953 .44154 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .54713 .41294 L .5559 .41066 L closepath p
1 g
F P
s
P
p
.002 w
.41469 .43991 m .43702 .47582 L .45752 .45785 L p
1 g
F P
s
P
p
.002 w
.45752 .45785 m .43907 .42805 L .41469 .43991 L p
1 g
F P
s
P
p
.002 w
.48414 .48079 m .45752 .45785 L .43702 .47582 L p
1 g
F P
s
P
p
.002 w
.56687 .43714 m .54953 .44154 L .55073 .46997 L p
1 g
F P
s
P
p
.002 w
.54953 .44154 m .56687 .43714 L .5559 .41066 L p
1 g
F P
s
P
p
.002 w
.43702 .47582 m .46913 .50351 L .48414 .48079 L p
1 g
F P
s
P
p
.002 w
.51627 .49457 m .48414 .48079 L .46913 .50351 L p
1 g
F P
s
P
p
.002 w
.49565 .35338 m .48825 .36954 L .51611 .37645 L p
1 g
F P
s
P
p
.002 w
.51611 .37645 m .51991 .36831 L .49565 .35338 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .51991 .36831 L .51611 .37645 L closepath p
1 g
F P
s
P
p
.002 w
.43343 .36018 m .4307 .39436 L .45827 .39039 L p
1 g
F P
s
P
p
.002 w
.45827 .39039 m .46052 .36407 L .43343 .36018 L p
1 g
F P
s
P
p
.002 w
.56331 .40561 m .5559 .41066 L .56687 .43714 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .5559 .41066 L .56331 .40561 L closepath p
1 g
F P
s
P
p
.002 w
.40444 .39928 m .41469 .43991 L .43907 .42805 L p
1 g
F P
s
P
p
.002 w
.43907 .42805 m .4307 .39436 L .40444 .39928 L p
1 g
F P
s
P
p
.002 w
.47125 .34021 m .46052 .36407 L .48825 .36954 L p
1 g
F P
s
P
p
.002 w
.48825 .36954 m .49565 .35338 L .47125 .34021 L p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .56331 .40561 L .56856 .39833 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .56856 .39833 L .57105 .38959 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .57105 .38959 L .5705 .38034 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .5705 .38034 L .56696 .37161 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .56696 .37161 L .5608 .36435 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .5608 .36435 L .55271 .35937 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .55271 .35937 L .54358 .35722 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .54358 .35722 L .53442 .35812 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .53442 .35812 L .52624 .36196 L closepath p
1 g
F P
s
P
p
.002 w
.54359 .38468 m .52624 .36196 L .51991 .36831 L closepath p
1 g
F P
s
P
p
.002 w
.51627 .49457 m .5507 .4977 L .55073 .46997 L p
1 g
F P
s
P
p
.002 w
.57627 .46365 m .55073 .46997 L .5507 .4977 L p
1 g
F P
s
P
p
.002 w
.55073 .46997 m .57627 .46365 L .56687 .43714 L p
1 g
F P
s
P
p
.002 w
.50809 .34073 m .49565 .35338 L .51991 .36831 L p
1 g
F P
s
P
p
.002 w
.51991 .36831 m .52624 .36196 L .50809 .34073 L p
1 g
F P
s
P
p
.002 w
.46913 .50351 m .50786 .52023 L .51627 .49457 L p
1 g
F P
s
P
p
.002 w
.5507 .4977 m .51627 .49457 L .50786 .52023 L p
1 g
F P
s
P
p
.002 w
.5816 .42726 m .56687 .43714 L .57627 .46365 L p
1 g
F P
s
P
p
.002 w
.56687 .43714 m .5816 .42726 L .56331 .40561 L p
1 g
F P
s
P
p
.002 w
.56856 .39833 m .56331 .40561 L .5816 .42726 L p
1 g
F P
s
P
p
.002 w
.52429 .333 m .50809 .34073 L .52624 .36196 L p
1 g
F P
s
P
p
.002 w
.52624 .36196 m .53442 .35812 L .52429 .333 L p
1 g
F P
s
P
p
.002 w
.5816 .42726 m .59209 .4129 L .56856 .39833 L p
1 g
F P
s
P
p
.002 w
.57105 .38959 m .56856 .39833 L .59209 .4129 L p
1 g
F P
s
P
p
.002 w
.48949 .32141 m .47125 .34021 L .49565 .35338 L p
1 g
F P
s
P
p
.002 w
.49565 .35338 m .50809 .34073 L .48949 .32141 L p
1 g
F P
s
P
p
.002 w
.44719 .32906 m .43343 .36018 L .46052 .36407 L p
1 g
F P
s
P
p
.002 w
.46052 .36407 m .47125 .34021 L .44719 .32906 L p
1 g
F P
s
P
p
.002 w
.39199 .45175 m .41772 .49299 L .43702 .47582 L p
1 g
F P
s
P
p
.002 w
.43702 .47582 m .41469 .43991 L .39199 .45175 L p
1 g
F P
s
P
p
.002 w
.46913 .50351 m .43702 .47582 L .41772 .49299 L p
1 g
F P
s
P
p
.002 w
.40752 .35796 m .40444 .39928 L .4307 .39436 L p
1 g
F P
s
P
p
.002 w
.4307 .39436 m .43343 .36018 L .40752 .35796 L p
1 g
F P
s
P
p
.002 w
.41772 .49299 m .45462 .52483 L .46913 .50351 L p
1 g
F P
s
P
p
.002 w
.50786 .52023 m .46913 .50351 L .45462 .52483 L p
1 g
F P
s
P
p
.002 w
.5425 .33111 m .52429 .333 L .53442 .35812 L p
1 g
F P
s
P
p
.002 w
.53442 .35812 m .54358 .35722 L .5425 .33111 L p
1 g
F P
s
P
p
.002 w
.57627 .46365 m .59808 .44924 L .5816 .42726 L p
1 g
F P
s
P
p
.002 w
.59209 .4129 m .5816 .42726 L .59808 .44924 L p
1 g
F P
s
P
p
.002 w
.59209 .4129 m .59715 .39557 L .57105 .38959 L p
1 g
F P
s
P
p
.002 w
.5705 .38034 m .57105 .38959 L .59715 .39557 L p
1 g
F P
s
P
p
.002 w
.5507 .4977 m .58393 .48969 L .57627 .46365 L p
1 g
F P
s
P
p
.002 w
.59808 .44924 m .57627 .46365 L .58393 .48969 L p
1 g
F P
s
P
p
.002 w
.50786 .52023 m .54942 .5242 L .5507 .4977 L p
1 g
F P
s
P
p
.002 w
.58393 .48969 m .5507 .4977 L .54942 .5242 L p
1 g
F P
s
P
p
.002 w
.5607 .33534 m .5425 .33111 L .54358 .35722 L p
1 g
F P
s
P
p
.002 w
.54358 .35722 m .55271 .35937 L .5607 .33534 L p
1 g
F P
s
P
p
.002 w
.38004 .40507 m .39199 .45175 L .41469 .43991 L p
1 g
F P
s
P
p
.002 w
.41469 .43991 m .40444 .39928 L .38004 .40507 L p
1 g
F P
s
P
p
.002 w
.59715 .39557 m .59614 .37717 L .5705 .38034 L p
1 g
F P
s
P
p
.002 w
.56696 .37161 m .5705 .38034 L .59614 .37717 L p
1 g
F P
s
P
p
.002 w
.57685 .34525 m .5607 .33534 L .55271 .35937 L p
1 g
F P
s
P
p
.002 w
.55271 .35937 m .5608 .36435 L .57685 .34525 L p
1 g
F P
s
P
p
.002 w
.59614 .37717 m .58913 .35974 L .56696 .37161 L p
1 g
F P
s
P
p
.002 w
.5608 .36435 m .56696 .37161 L .58913 .35974 L p
1 g
F P
s
P
p
.002 w
.58913 .35974 m .57685 .34525 L .5608 .36435 L p
1 g
F P
s
P
p
.002 w
.45462 .52483 m .4991 .54416 L .50786 .52023 L p
1 g
F P
s
P
p
.002 w
.54942 .5242 m .50786 .52023 L .4991 .54416 L p
1 g
F P
s
P
p
.002 w
.51337 .30983 m .48949 .32141 L .50809 .34073 L p
1 g
F P
s
P
p
.002 w
.50809 .34073 m .52429 .333 L .51337 .30983 L p
1 g
F P
s
P
p
.002 w
.59808 .44924 m .61373 .42814 L .59209 .4129 L p
1 g
F P
s
P
p
.002 w
.59715 .39557 m .59209 .4129 L .61373 .42814 L p
1 g
F P
s
P
p
.002 w
.47077 .30442 m .44719 .32906 L .47125 .34021 L p
1 g
F P
s
P
p
.002 w
.47125 .34021 m .48949 .32141 L .47077 .30442 L p
1 g
F P
s
P
p
.002 w
.42393 .32022 m .40752 .35796 L .43343 .36018 L p
1 g
F P
s
P
p
.002 w
.43343 .36018 m .44719 .32906 L .42393 .32022 L p
1 g
F P
s
P
p
.002 w
.58393 .48969 m .61242 .47113 L .59808 .44924 L p
1 g
F P
s
P
p
.002 w
.61373 .42814 m .59808 .44924 L .61242 .47113 L p
1 g
F P
s
P
p
.002 w
.54033 .30691 m .51337 .30983 L .52429 .333 L p
1 g
F P
s
P
p
.002 w
.52429 .333 m .5425 .33111 L .54033 .30691 L p
1 g
F P
s
P
p
.002 w
.38334 .35751 m .38004 .40507 L .40444 .39928 L p
1 g
F P
s
P
p
.002 w
.40444 .39928 m .40752 .35796 L .38334 .35751 L p
1 g
F P
s
P
p
.002 w
.54942 .5242 m .58963 .51474 L .58393 .48969 L p
1 g
F P
s
P
p
.002 w
.61242 .47113 m .58393 .48969 L .58963 .51474 L p
1 g
F P
s
P
p
.002 w
.61373 .42814 m .62136 .40255 L .59715 .39557 L p
1 g
F P
s
P
p
.002 w
.59614 .37717 m .59715 .39557 L .62136 .40255 L p
1 g
F P
s
P
p
.002 w
.37145 .46334 m .40004 .50899 L .41772 .49299 L p
1 g
F P
s
P
p
.002 w
.41772 .49299 m .39199 .45175 L .37145 .46334 L p
1 g
F P
s
P
p
.002 w
.45462 .52483 m .41772 .49299 L .40004 .50899 L p
1 g
F P
s
P
p
.002 w
.40004 .50899 m .4409 .54428 L .45462 .52483 L p
1 g
F P
s
P
p
.002 w
.4991 .54416 m .45462 .52483 L .4409 .54428 L p
1 g
F P
s
P
p
.002 w
.4991 .54416 m .54688 .54891 L .54942 .5242 L p
1 g
F P
s
P
p
.002 w
.58963 .51474 m .54942 .5242 L .54688 .54891 L p
1 g
F P
s
P
p
.002 w
.56737 .3131 m .54033 .30691 L .5425 .33111 L p
1 g
F P
s
P
p
.002 w
.5425 .33111 m .5607 .33534 L .56737 .3131 L p
1 g
F P
s
P
p
.002 w
.50184 .28915 m .47077 .30442 L .48949 .32141 L p
1 g
F P
s
P
p
.002 w
.48949 .32141 m .51337 .30983 L .50184 .28915 L p
1 g
F P
s
P
p
.002 w
.62136 .40255 m .61998 .37525 L .59614 .37717 L p
1 g
F P
s
P
p
.002 w
.58913 .35974 m .59614 .37717 L .61998 .37525 L p
1 g
F P
s
P
p
.002 w
.35803 .41165 m .37145 .46334 L .39199 .45175 L p
1 g
F P
s
P
p
.002 w
.39199 .45175 m .38004 .40507 L .35803 .41165 L p
1 g
F P
s
P
p
.002 w
.59139 .3278 m .56737 .3131 L .5607 .33534 L p
1 g
F P
s
P
p
.002 w
.5607 .33534 m .57685 .34525 L .59139 .3278 L p
1 g
F P
s
P
p
.002 w
.4409 .54428 m .49014 .56581 L .4991 .54416 L p
1 g
F P
s
P
p
.002 w
.54688 .54891 m .4991 .54416 L .49014 .56581 L p
1 g
F P
s
P
p
.002 w
.61242 .47113 m .63297 .44376 L .61373 .42814 L p
1 g
F P
s
P
p
.002 w
.62136 .40255 m .61373 .42814 L .63297 .44376 L p
1 g
F P
s
P
p
.002 w
.61998 .37525 m .60961 .34934 L .58913 .35974 L p
1 g
F P
s
P
p
.002 w
.57685 .34525 m .58913 .35974 L .60961 .34934 L p
1 g
F P
s
P
p
.002 w
.45232 .29021 m .42393 .32022 L .44719 .32906 L p
1 g
F P
s
P
p
.002 w
.44719 .32906 m .47077 .30442 L .45232 .29021 L p
1 g
F P
s
P
p
.002 w
.60961 .34934 m .59139 .3278 L .57685 .34525 L p
1 g
F P
s
P
p
.002 w
.402 .31395 m .38334 .35751 L .40752 .35796 L p
1 g
F P
s
P
p
.002 w
.40752 .35796 m .42393 .32022 L .402 .31395 L p
1 g
F P
s
P
p
.002 w
.58963 .51474 m .62424 .49249 L .61242 .47113 L p
1 g
F P
s
P
p
.002 w
.63297 .44376 m .61242 .47113 L .62424 .49249 L p
1 g
F P
s
P
p
.002 w
.53708 .28518 m .50184 .28915 L .51337 .30983 L p
1 g
F P
s
P
p
.002 w
.51337 .30983 m .54033 .30691 L .53708 .28518 L p
1 g
F P
s
P
p
.002 w
.36147 .35891 m .35803 .41165 L .38004 .40507 L p
1 g
F P
s
P
p
.002 w
.38004 .40507 m .38334 .35751 L .36147 .35891 L p
1 g
F P
s
P
p
.002 w
.54688 .54891 m .59321 .53826 L .58963 .51474 L p
1 g
F P
s
P
p
.002 w
.62424 .49249 m .58963 .51474 L .59321 .53826 L p
1 g
F P
s
P
p
.002 w
.63297 .44376 m .64311 .4104 L .62136 .40255 L p
1 g
F P
s
P
p
.002 w
.61998 .37525 m .62136 .40255 L .64311 .4104 L p
1 g
F P
s
P
p
.002 w
.35358 .47444 m .38438 .52346 L .40004 .50899 L p
1 g
F P
s
P
p
.002 w
.40004 .50899 m .37145 .46334 L .35358 .47444 L p
1 g
F P
s
P
p
.002 w
.4409 .54428 m .40004 .50899 L .38438 .52346 L p
1 g
F P
s
P
p
.002 w
.49014 .56581 m .54308 .57127 L .54688 .54891 L p
1 g
F P
s
P
p
.002 w
.59321 .53826 m .54688 .54891 L .54308 .57127 L p
1 g
F P
s
P
p
.002 w
.38438 .52346 m .42829 .56141 L .4409 .54428 L p
1 g
F P
s
P
p
.002 w
.49014 .56581 m .4409 .54428 L .42829 .56141 L p
1 g
F P
s
P
p
.002 w
.48993 .27148 m .45232 .29021 L .47077 .30442 L p
1 g
F P
s
P
p
.002 w
.47077 .30442 m .50184 .28915 L .48993 .27148 L p
1 g
F P
s
P
p
.002 w
.57251 .29319 m .53708 .28518 L .54033 .30691 L p
1 g
F P
s
P
p
.002 w
.54033 .30691 m .56737 .3131 L .57251 .29319 L p
1 g
F P
s
P
p
.002 w
.64311 .4104 m .64144 .37469 L .61998 .37525 L p
1 g
F P
s
P
p
.002 w
.60961 .34934 m .61998 .37525 L .64144 .37469 L p
1 g
F P
s
P
p
.002 w
.339 .41892 m .35358 .47444 L .37145 .46334 L p
1 g
F P
s
P
p
.002 w
.37145 .46334 m .35803 .41165 L .339 .41892 L p
1 g
F P
s
P
p
.002 w
.62424 .49249 m .64935 .45947 L .63297 .44376 L p
1 g
F P
s
P
p
.002 w
.64311 .4104 m .63297 .44376 L .64935 .45947 L p
1 g
F P
s
P
p
.002 w
.43455 .27918 m .402 .31395 L .42393 .32022 L p
1 g
F P
s
P
p
.002 w
.42393 .32022 m .45232 .29021 L .43455 .27918 L p
1 g
F P
s
P
p
.002 w
.60403 .31243 m .57251 .29319 L .56737 .3131 L p
1 g
F P
s
P
p
.002 w
.56737 .3131 m .59139 .3278 L .60403 .31243 L p
1 g
F P
s
P
p
.002 w
.42829 .56141 m .48118 .58465 L .49014 .56581 L p
1 g
F P
s
P
p
.002 w
.54308 .57127 m .49014 .56581 L .48118 .58465 L p
1 g
F P
s
P
p
.002 w
.64144 .37469 m .62793 .34071 L .60961 .34934 L p
1 g
F P
s
P
p
.002 w
.59139 .3278 m .60961 .34934 L .62793 .34071 L p
1 g
F P
s
P
p
.002 w
.62793 .34071 m .60403 .31243 L .59139 .3278 L p
1 g
F P
s
P
p
.002 w
.38193 .3105 m .36147 .35891 L .38334 .35751 L p
1 g
F P
s
P
p
.002 w
.38334 .35751 m .402 .31395 L .38193 .3105 L p
1 g
F P
s
P
p
.002 w
.59321 .53826 m .63322 .51285 L .62424 .49249 L p
1 g
F P
s
P
p
.002 w
.64935 .45947 m .62424 .49249 L .63322 .51285 L p
1 g
F P
s
P
p
.002 w
.53276 .26649 m .48993 .27148 L .50184 .28915 L p
1 g
F P
s
P
p
.002 w
.50184 .28915 m .53708 .28518 L .53276 .26649 L p
1 g
F P
s
P
p
.002 w
.54308 .57127 m .59451 .5597 L .59321 .53826 L p
1 g
F P
s
P
p
.002 w
.63322 .51285 m .59321 .53826 L .59451 .5597 L p
1 g
F P
s
P
p
.002 w
.34248 .36222 m .339 .41892 L .35803 .41165 L p
1 g
F P
s
P
p
.002 w
.35803 .41165 m .36147 .35891 L .34248 .36222 L p
1 g
F P
s
P
p
.002 w
.64935 .45947 m .66184 .41902 L .64311 .4104 L p
1 g
F P
s
P
p
.002 w
.64144 .37469 m .64311 .4104 L .66184 .41902 L p
1 g
F P
s
P
p
.002 w
.48118 .58465 m .53806 .5907 L .54308 .57127 L p
1 g
F P
s
P
p
.002 w
.59451 .5597 m .54308 .57127 L .53806 .5907 L p
1 g
F P
s
P
p
.002 w
.47789 .25736 m .43455 .27918 L .45232 .29021 L p
1 g
F P
s
P
p
.002 w
.45232 .29021 m .48993 .27148 L .47789 .25736 L p
1 g
F P
s
P
p
.002 w
.3389 .48477 m .37118 .53602 L .38438 .52346 L p
1 g
F P
s
P
p
.002 w
.38438 .52346 m .35358 .47444 L .3389 .48477 L p
1 g
F P
s
P
p
.002 w
.42829 .56141 m .38438 .52346 L .37118 .53602 L p
1 g
F P
s
P
p
.002 w
.37118 .53602 m .41711 .57573 L .42829 .56141 L p
1 g
F P
s
P
p
.002 w
.48118 .58465 m .42829 .56141 L .41711 .57573 L p
1 g
F P
s
P
p
.002 w
.57596 .27616 m .53276 .26649 L .53708 .28518 L p
1 g
F P
s
P
p
.002 w
.53708 .28518 m .57251 .29319 L .57596 .27616 L p
1 g
F P
s
P
p
.002 w
.66184 .41902 m .65995 .37555 L .64144 .37469 L p
1 g
F P
s
P
p
.002 w
.62793 .34071 m .64144 .37469 L .65995 .37555 L p
1 g
F P
s
P
p
.002 w
.63322 .51285 m .66237 .47491 L .64935 .45947 L p
1 g
F P
s
P
p
.002 w
.66184 .41902 m .64935 .45947 L .66237 .47491 L p
1 g
F P
s
P
p
.002 w
.41789 .27174 m .38193 .3105 L .402 .31395 L p
1 g
F P
s
P
p
.002 w
.402 .31395 m .43455 .27918 L .41789 .27174 L p
1 g
F P
s
P
p
.002 w
.32351 .42674 m .3389 .48477 L .35358 .47444 L p
1 g
F P
s
P
p
.002 w
.35358 .47444 m .339 .41892 L .32351 .42674 L p
1 g
F P
s
P
p
.002 w
.41711 .57573 m .4724 .60013 L .48118 .58465 L p
1 g
F P
s
P
p
.002 w
.53806 .5907 m .48118 .58465 L .4724 .60013 L p
1 g
F P
s
P
p
.002 w
.61442 .2996 m .57596 .27616 L .57251 .29319 L p
1 g
F P
s
P
p
.002 w
.57251 .29319 m .60403 .31243 L .61442 .2996 L p
1 g
F P
s
P
p
.002 w
.36426 .31009 m .34248 .36222 L .36147 .35891 L p
1 g
F P
s
P
p
.002 w
.36147 .35891 m .38193 .3105 L .36426 .31009 L p
1 g
F P
s
P
p
.002 w
.65995 .37555 m .64356 .3341 L .62793 .34071 L p
1 g
F P
s
P
p
.002 w
.60403 .31243 m .62793 .34071 L .64356 .3341 L p
1 g
F P
s
P
p
.002 w
.59451 .5597 m .63903 .53173 L .63322 .51285 L p
1 g
F P
s
P
p
.002 w
.66237 .47491 m .63322 .51285 L .63903 .53173 L p
1 g
F P
s
P
p
.002 w
.64356 .3341 m .61442 .2996 L .60403 .31243 L p
1 g
F P
s
P
p
.002 w
.52743 .25144 m .47789 .25736 L .48993 .27148 L p
1 g
F P
s
P
p
.002 w
.48993 .27148 m .53276 .26649 L .52743 .25144 L p
1 g
F P
s
P
p
.002 w
.53806 .5907 m .59338 .57849 L .59451 .5597 L p
1 g
F P
s
P
p
.002 w
.63903 .53173 m .59451 .5597 L .59338 .57849 L p
1 g
F P
s
P
p
.002 w
.32696 .36746 m .32351 .42674 L .339 .41892 L p
1 g
F P
s
P
p
.002 w
.339 .41892 m .34248 .36222 L .32696 .36746 L p
1 g
F P
s
P
p
.002 w
.66237 .47491 m .67699 .42822 L .66184 .41902 L p
1 g
F P
s
P
p
.002 w
.65995 .37555 m .66184 .41902 L .67699 .42822 L p
1 g
F P
s
P
p
.002 w
.4724 .60013 m .53186 .60662 L .53806 .5907 L p
1 g
F P
s
P
p
.002 w
.59338 .57849 m .53806 .5907 L .53186 .60662 L p
1 g
F P
s
P
p
.002 w
.46598 .24732 m .41789 .27174 L .43455 .27918 L p
1 g
F P
s
P
p
.002 w
.43455 .27918 m .47789 .25736 L .46598 .24732 L p
1 g
F P
s
P
p
.002 w
.32791 .49406 m .36087 .54627 L .37118 .53602 L p
1 g
F P
s
P
p
.002 w
.37118 .53602 m .3389 .48477 L .32791 .49406 L p
1 g
F P
s
P
p
.002 w
.41711 .57573 m .37118 .53602 L .36087 .54627 L p
1 g
F P
s
P
p
.002 w
.36087 .54627 m .4077 .58677 L .41711 .57573 L p
1 g
F P
s
P
p
.002 w
.4724 .60013 m .41711 .57573 L .4077 .58677 L p
1 g
F P
s
P
p
.002 w
.57752 .26257 m .52743 .25144 L .53276 .26649 L p
1 g
F P
s
P
p
.002 w
.53276 .26649 m .57596 .27616 L .57752 .26257 L p
1 g
F P
s
P
p
.002 w
.63903 .53173 m .67157 .48973 L .66237 .47491 L p
1 g
F P
s
P
p
.002 w
.67699 .42822 m .66237 .47491 L .67157 .48973 L p
1 g
F P
s
P
p
.002 w
.4028 .26827 m .36426 .31009 L .38193 .3105 L p
1 g
F P
s
P
p
.002 w
.38193 .3105 m .41789 .27174 L .4028 .26827 L p
1 g
F P
s
P
p
.002 w
.67699 .42822 m .67493 .3779 L .65995 .37555 L p
1 g
F P
s
P
p
.002 w
.64356 .3341 m .65995 .37555 L .67493 .3779 L p
1 g
F P
s
P
p
.002 w
.31213 .43497 m .32791 .49406 L .3389 .48477 L p
1 g
F P
s
P
p
.002 w
.3389 .48477 m .32351 .42674 L .31213 .43497 L p
1 g
F P
s
P
p
.002 w
.34957 .3129 m .32696 .36746 L .34248 .36222 L p
1 g
F P
s
P
p
.002 w
.34248 .36222 m .36426 .31009 L .34957 .3129 L p
1 g
F P
s
P
p
.002 w
.4077 .58677 m .46401 .61171 L .4724 .60013 L p
1 g
F P
s
P
p
.002 w
.53186 .60662 m .4724 .60013 L .46401 .61171 L p
1 g
F P
s
P
p
.002 w
.59338 .57849 m .64137 .54861 L .63903 .53173 L p
1 g
F P
s
P
p
.002 w
.67157 .48973 m .63903 .53173 L .64137 .54861 L p
1 g
F P
s
P
p
.002 w
.62218 .28973 m .57752 .26257 L .57596 .27616 L p
1 g
F P
s
P
p
.002 w
.57596 .27616 m .61442 .2996 L .62218 .28973 L p
1 g
F P
s
P
p
.002 w
.67493 .3779 m .65599 .3298 L .64356 .3341 L p
1 g
F P
s
P
p
.002 w
.61442 .2996 m .64356 .3341 L .65599 .3298 L p
1 g
F P
s
P
p
.002 w
.65599 .3298 m .62218 .28973 L .61442 .2996 L p
1 g
F P
s
P
p
.002 w
.52114 .2406 m .46598 .24732 L .47789 .25736 L p
1 g
F P
s
P
p
.002 w
.47789 .25736 m .52743 .25144 L .52114 .2406 L p
1 g
F P
s
P
p
.002 w
.53186 .60662 m .58973 .59404 L .59338 .57849 L p
1 g
F P
s
P
p
.002 w
.64137 .54861 m .59338 .57849 L .58973 .59404 L p
1 g
F P
s
P
p
.002 w
.31551 .3746 m .31213 .43497 L .32351 .42674 L p
1 g
F P
s
P
p
.002 w
.32351 .42674 m .32696 .36746 L .31551 .3746 L p
1 g
F P
s
P
p
.002 w
.67157 .48973 m .688 .43784 L .67699 .42822 L p
1 g
F P
s
P
p
.002 w
.67493 .3779 m .67699 .42822 L .688 .43784 L p
1 g
F P
s
P
p
.002 w
.45453 .24184 m .4028 .26827 L .41789 .27174 L p
1 g
F P
s
P
p
.002 w
.41789 .27174 m .46598 .24732 L .45453 .24184 L p
1 g
F P
s
P
p
.002 w
.46401 .61171 m .52457 .61844 L .53186 .60662 L p
1 g
F P
s
P
p
.002 w
.58973 .59404 m .53186 .60662 L .52457 .61844 L p
1 g
F P
s
P
p
.002 w
.32112 .50202 m .35388 .55383 L .36087 .54627 L p
1 g
F P
s
P
p
.002 w
.36087 .54627 m .32791 .49406 L .32112 .50202 L p
1 g
F P
s
P
p
.002 w
.4077 .58677 m .36087 .54627 L .35388 .55383 L p
1 g
F P
s
P
p
.002 w
.57705 .25295 m .52114 .2406 L .52743 .25144 L p
1 g
F P
s
P
p
.002 w
.52743 .25144 m .57752 .26257 L .57705 .25295 L p
1 g
F P
s
P
p
.002 w
.38975 .26908 m .34957 .3129 L .36426 .31009 L p
1 g
F P
s
P
p
.002 w
.36426 .31009 m .4028 .26827 L .38975 .26908 L p
1 g
F P
s
P
p
.002 w
.35388 .55383 m .40038 .59405 L .4077 .58677 L p
1 g
F P
s
P
p
.002 w
.46401 .61171 m .4077 .58677 L .40038 .59405 L p
1 g
F P
s
P
p
.002 w
.64137 .54861 m .67652 .50352 L .67157 .48973 L p
1 g
F P
s
P
p
.002 w
.688 .43784 m .67157 .48973 L .67652 .50352 L p
1 g
F P
s
P
p
.002 w
.688 .43784 m .6858 .38176 L .67493 .3779 L p
1 g
F P
s
P
p
.002 w
.65599 .3298 m .67493 .3779 L .6858 .38176 L p
1 g
F P
s
P
p
.002 w
.30539 .44341 m .32112 .50202 L .32791 .49406 L p
1 g
F P
s
P
p
.002 w
.32791 .49406 m .31213 .43497 L .30539 .44341 L p
1 g
F P
s
P
p
.002 w
.3384 .31904 m .31551 .3746 L .32696 .36746 L p
1 g
F P
s
P
p
.002 w
.32696 .36746 m .34957 .3129 L .3384 .31904 L p
1 g
F P
s
P
p
.002 w
.58973 .59404 m .63998 .56295 L .64137 .54861 L p
1 g
F P
s
P
p
.002 w
.67652 .50352 m .64137 .54861 L .63998 .56295 L p
1 g
F P
s
P
p
.002 w
.40038 .59405 m .45626 .61886 L .46401 .61171 L p
1 g
F P
s
P
p
.002 w
.52457 .61844 m .46401 .61171 L .45626 .61886 L p
1 g
F P
s
P
p
.002 w
.62695 .28328 m .57705 .25295 L .57752 .26257 L p
1 g
F P
s
P
p
.002 w
.57752 .26257 m .62218 .28973 L .62695 .28328 L p
1 g
F P
s
P
p
.002 w
.6858 .38176 m .66471 .32804 L .65599 .3298 L p
1 g
F P
s
P
p
.002 w
.62218 .28973 m .65599 .3298 L .66471 .32804 L p
1 g
F P
s
P
p
.002 w
.51402 .23452 m .45453 .24184 L .46598 .24732 L p
1 g
F P
s
P
p
.002 w
.46598 .24732 m .52114 .2406 L .51402 .23452 L p
1 g
F P
s
P
p
.002 w
.66471 .32804 m .62695 .28328 L .62218 .28973 L p
1 g
F P
s
P
p
.002 w
.52457 .61844 m .58351 .60577 L .58973 .59404 L p
1 g
F P
s
P
p
.002 w
.63998 .56295 m .58973 .59404 L .58351 .60577 L p
1 g
F P
s
P
p
.002 w
.30866 .38357 m .30539 .44341 L .31213 .43497 L p
1 g
F P
s
P
p
.002 w
.31213 .43497 m .31551 .3746 L .30866 .38357 L p
1 g
F P
s
P
p
.002 w
.67652 .50352 m .69434 .44765 L .688 .43784 L p
1 g
F P
s
P
p
.002 w
.6858 .38176 m .688 .43784 L .69434 .44765 L p
1 g
F P
s
P
p
.002 w
.44385 .24135 m .38975 .26908 L .4028 .26827 L p
1 g
F P
s
P
p
.002 w
.4028 .26827 m .45453 .24184 L .44385 .24135 L p
1 g
F P
s
P
p
.002 w
.45626 .61886 m .51631 .62562 L .52457 .61844 L p
1 g
F P
s
P
p
.002 w
.58351 .60577 m .52457 .61844 L .51631 .62562 L p
1 g
F P
s
P
p
.002 w
.37924 .27441 m .3384 .31904 L .34957 .3129 L p
1 g
F P
s
P
p
.002 w
.34957 .3129 m .38975 .26908 L .37924 .27441 L p
1 g
F P
s
P
p
.002 w
.63998 .56295 m .67684 .51587 L .67652 .50352 L p
1 g
F P
s
P
p
.002 w
.69434 .44765 m .67652 .50352 L .67684 .51587 L p
1 g
F P
s
P
p
.002 w
.57443 .24782 m .51402 .23452 L .52114 .2406 L p
1 g
F P
s
P
p
.002 w
.52114 .2406 m .57705 .25295 L .57443 .24782 L p
1 g
F P
s
P
p
.002 w
.31897 .50835 m .3506 .55834 L .35388 .55383 L p
1 g
F P
s
P
p
.002 w
.35388 .55383 m .32112 .50202 L .31897 .50835 L p
1 g
F P
s
P
p
.002 w
.40038 .59405 m .35388 .55383 L .3506 .55834 L p
1 g
F P
s
P
p
.002 w
.3506 .55834 m .39548 .59717 L .40038 .59405 L p
1 g
F P
s
P
p
.002 w
.45626 .61886 m .40038 .59405 L .39548 .59717 L p
1 g
F P
s
P
p
.002 w
.69434 .44765 m .69203 .38711 L .6858 .38176 L p
1 g
F P
s
P
p
.002 w
.66471 .32804 m .6858 .38176 L .69203 .38711 L p
1 g
F P
s
P
p
.002 w
.30377 .45185 m .31897 .50835 L .32112 .50202 L p
1 g
F P
s
P
p
.002 w
.32112 .50202 m .30539 .44341 L .30377 .45185 L p
1 g
F P
s
P
p
.002 w
.58351 .60577 m .63469 .57422 L .63998 .56295 L p
1 g
F P
s
P
p
.002 w
.67684 .51587 m .63998 .56295 L .63469 .57422 L p
1 g
F P
s
P
p
.002 w
.33129 .32855 m .30866 .38357 L .31551 .3746 L p
1 g
F P
s
P
p
.002 w
.31551 .3746 m .3384 .31904 L .33129 .32855 L p
1 g
F P
s
P
p
.002 w
.39548 .59717 m .44938 .62112 L .45626 .61886 L p
1 g
F P
s
P
p
.002 w
.51631 .62562 m .45626 .61886 L .44938 .62112 L p
1 g
F P
s
P
p
.002 w
.62841 .28061 m .57443 .24782 L .57705 .25295 L p
1 g
F P
s
P
p
.002 w
.57705 .25295 m .62695 .28328 L .62841 .28061 L p
1 g
F P
s
P
p
.002 w
.69203 .38711 m .66926 .32905 L .66471 .32804 L p
1 g
F P
s
P
p
.002 w
.62695 .28328 m .66471 .32804 L .66926 .32905 L p
1 g
F P
s
P
p
.002 w
.50619 .23366 m .44385 .24135 L .45453 .24184 L p
1 g
F P
s
P
p
.002 w
.45453 .24184 m .51402 .23452 L .50619 .23366 L p
1 g
F P
s
P
p
.002 w
.51631 .62562 m .57472 .61313 L .58351 .60577 L p
1 g
F P
s
P
p
.002 w
.63469 .57422 m .58351 .60577 L .57472 .61313 L p
1 g
F P
s
P
p
.002 w
.66926 .32905 m .62841 .28061 L .62695 .28328 L p
1 g
F P
s
P
p
.002 w
.3069 .39424 m .30377 .45185 L .30539 .44341 L p
1 g
F P
s
P
p
.002 w
.30539 .44341 m .30866 .38357 L .3069 .39424 L p
1 g
F P
s
P
p
.002 w
.67684 .51587 m .69554 .4574 L .69434 .44765 L p
1 g
F P
s
P
p
.002 w
.69203 .38711 m .69434 .44765 L .69554 .4574 L p
1 g
F P
s
P
p
.002 w
.43431 .24619 m .37924 .27441 L .38975 .26908 L p
1 g
F P
s
P
p
.002 w
.38975 .26908 m .44385 .24135 L .43431 .24619 L p
1 g
F P
s
P
p
.004 w
.31891 .24967 m
.33075 .26149 L
s
P
p
.004 w
.31706 .24782 m
.31891 .24967 L
s
P
p
.002 w
.44938 .62112 m .50725 .62767 L .51631 .62562 L p
1 g
F P
s
P
p
.002 w
.57472 .61313 m .51631 .62562 L .50725 .62767 L p
1 g
F P
s
P
p
.002 w
.37171 .28439 m .33129 .32855 L .3384 .31904 L p
1 g
F P
s
P
p
.002 w
.3384 .31904 m .37924 .27441 L .37171 .28439 L p
1 g
F P
s
P
p
.004 w
.33075 .26149 m
.34906 .27977 L
s
P
p
.002 w
.63469 .57422 m .67223 .52635 L .67684 .51587 L p
1 g
F P
s
P
p
.002 w
.69554 .4574 m .67684 .51587 L .67223 .52635 L p
1 g
F P
s
P
p
.002 w
.56959 .24763 m .50619 .23366 L .51402 .23452 L p
1 g
F P
s
P
p
.002 w
.51402 .23452 m .57443 .24782 L .56959 .24763 L p
1 g
F P
s
P
p
.002 w
.39548 .59717 m .3506 .55834 L .35136 .55946 L p
1 g
F P
s
P
p
.002 w
.32181 .51276 m .35136 .55946 L .3506 .55834 L p
1 g
F P
s
P
p
.002 w
.3506 .55834 m .31897 .50835 L .32181 .51276 L p
1 g
F P
s
P
p
.002 w
.35136 .55946 m .39329 .59574 L .39548 .59717 L p
1 g
F P
s
P
p
.002 w
.44938 .62112 m .39548 .59717 L .39329 .59574 L p
1 g
F P
s
P
p
.002 w
.69554 .4574 m .69314 .39393 L .69203 .38711 L p
1 g
F P
s
P
p
.002 w
.66926 .32905 m .69203 .38711 L .69314 .39393 L p
1 g
F P
s
P
p
.002 w
.57472 .61313 m .62539 .58193 L .63469 .57422 L p
1 g
F P
s
P
p
.002 w
.67223 .52635 m .63469 .57422 L .62539 .58193 L p
1 g
F P
s
P
p
.002 w
.32869 .34135 m .3069 .39424 L .30866 .38357 L p
1 g
F P
s
P
p
.002 w
.30866 .38357 m .33129 .32855 L .32869 .34135 L p
1 g
F P
s
P
p
.002 w
.30765 .46005 m .32181 .51276 L .31897 .50835 L p
1 g
F P
s
P
p
.002 w
.31897 .50835 m .30377 .45185 L .30765 .46005 L p
1 g
F P
s
P
p
.002 w
.39329 .59574 m .44362 .61811 L .44938 .62112 L p
1 g
F P
s
P
p
.002 w
.50725 .62767 m .44938 .62112 L .44362 .61811 L p
1 g
F P
s
P
p
.002 w
.6263 .28208 m .56959 .24763 L .57443 .24782 L p
1 g
F P
s
P
p
.002 w
.57443 .24782 m .62841 .28061 L .6263 .28208 L p
1 g
F P
s
P
p
.002 w
.49786 .23839 m .43431 .24619 L .44385 .24135 L p
1 g
F P
s
P
p
.002 w
.44385 .24135 m .50619 .23366 L .49786 .23839 L p
1 g
F P
s
P
p
.002 w
.50725 .62767 m .56345 .61565 L .57472 .61313 L p
1 g
F P
s
P
p
.002 w
.62539 .58193 m .57472 .61313 L .56345 .61565 L p
1 g
F P
s
P
p
.002 w
.69314 .39393 m .66922 .33296 L .66926 .32905 L p
1 g
F P
s
P
p
.002 w
.62841 .28061 m .66926 .32905 L .66922 .33296 L p
1 g
F P
s
P
p
.002 w
.66922 .33296 m .6263 .28208 L .62841 .28061 L p
1 g
F P
s
P
p
.002 w
.31061 .4064 m .30765 .46005 L .30377 .45185 L p
1 g
F P
s
P
p
.002 w
.30377 .45185 m .3069 .39424 L .31061 .4064 L p
1 g
F P
s
P
p
.002 w
.67223 .52635 m .69126 .4668 L .69554 .4574 L p
1 g
F P
s
P
p
.002 w
.69314 .39393 m .69554 .4574 L .69126 .4668 L p
1 g
F P
s
P
p
.002 w
.42626 .25653 m .37171 .28439 L .37924 .27441 L p
1 g
F P
s
P
p
.002 w
.37924 .27441 m .43431 .24619 L .42626 .25653 L p
1 g
F P
s
P
p
.002 w
.44362 .61811 m .49759 .62419 L .50725 .62767 L p
1 g
F P
s
P
p
.002 w
.56345 .61565 m .50725 .62767 L .49759 .62419 L p
1 g
F P
s
P
p
.002 w
.36759 .29901 m .32869 .34135 L .33129 .32855 L p
1 g
F P
s
P
p
.002 w
.33129 .32855 m .37171 .28439 L .36759 .29901 L p
1 g
F P
s
P
p
.004 w
.34906 .27977 m
.36549 .29618 L
s
P
p
.002 w
.62539 .58193 m .66251 .53453 L .67223 .52635 L p
1 g
F P
s
P
p
.002 w
.69126 .4668 m .67223 .52635 L .66251 .53453 L p
1 g
F P
s
P
p
.002 w
.56254 .25269 m .49786 .23839 L .50619 .23366 L p
1 g
F P
s
P
p
.002 w
.50619 .23366 m .56959 .24763 L .56254 .25269 L p
1 g
F P
s
P
p
.002 w
.32991 .51501 m .35641 .55693 L .35136 .55946 L p
1 g
F P
s
P
p
.002 w
.35136 .55946 m .32181 .51276 L .32991 .51501 L p
1 g
F P
s
P
p
.002 w
.39329 .59574 m .35136 .55946 L .35641 .55693 L p
1 g
F P
s
P
p
.002 w
.35641 .55693 m .39407 .58951 L .39329 .59574 L p
1 g
F P
s
P
p
.002 w
.44362 .61811 m .39329 .59574 L .39407 .58951 L p
1 g
F P
s
P
p
.002 w
.56345 .61565 m .61212 .58562 L .62539 .58193 L p
1 g
F P
s
P
p
.002 w
.66251 .53453 m .62539 .58193 L .61212 .58562 L p
1 g
F P
s
P
p
.002 w
.69126 .4668 m .68875 .40208 L .69314 .39393 L p
1 g
F P
s
P
p
.002 w
.66922 .33296 m .69314 .39393 L .68875 .40208 L p
1 g
F P
s
P
p
.002 w
.33097 .35727 m .31061 .4064 L .3069 .39424 L p
1 g
F P
s
P
p
.002 w
.3069 .39424 m .32869 .34135 L .33097 .35727 L p
1 g
F P
s
P
p
.002 w
.31726 .46774 m .32991 .51501 L .32181 .51276 L p
1 g
F P
s
P
p
.002 w
.32181 .51276 m .30765 .46005 L .31726 .46774 L p
1 g
F P
s
P
p
.002 w
.39407 .58951 m .43924 .60956 L .44362 .61811 L p
1 g
F P
s
P
p
.002 w
.49759 .62419 m .44362 .61811 L .43924 .60956 L p
1 g
F P
s
P
p
.002 w
.49759 .62419 m .54989 .61294 L .56345 .61565 L p
1 g
F P
s
P
p
.002 w
.61212 .58562 m .56345 .61565 L .54989 .61294 L p
1 g
F P
s
P
p
.002 w
.62044 .28791 m .56254 .25269 L .56959 .24763 L p
1 g
F P
s
P
p
.002 w
.56959 .24763 m .6263 .28208 L .62044 .28791 L p
1 g
F P
s
P
p
.002 w
.48923 .24892 m .42626 .25653 L .43431 .24619 L p
1 g
F P
s
P
p
.002 w
.43431 .24619 m .49786 .23839 L .48923 .24892 L p
1 g
F P
s
P
p
.002 w
.68875 .40208 m .66429 .33987 L .66922 .33296 L p
1 g
F P
s
P
p
.002 w
.6263 .28208 m .66922 .33296 L .66429 .33987 L p
1 g
F P
s
P
p
.002 w
.66429 .33987 m .62044 .28791 L .6263 .28208 L p
1 g
F P
s
P
p
.002 w
.66251 .53453 m .68126 .47555 L .69126 .4668 L p
1 g
F P
s
P
p
.002 w
.68875 .40208 m .69126 .4668 L .68126 .47555 L p
1 g
F P
s
P
p
.002 w
.32001 .41975 m .31726 .46774 L .30765 .46005 L p
1 g
F P
s
P
p
.002 w
.30765 .46005 m .31061 .4064 L .32001 .41975 L p
1 g
F P
s
P
p
.002 w
.42006 .2724 m .36759 .29901 L .37171 .28439 L p
1 g
F P
s
P
p
.002 w
.37171 .28439 m .42626 .25653 L .42006 .2724 L p
1 g
F P
s
P
p
.002 w
.43924 .60956 m .4876 .61494 L .49759 .62419 L p
1 g
F P
s
P
p
.002 w
.54989 .61294 m .49759 .62419 L .4876 .61494 L p
1 g
F P
s
P
p
.002 w
.36722 .31808 m .33097 .35727 L .32869 .34135 L p
1 g
F P
s
P
p
.002 w
.32869 .34135 m .36759 .29901 L .36722 .31808 L p
1 g
F P
s
P
p
.002 w
.61212 .58562 m .64767 .54002 L .66251 .53453 L p
1 g
F P
s
P
p
.002 w
.68126 .47555 m .66251 .53453 L .64767 .54002 L p
1 g
F P
s
P
p
.002 w
.55335 .26321 m .48923 .24892 L .49786 .23839 L p
1 g
F P
s
P
p
.002 w
.49786 .23839 m .56254 .25269 L .55335 .26321 L p
1 g
F P
s
P
p
.002 w
.54989 .61294 m .59505 .58492 L .61212 .58562 L p
1 g
F P
s
P
p
.002 w
.64767 .54002 m .61212 .58562 L .59505 .58492 L p
1 g
F P
s
P
p
.002 w
.34333 .51487 m .36588 .5506 L .35641 .55693 L p
1 g
F P
s
P
p
.002 w
.35641 .55693 m .32991 .51501 L .34333 .51487 L p
1 g
F P
s
P
p
.002 w
.39407 .58951 m .35641 .55693 L .36588 .5506 L p
1 g
F P
s
P
p
.002 w
.36588 .5506 m .39798 .57836 L .39407 .58951 L p
1 g
F P
s
P
p
.002 w
.43924 .60956 m .39407 .58951 L .39798 .57836 L p
1 g
F P
s
P
p
.002 w
.33833 .37596 m .32001 .41975 L .31061 .4064 L p
1 g
F P
s
P
p
.002 w
.31061 .4064 m .33097 .35727 L .33833 .37596 L p
1 g
F P
s
P
p
.002 w
.68126 .47555 m .67865 .41142 L .68875 .40208 L p
1 g
F P
s
P
p
.002 w
.66429 .33987 m .68875 .40208 L .67865 .41142 L p
1 g
F P
s
P
p
.002 w
.33265 .47465 m .34333 .51487 L .32991 .51501 L p
1 g
F P
s
P
p
.002 w
.32991 .51501 m .31726 .46774 L .33265 .47465 L p
1 g
F P
s
P
p
.002 w
.4876 .61494 m .53433 .60477 L .54989 .61294 L p
1 g
F P
s
P
p
.002 w
.59505 .58492 m .54989 .61294 L .53433 .60477 L p
1 g
F P
s
P
p
.002 w
.39798 .57836 m .43647 .59539 L .43924 .60956 L p
1 g
F P
s
P
p
.002 w
.4876 .61494 m .43924 .60956 L .43647 .59539 L p
1 g
F P
s
P
p
.002 w
.48058 .26527 m .42006 .2724 L .42626 .25653 L p
1 g
F P
s
P
p
.002 w
.42626 .25653 m .48923 .24892 L .48058 .26527 L p
1 g
F P
s
P
p
.002 w
.61077 .29819 m .55335 .26321 L .56254 .25269 L p
1 g
F P
s
P
p
.002 w
.56254 .25269 m .62044 .28791 L .61077 .29819 L p
1 g
F P
s
P
p
.002 w
.67865 .41142 m .6543 .34974 L .66429 .33987 L p
1 g
F P
s
P
p
.002 w
.62044 .28791 m .66429 .33987 L .6543 .34974 L p
1 g
F P
s
P
p
.002 w
.64767 .54002 m .66551 .48331 L .68126 .47555 L p
1 g
F P
s
P
p
.002 w
.67865 .41142 m .68126 .47555 L .66551 .48331 L p
1 g
F P
s
P
p
.002 w
.6543 .34974 m .61077 .29819 L .62044 .28791 L p
1 g
F P
s
P
p
.002 w
.41601 .29358 m .36722 .31808 L .36759 .29901 L p
1 g
F P
s
P
p
.002 w
.36759 .29901 m .42006 .2724 L .41601 .29358 L p
1 g
F P
s
P
p
.002 w
.33512 .43393 m .33265 .47465 L .31726 .46774 L p
1 g
F P
s
P
p
.002 w
.31726 .46774 m .32001 .41975 L .33512 .43393 L p
1 g
F P
s
P
p
.002 w
.43647 .59539 m .47758 .59987 L .4876 .61494 L p
1 g
F P
s
P
p
.002 w
.53433 .60477 m .4876 .61494 L .47758 .59987 L p
1 g
F P
s
P
p
.002 w
.37081 .34118 m .33833 .37596 L .33097 .35727 L p
1 g
F P
s
P
p
.002 w
.33097 .35727 m .36722 .31808 L .37081 .34118 L p
1 g
F P
s
P
p
.002 w
.59505 .58492 m .6279 .54247 L .64767 .54002 L p
1 g
F P
s
P
p
.002 w
.66551 .48331 m .64767 .54002 L .6279 .54247 L p
1 g
F P
s
P
p
.002 w
.5422 .27915 m .48058 .26527 L .48923 .24892 L p
1 g
F P
s
P
p
.002 w
.48923 .24892 m .55335 .26321 L .5422 .27915 L p
1 g
F P
s
P
p
.002 w
.53433 .60477 m .57452 .57961 L .59505 .58492 L p
1 g
F P
s
P
p
.002 w
.6279 .54247 m .59505 .58492 L .57452 .57961 L p
1 g
F P
s
P
p
.002 w
.35081 .39693 m .33512 .43393 L .32001 .41975 L p
1 g
F P
s
P
p
.002 w
.32001 .41975 m .33833 .37596 L .35081 .39693 L p
1 g
F P
s
P
p
.002 w
.36197 .51221 m .37974 .54043 L .36588 .5506 L p
1 g
F P
s
P
p
.002 w
.36588 .5506 m .34333 .51487 L .36197 .51221 L p
1 g
F P
s
P
p
.002 w
.39798 .57836 m .36588 .5506 L .37974 .54043 L p
1 g
F P
s
P
p
.002 w
.66551 .48331 m .66284 .42168 L .67865 .41142 L p
1 g
F P
s
P
p
.002 w
.6543 .34974 m .67865 .41142 L .66284 .42168 L p
1 g
F P
s
P
p
.002 w
.37974 .54043 m .40509 .56235 L .39798 .57836 L p
1 g
F P
s
P
p
.002 w
.43647 .59539 m .39798 .57836 L .40509 .56235 L p
1 g
F P
s
P
p
.002 w
.35363 .48048 m .36197 .51221 L .34333 .51487 L p
1 g
F P
s
P
p
.002 w
.34333 .51487 m .33265 .47465 L .35363 .48048 L p
1 g
F P
s
P
p
.002 w
.47758 .59987 m .51717 .5911 L .53433 .60477 L p
1 g
F P
s
P
p
.002 w
.57452 .57961 m .53433 .60477 L .51717 .5911 L p
1 g
F P
s
P
p
.002 w
.47221 .28719 m .41601 .29358 L .42006 .2724 L p
1 g
F P
s
P
p
.002 w
.42006 .2724 m .48058 .26527 L .47221 .28719 L p
1 g
F P
s
P
p
.002 w
.40509 .56235 m .43548 .57574 L .43647 .59539 L p
1 g
F P
s
P
p
.002 w
.47758 .59987 m .43647 .59539 L .43548 .57574 L p
1 g
F P
s
P
p
.002 w
.5974 .31286 m .5422 .27915 L .55335 .26321 L p
1 g
F P
s
P
p
.002 w
.55335 .26321 m .61077 .29819 L .5974 .31286 L p
1 g
F P
s
P
p
.002 w
.66284 .42168 m .6393 .36242 L .6543 .34974 L p
1 g
F P
s
P
p
.002 w
.61077 .29819 m .6543 .34974 L .6393 .36242 L p
1 g
F P
s
P
p
.002 w
.41438 .31961 m .37081 .34118 L .36722 .31808 L p
1 g
F P
s
P
p
.004 w
.39738 .32803 m
.5 .43051 L
s
P
p
.002 w
.36722 .31808 m .41601 .29358 L .41438 .31961 L p
1 g
F P
s
P
p
.004 w
.3841 .31477 m
.38501 .31568 L
s
P
p
.004 w
.36549 .29618 m
.37531 .30599 L
s
P
p
.004 w
.37531 .30599 m
.3841 .31477 L
s
P
p
.002 w
.6279 .54247 m .64423 .48977 L .66551 .48331 L p
1 g
F P
s
P
p
.002 w
.66284 .42168 m .66551 .48331 L .64423 .48977 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.35572 .44848 m .35363 .48048 L .33265 .47465 L p
1 g
F P
s
P
p
.002 w
.33265 .47465 m .33512 .43393 L .35572 .44848 L p
1 g
F P
s
P
p
.002 w
.6393 .36242 m .5974 .31286 L .61077 .29819 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.43548 .57574 m .46787 .57916 L .47758 .59987 L p
1 g
F P
s
P
p
.002 w
.51717 .5911 m .47758 .59987 L .46787 .57916 L p
1 g
F P
s
P
p
.002 w
.37844 .36771 m .35081 .39693 L .33833 .37596 L p
1 g
F P
s
P
p
.002 w
.33833 .37596 m .37081 .34118 L .37844 .36771 L p
1 g
F P
s
P
p
.002 w
.57452 .57961 m .60359 .54164 L .6279 .54247 L p
1 g
F P
s
P
p
.002 w
.64423 .48977 m .6279 .54247 L .60359 .54164 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.51717 .5911 m .55106 .56963 L .57452 .57961 L p
1 g
F P
s
P
p
.002 w
.60359 .54164 m .57452 .57961 L .55106 .56963 L p
1 g
F P
s
P
p
.002 w
.52938 .30025 m .47221 .28719 L .48058 .26527 L p
1 g
F P
s
P
p
.002 w
.48058 .26527 m .5422 .27915 L .52938 .30025 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.3682 .41954 m .35572 .44848 L .33512 .43393 L p
1 g
F P
s
P
p
.002 w
.33512 .43393 m .35081 .39693 L .3682 .41954 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.64423 .48977 m .64152 .43258 L .66284 .42168 L p
1 g
F P
s
P
p
.002 w
.6393 .36242 m .66284 .42168 L .64152 .43258 L p
1 g
F P
s
P
p
.002 w
.38545 .50696 m .39775 .52656 L .37974 .54043 L p
1 g
F P
s
P
p
.002 w
.37974 .54043 m .36197 .51221 L .38545 .50696 L p
1 g
F P
s
P
p
.002 w
.40509 .56235 m .37974 .54043 L .39775 .52656 L p
1 g
F P
s
P
p
.002 w
.39775 .52656 m .41534 .54176 L .40509 .56235 L p
1 g
F P
s
P
p
.002 w
.43548 .57574 m .40509 .56235 L .41534 .54176 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46787 .57916 m .47613 .57729 L p
.48446 .58009 L 1 g
F P
s
P
p
.51717 .5911 m .46982 .57964 L .48446 .58009 L 1 g
F
P
p
.46982 .57964 m .46787 .57916 L .48446 .58009 L 1 g
F
P
p
.51079 .57862 m .50088 .5806 L .50728 .5808 L 1 g
F
P
p
.002 w
.53774 .57807 m .51717 .5911 L .50788 .58142 L p
1 g
F P
s
P
p
.002 w
.50788 .58142 m .50728 .5808 L p
.51093 .58047 L 1 g
F P
s
P
p
.53774 .57807 m .50788 .58142 L .51093 .58047 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58047 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58047 L .52387 .57645 L 1 g
F
P
p
.002 w
.51093 .58047 m .51079 .57862 L p
.50728 .5808 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58023 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .58023 L .50088 .5806 L 1 g
F
P
p
.002 w
.48909 .58023 m .48921 .57862 L p
.47789 .57769 L 1 g
F P
s
P
p
.002 w
.51167 .58537 m .51717 .5911 L p
.4948 .58357 L 1 g
F P
s
P
p
.4948 .58357 m .47613 .57729 L .5 .58271 L 1 g
F
P
p
.4948 .58357 m .5 .58271 L .51167 .58537 L 1 g
F
P
p
.002 w
.50728 .5808 m .51167 .58537 L p
.48909 .58023 L 1 g
F P
s
P
p
.53774 .57807 m .51093 .58047 L .52498 .57611 L 1 g
F
P
p
.002 w
.55106 .56963 m .53774 .57807 L p
.52742 .57648 L 1 g
F P
s
P
p
.53036 .57477 m .52742 .57648 L .52498 .57611 L 1 g
F
P
p
.55106 .56963 m .52742 .57648 L .53036 .57477 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53159 .57406 L p
1 g
F P
s
P
p
.54854 .56129 m .53159 .57406 L .54075 .56871 L 1 g
F
P
p
.002 w
.53159 .57406 m .53128 .57265 L p
.52387 .57645 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53812 .57024 m .52498 .57611 L .49894 .57211 L 1 g
F
P
p
.54489 .56992 m .53159 .57406 L .53812 .57024 L 1 g
F
P
p
.53159 .57406 m .52498 .57611 L .53812 .57024 L 1 g
F
P
p
.55106 .56963 m .52498 .57611 L .54489 .56992 L 1 g
F
P
p
.54854 .56129 m .54075 .56871 L .54503 .56622 L 1 g
F
P
p
.002 w
.56581 .5501 m .55106 .56963 L .54622 .56689 L p
1 g
F P
s
P
p
.002 w
.54622 .56689 m .54503 .56622 L p
.54918 .563 L 1 g
F P
s
P
p
.56581 .5501 m .54622 .56689 L .54918 .563 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .563 L p
1 g
F P
s
P
p
.56075 .54566 m .54918 .563 L .55653 .5533 L 1 g
F
P
p
.002 w
.54918 .563 m .54854 .56129 L p
.54503 .56622 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5614 .54689 m .56075 .54566 L p
.55653 .5533 L 1 g
F P
s
P
p
.002 w
.54503 .56622 m .52538 .55511 L p
.55825 .55104 L 1 g
F P
s
P
p
.56581 .5501 m .54918 .563 L .55825 .55104 L 1 g
F
P
p
.54918 .563 m .54503 .56622 L .55825 .55104 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.5754 .5374 m .56581 .5501 L p
.55999 .55082 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5614 .54689 L p
1 g
F P
s
P
p
.56654 .52734 m .5614 .54689 L .5646 .53798 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56326 .5417 m .55999 .55082 L .52538 .55511 L 1 g
F
P
p
.5754 .5374 m .55999 .55082 L .56326 .5417 L 1 g
F
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.56654 .52734 m .5646 .53798 L .56566 .53501 L 1 g
F
P
p
.58719 .49766 m .56756 .53171 L .57228 .5088 L 1 g
F
P
p
.56756 .53171 m .56566 .53501 L .56731 .52847 L 1 g
F
P
p
.56756 .53171 m .56731 .52847 L .57228 .5088 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56731 .52847 L p
1 g
F P
s
P
p
.002 w
.58719 .49766 m .5754 .5374 L .56786 .53555 L p
1 g
F P
s
P
p
.002 w
.56786 .53555 m .56566 .53501 L p
.56756 .53171 L 1 g
F P
s
P
p
.58719 .49766 m .56786 .53555 L .56756 .53171 L 1 g
F
P
p
.002 w
.56583 .50906 m .56515 .50826 L p
.56637 .51618 L 1 g
F P
s
P
p
.56515 .50826 m .56731 .52847 L .56637 .51618 L 1 g
F
P
p
.002 w
.56731 .52847 m .56654 .52734 L p
.56566 .53501 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56566 .53501 m .54422 .52976 L p
.57228 .5088 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56583 .50906 L p
1 g
F P
s
P
p
.55661 .4905 m .56583 .50906 L .56197 .50076 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56089 .49843 m .58719 .49766 L p
.5674 .51245 L 1 g
F P
s
P
p
.002 w
.58472 .45476 m .58719 .49766 L .56089 .49843 L p
1 g
F P
s
P
p
.55802 .49194 m .56089 .49843 L .55783 .49221 L 1 g
F
P
p
.58472 .45476 m .56222 .496 L .55802 .49194 L 1 g
F
P
p
.56222 .496 m .56089 .49843 L .55802 .49194 L 1 g
F
P
p
.002 w
.55739 .49133 m .55661 .4905 L p
.56314 .50299 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55242 .48653 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55242 .48653 m .5532 .49866 L p
.54124 .47617 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54227 .47666 L p
1 g
F P
s
P
p
.52214 .46667 m .54227 .47666 L .53255 .47206 L 1 g
F
P
p
.54227 .47666 m .54124 .47617 L .54067 .47511 L 1 g
F
P
p
.55242 .48653 m .54124 .47617 L .54227 .47666 L 1 g
F
P
p
.002 w
.5532 .49866 m .51711 .49754 L p
.54067 .47511 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51711 .49754 m .51551 .47466 L .52994 .47082 L p
1 g
F P
s
P
p
.52214 .46667 m .53255 .47206 L .52994 .47082 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52994 .47082 m .51551 .47466 L p
.51974 .46682 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46718 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46718 L .51318 .46593 L 1 g
F
P
p
.52015 .46606 m .52245 .46718 L .51974 .46682 L 1 g
F
P
p
.52245 .46718 m .52994 .47082 L .51974 .46682 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50641 .45283 m .53789 .43321 L p
.51974 .46682 L 1 g
F P
s
P
p
.002 w
.51551 .47466 m .5118 .46575 L p
.51974 .46682 L 1 g
F P
s
P
p
.5 .4634 m .51318 .46593 L .5118 .46575 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5118 .46575 m .51551 .47466 L p
.49817 .46415 L 1 g
F P
s
P
p
.5118 .46575 m .49817 .46415 L .5 .46387 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46387 L p
1 g
F P
s
P
p
.002 w
.51551 .47466 m .47943 .48274 L p
.49589 .4645 L 1 g
F P
s
P
p
.49817 .46415 m .51551 .47466 L .49589 .4645 L 1 g
F
P
p
.47786 .46667 m .5 .46387 L .48912 .46552 L 1 g
F
P
p
.47786 .46667 m .48912 .46552 L .48379 .46634 L 1 g
F
P
p
.002 w
.48379 .46634 m .47479 .47171 L p
.47649 .46776 L 1 g
F P
s
P
p
.47751 .46726 m .48379 .46634 L .47649 .46776 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46726 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47479 .47171 m .44581 .48825 L p
.45662 .47775 L 1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.47292 .46953 m .47479 .47171 L p
.45662 .47775 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45767 .47673 L p
1 g
F P
s
P
p
.44339 .4905 m .45767 .47673 L .45082 .48338 L 1 g
F
P
p
.45767 .47673 m .45662 .47775 L .45286 .479 L 1 g
F
P
p
.47292 .46953 m .45662 .47775 L .45767 .47673 L 1 g
F
P
p
.002 w
.45767 .47673 m .45698 .47747 L p
.45082 .48338 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44243 .49152 L p
1 g
F P
s
P
p
.43485 .50826 m .44243 .49152 L .43976 .4971 L 1 g
F
P
p
.002 w
.42992 .51771 m .42851 .5171 L .43411 .50716 L p
1 g
F P
s
P
p
.002 w
.43411 .50716 m .43976 .4971 L p
.43388 .50941 L 1 g
F P
s
P
p
.42992 .51771 m .43411 .50716 L .43388 .50941 L 1 g
F
P
p
.43346 .52734 m .43311 .51721 L .43293 .51902 L 1 g
F
P
p
.002 w
.42851 .5171 m .42911 .51736 L p
.43234 .5335 L 1 g
F P
s
P
p
.002 w
.42911 .51736 m .43293 .51902 L p
.43254 .52869 L 1 g
F P
s
P
p
.43234 .5335 m .42911 .51736 L .43254 .52869 L 1 g
F
P
p
.43925 .54566 m .43532 .53789 L .43714 .5439 L 1 g
F
P
p
.002 w
.43951 .55131 m .43643 .551 L .43697 .5456 L p
1 g
F P
s
P
p
.002 w
.43697 .5456 m .43714 .5439 L p
.43829 .54748 L 1 g
F P
s
P
p
.43951 .55131 m .43697 .5456 L .43829 .54748 L 1 g
F
P
p
.002 w
.43548 .57574 m .43636 .55266 L p
.45509 .56771 L 1 g
F P
s
P
p
.002 w
.46787 .57916 m .46466 .57883 L p
.45754 .57055 L 1 g
F P
s
P
p
.45888 .57111 m .45754 .57055 L .45509 .56771 L 1 g
F
P
p
.46787 .57916 m .45754 .57055 L .45888 .57111 L 1 g
F
P
p
.46872 .57265 m .45982 .56909 L .46583 .57331 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46825 .57479 L p
1 g
F P
s
P
p
.002 w
.47338 .57792 m .46787 .57916 L .46611 .5741 L p
1 g
F P
s
P
p
.47338 .57792 m .46611 .5741 L .46825 .57479 L 1 g
F
P
p
.48921 .57862 m .46825 .57479 L .47722 .57763 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.49894 .57211 m .47613 .57729 L p
.45884 .55327 L 1 g
F P
s
P
p
.002 w
.47613 .57729 m .47338 .57792 L p
.47229 .57607 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.47613 .57729 m .47229 .57607 L .45884 .55327 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48901 .58138 L p
1 g
F P
s
P
p
.002 w
.48901 .58138 m .48909 .58023 L p
.48172 .57907 L 1 g
F P
s
P
p
.002 w
.46825 .57479 m .46872 .57265 L p
.46583 .57331 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45089 .56283 L p
1 g
F P
s
P
p
.46872 .57265 m .45089 .56283 L .45982 .56909 L 1 g
F
P
p
.002 w
.45089 .56283 m .45146 .56129 L p
.44388 .5547 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43829 .54748 L p
1 g
F P
s
P
p
.45146 .56129 m .43829 .54748 L .43992 .54979 L 1 g
F
P
p
.002 w
.44109 .55147 m .43951 .55131 L p
.4395 .54921 L 1 g
F P
s
P
p
.45146 .56129 m .43992 .54979 L .44388 .5547 L 1 g
F
P
p
.43951 .55131 m .43829 .54748 L .4395 .54921 L 1 g
F
P
p
.43992 .54979 m .43805 .54793 L .44109 .55147 L 1 g
F
P
p
.43992 .54979 m .44109 .55147 L .44388 .5547 L 1 g
F
P
p
.002 w
.43829 .54748 m .43925 .54566 L p
.43714 .5439 L 1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43643 .551 m .43234 .5335 L .43344 .53167 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43254 .52869 L p
1 g
F P
s
P
p
.43925 .54566 m .43254 .52869 L .43532 .53789 L 1 g
F
P
p
.002 w
.43936 .52182 m .43714 .5439 L p
.43344 .53167 L 1 g
F P
s
P
p
.002 w
.43714 .5439 m .43643 .551 L p
.43344 .53167 L 1 g
F P
s
P
p
.002 w
.43254 .52869 m .43346 .52734 L p
.43293 .51902 L 1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50941 L p
1 g
F P
s
P
p
.43346 .52734 m .43388 .50941 L .43311 .51721 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45085 .52293 m .43936 .52182 L .44413 .48988 L p
1 g
F P
s
P
p
.002 w
.47095 .51418 m .46178 .5203 L .44447 .48955 L p
1 g
F P
s
P
p
.002 w
.48032 .49433 m .47737 .50521 L .44467 .48936 L p
1 g
F P
s
P
p
.002 w
.47479 .47171 m .47943 .48274 L .44504 .489 L p
1 g
F P
s
P
p
.44339 .4905 m .45082 .48338 L .44581 .48825 L 1 g
F
P
p
.002 w
.44504 .489 m .44424 .48915 L .44581 .48825 L p
1 g
F P
s
P
p
.002 w
.44581 .48825 m .47479 .47171 L p
.44504 .489 L 1 g
F P
s
P
p
.44527 .48877 m .44581 .48825 L .44527 .48877 L 1 g
F
P
p
.44339 .4905 m .44581 .48825 L .44527 .48877 L 1 g
F
P
p
.44503 .48901 m .44527 .48877 L .44504 .489 L 1 g
F
P
p
.44339 .4905 m .44527 .48877 L .44503 .48901 L 1 g
F
P
p
.002 w
.47943 .48274 m .48032 .49433 L .4448 .48923 L p
1 g
F P
s
P
p
.002 w
.4448 .48923 m .44424 .48915 L .44504 .489 L p
1 g
F P
s
P
p
.002 w
.44504 .489 m .47943 .48274 L p
.4448 .48923 L 1 g
F P
s
P
p
.002 w
.44467 .48936 m .44424 .48915 L .4448 .48923 L p
1 g
F P
s
P
p
.002 w
.4448 .48923 m .48032 .49433 L p
.44467 .48936 L 1 g
F P
s
P
p
.44489 .48914 m .44504 .489 L .4449 .48914 L 1 g
F
P
p
.44339 .4905 m .44504 .489 L .44489 .48914 L 1 g
F
P
p
.4448 .48924 m .4449 .48914 L .4448 .48923 L 1 g
F
P
p
.44339 .4905 m .4449 .48914 L .4448 .48924 L 1 g
F
P
p
.002 w
.47737 .50521 m .47095 .51418 L .44457 .48946 L p
1 g
F P
s
P
p
.002 w
.44457 .48946 m .44424 .48915 L .44467 .48936 L p
1 g
F P
s
P
p
.002 w
.44467 .48936 m .47737 .50521 L p
.44457 .48946 L 1 g
F P
s
P
p
.002 w
.44447 .48955 m .44424 .48915 L .44457 .48946 L p
1 g
F P
s
P
p
.002 w
.44457 .48946 m .47095 .51418 L p
.44447 .48955 L 1 g
F P
s
P
p
.44472 .48931 m .4448 .48923 L .44473 .4893 L 1 g
F
P
p
.44339 .4905 m .4448 .48923 L .44472 .48931 L 1 g
F
P
p
.44466 .48937 m .44473 .4893 L .44466 .48936 L 1 g
F
P
p
.44339 .4905 m .44473 .4893 L .44466 .48937 L 1 g
F
P
p
.002 w
.46178 .5203 m .45085 .52293 L .44434 .48968 L p
1 g
F P
s
P
p
.002 w
.44434 .48968 m .44424 .48915 L .44447 .48955 L p
1 g
F P
s
P
p
.002 w
.44447 .48955 m .46178 .5203 L p
.44434 .48968 L 1 g
F P
s
P
p
.44339 .4905 m .44466 .48936 L .44461 .48942 L 1 g
F
P
p
.002 w
.44413 .48988 m .44424 .48915 L .44434 .48968 L p
1 g
F P
s
P
p
.002 w
.44434 .48968 m .45085 .52293 L p
.44413 .48988 L 1 g
F P
s
P
p
.44461 .48942 m .44466 .48936 L .44461 .48942 L 1 g
F
P
p
.002 w
.44243 .49152 m .44339 .4905 L p
.44461 .48942 L 1 g
F P
s
P
p
.43485 .50826 m .43976 .4971 L .43842 .49992 L 1 g
F
P
p
.002 w
.42851 .5171 m .42186 .51136 L p
.44243 .49152 L 1 g
F P
s
P
p
.002 w
.44346 .49052 m .43976 .4971 L p
.44243 .49152 L 1 g
F P
s
P
p
.002 w
.43976 .4971 m .42851 .5171 L p
.44243 .49152 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43387 .50942 L p
1 g
F P
s
P
p
.002 w
.43387 .50942 m .43485 .50826 L p
.43843 .4999 L 1 g
F P
s
P
p
.43843 .4999 m .44166 .49233 L .43387 .50942 L 1 g
F
P
p
.43293 .51902 m .43383 .5099 L .44363 .49037 L 1 g
F
P
p
.44386 .49014 m .44363 .49037 L .44424 .48915 L 1 g
F
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.43293 .51902 m .44363 .49037 L .44386 .49014 L 1 g
F
P
p
.002 w
.43936 .52182 m .43293 .51902 L p
.44386 .49014 L 1 g
F P
s
P
p
.002 w
.44413 .48988 m .43936 .52182 L p
.44386 .49014 L 1 g
F P
s
P
p
.002 w
.43976 .4971 m .44424 .48915 L p
.42992 .51771 L 1 g
F P
s
P
p
.002 w
.44243 .49152 m .44166 .49233 L p
.43843 .4999 L 1 g
F P
s
P
p
.44461 .48942 m .45698 .47747 L .44227 .49169 L 1 g
F
P
p
.45082 .48338 m .45689 .47756 L .44461 .48942 L 1 g
F
P
p
.45689 .47756 m .45698 .47747 L .44461 .48942 L 1 g
F
P
p
.002 w
.44227 .49169 m .44243 .49152 L p
.44461 .48942 L 1 g
F P
s
P
p
.002 w
.44424 .48915 m .44413 .48988 L p
.44386 .49014 L 1 g
F P
s
P
p
.002 w
.43293 .51902 m .42992 .51771 L p
.43383 .5099 L 1 g
F P
s
P
p
.002 w
.43388 .50941 m .43287 .51061 L p
.43311 .51721 L 1 g
F P
s
P
p
.002 w
.43293 .51902 m .43936 .52182 L p
.43234 .5335 L 1 g
F P
s
P
p
.002 w
.43643 .551 m .41534 .54176 L .42851 .5171 L p
1 g
F P
s
P
p
.002 w
.43254 .52869 m .43146 .53025 L p
.43532 .53789 L 1 g
F P
s
P
p
.002 w
.43714 .5439 m .43936 .52182 L p
.4395 .54921 L 1 g
F P
s
P
p
.43829 .54748 m .43714 .5439 L .4395 .54921 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45884 .55327 m .44109 .55147 L p
.43936 .52182 L 1 g
F P
s
P
p
.44109 .55147 m .4395 .54921 L .43936 .52182 L 1 g
F
P
p
.002 w
.43829 .54748 m .43805 .54793 L p
.43992 .54979 L 1 g
F P
s
P
p
.002 w
.43643 .551 m .44109 .55147 L p
.44873 .56033 L 1 g
F P
s
P
p
.002 w
.43805 .54793 m .43743 .5491 L p
.44388 .5547 L 1 g
F P
s
P
p
.002 w
.45884 .55327 m .46583 .57331 L p
.44873 .56033 L 1 g
F P
s
P
p
.002 w
.44109 .55147 m .45884 .55327 L p
.44873 .56033 L 1 g
F P
s
P
p
.002 w
.46583 .57331 m .46787 .57916 L p
.44518 .55883 L 1 g
F P
s
P
p
.44518 .55883 m .43643 .551 L .46583 .57331 L 1 g
F
P
p
.45509 .56771 m .43636 .55266 L .44518 .55883 L 1 g
F
P
p
.002 w
.45089 .56283 m .45002 .56518 L p
.45982 .56909 L 1 g
F P
s
P
p
.002 w
.46583 .57331 m .45884 .55327 L p
.47229 .57607 L 1 g
F P
s
P
p
.47338 .57792 m .46825 .57479 L .47229 .57607 L 1 g
F
P
p
.46825 .57479 m .46583 .57331 L .47229 .57607 L 1 g
F
P
p
.47789 .57769 m .47722 .57763 L .48909 .58023 L 1 g
F
P
p
.47722 .57763 m .4678 .57686 L .48172 .57907 L 1 g
F
P
p
.47722 .57763 m .48172 .57907 L .48909 .58023 L 1 g
F
P
p
.48172 .57907 m .4678 .57686 L .48901 .58138 L 1 g
F
P
p
.002 w
.46825 .57479 m .4678 .57686 L p
.47722 .57763 L 1 g
F P
s
P
p
.002 w
.46611 .5741 m .46583 .57331 L p
.46825 .57479 L 1 g
F P
s
P
p
.002 w
.46821 .57498 m .46825 .57479 L p
.46583 .57331 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .46687 .58109 L p
.48722 .58285 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .48446 .58171 L p
.48722 .58285 L 1 g
F P
s
P
p
.002 w
.48446 .58171 m .4678 .57686 L p
.48722 .58285 L 1 g
F P
s
P
p
.002 w
.46466 .57883 m .43548 .57574 L p
.45509 .56771 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46821 .57498 L p
1 g
F P
s
P
p
.45982 .56909 m .45002 .56518 L .46821 .57498 L 1 g
F
P
p
.002 w
.43636 .55266 m .43643 .551 L p
.44518 .55883 L 1 g
F P
s
P
p
.002 w
.45026 .56451 m .45089 .56283 L p
.44256 .55356 L 1 g
F P
s
P
p
.44388 .5547 m .44256 .55356 L .45089 .56283 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45026 .56451 L p
1 g
F P
s
P
p
.44256 .55356 m .43743 .5491 L .45026 .56451 L 1 g
F
P
p
.002 w
.43825 .54755 m .43829 .54748 L p
.43714 .5439 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43825 .54755 L p
1 g
F P
s
P
p
.43532 .53789 m .43146 .53025 L .43825 .54755 L 1 g
F
P
p
.002 w
.43187 .52966 m .43254 .52869 L p
.43293 .51902 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43187 .52966 L p
1 g
F P
s
P
p
.43311 .51721 m .43287 .51061 L .43187 .52966 L 1 g
F
P
p
.43842 .49992 m .43976 .4971 L .43843 .4999 L 1 g
F
P
p
.002 w
.44424 .48915 m .44346 .49052 L p
.44258 .49122 L 1 g
F P
s
P
p
.002 w
.41947 .50929 m .44314 .49004 L p
.44258 .49122 L 1 g
F P
s
P
p
.002 w
.44314 .49004 m .44424 .48915 L p
.44258 .49122 L 1 g
F P
s
P
p
.002 w
.42186 .51136 m .41947 .50929 L p
.44346 .49052 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44227 .49169 L p
.45427 .4801 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .45627 .47817 L p
.45427 .4801 L 1 g
F P
s
P
p
.002 w
.45627 .47817 m .44166 .49233 L p
.45427 .4801 L 1 g
F P
s
P
p
.002 w
.44424 .48915 m .45286 .479 L p
.45662 .47775 L 1 g
F P
s
P
p
.002 w
.44581 .48825 m .44424 .48915 L p
.45662 .47775 L 1 g
F P
s
P
p
.45826 .47608 m .47751 .46726 L .47086 .47055 L 1 g
F
P
p
.002 w
.45704 .47742 m .45826 .47608 L p
.47086 .47055 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45286 .479 m .46689 .46248 L .47292 .46953 L p
1 g
F P
s
P
p
.002 w
.47479 .47171 m .46689 .46248 L .49081 .43453 L p
1 g
F P
s
P
p
.47086 .47055 m .47292 .46953 L .47718 .46778 L 1 g
F
P
p
.002 w
.47751 .46726 m .47741 .46742 L p
.47292 .46953 L 1 g
F P
s
P
p
.002 w
.47741 .46742 m .47718 .46778 L p
.47292 .46953 L 1 g
F P
s
P
p
.002 w
.47751 .46726 m .47786 .46667 L p
.48379 .46634 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.49081 .43453 m .48434 .46387 L .47665 .46738 L 1 g
F
P
p
.48434 .46387 m .48379 .46634 L .47751 .46726 L 1 g
F
P
p
.48434 .46387 m .47751 .46726 L .47665 .46738 L 1 g
F
P
p
.47665 .46738 m .47751 .46726 L .47649 .46776 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45704 .47742 L p
1 g
F P
s
P
p
.47086 .47055 m .47718 .46778 L .45704 .47742 L 1 g
F
P
p
.002 w
.47748 .46729 m .47751 .46726 L p
.48379 .46634 L 1 g
F P
s
P
p
.002 w
.49081 .43453 m .50641 .45283 L .48379 .46634 L p
1 g
F P
s
P
p
.002 w
.47943 .48274 m .47479 .47171 L .50641 .45283 L p
1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .46442 L p
.48912 .46552 L 1 g
F P
s
P
p
.4969 .46338 m .49817 .46415 L .49589 .4645 L 1 g
F
P
p
.5 .46387 m .49817 .46415 L .4969 .46338 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47748 .46729 L p
1 g
F P
s
P
p
.48912 .46552 m .5 .46442 L .47748 .46729 L 1 g
F
P
p
.002 w
.5 .46416 m .5 .46387 L p
.5118 .46575 L 1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .4634 L p
.5118 .46575 L 1 g
F P
s
P
p
.002 w
.50641 .45283 m .5118 .46575 L p
.4969 .46338 L 1 g
F P
s
P
p
.002 w
.5118 .46575 m .50641 .45283 L p
.51974 .46682 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46416 L p
1 g
F P
s
P
p
.51318 .46593 m .52282 .46778 L .5 .46416 L 1 g
F
P
p
.002 w
.52245 .46718 m .52282 .46778 L p
.51318 .46593 L 1 g
F P
s
P
p
.002 w
.52253 .46732 m .52245 .46718 L p
.52994 .47082 L 1 g
F P
s
P
p
.002 w
.52245 .46718 m .52214 .46667 L p
.52994 .47082 L 1 g
F P
s
P
p
.002 w
.53789 .43321 m .55107 .46521 L .52994 .47082 L p
1 g
F P
s
P
p
.53789 .43321 m .52994 .47082 L .52015 .46606 L 1 g
F
P
p
.002 w
.52994 .47082 m .55107 .46521 L p
.54011 .47564 L 1 g
F P
s
P
p
.54011 .47564 m .51711 .49754 L .52994 .47082 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52253 .46732 L p
1 g
F P
s
P
p
.53255 .47206 m .54302 .47747 L .52253 .46732 L 1 g
F
P
p
.002 w
.54227 .47666 m .54302 .47747 L p
.53255 .47206 L 1 g
F P
s
P
p
.55021 .48437 m .55242 .48653 L .55101 .48516 L 1 g
F
P
p
.54174 .47608 m .55242 .48653 L .55021 .48437 L 1 g
F
P
p
.002 w
.55107 .46521 m .55242 .48653 L p
.54067 .47511 L 1 g
F P
s
P
p
.002 w
.55107 .46521 m .58472 .45476 L p
.55802 .49194 L 1 g
F P
s
P
p
.002 w
.5532 .49866 m .55242 .48653 L p
.55802 .49194 L 1 g
F P
s
P
p
.002 w
.55242 .48653 m .55107 .46521 L p
.55802 .49194 L 1 g
F P
s
P
p
.002 w
.55748 .49149 m .55834 .49233 L .55739 .49133 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .55748 .4915 L p
.56713 .51061 L 1 g
F P
s
P
p
.56314 .50299 m .56713 .51061 L .55739 .49133 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54262 .47704 L p
1 g
F P
s
P
p
.002 w
.54262 .47704 m .54174 .47608 L p
.55101 .48516 L 1 g
F P
s
P
p
.55101 .48516 m .55834 .49233 L .54262 .47704 L 1 g
F
P
p
.002 w
.55739 .49133 m .55834 .49233 L p
.55101 .48516 L 1 g
F P
s
P
p
.002 w
.56089 .49843 m .5532 .49866 L p
.55783 .49221 L 1 g
F P
s
P
p
.002 w
.54422 .52976 m .5532 .49866 L .56089 .49843 L p
1 g
F P
s
P
p
.5674 .51245 m .54422 .52976 L .56089 .49843 L 1 g
F
P
p
.002 w
.56583 .50906 m .56713 .51061 L p
.56197 .50076 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56583 .50906 L p
1 g
F P
s
P
p
.56637 .51618 m .56854 .53025 L .56583 .50906 L 1 g
F
P
p
.002 w
.56731 .52847 m .56854 .53025 L p
.56637 .51618 L 1 g
F P
s
P
p
.002 w
.56777 .52913 m .56731 .52847 L p
.56566 .53501 L 1 g
F P
s
P
p
.002 w
.52538 .55511 m .54422 .52976 L .56566 .53501 L p
1 g
F P
s
P
p
.002 w
.56566 .53501 m .5754 .5374 L p
.56326 .5417 L 1 g
F P
s
P
p
.56326 .5417 m .52538 .55511 L .56566 .53501 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56777 .52913 L p
1 g
F P
s
P
p
.5646 .53798 m .56257 .5491 L .56777 .52913 L 1 g
F
P
p
.002 w
.5614 .54689 m .56257 .5491 L p
.5646 .53798 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5614 .54689 L p
1 g
F P
s
P
p
.55653 .5533 m .54998 .56518 L .5614 .54689 L 1 g
F
P
p
.002 w
.54918 .563 m .54998 .56518 L p
.55653 .5533 L 1 g
F P
s
P
p
.002 w
.54942 .56366 m .54918 .563 L p
.54503 .56622 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.49894 .57211 m .52538 .55511 L .55106 .56963 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54942 .56366 L p
1 g
F P
s
P
p
.54075 .56871 m .5322 .57686 L .54942 .56366 L 1 g
F
P
p
.002 w
.53159 .57406 m .5322 .57686 L p
.54075 .56871 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53159 .57406 L p
1 g
F P
s
P
p
.52387 .57645 m .51111 .583 L .53159 .57406 L 1 g
F
P
p
.002 w
.50728 .5808 m .49894 .57211 L p
.52498 .57611 L 1 g
F P
s
P
p
.51093 .58047 m .50728 .5808 L .52498 .57611 L 1 g
F
P
p
.002 w
.51111 .583 m .51143 .5874 L p
.53055 .5777 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .52774 .57816 L p
.53055 .5777 L 1 g
F P
s
P
p
.002 w
.52774 .57816 m .51111 .583 L p
.53055 .5777 L 1 g
F P
s
P
p
.002 w
.47613 .57729 m .49894 .57211 L .50728 .5808 L p
1 g
F P
s
P
p
.48909 .58023 m .47613 .57729 L .50728 .5808 L 1 g
F
P
p
.002 w
.48909 .58023 m .48889 .583 L p
.50088 .5806 L 1 g
F P
s
P
p
.002 w
.51093 .58047 m .51111 .583 L p
.52387 .57645 L 1 g
F P
s
P
p
.002 w
.51096 .58091 m .51093 .58047 L p
.50728 .5808 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58091 L p
1 g
F P
s
P
p
.50088 .5806 m .48889 .583 L .51096 .58091 L 1 g
F
P
p
.004 w
.49335 .43751 m
.5 .43051 L
s
P
p
.002 w
.46444 .31417 m .41438 .31961 L .41601 .29358 L p
1 g
F P
s
P
p
.002 w
.41601 .29358 m .47221 .28719 L .46444 .31417 L p
1 g
F P
s
P
p
.002 w
.37976 .48498 m .38545 .50696 L .36197 .51221 L p
1 g
F P
s
P
p
.002 w
.36197 .51221 m .35363 .48048 L .37976 .48498 L p
1 g
F P
s
P
p
.002 w
.41534 .54176 m .43643 .551 L .43548 .57574 L p
1 g
F P
s
P
p
.002 w
.58059 .33162 m .52938 .30025 L .5422 .27915 L p
1 g
F P
s
P
p
.002 w
.5422 .27915 m .5974 .31286 L .58059 .33162 L p
1 g
F P
s
P
p
.002 w
.41534 .34975 m .37844 .36771 L .37081 .34118 L p
1 g
F P
s
P
p
.002 w
.37081 .34118 m .41438 .31961 L .41534 .34975 L p
1 g
F P
s
P
p
.002 w
.60359 .54164 m .61787 .49464 L .64423 .48977 L p
1 g
F P
s
P
p
.002 w
.64152 .43258 m .64423 .48977 L .61787 .49464 L p
1 g
F P
s
P
p
.002 w
.64152 .43258 m .61954 .37762 L .6393 .36242 L p
1 g
F P
s
P
p
.002 w
.5974 .31286 m .6393 .36242 L .61954 .37762 L p
1 g
F P
s
P
p
.002 w
.38132 .46289 m .37976 .48498 L .35363 .48048 L p
1 g
F P
s
P
p
.002 w
.35363 .48048 m .35572 .44848 L .38132 .46289 L p
1 g
F P
s
P
p
.002 w
.39 .39684 m .3682 .41954 L .35081 .39693 L p
1 g
F P
s
P
p
.002 w
.35081 .39693 m .37844 .36771 L .39 .39684 L p
1 g
F P
s
P
p
.002 w
.61954 .37762 m .58059 .33162 L .5974 .31286 L p
1 g
F P
s
P
p
.002 w
.55106 .56963 m .5754 .5374 L .60359 .54164 L p
1 g
F P
s
P
p
.002 w
.61787 .49464 m .60359 .54164 L .5754 .5374 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.51528 .32598 m .46444 .31417 L .47221 .28719 L p
1 g
F P
s
P
p
.002 w
.47221 .28719 m .52938 .30025 L .51528 .32598 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39007 .44303 m .38132 .46289 L .35572 .44848 L p
1 g
F P
s
P
p
.002 w
.35572 .44848 m .3682 .41954 L .39007 .44303 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.45884 .55327 m .48025 .54828 L .49894 .57211 L p
1 g
F P
s
P
p
.002 w
.52538 .55511 m .49894 .57211 L .48025 .54828 L p
1 g
F P
s
P
p
.002 w
.61787 .49464 m .61522 .44374 L .64152 .43258 L p
1 g
F P
s
P
p
.002 w
.61954 .37762 m .64152 .43258 L .61522 .44374 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41317 .49921 m .41947 .50929 L .39775 .52656 L p
1 g
F P
s
P
p
.002 w
.39775 .52656 m .38545 .50696 L .41317 .49921 L p
1 g
F P
s
P
p
.002 w
.41534 .54176 m .39775 .52656 L .41947 .50929 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45758 .34542 m .41534 .34975 L .41438 .31961 L p
1 g
F P
s
P
p
.002 w
.41438 .31961 m .46444 .31417 L .45758 .34542 L p
1 g
F P
s
P
p
.002 w
.41947 .50929 m .42851 .5171 L .41534 .54176 L p
1 g
F P
s
P
p
.002 w
.4103 .48793 m .41317 .49921 L .38545 .50696 L p
1 g
F P
s
P
p
.002 w
.38545 .50696 m .37976 .48498 L .4103 .48793 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.41893 .38303 m .39 .39684 L .37844 .36771 L p
1 g
F P
s
P
p
.002 w
.37844 .36771 m .41534 .34975 L .41893 .38303 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5754 .5374 m .58719 .49766 L .61787 .49464 L p
1 g
F P
s
P
p
.002 w
.61522 .44374 m .61787 .49464 L .58719 .49766 L p
1 g
F P
s
P
p
.002 w
.56081 .35397 m .51528 .32598 L .52938 .30025 L p
1 g
F P
s
P
p
.002 w
.52938 .30025 m .58059 .33162 L .56081 .35397 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.40518 .42756 m .39007 .44303 L .3682 .41954 L p
1 g
F P
s
P
p
.002 w
.3682 .41954 m .39 .39684 L .40518 .42756 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.41117 .47663 m .4103 .48793 L .37976 .48498 L p
1 g
F P
s
P
p
.002 w
.37976 .48498 m .38132 .46289 L .41117 .47663 L p
1 g
F P
s
P
p
.002 w
.61522 .44374 m .59551 .39488 L .61954 .37762 L p
1 g
F P
s
P
p
.002 w
.58059 .33162 m .61954 .37762 L .59551 .39488 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43936 .52182 m .45085 .52293 L .45884 .55327 L p
1 g
F P
s
P
p
.002 w
.48025 .54828 m .45884 .55327 L .45085 .52293 L p
1 g
F P
s
P
p
.002 w
.59551 .39488 m .56081 .35397 L .58059 .33162 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48025 .54828 m .49835 .53643 L .52538 .55511 L p
1 g
F P
s
P
p
.002 w
.54422 .52976 m .52538 .55511 L .49835 .53643 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41571 .46653 m .41117 .47663 L .38132 .46289 L p
1 g
F P
s
P
p
.002 w
.38132 .46289 m .39007 .44303 L .41571 .46653 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.50038 .35556 m .45758 .34542 L .46444 .31417 L p
1 g
F P
s
P
p
.002 w
.46444 .31417 m .51528 .32598 L .50038 .35556 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.45085 .52293 m .46178 .5203 L .48025 .54828 L p
1 g
F P
s
P
p
.002 w
.49835 .53643 m .48025 .54828 L .46178 .5203 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45191 .37987 m .41893 .38303 L .41534 .34975 L p
1 g
F P
s
P
p
.002 w
.41534 .34975 m .45758 .34542 L .45191 .37987 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58719 .49766 m .58472 .45476 L .61522 .44374 L p
1 g
F P
s
P
p
.002 w
.59551 .39488 m .61522 .44374 L .58472 .45476 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4251 .41826 m .40518 .42756 L .39 .39684 L p
1 g
F P
s
P
p
.002 w
.39 .39684 m .41893 .38303 L .4251 .41826 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.41947 .50929 m .41317 .49921 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.41317 .49921 m .4103 .48793 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.42348 .45873 m .41571 .46653 L .39007 .44303 L p
1 g
F P
s
P
p
.002 w
.39007 .44303 m .40518 .42756 L .42348 .45873 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.49835 .53643 m .51114 .51891 L .54422 .52976 L p
1 g
F P
s
P
p
.002 w
.5532 .49866 m .54422 .52976 L .51114 .51891 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4103 .48793 m .41117 .47663 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.46178 .5203 m .47095 .51418 L .49835 .53643 L p
1 g
F P
s
P
p
.002 w
.51114 .51891 m .49835 .53643 L .47095 .51418 L p
1 g
F P
s
P
p
.002 w
.53871 .3792 m .50038 .35556 L .51528 .32598 L p
1 g
F P
s
P
p
.002 w
.51528 .32598 m .56081 .35397 L .53871 .3792 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58472 .45476 m .56796 .41364 L .59551 .39488 L p
1 g
F P
s
P
p
.002 w
.56081 .35397 m .59551 .39488 L .56796 .41364 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.41117 .47663 m .41571 .46653 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56796 .41364 m .53871 .3792 L .56081 .35397 L p
1 g
F P
s
P
p
.002 w
.48525 .38792 m .45191 .37987 L .45758 .34542 L p
1 g
F P
s
P
p
.002 w
.45758 .34542 m .50038 .35556 L .48525 .38792 L p
1 g
F P
s
P
p
.002 w
.43364 .45409 m .42348 .45873 L .40518 .42756 L p
1 g
F P
s
P
p
.002 w
.40518 .42756 m .4251 .41826 L .43364 .45409 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.4477 .41625 m .4251 .41826 L .41893 .38303 L p
1 g
F P
s
P
p
.002 w
.41893 .38303 m .45191 .37987 L .4477 .41625 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.41571 .46653 m .42348 .45873 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47095 .51418 m .47737 .50521 L .51114 .51891 L p
1 g
F P
s
P
p
.002 w
.51711 .49754 m .51114 .51891 L .47737 .50521 L p
1 g
F P
s
P
p
.002 w
.51114 .51891 m .51711 .49754 L .5532 .49866 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56796 .41364 m .58472 .45476 L .55107 .46521 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.42348 .45873 m .43364 .45409 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.45661 .45605 m .46689 .46248 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.44511 .45316 m .45661 .45605 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.43364 .45409 m .44511 .45316 L .44424 .48915 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.004 w
.44245 .49103 m
.44424 .48915 L
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.47737 .50521 m .48032 .49433 L .51711 .49754 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.44511 .45316 m .43364 .45409 L .4251 .41826 L p
1 g
F P
s
P
p
.002 w
.4251 .41826 m .4477 .41625 L .44511 .45316 L p
1 g
F P
s
P
p
.002 w
.51507 .4064 m .48525 .38792 L .50038 .35556 L p
1 g
F P
s
P
p
.002 w
.50038 .35556 m .53871 .3792 L .51507 .4064 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55107 .46521 m .53789 .43321 L .56796 .41364 L p
1 g
F P
s
P
p
.002 w
.53871 .3792 m .56796 .41364 L .53789 .43321 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.47046 .42187 m .4477 .41625 L .45191 .37987 L p
1 g
F P
s
P
p
.002 w
.45191 .37987 m .48525 .38792 L .47046 .42187 L p
1 g
F P
s
P
p
.002 w
.51551 .47466 m .51711 .49754 L .48032 .49433 L p
1 g
F P
s
P
p
.002 w
.48032 .49433 m .47943 .48274 L .51551 .47466 L p
1 g
F P
s
P
p
.002 w
.53789 .43321 m .51507 .4064 L .53871 .3792 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.45661 .45605 m .44511 .45316 L .4477 .41625 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.4477 .41625 m .47046 .42187 L .45661 .45605 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46689 .46248 m .45661 .45605 L .47046 .42187 L p
1 g
F P
s
P
p
.002 w
.47046 .42187 m .49081 .43453 L .46689 .46248 L p
1 g
F P
s
P
p
.002 w
.49081 .43453 m .47046 .42187 L .48525 .38792 L p
1 g
F P
s
P
p
.002 w
.48525 .38792 m .51507 .4064 L .49081 .43453 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51507 .4064 m .53789 .43321 L .50641 .45283 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.50641 .45283 m .49081 .43453 L .51507 .4064 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.004 w
.41008 .52507 m
.44245 .49103 L
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .31706 .24782 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .41008 .52507 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.482946)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.482946)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47309 .43203 m .48559 .44565 L .50325 .42321 L p
1 g
F P
s
P
p
.002 w
.50325 .42321 m .49693 .4163 L .47309 .43203 L p
1 g
F P
s
P
p
.002 w
.51145 .42775 m .50325 .42321 L .48559 .44565 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .49693 .4163 L .50325 .42321 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .50325 .42321 L .51145 .42775 L closepath p
1 g
F P
s
P
p
.002 w
.48559 .44565 m .50177 .45461 L .51145 .42775 L p
1 g
F P
s
P
p
.002 w
.52065 .42942 m .51145 .42775 L .50177 .45461 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .51145 .42775 L .52065 .42942 L closepath p
1 g
F P
s
P
p
.002 w
.4656 .41518 m .47309 .43203 L .49693 .4163 L p
1 g
F P
s
P
p
.002 w
.49693 .4163 m .49316 .40777 L .4656 .41518 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .49316 .40777 L .49693 .4163 L closepath p
1 g
F P
s
P
p
.002 w
.50177 .45461 m .51992 .45796 L .52065 .42942 L p
1 g
F P
s
P
p
.002 w
.52985 .42806 m .52065 .42942 L .51992 .45796 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .52065 .42942 L .52985 .42806 L closepath p
1 g
F P
s
P
p
.002 w
.44978 .44779 m .46819 .46783 L .48559 .44565 L p
1 g
F P
s
P
p
.002 w
.48559 .44565 m .47309 .43203 L .44978 .44779 L p
1 g
F P
s
P
p
.002 w
.50177 .45461 m .48559 .44565 L .46819 .46783 L p
1 g
F P
s
P
p
.002 w
.46395 .39688 m .4656 .41518 L .49316 .40777 L p
1 g
F P
s
P
p
.002 w
.49316 .40777 m .49235 .39851 L .46395 .39688 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .49235 .39851 L .49316 .40777 L closepath p
1 g
F P
s
P
p
.002 w
.46819 .46783 m .492 .48103 L .50177 .45461 L p
1 g
F P
s
P
p
.002 w
.51992 .45796 m .50177 .45461 L .492 .48103 L p
1 g
F P
s
P
p
.002 w
.43871 .42301 m .44978 .44779 L .47309 .43203 L p
1 g
F P
s
P
p
.002 w
.47309 .43203 m .4656 .41518 L .43871 .42301 L p
1 g
F P
s
P
p
.002 w
.51992 .45796 m .53812 .45532 L .52985 .42806 L p
1 g
F P
s
P
p
.002 w
.53807 .4238 m .52985 .42806 L .53812 .45532 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .52985 .42806 L .53807 .4238 L closepath p
1 g
F P
s
P
p
.002 w
.46834 .3791 m .46395 .39688 L .49235 .39851 L p
1 g
F P
s
P
p
.002 w
.49235 .39851 m .4946 .38953 L .46834 .3791 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .4946 .38953 L .49235 .39851 L closepath p
1 g
F P
s
P
p
.002 w
.492 .48103 m .51872 .486 L .51992 .45796 L p
1 g
F P
s
P
p
.002 w
.53812 .45532 m .51992 .45796 L .51872 .486 L p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .50704 .37617 L .49968 .3818 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .49968 .3818 L .4946 .38953 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .53807 .4238 L .54443 .41708 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .54443 .41708 L .54821 .40862 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .54821 .40862 L .54901 .39935 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .54901 .39935 L .54672 .39027 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .54672 .39027 L .54159 .38237 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .54159 .38237 L .53417 .37652 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .53417 .37652 L .52528 .37337 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .52528 .37337 L .5159 .37325 L closepath p
1 g
F P
s
P
p
.002 w
.52087 .40091 m .5159 .37325 L .50704 .37617 L closepath p
1 g
F P
s
P
p
.002 w
.43619 .39606 m .43871 .42301 L .4656 .41518 L p
1 g
F P
s
P
p
.002 w
.4656 .41518 m .46395 .39688 L .43619 .39606 L p
1 g
F P
s
P
p
.002 w
.53812 .45532 m .55442 .44694 L .53807 .4238 L p
1 g
F P
s
P
p
.002 w
.54443 .41708 m .53807 .4238 L .55442 .44694 L p
1 g
F P
s
P
p
.002 w
.47833 .36375 m .46834 .3791 L .4946 .38953 L p
1 g
F P
s
P
p
.002 w
.4946 .38953 m .49968 .3818 L .47833 .36375 L p
1 g
F P
s
P
p
.002 w
.51872 .486 m .54553 .48218 L .53812 .45532 L p
1 g
F P
s
P
p
.002 w
.55442 .44694 m .53812 .45532 L .54553 .48218 L p
1 g
F P
s
P
p
.002 w
.55442 .44694 m .56706 .43368 L .54443 .41708 L p
1 g
F P
s
P
p
.002 w
.54821 .40862 m .54443 .41708 L .56706 .43368 L p
1 g
F P
s
P
p
.002 w
.4929 .35251 m .47833 .36375 L .49968 .3818 L p
1 g
F P
s
P
p
.002 w
.49968 .3818 m .50704 .37617 L .4929 .35251 L p
1 g
F P
s
P
p
.002 w
.42743 .46332 m .45138 .48934 L .46819 .46783 L p
1 g
F P
s
P
p
.002 w
.46819 .46783 m .44978 .44779 L .42743 .46332 L p
1 g
F P
s
P
p
.002 w
.492 .48103 m .46819 .46783 L .45138 .48934 L p
1 g
F P
s
P
p
.002 w
.44256 .36981 m .43619 .39606 L .46395 .39688 L p
1 g
F P
s
P
p
.002 w
.46395 .39688 m .46834 .3791 L .44256 .36981 L p
1 g
F P
s
P
p
.002 w
.45138 .48934 m .48232 .50651 L .492 .48103 L p
1 g
F P
s
P
p
.002 w
.51872 .486 m .492 .48103 L .48232 .50651 L p
1 g
F P
s
P
p
.002 w
.56706 .43368 m .57463 .41695 L .54821 .40862 L p
1 g
F P
s
P
p
.002 w
.54901 .39935 m .54821 .40862 L .57463 .41695 L p
1 g
F P
s
P
p
.002 w
.41297 .43112 m .42743 .46332 L .44978 .44779 L p
1 g
F P
s
P
p
.002 w
.44978 .44779 m .43871 .42301 L .41297 .43112 L p
1 g
F P
s
P
p
.002 w
.51047 .34665 m .4929 .35251 L .50704 .37617 L p
1 g
F P
s
P
p
.002 w
.50704 .37617 m .5159 .37325 L .51047 .34665 L p
1 g
F P
s
P
p
.002 w
.54553 .48218 m .56961 .46991 L .55442 .44694 L p
1 g
F P
s
P
p
.002 w
.56706 .43368 m .55442 .44694 L .56961 .46991 L p
1 g
F P
s
P
p
.002 w
.57463 .41695 m .57627 .39854 L .54901 .39935 L p
1 g
F P
s
P
p
.002 w
.54672 .39027 m .54901 .39935 L .57627 .39854 L p
1 g
F P
s
P
p
.002 w
.48232 .50651 m .51703 .51302 L .51872 .486 L p
1 g
F P
s
P
p
.002 w
.54553 .48218 m .51872 .486 L .51703 .51302 L p
1 g
F P
s
P
p
.002 w
.52913 .34685 m .51047 .34665 L .5159 .37325 L p
1 g
F P
s
P
p
.002 w
.5159 .37325 m .52528 .37337 L .52913 .34685 L p
1 g
F P
s
P
p
.002 w
.45724 .34709 m .44256 .36981 L .46834 .3791 L p
1 g
F P
s
P
p
.002 w
.46834 .3791 m .47833 .36375 L .45724 .34709 L p
1 g
F P
s
P
p
.002 w
.57627 .39854 m .57176 .38048 L .54672 .39027 L p
1 g
F P
s
P
p
.002 w
.54159 .38237 m .54672 .39027 L .57176 .38048 L p
1 g
F P
s
P
p
.002 w
.40959 .39608 m .41297 .43112 L .43871 .42301 L p
1 g
F P
s
P
p
.002 w
.43871 .42301 m .43619 .39606 L .40959 .39608 L p
1 g
F P
s
P
p
.002 w
.54682 .35311 m .52913 .34685 L .52528 .37337 L p
1 g
F P
s
P
p
.002 w
.52528 .37337 m .53417 .37652 L .54682 .35311 L p
1 g
F P
s
P
p
.002 w
.57176 .38048 m .56158 .36475 L .54159 .38237 L p
1 g
F P
s
P
p
.002 w
.53417 .37652 m .54159 .38237 L .56158 .36475 L p
1 g
F P
s
P
p
.002 w
.56158 .36475 m .54682 .35311 L .53417 .37652 L p
1 g
F P
s
P
p
.002 w
.56961 .46991 m .58833 .45041 L .56706 .43368 L p
1 g
F P
s
P
p
.002 w
.57463 .41695 m .56706 .43368 L .58833 .45041 L p
1 g
F P
s
P
p
.002 w
.51703 .51302 m .55193 .50815 L .54553 .48218 L p
1 g
F P
s
P
p
.002 w
.56961 .46991 m .54553 .48218 L .55193 .50815 L p
1 g
F P
s
P
p
.002 w
.47871 .3304 m .45724 .34709 L .47833 .36375 L p
1 g
F P
s
P
p
.002 w
.47833 .36375 m .4929 .35251 L .47871 .3304 L p
1 g
F P
s
P
p
.002 w
.41777 .36187 m .40959 .39608 L .43619 .39606 L p
1 g
F P
s
P
p
.002 w
.43619 .39606 m .44256 .36981 L .41777 .36187 L p
1 g
F P
s
P
p
.002 w
.58833 .45041 m .59961 .42573 L .57463 .41695 L p
1 g
F P
s
P
p
.002 w
.57627 .39854 m .57463 .41695 L .59961 .42573 L p
1 g
F P
s
P
p
.002 w
.40648 .47831 m .43548 .50977 L .45138 .48934 L p
1 g
F P
s
P
p
.002 w
.45138 .48934 m .42743 .46332 L .40648 .47831 L p
1 g
F P
s
P
p
.002 w
.48232 .50651 m .45138 .48934 L .43548 .50977 L p
1 g
F P
s
P
p
.002 w
.43548 .50977 m .4729 .53055 L .48232 .50651 L p
1 g
F P
s
P
p
.002 w
.51703 .51302 m .48232 .50651 L .4729 .53055 L p
1 g
F P
s
P
p
.002 w
.5047 .32166 m .47871 .3304 L .4929 .35251 L p
1 g
F P
s
P
p
.002 w
.4929 .35251 m .51047 .34665 L .5047 .32166 L p
1 g
F P
s
P
p
.002 w
.38891 .43937 m .40648 .47831 L .42743 .46332 L p
1 g
F P
s
P
p
.002 w
.42743 .46332 m .41297 .43112 L .38891 .43937 L p
1 g
F P
s
P
p
.002 w
.55193 .50815 m .58332 .49228 L .56961 .46991 L p
1 g
F P
s
P
p
.002 w
.58833 .45041 m .56961 .46991 L .58332 .49228 L p
1 g
F P
s
P
p
.002 w
.59961 .42573 m .60212 .39851 L .57627 .39854 L p
1 g
F P
s
P
p
.002 w
.57176 .38048 m .57627 .39854 L .60212 .39851 L p
1 g
F P
s
P
p
.002 w
.4368 .33218 m .41777 .36187 L .44256 .36981 L p
1 g
F P
s
P
p
.002 w
.44256 .36981 m .45724 .34709 L .4368 .33218 L p
1 g
F P
s
P
p
.002 w
.4729 .53055 m .5149 .5385 L .51703 .51302 L p
1 g
F P
s
P
p
.002 w
.55193 .50815 m .51703 .51302 L .5149 .5385 L p
1 g
F P
s
P
p
.002 w
.53234 .3219 m .5047 .32166 L .51047 .34665 L p
1 g
F P
s
P
p
.002 w
.51047 .34665 m .52913 .34685 L .53234 .3219 L p
1 g
F P
s
P
p
.002 w
.3847 .39695 m .38891 .43937 L .41297 .43112 L p
1 g
F P
s
P
p
.002 w
.41297 .43112 m .40959 .39608 L .3847 .39695 L p
1 g
F P
s
P
p
.002 w
.60212 .39851 m .59551 .37174 L .57176 .38048 L p
1 g
F P
s
P
p
.002 w
.56158 .36475 m .57176 .38048 L .59551 .37174 L p
1 g
F P
s
P
p
.002 w
.55857 .33115 m .53234 .3219 L .52913 .34685 L p
1 g
F P
s
P
p
.002 w
.52913 .34685 m .54682 .35311 L .55857 .33115 L p
1 g
F P
s
P
p
.002 w
.59551 .37174 m .58044 .34841 L .56158 .36475 L p
1 g
F P
s
P
p
.002 w
.54682 .35311 m .56158 .36475 L .58044 .34841 L p
1 g
F P
s
P
p
.002 w
.58044 .34841 m .55857 .33115 L .54682 .35311 L p
1 g
F P
s
P
p
.002 w
.58332 .49228 m .6078 .46696 L .58833 .45041 L p
1 g
F P
s
P
p
.002 w
.59961 .42573 m .58833 .45041 L .6078 .46696 L p
1 g
F P
s
P
p
.002 w
.5149 .5385 m .55716 .5327 L .55193 .50815 L p
1 g
F P
s
P
p
.002 w
.58332 .49228 m .55193 .50815 L .55716 .5327 L p
1 g
F P
s
P
p
.002 w
.46475 .31031 m .4368 .33218 L .45724 .34709 L p
1 g
F P
s
P
p
.002 w
.45724 .34709 m .47871 .3304 L .46475 .31031 L p
1 g
F P
s
P
p
.002 w
.39448 .35546 m .3847 .39695 L .40959 .39608 L p
1 g
F P
s
P
p
.002 w
.40959 .39608 m .41777 .36187 L .39448 .35546 L p
1 g
F P
s
P
p
.002 w
.6078 .46696 m .62263 .43481 L .59961 .42573 L p
1 g
F P
s
P
p
.002 w
.60212 .39851 m .59961 .42573 L .62263 .43481 L p
1 g
F P
s
P
p
.002 w
.38737 .49245 m .42083 .52868 L .43548 .50977 L p
1 g
F P
s
P
p
.002 w
.43548 .50977 m .40648 .47831 L .38737 .49245 L p
1 g
F P
s
P
p
.002 w
.4729 .53055 m .43548 .50977 L .42083 .52868 L p
1 g
F P
s
P
p
.002 w
.49866 .29879 m .46475 .31031 L .47871 .3304 L p
1 g
F P
s
P
p
.002 w
.47871 .3304 m .5047 .32166 L .49866 .29879 L p
1 g
F P
s
P
p
.002 w
.42083 .52868 m .46395 .55265 L .4729 .53055 L p
1 g
F P
s
P
p
.002 w
.5149 .5385 m .4729 .53055 L .46395 .55265 L p
1 g
F P
s
P
p
.002 w
.55716 .5327 m .59525 .51359 L .58332 .49228 L p
1 g
F P
s
P
p
.002 w
.6078 .46696 m .58332 .49228 L .59525 .51359 L p
1 g
F P
s
P
p
.002 w
.36704 .4476 m .38737 .49245 L .40648 .47831 L p
1 g
F P
s
P
p
.002 w
.40648 .47831 m .38891 .43937 L .36704 .4476 L p
1 g
F P
s
P
p
.002 w
.62263 .43481 m .62602 .39927 L .60212 .39851 L p
1 g
F P
s
P
p
.002 w
.59551 .37174 m .60212 .39851 L .62602 .39927 L p
1 g
F P
s
P
p
.002 w
.41744 .31937 m .39448 .35546 L .41777 .36187 L p
1 g
F P
s
P
p
.002 w
.41777 .36187 m .4368 .33218 L .41744 .31937 L p
1 g
F P
s
P
p
.002 w
.53482 .29904 m .49866 .29879 L .5047 .32166 L p
1 g
F P
s
P
p
.002 w
.5047 .32166 m .53234 .3219 L .53482 .29904 L p
1 g
F P
s
P
p
.002 w
.46395 .55265 m .51234 .56189 L .5149 .5385 L p
1 g
F P
s
P
p
.002 w
.55716 .5327 m .5149 .5385 L .51234 .56189 L p
1 g
F P
s
P
p
.002 w
.36207 .39869 m .36704 .4476 L .38891 .43937 L p
1 g
F P
s
P
p
.002 w
.38891 .43937 m .3847 .39695 L .36207 .39869 L p
1 g
F P
s
P
p
.002 w
.62602 .39927 m .61745 .36426 L .59551 .37174 L p
1 g
F P
s
P
p
.002 w
.58044 .34841 m .59551 .37174 L .61745 .36426 L p
1 g
F P
s
P
p
.002 w
.56915 .31112 m .53482 .29904 L .53234 .3219 L p
1 g
F P
s
P
p
.002 w
.53234 .3219 m .55857 .33115 L .56915 .31112 L p
1 g
F P
s
P
p
.002 w
.59525 .51359 m .62504 .48299 L .6078 .46696 L p
1 g
F P
s
P
p
.002 w
.62263 .43481 m .6078 .46696 L .62504 .48299 L p
1 g
F P
s
P
p
.002 w
.61745 .36426 m .59777 .33371 L .58044 .34841 L p
1 g
F P
s
P
p
.002 w
.55857 .33115 m .58044 .34841 L .59777 .33371 L p
1 g
F P
s
P
p
.002 w
.59777 .33371 m .56915 .31112 L .55857 .33115 L p
1 g
F P
s
P
p
.002 w
.4513 .29271 m .41744 .31937 L .4368 .33218 L p
1 g
F P
s
P
p
.002 w
.4368 .33218 m .46475 .31031 L .4513 .29271 L p
1 g
F P
s
P
p
.002 w
.51234 .56189 m .56109 .55531 L .55716 .5327 L p
1 g
F P
s
P
p
.002 w
.59525 .51359 m .55716 .5327 L .56109 .55531 L p
1 g
F P
s
P
p
.002 w
.37322 .35078 m .36207 .39869 L .3847 .39695 L p
1 g
F P
s
P
p
.002 w
.3847 .39695 m .39448 .35546 L .37322 .35078 L p
1 g
F P
s
P
p
.002 w
.62504 .48299 m .64316 .44403 L .62263 .43481 L p
1 g
F P
s
P
p
.002 w
.62602 .39927 m .62263 .43481 L .64316 .44403 L p
1 g
F P
s
P
p
.002 w
.49249 .27861 m .4513 .29271 L .46475 .31031 L p
1 g
F P
s
P
p
.002 w
.46475 .31031 m .49866 .29879 L .49249 .27861 L p
1 g
F P
s
P
p
.002 w
.37058 .50543 m .40777 .54565 L .42083 .52868 L p
1 g
F P
s
P
p
.002 w
.42083 .52868 m .38737 .49245 L .37058 .50543 L p
1 g
F P
s
P
p
.002 w
.46395 .55265 m .42083 .52868 L .40777 .54565 L p
1 g
F P
s
P
p
.002 w
.56109 .55531 m .60509 .53339 L .59525 .51359 L p
1 g
F P
s
P
p
.002 w
.62504 .48299 m .59525 .51359 L .60509 .53339 L p
1 g
F P
s
P
p
.002 w
.40777 .54565 m .45565 .57229 L .46395 .55265 L p
1 g
F P
s
P
p
.002 w
.51234 .56189 m .46395 .55265 L .45565 .57229 L p
1 g
F P
s
P
p
.002 w
.34791 .45564 m .37058 .50543 L .38737 .49245 L p
1 g
F P
s
P
p
.002 w
.38737 .49245 m .36704 .4476 L .34791 .45564 L p
1 g
F P
s
P
p
.002 w
.39961 .30902 m .37322 .35078 L .39448 .35546 L p
1 g
F P
s
P
p
.002 w
.39448 .35546 m .41744 .31937 L .39961 .30902 L p
1 g
F P
s
P
p
.002 w
.64316 .44403 m .64739 .40085 L .62602 .39927 L p
1 g
F P
s
P
p
.002 w
.61745 .36426 m .62602 .39927 L .64739 .40085 L p
1 g
F P
s
P
p
.002 w
.53648 .27884 m .49249 .27861 L .49866 .29879 L p
1 g
F P
s
P
p
.002 w
.49866 .29879 m .53482 .29904 L .53648 .27884 L p
1 g
F P
s
P
p
.002 w
.45565 .57229 m .5094 .58262 L .51234 .56189 L p
1 g
F P
s
P
p
.002 w
.56109 .55531 m .51234 .56189 L .5094 .58262 L p
1 g
F P
s
P
p
.002 w
.34227 .4013 m .34791 .45564 L .36704 .4476 L p
1 g
F P
s
P
p
.002 w
.36704 .4476 m .36207 .39869 L .34227 .4013 L p
1 g
F P
s
P
p
.002 w
.64739 .40085 m .63705 .35824 L .61745 .36426 L p
1 g
F P
s
P
p
.002 w
.59777 .33371 m .61745 .36426 L .63705 .35824 L p
1 g
F P
s
P
p
.002 w
.60509 .53339 m .6396 .49816 L .62504 .48299 L p
1 g
F P
s
P
p
.002 w
.64316 .44403 m .62504 .48299 L .6396 .49816 L p
1 g
F P
s
P
p
.002 w
.57829 .29352 m .53648 .27884 L .53482 .29904 L p
1 g
F P
s
P
p
.002 w
.53482 .29904 m .56915 .31112 L .57829 .29352 L p
1 g
F P
s
P
p
.002 w
.63705 .35824 m .61314 .32104 L .59777 .33371 L p
1 g
F P
s
P
p
.002 w
.56915 .31112 m .59777 .33371 L .61314 .32104 L p
1 g
F P
s
P
p
.002 w
.61314 .32104 m .57829 .29352 L .56915 .31112 L p
1 g
F P
s
P
p
.002 w
.43867 .2781 m .39961 .30902 L .41744 .31937 L p
1 g
F P
s
P
p
.002 w
.41744 .31937 m .4513 .29271 L .43867 .2781 L p
1 g
F P
s
P
p
.002 w
.5094 .58262 m .56357 .57542 L .56109 .55531 L p
1 g
F P
s
P
p
.002 w
.60509 .53339 m .56109 .55531 L .56357 .57542 L p
1 g
F P
s
P
p
.002 w
.35453 .348 m .34227 .4013 L .36207 .39869 L p
1 g
F P
s
P
p
.002 w
.36207 .39869 m .37322 .35078 L .35453 .348 L p
1 g
F P
s
P
p
.002 w
.6396 .49816 m .66066 .45319 L .64316 .44403 L p
1 g
F P
s
P
p
.002 w
.64739 .40085 m .64316 .44403 L .66066 .45319 L p
1 g
F P
s
P
p
.002 w
.4863 .26169 m .43867 .2781 L .4513 .29271 L p
1 g
F P
s
P
p
.002 w
.4513 .29271 m .49249 .27861 L .4863 .26169 L p
1 g
F P
s
P
p
.002 w
.56357 .57542 m .61255 .55116 L .60509 .53339 L p
1 g
F P
s
P
p
.002 w
.6396 .49816 m .60509 .53339 L .61255 .55116 L p
1 g
F P
s
P
p
.002 w
.35656 .51691 m .39665 .56021 L .40777 .54565 L p
1 g
F P
s
P
p
.002 w
.40777 .54565 m .37058 .50543 L .35656 .51691 L p
1 g
F P
s
P
p
.002 w
.45565 .57229 m .40777 .54565 L .39665 .56021 L p
1 g
F P
s
P
p
.002 w
.39665 .56021 m .44822 .58893 L .45565 .57229 L p
1 g
F P
s
P
p
.002 w
.5094 .58262 m .45565 .57229 L .44822 .58893 L p
1 g
F P
s
P
p
.002 w
.33208 .46331 m .35656 .51691 L .37058 .50543 L p
1 g
F P
s
P
p
.002 w
.37058 .50543 m .34791 .45564 L .33208 .46331 L p
1 g
F P
s
P
p
.002 w
.38377 .30147 m .35453 .348 L .37322 .35078 L p
1 g
F P
s
P
p
.002 w
.37322 .35078 m .39961 .30902 L .38377 .30147 L p
1 g
F P
s
P
p
.002 w
.66066 .45319 m .66567 .40325 L .64739 .40085 L p
1 g
F P
s
P
p
.002 w
.63705 .35824 m .64739 .40085 L .66567 .40325 L p
1 g
F P
s
P
p
.002 w
.53725 .26188 m .4863 .26169 L .49249 .27861 L p
1 g
F P
s
P
p
.002 w
.49249 .27861 m .53648 .27884 L .53725 .26188 L p
1 g
F P
s
P
p
.002 w
.44822 .58893 m .50611 .60011 L .5094 .58262 L p
1 g
F P
s
P
p
.002 w
.56357 .57542 m .5094 .58262 L .50611 .60011 L p
1 g
F P
s
P
p
.002 w
.32589 .40476 m .33208 .46331 L .34791 .45564 L p
1 g
F P
s
P
p
.002 w
.34791 .45564 m .34227 .4013 L .32589 .40476 L p
1 g
F P
s
P
p
.002 w
.66567 .40325 m .65378 .35389 L .63705 .35824 L p
1 g
F P
s
P
p
.002 w
.61314 .32104 m .63705 .35824 L .65378 .35389 L p
1 g
F P
s
P
p
.002 w
.61255 .55116 m .65102 .51208 L .6396 .49816 L p
1 g
F P
s
P
p
.002 w
.66066 .45319 m .6396 .49816 L .65102 .51208 L p
1 g
F P
s
P
p
.002 w
.58572 .27886 m .53725 .26188 L .53648 .27884 L p
1 g
F P
s
P
p
.002 w
.53648 .27884 m .57829 .29352 L .58572 .27886 L p
1 g
F P
s
P
p
.002 w
.65378 .35389 m .6261 .31076 L .61314 .32104 L p
1 g
F P
s
P
p
.002 w
.57829 .29352 m .61314 .32104 L .6261 .31076 L p
1 g
F P
s
P
p
.002 w
.42719 .26695 m .38377 .30147 L .39961 .30902 L p
1 g
F P
s
P
p
.002 w
.39961 .30902 m .43867 .2781 L .42719 .26695 L p
1 g
F P
s
P
p
.002 w
.6261 .31076 m .58572 .27886 L .57829 .29352 L p
1 g
F P
s
P
p
.002 w
.50611 .60011 m .56449 .59245 L .56357 .57542 L p
1 g
F P
s
P
p
.002 w
.61255 .55116 m .56357 .57542 L .56449 .59245 L p
1 g
F P
s
P
p
.002 w
.33899 .34729 m .32589 .40476 L .34227 .4013 L p
1 g
F P
s
P
p
.002 w
.34227 .4013 m .35453 .348 L .33899 .34729 L p
1 g
F P
s
P
p
.002 w
.65102 .51208 m .67458 .46208 L .66066 .45319 L p
1 g
F P
s
P
p
.002 w
.66567 .40325 m .66066 .45319 L .67458 .46208 L p
1 g
F P
s
P
p
.002 w
.48024 .24857 m .42719 .26695 L .43867 .2781 L p
1 g
F P
s
P
p
.002 w
.43867 .2781 m .4863 .26169 L .48024 .24857 L p
1 g
F P
s
P
p
.002 w
.56449 .59245 m .61732 .56642 L .61255 .55116 L p
1 g
F P
s
P
p
.002 w
.65102 .51208 m .61255 .55116 L .61732 .56642 L p
1 g
F P
s
P
p
.002 w
.3458 .52654 m .38783 .57191 L .39665 .56021 L p
1 g
F P
s
P
p
.002 w
.39665 .56021 m .35656 .51691 L .3458 .52654 L p
1 g
F P
s
P
p
.002 w
.44822 .58893 m .39665 .56021 L .38783 .57191 L p
1 g
F P
s
P
p
.002 w
.38783 .57191 m .44187 .60202 L .44822 .58893 L p
1 g
F P
s
P
p
.002 w
.50611 .60011 m .44822 .58893 L .44187 .60202 L p
1 g
F P
s
P
p
.002 w
.37042 .29706 m .33899 .34729 L .35453 .348 L p
1 g
F P
s
P
p
.002 w
.35453 .348 m .38377 .30147 L .37042 .29706 L p
1 g
F P
s
P
p
.002 w
.32008 .47039 m .3458 .52654 L .35656 .51691 L p
1 g
F P
s
P
p
.002 w
.35656 .51691 m .33208 .46331 L .32008 .47039 L p
1 g
F P
s
P
p
.002 w
.67458 .46208 m .68026 .40646 L .66567 .40325 L p
1 g
F P
s
P
p
.002 w
.65378 .35389 m .66567 .40325 L .68026 .40646 L p
1 g
F P
s
P
p
.002 w
.53706 .24873 m .48024 .24857 L .4863 .26169 L p
1 g
F P
s
P
p
.002 w
.4863 .26169 m .53725 .26188 L .53706 .24873 L p
1 g
F P
s
P
p
.002 w
.44187 .60202 m .50253 .61379 L .50611 .60011 L p
1 g
F P
s
P
p
.002 w
.56449 .59245 m .50611 .60011 L .50253 .61379 L p
1 g
F P
s
P
p
.002 w
.3135 .40905 m .32008 .47039 L .33208 .46331 L p
1 g
F P
s
P
p
.002 w
.33208 .46331 m .32589 .40476 L .3135 .40905 L p
1 g
F P
s
P
p
.002 w
.61732 .56642 m .65888 .52437 L .65102 .51208 L p
1 g
F P
s
P
p
.002 w
.67458 .46208 m .65102 .51208 L .65888 .52437 L p
1 g
F P
s
P
p
.002 w
.68026 .40646 m .66707 .35141 L .65378 .35389 L p
1 g
F P
s
P
p
.002 w
.6261 .31076 m .65378 .35389 L .66707 .35141 L p
1 g
F P
s
P
p
.002 w
.59116 .26765 m .53706 .24873 L .53725 .26188 L p
1 g
F P
s
P
p
.002 w
.53725 .26188 m .58572 .27886 L .59116 .26765 L p
1 g
F P
s
P
p
.002 w
.41721 .25974 m .37042 .29706 L .38377 .30147 L p
1 g
F P
s
P
p
.002 w
.38377 .30147 m .42719 .26695 L .41721 .25974 L p
1 g
F P
s
P
p
.002 w
.66707 .35141 m .63623 .30326 L .6261 .31076 L p
1 g
F P
s
P
p
.002 w
.58572 .27886 m .6261 .31076 L .63623 .30326 L p
1 g
F P
s
P
p
.002 w
.63623 .30326 m .59116 .26765 L .58572 .27886 L p
1 g
F P
s
P
p
.002 w
.50253 .61379 m .56372 .60585 L .56449 .59245 L p
1 g
F P
s
P
p
.002 w
.61732 .56642 m .56449 .59245 L .56372 .60585 L p
1 g
F P
s
P
p
.002 w
.32714 .34879 m .3135 .40905 L .32589 .40476 L p
1 g
F P
s
P
p
.002 w
.32589 .40476 m .33899 .34729 L .32714 .34879 L p
1 g
F P
s
P
p
.002 w
.65888 .52437 m .68439 .47048 L .67458 .46208 L p
1 g
F P
s
P
p
.002 w
.68026 .40646 m .67458 .46208 L .68439 .47048 L p
1 g
F P
s
P
p
.002 w
.47447 .23983 m .41721 .25974 L .42719 .26695 L p
1 g
F P
s
P
p
.002 w
.42719 .26695 m .48024 .24857 L .47447 .23983 L p
1 g
F P
s
P
p
.002 w
.56372 .60585 m .61914 .57865 L .61732 .56642 L p
1 g
F P
s
P
p
.002 w
.65888 .52437 m .61732 .56642 L .61914 .57865 L p
1 g
F P
s
P
p
.002 w
.33874 .53399 m .38166 .5803 L .38783 .57191 L p
1 g
F P
s
P
p
.002 w
.38783 .57191 m .3458 .52654 L .33874 .53399 L p
1 g
F P
s
P
p
.002 w
.44187 .60202 m .38783 .57191 L .38166 .5803 L p
1 g
F P
s
P
p
.002 w
.38166 .5803 m .43682 .61104 L .44187 .60202 L p
1 g
F P
s
P
p
.002 w
.50253 .61379 m .44187 .60202 L .43682 .61104 L p
1 g
F P
s
P
p
.002 w
.36003 .29608 m .32714 .34879 L .33899 .34729 L p
1 g
F P
s
P
p
.002 w
.33899 .34729 m .37042 .29706 L .36003 .29608 L p
1 g
F P
s
P
p
.002 w
.31244 .4767 m .33874 .53399 L .3458 .52654 L p
1 g
F P
s
P
p
.002 w
.3458 .52654 m .32008 .47039 L .31244 .4767 L p
1 g
F P
s
P
p
.002 w
.68439 .47048 m .6906 .41044 L .68026 .40646 L p
1 g
F P
s
P
p
.002 w
.66707 .35141 m .68026 .40646 L .6906 .41044 L p
1 g
F P
s
P
p
.002 w
.53587 .23995 m .47447 .23983 L .48024 .24857 L p
1 g
F P
s
P
p
.002 w
.48024 .24857 m .53706 .24873 L .53587 .23995 L p
1 g
F P
s
P
p
.002 w
.43682 .61104 m .49874 .6231 L .50253 .61379 L p
1 g
F P
s
P
p
.002 w
.56372 .60585 m .50253 .61379 L .49874 .6231 L p
1 g
F P
s
P
p
.002 w
.30568 .41409 m .31244 .4767 L .32008 .47039 L p
1 g
F P
s
P
p
.002 w
.32008 .47039 m .3135 .40905 L .30568 .41409 L p
1 g
F P
s
P
p
.002 w
.61914 .57865 m .66277 .53463 L .65888 .52437 L p
1 g
F P
s
P
p
.002 w
.68439 .47048 m .65888 .52437 L .66277 .53463 L p
1 g
F P
s
P
p
.002 w
.6906 .41044 m .6764 .35096 L .66707 .35141 L p
1 g
F P
s
P
p
.002 w
.63623 .30326 m .66707 .35141 L .6764 .35096 L p
1 g
F P
s
P
p
.002 w
.59435 .26039 m .53587 .23995 L .53706 .24873 L p
1 g
F P
s
P
p
.002 w
.53706 .24873 m .59116 .26765 L .59435 .26039 L p
1 g
F P
s
P
p
.002 w
.40906 .25689 m .36003 .29608 L .37042 .29706 L p
1 g
F P
s
P
p
.002 w
.37042 .29706 m .41721 .25974 L .40906 .25689 L p
1 g
F P
s
P
p
.002 w
.6764 .35096 m .64308 .29889 L .63623 .30326 L p
1 g
F P
s
P
p
.002 w
.59116 .26765 m .63623 .30326 L .64308 .29889 L p
1 g
F P
s
P
p
.002 w
.49874 .6231 m .5612 .61504 L .56372 .60585 L p
1 g
F P
s
P
p
.002 w
.61914 .57865 m .56372 .60585 L .5612 .61504 L p
1 g
F P
s
P
p
.002 w
.64308 .29889 m .59435 .26039 L .59116 .26765 L p
1 g
F P
s
P
p
.002 w
.31954 .35259 m .30568 .41409 L .3135 .40905 L p
1 g
F P
s
P
p
.002 w
.3135 .40905 m .32714 .34879 L .31954 .35259 L p
1 g
F P
s
P
p
.002 w
.66277 .53463 m .68958 .47814 L .68439 .47048 L p
1 g
F P
s
P
p
.002 w
.6906 .41044 m .68439 .47048 L .68958 .47814 L p
1 g
F P
s
P
p
.002 w
.46915 .23596 m .40906 .25689 L .41721 .25974 L p
1 g
F P
s
P
p
.002 w
.41721 .25974 m .47447 .23983 L .46915 .23596 L p
1 g
F P
s
P
p
.002 w
.5612 .61504 m .61778 .58733 L .61914 .57865 L p
1 g
F P
s
P
p
.002 w
.66277 .53463 m .61914 .57865 L .61778 .58733 L p
1 g
F P
s
P
p
.002 w
.3358 .53892 m .37847 .58493 L .38166 .5803 L p
1 g
F P
s
P
p
.002 w
.38166 .5803 m .33874 .53399 L .3358 .53892 L p
1 g
F P
s
P
p
.002 w
.43682 .61104 m .38166 .5803 L .37847 .58493 L p
1 g
F P
s
P
p
.002 w
.35307 .29878 m .31954 .35259 L .32714 .34879 L p
1 g
F P
s
P
p
.002 w
.32714 .34879 m .36003 .29608 L .35307 .29878 L p
1 g
F P
s
P
p
.002 w
.37847 .58493 m .43329 .61549 L .43682 .61104 L p
1 g
F P
s
P
p
.002 w
.49874 .6231 m .43682 .61104 L .43329 .61549 L p
1 g
F P
s
P
p
.002 w
.30965 .482 m .3358 .53892 L .33874 .53399 L p
1 g
F P
s
P
p
.002 w
.33874 .53399 m .31244 .4767 L .30965 .482 L p
1 g
F P
s
P
p
.002 w
.68958 .47814 m .69615 .41515 L .6906 .41044 L p
1 g
F P
s
P
p
.002 w
.6764 .35096 m .6906 .41044 L .69615 .41515 L p
1 g
F P
s
P
p
.002 w
.53362 .23607 m .46915 .23596 L .47447 .23983 L p
1 g
F P
s
P
p
.002 w
.47447 .23983 m .53587 .23995 L .53362 .23607 L p
1 g
F P
s
P
p
.002 w
.43329 .61549 m .49482 .62749 L .49874 .6231 L p
1 g
F P
s
P
p
.002 w
.5612 .61504 m .49874 .6231 L .49482 .62749 L p
1 g
F P
s
P
p
.002 w
.30291 .41982 m .30965 .482 L .31244 .4767 L p
1 g
F P
s
P
p
.002 w
.31244 .4767 m .30568 .41409 L .30291 .41982 L p
1 g
F P
s
P
p
.002 w
.61778 .58733 m .66233 .54245 L .66277 .53463 L p
1 g
F P
s
P
p
.002 w
.68958 .47814 m .66277 .53463 L .66233 .54245 L p
1 g
F P
s
P
p
.002 w
.69615 .41515 m .68126 .35268 L .6764 .35096 L p
1 g
F P
s
P
p
.002 w
.64308 .29889 m .6764 .35096 L .68126 .35268 L p
1 g
F P
s
P
p
.002 w
.59507 .25753 m .53362 .23607 L .53587 .23995 L p
1 g
F P
s
P
p
.002 w
.53587 .23995 m .59435 .26039 L .59507 .25753 L p
1 g
F P
s
P
p
.002 w
.4031 .25876 m .35307 .29878 L .36003 .29608 L p
1 g
F P
s
P
p
.002 w
.36003 .29608 m .40906 .25689 L .4031 .25876 L p
1 g
F P
s
P
p
.002 w
.49482 .62749 m .55687 .61951 L .5612 .61504 L p
1 g
F P
s
P
p
.002 w
.61778 .58733 m .5612 .61504 L .55687 .61951 L p
1 g
F P
s
P
p
.002 w
.68126 .35268 m .64627 .29799 L .64308 .29889 L p
1 g
F P
s
P
p
.002 w
.59435 .26039 m .64308 .29889 L .64627 .29799 L p
1 g
F P
s
P
p
.002 w
.64627 .29799 m .59507 .25753 L .59435 .26039 L p
1 g
F P
s
P
p
.002 w
.31666 .35874 m .30291 .41982 L .30568 .41409 L p
1 g
F P
s
P
p
.002 w
.30568 .41409 m .31954 .35259 L .31666 .35874 L p
1 g
F P
s
P
p
.002 w
.66233 .54245 m .68972 .4848 L .68958 .47814 L p
1 g
F P
s
P
p
.002 w
.69615 .41515 m .68958 .47814 L .68972 .4848 L p
1 g
F P
s
P
p
.004 w
.46298 .19918 m
.46486 .21092 L
s
P
p
.004 w
.46197 .19287 m
.46298 .19918 L
s
P
p
.002 w
.46446 .23738 m .4031 .25876 L .40906 .25689 L p
1 g
F P
s
P
p
.002 w
.40906 .25689 m .46915 .23596 L .46446 .23738 L p
1 g
F P
s
P
p
.004 w
.46486 .21092 m
.46871 .23498 L
s
P
p
.002 w
.55687 .61951 m .61306 .59202 L .61778 .58733 L p
1 g
F P
s
P
p
.002 w
.66233 .54245 m .61778 .58733 L .61306 .59202 L p
1 g
F P
s
P
p
.002 w
.33734 .54102 m .37854 .58545 L .37847 .58493 L p
1 g
F P
s
P
p
.002 w
.37847 .58493 m .3358 .53892 L .33734 .54102 L p
1 g
F P
s
P
p
.002 w
.43329 .61549 m .37847 .58493 L .37854 .58545 L p
1 g
F P
s
P
p
.002 w
.34995 .30533 m .31666 .35874 L .31954 .35259 L p
1 g
F P
s
P
p
.002 w
.31954 .35259 m .35307 .29878 L .34995 .30533 L p
1 g
F P
s
P
p
.002 w
.37854 .58545 m .43148 .61496 L .43329 .61549 L p
1 g
F P
s
P
p
.002 w
.49482 .62749 m .43329 .61549 L .43148 .61496 L p
1 g
F P
s
P
p
.002 w
.68972 .4848 m .69643 .42049 L .69615 .41515 L p
1 g
F P
s
P
p
.002 w
.68126 .35268 m .69615 .41515 L .69643 .42049 L p
1 g
F P
s
P
p
.002 w
.3121 .48608 m .33734 .54102 L .3358 .53892 L p
1 g
F P
s
P
p
.002 w
.3358 .53892 m .30965 .482 L .3121 .48608 L p
1 g
F P
s
P
p
.002 w
.53033 .23751 m .46446 .23738 L .46915 .23596 L p
1 g
F P
s
P
p
.002 w
.46915 .23596 m .53362 .23607 L .53033 .23751 L p
1 g
F P
s
P
p
.002 w
.43148 .61496 m .49087 .62654 L .49482 .62749 L p
1 g
F P
s
P
p
.002 w
.55687 .61951 m .49482 .62749 L .49087 .62654 L p
1 g
F P
s
P
p
.002 w
.61306 .59202 m .6573 .54745 L .66233 .54245 L p
1 g
F P
s
P
p
.002 w
.68972 .4848 m .66233 .54245 L .6573 .54745 L p
1 g
F P
s
P
p
.002 w
.30561 .42609 m .3121 .48608 L .30965 .482 L p
1 g
F P
s
P
p
.002 w
.30965 .482 m .30291 .41982 L .30561 .42609 L p
1 g
F P
s
P
p
.002 w
.69643 .42049 m .68122 .35668 L .68126 .35268 L p
1 g
F P
s
P
p
.002 w
.64627 .29799 m .68126 .35268 L .68122 .35668 L p
1 g
F P
s
P
p
.002 w
.59313 .25945 m .53033 .23751 L .53362 .23607 L p
1 g
F P
s
P
p
.002 w
.53362 .23607 m .59507 .25753 L .59313 .25945 L p
1 g
F P
s
P
p
.002 w
.39965 .26562 m .34995 .30533 L .35307 .29878 L p
1 g
F P
s
P
p
.002 w
.35307 .29878 m .4031 .25876 L .39965 .26562 L p
1 g
F P
s
P
p
.002 w
.49087 .62654 m .55075 .61883 L .55687 .61951 L p
1 g
F P
s
P
p
.002 w
.61306 .59202 m .55687 .61951 L .55075 .61883 L p
1 g
F P
s
P
p
.002 w
.68122 .35668 m .64546 .3008 L .64627 .29799 L p
1 g
F P
s
P
p
.002 w
.59507 .25753 m .64627 .29799 L .64546 .3008 L p
1 g
F P
s
P
p
.002 w
.64546 .3008 m .59313 .25945 L .59507 .25753 L p
1 g
F P
s
P
p
.002 w
.31891 .36722 m .30561 .42609 L .30291 .41982 L p
1 g
F P
s
P
p
.002 w
.30291 .41982 m .31666 .35874 L .31891 .36722 L p
1 g
F P
s
P
p
.002 w
.6573 .54745 m .68447 .49021 L .68972 .4848 L p
1 g
F P
s
P
p
.002 w
.69643 .42049 m .68972 .4848 L .68447 .49021 L p
1 g
F P
s
P
p
.002 w
.46059 .24442 m .39965 .26562 L .4031 .25876 L p
1 g
F P
s
P
p
.002 w
.4031 .25876 m .46446 .23738 L .46059 .24442 L p
1 g
F P
s
P
p
.002 w
.55075 .61883 m .60492 .59229 L .61306 .59202 L p
1 g
F P
s
P
p
.002 w
.6573 .54745 m .61306 .59202 L .60492 .59229 L p
1 g
F P
s
P
p
.002 w
.35104 .31577 m .31891 .36722 L .31666 .35874 L p
1 g
F P
s
P
p
.002 w
.31666 .35874 m .34995 .30533 L .35104 .31577 L p
1 g
F P
s
P
p
.002 w
.34362 .54005 m .38209 .58155 L .37854 .58545 L p
1 g
F P
s
P
p
.002 w
.37854 .58545 m .33734 .54102 L .34362 .54005 L p
1 g
F P
s
P
p
.002 w
.43148 .61496 m .37854 .58545 L .38209 .58155 L p
1 g
F P
s
P
p
.002 w
.38209 .58155 m .43155 .60911 L .43148 .61496 L p
1 g
F P
s
P
p
.002 w
.49087 .62654 m .43148 .61496 L .43155 .60911 L p
1 g
F P
s
P
p
.002 w
.68447 .49021 m .6911 .42635 L .69643 .42049 L p
1 g
F P
s
P
p
.002 w
.68122 .35668 m .69643 .42049 L .6911 .42635 L p
1 g
F P
s
P
p
.002 w
.32008 .48874 m .34362 .54005 L .33734 .54102 L p
1 g
F P
s
P
p
.002 w
.33734 .54102 m .3121 .48608 L .32008 .48874 L p
1 g
F P
s
P
p
.002 w
.52602 .24458 m .46059 .24442 L .46446 .23738 L p
1 g
F P
s
P
p
.002 w
.46446 .23738 m .53033 .23751 L .52602 .24458 L p
1 g
F P
s
P
p
.004 w
.46871 .23498 m
.47008 .24355 L
s
P
p
.002 w
.43155 .60911 m .48701 .61991 L .49087 .62654 L p
1 g
F P
s
P
p
.002 w
.55075 .61883 m .49087 .62654 L .48701 .61991 L p
1 g
F P
s
P
p
.002 w
.60492 .59229 m .64752 .54931 L .6573 .54745 L p
1 g
F P
s
P
p
.002 w
.68447 .49021 m .6573 .54745 L .64752 .54931 L p
1 g
F P
s
P
p
.002 w
.31407 .43277 m .32008 .48874 L .3121 .48608 L p
1 g
F P
s
P
p
.002 w
.3121 .48608 m .30561 .42609 L .31407 .43277 L p
1 g
F P
s
P
p
.002 w
.6911 .42635 m .67595 .36299 L .68122 .35668 L p
1 g
F P
s
P
p
.002 w
.64546 .3008 m .68122 .35668 L .67595 .36299 L p
1 g
F P
s
P
p
.002 w
.39897 .27756 m .35104 .31577 L .34995 .30533 L p
1 g
F P
s
P
p
.002 w
.34995 .30533 m .39965 .26562 L .39897 .27756 L p
1 g
F P
s
P
p
.002 w
.5884 .2664 m .52602 .24458 L .53033 .23751 L p
1 g
F P
s
P
p
.002 w
.53033 .23751 m .59313 .25945 L .5884 .2664 L p
1 g
F P
s
P
p
.002 w
.48701 .61991 m .54288 .61268 L .55075 .61883 L p
1 g
F P
s
P
p
.002 w
.60492 .59229 m .55075 .61883 L .54288 .61268 L p
1 g
F P
s
P
p
.002 w
.67595 .36299 m .6404 .30748 L .64546 .3008 L p
1 g
F P
s
P
p
.002 w
.59313 .25945 m .64546 .3008 L .6404 .30748 L p
1 g
F P
s
P
p
.002 w
.6404 .30748 m .5884 .2664 L .59313 .25945 L p
1 g
F P
s
P
p
.002 w
.32653 .3779 m .31407 .43277 L .30561 .42609 L p
1 g
F P
s
P
p
.002 w
.30561 .42609 m .31891 .36722 L .32653 .3779 L p
1 g
F P
s
P
p
.002 w
.64752 .54931 m .67364 .49413 L .68447 .49021 L p
1 g
F P
s
P
p
.002 w
.6911 .42635 m .68447 .49021 L .67364 .49413 L p
1 g
F P
s
P
p
.002 w
.45771 .25722 m .39897 .27756 L .39965 .26562 L p
1 g
F P
s
P
p
.002 w
.39965 .26562 m .46059 .24442 L .45771 .25722 L p
1 g
F P
s
P
p
.002 w
.54288 .61268 m .59337 .58787 L .60492 .59229 L p
1 g
F P
s
P
p
.002 w
.64752 .54931 m .60492 .59229 L .59337 .58787 L p
1 g
F P
s
P
p
.002 w
.35655 .33002 m .32653 .3779 L .31891 .36722 L p
1 g
F P
s
P
p
.002 w
.31891 .36722 m .35104 .31577 L .35655 .33002 L p
1 g
F P
s
P
p
.002 w
.35474 .53583 m .38924 .57307 L .38209 .58155 L p
1 g
F P
s
P
p
.002 w
.38209 .58155 m .34362 .54005 L .35474 .53583 L p
1 g
F P
s
P
p
.002 w
.43155 .60911 m .38209 .58155 L .38924 .57307 L p
1 g
F P
s
P
p
.002 w
.38924 .57307 m .43362 .59779 L .43155 .60911 L p
1 g
F P
s
P
p
.002 w
.48701 .61991 m .43155 .60911 L .43362 .59779 L p
1 g
F P
s
P
p
.002 w
.67364 .49413 m .67995 .43259 L .6911 .42635 L p
1 g
F P
s
P
p
.002 w
.67595 .36299 m .6911 .42635 L .67995 .43259 L p
1 g
F P
s
P
p
.002 w
.33368 .4898 m .35474 .53583 L .34362 .54005 L p
1 g
F P
s
P
p
.002 w
.34362 .54005 m .32008 .48874 L .33368 .4898 L p
1 g
F P
s
P
p
.002 w
.52076 .25744 m .45771 .25722 L .46059 .24442 L p
1 g
F P
s
P
p
.002 w
.46059 .24442 m .52602 .24458 L .52076 .25744 L p
1 g
F P
s
P
p
.002 w
.43362 .59779 m .48337 .60744 L .48701 .61991 L p
1 g
F P
s
P
p
.002 w
.54288 .61268 m .48701 .61991 L .48337 .60744 L p
1 g
F P
s
P
p
.002 w
.59337 .58787 m .63301 .54775 L .64752 .54931 L p
1 g
F P
s
P
p
.002 w
.67364 .49413 m .64752 .54931 L .63301 .54775 L p
1 g
F P
s
P
p
.002 w
.32837 .43965 m .33368 .4898 L .32008 .48874 L p
1 g
F P
s
P
p
.002 w
.32008 .48874 m .31407 .43277 L .32837 .43965 L p
1 g
F P
s
P
p
.002 w
.67995 .43259 m .66528 .37155 L .67595 .36299 L p
1 g
F P
s
P
p
.002 w
.6404 .30748 m .67595 .36299 L .66528 .37155 L p
1 g
F P
s
P
p
.002 w
.40125 .29453 m .35655 .33002 L .35104 .31577 L p
1 g
F P
s
P
p
.002 w
.35104 .31577 m .39897 .27756 L .40125 .29453 L p
1 g
F P
s
P
p
.002 w
.58087 .2785 m .52076 .25744 L .52602 .24458 L p
1 g
F P
s
P
p
.002 w
.52602 .24458 m .5884 .2664 L .58087 .2785 L p
1 g
F P
s
P
p
.002 w
.48337 .60744 m .53343 .6009 L .54288 .61268 L p
1 g
F P
s
P
p
.002 w
.59337 .58787 m .54288 .61268 L .53343 .6009 L p
1 g
F P
s
P
p
.002 w
.66528 .37155 m .63098 .31808 L .6404 .30748 L p
1 g
F P
s
P
p
.002 w
.5884 .2664 m .6404 .30748 L .63098 .31808 L p
1 g
F P
s
P
p
.002 w
.63098 .31808 m .58087 .2785 L .5884 .2664 L p
1 g
F P
s
P
p
.002 w
.33963 .39057 m .32837 .43965 L .31407 .43277 L p
1 g
F P
s
P
p
.002 w
.31407 .43277 m .32653 .3779 L .33963 .39057 L p
1 g
F P
s
P
p
.002 w
.63301 .54775 m .65723 .49631 L .67364 .49413 L p
1 g
F P
s
P
p
.002 w
.67995 .43259 m .67364 .49413 L .65723 .49631 L p
1 g
F P
s
P
p
.002 w
.45598 .2757 m .40125 .29453 L .39897 .27756 L p
1 g
F P
s
P
p
.002 w
.39897 .27756 m .45771 .25722 L .45598 .2757 L p
1 g
F P
s
P
p
.002 w
.53343 .6009 m .57859 .5786 L .59337 .58787 L p
1 g
F P
s
P
p
.002 w
.63301 .54775 m .59337 .58787 L .57859 .5786 L p
1 g
F P
s
P
p
.002 w
.36658 .34782 m .33963 .39057 L .32653 .3779 L p
1 g
F P
s
P
p
.002 w
.32653 .3779 m .35655 .33002 L .36658 .34782 L p
1 g
F P
s
P
p
.002 w
.37065 .52829 m .39999 .56 L .38924 .57307 L p
1 g
F P
s
P
p
.002 w
.38924 .57307 m .35474 .53583 L .37065 .52829 L p
1 g
F P
s
P
p
.002 w
.43362 .59779 m .38924 .57307 L .39999 .56 L p
1 g
F P
s
P
p
.002 w
.39999 .56 m .43776 .58102 L .43362 .59779 L p
1 g
F P
s
P
p
.002 w
.48337 .60744 m .43362 .59779 L .43776 .58102 L p
1 g
F P
s
P
p
.002 w
.65723 .49631 m .66299 .43901 L .67995 .43259 L p
1 g
F P
s
P
p
.002 w
.66528 .37155 m .67995 .43259 L .66299 .43901 L p
1 g
F P
s
P
p
.002 w
.35279 .48913 m .37065 .52829 L .35474 .53583 L p
1 g
F P
s
P
p
.002 w
.35474 .53583 m .33368 .4898 L .35279 .48913 L p
1 g
F P
s
P
p
.002 w
.51467 .27599 m .45598 .2757 L .45771 .25722 L p
1 g
F P
s
P
p
.002 w
.45771 .25722 m .52076 .25744 L .51467 .27599 L p
1 g
F P
s
P
p
.004 w
.47008 .24355 m
.47323 .26325 L
s
P
p
.002 w
.43776 .58102 m .48008 .58919 L .48337 .60744 L p
1 g
F P
s
P
p
.002 w
.53343 .6009 m .48337 .60744 L .48008 .58919 L p
1 g
F P
s
P
p
.002 w
.57859 .5786 m .61395 .54263 L .63301 .54775 L p
1 g
F P
s
P
p
.002 w
.65723 .49631 m .63301 .54775 L .61395 .54263 L p
1 g
F P
s
P
p
.002 w
.34837 .44652 m .35279 .48913 L .33368 .4898 L p
1 g
F P
s
P
p
.002 w
.33368 .4898 m .32837 .43965 L .34837 .44652 L p
1 g
F P
s
P
p
.002 w
.66299 .43901 m .64924 .38221 L .66528 .37155 L p
1 g
F P
s
P
p
.002 w
.63098 .31808 m .66528 .37155 L .64924 .38221 L p
1 g
F P
s
P
p
.002 w
.40661 .31623 m .36658 .34782 L .35655 .33002 L p
1 g
F P
s
P
p
.002 w
.35655 .33002 m .40125 .29453 L .40661 .31623 L p
1 g
F P
s
P
p
.002 w
.5706 .29563 m .51467 .27599 L .52076 .25744 L p
1 g
F P
s
P
p
.002 w
.52076 .25744 m .58087 .2785 L .5706 .29563 L p
1 g
F P
s
P
p
.002 w
.48008 .58919 m .52261 .58355 L .53343 .6009 L p
1 g
F P
s
P
p
.002 w
.57859 .5786 m .53343 .6009 L .52261 .58355 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.64924 .38221 m .61726 .33247 L .63098 .31808 L p
1 g
F P
s
P
p
.002 w
.58087 .2785 m .63098 .31808 L .61726 .33247 L p
1 g
F P
s
P
p
.002 w
.61726 .33247 m .5706 .29563 L .58087 .2785 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.35804 .4049 m .34837 .44652 L .32837 .43965 L p
1 g
F P
s
P
p
.002 w
.32837 .43965 m .33963 .39057 L .35804 .4049 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.61395 .54263 m .63547 .4966 L .65723 .49631 L p
1 g
F P
s
P
p
.002 w
.66299 .43901 m .65723 .49631 L .63547 .4966 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45552 .29953 m .40661 .31623 L .40125 .29453 L p
1 g
F P
s
P
p
.002 w
.40125 .29453 m .45598 .2757 L .45552 .29953 L p
1 g
F P
s
P
p
.002 w
.52261 .58355 m .5609 .56452 L .57859 .5786 L p
1 g
F P
s
P
p
.002 w
.61395 .54263 m .57859 .5786 L .5609 .56452 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.381 .36875 m .35804 .4049 L .33963 .39057 L p
1 g
F P
s
P
p
.002 w
.33963 .39057 m .36658 .34782 L .381 .36875 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.39106 .51752 m .41416 .54252 L .39999 .56 L p
1 g
F P
s
P
p
.002 w
.39999 .56 m .37065 .52829 L .39106 .51752 L p
1 g
F P
s
P
p
.002 w
.43776 .58102 m .39999 .56 L .41416 .54252 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.63547 .4966 m .64048 .4454 L .66299 .43901 L p
1 g
F P
s
P
p
.002 w
.64924 .38221 m .66299 .43901 L .64048 .4454 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.41416 .54252 m .44393 .55908 L .43776 .58102 L p
1 g
F P
s
P
p
.002 w
.41416 .54252 m .42555 .52834 L p
.44056 .55344 L 1 g
F P
s
P
p
.002 w
.4385 .54708 m .43925 .54566 L p
.43587 .53897 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.44393 .55908 m .42555 .52834 L .44134 .55119 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4385 .54708 L p
1 g
F P
s
P
p
.002 w
.4448 .55621 m .44393 .55908 L p
.44134 .55119 L 1 g
F P
s
P
p
.002 w
.4385 .54708 m .43743 .5491 L p
.44359 .55445 L 1 g
F P
s
P
p
.45146 .56129 m .4385 .54708 L .44359 .55445 L 1 g
F
P
p
.45146 .56129 m .44359 .55445 L .44361 .55448 L 1 g
F
P
p
.002 w
.45079 .56308 m .45146 .56129 L p
.44304 .55399 L 1 g
F P
s
P
p
.002 w
.44764 .55979 m .44393 .55908 L .4448 .55621 L p
1 g
F P
s
P
p
.44304 .55399 m .43748 .54916 L .44764 .55979 L 1 g
F
P
p
.44304 .55399 m .44764 .55979 L .45079 .56308 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.47728 .56546 m .44764 .55979 L p
.45202 .53249 L 1 g
F P
s
P
p
.002 w
.4448 .55621 m .45202 .53249 L p
.44764 .55979 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43142 .52104 m .43273 .52177 L p
.43266 .52429 L 1 g
F P
s
P
p
.002 w
.43253 .52869 m .43346 .52734 L p
.43312 .51756 L 1 g
F P
s
P
p
.002 w
.43296 .51911 m .43142 .52104 L p
.43332 .51555 L 1 g
F P
s
P
p
.002 w
.41545 .50373 m .43572 .49169 L p
.43278 .51178 L 1 g
F P
s
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43823 .50035 L 1 g
F P
s
P
p
.43142 .52104 m .43572 .49169 L .43332 .51555 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4338 .50951 L p
1 g
F P
s
P
p
.002 w
.4338 .50951 m .43305 .5104 L p
.4332 .5164 L 1 g
F P
s
P
p
.43346 .52734 m .4338 .50951 L .4332 .5164 L 1 g
F
P
p
.43346 .52734 m .43305 .5104 L .43297 .51333 L 1 g
F
P
p
.43312 .51756 m .43275 .52127 L .43253 .52869 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.45202 .53249 m .43273 .52177 L p
.45125 .4962 L 1 g
F P
s
P
p
.002 w
.43273 .52177 m .43142 .52104 L .43296 .51911 L p
1 g
F P
s
P
p
.002 w
.43296 .51911 m .45125 .4962 L p
.43273 .52177 L 1 g
F P
s
P
p
.44134 .55119 m .43265 .52476 L .4448 .55621 L 1 g
F
P
p
.43265 .52476 m .43142 .52104 L .43266 .52429 L 1 g
F
P
p
.43265 .52476 m .43266 .52429 L .4448 .55621 L 1 g
F
P
p
.002 w
.43305 .5104 m .43287 .51061 L p
.43297 .51333 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43572 .49169 m .44308 .48733 L p
.43948 .49774 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44246 .49149 L p
1 g
F P
s
P
p
.43485 .50826 m .44246 .49149 L .43823 .50035 L 1 g
F
P
p
.43332 .51555 m .43395 .50933 L .43948 .49774 L 1 g
F
P
p
.43395 .50933 m .43572 .49169 L .43948 .49774 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45125 .4962 m .43296 .51911 L p
.44144 .49247 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45319 .48108 m .46849 .47163 L p
.44482 .48921 L 1 g
F P
s
P
p
.45826 .47608 m .46944 .47118 L .46849 .47163 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.46849 .47163 m .45319 .48108 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45766 .47673 L p
1 g
F P
s
P
p
.002 w
.45766 .47673 m .45698 .47747 L p
.45088 .48332 L 1 g
F P
s
P
p
.44339 .4905 m .45766 .47673 L .45088 .48332 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4417 .48426 m .43817 .47638 L p
.46184 .47267 L 1 g
F P
s
P
p
.002 w
.45766 .47673 m .45826 .47608 L p
.46849 .47163 L 1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44482 .48921 m .46849 .47163 L .47037 .47074 L 1 g
F
P
p
.002 w
.46181 .50206 m .45125 .4962 L .47214 .4699 L p
1 g
F P
s
P
p
.002 w
.48545 .50262 m .47363 .50428 L .47298 .4695 L p
1 g
F P
s
P
p
.002 w
.50412 .48868 m .49599 .49722 L .47335 .46933 L p
1 g
F P
s
P
p
.002 w
.50991 .46601 m .50894 .47788 L .47385 .46908 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.48929 .46551 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.5 .46391 m .50991 .46601 L .47802 .46719 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5424 .4768 L p
1 g
F P
s
P
p
.52214 .46667 m .5424 .4768 L .53242 .47199 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56604 .50931 L p
1 g
F P
s
P
p
.002 w
.57819 .49112 m .56799 .51338 L p
.56604 .50931 L 1 g
F P
s
P
p
.56463 .49595 m .56604 .50931 L .56034 .49748 L 1 g
F
P
p
.57819 .49112 m .56604 .50931 L .56463 .49595 L 1 g
F
P
p
.002 w
.60887 .49488 m .59078 .53393 L .56729 .52323 L p
1 g
F P
s
P
p
.002 w
.56604 .50931 m .56515 .50826 L p
.56713 .52111 L 1 g
F P
s
P
p
.56713 .52111 m .56695 .51873 L .56604 .50931 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.60887 .49488 m .56729 .52323 L .56705 .52004 L 1 g
F
P
p
.59078 .53393 m .56764 .53946 L .56741 .5286 L 1 g
F
P
p
.002 w
.56729 .52323 m .56895 .52398 L p
.56741 .5286 L 1 g
F P
s
P
p
.002 w
.56895 .52398 m .59078 .53393 L p
.56741 .5286 L 1 g
F P
s
P
p
.002 w
.56741 .5286 m .56654 .52734 L p
.56498 .5359 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56741 .5286 L p
1 g
F P
s
P
p
.002 w
.56741 .5286 m .56854 .53025 L p
.56727 .52198 L 1 g
F P
s
P
p
.002 w
.57819 .49112 m .60887 .49488 L p
.56705 .52004 L 1 g
F P
s
P
p
.56515 .50826 m .56741 .5286 L .56729 .52323 L 1 g
F
P
p
.56515 .50826 m .56729 .52323 L .56713 .52111 L 1 g
F
P
p
.002 w
.56675 .51609 m .56799 .51338 L p
.56705 .52004 L 1 g
F P
s
P
p
.002 w
.56799 .51338 m .57819 .49112 L p
.56887 .5153 L 1 g
F P
s
P
p
.56705 .52004 m .56799 .51338 L .56887 .5153 L 1 g
F
P
p
.55661 .4905 m .56604 .50931 L .56126 .49941 L 1 g
F
P
p
.002 w
.55736 .4913 m .55661 .4905 L p
.56126 .49941 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.56283 .49659 m .5349 .50654 L .5527 .48679 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55736 .4913 L p
1 g
F P
s
P
p
.56126 .49941 m .56713 .51061 L .55736 .4913 L 1 g
F
P
p
.57819 .49112 m .56283 .49659 L .55736 .4913 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .4913 L p
1 g
F P
s
P
p
.54174 .47608 m .55736 .4913 L .5527 .48679 L 1 g
F
P
p
.002 w
.5527 .48679 m .54447 .48539 L p
.54826 .48249 L 1 g
F P
s
P
p
.55097 .48512 m .5527 .48679 L .55136 .4855 L 1 g
F
P
p
.54174 .47608 m .5527 .48679 L .55097 .48512 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.58127 .45716 m .57819 .49112 L .5527 .48679 L p
1 g
F P
s
P
p
.002 w
.5349 .50654 m .54447 .48539 L .5527 .48679 L p
1 g
F P
s
P
p
.002 w
.54447 .48539 m .50894 .47788 L p
.52798 .46986 L 1 g
F P
s
P
p
.53736 .47437 m .54447 .48539 L .52798 .46986 L 1 g
F
P
p
.002 w
.54499 .47933 m .54447 .48539 L p
.53307 .46771 L 1 g
F P
s
P
p
.52245 .46719 m .50894 .47788 L .51193 .46579 L 1 g
F
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.53242 .47199 L 1 g
F P
s
P
p
.53147 .46839 m .52798 .46986 L .52245 .46719 L 1 g
F
P
p
.52798 .46986 m .50894 .47788 L .52245 .46719 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.53242 .47199 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.53307 .46771 m .53736 .47437 L .52798 .46986 L 1 g
F
P
p
.002 w
.5424 .4768 m .54174 .47608 L p
.55097 .48512 L 1 g
F P
s
P
p
.002 w
.54447 .48539 m .54499 .47933 L p
.54826 .48249 L 1 g
F P
s
P
p
.55097 .48512 m .55654 .49058 L .54499 .47933 L 1 g
F
P
p
.55097 .48512 m .54499 .47933 L .5424 .4768 L 1 g
F
P
p
.002 w
.54648 .46206 m .58127 .45716 L p
.54826 .48249 L 1 g
F P
s
P
p
.002 w
.54499 .47933 m .54648 .46206 L p
.54826 .48249 L 1 g
F P
s
P
p
.002 w
.54648 .46206 m .54499 .47933 L p
.53307 .46771 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5424 .4768 L p
1 g
F P
s
P
p
.55654 .49058 m .55834 .49233 L .5424 .4768 L 1 g
F
P
p
.58127 .45716 m .5527 .48679 L .54826 .48249 L 1 g
F
P
p
.002 w
.5527 .48679 m .55541 .48725 L p
.55736 .4913 L 1 g
F P
s
P
p
.002 w
.55541 .48725 m .57819 .49112 L p
.55736 .4913 L 1 g
F P
s
P
p
.002 w
.55736 .4913 m .55834 .49233 L p
.55136 .4855 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56911 .51299 L p
.5586 .49284 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .55901 .49374 L p
.5586 .49284 L 1 g
F P
s
P
p
.002 w
.55901 .49374 m .56713 .51061 L p
.5586 .49284 L 1 g
F P
s
P
p
.56727 .52198 m .56724 .52074 L .56604 .50931 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56414 .52179 m .56675 .51609 L p
.56705 .52004 L 1 g
F P
s
P
p
.56713 .52111 m .56729 .52323 L .56727 .52198 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56135 .54679 L p
1 g
F P
s
P
p
.56764 .53946 m .56345 .54047 L .56741 .5286 L 1 g
F
P
p
.56654 .52734 m .56135 .54679 L .56498 .5359 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.59078 .53393 m .5609 .56452 L .55363 .55779 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56283 L p
1 g
F P
s
P
p
.002 w
.5609 .56452 m .53696 .57642 L p
.5484 .56363 L 1 g
F P
s
P
p
.56075 .54566 m .54911 .56283 L .55211 .55948 L 1 g
F
P
p
.5609 .56452 m .5484 .56363 L .54911 .56283 L 1 g
F
P
p
.002 w
.55363 .55779 m .55496 .55902 L p
.54911 .56283 L 1 g
F P
s
P
p
.002 w
.55496 .55902 m .5609 .56452 L p
.54911 .56283 L 1 g
F P
s
P
p
.002 w
.54911 .56283 m .54854 .56129 L p
.54219 .56734 L 1 g
F P
s
P
p
.56075 .54566 m .55211 .55948 L .55565 .5549 L 1 g
F
P
p
.55211 .55948 m .54945 .56374 L .55363 .55779 L 1 g
F
P
p
.55211 .55948 m .55363 .55779 L .55565 .5549 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53162 .57423 L p
1 g
F P
s
P
p
.002 w
.52261 .58355 m .52126 .58098 L p
.53208 .57406 L 1 g
F P
s
P
p
.5484 .56363 m .53736 .57216 L .53208 .57406 L 1 g
F
P
p
.53736 .57216 m .52261 .58355 L .53208 .57406 L 1 g
F
P
p
.002 w
.53162 .57423 m .53128 .57265 L p
.52011 .57838 L 1 g
F P
s
P
p
.54854 .56129 m .53162 .57423 L .54219 .56734 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58033 L p
1 g
F P
s
P
p
.52261 .58355 m .4798 .58685 L .51092 .58033 L 1 g
F
P
p
.51461 .58036 m .51092 .58033 L .5133 .57983 L 1 g
F
P
p
.52261 .58355 m .51092 .58033 L .51461 .58036 L 1 g
F
P
p
.002 w
.51092 .58033 m .51079 .57862 L p
.5025 .58028 L 1 g
F P
s
P
p
.53128 .57265 m .51092 .58033 L .51675 .57911 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58019 L p
1 g
F P
s
P
p
.51092 .58033 m .5 .58262 L .49685 .58024 L 1 g
F
P
p
.002 w
.4798 .58685 m .47875 .57789 L p
.5 .58262 L 1 g
F P
s
P
p
.51079 .57862 m .48909 .58019 L .5025 .58028 L 1 g
F
P
p
.002 w
.48909 .58019 m .48921 .57862 L p
.47827 .57772 L 1 g
F P
s
P
p
.48008 .58919 m .45708 .57003 L .4684 .57414 L 1 g
F
P
p
.002 w
.47875 .57789 m .4791 .58086 L p
.4684 .57414 L 1 g
F P
s
P
p
.002 w
.4791 .58086 m .48008 .58919 L p
.4684 .57414 L 1 g
F P
s
P
p
.002 w
.4684 .57414 m .46872 .57265 L p
.46132 .56969 L 1 g
F P
s
P
p
.47827 .57772 m .47875 .57789 L .48909 .58019 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.45708 .57003 m .44393 .55908 L .44743 .56097 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56308 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56308 L .46132 .56969 L 1 g
F
P
p
.4684 .57414 m .44743 .56097 L .47875 .57789 L 1 g
F
P
p
.45708 .57003 m .44743 .56097 L .4684 .57414 L 1 g
F
P
p
.002 w
.43776 .58102 m .44393 .55908 L p
.45885 .5715 L 1 g
F P
s
P
p
.002 w
.45079 .56308 m .45002 .56518 L p
.46132 .56969 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4684 .57414 L p
1 g
F P
s
P
p
.46132 .56969 m .45002 .56518 L .4684 .57414 L 1 g
F
P
p
.47827 .57772 m .4778 .57768 L .47875 .57789 L 1 g
F
P
p
.002 w
.44393 .55908 m .44764 .55979 L p
.45021 .56247 L 1 g
F P
s
P
p
.002 w
.44393 .55908 m .44205 .55803 L p
.44056 .55344 L 1 g
F P
s
P
p
.002 w
.44205 .55803 m .41416 .54252 L p
.44056 .55344 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .43748 .54916 L p
.4356 .55256 L 1 g
F P
s
P
p
.002 w
.43748 .54916 m .43743 .5491 L .43743 .54911 L p
1 g
F P
s
P
p
.002 w
.43743 .54911 m .4356 .55256 L p
.43748 .54916 L 1 g
F P
s
P
p
.002 w
.47728 .56546 m .47875 .57789 L p
.45021 .56247 L 1 g
F P
s
P
p
.002 w
.44764 .55979 m .47728 .56546 L p
.45021 .56247 L 1 g
F P
s
P
p
.002 w
.47875 .57789 m .47728 .56546 L p
.5 .58262 L 1 g
F P
s
P
p
.002 w
.48909 .58019 m .48889 .583 L p
.5025 .58028 L 1 g
F P
s
P
p
.5133 .57983 m .51092 .58033 L .47728 .56546 L 1 g
F
P
p
.51092 .58033 m .49685 .58024 L .47728 .56546 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58019 L p
1 g
F P
s
P
p
.4778 .57768 m .4678 .57686 L .48909 .58019 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58033 L p
1 g
F P
s
P
p
.5025 .58028 m .48889 .583 L .51092 .58033 L 1 g
F
P
p
.002 w
.51993 .57844 m .52261 .58355 L p
.5133 .57983 L 1 g
F P
s
P
p
.53128 .57265 m .51102 .58166 L .52011 .57838 L 1 g
F
P
p
.002 w
.47728 .56546 m .51074 .56094 L .51993 .57844 L p
1 g
F P
s
P
p
.5133 .57983 m .47728 .56546 L .51993 .57844 L 1 g
F
P
p
.002 w
.52126 .58098 m .51993 .57844 L p
.53162 .57423 L 1 g
F P
s
P
p
.002 w
.51102 .58166 m .51111 .583 L p
.52002 .57843 L 1 g
F P
s
P
p
.52011 .57838 m .51993 .57844 L .52002 .57843 L 1 g
F
P
p
.51993 .57844 m .51102 .58166 L .52002 .57843 L 1 g
F
P
p
.002 w
.51092 .58033 m .51102 .58166 L p
.51675 .57911 L 1 g
F P
s
P
p
.002 w
.52261 .58355 m .48008 .58919 L .4798 .58685 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54794 .5636 m .53162 .57423 L .51074 .56094 L 1 g
F
P
p
.002 w
.51993 .57844 m .51074 .56094 L p
.53162 .57423 L 1 g
F P
s
P
p
.5484 .56363 m .52126 .58098 L .54794 .5636 L 1 g
F
P
p
.002 w
.53696 .57642 m .52261 .58355 L p
.5484 .56363 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53162 .57423 L p
1 g
F P
s
P
p
.52011 .57838 m .51111 .583 L .53162 .57423 L 1 g
F
P
p
.002 w
.53162 .57423 m .5322 .57686 L p
.54219 .56734 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.5484 .56363 m .51074 .56094 L .55363 .55779 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56283 L p
1 g
F P
s
P
p
.54219 .56734 m .5322 .57686 L .54911 .56283 L 1 g
F
P
p
.002 w
.51074 .56094 m .54078 .54589 L .55363 .55779 L p
1 g
F P
s
P
p
.59078 .53393 m .55363 .55779 L .56625 .5398 L 1 g
F
P
p
.002 w
.54945 .56374 m .54998 .56518 L p
.55476 .55653 L 1 g
F P
s
P
p
.55565 .5549 m .55363 .55779 L .55476 .55653 L 1 g
F
P
p
.55363 .55779 m .54945 .56374 L .55476 .55653 L 1 g
F
P
p
.002 w
.54911 .56283 m .54945 .56374 L p
.55211 .55948 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55363 .55779 m .54078 .54589 L p
.56625 .5398 L 1 g
F P
s
P
p
.002 w
.56135 .54679 m .56257 .5491 L p
.56498 .5359 L 1 g
F P
s
P
p
.56741 .5286 m .54078 .54589 L .56729 .52323 L 1 g
F
P
p
.56345 .54047 m .54078 .54589 L .56741 .5286 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56741 .5286 L p
1 g
F P
s
P
p
.56498 .5359 m .56257 .5491 L .56741 .5286 L 1 g
F
P
p
.002 w
.56729 .52323 m .56414 .52179 L p
.56705 .52004 L 1 g
F P
s
P
p
.56713 .52111 m .56727 .52198 L .56695 .51873 L 1 g
F
P
p
.56727 .52198 m .56759 .52409 L .56724 .52074 L 1 g
F
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54078 .54589 m .56414 .52179 L .56729 .52323 L p
1 g
F P
s
P
p
.002 w
.56799 .51338 m .56414 .52179 L p
.56034 .49748 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56604 .50931 L p
1 g
F P
s
P
p
.56759 .52409 m .56854 .53025 L .56604 .50931 L 1 g
F
P
p
.002 w
.56604 .50931 m .56713 .51061 L p
.56126 .49941 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56414 .52179 m .5349 .50654 L p
.56034 .49748 L 1 g
F P
s
P
p
.002 w
.5424 .4768 m .54302 .47747 L p
.53242 .47199 L 1 g
F P
s
P
p
.54648 .46206 m .53147 .46839 L .52245 .46719 L 1 g
F
P
p
.5 .4634 m .52245 .46719 L .51537 .46625 L 1 g
F
P
p
.51372 .46604 m .52271 .46761 L .51739 .46674 L 1 g
F
P
p
.5 .4634 m .51562 .4663 L .51372 .46604 L 1 g
F
P
p
.51562 .4663 m .52271 .46761 L .51372 .46604 L 1 g
F
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.51193 .46579 m .50991 .46601 L p
.5104 .46558 L 1 g
F P
s
P
p
.002 w
.50894 .47788 m .50991 .46601 L .51193 .46579 L p
1 g
F P
s
P
p
.002 w
.50978 .4655 m .50991 .46601 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.50991 .46601 m .50978 .4655 L p
.5104 .46558 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .4634 L p
.51739 .46674 L 1 g
F P
s
P
p
.002 w
.50691 .45435 m .54065 .43909 L p
.5104 .46558 L 1 g
F P
s
P
p
.002 w
.50978 .4655 m .50691 .45435 L p
.5104 .46558 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46417 L p
1 g
F P
s
P
p
.002 w
.5 .46417 m .5 .46391 L p
.50778 .46523 L 1 g
F P
s
P
p
.50778 .46523 m .52282 .46778 L .5 .46417 L 1 g
F
P
p
.51739 .46674 m .52282 .46778 L .5 .46391 L 1 g
F
P
p
.002 w
.50691 .45435 m .50902 .46256 L p
.5 .46391 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46391 L .48929 .46551 L 1 g
F
P
p
.48933 .46216 m .5 .46391 L .47802 .46719 L 1 g
F
P
p
.50691 .45435 m .5 .46391 L .48933 .46216 L 1 g
F
P
p
.002 w
.54065 .43909 m .54648 .46206 L .51193 .46579 L p
1 g
F P
s
P
p
.54065 .43909 m .51193 .46579 L .5104 .46558 L 1 g
F
P
p
.002 w
.51193 .46579 m .51815 .46512 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.51815 .46512 m .54648 .46206 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.52245 .46719 m .52271 .46761 L p
.51537 .46625 L 1 g
F P
s
P
p
.002 w
.50902 .46256 m .50978 .4655 L p
.5 .46391 L 1 g
F P
s
P
p
.002 w
.52271 .46761 m .52282 .46778 L p
.51739 .46674 L 1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .46442 L p
.48929 .46551 L 1 g
F P
s
P
p
.002 w
.50991 .46601 m .47455 .46874 L p
.47802 .46719 L 1 g
F P
s
P
p
.002 w
.48255 .46476 m .50691 .45435 L p
.47802 .46719 L 1 g
F P
s
P
p
.47802 .46719 m .47455 .46874 L .4775 .46727 L 1 g
F
P
p
.47802 .46719 m .4775 .46727 L .48255 .46476 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46727 L p
1 g
F P
s
P
p
.48929 .46551 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.002 w
.4775 .46727 m .47749 .46728 L p
.47738 .46733 L 1 g
F P
s
P
p
.45826 .47608 m .4775 .46727 L .47738 .46733 L 1 g
F
P
p
.45826 .47608 m .47749 .46728 L .47723 .46741 L 1 g
F
P
p
.45826 .47608 m .47748 .46729 L .47708 .46749 L 1 g
F
P
p
.45826 .47608 m .47747 .46731 L .47696 .46756 L 1 g
F
P
p
.45826 .47608 m .47746 .46734 L .47686 .46763 L 1 g
F
P
p
.45826 .47608 m .47744 .46736 L .47681 .46767 L 1 g
F
P
p
.45826 .47608 m .47743 .46738 L .47683 .46767 L 1 g
F
P
p
.45826 .47608 m .47742 .4674 L .47696 .46762 L 1 g
F
P
p
.002 w
.47455 .46874 m .50991 .46601 L p
.47385 .46908 L 1 g
F P
s
P
p
.002 w
.50894 .47788 m .50412 .48868 L .47355 .46923 L p
1 g
F P
s
P
p
.002 w
.47385 .46908 m .50894 .47788 L p
.47355 .46923 L 1 g
F P
s
P
p
.002 w
.47355 .46923 m .50412 .48868 L p
.47335 .46933 L 1 g
F P
s
P
p
.002 w
.49599 .49722 m .48545 .50262 L .47317 .46941 L p
1 g
F P
s
P
p
.002 w
.47335 .46933 m .49599 .49722 L p
.47317 .46941 L 1 g
F P
s
P
p
.002 w
.47317 .46941 m .48545 .50262 L p
.47298 .4695 L 1 g
F P
s
P
p
.002 w
.47363 .50428 m .46181 .50206 L .47271 .46963 L p
1 g
F P
s
P
p
.002 w
.47298 .4695 m .47363 .50428 L p
.47271 .46963 L 1 g
F P
s
P
p
.002 w
.47271 .46963 m .46181 .50206 L p
.47214 .4699 L 1 g
F P
s
P
p
.45826 .47608 m .47741 .46742 L .46944 .47118 L 1 g
F
P
p
.002 w
.47455 .46874 m .47297 .46886 L .48255 .46476 L p
1 g
F P
s
P
p
.002 w
.47385 .46908 m .47297 .46886 L .47455 .46874 L p
1 g
F P
s
P
p
.002 w
.47749 .46728 m .47748 .46729 L p
.47723 .46741 L 1 g
F P
s
P
p
.002 w
.47748 .46729 m .47747 .46731 L p
.47708 .46749 L 1 g
F P
s
P
p
.002 w
.47355 .46923 m .47297 .46886 L .47385 .46908 L p
1 g
F P
s
P
p
.002 w
.47335 .46933 m .47297 .46886 L .47355 .46923 L p
1 g
F P
s
P
p
.002 w
.47747 .46731 m .47746 .46734 L p
.47696 .46756 L 1 g
F P
s
P
p
.002 w
.47746 .46734 m .47744 .46736 L p
.47686 .46763 L 1 g
F P
s
P
p
.002 w
.47317 .46941 m .47297 .46886 L .47335 .46933 L p
1 g
F P
s
P
p
.002 w
.47298 .4695 m .47297 .46886 L .47317 .46941 L p
1 g
F P
s
P
p
.002 w
.47744 .46736 m .47743 .46738 L p
.47681 .46767 L 1 g
F P
s
P
p
.002 w
.47743 .46738 m .47742 .4674 L p
.47683 .46767 L 1 g
F P
s
P
p
.002 w
.47271 .46963 m .47297 .46886 L .47298 .4695 L p
1 g
F P
s
P
p
.002 w
.47214 .4699 m .47297 .46886 L .47271 .46963 L p
1 g
F P
s
P
p
.002 w
.47742 .4674 m .47741 .46742 L p
.47696 .46762 L 1 g
F P
s
P
p
.002 w
.45125 .4962 m .44482 .48921 L p
.47037 .47074 L 1 g
F P
s
P
p
.002 w
.47214 .4699 m .45125 .4962 L p
.47037 .47074 L 1 g
F P
s
P
p
.002 w
.47741 .46742 m .47718 .46778 L p
.46944 .47118 L 1 g
F P
s
P
p
.002 w
.47297 .46886 m .47214 .4699 L p
.47037 .47074 L 1 g
F P
s
P
p
.45766 .47673 m .46184 .47267 L .46849 .47163 L 1 g
F
P
p
.4417 .48426 m .46184 .47267 L .45766 .47673 L 1 g
F
P
p
.002 w
.44308 .48733 m .4417 .48426 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.45319 .48108 m .44308 .48733 L p
.45766 .47673 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .45636 .47807 L p
.45059 .48361 L 1 g
F P
s
P
p
.45055 .48365 m .45059 .48361 L .45059 .48361 L 1 g
F
P
p
.45059 .48361 m .45698 .47747 L .45059 .48361 L 1 g
F
P
p
.002 w
.45766 .47674 m .45766 .47673 L p
.46849 .47163 L 1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.43817 .47638 m .47297 .46886 L .46849 .47163 L p
1 g
F P
s
P
p
.002 w
.46849 .47163 m .47297 .46886 L p
.47037 .47074 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45766 .47674 L p
1 g
F P
s
P
p
.46944 .47118 m .47718 .46778 L .45766 .47674 L 1 g
F
P
p
.44339 .4905 m .45084 .48336 L .45055 .48365 L 1 g
F
P
p
.45084 .48336 m .45698 .47747 L .45055 .48365 L 1 g
F
P
p
.002 w
.44246 .49149 m .44339 .4905 L p
.45636 .47807 L 1 g
F P
s
P
p
.002 w
.44482 .48921 m .44308 .48733 L .45319 .48108 L p
1 g
F P
s
P
p
.002 w
.44308 .48733 m .44482 .48921 L p
.44144 .49247 L 1 g
F P
s
P
p
.002 w
.44482 .48921 m .45125 .4962 L p
.44144 .49247 L 1 g
F P
s
P
p
.43332 .51555 m .44308 .48733 L .43296 .51911 L 1 g
F
P
p
.002 w
.44246 .49149 m .44166 .49233 L p
.43823 .50035 L 1 g
F P
s
P
p
.002 w
.45636 .47807 m .44166 .49233 L .44246 .49149 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43823 .50035 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.002 w
.43142 .52104 m .42941 .51885 L p
.43278 .51178 L 1 g
F P
s
P
p
.002 w
.42941 .51885 m .41545 .50373 L p
.43278 .51178 L 1 g
F P
s
P
p
.002 w
.42555 .52834 m .43142 .52104 L p
.43265 .52476 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43253 .52869 L p
1 g
F P
s
P
p
.4385 .54708 m .43227 .53807 L .43253 .52869 L 1 g
F
P
p
.43227 .53807 m .42555 .52834 L .43265 .52476 L 1 g
F
P
p
.002 w
.43253 .52869 m .43146 .53025 L p
.43587 .53897 L 1 g
F P
s
P
p
.43925 .54566 m .43253 .52869 L .43587 .53897 L 1 g
F
P
p
.44134 .55119 m .4385 .54708 L .43265 .52476 L 1 g
F
P
p
.4385 .54708 m .43253 .52869 L .43265 .52476 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43191 .5296 L p
1 g
F P
s
P
p
.002 w
.43191 .5296 m .43253 .52869 L p
.43266 .52213 L 1 g
F P
s
P
p
.43266 .52213 m .43287 .51061 L .43191 .5296 L 1 g
F
P
p
.43312 .51756 m .43297 .51333 L .43275 .52127 L 1 g
F
P
p
.43297 .51333 m .43287 .51061 L .43253 .52869 L 1 g
F
P
p
.002 w
.45202 .53249 m .4448 .55621 L p
.43266 .52429 L 1 g
F P
s
P
p
.002 w
.43273 .52177 m .45202 .53249 L p
.43266 .52429 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4385 .54708 L p
1 g
F P
s
P
p
.43587 .53897 m .43146 .53025 L .4385 .54708 L 1 g
F
P
p
.002 w
.43743 .5491 m .43748 .54916 L p
.44361 .55448 L 1 g
F P
s
P
p
.44359 .55445 m .43743 .5491 L .44361 .55448 L 1 g
F
P
p
.002 w
.43748 .54916 m .45002 .56518 L .45079 .56308 L p
1 g
F P
s
P
p
.002 w
.48008 .58919 m .47478 .58817 L p
.45885 .5715 L 1 g
F P
s
P
p
.002 w
.47478 .58817 m .43776 .58102 L p
.45885 .5715 L 1 g
F P
s
P
p
.002 w
.37704 .48666 m .39106 .51752 L .37065 .52829 L p
1 g
F P
s
P
p
.002 w
.37065 .52829 m .35279 .48913 L .37704 .48666 L p
1 g
F P
s
P
p
.002 w
.50792 .29989 m .45552 .29953 L .45598 .2757 L p
1 g
F P
s
P
p
.004 w
.47907 .2997 m
.5 .43051 L
s
P
p
.002 w
.45598 .2757 m .51467 .27599 L .50792 .29989 L p
1 g
F P
s
P
p
.004 w
.47605 .28084 m
.47624 .28203 L
s
P
p
.004 w
.47323 .26325 m
.47605 .28084 L
s
P
p
.002 w
.5609 .56452 m .59078 .53393 L .61395 .54263 L p
1 g
F P
s
P
p
.002 w
.63547 .4966 m .61395 .54263 L .59078 .53393 L p
1 g
F P
s
P
p
.002 w
.37366 .45313 m .37704 .48666 L .35279 .48913 L p
1 g
F P
s
P
p
.002 w
.35279 .48913 m .34837 .44652 L .37366 .45313 L p
1 g
F P
s
P
p
.002 w
.41499 .34211 m .381 .36875 L .36658 .34782 L p
1 g
F P
s
P
p
.002 w
.36658 .34782 m .40661 .31623 L .41499 .34211 L p
1 g
F P
s
P
p
.002 w
.64048 .4454 m .62809 .39472 L .64924 .38221 L p
1 g
F P
s
P
p
.002 w
.61726 .33247 m .64924 .38221 L .62809 .39472 L p
1 g
F P
s
P
p
.002 w
.55783 .31748 m .50792 .29989 L .51467 .27599 L p
1 g
F P
s
P
p
.002 w
.51467 .27599 m .5706 .29563 L .55783 .31748 L p
1 g
F P
s
P
p
.002 w
.62809 .39472 m .59949 .35035 L .61726 .33247 L p
1 g
F P
s
P
p
.002 w
.5706 .29563 m .61726 .33247 L .59949 .35035 L p
1 g
F P
s
P
p
.002 w
.38137 .42045 m .37366 .45313 L .34837 .44652 L p
1 g
F P
s
P
p
.002 w
.34837 .44652 m .35804 .4049 L .38137 .42045 L p
1 g
F P
s
P
p
.002 w
.59949 .35035 m .55783 .31748 L .5706 .29563 L p
1 g
F P
s
P
p
.002 w
.59078 .53393 m .60887 .49488 L .63547 .4966 L p
1 g
F P
s
P
p
.002 w
.64048 .4454 m .63547 .4966 L .60887 .49488 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.45642 .32812 m .41499 .34211 L .40661 .31623 L p
1 g
F P
s
P
p
.002 w
.40661 .31623 m .45552 .29953 L .45642 .32812 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.3995 .39217 m .38137 .42045 L .35804 .4049 L p
1 g
F P
s
P
p
.002 w
.35804 .4049 m .381 .36875 L .3995 .39217 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60887 .49488 m .61296 .45153 L .64048 .4454 L p
1 g
F P
s
P
p
.002 w
.62809 .39472 m .64048 .4454 L .61296 .45153 L p
1 g
F P
s
P
p
.002 w
.41545 .50373 m .43142 .52104 L .41416 .54252 L p
1 g
F P
s
P
p
.002 w
.41416 .54252 m .39106 .51752 L .41545 .50373 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.40581 .48237 m .41545 .50373 L .39106 .51752 L p
1 g
F P
s
P
p
.002 w
.39106 .51752 m .37704 .48666 L .40581 .48237 L p
1 g
F P
s
P
p
.002 w
.50073 .32853 m .45642 .32812 L .45552 .29953 L p
1 g
F P
s
P
p
.002 w
.45552 .29953 m .50792 .29989 L .50073 .32853 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.45202 .53249 m .47509 .53687 L .47728 .56546 L p
1 g
F P
s
P
p
.002 w
.51074 .56094 m .47728 .56546 L .47509 .53687 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40354 .45921 m .40581 .48237 L .37704 .48666 L p
1 g
F P
s
P
p
.002 w
.37704 .48666 m .37366 .45313 L .40354 .45921 L p
1 g
F P
s
P
p
.002 w
.42622 .37141 m .3995 .39217 L .381 .36875 L p
1 g
F P
s
P
p
.002 w
.381 .36875 m .41499 .34211 L .42622 .37141 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.61296 .45153 m .60237 .40869 L .62809 .39472 L p
1 g
F P
s
P
p
.002 w
.59949 .35035 m .62809 .39472 L .60237 .40869 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.47509 .53687 m .4982 .53368 L .51074 .56094 L p
1 g
F P
s
P
p
.002 w
.54078 .54589 m .51074 .56094 L .4982 .53368 L p
1 g
F P
s
P
p
.002 w
.54291 .34344 m .50073 .32853 L .50792 .29989 L p
1 g
F P
s
P
p
.002 w
.50792 .29989 m .55783 .31748 L .54291 .34344 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.40896 .43671 m .40354 .45921 L .37366 .45313 L p
1 g
F P
s
P
p
.002 w
.37366 .45313 m .38137 .42045 L .40896 .43671 L p
1 g
F P
s
P
p
.002 w
.60237 .40869 m .57813 .37122 L .59949 .35035 L p
1 g
F P
s
P
p
.002 w
.55783 .31748 m .59949 .35035 L .57813 .37122 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.57813 .37122 m .54291 .34344 L .55783 .31748 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.61296 .45153 m .60887 .49488 L .57819 .49112 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.45869 .36057 m .42622 .37141 L .41499 .34211 L p
1 g
F P
s
P
p
.002 w
.41499 .34211 m .45642 .32812 L .45869 .36057 L p
1 g
F P
s
P
p
.002 w
.4982 .53368 m .51888 .52322 L .54078 .54589 L p
1 g
F P
s
P
p
.002 w
.56414 .52179 m .54078 .54589 L .51888 .52322 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42153 .41729 m .40896 .43671 L .38137 .42045 L p
1 g
F P
s
P
p
.002 w
.38137 .42045 m .3995 .39217 L .42153 .41729 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.57819 .49112 m .58127 .45716 L .61296 .45153 L p
1 g
F P
s
P
p
.002 w
.60237 .40869 m .61296 .45153 L .58127 .45716 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45125 .4962 m .46181 .50206 L .45202 .53249 L p
1 g
F P
s
P
p
.002 w
.47509 .53687 m .45202 .53249 L .46181 .50206 L p
1 g
F P
s
P
p
.002 w
.43817 .47638 m .44308 .48733 L .41545 .50373 L p
1 g
F P
s
P
p
.002 w
.41545 .50373 m .40581 .48237 L .43817 .47638 L p
1 g
F P
s
P
p
.002 w
.51888 .52322 m .5349 .50654 L .56414 .52179 L p
1 g
F P
s
P
p
.002 w
.49336 .36098 m .45869 .36057 L .45642 .32812 L p
1 g
F P
s
P
p
.002 w
.45642 .32812 m .50073 .32853 L .49336 .36098 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.46181 .50206 m .47363 .50428 L .47509 .53687 L p
1 g
F P
s
P
p
.002 w
.4982 .53368 m .47509 .53687 L .47363 .50428 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.43997 .4031 m .42153 .41729 L .3995 .39217 L p
1 g
F P
s
P
p
.002 w
.3995 .39217 m .42622 .37141 L .43997 .4031 L p
1 g
F P
s
P
p
.002 w
.43705 .46453 m .43817 .47638 L .40581 .48237 L p
1 g
F P
s
P
p
.002 w
.40581 .48237 m .40354 .45921 L .43705 .46453 L p
1 g
F P
s
P
p
.002 w
.58127 .45716 m .57288 .42367 L .60237 .40869 L p
1 g
F P
s
P
p
.002 w
.57813 .37122 m .60237 .40869 L .57288 .42367 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.47363 .50428 m .48545 .50262 L .4982 .53368 L p
1 g
F P
s
P
p
.002 w
.51888 .52322 m .4982 .53368 L .48545 .50262 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.52633 .37268 m .49336 .36098 L .50073 .32853 L p
1 g
F P
s
P
p
.002 w
.50073 .32853 m .54291 .34344 L .52633 .37268 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.43987 .45305 m .43705 .46453 L .40354 .45921 L p
1 g
F P
s
P
p
.002 w
.40354 .45921 m .40896 .43671 L .43987 .45305 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.57288 .42367 m .55387 .3944 L .57813 .37122 L p
1 g
F P
s
P
p
.002 w
.54291 .34344 m .57813 .37122 L .55387 .3944 L p
1 g
F P
s
P
p
.002 w
.55387 .3944 m .52633 .37268 L .54291 .34344 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.48545 .50262 m .49599 .49722 L .51888 .52322 L p
1 g
F P
s
P
p
.002 w
.5349 .50654 m .51888 .52322 L .49599 .49722 L p
1 g
F P
s
P
p
.002 w
.4623 .39574 m .43997 .4031 L .42622 .37141 L p
1 g
F P
s
P
p
.002 w
.42622 .37141 m .45869 .36057 L .4623 .39574 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.44633 .44319 m .43987 .45305 L .40896 .43671 L p
1 g
F P
s
P
p
.002 w
.40896 .43671 m .42153 .41729 L .44633 .44319 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57288 .42367 m .58127 .45716 L .54648 .46206 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49599 .49722 m .50412 .48868 L .5349 .50654 L p
1 g
F P
s
P
p
.002 w
.54447 .48539 m .5349 .50654 L .50412 .48868 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.48608 .39609 m .4623 .39574 L .45869 .36057 L p
1 g
F P
s
P
p
.002 w
.45869 .36057 m .49336 .36098 L .48608 .39609 L p
1 g
F P
s
P
p
.002 w
.45575 .43601 m .44633 .44319 L .42153 .41729 L p
1 g
F P
s
P
p
.002 w
.42153 .41729 m .43997 .4031 L .45575 .43601 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43817 .47638 m .43705 .46453 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54648 .46206 m .54065 .43909 L .57288 .42367 L p
1 g
F P
s
P
p
.002 w
.55387 .3944 m .57288 .42367 L .54065 .43909 L p
1 g
F P
s
P
p
.002 w
.43705 .46453 m .43987 .45305 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.50412 .48868 m .50894 .47788 L .54447 .48539 L p
1 g
F P
s
P
p
.002 w
.50868 .40415 m .48608 .39609 L .49336 .36098 L p
1 g
F P
s
P
p
.002 w
.49336 .36098 m .52633 .37268 L .50868 .40415 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.46712 .43232 m .45575 .43601 L .43997 .4031 L p
1 g
F P
s
P
p
.002 w
.43997 .4031 m .4623 .39574 L .46712 .43232 L p
1 g
F P
s
P
p
.002 w
.54065 .43909 m .52757 .41903 L .55387 .3944 L p
1 g
F P
s
P
p
.002 w
.52633 .37268 m .55387 .3944 L .52757 .41903 L p
1 g
F P
s
P
p
.002 w
.43987 .45305 m .44633 .44319 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.52757 .41903 m .50868 .40415 L .52633 .37268 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.44633 .44319 m .45575 .43601 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.4792 .43253 m .46712 .43232 L .4623 .39574 L p
1 g
F P
s
P
p
.002 w
.4623 .39574 m .48608 .39609 L .4792 .43253 L p
1 g
F P
s
P
p
.002 w
.50025 .44419 m .50691 .45435 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.49066 .43663 m .50025 .44419 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.004 w
.49389 .43918 m
.5 .43051 L
s
P
p
.002 w
.4792 .43253 m .49066 .43663 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.46712 .43232 m .4792 .43253 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.45575 .43601 m .46712 .43232 L .47297 .46886 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52757 .41903 m .54065 .43909 L .50691 .45435 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.49066 .43663 m .4792 .43253 L .48608 .39609 L p
1 g
F P
s
P
p
.002 w
.48608 .39609 m .50868 .40415 L .49066 .43663 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50691 .45435 m .50025 .44419 L .52757 .41903 L p
1 g
F P
s
P
p
.002 w
.50868 .40415 m .52757 .41903 L .50025 .44419 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.50025 .44419 m .49066 .43663 L .50868 .40415 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.45622 .49261 m
.47297 .46886 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .46197 .19287 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .45622 .49261 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.488372)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.488372)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48554 .46084 m .50403 .46005 L .49819 .43216 L p
1 g
F P
s
P
p
.002 w
.49819 .43216 m .48883 .43255 L .48554 .46084 L p
1 g
F P
s
P
p
.002 w
.50693 .42878 m .49819 .43216 L .50403 .46005 L p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .48883 .43255 L .49819 .43216 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .49819 .43216 L .50693 .42878 L closepath p
1 g
F P
s
P
p
.002 w
.50403 .46005 m .5213 .45338 L .50693 .42878 L p
1 g
F P
s
P
p
.002 w
.51411 .42279 m .50693 .42878 L .5213 .45338 L p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .50693 .42878 L .51411 .42279 L closepath p
1 g
F P
s
P
p
.002 w
.46779 .45566 m .48554 .46084 L .48883 .43255 L p
1 g
F P
s
P
p
.002 w
.48883 .43255 m .47986 .42992 L .46779 .45566 L p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .47986 .42992 L .48883 .43255 L closepath p
1 g
F P
s
P
p
.002 w
.5213 .45338 m .53552 .44155 L .51411 .42279 L p
1 g
F P
s
P
p
.002 w
.51897 .41481 m .51411 .42279 L .53552 .44155 L p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .51411 .42279 L .51897 .41481 L closepath p
1 g
F P
s
P
p
.002 w
.4527 .44505 m .46779 .45566 L .47986 .42992 L p
1 g
F P
s
P
p
.002 w
.47986 .42992 m .47225 .42454 L .4527 .44505 L p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .47225 .42454 L .47986 .42992 L closepath p
1 g
F P
s
P
p
.002 w
.53552 .44155 m .54515 .42579 L .51897 .41481 L p
1 g
F P
s
P
p
.002 w
.52096 .40571 m .51897 .41481 L .54515 .42579 L p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .51897 .41481 L .52096 .40571 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .49145 .3762 L .48222 .37812 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .48222 .37812 L .47411 .38291 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .47411 .38291 L .468 .39004 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .468 .39004 L .46456 .39875 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .46456 .39875 L .46415 .40806 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .46415 .40806 L .46681 .41698 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .46681 .41698 L .47225 .42454 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .52096 .40571 L .51987 .39647 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .51987 .39647 L .51581 .38809 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .51581 .38809 L .50921 .38148 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .50921 .38148 L .50078 .37736 L closepath p
1 g
F P
s
P
p
.002 w
.4924 .40423 m .50078 .37736 L .49145 .3762 L closepath p
1 g
F P
s
P
p
.002 w
.4419 .43012 m .4527 .44505 L .47225 .42454 L p
1 g
F P
s
P
p
.002 w
.47225 .42454 m .46681 .41698 L .4419 .43012 L p
1 g
F P
s
P
p
.002 w
.48257 .48859 m .50981 .48741 L .50403 .46005 L p
1 g
F P
s
P
p
.002 w
.50403 .46005 m .48554 .46084 L .48257 .48859 L p
1 g
F P
s
P
p
.002 w
.5213 .45338 m .50403 .46005 L .50981 .48741 L p
1 g
F P
s
P
p
.002 w
.50981 .48741 m .53526 .4776 L .5213 .45338 L p
1 g
F P
s
P
p
.002 w
.53552 .44155 m .5213 .45338 L .53526 .4776 L p
1 g
F P
s
P
p
.002 w
.54515 .42579 m .54914 .40779 L .52096 .40571 L p
1 g
F P
s
P
p
.002 w
.51987 .39647 m .52096 .40571 L .54914 .40779 L p
1 g
F P
s
P
p
.002 w
.45641 .48101 m .48257 .48859 L .48554 .46084 L p
1 g
F P
s
P
p
.002 w
.48554 .46084 m .46779 .45566 L .45641 .48101 L p
1 g
F P
s
P
p
.002 w
.43657 .41246 m .4419 .43012 L .46681 .41698 L p
1 g
F P
s
P
p
.002 w
.46681 .41698 m .46415 .40806 L .43657 .41246 L p
1 g
F P
s
P
p
.002 w
.53526 .4776 m .55622 .46018 L .53552 .44155 L p
1 g
F P
s
P
p
.002 w
.54515 .42579 m .53552 .44155 L .55622 .46018 L p
1 g
F P
s
P
p
.002 w
.54914 .40779 m .54704 .38948 L .51987 .39647 L p
1 g
F P
s
P
p
.002 w
.51581 .38809 m .51987 .39647 L .54704 .38948 L p
1 g
F P
s
P
p
.002 w
.43412 .46541 m .45641 .48101 L .46779 .45566 L p
1 g
F P
s
P
p
.002 w
.46779 .45566 m .4527 .44505 L .43412 .46541 L p
1 g
F P
s
P
p
.002 w
.43733 .39398 m .43657 .41246 L .46415 .40806 L p
1 g
F P
s
P
p
.002 w
.46415 .40806 m .46456 .39875 L .43733 .39398 L p
1 g
F P
s
P
p
.002 w
.54704 .38948 m .53903 .37284 L .51581 .38809 L p
1 g
F P
s
P
p
.002 w
.50921 .38148 m .51581 .38809 L .53903 .37284 L p
1 g
F P
s
P
p
.002 w
.55622 .46018 m .57046 .43699 L .54515 .42579 L p
1 g
F P
s
P
p
.002 w
.54914 .40779 m .54515 .42579 L .57046 .43699 L p
1 g
F P
s
P
p
.002 w
.44412 .37669 m .43733 .39398 L .46456 .39875 L p
1 g
F P
s
P
p
.002 w
.46456 .39875 m .468 .39004 L .44412 .37669 L p
1 g
F P
s
P
p
.002 w
.41812 .44342 m .43412 .46541 L .4527 .44505 L p
1 g
F P
s
P
p
.002 w
.4527 .44505 m .4419 .43012 L .41812 .44342 L p
1 g
F P
s
P
p
.002 w
.53903 .37284 m .52597 .35969 L .50921 .38148 L p
1 g
F P
s
P
p
.002 w
.50078 .37736 m .50921 .38148 L .52597 .35969 L p
1 g
F P
s
P
p
.002 w
.45623 .36249 m .44412 .37669 L .468 .39004 L p
1 g
F P
s
P
p
.002 w
.468 .39004 m .47411 .38291 L .45623 .36249 L p
1 g
F P
s
P
p
.002 w
.52597 .35969 m .50925 .35148 L .50078 .37736 L p
1 g
F P
s
P
p
.002 w
.49145 .3762 m .50078 .37736 L .50925 .35148 L p
1 g
F P
s
P
p
.002 w
.57046 .43699 m .57641 .41046 L .54914 .40779 L p
1 g
F P
s
P
p
.002 w
.54704 .38948 m .54914 .40779 L .57641 .41046 L p
1 g
F P
s
P
p
.002 w
.47235 .35296 m .45623 .36249 L .47411 .38291 L p
1 g
F P
s
P
p
.002 w
.47411 .38291 m .48222 .37812 L .47235 .35296 L p
1 g
F P
s
P
p
.002 w
.48222 .37812 m .49145 .3762 L .49069 .34915 L p
1 g
F P
s
P
p
.002 w
.50925 .35148 m .49069 .34915 L .49145 .3762 L p
1 g
F P
s
P
p
.002 w
.49069 .34915 m .47235 .35296 L .48222 .37812 L p
1 g
F P
s
P
p
.002 w
.47998 .5153 m .51542 .51373 L .50981 .48741 L p
1 g
F P
s
P
p
.002 w
.50981 .48741 m .48257 .48859 L .47998 .5153 L p
1 g
F P
s
P
p
.002 w
.53526 .4776 m .50981 .48741 L .51542 .51373 L p
1 g
F P
s
P
p
.002 w
.41018 .41737 m .41812 .44342 L .4419 .43012 L p
1 g
F P
s
P
p
.002 w
.4419 .43012 m .43657 .41246 L .41018 .41737 L p
1 g
F P
s
P
p
.002 w
.51542 .51373 m .54853 .50097 L .53526 .4776 L p
1 g
F P
s
P
p
.002 w
.55622 .46018 m .53526 .4776 L .54853 .50097 L p
1 g
F P
s
P
p
.002 w
.44593 .50547 m .47998 .5153 L .48257 .48859 L p
1 g
F P
s
P
p
.002 w
.48257 .48859 m .45641 .48101 L .44593 .50547 L p
1 g
F P
s
P
p
.002 w
.57641 .41046 m .57339 .38341 L .54704 .38948 L p
1 g
F P
s
P
p
.002 w
.53903 .37284 m .54704 .38948 L .57339 .38341 L p
1 g
F P
s
P
p
.002 w
.54853 .50097 m .57583 .47835 L .55622 .46018 L p
1 g
F P
s
P
p
.002 w
.57046 .43699 m .55622 .46018 L .57583 .47835 L p
1 g
F P
s
P
p
.002 w
.41122 .39004 m .41018 .41737 L .43657 .41246 L p
1 g
F P
s
P
p
.002 w
.43657 .41246 m .43733 .39398 L .41122 .39004 L p
1 g
F P
s
P
p
.002 w
.41687 .48523 m .44593 .50547 L .45641 .48101 L p
1 g
F P
s
P
p
.002 w
.45641 .48101 m .43412 .46541 L .41687 .48523 L p
1 g
F P
s
P
p
.002 w
.57339 .38341 m .56163 .35879 L .53903 .37284 L p
1 g
F P
s
P
p
.002 w
.52597 .35969 m .53903 .37284 L .56163 .35879 L p
1 g
F P
s
P
p
.002 w
.57583 .47835 m .59442 .44819 L .57046 .43699 L p
1 g
F P
s
P
p
.002 w
.57641 .41046 m .57046 .43699 L .59442 .44819 L p
1 g
F P
s
P
p
.002 w
.42122 .36444 m .41122 .39004 L .43733 .39398 L p
1 g
F P
s
P
p
.002 w
.43733 .39398 m .44412 .37669 L .42122 .36444 L p
1 g
F P
s
P
p
.002 w
.39595 .45664 m .41687 .48523 L .43412 .46541 L p
1 g
F P
s
P
p
.002 w
.43412 .46541 m .41812 .44342 L .39595 .45664 L p
1 g
F P
s
P
p
.002 w
.56163 .35879 m .54236 .33929 L .52597 .35969 L p
1 g
F P
s
P
p
.002 w
.50925 .35148 m .52597 .35969 L .54236 .33929 L p
1 g
F P
s
P
p
.002 w
.43912 .34339 m .42122 .36444 L .44412 .37669 L p
1 g
F P
s
P
p
.002 w
.44412 .37669 m .45623 .36249 L .43912 .34339 L p
1 g
F P
s
P
p
.002 w
.59442 .44819 m .60226 .41366 L .57641 .41046 L p
1 g
F P
s
P
p
.002 w
.57339 .38341 m .57641 .41046 L .60226 .41366 L p
1 g
F P
s
P
p
.002 w
.54236 .33929 m .51763 .3271 L .50925 .35148 L p
1 g
F P
s
P
p
.002 w
.49069 .34915 m .50925 .35148 L .51763 .3271 L p
1 g
F P
s
P
p
.002 w
.46298 .32925 m .43912 .34339 L .45623 .36249 L p
1 g
F P
s
P
p
.002 w
.45623 .36249 m .47235 .35296 L .46298 .32925 L p
1 g
F P
s
P
p
.002 w
.47235 .35296 m .49069 .34915 L .49016 .32361 L p
1 g
F P
s
P
p
.002 w
.51763 .3271 m .49016 .32361 L .49069 .34915 L p
1 g
F P
s
P
p
.002 w
.49016 .32361 m .46298 .32925 L .47235 .35296 L p
1 g
F P
s
P
p
.002 w
.3855 .42269 m .39595 .45664 L .41812 .44342 L p
1 g
F P
s
P
p
.002 w
.41812 .44342 m .41018 .41737 L .3855 .42269 L p
1 g
F P
s
P
p
.002 w
.47785 .54041 m .52076 .53849 L .51542 .51373 L p
1 g
F P
s
P
p
.002 w
.51542 .51373 m .47998 .5153 L .47785 .54041 L p
1 g
F P
s
P
p
.002 w
.54853 .50097 m .51542 .51373 L .52076 .53849 L p
1 g
F P
s
P
p
.002 w
.52076 .53849 m .56085 .52305 L .54853 .50097 L p
1 g
F P
s
P
p
.002 w
.57583 .47835 m .54853 .50097 L .56085 .52305 L p
1 g
F P
s
P
p
.002 w
.43658 .52857 m .47785 .54041 L .47998 .5153 L p
1 g
F P
s
P
p
.002 w
.47998 .5153 m .44593 .50547 L .43658 .52857 L p
1 g
F P
s
P
p
.002 w
.60226 .41366 m .59841 .3784 L .57339 .38341 L p
1 g
F P
s
P
p
.002 w
.56163 .35879 m .57339 .38341 L .59841 .3784 L p
1 g
F P
s
P
p
.002 w
.56085 .52305 m .59394 .49568 L .57583 .47835 L p
1 g
F P
s
P
p
.002 w
.59442 .44819 m .57583 .47835 L .59394 .49568 L p
1 g
F P
s
P
p
.002 w
.38677 .38703 m .3855 .42269 L .41018 .41737 L p
1 g
F P
s
P
p
.002 w
.41018 .41737 m .41122 .39004 L .38677 .38703 L p
1 g
F P
s
P
p
.002 w
.40132 .50412 m .43658 .52857 L .44593 .50547 L p
1 g
F P
s
P
p
.002 w
.44593 .50547 m .41687 .48523 L .40132 .50412 L p
1 g
F P
s
P
p
.002 w
.59841 .3784 m .58316 .34623 L .56163 .35879 L p
1 g
F P
s
P
p
.002 w
.54236 .33929 m .56163 .35879 L .58316 .34623 L p
1 g
F P
s
P
p
.002 w
.59394 .49568 m .61653 .45919 L .59442 .44819 L p
1 g
F P
s
P
p
.002 w
.60226 .41366 m .59442 .44819 L .61653 .45919 L p
1 g
F P
s
P
p
.002 w
.39976 .35355 m .38677 .38703 L .41122 .39004 L p
1 g
F P
s
P
p
.002 w
.41122 .39004 m .42122 .36444 L .39976 .35355 L p
1 g
F P
s
P
p
.002 w
.37586 .46951 m .40132 .50412 L .41687 .48523 L p
1 g
F P
s
P
p
.002 w
.41687 .48523 m .39595 .45664 L .37586 .46951 L p
1 g
F P
s
P
p
.002 w
.58316 .34623 m .55805 .32071 L .54236 .33929 L p
1 g
F P
s
P
p
.002 w
.51763 .3271 m .54236 .33929 L .55805 .32071 L p
1 g
F P
s
P
p
.002 w
.42312 .32601 m .39976 .35355 L .42122 .36444 L p
1 g
F P
s
P
p
.002 w
.42122 .36444 m .43912 .34339 L .42312 .32601 L p
1 g
F P
s
P
p
.002 w
.61653 .45919 m .62614 .41735 L .60226 .41366 L p
1 g
F P
s
P
p
.002 w
.59841 .3784 m .60226 .41366 L .62614 .41735 L p
1 g
F P
s
P
p
.002 w
.55805 .32071 m .52577 .30473 L .51763 .3271 L p
1 g
F P
s
P
p
.002 w
.49016 .32361 m .51763 .3271 L .52577 .30473 L p
1 g
F P
s
P
p
.002 w
.45431 .30751 m .42312 .32601 L .43912 .34339 L p
1 g
F P
s
P
p
.002 w
.43912 .34339 m .46298 .32925 L .45431 .30751 L p
1 g
F P
s
P
p
.002 w
.36308 .42834 m .37586 .46951 L .39595 .45664 L p
1 g
F P
s
P
p
.002 w
.39595 .45664 m .3855 .42269 L .36308 .42834 L p
1 g
F P
s
P
p
.002 w
.46298 .32925 m .49016 .32361 L .48985 .30014 L p
1 g
F P
s
P
p
.002 w
.52577 .30473 m .48985 .30014 L .49016 .32361 L p
1 g
F P
s
P
p
.002 w
.48985 .30014 m .45431 .30751 L .46298 .32925 L p
1 g
F P
s
P
p
.002 w
.47621 .5634 m .52571 .56116 L .52076 .53849 L p
1 g
F P
s
P
p
.002 w
.52076 .53849 m .47785 .54041 L .47621 .5634 L p
1 g
F P
s
P
p
.002 w
.56085 .52305 m .52076 .53849 L .52571 .56116 L p
1 g
F P
s
P
p
.002 w
.52571 .56116 m .57196 .54336 L .56085 .52305 L p
1 g
F P
s
P
p
.002 w
.59394 .49568 m .56085 .52305 L .57196 .54336 L p
1 g
F P
s
P
p
.002 w
.62614 .41735 m .62157 .37457 L .59841 .3784 L p
1 g
F P
s
P
p
.002 w
.58316 .34623 m .59841 .3784 L .62157 .37457 L p
1 g
F P
s
P
p
.002 w
.42859 .5498 m .47621 .5634 L .47785 .54041 L p
1 g
F P
s
P
p
.002 w
.47785 .54041 m .43658 .52857 L .42859 .5498 L p
1 g
F P
s
P
p
.002 w
.57196 .54336 m .61016 .51182 L .59394 .49568 L p
1 g
F P
s
P
p
.002 w
.61653 .45919 m .59394 .49568 L .61016 .51182 L p
1 g
F P
s
P
p
.002 w
.36453 .38503 m .36308 .42834 L .3855 .42269 L p
1 g
F P
s
P
p
.002 w
.3855 .42269 m .38677 .38703 L .36453 .38503 L p
1 g
F P
s
P
p
.002 w
.38784 .52165 m .42859 .5498 L .43658 .52857 L p
1 g
F P
s
P
p
.002 w
.43658 .52857 m .40132 .50412 L .38784 .52165 L p
1 g
F P
s
P
p
.002 w
.62157 .37457 m .60315 .33547 L .58316 .34623 L p
1 g
F P
s
P
p
.002 w
.55805 .32071 m .58316 .34623 L .60315 .33547 L p
1 g
F P
s
P
p
.002 w
.61016 .51182 m .63629 .46976 L .61653 .45919 L p
1 g
F P
s
P
p
.002 w
.62614 .41735 m .61653 .45919 L .63629 .46976 L p
1 g
F P
s
P
p
.002 w
.38024 .34432 m .36453 .38503 L .38677 .38703 L p
1 g
F P
s
P
p
.002 w
.38677 .38703 m .39976 .35355 L .38024 .34432 L p
1 g
F P
s
P
p
.002 w
.35836 .48175 m .38784 .52165 L .40132 .50412 L p
1 g
F P
s
P
p
.002 w
.40132 .50412 m .37586 .46951 L .35836 .48175 L p
1 g
F P
s
P
p
.002 w
.60315 .33547 m .57271 .30441 L .55805 .32071 L p
1 g
F P
s
P
p
.002 w
.52577 .30473 m .55805 .32071 L .57271 .30441 L p
1 g
F P
s
P
p
.002 w
.40861 .31078 m .38024 .34432 L .39976 .35355 L p
1 g
F P
s
P
p
.002 w
.39976 .35355 m .42312 .32601 L .40861 .31078 L p
1 g
F P
s
P
p
.002 w
.63629 .46976 m .64748 .42148 L .62614 .41735 L p
1 g
F P
s
P
p
.002 w
.62157 .37457 m .62614 .41735 L .64748 .42148 L p
1 g
F P
s
P
p
.002 w
.57271 .30441 m .53348 .28492 L .52577 .30473 L p
1 g
F P
s
P
p
.002 w
.48985 .30014 m .52577 .30473 L .53348 .28492 L p
1 g
F P
s
P
p
.002 w
.44655 .28825 m .40861 .31078 L .42312 .32601 L p
1 g
F P
s
P
p
.002 w
.42312 .32601 m .45431 .30751 L .44655 .28825 L p
1 g
F P
s
P
p
.002 w
.34348 .43422 m .35836 .48175 L .37586 .46951 L p
1 g
F P
s
P
p
.002 w
.37586 .46951 m .36308 .42834 L .34348 .43422 L p
1 g
F P
s
P
p
.002 w
.45431 .30751 m .48985 .30014 L .4898 .27929 L p
1 g
F P
s
P
p
.002 w
.53348 .28492 m .4898 .27929 L .48985 .30014 L p
1 g
F P
s
P
p
.002 w
.4898 .27929 m .44655 .28825 L .45431 .30751 L p
1 g
F P
s
P
p
.002 w
.47514 .5837 m .53015 .58117 L .52571 .56116 L p
1 g
F P
s
P
p
.002 w
.52571 .56116 m .47621 .5634 L .47514 .5837 L p
1 g
F P
s
P
p
.002 w
.57196 .54336 m .52571 .56116 L .53015 .58117 L p
1 g
F P
s
P
p
.002 w
.64748 .42148 m .64232 .37205 L .62157 .37457 L p
1 g
F P
s
P
p
.002 w
.60315 .33547 m .62157 .37457 L .64232 .37205 L p
1 g
F P
s
P
p
.002 w
.53015 .58117 m .58156 .5614 L .57196 .54336 L p
1 g
F P
s
P
p
.002 w
.61016 .51182 m .57196 .54336 L .58156 .5614 L p
1 g
F P
s
P
p
.002 w
.42217 .56864 m .47514 .5837 L .47621 .5634 L p
1 g
F P
s
P
p
.002 w
.47621 .5634 m .42859 .5498 L .42217 .56864 L p
1 g
F P
s
P
p
.002 w
.58156 .5614 m .62406 .52638 L .61016 .51182 L p
1 g
F P
s
P
p
.002 w
.63629 .46976 m .61016 .51182 L .62406 .52638 L p
1 g
F P
s
P
p
.002 w
.34506 .38413 m .34348 .43422 L .36308 .42834 L p
1 g
F P
s
P
p
.002 w
.36308 .42834 m .36453 .38503 L .34506 .38413 L p
1 g
F P
s
P
p
.002 w
.37681 .53741 m .42217 .56864 L .42859 .5498 L p
1 g
F P
s
P
p
.002 w
.42859 .5498 m .38784 .52165 L .37681 .53741 L p
1 g
F P
s
P
p
.002 w
.64232 .37205 m .62112 .32681 L .60315 .33547 L p
1 g
F P
s
P
p
.002 w
.57271 .30441 m .60315 .33547 L .62112 .32681 L p
1 g
F P
s
P
p
.002 w
.62406 .52638 m .65318 .47965 L .63629 .46976 L p
1 g
F P
s
P
p
.002 w
.64748 .42148 m .63629 .46976 L .65318 .47965 L p
1 g
F P
s
P
p
.002 w
.36317 .337 m .34506 .38413 L .36453 .38503 L p
1 g
F P
s
P
p
.002 w
.36453 .38503 m .38024 .34432 L .36317 .337 L p
1 g
F P
s
P
p
.002 w
.34393 .49308 m .37681 .53741 L .38784 .52165 L p
1 g
F P
s
P
p
.002 w
.38784 .52165 m .35836 .48175 L .34393 .49308 L p
1 g
F P
s
P
p
.002 w
.62112 .32681 m .58597 .29082 L .57271 .30441 L p
1 g
F P
s
P
p
.002 w
.53348 .28492 m .57271 .30441 L .58597 .29082 L p
1 g
F P
s
P
p
.002 w
.39598 .29813 m .36317 .337 L .38024 .34432 L p
1 g
F P
s
P
p
.002 w
.38024 .34432 m .40861 .31078 L .39598 .29813 L p
1 g
F P
s
P
p
.002 w
.65318 .47965 m .66572 .42597 L .64748 .42148 L p
1 g
F P
s
P
p
.002 w
.64232 .37205 m .64748 .42148 L .66572 .42597 L p
1 g
F P
s
P
p
.002 w
.58597 .29082 m .54059 .2682 L .53348 .28492 L p
1 g
F P
s
P
p
.002 w
.4898 .27929 m .53348 .28492 L .54059 .2682 L p
1 g
F P
s
P
p
.002 w
.4399 .27201 m .39598 .29813 L .40861 .31078 L p
1 g
F P
s
P
p
.002 w
.40861 .31078 m .44655 .28825 L .4399 .27201 L p
1 g
F P
s
P
p
.002 w
.32727 .44021 m .34393 .49308 L .35836 .48175 L p
1 g
F P
s
P
p
.002 w
.35836 .48175 m .34348 .43422 L .32727 .44021 L p
1 g
F P
s
P
p
.002 w
.44655 .28825 m .4898 .27929 L .49 .26165 L p
1 g
F P
s
P
p
.002 w
.54059 .2682 m .49 .26165 L .4898 .27929 L p
1 g
F P
s
P
p
.002 w
.49 .26165 m .4399 .27201 L .44655 .28825 L p
1 g
F P
s
P
p
.002 w
.47467 .60072 m .53397 .59798 L .53015 .58117 L p
1 g
F P
s
P
p
.002 w
.53015 .58117 m .47514 .5837 L .47467 .60072 L p
1 g
F P
s
P
p
.002 w
.58156 .5614 m .53015 .58117 L .53397 .59798 L p
1 g
F P
s
P
p
.002 w
.66572 .42597 m .66008 .37096 L .64232 .37205 L p
1 g
F P
s
P
p
.002 w
.62112 .32681 m .64232 .37205 L .66008 .37096 L p
1 g
F P
s
P
p
.002 w
.53397 .59798 m .58938 .57667 L .58156 .5614 L p
1 g
F P
s
P
p
.002 w
.62406 .52638 m .58156 .5614 L .58938 .57667 L p
1 g
F P
s
P
p
.002 w
.41756 .58455 m .47467 .60072 L .47514 .5837 L p
1 g
F P
s
P
p
.002 w
.47514 .5837 m .42217 .56864 L .41756 .58455 L p
1 g
F P
s
P
p
.002 w
.32894 .38442 m .32727 .44021 L .34348 .43422 L p
1 g
F P
s
P
p
.002 w
.34348 .43422 m .34506 .38413 L .32894 .38442 L p
1 g
F P
s
P
p
.002 w
.58938 .57667 m .63522 .53896 L .62406 .52638 L p
1 g
F P
s
P
p
.002 w
.65318 .47965 m .62406 .52638 L .63522 .53896 L p
1 g
F P
s
P
p
.002 w
.3686 .55094 m .41756 .58455 L .42217 .56864 L p
1 g
F P
s
P
p
.002 w
.42217 .56864 m .37681 .53741 L .3686 .55094 L p
1 g
F P
s
P
p
.002 w
.66008 .37096 m .63656 .32055 L .62112 .32681 L p
1 g
F P
s
P
p
.002 w
.58597 .29082 m .62112 .32681 L .63656 .32055 L p
1 g
F P
s
P
p
.002 w
.63522 .53896 m .66668 .48862 L .65318 .47965 L p
1 g
F P
s
P
p
.002 w
.66572 .42597 m .65318 .47965 L .66668 .48862 L p
1 g
F P
s
P
p
.002 w
.34905 .33186 m .32894 .38442 L .34506 .38413 L p
1 g
F P
s
P
p
.002 w
.34506 .38413 m .36317 .337 L .34905 .33186 L p
1 g
F P
s
P
p
.002 w
.33307 .50319 m .3686 .55094 L .37681 .53741 L p
1 g
F P
s
P
p
.002 w
.37681 .53741 m .34393 .49308 L .33307 .50319 L p
1 g
F P
s
P
p
.002 w
.63656 .32055 m .59746 .28039 L .58597 .29082 L p
1 g
F P
s
P
p
.002 w
.54059 .2682 m .58597 .29082 L .59746 .28039 L p
1 g
F P
s
P
p
.002 w
.3856 .2885 m .34905 .33186 L .36317 .337 L p
1 g
F P
s
P
p
.002 w
.36317 .337 m .39598 .29813 L .3856 .2885 L p
1 g
F P
s
P
p
.002 w
.66668 .48862 m .68028 .43075 L .66572 .42597 L p
1 g
F P
s
P
p
.002 w
.66008 .37096 m .66572 .42597 L .68028 .43075 L p
1 g
F P
s
P
p
.002 w
.59746 .28039 m .5469 .25512 L .54059 .2682 L p
1 g
F P
s
P
p
.002 w
.49 .26165 m .54059 .2682 L .5469 .25512 L p
1 g
F P
s
P
p
.002 w
.31502 .44617 m .33307 .50319 L .34393 .49308 L p
1 g
F P
s
P
p
.002 w
.34393 .49308 m .32727 .44021 L .31502 .44617 L p
1 g
F P
s
P
p
.002 w
.43459 .25934 m .3856 .2885 L .39598 .29813 L p
1 g
F P
s
P
p
.002 w
.39598 .29813 m .4399 .27201 L .43459 .25934 L p
1 g
F P
s
P
p
.002 w
.4399 .27201 m .49 .26165 L .49048 .24779 L p
1 g
F P
s
P
p
.002 w
.5469 .25512 m .49048 .24779 L .49 .26165 L p
1 g
F P
s
P
p
.002 w
.49048 .24779 m .43459 .25934 L .4399 .27201 L p
1 g
F P
s
P
p
.002 w
.68028 .43075 m .67428 .3714 L .66008 .37096 L p
1 g
F P
s
P
p
.002 w
.63656 .32055 m .66008 .37096 L .67428 .3714 L p
1 g
F P
s
P
p
.002 w
.47485 .6139 m .53703 .611 L .53397 .59798 L p
1 g
F P
s
P
p
.002 w
.53397 .59798 m .47467 .60072 L .47485 .6139 L p
1 g
F P
s
P
p
.002 w
.58938 .57667 m .53397 .59798 L .53703 .611 L p
1 g
F P
s
P
p
.002 w
.53703 .611 m .59514 .58866 L .58938 .57667 L p
1 g
F P
s
P
p
.002 w
.63522 .53896 m .58938 .57667 L .59514 .58866 L p
1 g
F P
s
P
p
.002 w
.41496 .59698 m .47485 .6139 L .47467 .60072 L p
1 g
F P
s
P
p
.002 w
.47467 .60072 m .41756 .58455 L .41496 .59698 L p
1 g
F P
s
P
p
.002 w
.31675 .38595 m .31502 .44617 L .32727 .44021 L p
1 g
F P
s
P
p
.002 w
.32727 .44021 m .32894 .38442 L .31675 .38595 L p
1 g
F P
s
P
p
.002 w
.59514 .58866 m .64323 .54915 L .63522 .53896 L p
1 g
F P
s
P
p
.002 w
.66668 .48862 m .63522 .53896 L .64323 .54915 L p
1 g
F P
s
P
p
.002 w
.36358 .56179 m .41496 .59698 L .41756 .58455 L p
1 g
F P
s
P
p
.002 w
.41756 .58455 m .3686 .55094 L .36358 .56179 L p
1 g
F P
s
P
p
.002 w
.67428 .3714 m .64898 .31697 L .63656 .32055 L p
1 g
F P
s
P
p
.002 w
.59746 .28039 m .63656 .32055 L .64898 .31697 L p
1 g
F P
s
P
p
.002 w
.64323 .54915 m .67626 .49639 L .66668 .48862 L p
1 g
F P
s
P
p
.002 w
.68028 .43075 m .66668 .48862 L .67626 .49639 L p
1 g
F P
s
P
p
.002 w
.33842 .32916 m .31675 .38595 L .32894 .38442 L p
1 g
F P
s
P
p
.002 w
.32894 .38442 m .34905 .33186 L .33842 .32916 L p
1 g
F P
s
P
p
.002 w
.32626 .51175 m .36358 .56179 L .3686 .55094 L p
1 g
F P
s
P
p
.002 w
.3686 .55094 m .33307 .50319 L .32626 .51175 L p
1 g
F P
s
P
p
.002 w
.64898 .31697 m .6068 .27356 L .59746 .28039 L p
1 g
F P
s
P
p
.002 w
.5469 .25512 m .59746 .28039 L .6068 .27356 L p
1 g
F P
s
P
p
.002 w
.67626 .49639 m .69059 .43572 L .68028 .43075 L p
1 g
F P
s
P
p
.002 w
.67428 .3714 m .68028 .43075 L .69059 .43572 L p
1 g
F P
s
P
p
.002 w
.37788 .28229 m .33842 .32916 L .34905 .33186 L p
1 g
F P
s
P
p
.002 w
.34905 .33186 m .3856 .2885 L .37788 .28229 L p
1 g
F P
s
P
p
.002 w
.6068 .27356 m .55221 .24623 L .5469 .25512 L p
1 g
F P
s
P
p
.002 w
.49048 .24779 m .5469 .25512 L .55221 .24623 L p
1 g
F P
s
P
p
.002 w
.30727 .45195 m .32626 .51175 L .33307 .50319 L p
1 g
F P
s
P
p
.002 w
.33307 .50319 m .31502 .44617 L .30727 .45195 L p
1 g
F P
s
P
p
.002 w
.43082 .25076 m .37788 .28229 L .3856 .2885 L p
1 g
F P
s
P
p
.002 w
.3856 .2885 m .43459 .25934 L .43082 .25076 L p
1 g
F P
s
P
p
.002 w
.43459 .25934 m .49048 .24779 L .49124 .23827 L p
1 g
F P
s
P
p
.002 w
.55221 .24623 m .49124 .23827 L .49048 .24779 L p
1 g
F P
s
P
p
.002 w
.49124 .23827 m .43082 .25076 L .43459 .25934 L p
1 g
F P
s
P
p
.002 w
.69059 .43572 m .68436 .37346 L .67428 .3714 L p
1 g
F P
s
P
p
.002 w
.64898 .31697 m .67428 .3714 L .68436 .37346 L p
1 g
F P
s
P
p
.002 w
.47572 .62266 m .53922 .61969 L .53703 .611 L p
1 g
F P
s
P
p
.002 w
.53703 .611 m .47485 .6139 L .47572 .62266 L p
1 g
F P
s
P
p
.002 w
.59514 .58866 m .53703 .611 L .53922 .61969 L p
1 g
F P
s
P
p
.002 w
.53922 .61969 m .59857 .59688 L .59514 .58866 L p
1 g
F P
s
P
p
.002 w
.64323 .54915 m .59514 .58866 L .59857 .59688 L p
1 g
F P
s
P
p
.002 w
.41455 .60542 m .47572 .62266 L .47485 .6139 L p
1 g
F P
s
P
p
.002 w
.47485 .6139 m .41496 .59698 L .41455 .60542 L p
1 g
F P
s
P
p
.002 w
.30903 .38875 m .30727 .45195 L .31502 .44617 L p
1 g
F P
s
P
p
.002 w
.31502 .44617 m .31675 .38595 L .30903 .38875 L p
1 g
F P
s
P
p
.002 w
.59857 .59688 m .64769 .55655 L .64323 .54915 L p
1 g
F P
s
P
p
.002 w
.67626 .49639 m .64323 .54915 L .64769 .55655 L p
1 g
F P
s
P
p
.002 w
.36207 .56951 m .41455 .60542 L .41496 .59698 L p
1 g
F P
s
P
p
.002 w
.41496 .59698 m .36358 .56179 L .36207 .56951 L p
1 g
F P
s
P
p
.002 w
.68436 .37346 m .65786 .31633 L .64898 .31697 L p
1 g
F P
s
P
p
.002 w
.6068 .27356 m .64898 .31697 L .65786 .31633 L p
1 g
F P
s
P
p
.002 w
.64769 .55655 m .68145 .50269 L .67626 .49639 L p
1 g
F P
s
P
p
.002 w
.69059 .43572 m .67626 .49639 L .68145 .50269 L p
1 g
F P
s
P
p
.002 w
.33175 .32913 m .30903 .38875 L .31675 .38595 L p
1 g
F P
s
P
p
.002 w
.31675 .38595 m .33842 .32916 L .33175 .32913 L p
1 g
F P
s
P
p
.002 w
.32394 .51844 m .36207 .56951 L .36358 .56179 L p
1 g
F P
s
P
p
.002 w
.36358 .56179 m .32626 .51175 L .32394 .51844 L p
1 g
F P
s
P
p
.002 w
.65786 .31633 m .61362 .27074 L .6068 .27356 L p
1 g
F P
s
P
p
.002 w
.55221 .24623 m .6068 .27356 L .61362 .27074 L p
1 g
F P
s
P
p
.002 w
.68145 .50269 m .69612 .44076 L .69059 .43572 L p
1 g
F P
s
P
p
.002 w
.68436 .37346 m .69059 .43572 L .69612 .44076 L p
1 g
F P
s
P
p
.002 w
.37318 .27988 m .33175 .32913 L .33842 .32916 L p
1 g
F P
s
P
p
.002 w
.33842 .32916 m .37788 .28229 L .37318 .27988 L p
1 g
F P
s
P
p
.002 w
.61362 .27074 m .55631 .24201 L .55221 .24623 L p
1 g
F P
s
P
p
.002 w
.49124 .23827 m .55221 .24623 L .55631 .24201 L p
1 g
F P
s
P
p
.002 w
.30451 .45739 m .32394 .51844 L .32626 .51175 L p
1 g
F P
s
P
p
.002 w
.32626 .51175 m .30727 .45195 L .30451 .45739 L p
1 g
F P
s
P
p
.002 w
.42879 .24676 m .37318 .27988 L .37788 .28229 L p
1 g
F P
s
P
p
.002 w
.37788 .28229 m .43082 .25076 L .42879 .24676 L p
1 g
F P
s
P
p
.002 w
.43082 .25076 m .49124 .23827 L .49227 .23364 L p
1 g
F P
s
P
p
.002 w
.55631 .24201 m .49227 .23364 L .49124 .23827 L p
1 g
F P
s
P
p
.002 w
.49227 .23364 m .42879 .24676 L .43082 .25076 L p
1 g
F P
s
P
p
.002 w
.69612 .44076 m .68979 .37718 L .68436 .37346 L p
1 g
F P
s
P
p
.002 w
.65786 .31633 m .68436 .37346 L .68979 .37718 L p
1 g
F P
s
P
p
.002 w
.4773 .6265 m .54043 .62353 L .53922 .61969 L p
1 g
F P
s
P
p
.002 w
.53922 .61969 m .47572 .62266 L .4773 .6265 L p
1 g
F P
s
P
p
.002 w
.59857 .59688 m .53922 .61969 L .54043 .62353 L p
1 g
F P
s
P
p
.002 w
.54043 .62353 m .59942 .60087 L .59857 .59688 L p
1 g
F P
s
P
p
.002 w
.64769 .55655 m .59857 .59688 L .59942 .60087 L p
1 g
F P
s
P
p
.002 w
.4165 .60937 m .4773 .6265 L .47572 .62266 L p
1 g
F P
s
P
p
.002 w
.47572 .62266 m .41455 .60542 L .4165 .60937 L p
1 g
F P
s
P
p
.002 w
.3063 .39285 m .30451 .45739 L .30727 .45195 L p
1 g
F P
s
P
p
.002 w
.30727 .45195 m .30903 .38875 L .3063 .39285 L p
1 g
F P
s
P
p
.002 w
.59942 .60087 m .64826 .56078 L .64769 .55655 L p
1 g
F P
s
P
p
.002 w
.68145 .50269 m .64769 .55655 L .64826 .56078 L p
1 g
F P
s
P
p
.002 w
.36434 .5737 m .4165 .60937 L .41455 .60542 L p
1 g
F P
s
P
p
.002 w
.41455 .60542 m .36207 .56951 L .36434 .5737 L p
1 g
F P
s
P
p
.002 w
.68979 .37718 m .66275 .31883 L .65786 .31633 L p
1 g
F P
s
P
p
.002 w
.61362 .27074 m .65786 .31633 L .66275 .31883 L p
1 g
F P
s
P
p
.002 w
.64826 .56078 m .68182 .50727 L .68145 .50269 L p
1 g
F P
s
P
p
.002 w
.69612 .44076 m .68145 .50269 L .68182 .50727 L p
1 g
F P
s
P
p
.002 w
.3295 .33193 m .3063 .39285 L .30903 .38875 L p
1 g
F P
s
P
p
.002 w
.30903 .38875 m .33175 .32913 L .3295 .33193 L p
1 g
F P
s
P
p
.004 w
.60975 .22831 m
.61871 .2118 L
s
P
p
.002 w
.32646 .52296 m .36434 .5737 L .36207 .56951 L p
1 g
F P
s
P
p
.002 w
.36207 .56951 m .32394 .51844 L .32646 .52296 L p
1 g
F P
s
P
p
.002 w
.66275 .31883 m .61757 .27225 L .61362 .27074 L p
1 g
F P
s
P
p
.002 w
.55631 .24201 m .61362 .27074 L .61757 .27225 L p
1 g
F P
s
P
p
.002 w
.68182 .50727 m .6964 .44573 L .69612 .44076 L p
1 g
F P
s
P
p
.002 w
.68979 .37718 m .69612 .44076 L .6964 .44573 L p
1 g
F P
s
P
p
.002 w
.37184 .2816 m .3295 .33193 L .33175 .32913 L p
1 g
F P
s
P
p
.002 w
.33175 .32913 m .37318 .27988 L .37184 .2816 L p
1 g
F P
s
P
p
.002 w
.61757 .27225 m .55901 .24289 L .55631 .24201 L p
1 g
F P
s
P
p
.002 w
.49227 .23364 m .55631 .24201 L .55901 .24289 L p
1 g
F P
s
P
p
.002 w
.30717 .46231 m .32646 .52296 L .32394 .51844 L p
1 g
F P
s
P
p
.002 w
.32394 .51844 m .30451 .45739 L .30717 .46231 L p
1 g
F P
s
P
p
.002 w
.42868 .24775 m .37184 .2816 L .37318 .27988 L p
1 g
F P
s
P
p
.002 w
.37318 .27988 m .42879 .24676 L .42868 .24775 L p
1 g
F P
s
P
p
.002 w
.42879 .24676 m .49227 .23364 L .49356 .23434 L p
1 g
F P
s
P
p
.002 w
.55901 .24289 m .49356 .23434 L .49227 .23364 L p
1 g
F P
s
P
p
.002 w
.49356 .23434 m .42868 .24775 L .42879 .24676 L p
1 g
F P
s
P
p
.002 w
.6964 .44573 m .69012 .38257 L .68979 .37718 L p
1 g
F P
s
P
p
.002 w
.66275 .31883 m .68979 .37718 L .69012 .38257 L p
1 g
F P
s
P
p
.002 w
.4796 .62497 m .54055 .62211 L .54043 .62353 L p
1 g
F P
s
P
p
.002 w
.54043 .62353 m .4773 .6265 L .4796 .62497 L p
1 g
F P
s
P
p
.002 w
.59942 .60087 m .54043 .62353 L .54055 .62211 L p
1 g
F P
s
P
p
.002 w
.54055 .62211 m .59751 .60022 L .59942 .60087 L p
1 g
F P
s
P
p
.002 w
.64826 .56078 m .59942 .60087 L .59751 .60022 L p
1 g
F P
s
P
p
.002 w
.42091 .60842 m .4796 .62497 L .4773 .6265 L p
1 g
F P
s
P
p
.002 w
.4773 .6265 m .4165 .60937 L .42091 .60842 L p
1 g
F P
s
P
p
.002 w
.30896 .39819 m .30717 .46231 L .30451 .45739 L p
1 g
F P
s
P
p
.002 w
.30451 .45739 m .3063 .39285 L .30896 .39819 L p
1 g
F P
s
P
p
.002 w
.59751 .60022 m .64465 .56151 L .64826 .56078 L p
1 g
F P
s
P
p
.002 w
.68182 .50727 m .64826 .56078 L .64465 .56151 L p
1 g
F P
s
P
p
.002 w
.37058 .57399 m .42091 .60842 L .4165 .60937 L p
1 g
F P
s
P
p
.002 w
.4165 .60937 m .36434 .5737 L .37058 .57399 L p
1 g
F P
s
P
p
.002 w
.69012 .38257 m .66324 .32461 L .66275 .31883 L p
1 g
F P
s
P
p
.002 w
.61757 .27225 m .66275 .31883 L .66324 .32461 L p
1 g
F P
s
P
p
.002 w
.64465 .56151 m .67704 .50986 L .68182 .50727 L p
1 g
F P
s
P
p
.002 w
.6964 .44573 m .68182 .50727 L .67704 .50986 L p
1 g
F P
s
P
p
.002 w
.33203 .33768 m .30896 .39819 L .3063 .39285 L p
1 g
F P
s
P
p
.002 w
.3063 .39285 m .3295 .33193 L .33203 .33768 L p
1 g
F P
s
P
p
.002 w
.33406 .52503 m .37058 .57399 L .36434 .5737 L p
1 g
F P
s
P
p
.002 w
.36434 .5737 m .32646 .52296 L .33406 .52503 L p
1 g
F P
s
P
p
.002 w
.66324 .32461 m .61834 .27834 L .61757 .27225 L p
1 g
F P
s
P
p
.002 w
.55901 .24289 m .61757 .27225 L .61834 .27834 L p
1 g
F P
s
P
p
.002 w
.67704 .50986 m .69108 .45048 L .6964 .44573 L p
1 g
F P
s
P
p
.002 w
.69012 .38257 m .6964 .44573 L .69108 .45048 L p
1 g
F P
s
P
p
.002 w
.37412 .28768 m .33203 .33768 L .3295 .33193 L p
1 g
F P
s
P
p
.002 w
.3295 .33193 m .37184 .2816 L .37412 .28768 L p
1 g
F P
s
P
p
.002 w
.61834 .27834 m .56014 .2492 L .55901 .24289 L p
1 g
F P
s
P
p
.002 w
.49356 .23434 m .55901 .24289 L .56014 .2492 L p
1 g
F P
s
P
p
.002 w
.3155 .46653 m .33406 .52503 L .32646 .52296 L p
1 g
F P
s
P
p
.002 w
.32646 .52296 m .30717 .46231 L .3155 .46653 L p
1 g
F P
s
P
p
.002 w
.43062 .25405 m .37412 .28768 L .37184 .2816 L p
1 g
F P
s
P
p
.002 w
.37184 .2816 m .42868 .24775 L .43062 .25405 L p
1 g
F P
s
P
p
.002 w
.42868 .24775 m .49356 .23434 L .49509 .24072 L p
1 g
F P
s
P
p
.002 w
.56014 .2492 m .49509 .24072 L .49356 .23434 L p
1 g
F P
s
P
p
.002 w
.49509 .24072 m .43062 .25405 L .42868 .24775 L p
1 g
F P
s
P
p
.002 w
.69108 .45048 m .68498 .38957 L .69012 .38257 L p
1 g
F P
s
P
p
.002 w
.66324 .32461 m .69012 .38257 L .68498 .38957 L p
1 g
F P
s
P
p
.002 w
.48258 .61776 m .5395 .61509 L .54055 .62211 L p
1 g
F P
s
P
p
.002 w
.54055 .62211 m .4796 .62497 L .48258 .61776 L p
1 g
F P
s
P
p
.002 w
.59751 .60022 m .54055 .62211 L .5395 .61509 L p
1 g
F P
s
P
p
.002 w
.5395 .61509 m .5927 .59465 L .59751 .60022 L p
1 g
F P
s
P
p
.002 w
.64465 .56151 m .59751 .60022 L .5927 .59465 L p
1 g
F P
s
P
p
.002 w
.42779 .60228 m .48258 .61776 L .4796 .62497 L p
1 g
F P
s
P
p
.002 w
.4796 .62497 m .42091 .60842 L .42779 .60228 L p
1 g
F P
s
P
p
.002 w
.31728 .4047 m .3155 .46653 L .30717 .46231 L p
1 g
F P
s
P
p
.002 w
.30717 .46231 m .30896 .39819 L .31728 .4047 L p
1 g
F P
s
P
p
.002 w
.5927 .59465 m .63671 .55849 L .64465 .56151 L p
1 g
F P
s
P
p
.002 w
.67704 .50986 m .64465 .56151 L .63671 .55849 L p
1 g
F P
s
P
p
.002 w
.38086 .57012 m .42779 .60228 L .42091 .60842 L p
1 g
F P
s
P
p
.002 w
.42091 .60842 m .37058 .57399 L .38086 .57012 L p
1 g
F P
s
P
p
.002 w
.68498 .38957 m .65902 .3337 L .66324 .32461 L p
1 g
F P
s
P
p
.002 w
.61834 .27834 m .66324 .32461 L .65902 .3337 L p
1 g
F P
s
P
p
.002 w
.63671 .55849 m .6669 .51026 L .67704 .50986 L p
1 g
F P
s
P
p
.002 w
.69108 .45048 m .67704 .50986 L .6669 .51026 L p
1 g
F P
s
P
p
.002 w
.33958 .34638 m .31728 .4047 L .30896 .39819 L p
1 g
F P
s
P
p
.002 w
.30896 .39819 m .33203 .33768 L .33958 .34638 L p
1 g
F P
s
P
p
.002 w
.34684 .52442 m .38086 .57012 L .37058 .57399 L p
1 g
F P
s
P
p
.002 w
.37058 .57399 m .33406 .52503 L .34684 .52442 L p
1 g
F P
s
P
p
.002 w
.65902 .3337 m .61569 .28914 L .61834 .27834 L p
1 g
F P
s
P
p
.002 w
.56014 .2492 m .61834 .27834 L .61569 .28914 L p
1 g
F P
s
P
p
.002 w
.6669 .51026 m .67995 .45486 L .69108 .45048 L p
1 g
F P
s
P
p
.002 w
.68498 .38957 m .69108 .45048 L .67995 .45486 L p
1 g
F P
s
P
p
.002 w
.38019 .29821 m .33958 .34638 L .33203 .33768 L p
1 g
F P
s
P
p
.002 w
.33203 .33768 m .37412 .28768 L .38019 .29821 L p
1 g
F P
s
P
p
.002 w
.61569 .28914 m .55956 .26108 L .56014 .2492 L p
1 g
F P
s
P
p
.004 w
.59353 .25819 m
.60975 .22831 L
s
P
p
.002 w
.49509 .24072 m .56014 .2492 L .55956 .26108 L p
1 g
F P
s
P
p
.002 w
.32961 .46986 m .34684 .52442 L .33406 .52503 L p
1 g
F P
s
P
p
.002 w
.33406 .52503 m .3155 .46653 L .32961 .46986 L p
1 g
F P
s
P
p
.002 w
.43467 .26579 m .38019 .29821 L .37412 .28768 L p
1 g
F P
s
P
p
.002 w
.37412 .28768 m .43062 .25405 L .43467 .26579 L p
1 g
F P
s
P
p
.002 w
.43062 .25405 m .49509 .24072 L .49684 .25294 L p
1 g
F P
s
P
p
.002 w
.55956 .26108 m .49684 .25294 L .49509 .24072 L p
1 g
F P
s
P
p
.002 w
.49684 .25294 m .43467 .26579 L .43062 .25405 L p
1 g
F P
s
P
p
.002 w
.67995 .45486 m .6742 .39807 L .68498 .38957 L p
1 g
F P
s
P
p
.002 w
.65902 .3337 m .68498 .38957 L .6742 .39807 L p
1 g
F P
s
P
p
.002 w
.4862 .60472 m .53725 .60235 L .5395 .61509 L p
1 g
F P
s
P
p
.002 w
.5395 .61509 m .48258 .61776 L .4862 .60472 L p
1 g
F P
s
P
p
.002 w
.5927 .59465 m .5395 .61509 L .53725 .60235 L p
1 g
F P
s
P
p
.002 w
.53725 .60235 m .58496 .58401 L .5927 .59465 L p
1 g
F P
s
P
p
.002 w
.63671 .55849 m .5927 .59465 L .58496 .58401 L p
1 g
F P
s
P
p
.002 w
.4371 .59081 m .4862 .60472 L .48258 .61776 L p
1 g
F P
s
P
p
.002 w
.48258 .61776 m .42779 .60228 L .4371 .59081 L p
1 g
F P
s
P
p
.002 w
.33136 .41225 m .32961 .46986 L .3155 .46653 L p
1 g
F P
s
P
p
.002 w
.3155 .46653 m .31728 .4047 L .33136 .41225 L p
1 g
F P
s
P
p
.002 w
.58496 .58401 m .6244 .55157 L .63671 .55849 L p
1 g
F P
s
P
p
.002 w
.6669 .51026 m .63671 .55849 L .6244 .55157 L p
1 g
F P
s
P
p
.002 w
.39509 .56194 m .4371 .59081 L .42779 .60228 L p
1 g
F P
s
P
p
.002 w
.42779 .60228 m .38086 .57012 L .39509 .56194 L p
1 g
F P
s
P
p
.002 w
.6742 .39807 m .64993 .34603 L .65902 .3337 L p
1 g
F P
s
P
p
.002 w
.61569 .28914 m .65902 .3337 L .64993 .34603 L p
1 g
F P
s
P
p
.002 w
.6244 .55157 m .65141 .50832 L .6669 .51026 L p
1 g
F P
s
P
p
.002 w
.67995 .45486 m .6669 .51026 L .65141 .50832 L p
1 g
F P
s
P
p
.002 w
.3522 .35794 m .33136 .41225 L .31728 .4047 L p
1 g
F P
s
P
p
.002 w
.31728 .4047 m .33958 .34638 L .3522 .35794 L p
1 g
F P
s
P
p
.002 w
.3647 .52098 m .39509 .56194 L .38086 .57012 L p
1 g
F P
s
P
p
.002 w
.38086 .57012 m .34684 .52442 L .3647 .52098 L p
1 g
F P
s
P
p
.002 w
.64993 .34603 m .6095 .30457 L .61569 .28914 L p
1 g
F P
s
P
p
.002 w
.55956 .26108 m .61569 .28914 L .6095 .30457 L p
1 g
F P
s
P
p
.002 w
.65141 .50832 m .66303 .45868 L .67995 .45486 L p
1 g
F P
s
P
p
.002 w
.6742 .39807 m .67995 .45486 L .66303 .45868 L p
1 g
F P
s
P
p
.002 w
.39008 .31311 m .3522 .35794 L .33958 .34638 L p
1 g
F P
s
P
p
.002 w
.33958 .34638 m .38019 .29821 L .39008 .31311 L p
1 g
F P
s
P
p
.002 w
.34939 .47214 m .3647 .52098 L .34684 .52442 L p
1 g
F P
s
P
p
.002 w
.34684 .52442 m .32961 .46986 L .34939 .47214 L p
1 g
F P
s
P
p
.002 w
.6095 .30457 m .55717 .2785 L .55956 .26108 L p
1 g
F P
s
P
p
.004 w
.58372 .27627 m
.59353 .25819 L
s
P
p
.002 w
.49684 .25294 m .55956 .26108 L .55717 .2785 L p
1 g
F P
s
P
p
.002 w
.44084 .28294 m .39008 .31311 L .38019 .29821 L p
1 g
F P
s
P
p
.002 w
.38019 .29821 m .43467 .26579 L .44084 .28294 L p
1 g
F P
s
P
p
.002 w
.43467 .26579 m .49684 .25294 L .49875 .27095 L p
1 g
F P
s
P
p
.002 w
.55717 .2785 m .49875 .27095 L .49684 .25294 L p
1 g
F P
s
P
p
.002 w
.49875 .27095 m .44084 .28294 L .43467 .26579 L p
1 g
F P
s
P
p
.002 w
.66303 .45868 m .65778 .40787 L .6742 .39807 L p
1 g
F P
s
P
p
.002 w
.64993 .34603 m .6742 .39807 L .65778 .40787 L p
1 g
F P
s
P
p
.002 w
.49038 .58595 m .53379 .58395 L .53725 .60235 L p
1 g
F P
s
P
p
.002 w
.53725 .60235 m .4862 .60472 L .49038 .58595 L p
1 g
F P
s
P
p
.002 w
.58496 .58401 m .53725 .60235 L .53379 .58395 L p
1 g
F P
s
P
p
.002 w
.53379 .58395 m .57436 .56835 L .58496 .58401 L p
1 g
F P
s
P
p
.002 w
.6244 .55157 m .58496 .58401 L .57436 .56835 L p
1 g
F P
s
P
p
.002 w
.35105 .42063 m .34939 .47214 L .32961 .46986 L p
1 g
F P
s
P
p
.002 w
.32961 .46986 m .33136 .41225 L .35105 .42063 L p
1 g
F P
s
P
p
.002 w
.44866 .57408 m .49038 .58595 L .4862 .60472 L p
1 g
F P
s
P
p
.002 w
.4862 .60472 m .4371 .59081 L .44866 .57408 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.57436 .56835 m .60787 .54074 L .6244 .55157 L p
1 g
F P
s
P
p
.002 w
.65141 .50832 m .6244 .55157 L .60787 .54074 L p
1 g
F P
s
P
p
.002 w
.41302 .5495 m .44866 .57408 L .4371 .59081 L p
1 g
F P
s
P
p
.002 w
.4371 .59081 m .39509 .56194 L .41302 .5495 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.65778 .40787 m .63598 .36138 L .64993 .34603 L p
1 g
F P
s
P
p
.002 w
.6095 .30457 m .64993 .34603 L .63598 .36138 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.60787 .54074 m .63077 .50396 L .65141 .50832 L p
1 g
F P
s
P
p
.002 w
.66303 .45868 m .65141 .50832 L .63077 .50396 L p
1 g
F P
s
P
p
.002 w
.36977 .37213 m .35105 .42063 L .33136 .41225 L p
1 g
F P
s
P
p
.002 w
.33136 .41225 m .3522 .35794 L .36977 .37213 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.38731 .51468 m .41302 .5495 L .39509 .56194 L p
1 g
F P
s
P
p
.002 w
.39509 .56194 m .3647 .52098 L .38731 .51468 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63598 .36138 m .59977 .32438 L .6095 .30457 L p
1 g
F P
s
P
p
.002 w
.55717 .2785 m .6095 .30457 L .59977 .32438 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.63077 .50396 m .64055 .4618 L .66303 .45868 L p
1 g
F P
s
P
p
.002 w
.65778 .40787 m .66303 .45868 L .64055 .4618 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.40367 .33211 m .36977 .37213 L .3522 .35794 L p
1 g
F P
s
P
p
.002 w
.3522 .35794 m .39008 .31311 L .40367 .33211 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.37442 .47323 m .38731 .51468 L .3647 .52098 L p
1 g
F P
s
P
p
.002 w
.3647 .52098 m .34939 .47214 L .37442 .47323 L p
1 g
F P
s
P
p
.002 w
.59977 .32438 m .55297 .30116 L .55717 .2785 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.56655 .3079 L
s
P
p
.004 w
.57436 .29351 m
.57495 .29242 L
s
P
p
.004 w
.57495 .29242 m
.5779 .28698 L
s
P
p
.004 w
.5779 .28698 m
.58372 .27627 L
s
P
p
.002 w
.49875 .27095 m .55717 .2785 L .55297 .30116 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.44903 .30518 m .40367 .33211 L .39008 .31311 L p
1 g
F P
s
P
p
.002 w
.39008 .31311 m .44084 .28294 L .44903 .30518 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.44084 .28294 m .49875 .27095 L .50076 .29447 L p
1 g
F P
s
P
p
.002 w
.55297 .30116 m .50076 .29447 L .49875 .27095 L p
1 g
F P
s
P
p
.002 w
.64055 .4618 m .63599 .41871 L .65778 .40787 L p
1 g
F P
s
P
p
.002 w
.63598 .36138 m .65778 .40787 L .63599 .41871 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.50076 .29447 m .44903 .30518 L .44084 .28294 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .5801 L p
1 g
F P
s
P
p
.002 w
.53196 .57457 m .53379 .58395 L p
.52433 .57855 L 1 g
F P
s
P
p
.52433 .57855 m .52196 .57719 L .53171 .57463 L 1 g
F
P
p
.52433 .57855 m .53171 .57463 L .53196 .57457 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57463 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57463 L .53195 .57451 L 1 g
F
P
p
.54811 .56363 m .53195 .57451 L .54763 .56355 L 1 g
F
P
p
.57436 .56835 m .53966 .57339 L .54811 .56363 L 1 g
F
P
p
.53966 .57339 m .53195 .57451 L .54811 .56363 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54902 .56258 L p
1 g
F P
s
P
p
.56075 .54566 m .54902 .56258 L .55563 .55494 L 1 g
F
P
p
.54854 .56129 m .53195 .57451 L .54216 .56737 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56137 .54831 m .56388 .55219 L p
.55654 .55389 L 1 g
F P
s
P
p
.002 w
.56388 .55219 m .57436 .56835 L p
.54763 .56355 L 1 g
F P
s
P
p
.56075 .54566 m .55563 .55494 L .56137 .54831 L 1 g
F
P
p
.56175 .54784 m .56137 .54831 L .56169 .54785 L 1 g
F
P
p
.60787 .54074 m .5616 .54827 L .56175 .54784 L 1 g
F
P
p
.5616 .54827 m .56137 .54831 L .56175 .54784 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56181 .54767 L p
1 g
F P
s
P
p
.002 w
.60787 .54074 m .57436 .56835 L .56137 .54831 L p
1 g
F P
s
P
p
.56654 .52734 m .56181 .54767 L .56196 .54725 L 1 g
F
P
p
.002 w
.58748 .52618 m .56808 .5422 L p
.56834 .52486 L 1 g
F P
s
P
p
.002 w
.56808 .5422 m .56196 .54725 L p
.56731 .52846 L 1 g
F P
s
P
p
.56808 .5422 m .56731 .52846 L .56834 .52486 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56731 .52846 L p
1 g
F P
s
P
p
.56515 .50826 m .56731 .52846 L .56677 .51877 L 1 g
F
P
p
.56654 .52734 m .56196 .54725 L .56459 .53802 L 1 g
F
P
p
.002 w
.56181 .54767 m .56075 .54566 L p
.56137 .54831 L 1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.58748 .52618 m .60787 .54074 L p
.56175 .54784 L 1 g
F P
s
P
p
.002 w
.56113 .54794 m .56196 .54725 L p
.56175 .54784 L 1 g
F P
s
P
p
.56175 .54784 m .56181 .54767 L .58748 .52618 L 1 g
F
P
p
.002 w
.54902 .56258 m .54854 .56129 L p
.54216 .56737 L 1 g
F P
s
P
p
.54763 .56355 m .52918 .56023 L .55654 .55389 L 1 g
F
P
p
.54902 .56258 m .55654 .55389 L .56388 .55219 L 1 g
F
P
p
.54763 .56355 m .55654 .55389 L .54902 .56258 L 1 g
F
P
p
.56137 .54831 m .54998 .56518 L .56186 .54775 L 1 g
F
P
p
.55563 .55494 m .55123 .56291 L .56137 .54831 L 1 g
F
P
p
.55123 .56291 m .54998 .56518 L .56137 .54831 L 1 g
F
P
p
.002 w
.56196 .54725 m .5623 .54697 L p
.56181 .54767 L 1 g
F P
s
P
p
.002 w
.5623 .54697 m .58748 .52618 L p
.56181 .54767 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56812 .52964 L p
1 g
F P
s
P
p
.002 w
.56812 .52964 m .56654 .52734 L p
.56394 .5416 L 1 g
F P
s
P
p
.56394 .5416 m .56257 .5491 L .56812 .52964 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56113 .54794 m .54561 .5233 L p
.56711 .52478 L 1 g
F P
s
P
p
.56834 .52486 m .5673 .52819 L .56711 .52478 L 1 g
F
P
p
.5673 .52819 m .56113 .54794 L .56711 .52478 L 1 g
F
P
p
.002 w
.56196 .54725 m .56113 .54794 L p
.56834 .52486 L 1 g
F P
s
P
p
.56515 .50826 m .56677 .51877 L .56629 .51012 L 1 g
F
P
p
.60545 .49721 m .56647 .51006 L .56607 .50764 L 1 g
F
P
p
.56647 .51006 m .56629 .51012 L .56624 .50956 L 1 g
F
P
p
.56647 .51006 m .56624 .50956 L .56607 .50764 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56624 .50956 L p
1 g
F P
s
P
p
.002 w
.60545 .49721 m .58748 .52618 L .56629 .51012 L p
1 g
F P
s
P
p
.55661 .4905 m .56624 .50956 L .56485 .50655 L 1 g
F
P
p
.002 w
.57617 .48821 m .56794 .50154 L p
.55566 .48782 L 1 g
F P
s
P
p
.002 w
.56794 .50154 m .56485 .50655 L p
.55736 .4913 L 1 g
F P
s
P
p
.56794 .50154 m .55736 .4913 L .55566 .48782 L 1 g
F
P
p
.55661 .4905 m .56485 .50655 L .56247 .50171 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56624 .50956 m .56515 .50826 L p
.56629 .51012 L 1 g
F P
s
P
p
.002 w
.56629 .51012 m .56381 .50824 L p
.56543 .50781 L 1 g
F P
s
P
p
.56607 .50764 m .56624 .50956 L .56543 .50781 L 1 g
F
P
p
.56624 .50956 m .56629 .51012 L .56543 .50781 L 1 g
F
P
p
.002 w
.56381 .50824 m .57617 .48821 L .60545 .49721 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55815 .49214 L p
1 g
F P
s
P
p
.002 w
.55815 .49214 m .55661 .4905 L p
.5636 .50387 L 1 g
F P
s
P
p
.5636 .50387 m .56713 .51061 L .55815 .49214 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .4913 L p
1 g
F P
s
P
p
.54174 .47608 m .55736 .4913 L .55044 .4846 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56381 .50824 m .53762 .48748 L p
.55373 .48778 L 1 g
F P
s
P
p
.55566 .48782 m .55685 .4908 L .55373 .48778 L 1 g
F
P
p
.55685 .4908 m .56381 .50824 L .55373 .48778 L 1 g
F
P
p
.002 w
.56485 .50655 m .56381 .50824 L p
.55566 .48782 L 1 g
F P
s
P
p
.54174 .47608 m .55044 .4846 L .54351 .47789 L 1 g
F
P
p
.002 w
.54351 .47789 m .53762 .48748 L p
.5421 .4767 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54248 .47689 L p
1 g
F P
s
P
p
.54248 .47689 m .5421 .4767 L .54216 .47657 L 1 g
F
P
p
.54351 .47789 m .5421 .4767 L .54248 .47689 L 1 g
F
P
p
.52214 .46667 m .54248 .47689 L .54077 .47606 L 1 g
F
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.002 w
.50987 .46463 m .51754 .46482 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.54077 .47606 m .51361 .46601 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.53762 .48748 m .51114 .46568 L p
.54096 .47615 L 1 g
F P
s
P
p
.5421 .4767 m .53762 .48748 L .54096 .47615 L 1 g
F
P
p
.002 w
.51361 .46601 m .54216 .47657 L p
.51114 .46568 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52247 .46721 L p
1 g
F P
s
P
p
.002 w
.52247 .46721 m .52214 .46667 L p
.53337 .47248 L 1 g
F P
s
P
p
.53337 .47248 m .54302 .47747 L .52247 .46721 L 1 g
F
P
p
.54216 .47657 m .5421 .4767 L .54096 .47615 L 1 g
F
P
p
.5 .4634 m .52246 .4672 L .51361 .46601 L 1 g
F
P
p
.002 w
.51702 .49956 m .50493 .50009 L .50975 .46549 L p
1 g
F P
s
P
p
.002 w
.51005 .46553 m .51702 .49956 L p
.50975 .46549 L 1 g
F P
s
P
p
.002 w
.52832 .4952 m .51702 .49956 L .51005 .46553 L p
1 g
F P
s
P
p
.002 w
.50493 .50009 m .49334 .49673 L .50945 .46544 L p
1 g
F P
s
P
p
.002 w
.48351 .48983 m .47649 .48014 L .50847 .46529 L p
1 g
F P
s
P
p
.5 .4634 m .51371 .46604 L .50821 .46524 L 1 g
F
P
p
.002 w
.50847 .46529 m .47649 .48014 L p
.50664 .46499 L 1 g
F P
s
P
p
.50815 .46523 m .50821 .46524 L .50816 .46524 L 1 g
F
P
p
.5 .4634 m .50821 .46524 L .50815 .46523 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47649 .48014 m .47326 .46937 L p
.50664 .46499 L 1 g
F P
s
P
p
.002 w
.47512 .46845 m .50664 .46499 L p
.47326 .46937 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.47649 .48014 m .44415 .49396 L p
.4711 .47039 L 1 g
F P
s
P
p
.002 w
.47326 .46937 m .47649 .48014 L p
.4711 .47039 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47305 .46868 m .47359 .45669 L .49109 .46052 L p
1 g
F P
s
P
p
.5 .4634 m .50816 .46524 L .50788 .46519 L 1 g
F
P
p
.50778 .46518 m .50788 .46519 L .50778 .46518 L 1 g
F
P
p
.5 .4634 m .50788 .46519 L .50778 .46518 L 1 g
F
P
p
.002 w
.50664 .46499 m .47512 .46845 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.48931 .46551 L 1 g
F P
s
P
p
.4775 .46727 m .5 .46391 L .50664 .46499 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .46442 L p
.48931 .46551 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46391 L .48931 .46551 L 1 g
F
P
p
.48817 .46197 m .49109 .46052 L .50188 .46362 L 1 g
F
P
p
.50647 .46496 m .50785 .46519 L .50665 .46501 L 1 g
F
P
p
.5 .4634 m .50778 .46518 L .50647 .46496 L 1 g
F
P
p
.50778 .46518 m .50785 .46519 L .50647 .46496 L 1 g
F
P
p
.002 w
.5 .46402 m .5 .4634 L p
.50679 .46504 L 1 g
F P
s
P
p
.5 .46391 m .50188 .46362 L .50664 .46499 L 1 g
F
P
p
.48817 .46197 m .50188 .46362 L .5 .46391 L 1 g
F
P
p
.4775 .46727 m .48817 .46197 L .5 .46391 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46727 L p
1 g
F P
s
P
p
.48931 .46551 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.002 w
.49109 .46052 m .50987 .46463 L .50664 .46499 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.45826 .47608 m .4775 .46727 L .47502 .4685 L 1 g
F
P
p
.002 w
.47512 .46845 m .47305 .46868 L p
.49109 .46052 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .4774 .46743 L p
.47502 .4685 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44242 .49153 L p
1 g
F P
s
P
p
.41407 .50559 m .44303 .49028 L .44242 .49153 L 1 g
F
P
p
.002 w
.44058 .49534 m .43707 .49669 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.43707 .49669 m .41407 .50559 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44242 .49153 m .44237 .49158 L p
.44203 .49233 L 1 g
F P
s
P
p
.43485 .50826 m .44242 .49153 L .44203 .49233 L 1 g
F
P
p
.002 w
.44242 .49153 m .44339 .4905 L p
.45034 .48384 L 1 g
F P
s
P
p
.44318 .49079 m .44556 .48849 L .4711 .47039 L 1 g
F
P
p
.45034 .48384 m .44318 .49079 L .44242 .49153 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44556 .48849 m .4577 .47669 L .4711 .47039 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .4577 .47669 L p
1 g
F P
s
P
p
.002 w
.4577 .47669 m .45698 .47747 L p
.45034 .48384 L 1 g
F P
s
P
p
.44339 .4905 m .4577 .47669 L .45034 .48384 L 1 g
F
P
p
.002 w
.44125 .48443 m .43733 .47151 L p
.46394 .47063 L 1 g
F P
s
P
p
.45826 .47608 m .4774 .46743 L .46921 .47128 L 1 g
F
P
p
.002 w
.4577 .47669 m .45826 .47608 L p
.46921 .47128 L 1 g
F P
s
P
p
.4577 .47669 m .46394 .47063 L .4711 .47039 L 1 g
F
P
p
.44125 .48443 m .46394 .47063 L .4577 .47669 L 1 g
F
P
p
.44303 .49028 m .44745 .48152 L .4577 .47669 L 1 g
F
P
p
.44303 .49028 m .4577 .47669 L .44556 .48849 L 1 g
F
P
p
.002 w
.44415 .49396 m .44318 .49079 L p
.4711 .47039 L 1 g
F P
s
P
p
.43485 .50826 m .44237 .49158 L .44191 .4925 L 1 g
F
P
p
.002 w
.4273 .52362 m .41407 .50559 L .43508 .49747 L p
1 g
F P
s
P
p
.002 w
.43508 .49747 m .44058 .49534 L p
.43408 .50918 L 1 g
F P
s
P
p
.4273 .52362 m .43508 .49747 L .43408 .50918 L 1 g
F
P
p
.002 w
.4324 .52889 m .43346 .52734 L p
.43319 .51959 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4324 .52889 L p
1 g
F P
s
P
p
.002 w
.41407 .50559 m .43227 .53039 L p
.41302 .5495 L 1 g
F P
s
P
p
.002 w
.43301 .5314 m .4273 .52362 L p
.42997 .51891 L 1 g
F P
s
P
p
.43925 .54566 m .4324 .52889 L .43301 .5314 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43408 .50918 L p
1 g
F P
s
P
p
.43346 .52734 m .43408 .50918 L .43319 .51959 L 1 g
F
P
p
.43301 .5314 m .4324 .52889 L .44415 .49396 L 1 g
F
P
p
.4324 .52889 m .42997 .51891 L .43383 .51212 L 1 g
F
P
p
.4324 .52889 m .43383 .51212 L .44415 .49396 L 1 g
F
P
p
.43485 .50826 m .44191 .4925 L .43834 .50011 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44058 .49534 m .44415 .49396 L p
.4273 .52362 L 1 g
F P
s
P
p
.002 w
.43408 .50918 m .43287 .51061 L p
.43319 .51959 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43233 .52898 L p
1 g
F P
s
P
p
.002 w
.43233 .52898 m .4324 .52889 L p
.43249 .52528 L 1 g
F P
s
P
p
.43249 .52528 m .43287 .51061 L .43233 .52898 L 1 g
F
P
p
.002 w
.43227 .53039 m .43301 .5314 L p
.43219 .53213 L 1 g
F P
s
P
p
.41302 .5495 m .43227 .53039 L .43219 .53213 L 1 g
F
P
p
.43925 .54566 m .43301 .5314 L .43351 .53319 L 1 g
F
P
p
.43925 .54566 m .43337 .53288 L .43504 .53733 L 1 g
F
P
p
.002 w
.43301 .5314 m .43419 .53301 L .43359 .53347 L p
1 g
F P
s
P
p
.002 w
.43359 .53347 m .41302 .5495 L p
.43301 .5314 L 1 g
F P
s
P
p
.43351 .53319 m .43301 .5314 L .43337 .53288 L 1 g
F
P
p
.44866 .57408 m .43034 .53601 L .4385 .54671 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43861 .54686 L p
1 g
F P
s
P
p
.45146 .56129 m .43861 .54686 L .44603 .55657 L 1 g
F
P
p
.002 w
.43034 .53601 m .43359 .53347 L p
.4385 .54671 L 1 g
F P
s
P
p
.44866 .57408 m .43359 .53347 L .44596 .56643 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43359 .53347 m .43419 .53301 L p
.43946 .54796 L 1 g
F P
s
P
p
.44596 .56643 m .43861 .54686 L .43946 .54796 L 1 g
F
P
p
.43861 .54686 m .43359 .53347 L .43946 .54796 L 1 g
F
P
p
.002 w
.45086 .5629 m .45146 .56129 L p
.44603 .55657 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45405 .56543 m .44877 .5739 L p
.44247 .55623 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45067 .5634 L p
1 g
F P
s
P
p
.002 w
.48615 .58475 m .44866 .57408 L .45197 .56877 L p
1 g
F P
s
P
p
.002 w
.45197 .56877 m .45405 .56543 L p
.46841 .57407 L 1 g
F P
s
P
p
.48615 .58475 m .45197 .56877 L .46841 .57407 L 1 g
F
P
p
.002 w
.48905 .58073 m .48921 .57862 L p
.48023 .57788 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.49038 .58595 m .48615 .58475 L p
.48133 .57824 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46841 .57407 L p
1 g
F P
s
P
p
.48921 .57862 m .46841 .57407 L .48023 .57788 L 1 g
F
P
p
.48485 .57937 m .48133 .57824 L .46218 .5524 L 1 g
F
P
p
.49038 .58595 m .48133 .57824 L .48485 .57937 L 1 g
F
P
p
.46872 .57265 m .45067 .5634 L .46076 .56947 L 1 g
F
P
p
.002 w
.46789 .57643 m .46872 .57265 L p
.45748 .56816 L 1 g
F P
s
P
p
.002 w
.45405 .56543 m .46218 .5524 L p
.48615 .58475 L 1 g
F P
s
P
p
.002 w
.46841 .57407 m .4678 .57686 L p
.48023 .57788 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49134 .58095 m .49038 .58595 L p
.48572 .58041 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58105 L p
1 g
F P
s
P
p
.002 w
.53379 .58395 m .49038 .58595 L .49134 .58095 L p
1 g
F P
s
P
p
.53379 .58395 m .49134 .58095 L .5259 .57945 L 1 g
F
P
p
.002 w
.48903 .58105 m .48889 .583 L p
.50132 .58051 L 1 g
F P
s
P
p
.51079 .57862 m .48903 .58105 L .50132 .58051 L 1 g
F
P
p
.002 w
.5111 .58285 m .51079 .57862 L p
.4966 .58146 L 1 g
F P
s
P
p
.53128 .57265 m .5109 .5801 L .52291 .57694 L 1 g
F
P
p
.5259 .57945 m .5109 .5801 L .52196 .57719 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57463 L p
1 g
F P
s
P
p
.002 w
.53171 .57463 m .53128 .57265 L p
.52291 .57694 L 1 g
F P
s
P
p
.52291 .57694 m .51111 .583 L .53171 .57463 L 1 g
F
P
p
.002 w
.49134 .58095 m .495 .56178 L p
.52196 .57719 L 1 g
F P
s
P
p
.5109 .5801 m .49134 .58095 L .52196 .57719 L 1 g
F
P
p
.002 w
.46218 .5524 m .495 .56178 L .49134 .58095 L p
1 g
F P
s
P
p
.48572 .58041 m .46218 .5524 L .49134 .58095 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .5111 .58285 L p
1 g
F P
s
P
p
.4966 .58146 m .48889 .583 L .5111 .58285 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58073 L p
1 g
F P
s
P
p
.48023 .57788 m .4678 .57686 L .48905 .58073 L 1 g
F
P
p
.002 w
.45067 .5634 m .45002 .56518 L p
.46076 .56947 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43419 .53301 m .46218 .5524 L .45405 .56543 L p
1 g
F P
s
P
p
.44247 .55623 m .43419 .53301 L .45405 .56543 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46789 .57643 L p
1 g
F P
s
P
p
.45748 .56816 m .45002 .56518 L .46789 .57643 L 1 g
F
P
p
.44596 .56643 m .43419 .53301 L .44877 .5739 L 1 g
F
P
p
.002 w
.43861 .54686 m .43743 .5491 L p
.44603 .55657 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45086 .5629 L p
1 g
F P
s
P
p
.44603 .55657 m .43743 .5491 L .45086 .5629 L 1 g
F
P
p
.002 w
.44866 .57408 m .41302 .5495 L .43034 .53601 L p
1 g
F P
s
P
p
.4339 .53509 m .43337 .53288 L .43146 .53025 L 1 g
F
P
p
.002 w
.4324 .52889 m .43206 .52938 L p
.43337 .53288 L 1 g
F P
s
P
p
.002 w
.43206 .52938 m .43146 .53025 L p
.43337 .53288 L 1 g
F P
s
P
p
.43504 .53733 m .43337 .53288 L .4339 .53509 L 1 g
F
P
p
.002 w
.44877 .5739 m .44866 .57408 L p
.44596 .56643 L 1 g
F P
s
P
p
.002 w
.43419 .53301 m .43301 .5314 L p
.44415 .49396 L 1 g
F P
s
P
p
.43319 .51959 m .43287 .51061 L .4324 .52889 L 1 g
F
P
p
.43834 .50011 m .44191 .4925 L .43981 .49666 L 1 g
F
P
p
.002 w
.44415 .49396 m .44058 .49534 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44303 .49028 m .44318 .49079 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44318 .49079 m .44415 .49396 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44237 .49158 m .44166 .49233 L p
.43981 .49666 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44237 .49158 L p
1 g
F P
s
P
p
.002 w
.44237 .49158 m .44242 .49153 L p
.44316 .49082 L 1 g
F P
s
P
p
.44316 .49082 m .45698 .47747 L .44237 .49158 L 1 g
F
P
p
.45034 .48384 m .45654 .4779 L .44318 .49079 L 1 g
F
P
p
.002 w
.44318 .49079 m .44303 .49028 L p
.44556 .48849 L 1 g
F P
s
P
p
.45654 .4779 m .45698 .47747 L .44242 .49153 L 1 g
F
P
p
.002 w
.43733 .47151 m .44303 .49028 L p
.41407 .50559 L 1 g
F P
s
P
p
.002 w
.44303 .49028 m .44125 .48443 L p
.44745 .48152 L 1 g
F P
s
P
p
.002 w
.4774 .46743 m .47718 .46778 L p
.46921 .47128 L 1 g
F P
s
P
p
.002 w
.43733 .47151 m .47305 .46868 L p
.4711 .47039 L 1 g
F P
s
P
p
.002 w
.47305 .46868 m .47326 .46937 L p
.4711 .47039 L 1 g
F P
s
P
p
.002 w
.45705 .4774 m .4577 .47669 L p
.47099 .4705 L 1 g
F P
s
P
p
.46921 .47128 m .47099 .4705 L .4577 .47669 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45705 .4774 L p
1 g
F P
s
P
p
.47099 .4705 m .47718 .46778 L .45705 .4774 L 1 g
F
P
p
.002 w
.47326 .46937 m .47305 .46868 L .47512 .46845 L p
1 g
F P
s
P
p
.002 w
.50664 .46499 m .50987 .46463 L .50847 .46529 L p
1 g
F P
s
P
p
.002 w
.50909 .46538 m .48351 .48983 L p
.50847 .46529 L 1 g
F P
s
P
p
.51371 .46604 m .51208 .46581 L .5 .46406 L 1 g
F
P
p
.002 w
.49334 .49673 m .48351 .48983 L .50909 .46538 L p
1 g
F P
s
P
p
.002 w
.50945 .46544 m .49334 .49673 L p
.50909 .46538 L 1 g
F P
s
P
p
.002 w
.50975 .46549 m .50493 .50009 L p
.50945 .46544 L 1 g
F P
s
P
p
.51396 .46608 m .51005 .46553 L .5 .46406 L 1 g
F
P
p
.002 w
.50847 .46529 m .50987 .46463 L .50909 .46538 L p
1 g
F P
s
P
p
.50778 .46518 m .50816 .46524 L .50785 .46519 L 1 g
F
P
p
.50665 .46501 m .50785 .46519 L .50679 .46504 L 1 g
F
P
p
.002 w
.50909 .46538 m .50987 .46463 L .50945 .46544 L p
1 g
F P
s
P
p
.002 w
.50945 .46544 m .50987 .46463 L .50975 .46549 L p
1 g
F P
s
P
p
.002 w
.5 .46406 m .5 .46402 L p
.50679 .46504 L 1 g
F P
s
P
p
.51371 .46604 m .51396 .46608 L .51208 .46581 L 1 g
F
P
p
.002 w
.53762 .48748 m .52832 .4952 L .51045 .46559 L p
1 g
F P
s
P
p
.002 w
.51045 .46559 m .50987 .46463 L .51114 .46568 L p
1 g
F P
s
P
p
.002 w
.51114 .46568 m .53762 .48748 L p
.51045 .46559 L 1 g
F P
s
P
p
.002 w
.51005 .46553 m .50987 .46463 L .51045 .46559 L p
1 g
F P
s
P
p
.002 w
.51045 .46559 m .52832 .4952 L p
.51005 .46553 L 1 g
F P
s
P
p
.51396 .46608 m .51434 .46616 L .51005 .46553 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46406 L p
1 g
F P
s
P
p
.51434 .46616 m .52282 .46778 L .5 .46406 L 1 g
F
P
p
.002 w
.50975 .46549 m .50987 .46463 L .51005 .46553 L p
1 g
F P
s
P
p
.002 w
.51114 .46568 m .50987 .46463 L .51361 .46601 L p
1 g
F P
s
P
p
.002 w
.51361 .46601 m .50987 .46463 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52282 .46778 L p
.5136 .46601 L 1 g
F P
s
P
p
.53328 .47244 m .54077 .47606 L .53337 .47248 L 1 g
F
P
p
.52214 .46667 m .54077 .47606 L .53328 .47244 L 1 g
F
P
p
.002 w
.54248 .47689 m .54174 .47608 L p
.54351 .47789 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54652 .46552 m .54391 .47722 L .54077 .47606 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51754 .46482 m .54652 .46552 L p
.54077 .47606 L 1 g
F P
s
P
p
.002 w
.54248 .47689 m .54302 .47747 L p
.53337 .47248 L 1 g
F P
s
P
p
.002 w
.54253 .47694 m .54248 .47689 L p
.54351 .47789 L 1 g
F P
s
P
p
.002 w
.54216 .47657 m .54391 .47722 L .54351 .47789 L p
1 g
F P
s
P
p
.002 w
.53762 .48748 m .54391 .47722 L .57617 .48821 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54253 .47694 L p
1 g
F P
s
P
p
.55044 .4846 m .55834 .49233 L .54253 .47694 L 1 g
F
P
p
.002 w
.55736 .4913 m .55834 .49233 L p
.55044 .4846 L 1 g
F P
s
P
p
.56247 .50171 m .56485 .50655 L .5636 .50387 L 1 g
F
P
p
.002 w
.56624 .50956 m .56713 .51061 L p
.5636 .50387 L 1 g
F P
s
P
p
.002 w
.56626 .50958 m .56624 .50956 L p
.56629 .51012 L 1 g
F P
s
P
p
.002 w
.54561 .5233 m .56381 .50824 L .58748 .52618 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56626 .50958 L p
1 g
F P
s
P
p
.56677 .51877 m .56854 .53025 L .56626 .50958 L 1 g
F
P
p
.002 w
.56731 .52846 m .56854 .53025 L p
.56677 .51877 L 1 g
F P
s
P
p
.56459 .53802 m .56196 .54725 L .56394 .5416 L 1 g
F
P
p
.002 w
.56181 .54767 m .56257 .5491 L p
.56394 .5416 L 1 g
F P
s
P
p
.002 w
.56186 .54775 m .56181 .54767 L p
.56137 .54831 L 1 g
F P
s
P
p
.002 w
.56137 .54831 m .56113 .54794 L p
.56169 .54785 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56186 .54775 L p
1 g
F P
s
P
p
.002 w
.52918 .56023 m .56113 .54794 L .56137 .54831 L p
1 g
F P
s
P
p
.55654 .55389 m .52918 .56023 L .56137 .54831 L 1 g
F
P
p
.002 w
.57436 .56835 m .53379 .58395 L .53195 .57451 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54902 .56258 L p
1 g
F P
s
P
p
.54216 .56737 m .5322 .57686 L .54902 .56258 L 1 g
F
P
p
.002 w
.54902 .56258 m .54998 .56518 L p
.55563 .55494 L 1 g
F P
s
P
p
.54216 .56737 m .53195 .57451 L .53809 .57125 L 1 g
F
P
p
.002 w
.53195 .57451 m .52918 .56023 L p
.54763 .56355 L 1 g
F P
s
P
p
.002 w
.495 .56178 m .52918 .56023 L .53196 .57457 L p
1 g
F P
s
P
p
.52196 .57719 m .495 .56178 L .53196 .57457 L 1 g
F
P
p
.002 w
.53171 .57463 m .5322 .57686 L p
.53809 .57125 L 1 g
F P
s
P
p
.002 w
.5109 .5801 m .51111 .583 L p
.52291 .57694 L 1 g
F P
s
P
p
.002 w
.37594 .42959 m .37442 .47323 L .34939 .47214 L p
1 g
F P
s
P
p
.002 w
.34939 .47214 m .35105 .42063 L .37594 .42959 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.63077 .50396 m .60787 .54074 L .58748 .52618 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.63599 .41871 m .61742 .37935 L .63598 .36138 L p
1 g
F P
s
P
p
.002 w
.59977 .32438 m .63598 .36138 L .61742 .37935 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.58748 .52618 m .60545 .49721 L .63077 .50396 L p
1 g
F P
s
P
p
.002 w
.64055 .4618 m .63077 .50396 L .60545 .49721 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39189 .38855 m .37594 .42959 L .35105 .42063 L p
1 g
F P
s
P
p
.002 w
.35105 .42063 m .36977 .37213 L .39189 .38855 L p
1 g
F P
s
P
p
.002 w
.41302 .5495 m .38731 .51468 L .41407 .50559 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61742 .37935 m .58666 .34809 L .59977 .32438 L p
1 g
F P
s
P
p
.002 w
.55297 .30116 m .59977 .32438 L .58666 .34809 L p
1 g
F P
s
P
p
.002 w
.60545 .49721 m .61305 .46405 L .64055 .4618 L p
1 g
F P
s
P
p
.002 w
.63599 .41871 m .64055 .4618 L .61305 .46405 L p
1 g
F P
s
P
p
.002 w
.42064 .35473 m .39189 .38855 L .36977 .37213 L p
1 g
F P
s
P
p
.002 w
.36977 .37213 m .40367 .33211 L .42064 .35473 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40405 .47303 m .41407 .50559 L .38731 .51468 L p
1 g
F P
s
P
p
.002 w
.38731 .51468 m .37442 .47323 L .40405 .47303 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58666 .34809 m .54701 .3285 L .55297 .30116 L p
1 g
F P
s
P
p
.002 w
.50076 .29447 m .55297 .30116 L .54701 .3285 L p
1 g
F P
s
P
p
.002 w
.45904 .33197 m .42064 .35473 L .40367 .33211 L p
1 g
F P
s
P
p
.002 w
.40367 .33211 m .44903 .30518 L .45904 .33197 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.61305 .46405 m .60937 .43023 L .63599 .41871 L p
1 g
F P
s
P
p
.002 w
.61742 .37935 m .63599 .41871 L .60937 .43023 L p
1 g
F P
s
P
p
.002 w
.44903 .30518 m .50076 .29447 L .50282 .32289 L p
1 g
F P
s
P
p
.002 w
.54701 .3285 m .50282 .32289 L .50076 .29447 L p
1 g
F P
s
P
p
.002 w
.50282 .32289 m .45904 .33197 L .44903 .30518 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.49991 .53286 m .52353 .5318 L .52918 .56023 L p
1 g
F P
s
P
p
.002 w
.52918 .56023 m .495 .56178 L .49991 .53286 L p
1 g
F P
s
P
p
.002 w
.56113 .54794 m .52918 .56023 L .52353 .5318 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.40535 .43882 m .40405 .47303 L .37442 .47323 L p
1 g
F P
s
P
p
.002 w
.37442 .47323 m .37594 .42959 L .40535 .43882 L p
1 g
F P
s
P
p
.002 w
.52353 .5318 m .54561 .5233 L .56113 .54794 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.47724 .52634 m .49991 .53286 L .495 .56178 L p
1 g
F P
s
P
p
.002 w
.495 .56178 m .46218 .5524 L .47724 .52634 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.60937 .43023 m .5947 .3994 L .61742 .37935 L p
1 g
F P
s
P
p
.002 w
.58666 .34809 m .61742 .37935 L .5947 .3994 L p
1 g
F P
s
P
p
.002 w
.45796 .5129 m .47724 .52634 L .46218 .5524 L p
1 g
F P
s
P
p
.002 w
.46218 .5524 m .43419 .53301 L .45796 .5129 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.61305 .46405 m .60545 .49721 L .57617 .48821 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.41793 .4067 m .40535 .43882 L .37594 .42959 L p
1 g
F P
s
P
p
.002 w
.37594 .42959 m .39189 .38855 L .41793 .4067 L p
1 g
F P
s
P
p
.002 w
.44415 .49396 m .45796 .5129 L .43419 .53301 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5947 .3994 m .57053 .37496 L .58666 .34809 L p
1 g
F P
s
P
p
.002 w
.54701 .3285 m .58666 .34809 L .57053 .37496 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.57617 .48821 m .58134 .46532 L .61305 .46405 L p
1 g
F P
s
P
p
.002 w
.60937 .43023 m .61305 .46405 L .58134 .46532 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44049 .38025 m .41793 .4067 L .39189 .38855 L p
1 g
F P
s
P
p
.002 w
.39189 .38855 m .42064 .35473 L .44049 .38025 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.41407 .50559 m .40405 .47303 L .43733 .47151 L p
1 g
F P
s
P
p
.002 w
.57053 .37496 m .53944 .35969 L .54701 .3285 L p
1 g
F P
s
P
p
.002 w
.50282 .32289 m .54701 .3285 L .53944 .35969 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.47057 .36246 m .44049 .38025 L .42064 .35473 L p
1 g
F P
s
P
p
.002 w
.42064 .35473 m .45904 .33197 L .47057 .36246 L p
1 g
F P
s
P
p
.002 w
.58134 .46532 m .57873 .44202 L .60937 .43023 L p
1 g
F P
s
P
p
.002 w
.5947 .3994 m .60937 .43023 L .57873 .44202 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45904 .33197 m .50282 .32289 L .50483 .35535 L p
1 g
F P
s
P
p
.002 w
.53944 .35969 m .50483 .35535 L .50282 .32289 L p
1 g
F P
s
P
p
.002 w
.50483 .35535 m .47057 .36246 L .45904 .33197 L p
1 g
F P
s
P
p
.002 w
.4383 .44797 m .43733 .47151 L .40405 .47303 L p
1 g
F P
s
P
p
.002 w
.40405 .47303 m .40535 .43882 L .4383 .44797 L p
1 g
F P
s
P
p
.002 w
.50493 .50009 m .51702 .49956 L .52353 .5318 L p
1 g
F P
s
P
p
.002 w
.52353 .5318 m .49991 .53286 L .50493 .50009 L p
1 g
F P
s
P
p
.002 w
.54561 .5233 m .52353 .5318 L .51702 .49956 L p
1 g
F P
s
P
p
.002 w
.51702 .49956 m .52832 .4952 L .54561 .5233 L p
1 g
F P
s
P
p
.002 w
.56381 .50824 m .54561 .5233 L .52832 .4952 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49334 .49673 m .50493 .50009 L .49991 .53286 L p
1 g
F P
s
P
p
.002 w
.49991 .53286 m .47724 .52634 L .49334 .49673 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.52832 .4952 m .53762 .48748 L .56381 .50824 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57873 .44202 m .56856 .42084 L .5947 .3994 L p
1 g
F P
s
P
p
.002 w
.57053 .37496 m .5947 .3994 L .56856 .42084 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.48351 .48983 m .49334 .49673 L .47724 .52634 L p
1 g
F P
s
P
p
.002 w
.47724 .52634 m .45796 .5129 L .48351 .48983 L p
1 g
F P
s
P
p
.002 w
.58134 .46532 m .57617 .48821 L .54391 .47722 L p
1 g
F P
s
P
p
.002 w
.44701 .42592 m .4383 .44797 L .40535 .43882 L p
1 g
F P
s
P
p
.002 w
.40535 .43882 m .41793 .4067 L .44701 .42592 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.47649 .48014 m .48351 .48983 L .45796 .5129 L p
1 g
F P
s
P
p
.002 w
.45796 .5129 m .44415 .49396 L .47649 .48014 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56856 .42084 m .55189 .40409 L .57053 .37496 L p
1 g
F P
s
P
p
.002 w
.53944 .35969 m .57053 .37496 L .55189 .40409 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54391 .47722 m .54652 .46552 L .58134 .46532 L p
1 g
F P
s
P
p
.002 w
.57873 .44202 m .58134 .46532 L .54652 .46552 L p
1 g
F P
s
P
p
.002 w
.46254 .40778 m .44701 .42592 L .41793 .4067 L p
1 g
F P
s
P
p
.002 w
.41793 .4067 m .44049 .38025 L .46254 .40778 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55189 .40409 m .5305 .39365 L .53944 .35969 L p
1 g
F P
s
P
p
.002 w
.50483 .35535 m .53944 .35969 L .5305 .39365 L p
1 g
F P
s
P
p
.002 w
.54652 .46552 m .54515 .45364 L .57873 .44202 L p
1 g
F P
s
P
p
.002 w
.56856 .42084 m .57873 .44202 L .54515 .45364 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.48321 .39559 m .46254 .40778 L .44049 .38025 L p
1 g
F P
s
P
p
.002 w
.44049 .38025 m .47057 .36246 L .48321 .39559 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47057 .36246 m .50483 .35535 L .50673 .3907 L p
1 g
F P
s
P
p
.002 w
.5305 .39365 m .50673 .3907 L .50483 .35535 L p
1 g
F P
s
P
p
.002 w
.47359 .45669 m .47305 .46868 L .43733 .47151 L p
1 g
F P
s
P
p
.002 w
.43733 .47151 m .4383 .44797 L .47359 .45669 L p
1 g
F P
s
P
p
.002 w
.50673 .3907 m .48321 .39559 L .47057 .36246 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54515 .45364 m .53992 .44287 L .56856 .42084 L p
1 g
F P
s
P
p
.002 w
.55189 .40409 m .56856 .42084 L .53992 .44287 L p
1 g
F P
s
P
p
.002 w
.47806 .44549 m .47359 .45669 L .4383 .44797 L p
1 g
F P
s
P
p
.002 w
.4383 .44797 m .44701 .42592 L .47806 .44549 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.53992 .44287 m .53141 .43437 L .55189 .40409 L p
1 g
F P
s
P
p
.002 w
.5305 .39365 m .55189 .40409 L .53141 .43437 L p
1 g
F P
s
P
p
.002 w
.54515 .45364 m .54652 .46552 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48597 .43629 m .47806 .44549 L .44701 .42592 L p
1 g
F P
s
P
p
.002 w
.44701 .42592 m .46254 .40778 L .48597 .43629 L p
1 g
F P
s
P
p
.002 w
.53992 .44287 m .54515 .45364 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.53141 .43437 m .52051 .42909 L .5305 .39365 L p
1 g
F P
s
P
p
.002 w
.50673 .3907 m .5305 .39365 L .52051 .42909 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49648 .4301 m .48597 .43629 L .46254 .40778 L p
1 g
F P
s
P
p
.002 w
.46254 .40778 m .48321 .39559 L .49648 .4301 L p
1 g
F P
s
P
p
.002 w
.53141 .43437 m .53992 .44287 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.48321 .39559 m .50673 .3907 L .50843 .42761 L p
1 g
F P
s
P
p
.002 w
.52051 .42909 m .50843 .42761 L .50673 .3907 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.50843 .42761 m .49648 .4301 L .48321 .39559 L p
1 g
F P
s
P
p
.002 w
.47359 .45669 m .47806 .44549 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.49648 .4301 m .50843 .42761 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.48597 .43629 m .49648 .4301 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.47806 .44549 m .48597 .43629 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.52051 .42909 m .53141 .43437 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.50843 .42761 m .52051 .42909 L .50987 .46463 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.50987 .46463 m
.516 .48582 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .61871 .2118 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .516 .48582 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.493798)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.493798)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50107 .47147 m .52368 .45644 L .50442 .43552 L p
1 g
F P
s
P
p
.002 w
.50442 .43552 m .48903 .44574 L .50107 .47147 L p
1 g
F P
s
P
p
.002 w
.51588 .42103 m .50442 .43552 L .52368 .45644 L p
1 g
F P
s
P
p
.002 w
.48903 .44574 m .50442 .43552 L .48509 .41451 L p
1 g
F P
s
P
p
.002 w
.50442 .43552 m .51588 .42103 L .49089 .40715 L p
1 g
F P
s
P
p
.002 w
.49089 .40715 m .48509 .41451 L .50442 .43552 L p
1 g
F P
s
P
p
.002 w
.52368 .45644 m .54053 .43516 L .51588 .42103 L p
1 g
F P
s
P
p
.002 w
.52217 .40376 m .51588 .42103 L .54053 .43516 L p
1 g
F P
s
P
p
.002 w
.51588 .42103 m .52217 .40376 L .49406 .39839 L p
1 g
F P
s
P
p
.002 w
.49406 .39839 m .49089 .40715 L .51588 .42103 L p
1 g
F P
s
P
p
.002 w
.47503 .47866 m .50107 .47147 L .48903 .44574 L p
1 g
F P
s
P
p
.002 w
.48903 .44574 m .4713 .45058 L .47503 .47866 L p
1 g
F P
s
P
p
.002 w
.4713 .45058 m .48903 .44574 L .47727 .41969 L p
1 g
F P
s
P
p
.002 w
.48509 .41451 m .47727 .41969 L .48903 .44574 L p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .47727 .41969 L .48509 .41451 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .48509 .41451 L .49089 .40715 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .49089 .40715 L .49406 .39839 L closepath p
1 g
F P
s
P
p
.002 w
.47727 .41969 m .46828 .42212 L .4713 .45058 L p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .46828 .42212 L .47727 .41969 L closepath p
1 g
F P
s
P
p
.002 w
.49425 .38916 m .49406 .39839 L .52217 .40376 L p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .49406 .39839 L .49425 .38916 L closepath p
1 g
F P
s
P
p
.002 w
.45311 .44952 m .4713 .45058 L .46828 .42212 L p
1 g
F P
s
P
p
.002 w
.46828 .42212 m .45907 .42155 L .45311 .44952 L p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .45907 .42155 L .46828 .42212 L closepath p
1 g
F P
s
P
p
.002 w
.54053 .43516 m .54985 .4098 L .52217 .40376 L p
1 g
F P
s
P
p
.002 w
.52263 .38554 m .52217 .40376 L .54985 .4098 L p
1 g
F P
s
P
p
.002 w
.52217 .40376 m .52263 .38554 L .49425 .38916 L p
1 g
F P
s
P
p
.002 w
.44825 .47721 m .47503 .47866 L .4713 .45058 L p
1 g
F P
s
P
p
.002 w
.4713 .45058 m .45311 .44952 L .44825 .47721 L p
1 g
F P
s
P
p
.002 w
.51319 .49643 m .54251 .4769 L .52368 .45644 L p
1 g
F P
s
P
p
.002 w
.52368 .45644 m .50107 .47147 L .51319 .49643 L p
1 g
F P
s
P
p
.002 w
.54053 .43516 m .52368 .45644 L .54251 .4769 L p
1 g
F P
s
P
p
.002 w
.54251 .4769 m .5644 .44929 L .54053 .43516 L p
1 g
F P
s
P
p
.002 w
.54985 .4098 m .54053 .43516 L .5644 .44929 L p
1 g
F P
s
P
p
.002 w
.47941 .50585 m .51319 .49643 L .50107 .47147 L p
1 g
F P
s
P
p
.002 w
.50107 .47147 m .47503 .47866 L .47941 .50585 L p
1 g
F P
s
P
p
.002 w
.49143 .38045 m .49425 .38916 L .52263 .38554 L p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .49425 .38916 L .49143 .38045 L closepath p
1 g
F P
s
P
p
.002 w
.43638 .44263 m .45311 .44952 L .45907 .42155 L p
1 g
F P
s
P
p
.002 w
.45907 .42155 m .45062 .41801 L .43638 .44263 L p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .45062 .41801 L .45907 .42155 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .47822 .36822 L .46924 .36605 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .46924 .36605 L .45993 .36693 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .45993 .36693 L .45131 .3708 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .45131 .3708 L .44434 .37722 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .44434 .37722 L .43977 .38549 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .43977 .38549 L .43811 .3947 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .43811 .3947 L .43953 .40383 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .43953 .40383 L .44386 .41189 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .44386 .41189 L .45062 .41801 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .49143 .38045 L .4859 .37321 L closepath p
1 g
F P
s
P
p
.002 w
.46602 .39379 m .4859 .37321 L .47822 .36822 L closepath p
1 g
F P
s
P
p
.002 w
.54985 .4098 m .55063 .38298 L .52263 .38554 L p
1 g
F P
s
P
p
.002 w
.51715 .36829 m .52263 .38554 L .55063 .38298 L p
1 g
F P
s
P
p
.002 w
.52263 .38554 m .51715 .36829 L .49143 .38045 L p
1 g
F P
s
P
p
.002 w
.42355 .46718 m .44825 .47721 L .45311 .44952 L p
1 g
F P
s
P
p
.002 w
.45311 .44952 m .43638 .44263 L .42355 .46718 L p
1 g
F P
s
P
p
.002 w
.4859 .37321 m .49143 .38045 L .51715 .36829 L p
1 g
F P
s
P
p
.002 w
.42292 .43058 m .43638 .44263 L .45062 .41801 L p
1 g
F P
s
P
p
.002 w
.45062 .41801 m .44386 .41189 L .42292 .43058 L p
1 g
F P
s
P
p
.002 w
.5644 .44929 m .57659 .4164 L .54985 .4098 L p
1 g
F P
s
P
p
.002 w
.55063 .38298 m .54985 .4098 L .57659 .4164 L p
1 g
F P
s
P
p
.002 w
.4446 .5041 m .47941 .50585 L .47503 .47866 L p
1 g
F P
s
P
p
.002 w
.47503 .47866 m .44825 .47721 L .4446 .5041 L p
1 g
F P
s
P
p
.002 w
.51715 .36829 m .50626 .35388 L .4859 .37321 L p
1 g
F P
s
P
p
.002 w
.47822 .36822 m .4859 .37321 L .50626 .35388 L p
1 g
F P
s
P
p
.002 w
.41424 .41463 m .42292 .43058 L .44386 .41189 L p
1 g
F P
s
P
p
.002 w
.44386 .41189 m .43953 .40383 L .41424 .41463 L p
1 g
F P
s
P
p
.002 w
.52516 .52012 m .56057 .4965 L .54251 .4769 L p
1 g
F P
s
P
p
.002 w
.54251 .4769 m .51319 .49643 L .52516 .52012 L p
1 g
F P
s
P
p
.002 w
.5644 .44929 m .54251 .4769 L .56057 .4965 L p
1 g
F P
s
P
p
.002 w
.55063 .38298 m .54268 .35753 L .51715 .36829 L p
1 g
F P
s
P
p
.002 w
.50626 .35388 m .51715 .36829 L .54268 .35753 L p
1 g
F P
s
P
p
.002 w
.4036 .44951 m .42355 .46718 L .43638 .44263 L p
1 g
F P
s
P
p
.002 w
.43638 .44263 m .42292 .43058 L .4036 .44951 L p
1 g
F P
s
P
p
.002 w
.46924 .36605 m .47822 .36822 L .49109 .34391 L p
1 g
F P
s
P
p
.002 w
.50626 .35388 m .49109 .34391 L .47822 .36822 L p
1 g
F P
s
P
p
.002 w
.41134 .3965 m .41424 .41463 L .43953 .40383 L p
1 g
F P
s
P
p
.002 w
.43953 .40383 m .43811 .3947 L .41134 .3965 L p
1 g
F P
s
P
p
.002 w
.56057 .4965 m .58704 .46317 L .5644 .44929 L p
1 g
F P
s
P
p
.002 w
.57659 .4164 m .5644 .44929 L .58704 .46317 L p
1 g
F P
s
P
p
.002 w
.48436 .53161 m .52516 .52012 L .51319 .49643 L p
1 g
F P
s
P
p
.002 w
.51319 .49643 m .47941 .50585 L .48436 .53161 L p
1 g
F P
s
P
p
.002 w
.57659 .4164 m .57774 .38157 L .55063 .38298 L p
1 g
F P
s
P
p
.002 w
.54268 .35753 m .55063 .38298 L .57774 .38157 L p
1 g
F P
s
P
p
.002 w
.41241 .4912 m .4446 .5041 L .44825 .47721 L p
1 g
F P
s
P
p
.002 w
.44825 .47721 m .42355 .46718 L .41241 .4912 L p
1 g
F P
s
P
p
.002 w
.49109 .34391 m .47327 .33951 L .46924 .36605 L p
1 g
F P
s
P
p
.002 w
.45993 .36693 m .46924 .36605 L .47327 .33951 L p
1 g
F P
s
P
p
.002 w
.41458 .37817 m .41134 .3965 L .43811 .3947 L p
1 g
F P
s
P
p
.002 w
.43811 .3947 m .43977 .38549 L .41458 .37817 L p
1 g
F P
s
P
p
.002 w
.47327 .33951 m .45474 .34122 L .45993 .36693 L p
1 g
F P
s
P
p
.002 w
.45131 .3708 m .45993 .36693 L .45474 .34122 L p
1 g
F P
s
P
p
.002 w
.42365 .36168 m .41458 .37817 L .43977 .38549 L p
1 g
F P
s
P
p
.002 w
.43977 .38549 m .44434 .37722 L .42365 .36168 L p
1 g
F P
s
P
p
.002 w
.54268 .35753 m .52673 .33619 L .50626 .35388 L p
1 g
F P
s
P
p
.002 w
.49109 .34391 m .50626 .35388 L .52673 .33619 L p
1 g
F P
s
P
p
.002 w
.45474 .34122 m .43756 .34889 L .45131 .3708 L p
1 g
F P
s
P
p
.002 w
.44434 .37722 m .45131 .3708 L .43756 .34889 L p
1 g
F P
s
P
p
.002 w
.43756 .34889 m .42365 .36168 L .44434 .37722 L p
1 g
F P
s
P
p
.002 w
.39066 .426 m .4036 .44951 L .42292 .43058 L p
1 g
F P
s
P
p
.002 w
.42292 .43058 m .41424 .41463 L .39066 .426 L p
1 g
F P
s
P
p
.002 w
.58704 .46317 m .60187 .42345 L .57659 .4164 L p
1 g
F P
s
P
p
.002 w
.57774 .38157 m .57659 .4164 L .60187 .42345 L p
1 g
F P
s
P
p
.002 w
.44226 .52966 m .48436 .53161 L .47941 .50585 L p
1 g
F P
s
P
p
.002 w
.47941 .50585 m .4446 .5041 L .44226 .52966 L p
1 g
F P
s
P
p
.002 w
.57774 .38157 m .56755 .34841 L .54268 .35753 L p
1 g
F P
s
P
p
.002 w
.52673 .33619 m .54268 .35753 L .56755 .34841 L p
1 g
F P
s
P
p
.002 w
.38632 .46832 m .41241 .4912 L .42355 .46718 L p
1 g
F P
s
P
p
.002 w
.42355 .46718 m .4036 .44951 L .38632 .46832 L p
1 g
F P
s
P
p
.002 w
.47327 .33951 m .49109 .34391 L .50439 .32133 L p
1 g
F P
s
P
p
.002 w
.52673 .33619 m .50439 .32133 L .49109 .34391 L p
1 g
F P
s
P
p
.002 w
.38625 .39918 m .39066 .426 L .41424 .41463 L p
1 g
F P
s
P
p
.002 w
.41424 .41463 m .41134 .3965 L .38625 .39918 L p
1 g
F P
s
P
p
.002 w
.53676 .54208 m .57749 .51486 L .56057 .4965 L p
1 g
F P
s
P
p
.002 w
.56057 .4965 m .52516 .52012 L .53676 .54208 L p
1 g
F P
s
P
p
.002 w
.58704 .46317 m .56057 .4965 L .57749 .51486 L p
1 g
F P
s
P
p
.002 w
.60187 .42345 m .60341 .38133 L .57774 .38157 L p
1 g
F P
s
P
p
.002 w
.56755 .34841 m .57774 .38157 L .60341 .38133 L p
1 g
F P
s
P
p
.002 w
.40323 .51422 m .44226 .52966 L .4446 .5041 L p
1 g
F P
s
P
p
.002 w
.4446 .5041 m .41241 .4912 L .40323 .51422 L p
1 g
F P
s
P
p
.002 w
.57749 .51486 m .60798 .47652 L .58704 .46317 L p
1 g
F P
s
P
p
.002 w
.60187 .42345 m .58704 .46317 L .60798 .47652 L p
1 g
F P
s
P
p
.002 w
.48981 .55542 m .53676 .54208 L .52516 .52012 L p
1 g
F P
s
P
p
.002 w
.52516 .52012 m .48436 .53161 L .48981 .55542 L p
1 g
F P
s
P
p
.002 w
.50439 .32133 m .47803 .31471 L .47327 .33951 L p
1 g
F P
s
P
p
.002 w
.45474 .34122 m .47327 .33951 L .47803 .31471 L p
1 g
F P
s
P
p
.002 w
.39098 .37199 m .38625 .39918 L .41134 .3965 L p
1 g
F P
s
P
p
.002 w
.41134 .3965 m .41458 .37817 L .39098 .37199 L p
1 g
F P
s
P
p
.002 w
.56755 .34841 m .54692 .32051 L .52673 .33619 L p
1 g
F P
s
P
p
.002 w
.50439 .32133 m .52673 .33619 L .54692 .32051 L p
1 g
F P
s
P
p
.002 w
.36929 .43774 m .38632 .46832 L .4036 .44951 L p
1 g
F P
s
P
p
.002 w
.4036 .44951 m .39066 .426 L .36929 .43774 L p
1 g
F P
s
P
p
.002 w
.47803 .31471 m .45055 .31717 L .45474 .34122 L p
1 g
F P
s
P
p
.002 w
.43756 .34889 m .45474 .34122 L .45055 .31717 L p
1 g
F P
s
P
p
.002 w
.4044 .3475 m .39098 .37199 L .41458 .37817 L p
1 g
F P
s
P
p
.002 w
.41458 .37817 m .42365 .36168 L .4044 .3475 L p
1 g
F P
s
P
p
.002 w
.60798 .47652 m .62516 .43084 L .60187 .42345 L p
1 g
F P
s
P
p
.002 w
.60341 .38133 m .60187 .42345 L .62516 .43084 L p
1 g
F P
s
P
p
.002 w
.44132 .55333 m .48981 .55542 L .48436 .53161 L p
1 g
F P
s
P
p
.002 w
.48436 .53161 m .44226 .52966 L .44132 .55333 L p
1 g
F P
s
P
p
.002 w
.45055 .31717 m .42504 .32851 L .43756 .34889 L p
1 g
F P
s
P
p
.002 w
.42365 .36168 m .43756 .34889 L .42504 .32851 L p
1 g
F P
s
P
p
.002 w
.42504 .32851 m .4044 .3475 L .42365 .36168 L p
1 g
F P
s
P
p
.002 w
.60341 .38133 m .59127 .34115 L .56755 .34841 L p
1 g
F P
s
P
p
.002 w
.54692 .32051 m .56755 .34841 L .59127 .34115 L p
1 g
F P
s
P
p
.002 w
.37147 .48663 m .40323 .51422 L .41241 .4912 L p
1 g
F P
s
P
p
.002 w
.41241 .4912 m .38632 .46832 L .37147 .48663 L p
1 g
F P
s
P
p
.002 w
.47803 .31471 m .50439 .32133 L .51788 .30099 L p
1 g
F P
s
P
p
.002 w
.54692 .32051 m .51788 .30099 L .50439 .32133 L p
1 g
F P
s
P
p
.002 w
.36339 .40272 m .36929 .43774 L .39066 .426 L p
1 g
F P
s
P
p
.002 w
.39066 .426 m .38625 .39918 L .36339 .40272 L p
1 g
F P
s
P
p
.002 w
.62516 .43084 m .6271 .38233 L .60341 .38133 L p
1 g
F P
s
P
p
.002 w
.59127 .34115 m .60341 .38133 L .6271 .38233 L p
1 g
F P
s
P
p
.002 w
.54773 .56181 m .59289 .53158 L .57749 .51486 L p
1 g
F P
s
P
p
.002 w
.57749 .51486 m .53676 .54208 L .54773 .56181 L p
1 g
F P
s
P
p
.002 w
.60798 .47652 m .57749 .51486 L .59289 .53158 L p
1 g
F P
s
P
p
.002 w
.39625 .53572 m .44132 .55333 L .44226 .52966 L p
1 g
F P
s
P
p
.002 w
.44226 .52966 m .40323 .51422 L .39625 .53572 L p
1 g
F P
s
P
p
.002 w
.59289 .53158 m .62675 .48906 L .60798 .47652 L p
1 g
F P
s
P
p
.002 w
.62516 .43084 m .60798 .47652 L .62675 .48906 L p
1 g
F P
s
P
p
.002 w
.49567 .57671 m .54773 .56181 L .53676 .54208 L p
1 g
F P
s
P
p
.002 w
.53676 .54208 m .48981 .55542 L .49567 .57671 L p
1 g
F P
s
P
p
.002 w
.51788 .30099 m .48347 .29221 L .47803 .31471 L p
1 g
F P
s
P
p
.002 w
.45055 .31717 m .47803 .31471 L .48347 .29221 L p
1 g
F P
s
P
p
.002 w
.36948 .36713 m .36339 .40272 L .38625 .39918 L p
1 g
F P
s
P
p
.002 w
.38625 .39918 m .39098 .37199 L .36948 .36713 L p
1 g
F P
s
P
p
.002 w
.59127 .34115 m .56642 .30721 L .54692 .32051 L p
1 g
F P
s
P
p
.002 w
.51788 .30099 m .54692 .32051 L .56642 .30721 L p
1 g
F P
s
P
p
.002 w
.35065 .44962 m .37147 .48663 L .38632 .46832 L p
1 g
F P
s
P
p
.002 w
.38632 .46832 m .36929 .43774 L .35065 .44962 L p
1 g
F P
s
P
p
.002 w
.48347 .29221 m .44751 .29533 L .45055 .31717 L p
1 g
F P
s
P
p
.002 w
.42504 .32851 m .45055 .31717 L .44751 .29533 L p
1 g
F P
s
P
p
.002 w
.38703 .33503 m .36948 .36713 L .39098 .37199 L p
1 g
F P
s
P
p
.002 w
.39098 .37199 m .4044 .3475 L .38703 .33503 L p
1 g
F P
s
P
p
.002 w
.62675 .48906 m .64591 .43841 L .62516 .43084 L p
1 g
F P
s
P
p
.002 w
.6271 .38233 m .62516 .43084 L .64591 .43841 L p
1 g
F P
s
P
p
.002 w
.44184 .57456 m .49567 .57671 L .48981 .55542 L p
1 g
F P
s
P
p
.002 w
.48981 .55542 m .44132 .55333 L .44184 .57456 L p
1 g
F P
s
P
p
.002 w
.44751 .29533 m .41407 .31014 L .42504 .32851 L p
1 g
F P
s
P
p
.002 w
.4044 .3475 m .42504 .32851 L .41407 .31014 L p
1 g
F P
s
P
p
.002 w
.41407 .31014 m .38703 .33503 L .4044 .3475 L p
1 g
F P
s
P
p
.002 w
.6271 .38233 m .61329 .33596 L .59127 .34115 L p
1 g
F P
s
P
p
.002 w
.56642 .30721 m .59127 .34115 L .61329 .33596 L p
1 g
F P
s
P
p
.002 w
.35948 .50405 m .39625 .53572 L .40323 .51422 L p
1 g
F P
s
P
p
.002 w
.40323 .51422 m .37147 .48663 L .35948 .50405 L p
1 g
F P
s
P
p
.002 w
.48347 .29221 m .51788 .30099 L .53127 .28339 L p
1 g
F P
s
P
p
.002 w
.56642 .30721 m .53127 .28339 L .51788 .30099 L p
1 g
F P
s
P
p
.002 w
.34334 .40707 m .35065 .44962 L .36929 .43774 L p
1 g
F P
s
P
p
.002 w
.36929 .43774 m .36339 .40272 L .34334 .40707 L p
1 g
F P
s
P
p
.002 w
.64591 .43841 m .64823 .38459 L .6271 .38233 L p
1 g
F P
s
P
p
.002 w
.61329 .33596 m .6271 .38233 L .64823 .38459 L p
1 g
F P
s
P
p
.002 w
.39173 .55519 m .44184 .57456 L .44132 .55333 L p
1 g
F P
s
P
p
.002 w
.44132 .55333 m .39625 .53572 L .39173 .55519 L p
1 g
F P
s
P
p
.002 w
.55782 .57879 m .6064 .54622 L .59289 .53158 L p
1 g
F P
s
P
p
.002 w
.59289 .53158 m .54773 .56181 L .55782 .57879 L p
1 g
F P
s
P
p
.002 w
.62675 .48906 m .59289 .53158 L .6064 .54622 L p
1 g
F P
s
P
p
.002 w
.53127 .28339 m .4895 .27256 L .48347 .29221 L p
1 g
F P
s
P
p
.002 w
.44751 .29533 m .48347 .29221 L .4895 .27256 L p
1 g
F P
s
P
p
.002 w
.35066 .36373 m .34334 .40707 L .36339 .40272 L p
1 g
F P
s
P
p
.002 w
.36339 .40272 m .36948 .36713 L .35066 .36373 L p
1 g
F P
s
P
p
.002 w
.6064 .54622 m .64286 .5005 L .62675 .48906 L p
1 g
F P
s
P
p
.002 w
.64591 .43841 m .62675 .48906 L .64286 .5005 L p
1 g
F P
s
P
p
.002 w
.50183 .59492 m .55782 .57879 L .54773 .56181 L p
1 g
F P
s
P
p
.002 w
.54773 .56181 m .49567 .57671 L .50183 .59492 L p
1 g
F P
s
P
p
.002 w
.61329 .33596 m .58479 .29669 L .56642 .30721 L p
1 g
F P
s
P
p
.002 w
.53127 .28339 m .56642 .30721 L .58479 .29669 L p
1 g
F P
s
P
p
.002 w
.33527 .46138 m .35948 .50405 L .37147 .48663 L p
1 g
F P
s
P
p
.002 w
.37147 .48663 m .35065 .44962 L .33527 .46138 L p
1 g
F P
s
P
p
.002 w
.4895 .27256 m .44571 .27626 L .44751 .29533 L p
1 g
F P
s
P
p
.002 w
.41407 .31014 m .44751 .29533 L .44571 .27626 L p
1 g
F P
s
P
p
.002 w
.37199 .3246 m .35066 .36373 L .36948 .36713 L p
1 g
F P
s
P
p
.002 w
.36948 .36713 m .38703 .33503 L .37199 .3246 L p
1 g
F P
s
P
p
.002 w
.64286 .5005 m .66358 .44603 L .64591 .43841 L p
1 g
F P
s
P
p
.002 w
.64823 .38459 m .64591 .43841 L .66358 .44603 L p
1 g
F P
s
P
p
.002 w
.44389 .59276 m .50183 .59492 L .49567 .57671 L p
1 g
F P
s
P
p
.002 w
.49567 .57671 m .44184 .57456 L .44389 .59276 L p
1 g
F P
s
P
p
.002 w
.64823 .38459 m .63308 .33304 L .61329 .33596 L p
1 g
F P
s
P
p
.002 w
.58479 .29669 m .61329 .33596 L .63308 .33304 L p
1 g
F P
s
P
p
.002 w
.35075 .52014 m .39173 .55519 L .39625 .53572 L p
1 g
F P
s
P
p
.002 w
.39625 .53572 m .35948 .50405 L .35075 .52014 L p
1 g
F P
s
P
p
.002 w
.44571 .27626 m .40495 .29426 L .41407 .31014 L p
1 g
F P
s
P
p
.002 w
.38703 .33503 m .41407 .31014 L .40495 .29426 L p
1 g
F P
s
P
p
.002 w
.40495 .29426 m .37199 .3246 L .38703 .33503 L p
1 g
F P
s
P
p
.002 w
.4895 .27256 m .53127 .28339 L .5443 .26901 L p
1 g
F P
s
P
p
.002 w
.58479 .29669 m .5443 .26901 L .53127 .28339 L p
1 g
F P
s
P
p
.002 w
.32667 .41219 m .33527 .46138 L .35065 .44962 L p
1 g
F P
s
P
p
.002 w
.35065 .44962 m .34334 .40707 L .32667 .41219 L p
1 g
F P
s
P
p
.002 w
.66358 .44603 m .66622 .38811 L .64823 .38459 L p
1 g
F P
s
P
p
.002 w
.63308 .33304 m .64823 .38459 L .66622 .38811 L p
1 g
F P
s
P
p
.002 w
.38989 .57207 m .44389 .59276 L .44184 .57456 L p
1 g
F P
s
P
p
.002 w
.44184 .57456 m .39173 .55519 L .38989 .57207 L p
1 g
F P
s
P
p
.002 w
.56676 .59251 m .61761 .55838 L .6064 .54622 L p
1 g
F P
s
P
p
.002 w
.6064 .54622 m .55782 .57879 L .56676 .59251 L p
1 g
F P
s
P
p
.002 w
.64286 .5005 m .6064 .54622 L .61761 .55838 L p
1 g
F P
s
P
p
.002 w
.5443 .26901 m .49601 .25636 L .4895 .27256 L p
1 g
F P
s
P
p
.002 w
.44571 .27626 m .4895 .27256 L .49601 .25636 L p
1 g
F P
s
P
p
.002 w
.33506 .36197 m .32667 .41219 L .34334 .40707 L p
1 g
F P
s
P
p
.002 w
.34334 .40707 m .35066 .36373 L .33506 .36197 L p
1 g
F P
s
P
p
.002 w
.63308 .33304 m .60157 .28929 L .58479 .29669 L p
1 g
F P
s
P
p
.002 w
.5443 .26901 m .58479 .29669 L .60157 .28929 L p
1 g
F P
s
P
p
.002 w
.32367 .47276 m .35075 .52014 L .35948 .50405 L p
1 g
F P
s
P
p
.002 w
.35948 .50405 m .33527 .46138 L .32367 .47276 L p
1 g
F P
s
P
p
.002 w
.61761 .55838 m .65582 .51052 L .64286 .5005 L p
1 g
F P
s
P
p
.002 w
.66358 .44603 m .64286 .5005 L .65582 .51052 L p
1 g
F P
s
P
p
.002 w
.50816 .60949 m .56676 .59251 L .55782 .57879 L p
1 g
F P
s
P
p
.002 w
.55782 .57879 m .50183 .59492 L .50816 .60949 L p
1 g
F P
s
P
p
.002 w
.49601 .25636 m .44528 .26054 L .44571 .27626 L p
1 g
F P
s
P
p
.002 w
.40495 .29426 m .44571 .27626 L .44528 .26054 L p
1 g
F P
s
P
p
.002 w
.35975 .31656 m .33506 .36197 L .35066 .36373 L p
1 g
F P
s
P
p
.002 w
.35066 .36373 m .37199 .3246 L .35975 .31656 L p
1 g
F P
s
P
p
.002 w
.65582 .51052 m .6776 .45352 L .66358 .44603 L p
1 g
F P
s
P
p
.002 w
.66622 .38811 m .66358 .44603 L .6776 .45352 L p
1 g
F P
s
P
p
.002 w
.4475 .60735 m .50816 .60949 L .50183 .59492 L p
1 g
F P
s
P
p
.002 w
.50183 .59492 m .44389 .59276 L .4475 .60735 L p
1 g
F P
s
P
p
.002 w
.66622 .38811 m .65009 .33257 L .63308 .33304 L p
1 g
F P
s
P
p
.002 w
.60157 .28929 m .63308 .33304 L .65009 .33257 L p
1 g
F P
s
P
p
.002 w
.34565 .53445 m .38989 .57207 L .39173 .55519 L p
1 g
F P
s
P
p
.002 w
.39173 .55519 m .35075 .52014 L .34565 .53445 L p
1 g
F P
s
P
p
.002 w
.44528 .26054 m .39799 .28137 L .40495 .29426 L p
1 g
F P
s
P
p
.002 w
.37199 .3246 m .40495 .29426 L .39799 .28137 L p
1 g
F P
s
P
p
.002 w
.39799 .28137 m .35975 .31656 L .37199 .3246 L p
1 g
F P
s
P
p
.002 w
.49601 .25636 m .5443 .26901 L .55662 .25837 L p
1 g
F P
s
P
p
.002 w
.60157 .28929 m .55662 .25837 L .5443 .26901 L p
1 g
F P
s
P
p
.002 w
.31397 .41799 m .32367 .47276 L .33527 .46138 L p
1 g
F P
s
P
p
.002 w
.33527 .46138 m .32667 .41219 L .31397 .41799 L p
1 g
F P
s
P
p
.002 w
.6776 .45352 m .68049 .39288 L .66622 .38811 L p
1 g
F P
s
P
p
.002 w
.65009 .33257 m .66622 .38811 L .68049 .39288 L p
1 g
F P
s
P
p
.002 w
.39092 .58582 m .4475 .60735 L .44389 .59276 L p
1 g
F P
s
P
p
.002 w
.44389 .59276 m .38989 .57207 L .39092 .58582 L p
1 g
F P
s
P
p
.002 w
.57428 .60245 m .62615 .56762 L .61761 .55838 L p
1 g
F P
s
P
p
.002 w
.61761 .55838 m .56676 .59251 L .57428 .60245 L p
1 g
F P
s
P
p
.002 w
.65582 .51052 m .61761 .55838 L .62615 .56762 L p
1 g
F P
s
P
p
.002 w
.65009 .33257 m .61629 .28537 L .60157 .28929 L p
1 g
F P
s
P
p
.002 w
.55662 .25837 m .60157 .28929 L .61629 .28537 L p
1 g
F P
s
P
p
.002 w
.31634 .48345 m .34565 .53445 L .35075 .52014 L p
1 g
F P
s
P
p
.002 w
.35075 .52014 m .32367 .47276 L .31634 .48345 L p
1 g
F P
s
P
p
.002 w
.55662 .25837 m .50287 .24415 L .49601 .25636 L p
1 g
F P
s
P
p
.002 w
.44528 .26054 m .49601 .25636 L .50287 .24415 L p
1 g
F P
s
P
p
.002 w
.32324 .36196 m .31397 .41799 L .32667 .41219 L p
1 g
F P
s
P
p
.002 w
.32667 .41219 m .33506 .36197 L .32324 .36196 L p
1 g
F P
s
P
p
.002 w
.62615 .56762 m .66515 .5188 L .65582 .51052 L p
1 g
F P
s
P
p
.002 w
.6776 .45352 m .65582 .51052 L .66515 .5188 L p
1 g
F P
s
P
p
.002 w
.51452 .61984 m .57428 .60245 L .56676 .59251 L p
1 g
F P
s
P
p
.002 w
.56676 .59251 m .50816 .60949 L .51452 .61984 L p
1 g
F P
s
P
p
.002 w
.50287 .24415 m .44629 .24874 L .44528 .26054 L p
1 g
F P
s
P
p
.002 w
.39799 .28137 m .44528 .26054 L .44629 .24874 L p
1 g
F P
s
P
p
.002 w
.35077 .31126 m .32324 .36196 L .33506 .36197 L p
1 g
F P
s
P
p
.002 w
.33506 .36197 m .35975 .31656 L .35077 .31126 L p
1 g
F P
s
P
p
.002 w
.66515 .5188 m .68742 .46068 L .6776 .45352 L p
1 g
F P
s
P
p
.002 w
.68049 .39288 m .6776 .45352 L .68742 .46068 L p
1 g
F P
s
P
p
.002 w
.45267 .61775 m .51452 .61984 L .50816 .60949 L p
1 g
F P
s
P
p
.002 w
.50816 .60949 m .4475 .60735 L .45267 .61775 L p
1 g
F P
s
P
p
.002 w
.68049 .39288 m .66373 .33471 L .65009 .33257 L p
1 g
F P
s
P
p
.002 w
.61629 .28537 m .65009 .33257 L .66373 .33471 L p
1 g
F P
s
P
p
.002 w
.34452 .54652 m .39092 .58582 L .38989 .57207 L p
1 g
F P
s
P
p
.002 w
.38989 .57207 m .34565 .53445 L .34452 .54652 L p
1 g
F P
s
P
p
.002 w
.44629 .24874 m .39348 .27196 L .39799 .28137 L p
1 g
F P
s
P
p
.002 w
.35975 .31656 m .39799 .28137 L .39348 .27196 L p
1 g
F P
s
P
p
.002 w
.39348 .27196 m .35077 .31126 L .35975 .31656 L p
1 g
F P
s
P
p
.002 w
.61629 .28537 m .56791 .25193 L .55662 .25837 L p
1 g
F P
s
P
p
.002 w
.50287 .24415 m .55662 .25837 L .56791 .25193 L p
1 g
F P
s
P
p
.002 w
.30579 .42436 m .31634 .48345 L .32367 .47276 L p
1 g
F P
s
P
p
.002 w
.32367 .47276 m .31397 .41799 L .30579 .42436 L p
1 g
F P
s
P
p
.002 w
.68742 .46068 m .69046 .39887 L .68049 .39288 L p
1 g
F P
s
P
p
.002 w
.66373 .33471 m .68049 .39288 L .69046 .39887 L p
1 g
F P
s
P
p
.002 w
.39498 .59589 m .45267 .61775 L .4475 .60735 L p
1 g
F P
s
P
p
.002 w
.4475 .60735 m .39092 .58582 L .39498 .59589 L p
1 g
F P
s
P
p
.002 w
.66373 .33471 m .62844 .28521 L .61629 .28537 L p
1 g
F P
s
P
p
.002 w
.56791 .25193 m .61629 .28537 L .62844 .28521 L p
1 g
F P
s
P
p
.002 w
.31375 .49313 m .34452 .54652 L .34565 .53445 L p
1 g
F P
s
P
p
.002 w
.34565 .53445 m .31634 .48345 L .31375 .49313 L p
1 g
F P
s
P
p
.002 w
.5801 .60815 m .63162 .57352 L .62615 .56762 L p
1 g
F P
s
P
p
.002 w
.62615 .56762 m .57428 .60245 L .5801 .60815 L p
1 g
F P
s
P
p
.002 w
.66515 .5188 m .62615 .56762 L .63162 .57352 L p
1 g
F P
s
P
p
.002 w
.56791 .25193 m .50993 .2365 L .50287 .24415 L p
1 g
F P
s
P
p
.002 w
.44629 .24874 m .50287 .24415 L .50993 .2365 L p
1 g
F P
s
P
p
.002 w
.31576 .36383 m .30579 .42436 L .31397 .41799 L p
1 g
F P
s
P
p
.002 w
.31397 .41799 m .32324 .36196 L .31576 .36383 L p
1 g
F P
s
P
p
.002 w
.63162 .57352 m .67038 .52503 L .66515 .5188 L p
1 g
F P
s
P
p
.002 w
.68742 .46068 m .66515 .5188 L .67038 .52503 L p
1 g
F P
s
P
p
.002 w
.52076 .62545 m .5801 .60815 L .57428 .60245 L p
1 g
F P
s
P
p
.002 w
.57428 .60245 m .51452 .61984 L .52076 .62545 L p
1 g
F P
s
P
p
.002 w
.50993 .2365 m .4488 .2414 L .44629 .24874 L p
1 g
F P
s
P
p
.002 w
.39348 .27196 m .44629 .24874 L .4488 .2414 L p
1 g
F P
s
P
p
.002 w
.34551 .30899 m .31576 .36383 L .32324 .36196 L p
1 g
F P
s
P
p
.002 w
.32324 .36196 m .35077 .31126 L .34551 .30899 L p
1 g
F P
s
P
p
.002 w
.69046 .39887 m .67347 .33955 L .66373 .33471 L p
1 g
F P
s
P
p
.002 w
.62844 .28521 m .66373 .33471 L .67347 .33955 L p
1 g
F P
s
P
p
.002 w
.34765 .55589 m .39498 .59589 L .39092 .58582 L p
1 g
F P
s
P
p
.002 w
.39092 .58582 m .34452 .54652 L .34765 .55589 L p
1 g
F P
s
P
p
.002 w
.67038 .52503 m .69253 .46733 L .68742 .46068 L p
1 g
F P
s
P
p
.002 w
.69046 .39887 m .68742 .46068 L .69253 .46733 L p
1 g
F P
s
P
p
.002 w
.45937 .62343 m .52076 .62545 L .51452 .61984 L p
1 g
F P
s
P
p
.002 w
.51452 .61984 m .45267 .61775 L .45937 .62343 L p
1 g
F P
s
P
p
.002 w
.4488 .2414 m .3917 .26649 L .39348 .27196 L p
1 g
F P
s
P
p
.002 w
.35077 .31126 m .39348 .27196 L .3917 .26649 L p
1 g
F P
s
P
p
.002 w
.3917 .26649 m .34551 .30899 L .35077 .31126 L p
1 g
F P
s
P
p
.002 w
.62844 .28521 m .57781 .25011 L .56791 .25193 L p
1 g
F P
s
P
p
.002 w
.50993 .2365 m .56791 .25193 L .57781 .25011 L p
1 g
F P
s
P
p
.002 w
.30264 .43118 m .31375 .49313 L .31634 .48345 L p
1 g
F P
s
P
p
.002 w
.31634 .48345 m .30579 .42436 L .30264 .43118 L p
1 g
F P
s
P
p
.002 w
.69253 .46733 m .69561 .40598 L .69046 .39887 L p
1 g
F P
s
P
p
.002 w
.67347 .33955 m .69046 .39887 L .69561 .40598 L p
1 g
F P
s
P
p
.002 w
.40213 .60178 m .45937 .62343 L .45267 .61775 L p
1 g
F P
s
P
p
.002 w
.45267 .61775 m .39498 .59589 L .40213 .60178 L p
1 g
F P
s
P
p
.002 w
.67347 .33955 m .63756 .28907 L .62844 .28521 L p
1 g
F P
s
P
p
.002 w
.57781 .25011 m .62844 .28521 L .63756 .28907 L p
1 g
F P
s
P
p
.002 w
.31626 .50147 m .34765 .55589 L .34452 .54652 L p
1 g
F P
s
P
p
.002 w
.34452 .54652 m .31375 .49313 L .31626 .50147 L p
1 g
F P
s
P
p
.002 w
.57781 .25011 m .51703 .23389 L .50993 .2365 L p
1 g
F P
s
P
p
.002 w
.4488 .2414 m .50993 .2365 L .51703 .23389 L p
1 g
F P
s
P
p
.002 w
.31309 .36764 m .30264 .43118 L .30579 .42436 L p
1 g
F P
s
P
p
.002 w
.30579 .42436 m .31576 .36383 L .31309 .36764 L p
1 g
F P
s
P
p
.002 w
.58394 .60916 m .63368 .57573 L .63162 .57352 L p
1 g
F P
s
P
p
.002 w
.63162 .57352 m .5801 .60815 L .58394 .60916 L p
1 g
F P
s
P
p
.002 w
.67038 .52503 m .63162 .57352 L .63368 .57573 L p
1 g
F P
s
P
p
.002 w
.63368 .57573 m .67111 .52892 L .67038 .52503 L p
1 g
F P
s
P
p
.002 w
.69253 .46733 m .67038 .52503 L .67111 .52892 L p
1 g
F P
s
P
p
.002 w
.52669 .62587 m .58394 .60916 L .5801 .60815 L p
1 g
F P
s
P
p
.002 w
.5801 .60815 m .52076 .62545 L .52669 .62587 L p
1 g
F P
s
P
p
.004 w
.68303 .32921 m
.69024 .32523 L
s
P
p
.004 w
.69024 .32523 m
.70595 .31653 L
s
P
p
.004 w
.70595 .31653 m
.74003 .29767 L
s
P
p
.002 w
.69561 .40598 m .67878 .34714 L .67347 .33955 L p
1 g
F P
s
P
p
.002 w
.63756 .28907 m .67347 .33955 L .67878 .34714 L p
1 g
F P
s
P
p
.002 w
.35521 .56212 m .40213 .60178 L .39498 .59589 L p
1 g
F P
s
P
p
.002 w
.39498 .59589 m .34765 .55589 L .35521 .56212 L p
1 g
F P
s
P
p
.002 w
.51703 .23389 m .45286 .23902 L .4488 .2414 L p
1 g
F P
s
P
p
.002 w
.3917 .26649 m .4488 .2414 L .45286 .23902 L p
1 g
F P
s
P
p
.002 w
.34434 .31004 m .31309 .36764 L .31576 .36383 L p
1 g
F P
s
P
p
.002 w
.31576 .36383 m .34551 .30899 L .34434 .31004 L p
1 g
F P
s
P
p
.002 w
.67111 .52892 m .6925 .47324 L .69253 .46733 L p
1 g
F P
s
P
p
.002 w
.69561 .40598 m .69253 .46733 L .6925 .47324 L p
1 g
F P
s
P
p
.002 w
.46751 .62392 m .52669 .62587 L .52076 .62545 L p
1 g
F P
s
P
p
.002 w
.52076 .62545 m .45937 .62343 L .46751 .62392 L p
1 g
F P
s
P
p
.002 w
.63756 .28907 m .58596 .25327 L .57781 .25011 L p
1 g
F P
s
P
p
.002 w
.51703 .23389 m .57781 .25011 L .58596 .25327 L p
1 g
F P
s
P
p
.002 w
.30493 .43828 m .31626 .50147 L .31375 .49313 L p
1 g
F P
s
P
p
.002 w
.31375 .49313 m .30264 .43118 L .30493 .43828 L p
1 g
F P
s
P
p
.002 w
.45286 .23902 m .39288 .26537 L .3917 .26649 L p
1 g
F P
s
P
p
.002 w
.34551 .30899 m .3917 .26649 L .39288 .26537 L p
1 g
F P
s
P
p
.002 w
.39288 .26537 m .34434 .31004 L .34551 .30899 L p
1 g
F P
s
P
p
.002 w
.6925 .47324 m .69546 .41409 L .69561 .40598 L p
1 g
F P
s
P
p
.002 w
.67878 .34714 m .69561 .40598 L .69546 .41409 L p
1 g
F P
s
P
p
.002 w
.41238 .60304 m .46751 .62392 L .45937 .62343 L p
1 g
F P
s
P
p
.002 w
.45937 .62343 m .40213 .60178 L .41238 .60304 L p
1 g
F P
s
P
p
.002 w
.67878 .34714 m .64318 .29709 L .63756 .28907 L p
1 g
F P
s
P
p
.002 w
.58596 .25327 m .63756 .28907 L .64318 .29709 L p
1 g
F P
s
P
p
.002 w
.32413 .50815 m .35521 .56212 L .34765 .55589 L p
1 g
F P
s
P
p
.002 w
.34765 .55589 m .31626 .50147 L .32413 .50815 L p
1 g
F P
s
P
p
.002 w
.58596 .25327 m .52395 .23673 L .51703 .23389 L p
1 g
F P
s
P
p
.002 w
.45286 .23902 m .51703 .23389 L .52395 .23673 L p
1 g
F P
s
P
p
.002 w
.31563 .37341 m .30493 .43828 L .30264 .43118 L p
1 g
F P
s
P
p
.002 w
.30264 .43118 m .31309 .36764 L .31563 .37341 L p
1 g
F P
s
P
p
.002 w
.58558 .60514 m .63205 .57391 L .63368 .57573 L p
1 g
F P
s
P
p
.002 w
.63368 .57573 m .58394 .60916 L .58558 .60514 L p
1 g
F P
s
P
p
.002 w
.67111 .52892 m .63368 .57573 L .63205 .57391 L p
1 g
F P
s
P
p
.002 w
.63205 .57391 m .66701 .53018 L .67111 .52892 L p
1 g
F P
s
P
p
.002 w
.6925 .47324 m .67111 .52892 L .66701 .53018 L p
1 g
F P
s
P
p
.002 w
.53212 .62073 m .58558 .60514 L .58394 .60916 L p
1 g
F P
s
P
p
.002 w
.58394 .60916 m .52669 .62587 L .53212 .62073 L p
1 g
F P
s
P
p
.002 w
.69546 .41409 m .67923 .35742 L .67878 .34714 L p
1 g
F P
s
P
p
.002 w
.64318 .29709 m .67878 .34714 L .67923 .35742 L p
1 g
F P
s
P
p
.002 w
.36727 .56482 m .41238 .60304 L .40213 .60178 L p
1 g
F P
s
P
p
.002 w
.40213 .60178 m .35521 .56212 L .36727 .56482 L p
1 g
F P
s
P
p
.002 w
.52395 .23673 m .45844 .24199 L .45286 .23902 L p
1 g
F P
s
P
p
.002 w
.39288 .26537 m .45286 .23902 L .45844 .24199 L p
1 g
F P
s
P
p
.002 w
.34757 .31457 m .31563 .37341 L .31309 .36764 L p
1 g
F P
s
P
p
.002 w
.31309 .36764 m .34434 .31004 L .34757 .31457 L p
1 g
F P
s
P
p
.002 w
.66701 .53018 m .68697 .47819 L .6925 .47324 L p
1 g
F P
s
P
p
.002 w
.69546 .41409 m .6925 .47324 L .68697 .47819 L p
1 g
F P
s
P
p
.002 w
.47692 .61887 m .53212 .62073 L .52669 .62587 L p
1 g
F P
s
P
p
.002 w
.52669 .62587 m .46751 .62392 L .47692 .61887 L p
1 g
F P
s
P
p
.002 w
.64318 .29709 m .592 .26162 L .58596 .25327 L p
1 g
F P
s
P
p
.002 w
.52395 .23673 m .58596 .25327 L .592 .26162 L p
1 g
F P
s
P
p
.002 w
.31297 .44546 m .32413 .50815 L .31626 .50147 L p
1 g
F P
s
P
p
.002 w
.31626 .50147 m .30493 .43828 L .31297 .44546 L p
1 g
F P
s
P
p
.002 w
.45844 .24199 m .39717 .26893 L .39288 .26537 L p
1 g
F P
s
P
p
.002 w
.34434 .31004 m .39288 .26537 L .39717 .26893 L p
1 g
F P
s
P
p
.002 w
.39717 .26893 m .34757 .31457 L .34434 .31004 L p
1 g
F P
s
P
p
.002 w
.68697 .47819 m .68969 .42302 L .69546 .41409 L p
1 g
F P
s
P
p
.002 w
.67923 .35742 m .69546 .41409 L .68969 .42302 L p
1 g
F P
s
P
p
.002 w
.42561 .59934 m .47692 .61887 L .46751 .62392 L p
1 g
F P
s
P
p
.002 w
.46751 .62392 m .41238 .60304 L .42561 .59934 L p
1 g
F P
s
P
p
.002 w
.67923 .35742 m .64491 .30929 L .64318 .29709 L p
1 g
F P
s
P
p
.002 w
.592 .26162 m .64318 .29709 L .64491 .30929 L p
1 g
F P
s
P
p
.002 w
.33745 .51284 m .36727 .56482 L .35521 .56212 L p
1 g
F P
s
P
p
.002 w
.35521 .56212 m .32413 .50815 L .33745 .51284 L p
1 g
F P
s
P
p
.002 w
.592 .26162 m .53048 .24529 L .52395 .23673 L p
1 g
F P
s
P
p
.002 w
.45844 .24199 m .52395 .23673 L .53048 .24529 L p
1 g
F P
s
P
p
.002 w
.32365 .3811 m .31297 .44546 L .30493 .43828 L p
1 g
F P
s
P
p
.002 w
.30493 .43828 m .31563 .37341 L .32365 .3811 L p
1 g
F P
s
P
p
.002 w
.58481 .59589 m .62652 .56787 L .63205 .57391 L p
1 g
F P
s
P
p
.002 w
.63205 .57391 m .58558 .60514 L .58481 .59589 L p
1 g
F P
s
P
p
.002 w
.66701 .53018 m .63205 .57391 L .62652 .56787 L p
1 g
F P
s
P
p
.002 w
.62652 .56787 m .6579 .52861 L .66701 .53018 L p
1 g
F P
s
P
p
.002 w
.68697 .47819 m .66701 .53018 L .6579 .52861 L p
1 g
F P
s
P
p
.002 w
.53685 .60983 m .58481 .59589 L .58558 .60514 L p
1 g
F P
s
P
p
.002 w
.58558 .60514 m .53212 .62073 L .53685 .60983 L p
1 g
F P
s
P
p
.002 w
.68969 .42302 m .67449 .37025 L .67923 .35742 L p
1 g
F P
s
P
p
.002 w
.64491 .30929 m .67923 .35742 L .67449 .37025 L p
1 g
F P
s
P
p
.002 w
.38371 .56368 m .42561 .59934 L .41238 .60304 L p
1 g
F P
s
P
p
.002 w
.41238 .60304 m .36727 .56482 L .38371 .56368 L p
1 g
F P
s
P
p
.002 w
.53048 .24529 m .46548 .25058 L .45844 .24199 L p
1 g
F P
s
P
p
.002 w
.39717 .26893 m .45844 .24199 L .46548 .25058 L p
1 g
F P
s
P
p
.002 w
.3554 .3227 m .32365 .3811 L .31563 .37341 L p
1 g
F P
s
P
p
.002 w
.31563 .37341 m .34757 .31457 L .3554 .3227 L p
1 g
F P
s
P
p
.002 w
.6579 .52861 m .67575 .48196 L .68697 .47819 L p
1 g
F P
s
P
p
.002 w
.68969 .42302 m .68697 .47819 L .67575 .48196 L p
1 g
F P
s
P
p
.002 w
.48741 .60808 m .53685 .60983 L .53212 .62073 L p
1 g
F P
s
P
p
.002 w
.53212 .62073 m .47692 .61887 L .48741 .60808 L p
1 g
F P
s
P
p
.002 w
.64491 .30929 m .5956 .27525 L .592 .26162 L p
1 g
F P
s
P
p
.002 w
.53048 .24529 m .592 .26162 L .5956 .27525 L p
1 g
F P
s
P
p
.002 w
.32684 .4525 m .33745 .51284 L .32413 .50815 L p
1 g
F P
s
P
p
.002 w
.32413 .50815 m .31297 .44546 L .32684 .4525 L p
1 g
F P
s
P
p
.002 w
.46548 .25058 m .40466 .27737 L .39717 .26893 L p
1 g
F P
s
P
p
.002 w
.34757 .31457 m .39717 .26893 L .40466 .27737 L p
1 g
F P
s
P
p
.002 w
.40466 .27737 m .3554 .3227 L .34757 .31457 L p
1 g
F P
s
P
p
.002 w
.67575 .48196 m .67811 .43253 L .68969 .42302 L p
1 g
F P
s
P
p
.002 w
.67449 .37025 m .68969 .42302 L .67811 .43253 L p
1 g
F P
s
P
p
.002 w
.44155 .5905 m .48741 .60808 L .47692 .61887 L p
1 g
F P
s
P
p
.002 w
.47692 .61887 m .42561 .59934 L .44155 .5905 L p
1 g
F P
s
P
p
.002 w
.67449 .37025 m .64245 .32554 L .64491 .30929 L p
1 g
F P
s
P
p
.002 w
.5956 .27525 m .64491 .30929 L .64245 .32554 L p
1 g
F P
s
P
p
.002 w
.35613 .51527 m .38371 .56368 L .36727 .56482 L p
1 g
F P
s
P
p
.002 w
.36727 .56482 m .33745 .51284 L .35613 .51527 L p
1 g
F P
s
P
p
.002 w
.5956 .27525 m .53638 .25966 L .53048 .24529 L p
1 g
F P
s
P
p
.002 w
.46548 .25058 m .53048 .24529 L .53638 .25966 L p
1 g
F P
s
P
p
.002 w
.33723 .39056 m .32684 .4525 L .31297 .44546 L p
1 g
F P
s
P
p
.002 w
.31297 .44546 m .32365 .3811 L .33723 .39056 L p
1 g
F P
s
P
p
.002 w
.58149 .58136 m .61703 .55752 L .62652 .56787 L p
1 g
F P
s
P
p
.002 w
.62652 .56787 m .58481 .59589 L .58149 .58136 L p
1 g
F P
s
P
p
.002 w
.6579 .52861 m .62652 .56787 L .61703 .55752 L p
1 g
F P
s
P
p
.002 w
.61703 .55752 m .64373 .52407 L .6579 .52861 L p
1 g
F P
s
P
p
.002 w
.67575 .48196 m .6579 .52861 L .64373 .52407 L p
1 g
F P
s
P
p
.002 w
.54067 .59317 m .58149 .58136 L .58481 .59589 L p
1 g
F P
s
P
p
.002 w
.58481 .59589 m .53685 .60983 L .54067 .59317 L p
1 g
F P
s
P
p
.002 w
.67811 .43253 m .6644 .38538 L .67449 .37025 L p
1 g
F P
s
P
p
.002 w
.64245 .32554 m .67449 .37025 L .6644 .38538 L p
1 g
F P
s
P
p
.004 w
.67068 .33605 m
.68303 .32921 L
s
P
p
.004 w
.5 .43051 m
.65042 .34726 L
s
P
p
.002 w
.40425 .55852 m .44155 .5905 L .42561 .59934 L p
1 g
F P
s
P
p
.002 w
.42561 .59934 m .38371 .56368 L .40425 .55852 L p
1 g
F P
s
P
p
.002 w
.53638 .25966 m .47382 .26487 L .46548 .25058 L p
1 g
F P
s
P
p
.002 w
.40466 .27737 m .46548 .25058 L .47382 .26487 L p
1 g
F P
s
P
p
.002 w
.36786 .33437 m .33723 .39056 L .32365 .3811 L p
1 g
F P
s
P
p
.002 w
.32365 .3811 m .3554 .3227 L .36786 .33437 L p
1 g
F P
s
P
p
.002 w
.64373 .52407 m .65887 .48436 L .67575 .48196 L p
1 g
F P
s
P
p
.002 w
.67811 .43253 m .67575 .48196 L .65887 .48436 L p
1 g
F P
s
P
p
.002 w
.49867 .59158 m .54067 .59317 L .53685 .60983 L p
1 g
F P
s
P
p
.002 w
.53685 .60983 m .48741 .60808 L .49867 .59158 L p
1 g
F P
s
P
p
.002 w
.64245 .32554 m .59651 .29403 L .5956 .27525 L p
1 g
F P
s
P
p
.002 w
.53638 .25966 m .5956 .27525 L .59651 .29403 L p
1 g
F P
s
P
p
.002 w
.34643 .45914 m .35613 .51527 L .33745 .51284 L p
1 g
F P
s
P
p
.002 w
.33745 .51284 m .32684 .4525 L .34643 .45914 L p
1 g
F P
s
P
p
.002 w
.47382 .26487 m .41529 .29072 L .40466 .27737 L p
1 g
F P
s
P
p
.002 w
.3554 .3227 m .40466 .27737 L .41529 .29072 L p
1 g
F P
s
P
p
.002 w
.41529 .29072 m .36786 .33437 L .3554 .3227 L p
1 g
F P
s
P
p
.002 w
.65887 .48436 m .66077 .44236 L .67811 .43253 L p
1 g
F P
s
P
p
.002 w
.6644 .38538 m .67811 .43253 L .66077 .44236 L p
1 g
F P
s
P
p
.002 w
.45983 .57652 m .49867 .59158 L .48741 .60808 L p
1 g
F P
s
P
p
.002 w
.48741 .60808 m .44155 .5905 L .45983 .57652 L p
1 g
F P
s
P
p
.002 w
.6644 .38538 m .63564 .34554 L .64245 .32554 L p
1 g
F P
s
P
p
.004 w
.65193 .34643 m
.65312 .34577 L
s
P
p
.004 w
.65312 .34577 m
.65904 .34249 L
s
P
p
.004 w
.65904 .34249 m
.67068 .33605 L
s
P
p
.002 w
.59651 .29403 m .64245 .32554 L .63564 .34554 L p
1 g
F P
s
P
p
.002 w
.37981 .51522 m .40425 .55852 L .38371 .56368 L p
1 g
F P
s
P
p
.002 w
.38371 .56368 m .35613 .51527 L .37981 .51522 L p
1 g
F P
s
P
p
.002 w
.59651 .29403 m .54141 .2797 L .53638 .25966 L p
1 g
F P
s
P
p
.002 w
.47382 .26487 m .53638 .25966 L .54141 .2797 L p
1 g
F P
s
P
p
.002 w
.35623 .40159 m .34643 .45914 L .32684 .4525 L p
1 g
F P
s
P
p
.002 w
.32684 .4525 m .33723 .39056 L .35623 .40159 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.5756 .56174 m .60365 .54294 L .61703 .55752 L p
1 g
F P
s
P
p
.002 w
.61703 .55752 m .58149 .58136 L .5756 .56174 L p
1 g
F P
s
P
p
.002 w
.64373 .52407 m .61703 .55752 L .60365 .54294 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.60365 .54294 m .6247 .51654 L .64373 .52407 L p
1 g
F P
s
P
p
.002 w
.65887 .48436 m .64373 .52407 L .6247 .51654 L p
1 g
F P
s
P
p
.002 w
.54341 .57098 m .5756 .56174 L .58149 .58136 L p
1 g
F P
s
P
p
.002 w
.58149 .58136 m .54067 .59317 L .54341 .57098 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.66077 .44236 m .649 .4024 L .6644 .38538 L p
1 g
F P
s
P
p
.002 w
.63564 .34554 m .6644 .38538 L .649 .4024 L p
1 g
F P
s
P
p
.002 w
.42837 .5493 m .45983 .57652 L .44155 .5905 L p
1 g
F P
s
P
p
.002 w
.44155 .5905 m .40425 .55852 L .42837 .5493 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.6247 .51654 m .63657 .48522 L .65887 .48436 L p
1 g
F P
s
P
p
.002 w
.66077 .44236 m .65887 .48436 L .63657 .48522 L p
1 g
F P
s
P
p
.002 w
.54141 .2797 m .48327 .28468 L .47382 .26487 L p
1 g
F P
s
P
p
.002 w
.41529 .29072 m .47382 .26487 L .48327 .28468 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58032 L p
1 g
F P
s
P
p
.002 w
.5434 .57103 m .54067 .59317 L p
.52267 .57918 L 1 g
F P
s
P
p
.52267 .57918 m .52057 .57755 L .53166 .57439 L 1 g
F
P
p
.52267 .57918 m .53166 .57439 L .5434 .57103 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53166 .57439 L p
1 g
F P
s
P
p
.54854 .56129 m .53166 .57439 L .53842 .57077 L 1 g
F
P
p
.54854 .56129 m .53842 .57077 L .53896 .57042 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54341 .57098 m .53842 .57077 L p
.54164 .56865 L 1 g
F P
s
P
p
.002 w
.5436 .56735 m .54341 .57098 L p
.54164 .56865 L 1 g
F P
s
P
p
.002 w
.54341 .57098 m .5434 .57103 L p
.53835 .57081 L 1 g
F P
s
P
p
.002 w
.51036 .56962 m .53842 .57077 L p
.53835 .57081 L 1 g
F P
s
P
p
.002 w
.53842 .57077 m .54341 .57098 L p
.53835 .57081 L 1 g
F P
s
P
p
.53128 .57265 m .51092 .58032 L .52316 .57681 L 1 g
F
P
p
.54067 .59317 m .50354 .58242 L .51092 .58032 L 1 g
F
P
p
.52286 .57933 m .51092 .58032 L .52057 .57755 L 1 g
F
P
p
.54067 .59317 m .51092 .58032 L .52286 .57933 L 1 g
F
P
p
.002 w
.54067 .59317 m .49867 .59158 L .50354 .58242 L p
1 g
F P
s
P
p
.002 w
.51092 .58032 m .51079 .57862 L p
.50057 .58066 L 1 g
F P
s
P
p
.002 w
.50438 .58086 m .49867 .59158 L p
.49241 .58025 L 1 g
F P
s
P
p
.50057 .58066 m .49623 .58153 L .50438 .58086 L 1 g
F
P
p
.50057 .58066 m .50438 .58086 L .51092 .58032 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.52057 .57755 m .51092 .58032 L .51036 .56962 L 1 g
F
P
p
.002 w
.50354 .58242 m .50438 .58086 L p
.51092 .58032 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58009 L p
1 g
F P
s
P
p
.002 w
.49867 .59158 m .46602 .57892 L p
.4891 .58009 L 1 g
F P
s
P
p
.49287 .5811 m .4891 .58009 L .49241 .58025 L 1 g
F
P
p
.49867 .59158 m .4891 .58009 L .49287 .5811 L 1 g
F
P
p
.002 w
.4891 .58009 m .48921 .57862 L p
.48118 .57796 L 1 g
F P
s
P
p
.51079 .57862 m .4891 .58009 L .49868 .58057 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46832 .57451 L p
1 g
F P
s
P
p
.48921 .57862 m .46832 .57451 L .48118 .57796 L 1 g
F
P
p
.49241 .58025 m .48772 .57972 L .47991 .55766 L 1 g
F
P
p
.002 w
.45983 .57652 m .46339 .57318 L p
.46832 .57451 L 1 g
F P
s
P
p
.47542 .57831 m .45983 .57652 L .46832 .57451 L 1 g
F
P
p
.002 w
.46832 .57451 m .46872 .57265 L p
.45979 .56908 L 1 g
F P
s
P
p
.002 w
.46428 .57235 m .45983 .57652 L p
.45894 .56846 L 1 g
F P
s
P
p
.002 w
.45983 .57652 m .42837 .5493 L .4309 .54807 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.45983 .57652 m .4309 .54807 L .45095 .56266 L 1 g
F
P
p
.45946 .57317 m .45095 .56266 L .45894 .56846 L 1 g
F
P
p
.45983 .57652 m .45095 .56266 L .45946 .57317 L 1 g
F
P
p
.002 w
.45095 .56266 m .45146 .56129 L p
.44602 .55656 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45095 .56266 L p
1 g
F P
s
P
p
.002 w
.45095 .56266 m .45002 .56518 L p
.45979 .56908 L 1 g
F P
s
P
p
.46872 .57265 m .45095 .56266 L .45979 .56908 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43844 .54719 L p
1 g
F P
s
P
p
.002 w
.4309 .54807 m .43682 .54519 L p
.43844 .54719 L 1 g
F P
s
P
p
.45095 .56266 m .44189 .55607 L .43844 .54719 L 1 g
F
P
p
.44189 .55607 m .4309 .54807 L .43844 .54719 L 1 g
F
P
p
.002 w
.43844 .54719 m .43925 .54566 L p
.43585 .53894 L 1 g
F P
s
P
p
.002 w
.43752 .54485 m .42837 .5493 L p
.43341 .5303 L 1 g
F P
s
P
p
.43585 .53894 m .43309 .53348 L .43752 .54485 L 1 g
F
P
p
.43585 .53894 m .43752 .54485 L .43844 .54719 L 1 g
F
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.45146 .56129 m .43844 .54719 L .44602 .55656 L 1 g
F
P
p
.45095 .56266 m .43844 .54719 L .45536 .53618 L 1 g
F
P
p
.002 w
.43682 .54519 m .43752 .54485 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43283 .52826 L p
1 g
F P
s
P
p
.42837 .5493 m .42748 .50933 L .43283 .52826 L 1 g
F
P
p
.43254 .53358 m .43283 .52826 L .43341 .5303 L 1 g
F
P
p
.42837 .5493 m .43283 .52826 L .43254 .53358 L 1 g
F
P
p
.002 w
.43283 .52826 m .43346 .52734 L p
.43324 .52087 L 1 g
F P
s
P
p
.43925 .54566 m .43283 .52826 L .4356 .53804 L 1 g
F
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43386 .50944 L p
1 g
F P
s
P
p
.43346 .52734 m .43386 .50944 L .43324 .52087 L 1 g
F
P
p
.43341 .5303 m .43283 .52826 L .4395 .50734 L 1 g
F
P
p
.002 w
.43425 .4742 m .43834 .50001 L p
.40789 .51258 L 1 g
F P
s
P
p
.43485 .50826 m .43864 .4994 L .43799 .50073 L 1 g
F
P
p
.002 w
.43425 .4742 m .45052 .4754 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.43834 .50001 m .43772 .49607 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.43772 .49607 m .43425 .4742 L p
.44266 .49128 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44266 .49128 m .44339 .4905 L p
.44943 .48471 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43834 .50001 m .44266 .49128 L .47008 .47685 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45766 .47674 L p
1 g
F P
s
P
p
.44339 .4905 m .45766 .47674 L .44943 .48471 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45766 .47674 m .45826 .47608 L p
.46924 .47127 L 1 g
F P
s
P
p
.002 w
.4713 .47029 m .47008 .47685 L .45915 .47604 L p
1 g
F P
s
P
p
.002 w
.47008 .47685 m .4713 .47029 L p
.5093 .46636 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.4713 .47029 m .47753 .46721 L .5093 .46636 L 1 g
F
P
p
.002 w
.47753 .46721 m .47786 .46667 L p
.4887 .46557 L 1 g
F P
s
P
p
.47753 .46721 m .5 .4639 L .5093 .46636 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56614 .50944 L p
1 g
F P
s
P
p
.56891 .51545 m .56614 .50944 L .56647 .50249 L 1 g
F
P
p
.002 w
.56377 .50429 m .56569 .50301 L p
.56614 .50944 L 1 g
F P
s
P
p
.002 w
.56569 .50301 m .56647 .50249 L p
.56614 .50944 L 1 g
F P
s
P
p
.002 w
.56614 .50944 m .56515 .50826 L p
.56682 .5191 L 1 g
F P
s
P
p
.55661 .4905 m .56614 .50944 L .56377 .50429 L 1 g
F
P
p
.002 w
.55879 .49414 m .56647 .50249 L .56377 .50429 L p
1 g
F P
s
P
p
.56306 .50285 m .56377 .50429 L .56344 .50356 L 1 g
F
P
p
.55661 .4905 m .56377 .50429 L .56306 .50285 L 1 g
F
P
p
.002 w
.57394 .49309 m .56647 .50249 L .55879 .49414 L p
1 g
F P
s
P
p
.002 w
.55307 .48252 m .57394 .49309 L p
.56019 .49404 L 1 g
F P
s
P
p
.56019 .49404 m .55879 .49414 L .55742 .49136 L 1 g
F
P
p
.56019 .49404 m .55742 .49136 L .55307 .48252 L 1 g
F
P
p
.002 w
.55742 .49136 m .55661 .4905 L p
.56325 .5032 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55742 .49136 L p
1 g
F P
s
P
p
.54174 .47608 m .55742 .49136 L .55732 .49127 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54378 .47782 m .55307 .48252 L p
.55742 .49136 L 1 g
F P
s
P
p
.002 w
.55879 .49414 m .54658 .48086 L p
.55742 .49136 L 1 g
F P
s
P
p
.54174 .47608 m .55732 .49127 L .55071 .48487 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55742 .49136 L p
1 g
F P
s
P
p
.56325 .5032 m .56713 .51061 L .55742 .49136 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55648 .50915 m .544 .47837 L p
.55879 .49414 L 1 g
F P
s
P
p
.002 w
.54658 .48086 m .55879 .49414 L p
.544 .47837 L 1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54248 .47688 L p
1 g
F P
s
P
p
.50979 .4655 m .52246 .4672 L .54094 .47614 L 1 g
F
P
p
.52214 .46667 m .54248 .47688 L .53324 .47242 L 1 g
F
P
p
.50979 .4655 m .54094 .47614 L .54323 .47762 L 1 g
F
P
p
.54094 .47614 m .54213 .47655 L .54248 .47688 L 1 g
F
P
p
.54094 .47614 m .54248 .47688 L .54323 .47762 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52246 .4672 L p
1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53324 .47242 L 1 g
F P
s
P
p
.53324 .47242 m .54302 .47747 L .52246 .4672 L 1 g
F
P
p
.002 w
.54248 .47688 m .54302 .47747 L p
.53324 .47242 L 1 g
F P
s
P
p
.002 w
.53161 .46843 m .54213 .47655 L p
.54094 .47614 L 1 g
F P
s
P
p
.52246 .4672 m .53161 .46843 L .54094 .47614 L 1 g
F
P
p
.002 w
.55834 .49233 m .55635 .49041 L p
.55 .48418 L 1 g
F P
s
P
p
.54174 .47608 m .551 .48515 L .55 .48418 L 1 g
F
P
p
.551 .48515 m .55834 .49233 L .55 .48418 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55648 .50915 m .54504 .51237 L .54379 .47816 L p
1 g
F P
s
P
p
.002 w
.544 .47837 m .55648 .50915 L p
.54379 .47816 L 1 g
F P
s
P
p
.002 w
.54248 .47688 m .54174 .47608 L p
.55041 .48458 L 1 g
F P
s
P
p
.002 w
.54504 .51237 m .53335 .51179 L .5437 .47807 L p
1 g
F P
s
P
p
.002 w
.54379 .47816 m .54504 .51237 L p
.5437 .47807 L 1 g
F P
s
P
p
.002 w
.53335 .51179 m .52268 .50745 L .54364 .47801 L p
1 g
F P
s
P
p
.002 w
.54364 .47801 m .54378 .47782 L .5437 .47807 L p
1 g
F P
s
P
p
.002 w
.5437 .47807 m .53335 .51179 L p
.54364 .47801 L 1 g
F P
s
P
p
.002 w
.52268 .50745 m .51417 .4998 L .54358 .47796 L p
1 g
F P
s
P
p
.002 w
.54358 .47796 m .54378 .47782 L .54364 .47801 L p
1 g
F P
s
P
p
.002 w
.54364 .47801 m .52268 .50745 L p
.54358 .47796 L 1 g
F P
s
P
p
.002 w
.51417 .4998 m .50876 .48965 L .54352 .4779 L p
1 g
F P
s
P
p
.002 w
.54352 .4779 m .54378 .47782 L .54358 .47796 L p
1 g
F P
s
P
p
.002 w
.54358 .47796 m .51417 .4998 L p
.54352 .4779 L 1 g
F P
s
P
p
.54364 .47802 m .55635 .49041 L .54356 .47794 L 1 g
F
P
p
.54367 .47804 m .54371 .47808 L .54364 .47802 L 1 g
F
P
p
.54371 .47808 m .55635 .49041 L .54364 .47802 L 1 g
F
P
p
.5437 .47807 m .54372 .47809 L .54367 .47804 L 1 g
F
P
p
.54372 .47809 m .55635 .49041 L .54367 .47804 L 1 g
F
P
p
.55041 .48458 m .55104 .4852 L .5437 .47807 L 1 g
F
P
p
.55104 .4852 m .55635 .49041 L .5437 .47807 L 1 g
F
P
p
.002 w
.50707 .47808 m .5093 .46636 L .54326 .47764 L p
1 g
F P
s
P
p
.002 w
.54326 .47764 m .54378 .47782 L .54344 .47782 L p
1 g
F P
s
P
p
.002 w
.54344 .47782 m .50707 .47808 L p
.54326 .47764 L 1 g
F P
s
P
p
.002 w
.50876 .48965 m .50707 .47808 L .54344 .47782 L p
1 g
F P
s
P
p
.002 w
.54344 .47782 m .54378 .47782 L .54352 .4779 L p
1 g
F P
s
P
p
.002 w
.54352 .4779 m .50876 .48965 L p
.54344 .47782 L 1 g
F P
s
P
p
.55041 .48458 m .54361 .47799 L .54248 .47688 L 1 g
F
P
p
.54361 .47799 m .54358 .47796 L .54348 .47786 L 1 g
F
P
p
.54361 .47799 m .54348 .47786 L .54248 .47688 L 1 g
F
P
p
.54358 .47796 m .54356 .47794 L .54326 .47764 L 1 g
F
P
p
.54358 .47796 m .54326 .47764 L .54248 .47688 L 1 g
F
P
p
.002 w
.5437 .47807 m .54378 .47782 L .54379 .47816 L p
1 g
F P
s
P
p
.002 w
.54379 .47816 m .54378 .47782 L .544 .47837 L p
1 g
F P
s
P
p
.002 w
.54213 .47655 m .54378 .47782 L p
.54323 .47762 L 1 g
F P
s
P
p
.002 w
.5093 .46636 m .50979 .4655 L p
.54323 .47762 L 1 g
F P
s
P
p
.002 w
.54378 .47782 m .54326 .47764 L p
.54323 .47762 L 1 g
F P
s
P
p
.002 w
.54326 .47764 m .5093 .46636 L p
.54323 .47762 L 1 g
F P
s
P
p
.002 w
.56647 .50249 m .58664 .52443 L p
.56891 .51545 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55635 .49041 L p
.56007 .49417 L 1 g
F P
s
P
p
.002 w
.55635 .49041 m .55834 .49233 L .55845 .49245 L p
1 g
F P
s
P
p
.002 w
.55845 .49245 m .56007 .49417 L p
.55635 .49041 L 1 g
F P
s
P
p
.002 w
.55635 .49041 m .54302 .47747 L .54248 .47688 L p
1 g
F P
s
P
p
.002 w
.54658 .48086 m .54378 .47782 L p
.55742 .49136 L 1 g
F P
s
P
p
.55071 .48487 m .55743 .49137 L .55074 .48489 L 1 g
F
P
p
.55732 .49127 m .55743 .49137 L .55071 .48487 L 1 g
F
P
p
.002 w
.55742 .49136 m .55743 .49137 L p
.55732 .49127 L 1 g
F P
s
P
p
.002 w
.55743 .49137 m .55834 .49233 L p
.55074 .48489 L 1 g
F P
s
P
p
.002 w
.544 .47837 m .54378 .47782 L .54658 .48086 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56377 .50429 m .55648 .50915 L p
.55879 .49414 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5675 .52874 L p
1 g
F P
s
P
p
.56515 .50826 m .5675 .52874 L .56682 .5191 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55648 .50915 m .56377 .50429 L p
.56614 .50944 L 1 g
F P
s
P
p
.56891 .51545 m .56648 .51422 L .56614 .50944 L 1 g
F
P
p
.56648 .51422 m .55648 .50915 L .56614 .50944 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.58664 .52443 m .5672 .53744 L .56603 .53437 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56153 .54713 L p
1 g
F P
s
P
p
.5756 .56174 m .55954 .55235 L .56357 .54451 L 1 g
F
P
p
.002 w
.5672 .53744 m .56777 .5391 L p
.56357 .54451 L 1 g
F P
s
P
p
.002 w
.56777 .5391 m .5756 .56174 L p
.56357 .54451 L 1 g
F P
s
P
p
.002 w
.56153 .54713 m .56075 .54566 L p
.55604 .5542 L 1 g
F P
s
P
p
.56654 .52734 m .56153 .54713 L .5638 .54118 L 1 g
F
P
p
.002 w
.56498 .53807 m .5672 .53744 L p
.55954 .55235 L 1 g
F P
s
P
p
.56387 .54199 m .56232 .54863 L .56343 .54436 L 1 g
F
P
p
.56654 .52734 m .56311 .54463 L .56387 .54199 L 1 g
F
P
p
.56311 .54463 m .56232 .54863 L .56387 .54199 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56603 .53437 m .5672 .53744 L p
.56566 .5357 L 1 g
F P
s
P
p
.58664 .52443 m .56603 .53437 L .57072 .51637 L 1 g
F
P
p
.002 w
.5672 .53744 m .56498 .53807 L p
.56566 .5357 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5676 .52888 L p
1 g
F P
s
P
p
.002 w
.5676 .52888 m .56654 .52734 L p
.56387 .54199 L 1 g
F P
s
P
p
.56387 .54199 m .56257 .5491 L .5676 .52888 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.5449 .54378 m .54504 .51237 L p
.56566 .5357 L 1 g
F P
s
P
p
.002 w
.56498 .53807 m .5449 .54378 L p
.56566 .5357 L 1 g
F P
s
P
p
.002 w
.54504 .51237 m .55648 .50915 L .56603 .53437 L p
1 g
F P
s
P
p
.56566 .5357 m .54504 .51237 L .56603 .53437 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56302 L p
1 g
F P
s
P
p
.56075 .54566 m .54918 .56302 L .55604 .5542 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5449 .54378 m .56498 .53807 L p
.56153 .54713 L 1 g
F P
s
P
p
.55954 .55235 m .55812 .55152 L .56153 .54713 L 1 g
F
P
p
.55812 .55152 m .5449 .54378 L .56153 .54713 L 1 g
F
P
p
.002 w
.5756 .56174 m .54341 .57098 L .5436 .56735 L p
1 g
F P
s
P
p
.54854 .56129 m .5388 .57057 L .54089 .56946 L 1 g
F
P
p
.002 w
.54918 .56302 m .54854 .56129 L p
.54089 .56946 L 1 g
F P
s
P
p
.002 w
.5436 .56735 m .5449 .54378 L p
.56149 .55348 L 1 g
F P
s
P
p
.5756 .56174 m .5436 .56735 L .56149 .55348 L 1 g
F
P
p
.002 w
.54981 .5647 m .54918 .56302 L p
.54089 .56946 L 1 g
F P
s
P
p
.002 w
.54918 .56302 m .54998 .56518 L p
.55604 .5542 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56153 .54713 L p
1 g
F P
s
P
p
.55604 .5542 m .54998 .56518 L .56153 .54713 L 1 g
F
P
p
.002 w
.56153 .54713 m .56232 .54863 L p
.5638 .54118 L 1 g
F P
s
P
p
.002 w
.56603 .53437 m .55648 .50915 L p
.57072 .51637 L 1 g
F P
s
P
p
.002 w
.56232 .54863 m .56257 .5491 L p
.56343 .54436 L 1 g
F P
s
P
p
.002 w
.5675 .52874 m .56854 .53025 L p
.56682 .5191 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56614 .50944 L p
1 g
F P
s
P
p
.56682 .5191 m .56854 .53025 L .56614 .50944 L 1 g
F
P
p
.002 w
.56614 .50944 m .56713 .51061 L p
.56344 .50356 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52273 .46764 L p
.51499 .4662 L 1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .51499 .4662 L 1 g
F
P
p
.51699 .46666 m .52273 .46764 L .51818 .46689 L 1 g
F
P
p
.5 .4634 m .52078 .46728 L .51699 .46666 L 1 g
F
P
p
.52078 .46728 m .52273 .46764 L .51699 .46666 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.50979 .4655 m .5093 .46636 L .50459 .46466 L p
1 g
F P
s
P
p
.002 w
.50459 .46466 m .5093 .46636 L p
.5 .4639 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4639 L p
1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .4634 L p
.51818 .46689 L 1 g
F P
s
P
p
.51818 .46689 m .52282 .46778 L .5 .4639 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4639 L p
1 g
F P
s
P
p
.002 w
.5 .4639 m .5 .46442 L p
.4887 .46557 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4639 L .4887 .46557 L 1 g
F
P
p
.002 w
.49196 .46009 m .50178 .46364 L p
.5 .4639 L 1 g
F P
s
P
p
.47753 .46721 m .48817 .46196 L .5 .4639 L 1 g
F
P
p
.48817 .46196 m .49196 .46009 L .5 .4639 L 1 g
F
P
p
.002 w
.51523 .45579 m .50979 .4655 L p
.47438 .45373 L 1 g
F P
s
P
p
.002 w
.50459 .46466 m .47438 .45373 L p
.50979 .4655 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.50979 .4655 m .51523 .45579 L .53161 .46843 L p
1 g
F P
s
P
p
.002 w
.50178 .46364 m .50459 .46466 L p
.5 .4639 L 1 g
F P
s
P
p
.002 w
.52273 .46764 m .52282 .46778 L p
.51818 .46689 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47753 .46721 L p
1 g
F P
s
P
p
.4887 .46557 m .5 .46442 L .47753 .46721 L 1 g
F
P
p
.44266 .49128 m .45766 .47674 L .47008 .47685 L 1 g
F
P
p
.002 w
.45843 .47599 m .45915 .47604 L p
.45766 .47674 L 1 g
F P
s
P
p
.002 w
.45915 .47604 m .47008 .47685 L p
.45766 .47674 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47727 .46765 L p
1 g
F P
s
P
p
.002 w
.47727 .46765 m .47718 .46778 L p
.47328 .46949 L 1 g
F P
s
P
p
.45826 .47608 m .47727 .46765 L .47328 .46949 L 1 g
F
P
p
.002 w
.4713 .47029 m .47438 .45373 L .49196 .46009 L p
1 g
F P
s
P
p
.46924 .47127 m .46998 .47094 L .45915 .47604 L 1 g
F
P
p
.46998 .47094 m .47328 .46949 L .46722 .47231 L 1 g
F
P
p
.46998 .47094 m .46722 .47231 L .45915 .47604 L 1 g
F
P
p
.46924 .47127 m .45915 .47604 L .45766 .47674 L 1 g
F
P
p
.002 w
.47438 .45373 m .4713 .47029 L p
.43425 .4742 L 1 g
F P
s
P
p
.002 w
.45915 .47604 m .43425 .4742 L p
.4713 .47029 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45766 .47674 L p
1 g
F P
s
P
p
.47328 .46949 m .47718 .46778 L .45766 .47674 L 1 g
F
P
p
.002 w
.45052 .4754 m .45843 .47599 L p
.45766 .47674 L 1 g
F P
s
P
p
.44266 .49128 m .44753 .48143 L .45766 .47674 L 1 g
F
P
p
.44753 .48143 m .45052 .4754 L .45766 .47674 L 1 g
F
P
p
.002 w
.45766 .47674 m .45698 .47747 L p
.44943 .48471 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44266 .49128 L p
1 g
F P
s
P
p
.44943 .48471 m .45698 .47747 L .44266 .49128 L 1 g
F
P
p
.43864 .4994 m .43872 .49921 L .43834 .50001 L 1 g
F
P
p
.43864 .4994 m .43834 .50001 L .43799 .50073 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.4395 .50734 m .43834 .50001 L p
.47008 .47685 L 1 g
F P
s
P
p
.002 w
.43443 .50818 m .40789 .51258 L p
.43834 .50001 L 1 g
F P
s
P
p
.002 w
.43386 .50944 m .43485 .50826 L p
.44043 .49491 L 1 g
F P
s
P
p
.002 w
.43834 .50001 m .4395 .50734 L .43443 .50818 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .44043 .49491 L p
.43799 .50073 L 1 g
F P
s
P
p
.43872 .49921 m .44166 .49233 L .43799 .50073 L 1 g
F
P
p
.002 w
.42748 .50933 m .43393 .50826 L p
.43386 .50944 L 1 g
F P
s
P
p
.42995 .51808 m .42748 .50933 L .43386 .50944 L 1 g
F
P
p
.43283 .52826 m .43386 .50944 L .4395 .50734 L 1 g
F
P
p
.002 w
.43393 .50826 m .43443 .50818 L p
.43386 .50944 L 1 g
F P
s
P
p
.002 w
.43443 .50818 m .4395 .50734 L p
.43386 .50944 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .44043 .49491 L p
.43993 .49417 L 1 g
F P
s
P
p
.002 w
.44043 .49491 m .44166 .49233 L .44152 .49248 L p
1 g
F P
s
P
p
.002 w
.44152 .49248 m .43993 .49417 L p
.44043 .49491 L 1 g
F P
s
P
p
.002 w
.44043 .49491 m .43287 .51061 L .43386 .50944 L p
1 g
F P
s
P
p
.43283 .52826 m .42995 .51808 L .43386 .50944 L 1 g
F
P
p
.002 w
.43386 .50944 m .43287 .51061 L p
.43324 .52087 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43283 .52826 L p
1 g
F P
s
P
p
.43324 .52087 m .43287 .51061 L .43283 .52826 L 1 g
F
P
p
.002 w
.43283 .52826 m .4317 .5299 L p
.4356 .53804 L 1 g
F P
s
P
p
.002 w
.42837 .5493 m .40789 .51258 L .42748 .50933 L p
1 g
F P
s
P
p
.43925 .54566 m .4317 .5299 L .43309 .53348 L 1 g
F
P
p
.002 w
.43752 .54485 m .45536 .53618 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.4317 .5299 m .43146 .53025 L p
.43309 .53348 L 1 g
F P
s
P
p
.002 w
.4395 .50734 m .45536 .53618 L .43752 .54485 L p
1 g
F P
s
P
p
.43341 .5303 m .4395 .50734 L .43752 .54485 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43844 .54719 L p
1 g
F P
s
P
p
.43309 .53348 m .43146 .53025 L .43844 .54719 L 1 g
F
P
p
.002 w
.43844 .54719 m .43743 .5491 L p
.44602 .55656 L 1 g
F P
s
P
p
.45894 .56846 m .45095 .56266 L .45536 .53618 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45095 .56266 L p
1 g
F P
s
P
p
.44602 .55656 m .43743 .5491 L .45095 .56266 L 1 g
F
P
p
.48772 .57972 m .46832 .57451 L .47991 .55766 L 1 g
F
P
p
.002 w
.46339 .57318 m .46428 .57235 L p
.46832 .57451 L 1 g
F P
s
P
p
.45979 .56908 m .46428 .57235 L .46832 .57451 L 1 g
F
P
p
.002 w
.46428 .57235 m .47991 .55766 L p
.46832 .57451 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46817 .57518 L p
1 g
F P
s
P
p
.002 w
.46817 .57518 m .46832 .57451 L p
.46475 .57269 L 1 g
F P
s
P
p
.46475 .57269 m .45002 .56518 L .46817 .57518 L 1 g
F
P
p
.45979 .56908 m .45343 .56654 L .46428 .57235 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45536 .53618 m .47991 .55766 L .46428 .57235 L p
1 g
F P
s
P
p
.45894 .56846 m .45536 .53618 L .46428 .57235 L 1 g
F
P
p
.45343 .56654 m .45002 .56518 L .46832 .57451 L 1 g
F
P
p
.48772 .57972 m .47542 .57831 L .46832 .57451 L 1 g
F
P
p
.002 w
.46832 .57451 m .4678 .57686 L p
.48118 .57796 L 1 g
F P
s
P
p
.002 w
.46602 .57892 m .45983 .57652 L p
.49241 .58025 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58009 L p
1 g
F P
s
P
p
.48118 .57796 m .4678 .57686 L .4891 .58009 L 1 g
F
P
p
.002 w
.4891 .58009 m .48895 .58213 L p
.49868 .58057 L 1 g
F P
s
P
p
.51079 .57862 m .48895 .58213 L .49623 .58153 L 1 g
F
P
p
.002 w
.50438 .58086 m .51036 .56962 L p
.51092 .58032 L 1 g
F P
s
P
p
.002 w
.48895 .58213 m .48889 .583 L p
.49623 .58153 L 1 g
F P
s
P
p
.002 w
.47991 .55766 m .51036 .56962 L .50438 .58086 L p
1 g
F P
s
P
p
.49241 .58025 m .47991 .55766 L .50438 .58086 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .58032 L p
1 g
F P
s
P
p
.49623 .58153 m .48889 .583 L .51092 .58032 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53166 .57439 L p
1 g
F P
s
P
p
.002 w
.53166 .57439 m .53128 .57265 L p
.52316 .57681 L 1 g
F P
s
P
p
.52316 .57681 m .51111 .583 L .53166 .57439 L 1 g
F
P
p
.52057 .57755 m .51036 .56962 L .5434 .57103 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54981 .5647 L p
1 g
F P
s
P
p
.5388 .57057 m .5322 .57686 L .54981 .5647 L 1 g
F
P
p
.002 w
.51036 .56962 m .52207 .54275 L p
.54164 .56865 L 1 g
F P
s
P
p
.002 w
.53842 .57077 m .51036 .56962 L p
.54164 .56865 L 1 g
F P
s
P
p
.5388 .57057 m .53842 .57077 L .5322 .57686 L 1 g
F
P
p
.002 w
.53166 .57439 m .53182 .57513 L p
.53842 .57077 L 1 g
F P
s
P
p
.002 w
.53182 .57513 m .5322 .57686 L p
.53842 .57077 L 1 g
F P
s
P
p
.53896 .57042 m .53842 .57077 L .5388 .57057 L 1 g
F
P
p
.002 w
.52207 .54275 m .5449 .54378 L .5436 .56735 L p
1 g
F P
s
P
p
.54164 .56865 m .52207 .54275 L .5436 .56735 L 1 g
F
P
p
.002 w
.51092 .58032 m .51111 .583 L p
.52316 .57681 L 1 g
F P
s
P
p
.002 w
.38479 .34938 m .35623 .40159 L .33723 .39056 L p
1 g
F P
s
P
p
.002 w
.33723 .39056 m .36786 .33437 L .38479 .34938 L p
1 g
F P
s
P
p
.002 w
.63564 .34554 m .59454 .31759 L .59651 .29403 L p
1 g
F P
s
P
p
.002 w
.54141 .2797 m .59651 .29403 L .59454 .31759 L p
1 g
F P
s
P
p
.002 w
.37136 .46513 m .37981 .51522 L .35613 .51527 L p
1 g
F P
s
P
p
.002 w
.35613 .51527 m .34643 .45914 L .37136 .46513 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.48327 .28468 m .42888 .3088 L .41529 .29072 L p
1 g
F P
s
P
p
.002 w
.36786 .33437 m .41529 .29072 L .42888 .3088 L p
1 g
F P
s
P
p
.002 w
.42888 .3088 m .38479 .34938 L .36786 .33437 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.63657 .48522 m .63796 .45216 L .66077 .44236 L p
1 g
F P
s
P
p
.002 w
.649 .4024 m .66077 .44236 L .63796 .45216 L p
1 g
F P
s
P
p
.002 w
.649 .4024 m .62449 .36878 L .63564 .34554 L p
1 g
F P
s
P
p
.002 w
.59454 .31759 m .63564 .34554 L .62449 .36878 L p
1 g
F P
s
P
p
.002 w
.40789 .51258 m .42837 .5493 L .40425 .55852 L p
1 g
F P
s
P
p
.002 w
.40425 .55852 m .37981 .51522 L .40789 .51258 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.59454 .31759 m .54535 .305 L .54141 .2797 L p
1 g
F P
s
P
p
.002 w
.48327 .28468 m .54141 .2797 L .54535 .305 L p
1 g
F P
s
P
p
.002 w
.38026 .41385 m .37136 .46513 L .34643 .45914 L p
1 g
F P
s
P
p
.002 w
.34643 .45914 m .35623 .40159 L .38026 .41385 L p
1 g
F P
s
P
p
.002 w
.5672 .53744 m .58664 .52443 L .60365 .54294 L p
1 g
F P
s
P
p
.002 w
.60365 .54294 m .5756 .56174 L .5672 .53744 L p
1 g
F P
s
P
p
.002 w
.6247 .51654 m .60365 .54294 L .58664 .52443 L p
1 g
F P
s
P
p
.002 w
.63796 .45216 m .62857 .42082 L .649 .4024 L p
1 g
F P
s
P
p
.002 w
.62449 .36878 m .649 .4024 L .62857 .42082 L p
1 g
F P
s
P
p
.002 w
.58664 .52443 m .60121 .50613 L .6247 .51654 L p
1 g
F P
s
P
p
.002 w
.63657 .48522 m .6247 .51654 L .60121 .50613 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62449 .36878 m .58962 .34532 L .59454 .31759 L p
1 g
F P
s
P
p
.002 w
.54535 .305 m .59454 .31759 L .58962 .34532 L p
1 g
F P
s
P
p
.002 w
.60121 .50613 m .60938 .48443 L .63657 .48522 L p
1 g
F P
s
P
p
.002 w
.63796 .45216 m .63657 .48522 L .60938 .48443 L p
1 g
F P
s
P
p
.002 w
.40095 .47023 m .40789 .51258 L .37981 .51522 L p
1 g
F P
s
P
p
.002 w
.37981 .51522 m .37136 .46513 L .40095 .47023 L p
1 g
F P
s
P
p
.002 w
.54535 .305 m .49353 .30961 L .48327 .28468 L p
1 g
F P
s
P
p
.002 w
.42888 .3088 m .48327 .28468 L .49353 .30961 L p
1 g
F P
s
P
p
.002 w
.40579 .36736 m .38026 .41385 L .35623 .40159 L p
1 g
F P
s
P
p
.002 w
.35623 .40159 m .38479 .34938 L .40579 .36736 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.49353 .30961 m .44509 .33119 L .42888 .3088 L p
1 g
F P
s
P
p
.002 w
.38479 .34938 m .42888 .3088 L .44509 .33119 L p
1 g
F P
s
P
p
.002 w
.44509 .33119 m .40579 .36736 L .38479 .34938 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60938 .48443 m .61025 .46158 L .63796 .45216 L p
1 g
F P
s
P
p
.002 w
.62857 .42082 m .63796 .45216 L .61025 .46158 L p
1 g
F P
s
P
p
.002 w
.50111 .53439 m .52207 .54275 L .51036 .56962 L p
1 g
F P
s
P
p
.002 w
.51036 .56962 m .47991 .55766 L .50111 .53439 L p
1 g
F P
s
P
p
.002 w
.62857 .42082 m .60921 .39457 L .62449 .36878 L p
1 g
F P
s
P
p
.002 w
.58962 .34532 m .62449 .36878 L .60921 .39457 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.58962 .34532 m .548 .33488 L .54535 .305 L p
1 g
F P
s
P
p
.002 w
.49353 .30961 m .54535 .305 L .548 .33488 L p
1 g
F P
s
P
p
.002 w
.40862 .42696 m .40095 .47023 L .37136 .46513 L p
1 g
F P
s
P
p
.002 w
.37136 .46513 m .38026 .41385 L .40862 .42696 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61025 .46158 m .60365 .44 L .62857 .42082 L p
1 g
F P
s
P
p
.002 w
.60921 .39457 m .62857 .42082 L .60365 .44 L p
1 g
F P
s
P
p
.002 w
.48431 .5195 m .50111 .53439 L .47991 .55766 L p
1 g
F P
s
P
p
.002 w
.47991 .55766 m .45536 .53618 L .48431 .5195 L p
1 g
F P
s
P
p
.002 w
.60121 .50613 m .58664 .52443 L .56647 .50249 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.56647 .50249 m .57394 .49309 L .60121 .50613 L p
1 g
F P
s
P
p
.002 w
.60938 .48443 m .60121 .50613 L .57394 .49309 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.548 .33488 m .58962 .34532 L .5818 .37636 L p
1 g
F P
s
P
p
.002 w
.60921 .39457 m .5818 .37636 L .58962 .34532 L p
1 g
F P
s
P
p
.002 w
.40789 .51258 m .40095 .47023 L .43425 .4742 L p
1 g
F P
s
P
p
.002 w
.57394 .49309 m .57809 .48195 L .60938 .48443 L p
1 g
F P
s
P
p
.002 w
.61025 .46158 m .60938 .48443 L .57809 .48195 L p
1 g
F P
s
P
p
.002 w
.53335 .51179 m .54504 .51237 L .5449 .54378 L p
1 g
F P
s
P
p
.002 w
.5449 .54378 m .52207 .54275 L .53335 .51179 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.548 .33488 m .50426 .33893 L .49353 .30961 L p
1 g
F P
s
P
p
.002 w
.44509 .33119 m .49353 .30961 L .50426 .33893 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.43024 .38775 m .40862 .42696 L .38026 .41385 L p
1 g
F P
s
P
p
.002 w
.38026 .41385 m .40579 .36736 L .43024 .38775 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.60365 .44 m .59021 .42202 L .60921 .39457 L p
1 g
F P
s
P
p
.002 w
.5818 .37636 m .60921 .39457 L .59021 .42202 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.47355 .49961 m .48431 .5195 L .45536 .53618 L p
1 g
F P
s
P
p
.002 w
.45536 .53618 m .4395 .50734 L .47355 .49961 L p
1 g
F P
s
P
p
.002 w
.57809 .48195 m .57848 .47025 L .61025 .46158 L p
1 g
F P
s
P
p
.002 w
.60365 .44 m .61025 .46158 L .57848 .47025 L p
1 g
F P
s
P
p
.002 w
.52268 .50745 m .53335 .51179 L .52207 .54275 L p
1 g
F P
s
P
p
.002 w
.52207 .54275 m .50111 .53439 L .52268 .50745 L p
1 g
F P
s
P
p
.002 w
.50426 .33893 m .46341 .35723 L .44509 .33119 L p
1 g
F P
s
P
p
.002 w
.40579 .36736 m .44509 .33119 L .46341 .35723 L p
1 g
F P
s
P
p
.002 w
.46341 .35723 m .43024 .38775 L .40579 .36736 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5818 .37636 m .54922 .36838 L .548 .33488 L p
1 g
F P
s
P
p
.002 w
.50426 .33893 m .548 .33488 L .54922 .36838 L p
1 g
F P
s
P
p
.002 w
.44038 .44042 m .43425 .4742 L .40095 .47023 L p
1 g
F P
s
P
p
.002 w
.40095 .47023 m .40862 .42696 L .44038 .44042 L p
1 g
F P
s
P
p
.002 w
.57848 .47025 m .57505 .45925 L .60365 .44 L p
1 g
F P
s
P
p
.002 w
.59021 .42202 m .60365 .44 L .57505 .45925 L p
1 g
F P
s
P
p
.002 w
.51417 .4998 m .52268 .50745 L .50111 .53439 L p
1 g
F P
s
P
p
.002 w
.50111 .53439 m .48431 .5195 L .51417 .4998 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.54922 .36838 m .5818 .37636 L .5713 .40964 L p
1 g
F P
s
P
p
.002 w
.59021 .42202 m .5713 .40964 L .5818 .37636 L p
1 g
F P
s
P
p
.002 w
.47008 .47685 m .47355 .49961 L .4395 .50734 L p
1 g
F P
s
P
p
.002 w
.57809 .48195 m .57394 .49309 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57848 .47025 m .57809 .48195 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.54922 .36838 m .51507 .37168 L .50426 .33893 L p
1 g
F P
s
P
p
.002 w
.46341 .35723 m .50426 .33893 L .51507 .37168 L p
1 g
F P
s
P
p
.002 w
.45733 .40986 m .44038 .44042 L .40862 .42696 L p
1 g
F P
s
P
p
.002 w
.40862 .42696 m .43024 .38775 L .45733 .40986 L p
1 g
F P
s
P
p
.002 w
.57505 .45925 m .56813 .45013 L .59021 .42202 L p
1 g
F P
s
P
p
.002 w
.5713 .40964 m .59021 .42202 L .56813 .45013 L p
1 g
F P
s
P
p
.002 w
.50876 .48965 m .51417 .4998 L .48431 .5195 L p
1 g
F P
s
P
p
.002 w
.48431 .5195 m .47355 .49961 L .50876 .48965 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.57505 .45925 m .57848 .47025 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.51507 .37168 m .48321 .38603 L .46341 .35723 L p
1 g
F P
s
P
p
.002 w
.43024 .38775 m .46341 .35723 L .48321 .38603 L p
1 g
F P
s
P
p
.002 w
.48321 .38603 m .45733 .40986 L .43024 .38775 L p
1 g
F P
s
P
p
.002 w
.56813 .45013 m .57505 .45925 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.5713 .40964 m .54892 .40429 L .54922 .36838 L p
1 g
F P
s
P
p
.002 w
.51507 .37168 m .54922 .36838 L .54892 .40429 L p
1 g
F P
s
P
p
.002 w
.43425 .4742 m .44038 .44042 L .47438 .45373 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54892 .40429 m .5713 .40964 L .55846 .4439 L p
1 g
F P
s
P
p
.002 w
.56813 .45013 m .55846 .4439 L .5713 .40964 L p
1 g
F P
s
P
p
.002 w
.50707 .47808 m .50876 .48965 L .47355 .49961 L p
1 g
F P
s
P
p
.002 w
.47355 .49961 m .47008 .47685 L .50707 .47808 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55846 .4439 m .56813 .45013 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54708 .44125 m .55846 .4439 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.53522 .44251 m .54708 .44125 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.5242 .44754 m .53522 .44251 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.002 w
.51523 .45579 m .5242 .44754 L .54378 .47782 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51964 .45173 L
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54892 .40429 m .52553 .40666 L .51507 .37168 L p
1 g
F P
s
P
p
.002 w
.48321 .38603 m .51507 .37168 L .52553 .40666 L p
1 g
F P
s
P
p
.002 w
.48603 .43284 m .47438 .45373 L .44038 .44042 L p
1 g
F P
s
P
p
.002 w
.44038 .44042 m .45733 .40986 L .48603 .43284 L p
1 g
F P
s
P
p
.002 w
.55846 .4439 m .54708 .44125 L .54892 .40429 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52553 .40666 m .54892 .40429 L .54708 .44125 L p
1 g
F P
s
P
p
.002 w
.5093 .46636 m .50707 .47808 L .47008 .47685 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.004 w
.54378 .47782 m
.54519 .47934 L
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54708 .44125 m .53522 .44251 L .52553 .40666 L p
1 g
F P
s
P
p
.002 w
.52553 .40666 m .50374 .41653 L .48321 .38603 L p
1 g
F P
s
P
p
.002 w
.45733 .40986 m .48321 .38603 L .50374 .41653 L p
1 g
F P
s
P
p
.002 w
.50374 .41653 m .48603 .43284 L .45733 .40986 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53522 .44251 m .5242 .44754 L .50374 .41653 L p
1 g
F P
s
P
p
.002 w
.50374 .41653 m .52553 .40666 L .53522 .44251 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47438 .45373 m .48603 .43284 L .51523 .45579 L p
1 g
F P
s
P
p
.002 w
.5242 .44754 m .51523 .45579 L .48603 .43284 L p
1 g
F P
s
P
p
.002 w
.48603 .43284 m .50374 .41653 L .5242 .44754 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.54519 .47934 m
.57077 .50698 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .74003 .29767 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57077 .50698 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.499225)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.499225)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48293 .48009 m .51399 .46415 L .49733 .44111 L p
1 g
F P
s
P
p
.002 w
.49733 .44111 m .4733 .45338 L .48293 .48009 L p
1 g
F P
s
P
p
.002 w
.5168 .42226 m .49733 .44111 L .51399 .46415 L p
1 g
F P
s
P
p
.002 w
.4733 .45338 m .49733 .44111 L .48075 .41785 L p
1 g
F P
s
P
p
.002 w
.49733 .44111 m .5168 .42226 L .49404 .40497 L p
1 g
F P
s
P
p
.002 w
.49404 .40497 m .48075 .41785 L .49733 .44111 L p
1 g
F P
s
P
p
.002 w
.51399 .46415 m .53919 .43977 L .5168 .42226 L p
1 g
F P
s
P
p
.002 w
.52974 .39872 m .5168 .42226 L .53919 .43977 L p
1 g
F P
s
P
p
.002 w
.5168 .42226 m .52974 .39872 L .50282 .38888 L p
1 g
F P
s
P
p
.002 w
.50282 .38888 m .49404 .40497 L .5168 .42226 L p
1 g
F P
s
P
p
.002 w
.48075 .41785 m .46433 .42619 L .4733 .45338 L p
1 g
F P
s
P
p
.002 w
.46433 .42619 m .48075 .41785 L .46457 .39479 L p
1 g
F P
s
P
p
.002 w
.48075 .41785 m .49404 .40497 L .47132 .38823 L p
1 g
F P
s
P
p
.002 w
.47132 .38823 m .46457 .39479 L .48075 .41785 L p
1 g
F P
s
P
p
.002 w
.49404 .40497 m .50282 .38888 L .47576 .38003 L p
1 g
F P
s
P
p
.002 w
.47576 .38003 m .47132 .38823 L .49404 .40497 L p
1 g
F P
s
P
p
.002 w
.44906 .48596 m .48293 .48009 L .4733 .45338 L p
1 g
F P
s
P
p
.002 w
.4733 .45338 m .44712 .45778 L .44906 .48596 L p
1 g
F P
s
P
p
.002 w
.44712 .45778 m .4733 .45338 L .46433 .42619 L p
1 g
F P
s
P
p
.002 w
.46433 .42619 m .44647 .4291 L .44712 .45778 L p
1 g
F P
s
P
p
.002 w
.44647 .4291 m .46433 .42619 L .4562 .39901 L p
1 g
F P
s
P
p
.002 w
.46457 .39479 m .4562 .39901 L .46433 .42619 L p
1 g
F P
s
P
p
.002 w
.49308 .50584 m .53044 .48655 L .51399 .46415 L p
1 g
F P
s
P
p
.002 w
.51399 .46415 m .48293 .48009 L .49308 .50584 L p
1 g
F P
s
P
p
.002 w
.53919 .43977 m .51399 .46415 L .53044 .48655 L p
1 g
F P
s
P
p
.002 w
.53044 .48655 m .56081 .45721 L .53919 .43977 L p
1 g
F P
s
P
p
.002 w
.55603 .40936 m .53919 .43977 L .56081 .45721 L p
1 g
F P
s
P
p
.002 w
.53919 .43977 m .55603 .40936 L .52974 .39872 L p
1 g
F P
s
P
p
.002 w
.50615 .37123 m .50282 .38888 L .52974 .39872 L p
1 g
F P
s
P
p
.002 w
.50282 .38888 m .50615 .37123 L .4774 .37106 L p
1 g
F P
s
P
p
.002 w
.4774 .37106 m .47576 .38003 L .50282 .38888 L p
1 g
F P
s
P
p
.002 w
.53478 .37285 m .52974 .39872 L .55603 .40936 L p
1 g
F P
s
P
p
.002 w
.52974 .39872 m .53478 .37285 L .50615 .37123 L p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .4562 .39901 L .46457 .39479 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .46457 .39479 L .47132 .38823 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .47132 .38823 L .47576 .38003 L closepath p
1 g
F P
s
P
p
.002 w
.45228 .51311 m .49308 .50584 L .48293 .48009 L p
1 g
F P
s
P
p
.002 w
.48293 .48009 m .44906 .48596 L .45228 .51311 L p
1 g
F P
s
P
p
.002 w
.42145 .45376 m .44712 .45778 L .44647 .4291 L p
1 g
F P
s
P
p
.002 w
.44647 .4291 m .42902 .42624 L .42145 .45376 L p
1 g
F P
s
P
p
.002 w
.42902 .42624 m .44647 .4291 L .44712 .40044 L p
1 g
F P
s
P
p
.002 w
.4562 .39901 m .44712 .40044 L .44647 .4291 L p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .44712 .40044 L .4562 .39901 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .47576 .38003 L .4774 .37106 L closepath p
1 g
F P
s
P
p
.002 w
.41574 .48097 m .44906 .48596 L .44712 .45778 L p
1 g
F P
s
P
p
.002 w
.44712 .45778 m .42145 .45376 L .41574 .48097 L p
1 g
F P
s
P
p
.002 w
.50363 .35386 m .50615 .37123 L .53478 .37285 L p
1 g
F P
s
P
p
.002 w
.50615 .37123 m .50363 .35386 L .47606 .36227 L p
1 g
F P
s
P
p
.002 w
.47606 .36227 m .4774 .37106 L .50615 .37123 L p
1 g
F P
s
P
p
.002 w
.56081 .45721 m .58122 .42063 L .55603 .40936 L p
1 g
F P
s
P
p
.002 w
.56275 .37588 m .55603 .40936 L .58122 .42063 L p
1 g
F P
s
P
p
.002 w
.55603 .40936 m .56275 .37588 L .53478 .37285 L p
1 g
F P
s
P
p
.002 w
.44712 .40044 m .43828 .39893 L .42902 .42624 L p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .43828 .39893 L .44712 .40044 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .4774 .37106 L .47606 .36227 L closepath p
1 g
F P
s
P
p
.002 w
.50354 .53013 m .54639 .5079 L .53044 .48655 L p
1 g
F P
s
P
p
.002 w
.53044 .48655 m .49308 .50584 L .50354 .53013 L p
1 g
F P
s
P
p
.002 w
.56081 .45721 m .53044 .48655 L .54639 .5079 L p
1 g
F P
s
P
p
.002 w
.54639 .5079 m .58125 .47423 L .56081 .45721 L p
1 g
F P
s
P
p
.002 w
.58122 .42063 m .56081 .45721 L .58125 .47423 L p
1 g
F P
s
P
p
.002 w
.53127 .34728 m .53478 .37285 L .56275 .37588 L p
1 g
F P
s
P
p
.002 w
.53478 .37285 m .53127 .34728 L .50363 .35386 L p
1 g
F P
s
P
p
.002 w
.41383 .41782 m .42902 .42624 L .43828 .39893 L p
1 g
F P
s
P
p
.002 w
.43828 .39893 m .43063 .3946 L .41383 .41782 L p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .43063 .3946 L .43828 .39893 L closepath p
1 g
F P
s
P
p
.002 w
.39899 .44157 m .42145 .45376 L .42902 .42624 L p
1 g
F P
s
P
p
.002 w
.42902 .42624 m .41383 .41782 L .39899 .44157 L p
1 g
F P
s
P
p
.002 w
.47185 .35459 m .47606 .36227 L .50363 .35386 L p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .47606 .36227 L .47185 .35459 L closepath p
1 g
F P
s
P
p
.002 w
.41204 .50736 m .45228 .51311 L .44906 .48596 L p
1 g
F P
s
P
p
.002 w
.44906 .48596 m .41574 .48097 L .41204 .50736 L p
1 g
F P
s
P
p
.002 w
.45673 .53868 m .50354 .53013 L .49308 .50584 L p
1 g
F P
s
P
p
.002 w
.49308 .50584 m .45228 .51311 L .45673 .53868 L p
1 g
F P
s
P
p
.002 w
.49544 .33861 m .50363 .35386 L .53127 .34728 L p
1 g
F P
s
P
p
.002 w
.50363 .35386 m .49544 .33861 L .47185 .35459 L p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .47185 .35459 L .46521 .34888 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .46521 .34888 L .45684 .34577 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .45684 .34577 L .44766 .34563 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .44766 .34563 L .43866 .34848 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .43866 .34848 L .43086 .35402 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .43086 .35402 L .42512 .36163 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .42512 .36163 L .42207 .37048 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .42207 .37048 L .42204 .37958 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .42204 .37958 L .425 .38792 L closepath p
1 g
F P
s
P
p
.002 w
.44907 .37234 m .425 .38792 L .43063 .3946 L closepath p
1 g
F P
s
P
p
.002 w
.40257 .40468 m .41383 .41782 L .43063 .3946 L p
1 g
F P
s
P
p
.002 w
.43063 .3946 m .425 .38792 L .40257 .40468 L p
1 g
F P
s
P
p
.002 w
.46521 .34888 m .47185 .35459 L .49544 .33861 L p
1 g
F P
s
P
p
.002 w
.58125 .47423 m .60481 .43232 L .58122 .42063 L p
1 g
F P
s
P
p
.002 w
.58954 .3803 m .58122 .42063 L .60481 .43232 L p
1 g
F P
s
P
p
.002 w
.58122 .42063 m .58954 .3803 L .56275 .37588 L p
1 g
F P
s
P
p
.002 w
.38645 .46539 m .41574 .48097 L .42145 .45376 L p
1 g
F P
s
P
p
.002 w
.42145 .45376 m .39899 .44157 L .38645 .46539 L p
1 g
F P
s
P
p
.002 w
.55845 .34268 m .56275 .37588 L .58954 .3803 L p
1 g
F P
s
P
p
.002 w
.56275 .37588 m .55845 .34268 L .53127 .34728 L p
1 g
F P
s
P
p
.002 w
.39655 .38818 m .40257 .40468 L .425 .38792 L p
1 g
F P
s
P
p
.002 w
.425 .38792 m .42204 .37958 L .39655 .38818 L p
1 g
F P
s
P
p
.002 w
.38223 .42234 m .39899 .44157 L .41383 .41782 L p
1 g
F P
s
P
p
.002 w
.41383 .41782 m .40257 .40468 L .38223 .42234 L p
1 g
F P
s
P
p
.002 w
.49544 .33861 m .48238 .32718 L .46521 .34888 L p
1 g
F P
s
P
p
.002 w
.45684 .34577 m .46521 .34888 L .48238 .32718 L p
1 g
F P
s
P
p
.002 w
.51941 .32473 m .53127 .34728 L .55845 .34268 L p
1 g
F P
s
P
p
.002 w
.53127 .34728 m .51941 .32473 L .49544 .33861 L p
1 g
F P
s
P
p
.002 w
.51414 .55245 m .5615 .52775 L .54639 .5079 L p
1 g
F P
s
P
p
.002 w
.54639 .5079 m .50354 .53013 L .51414 .55245 L p
1 g
F P
s
P
p
.002 w
.58125 .47423 m .54639 .5079 L .5615 .52775 L p
1 g
F P
s
P
p
.002 w
.48238 .32718 m .49544 .33861 L .51941 .32473 L p
1 g
F P
s
P
p
.002 w
.5615 .52775 m .60009 .49052 L .58125 .47423 L p
1 g
F P
s
P
p
.002 w
.60481 .43232 m .58125 .47423 L .60009 .49052 L p
1 g
F P
s
P
p
.002 w
.3965 .37008 m .39655 .38818 L .42204 .37958 L p
1 g
F P
s
P
p
.002 w
.42204 .37958 m .42207 .37048 L .3965 .37008 L p
1 g
F P
s
P
p
.002 w
.48238 .32718 m .46581 .32088 L .45684 .34577 L p
1 g
F P
s
P
p
.002 w
.44766 .34563 m .45684 .34577 L .46581 .32088 L p
1 g
F P
s
P
p
.002 w
.41046 .53237 m .45673 .53868 L .45228 .51311 L p
1 g
F P
s
P
p
.002 w
.45228 .51311 m .41204 .50736 L .41046 .53237 L p
1 g
F P
s
P
p
.002 w
.37651 .48881 m .41204 .50736 L .41574 .48097 L p
1 g
F P
s
P
p
.002 w
.41574 .48097 m .38645 .46539 L .37651 .48881 L p
1 g
F P
s
P
p
.002 w
.40252 .35241 m .3965 .37008 L .42207 .37048 L p
1 g
F P
s
P
p
.002 w
.42207 .37048 m .42512 .36163 L .40252 .35241 L p
1 g
F P
s
P
p
.002 w
.46238 .56213 m .51414 .55245 L .50354 .53013 L p
1 g
F P
s
P
p
.002 w
.50354 .53013 m .45673 .53868 L .46238 .56213 L p
1 g
F P
s
P
p
.002 w
.46581 .32088 m .44752 .32049 L .44766 .34563 L p
1 g
F P
s
P
p
.002 w
.43866 .34848 m .44766 .34563 L .44752 .32049 L p
1 g
F P
s
P
p
.002 w
.37314 .39801 m .38223 .42234 L .40257 .40468 L p
1 g
F P
s
P
p
.002 w
.40257 .40468 m .39655 .38818 L .37314 .39801 L p
1 g
F P
s
P
p
.002 w
.36444 .44055 m .38645 .46539 L .39899 .44157 L p
1 g
F P
s
P
p
.002 w
.39899 .44157 m .38223 .42234 L .36444 .44055 L p
1 g
F P
s
P
p
.002 w
.41396 .33718 m .40252 .35241 L .42512 .36163 L p
1 g
F P
s
P
p
.002 w
.42512 .36163 m .43086 .35402 L .41396 .33718 L p
1 g
F P
s
P
p
.002 w
.44752 .32049 m .42956 .32612 L .43866 .34848 L p
1 g
F P
s
P
p
.002 w
.43086 .35402 m .43866 .34848 L .42956 .32612 L p
1 g
F P
s
P
p
.002 w
.60481 .43232 m .6146 .38605 L .58954 .3803 L p
1 g
F P
s
P
p
.002 w
.58464 .34019 m .58954 .3803 L .6146 .38605 L p
1 g
F P
s
P
p
.002 w
.58954 .3803 m .58464 .34019 L .55845 .34268 L p
1 g
F P
s
P
p
.002 w
.42956 .32612 m .41396 .33718 L .43086 .35402 L p
1 g
F P
s
P
p
.002 w
.60009 .49052 m .62628 .44421 L .60481 .43232 L p
1 g
F P
s
P
p
.002 w
.6146 .38605 m .60481 .43232 L .62628 .44421 L p
1 g
F P
s
P
p
.002 w
.51941 .32473 m .50028 .30769 L .48238 .32718 L p
1 g
F P
s
P
p
.002 w
.46581 .32088 m .48238 .32718 L .50028 .30769 L p
1 g
F P
s
P
p
.002 w
.54328 .31325 m .55845 .34268 L .58464 .34019 L p
1 g
F P
s
P
p
.002 w
.55845 .34268 m .54328 .31325 L .51941 .32473 L p
1 g
F P
s
P
p
.002 w
.50028 .30769 m .51941 .32473 L .54328 .31325 L p
1 g
F P
s
P
p
.002 w
.37292 .37119 m .37314 .39801 L .39655 .38818 L p
1 g
F P
s
P
p
.002 w
.39655 .38818 m .3965 .37008 L .37292 .37119 L p
1 g
F P
s
P
p
.002 w
.50028 .30769 m .47583 .2982 L .46581 .32088 L p
1 g
F P
s
P
p
.002 w
.44752 .32049 m .46581 .32088 L .47583 .2982 L p
1 g
F P
s
P
p
.002 w
.52466 .57228 m .57545 .54568 L .5615 .52775 L p
1 g
F P
s
P
p
.002 w
.5615 .52775 m .51414 .55245 L .52466 .57228 L p
1 g
F P
s
P
p
.002 w
.60009 .49052 m .5615 .52775 L .57545 .54568 L p
1 g
F P
s
P
p
.002 w
.41112 .55544 m .46238 .56213 L .45673 .53868 L p
1 g
F P
s
P
p
.002 w
.45673 .53868 m .41046 .53237 L .41112 .55544 L p
1 g
F P
s
P
p
.002 w
.57545 .54568 m .6169 .50572 L .60009 .49052 L p
1 g
F P
s
P
p
.002 w
.62628 .44421 m .60009 .49052 L .6169 .50572 L p
1 g
F P
s
P
p
.002 w
.36947 .51133 m .41046 .53237 L .41204 .50736 L p
1 g
F P
s
P
p
.002 w
.41204 .50736 m .37651 .48881 L .36947 .51133 L p
1 g
F P
s
P
p
.002 w
.35237 .40891 m .36444 .44055 L .38223 .42234 L p
1 g
F P
s
P
p
.002 w
.38223 .42234 m .37314 .39801 L .35237 .40891 L p
1 g
F P
s
P
p
.002 w
.34966 .45896 m .37651 .48881 L .38645 .46539 L p
1 g
F P
s
P
p
.002 w
.38645 .46539 m .36444 .44055 L .34966 .45896 L p
1 g
F P
s
P
p
.002 w
.38177 .34491 m .37292 .37119 L .3965 .37008 L p
1 g
F P
s
P
p
.002 w
.3965 .37008 m .40252 .35241 L .38177 .34491 L p
1 g
F P
s
P
p
.002 w
.47583 .2982 m .4487 .29749 L .44752 .32049 L p
1 g
F P
s
P
p
.002 w
.42956 .32612 m .44752 .32049 L .4487 .29749 L p
1 g
F P
s
P
p
.002 w
.46914 .58288 m .52466 .57228 L .51414 .55245 L p
1 g
F P
s
P
p
.002 w
.51414 .55245 m .46238 .56213 L .46914 .58288 L p
1 g
F P
s
P
p
.002 w
.54328 .31325 m .51856 .29088 L .50028 .30769 L p
1 g
F P
s
P
p
.002 w
.47583 .2982 m .50028 .30769 L .51856 .29088 L p
1 g
F P
s
P
p
.002 w
.62628 .44421 m .63737 .39307 L .6146 .38605 L p
1 g
F P
s
P
p
.002 w
.60927 .33993 m .6146 .38605 L .63737 .39307 L p
1 g
F P
s
P
p
.002 w
.6146 .38605 m .60927 .33993 L .58464 .34019 L p
1 g
F P
s
P
p
.002 w
.56658 .30448 m .58464 .34019 L .60927 .33993 L p
1 g
F P
s
P
p
.002 w
.58464 .34019 m .56658 .30448 L .54328 .31325 L p
1 g
F P
s
P
p
.002 w
.39876 .32223 m .38177 .34491 L .40252 .35241 L p
1 g
F P
s
P
p
.002 w
.40252 .35241 m .41396 .33718 L .39876 .32223 L p
1 g
F P
s
P
p
.002 w
.51856 .29088 m .54328 .31325 L .56658 .30448 L p
1 g
F P
s
P
p
.002 w
.4487 .29749 m .42198 .30579 L .42956 .32612 L p
1 g
F P
s
P
p
.002 w
.41396 .33718 m .42956 .32612 L .42198 .30579 L p
1 g
F P
s
P
p
.002 w
.42198 .30579 m .39876 .32223 L .41396 .33718 L p
1 g
F P
s
P
p
.002 w
.6169 .50572 m .64514 .45608 L .62628 .44421 L p
1 g
F P
s
P
p
.002 w
.63737 .39307 m .62628 .44421 L .64514 .45608 L p
1 g
F P
s
P
p
.002 w
.35191 .37385 m .35237 .40891 L .37314 .39801 L p
1 g
F P
s
P
p
.002 w
.37314 .39801 m .37292 .37119 L .35191 .37385 L p
1 g
F P
s
P
p
.002 w
.51856 .29088 m .48673 .27829 L .47583 .2982 L p
1 g
F P
s
P
p
.002 w
.4487 .29749 m .47583 .2982 L .48673 .27829 L p
1 g
F P
s
P
p
.002 w
.36559 .53242 m .41112 .55544 L .41046 .53237 L p
1 g
F P
s
P
p
.002 w
.41046 .53237 m .36947 .51133 L .36559 .53242 L p
1 g
F P
s
P
p
.002 w
.33479 .42069 m .34966 .45896 L .36444 .44055 L p
1 g
F P
s
P
p
.002 w
.36444 .44055 m .35237 .40891 L .33479 .42069 L p
1 g
F P
s
P
p
.002 w
.33832 .47717 m .36947 .51133 L .37651 .48881 L p
1 g
F P
s
P
p
.002 w
.37651 .48881 m .34966 .45896 L .33832 .47717 L p
1 g
F P
s
P
p
.002 w
.41411 .57597 m .46914 .58288 L .46238 .56213 L p
1 g
F P
s
P
p
.002 w
.46238 .56213 m .41112 .55544 L .41411 .57597 L p
1 g
F P
s
P
p
.002 w
.53488 .5891 m .58791 .56121 L .57545 .54568 L p
1 g
F P
s
P
p
.002 w
.57545 .54568 m .52466 .57228 L .53488 .5891 L p
1 g
F P
s
P
p
.002 w
.6169 .50572 m .57545 .54568 L .58791 .56121 L p
1 g
F P
s
P
p
.002 w
.58791 .56121 m .63124 .51947 L .6169 .50572 L p
1 g
F P
s
P
p
.002 w
.64514 .45608 m .6169 .50572 L .63124 .51947 L p
1 g
F P
s
P
p
.002 w
.36339 .33938 m .35191 .37385 L .37292 .37119 L p
1 g
F P
s
P
p
.002 w
.37292 .37119 m .38177 .34491 L .36339 .33938 L p
1 g
F P
s
P
p
.002 w
.56658 .30448 m .53685 .27719 L .51856 .29088 L p
1 g
F P
s
P
p
.002 w
.48673 .27829 m .51856 .29088 L .53685 .27719 L p
1 g
F P
s
P
p
.002 w
.63737 .39307 m .63178 .34197 L .60927 .33993 L p
1 g
F P
s
P
p
.002 w
.5888 .29871 m .60927 .33993 L .63178 .34197 L p
1 g
F P
s
P
p
.002 w
.60927 .33993 m .5888 .29871 L .56658 .30448 L p
1 g
F P
s
P
p
.002 w
.64514 .45608 m .65727 .40124 L .63737 .39307 L p
1 g
F P
s
P
p
.002 w
.63178 .34197 m .63737 .39307 L .65727 .40124 L p
1 g
F P
s
P
p
.002 w
.53685 .27719 m .56658 .30448 L .5888 .29871 L p
1 g
F P
s
P
p
.002 w
.48673 .27829 m .45124 .2772 L .4487 .29749 L p
1 g
F P
s
P
p
.002 w
.42198 .30579 m .4487 .29749 L .45124 .2772 L p
1 g
F P
s
P
p
.002 w
.47693 .60035 m .53488 .5891 L .52466 .57228 L p
1 g
F P
s
P
p
.002 w
.52466 .57228 m .46914 .58288 L .47693 .60035 L p
1 g
F P
s
P
p
.002 w
.38567 .30957 m .36339 .33938 L .38177 .34491 L p
1 g
F P
s
P
p
.002 w
.38177 .34491 m .39876 .32223 L .38567 .30957 L p
1 g
F P
s
P
p
.002 w
.45124 .2772 m .41616 .288 L .42198 .30579 L p
1 g
F P
s
P
p
.002 w
.39876 .32223 m .42198 .30579 L .41616 .288 L p
1 g
F P
s
P
p
.002 w
.63124 .51947 m .66086 .46767 L .64514 .45608 L p
1 g
F P
s
P
p
.002 w
.65727 .40124 m .64514 .45608 L .66086 .46767 L p
1 g
F P
s
P
p
.002 w
.41616 .288 m .38567 .30957 L .39876 .32223 L p
1 g
F P
s
P
p
.002 w
.33404 .37808 m .33479 .42069 L .35237 .40891 L p
1 g
F P
s
P
p
.002 w
.35237 .40891 m .35191 .37385 L .33404 .37808 L p
1 g
F P
s
P
p
.002 w
.53685 .27719 m .49831 .2617 L .48673 .27829 L p
1 g
F P
s
P
p
.002 w
.45124 .2772 m .48673 .27829 L .49831 .2617 L p
1 g
F P
s
P
p
.002 w
.32094 .43312 m .33832 .47717 L .34966 .45896 L p
1 g
F P
s
P
p
.002 w
.34966 .45896 m .33479 .42069 L .32094 .43312 L p
1 g
F P
s
P
p
.002 w
.36512 .55154 m .41411 .57597 L .41112 .55544 L p
1 g
F P
s
P
p
.002 w
.41112 .55544 m .36559 .53242 L .36512 .55154 L p
1 g
F P
s
P
p
.002 w
.33087 .49477 m .36559 .53242 L .36947 .51133 L p
1 g
F P
s
P
p
.002 w
.36947 .51133 m .33832 .47717 L .33087 .49477 L p
1 g
F P
s
P
p
.002 w
.41945 .59338 m .47693 .60035 L .46914 .58288 L p
1 g
F P
s
P
p
.002 w
.46914 .58288 m .41411 .57597 L .41945 .59338 L p
1 g
F P
s
P
p
.002 w
.54455 .60236 m .59852 .57389 L .58791 .56121 L p
1 g
F P
s
P
p
.002 w
.58791 .56121 m .53488 .5891 L .54455 .60236 L p
1 g
F P
s
P
p
.002 w
.63124 .51947 m .58791 .56121 L .59852 .57389 L p
1 g
F P
s
P
p
.002 w
.5888 .29871 m .55474 .26706 L .53685 .27719 L p
1 g
F P
s
P
p
.002 w
.49831 .2617 m .53685 .27719 L .55474 .26706 L p
1 g
F P
s
P
p
.002 w
.59852 .57389 m .64266 .53139 L .63124 .51947 L p
1 g
F P
s
P
p
.002 w
.66086 .46767 m .63124 .51947 L .64266 .53139 L p
1 g
F P
s
P
p
.002 w
.34793 .33603 m .33404 .37808 L .35191 .37385 L p
1 g
F P
s
P
p
.002 w
.35191 .37385 m .36339 .33938 L .34793 .33603 L p
1 g
F P
s
P
p
.002 w
.65727 .40124 m .65156 .34638 L .63178 .34197 L p
1 g
F P
s
P
p
.002 w
.60939 .29618 m .63178 .34197 L .65156 .34638 L p
1 g
F P
s
P
p
.002 w
.63178 .34197 m .60939 .29618 L .5888 .29871 L p
1 g
F P
s
P
p
.002 w
.55474 .26706 m .5888 .29871 L .60939 .29618 L p
1 g
F P
s
P
p
.002 w
.66086 .46767 m .67373 .41045 L .65727 .40124 L p
1 g
F P
s
P
p
.002 w
.65156 .34638 m .65727 .40124 L .67373 .41045 L p
1 g
F P
s
P
p
.002 w
.49831 .2617 m .45513 .26022 L .45124 .2772 L p
1 g
F P
s
P
p
.002 w
.41616 .288 m .45124 .2772 L .45513 .26022 L p
1 g
F P
s
P
p
.002 w
.48561 .61397 m .54455 .60236 L .53488 .5891 L p
1 g
F P
s
P
p
.002 w
.53488 .5891 m .47693 .60035 L .48561 .61397 L p
1 g
F P
s
P
p
.002 w
.37509 .29962 m .34793 .33603 L .36339 .33938 L p
1 g
F P
s
P
p
.002 w
.36339 .33938 m .38567 .30957 L .37509 .29962 L p
1 g
F P
s
P
p
.002 w
.64266 .53139 m .67292 .4787 L .66086 .46767 L p
1 g
F P
s
P
p
.002 w
.67373 .41045 m .66086 .46767 L .67292 .4787 L p
1 g
F P
s
P
p
.002 w
.45513 .26022 m .41234 .2733 L .41616 .288 L p
1 g
F P
s
P
p
.002 w
.38567 .30957 m .41616 .288 L .41234 .2733 L p
1 g
F P
s
P
p
.002 w
.31991 .38385 m .32094 .43312 L .33479 .42069 L p
1 g
F P
s
P
p
.002 w
.33479 .42069 m .33404 .37808 L .31991 .38385 L p
1 g
F P
s
P
p
.002 w
.41234 .2733 m .37509 .29962 L .38567 .30957 L p
1 g
F P
s
P
p
.002 w
.31137 .44595 m .33087 .49477 L .33832 .47717 L p
1 g
F P
s
P
p
.002 w
.33832 .47717 m .32094 .43312 L .31137 .44595 L p
1 g
F P
s
P
p
.002 w
.32767 .51128 m .36512 .55154 L .36559 .53242 L p
1 g
F P
s
P
p
.002 w
.36559 .53242 m .33087 .49477 L .32767 .51128 L p
1 g
F P
s
P
p
.002 w
.55474 .26706 m .51034 .24897 L .49831 .2617 L p
1 g
F P
s
P
p
.002 w
.45513 .26022 m .49831 .2617 L .51034 .24897 L p
1 g
F P
s
P
p
.002 w
.36825 .56811 m .41945 .59338 L .41411 .57597 L p
1 g
F P
s
P
p
.002 w
.41411 .57597 m .36512 .55154 L .36825 .56811 L p
1 g
F P
s
P
p
.002 w
.42716 .60708 m .48561 .61397 L .47693 .60035 L p
1 g
F P
s
P
p
.002 w
.47693 .60035 m .41945 .59338 L .42716 .60708 L p
1 g
F P
s
P
p
.002 w
.60939 .29618 m .57181 .2609 L .55474 .26706 L p
1 g
F P
s
P
p
.002 w
.51034 .24897 m .55474 .26706 L .57181 .2609 L p
1 g
F P
s
P
p
.002 w
.65156 .34638 m .62779 .29713 L .60939 .29618 L p
1 g
F P
s
P
p
.002 w
.57181 .2609 m .60939 .29618 L .62779 .29713 L p
1 g
F P
s
P
p
.002 w
.67373 .41045 m .66802 .35318 L .65156 .34638 L p
1 g
F P
s
P
p
.002 w
.62779 .29713 m .65156 .34638 L .66802 .35318 L p
1 g
F P
s
P
p
.002 w
.55342 .61156 m .60693 .58326 L .59852 .57389 L p
1 g
F P
s
P
p
.002 w
.59852 .57389 m .54455 .60236 L .55342 .61156 L p
1 g
F P
s
P
p
.002 w
.64266 .53139 m .59852 .57389 L .60693 .58326 L p
1 g
F P
s
P
p
.002 w
.33592 .33508 m .31991 .38385 L .33404 .37808 L p
1 g
F P
s
P
p
.002 w
.33404 .37808 m .34793 .33603 L .33592 .33508 L p
1 g
F P
s
P
p
.002 w
.60693 .58326 m .65075 .54109 L .64266 .53139 L p
1 g
F P
s
P
p
.002 w
.67292 .4787 m .64266 .53139 L .65075 .54109 L p
1 g
F P
s
P
p
.002 w
.67292 .4787 m .68619 .42052 L .67373 .41045 L p
1 g
F P
s
P
p
.002 w
.66802 .35318 m .67373 .41045 L .68619 .42052 L p
1 g
F P
s
P
p
.002 w
.51034 .24897 m .46037 .24711 L .45513 .26022 L p
1 g
F P
s
P
p
.002 w
.41234 .2733 m .45513 .26022 L .46037 .24711 L p
1 g
F P
s
P
p
.002 w
.49502 .62317 m .55342 .61156 L .54455 .60236 L p
1 g
F P
s
P
p
.002 w
.54455 .60236 m .48561 .61397 L .49502 .62317 L p
1 g
F P
s
P
p
.002 w
.36743 .29277 m .33592 .33508 L .34793 .33603 L p
1 g
F P
s
P
p
.002 w
.34793 .33603 m .37509 .29962 L .36743 .29277 L p
1 g
F P
s
P
p
.002 w
.31009 .39112 m .31137 .44595 L .32094 .43312 L p
1 g
F P
s
P
p
.002 w
.32094 .43312 m .31991 .38385 L .31009 .39112 L p
1 g
F P
s
P
p
.002 w
.65075 .54109 m .68083 .48887 L .67292 .4787 L p
1 g
F P
s
P
p
.002 w
.68619 .42052 m .67292 .4787 L .68083 .48887 L p
1 g
F P
s
P
p
.002 w
.46037 .24711 m .4107 .26222 L .41234 .2733 L p
1 g
F P
s
P
p
.002 w
.37509 .29962 m .41234 .2733 L .4107 .26222 L p
1 g
F P
s
P
p
.002 w
.30656 .45886 m .32767 .51128 L .33087 .49477 L p
1 g
F P
s
P
p
.002 w
.33087 .49477 m .31137 .44595 L .30656 .45886 L p
1 g
F P
s
P
p
.002 w
.4107 .26222 m .36743 .29277 L .37509 .29962 L p
1 g
F P
s
P
p
.002 w
.32905 .52623 m .36825 .56811 L .36512 .55154 L p
1 g
F P
s
P
p
.002 w
.36512 .55154 m .32767 .51128 L .32905 .52623 L p
1 g
F P
s
P
p
.002 w
.3751 .58155 m .42716 .60708 L .41945 .59338 L p
1 g
F P
s
P
p
.002 w
.41945 .59338 m .36825 .56811 L .3751 .58155 L p
1 g
F P
s
P
p
.002 w
.57181 .2609 m .52255 .24063 L .51034 .24897 L p
1 g
F P
s
P
p
.002 w
.46037 .24711 m .51034 .24897 L .52255 .24063 L p
1 g
F P
s
P
p
.002 w
.43717 .61647 m .49502 .62317 L .48561 .61397 L p
1 g
F P
s
P
p
.002 w
.48561 .61397 m .42716 .60708 L .43717 .61647 L p
1 g
F P
s
P
p
.002 w
.62779 .29713 m .58758 .25908 L .57181 .2609 L p
1 g
F P
s
P
p
.002 w
.52255 .24063 m .57181 .2609 L .58758 .25908 L p
1 g
F P
s
P
p
.002 w
.66802 .35318 m .64342 .30171 L .62779 .29713 L p
1 g
F P
s
P
p
.002 w
.58758 .25908 m .62779 .29713 L .64342 .30171 L p
1 g
F P
s
P
p
.002 w
.68619 .42052 m .68057 .36232 L .66802 .35318 L p
1 g
F P
s
P
p
.002 w
.64342 .30171 m .66802 .35318 L .68057 .36232 L p
1 g
F P
s
P
p
.002 w
.32789 .33669 m .31009 .39112 L .31991 .38385 L p
1 g
F P
s
P
p
.002 w
.31991 .38385 m .33592 .33508 L .32789 .33669 L p
1 g
F P
s
P
p
.002 w
.68083 .48887 m .69409 .43127 L .68619 .42052 L p
1 g
F P
s
P
p
.002 w
.68057 .36232 m .68619 .42052 L .69409 .43127 L p
1 g
F P
s
P
p
.002 w
.56119 .61621 m .61279 .58888 L .60693 .58326 L p
1 g
F P
s
P
p
.002 w
.60693 .58326 m .55342 .61156 L .56119 .61621 L p
1 g
F P
s
P
p
.002 w
.65075 .54109 m .60693 .58326 L .61279 .58888 L p
1 g
F P
s
P
p
.002 w
.61279 .58888 m .65508 .5482 L .65075 .54109 L p
1 g
F P
s
P
p
.002 w
.68083 .48887 m .65075 .54109 L .65508 .5482 L p
1 g
F P
s
P
p
.002 w
.52255 .24063 m .46691 .23845 L .46037 .24711 L p
1 g
F P
s
P
p
.002 w
.4107 .26222 m .46037 .24711 L .46691 .23845 L p
1 g
F P
s
P
p
.002 w
.50495 .62746 m .56119 .61621 L .55342 .61156 L p
1 g
F P
s
P
p
.002 w
.55342 .61156 m .49502 .62317 L .50495 .62746 L p
1 g
F P
s
P
p
.002 w
.3051 .39979 m .30656 .45886 L .31137 .44595 L p
1 g
F P
s
P
p
.002 w
.31137 .44595 m .31009 .39112 L .3051 .39979 L p
1 g
F P
s
P
p
.002 w
.36307 .28941 m .32789 .33669 L .33592 .33508 L p
1 g
F P
s
P
p
.002 w
.33592 .33508 m .36743 .29277 L .36307 .28941 L p
1 g
F P
s
P
p
.002 w
.65508 .5482 m .68412 .49787 L .68083 .48887 L p
1 g
F P
s
P
p
.002 w
.69409 .43127 m .68083 .48887 L .68412 .49787 L p
1 g
F P
s
P
p
.002 w
.30694 .4715 m .32905 .52623 L .32767 .51128 L p
1 g
F P
s
P
p
.002 w
.32767 .51128 m .30656 .45886 L .30694 .4715 L p
1 g
F P
s
P
p
.002 w
.33526 .5391 m .3751 .58155 L .36825 .56811 L p
1 g
F P
s
P
p
.002 w
.36825 .56811 m .32905 .52623 L .33526 .5391 L p
1 g
F P
s
P
p
.002 w
.46691 .23845 m .41144 .25528 L .4107 .26222 L p
1 g
F P
s
P
p
.002 w
.36743 .29277 m .4107 .26222 L .41144 .25528 L p
1 g
F P
s
P
p
.002 w
.3857 .59133 m .43717 .61647 L .42716 .60708 L p
1 g
F P
s
P
p
.002 w
.42716 .60708 m .3751 .58155 L .3857 .59133 L p
1 g
F P
s
P
p
.002 w
.41144 .25528 m .36307 .28941 L .36743 .29277 L p
1 g
F P
s
P
p
.002 w
.58758 .25908 m .53464 .23716 L .52255 .24063 L p
1 g
F P
s
P
p
.002 w
.46691 .23845 m .52255 .24063 L .53464 .23716 L p
1 g
F P
s
P
p
.002 w
.64342 .30171 m .60157 .2619 L .58758 .25908 L p
1 g
F P
s
P
p
.002 w
.53464 .23716 m .58758 .25908 L .60157 .2619 L p
1 g
F P
s
P
p
.002 w
.44934 .62106 m .50495 .62746 L .49502 .62317 L p
1 g
F P
s
P
p
.002 w
.49502 .62317 m .43717 .61647 L .44934 .62106 L p
1 g
F P
s
P
p
.002 w
.68057 .36232 m .65573 .31 L .64342 .30171 L p
1 g
F P
s
P
p
.002 w
.60157 .2619 m .64342 .30171 L .65573 .31 L p
1 g
F P
s
P
p
.002 w
.69409 .43127 m .68864 .37369 L .68057 .36232 L p
1 g
F P
s
P
p
.002 w
.65573 .31 m .68057 .36232 L .68864 .37369 L p
1 g
F P
s
P
p
.002 w
.32431 .341 m .3051 .39979 L .31009 .39112 L p
1 g
F P
s
P
p
.002 w
.31009 .39112 m .32789 .33669 L .32431 .341 L p
1 g
F P
s
P
p
.002 w
.68412 .49787 m .69695 .44244 L .69409 .43127 L p
1 g
F P
s
P
p
.002 w
.68864 .37369 m .69409 .43127 L .69695 .44244 L p
1 g
F P
s
P
p
.002 w
.56761 .61589 m .61579 .59036 L .61279 .58888 L p
1 g
F P
s
P
p
.002 w
.61279 .58888 m .56119 .61621 L .56761 .61589 L p
1 g
F P
s
P
p
.002 w
.65508 .5482 m .61279 .58888 L .61579 .59036 L p
1 g
F P
s
P
p
.002 w
.61579 .59036 m .65529 .55236 L .65508 .5482 L p
1 g
F P
s
P
p
.002 w
.68412 .49787 m .65508 .5482 L .65529 .55236 L p
1 g
F P
s
P
p
.002 w
.53464 .23716 m .47464 .23476 L .46691 .23845 L p
1 g
F P
s
P
p
.002 w
.41144 .25528 m .46691 .23845 L .47464 .23476 L p
1 g
F P
s
P
p
.002 w
.30541 .40969 m .30694 .4715 L .30656 .45886 L p
1 g
F P
s
P
p
.002 w
.30656 .45886 m .3051 .39979 L .30541 .40969 L p
1 g
F P
s
P
p
.002 w
.51517 .62639 m .56761 .61589 L .56119 .61621 L p
1 g
F P
s
P
p
.002 w
.56119 .61621 m .50495 .62746 L .51517 .62639 L p
1 g
F P
s
P
p
.004 w
.69777 .42447 m
.71182 .42404 L
s
P
p
.004 w
.71182 .42404 m
.79441 .42152 L
s
P
p
.002 w
.31281 .48351 m .33526 .5391 L .32905 .52623 L p
1 g
F P
s
P
p
.002 w
.32905 .52623 m .30694 .4715 L .31281 .48351 L p
1 g
F P
s
P
p
.002 w
.34639 .54941 m .3857 .59133 L .3751 .58155 L p
1 g
F P
s
P
p
.002 w
.3751 .58155 m .33526 .5391 L .34639 .54941 L p
1 g
F P
s
P
p
.002 w
.36237 .28986 m .32431 .341 L .32789 .33669 L p
1 g
F P
s
P
p
.002 w
.32789 .33669 m .36307 .28941 L .36237 .28986 L p
1 g
F P
s
P
p
.002 w
.65529 .55236 m .68242 .50538 L .68412 .49787 L p
1 g
F P
s
P
p
.002 w
.69695 .44244 m .68412 .49787 L .68242 .50538 L p
1 g
F P
s
P
p
.002 w
.39997 .59692 m .44934 .62106 L .43717 .61647 L p
1 g
F P
s
P
p
.002 w
.43717 .61647 m .3857 .59133 L .39997 .59692 L p
1 g
F P
s
P
p
.002 w
.47464 .23476 m .4147 .25293 L .41144 .25528 L p
1 g
F P
s
P
p
.002 w
.36307 .28941 m .41144 .25528 L .4147 .25293 L p
1 g
F P
s
P
p
.002 w
.60157 .2619 m .54626 .23895 L .53464 .23716 L p
1 g
F P
s
P
p
.002 w
.47464 .23476 m .53464 .23716 L .54626 .23895 L p
1 g
F P
s
P
p
.002 w
.4147 .25293 m .36237 .28986 L .36307 .28941 L p
1 g
F P
s
P
p
.002 w
.65573 .31 m .61327 .26956 L .60157 .2619 L p
1 g
F P
s
P
p
.002 w
.54626 .23895 m .60157 .2619 L .61327 .26956 L p
1 g
F P
s
P
p
.002 w
.68864 .37369 m .66415 .32201 L .65573 .31 L p
1 g
F P
s
P
p
.002 w
.61327 .26956 m .65573 .31 L .66415 .32201 L p
1 g
F P
s
P
p
.002 w
.46345 .62041 m .51517 .62639 L .50495 .62746 L p
1 g
F P
s
P
p
.002 w
.50495 .62746 m .44934 .62106 L .46345 .62041 L p
1 g
F P
s
P
p
.002 w
.69695 .44244 m .69174 .38713 L .68864 .37369 L p
1 g
F P
s
P
p
.002 w
.66415 .32201 m .68864 .37369 L .69174 .38713 L p
1 g
F P
s
P
p
.002 w
.32559 .34805 m .30541 .40969 L .3051 .39979 L p
1 g
F P
s
P
p
.002 w
.3051 .39979 m .32431 .341 L .32559 .34805 L p
1 g
F P
s
P
p
.002 w
.68242 .50538 m .69437 .45374 L .69695 .44244 L p
1 g
F P
s
P
p
.002 w
.69174 .38713 m .69695 .44244 L .69437 .45374 L p
1 g
F P
s
P
p
.002 w
.57237 .61029 m .61563 .58738 L .61579 .59036 L p
1 g
F P
s
P
p
.002 w
.61579 .59036 m .56761 .61589 L .57237 .61029 L p
1 g
F P
s
P
p
.002 w
.65529 .55236 m .61579 .59036 L .61563 .58738 L p
1 g
F P
s
P
p
.002 w
.61563 .58738 m .65111 .55324 L .65529 .55236 L p
1 g
F P
s
P
p
.002 w
.68242 .50538 m .65529 .55236 L .65111 .55324 L p
1 g
F P
s
P
p
.002 w
.54626 .23895 m .48342 .23645 L .47464 .23476 L p
1 g
F P
s
P
p
.002 w
.4147 .25293 m .47464 .23476 L .48342 .23645 L p
1 g
F P
s
P
p
.002 w
.31134 .42061 m .31281 .48351 L .30694 .4715 L p
1 g
F P
s
P
p
.002 w
.30694 .4715 m .30541 .40969 L .31134 .42061 L p
1 g
F P
s
P
p
.002 w
.52538 .61965 m .57237 .61029 L .56761 .61589 L p
1 g
F P
s
P
p
.002 w
.56761 .61589 m .51517 .62639 L .52538 .61965 L p
1 g
F P
s
P
p
.002 w
.32433 .49446 m .34639 .54941 L .33526 .5391 L p
1 g
F P
s
P
p
.002 w
.33526 .5391 m .31281 .48351 L .32433 .49446 L p
1 g
F P
s
P
p
.002 w
.3624 .55668 m .39997 .59692 L .3857 .59133 L p
1 g
F P
s
P
p
.002 w
.3857 .59133 m .34639 .54941 L .3624 .55668 L p
1 g
F P
s
P
p
.002 w
.65111 .55324 m .67544 .51108 L .68242 .50538 L p
1 g
F P
s
P
p
.002 w
.69437 .45374 m .68242 .50538 L .67544 .51108 L p
1 g
F P
s
P
p
.002 w
.36557 .29436 m .32559 .34805 L .32431 .341 L p
1 g
F P
s
P
p
.002 w
.32431 .341 m .36237 .28986 L .36557 .29436 L p
1 g
F P
s
P
p
.002 w
.41769 .59791 m .46345 .62041 L .44934 .62106 L p
1 g
F P
s
P
p
.002 w
.44934 .62106 m .39997 .59692 L .41769 .59791 L p
1 g
F P
s
P
p
.002 w
.61327 .26956 m .55704 .24628 L .54626 .23895 L p
1 g
F P
s
P
p
.002 w
.48342 .23645 m .54626 .23895 L .55704 .24628 L p
1 g
F P
s
P
p
.002 w
.48342 .23645 m .42053 .25555 L .4147 .25293 L p
1 g
F P
s
P
p
.002 w
.36237 .28986 m .4147 .25293 L .42053 .25555 L p
1 g
F P
s
P
p
.002 w
.66415 .32201 m .6222 .28213 L .61327 .26956 L p
1 g
F P
s
P
p
.002 w
.55704 .24628 m .61327 .26956 L .6222 .28213 L p
1 g
F P
s
P
p
.002 w
.42053 .25555 m .36557 .29436 L .36237 .28986 L p
1 g
F P
s
P
p
.002 w
.69174 .38713 m .66821 .3376 L .66415 .32201 L p
1 g
F P
s
P
p
.002 w
.6222 .28213 m .66415 .32201 L .66821 .3376 L p
1 g
F P
s
P
p
.002 w
.69437 .45374 m .68948 .40234 L .69174 .38713 L p
1 g
F P
s
P
p
.002 w
.66821 .3376 m .69174 .38713 L .68948 .40234 L p
1 g
F P
s
P
p
.002 w
.47918 .61421 m .52538 .61965 L .51517 .62639 L p
1 g
F P
s
P
p
.002 w
.51517 .62639 m .46345 .62041 L .47918 .61421 L p
1 g
F P
s
P
p
.002 w
.67544 .51108 m .68608 .46483 L .69437 .45374 L p
1 g
F P
s
P
p
.002 w
.68948 .40234 m .69437 .45374 L .68608 .46483 L p
1 g
F P
s
P
p
.004 w
.6906 .42469 m
.69777 .42447 L
s
P
p
.004 w
.5 .43051 m
.68826 .42476 L
s
P
p
.002 w
.332 .3578 m .31134 .42061 L .30541 .40969 L p
1 g
F P
s
P
p
.002 w
.30541 .40969 m .32559 .34805 L .332 .3578 L p
1 g
F P
s
P
p
.002 w
.57525 .59922 m .61213 .57972 L .61563 .58738 L p
1 g
F P
s
P
p
.002 w
.61563 .58738 m .57237 .61029 L .57525 .59922 L p
1 g
F P
s
P
p
.002 w
.65111 .55324 m .61563 .58738 L .61213 .57972 L p
1 g
F P
s
P
p
.002 w
.55704 .24628 m .49305 .24384 L .48342 .23645 L p
1 g
F P
s
P
p
.002 w
.42053 .25555 m .48342 .23645 L .49305 .24384 L p
1 g
F P
s
P
p
.002 w
.61213 .57972 m .64238 .5506 L .65111 .55324 L p
1 g
F P
s
P
p
.002 w
.67544 .51108 m .65111 .55324 L .64238 .5506 L p
1 g
F P
s
P
p
.002 w
.32305 .43226 m .32433 .49446 L .31281 .48351 L p
1 g
F P
s
P
p
.002 w
.31281 .48351 m .31134 .42061 L .32305 .43226 L p
1 g
F P
s
P
p
.002 w
.34146 .50395 m .3624 .55668 L .34639 .54941 L p
1 g
F P
s
P
p
.002 w
.34639 .54941 m .32433 .49446 L .34146 .50395 L p
1 g
F P
s
P
p
.002 w
.38305 .56049 m .41769 .59791 L .39997 .59692 L p
1 g
F P
s
P
p
.002 w
.39997 .59692 m .3624 .55668 L .38305 .56049 L p
1 g
F P
s
P
p
.002 w
.53527 .60711 m .57525 .59922 L .57237 .61029 L p
1 g
F P
s
P
p
.002 w
.57237 .61029 m .52538 .61965 L .53527 .60711 L p
1 g
F P
s
P
p
.002 w
.43849 .59401 m .47918 .61421 L .46345 .62041 L p
1 g
F P
s
P
p
.002 w
.46345 .62041 m .41769 .59791 L .43849 .59401 L p
1 g
F P
s
P
p
.002 w
.64238 .5506 m .66306 .51468 L .67544 .51108 L p
1 g
F P
s
P
p
.002 w
.68608 .46483 m .67544 .51108 L .66306 .51468 L p
1 g
F P
s
P
p
.002 w
.37285 .30303 m .332 .3578 L .32559 .34805 L p
1 g
F P
s
P
p
.002 w
.32559 .34805 m .36557 .29436 L .37285 .30303 L p
1 g
F P
s
P
p
.002 w
.6222 .28213 m .5666 .25927 L .55704 .24628 L p
1 g
F P
s
P
p
.002 w
.49305 .24384 m .55704 .24628 L .5666 .25927 L p
1 g
F P
s
P
p
.002 w
.66821 .3376 m .62792 .29951 L .6222 .28213 L p
1 g
F P
s
P
p
.002 w
.5666 .25927 m .6222 .28213 L .62792 .29951 L p
1 g
F P
s
P
p
.002 w
.62792 .29951 m .66821 .3376 L .66753 .35649 L p
1 g
F P
s
P
p
.002 w
.68948 .40234 m .66753 .35649 L .66821 .3376 L p
1 g
F P
s
P
p
.002 w
.49305 .24384 m .42894 .2634 L .42053 .25555 L p
1 g
F P
s
P
p
.002 w
.36557 .29436 m .42053 .25555 L .42894 .2634 L p
1 g
F P
s
P
p
.002 w
.68608 .46483 m .6816 .41897 L .68948 .40234 L p
1 g
F P
s
P
p
.004 w
.68915 .42474 m
.6906 .42469 L
s
P
p
.002 w
.66753 .35649 m .68948 .40234 L .6816 .41897 L p
1 g
F P
s
P
p
.002 w
.42894 .2634 m .37285 .30303 L .36557 .29436 L p
1 g
F P
s
P
p
.002 w
.49611 .60236 m .53527 .60711 L .52538 .61965 L p
1 g
F P
s
P
p
.002 w
.52538 .61965 m .47918 .61421 L .49611 .60236 L p
1 g
F P
s
P
p
.002 w
.66306 .51468 m .67201 .47536 L .68608 .46483 L p
1 g
F P
s
P
p
.002 w
.6816 .41897 m .68608 .46483 L .67201 .47536 L p
1 g
F P
s
P
p
.002 w
.34366 .37011 m .32305 .43226 L .31134 .42061 L p
1 g
F P
s
P
p
.002 w
.31134 .42061 m .332 .3578 L .34366 .37011 L p
1 g
F P
s
P
p
.002 w
.34049 .44429 m .34146 .50395 L .32433 .49446 L p
1 g
F P
s
P
p
.002 w
.32433 .49446 m .32305 .43226 L .34049 .44429 L p
1 g
F P
s
P
p
.002 w
.5666 .25927 m .50328 .25703 L .49305 .24384 L p
1 g
F P
s
P
p
.002 w
.42894 .2634 m .49305 .24384 L .50328 .25703 L p
1 g
F P
s
P
p
.002 w
.36394 .51157 m .38305 .56049 L .3624 .55668 L p
1 g
F P
s
P
p
.002 w
.3624 .55668 m .34146 .50395 L .36394 .51157 L p
1 g
F P
s
P
p
.002 w
.57601 .5827 m .60516 .56733 L .61213 .57972 L p
1 g
F P
s
P
p
.002 w
.61213 .57972 m .57525 .59922 L .57601 .5827 L p
1 g
F P
s
P
p
.002 w
.64238 .5506 m .61213 .57972 L .60516 .56733 L p
1 g
F P
s
P
p
.002 w
.40789 .56055 m .43849 .59401 L .41769 .59791 L p
1 g
F P
s
P
p
.002 w
.41769 .59791 m .38305 .56049 L .40789 .56055 L p
1 g
F P
s
P
p
.002 w
.60516 .56733 m .62907 .54431 L .64238 .5506 L p
1 g
F P
s
P
p
.002 w
.66306 .51468 m .64238 .5506 L .62907 .54431 L p
1 g
F P
s
P
p
.002 w
.46183 .58508 m .49611 .60236 L .47918 .61421 L p
1 g
F P
s
P
p
.002 w
.47918 .61421 m .43849 .59401 L .46183 .58508 L p
1 g
F P
s
P
p
.002 w
.54448 .58883 m .57601 .5827 L .57525 .59922 L p
1 g
F P
s
P
p
.002 w
.57525 .59922 m .53527 .60711 L .54448 .58883 L p
1 g
F P
s
P
p
.002 w
.62792 .29951 m .57454 .27781 L .5666 .25927 L p
1 g
F P
s
P
p
.002 w
.50328 .25703 m .5666 .25927 L .57454 .27781 L p
1 g
F P
s
P
p
.002 w
.62907 .54431 m .64535 .51592 L .66306 .51468 L p
1 g
F P
s
P
p
.002 w
.67201 .47536 m .66306 .51468 L .64535 .51592 L p
1 g
F P
s
P
p
.002 w
.6816 .41897 m .66187 .37824 L .66753 .35649 L p
1 g
F P
s
P
p
.002 w
.63006 .3214 m .66753 .35649 L .66187 .37824 L p
1 g
F P
s
P
p
.002 w
.66753 .35649 m .63006 .3214 L .62792 .29951 L p
1 g
F P
s
P
p
.002 w
.57454 .27781 m .62792 .29951 L .63006 .3214 L p
1 g
F P
s
P
p
.002 w
.38421 .31586 m .34366 .37011 L .332 .3578 L p
1 g
F P
s
P
p
.002 w
.332 .3578 m .37285 .30303 L .38421 .31586 L p
1 g
F P
s
P
p
.002 w
.67201 .47536 m .66805 .43654 L .6816 .41897 L p
1 g
F P
s
P
p
.002 w
.66187 .37824 m .6816 .41897 L .66805 .43654 L p
1 g
F P
s
P
p
.002 w
.50328 .25703 m .4398 .27653 L .42894 .2634 L p
1 g
F P
s
P
p
.002 w
.37285 .30303 m .42894 .2634 L .4398 .27653 L p
1 g
F P
s
P
p
.002 w
.51373 .58495 m .54448 .58883 L .53527 .60711 L p
1 g
F P
s
P
p
.002 w
.53527 .60711 m .49611 .60236 L .51373 .58495 L p
1 g
F P
s
P
p
.002 w
.4398 .27653 m .38421 .31586 L .37285 .30303 L p
1 g
F P
s
P
p
.002 w
.64535 .51592 m .65229 .48494 L .67201 .47536 L p
1 g
F P
s
P
p
.002 w
.66805 .43654 m .67201 .47536 L .65229 .48494 L p
1 g
F P
s
P
p
.002 w
.36047 .38469 m .34049 .44429 L .32305 .43226 L p
1 g
F P
s
P
p
.002 w
.32305 .43226 m .34366 .37011 L .36047 .38469 L p
1 g
F P
s
P
p
.002 w
.39123 .51696 m .40789 .56055 L .38305 .56049 L p
1 g
F P
s
P
p
.002 w
.38305 .56049 m .36394 .51157 L .39123 .51696 L p
1 g
F P
s
P
p
.002 w
.36335 .4563 m .36394 .51157 L .34146 .50395 L p
1 g
F P
s
P
p
.002 w
.34146 .50395 m .34049 .44429 L .36335 .4563 L p
1 g
F P
s
P
p
.002 w
.43624 .55667 m .46183 .58508 L .43849 .59401 L p
1 g
F P
s
P
p
.002 w
.43849 .59401 m .40789 .56055 L .43624 .55667 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.57454 .27781 m .51379 .27591 L .50328 .25703 L p
1 g
F P
s
P
p
.002 w
.4398 .27653 m .50328 .25703 L .51379 .27591 L p
1 g
F P
s
P
p
.002 w
.57451 .56099 m .59476 .55035 L .60516 .56733 L p
1 g
F P
s
P
p
.002 w
.60516 .56733 m .57601 .5827 L .57451 .56099 L p
1 g
F P
s
P
p
.002 w
.62907 .54431 m .60516 .56733 L .59476 .55035 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.59476 .55035 m .61136 .53436 L .62907 .54431 L p
1 g
F P
s
P
p
.002 w
.64535 .51592 m .62907 .54431 L .61136 .53436 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48909 .58024 m .48921 .57862 L p
.47874 .57776 L 1 g
F P
s
P
p
.002 w
.49611 .60236 m .46183 .58508 L .47621 .57716 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46838 .57423 L p
1 g
F P
s
P
p
.46183 .58508 m .4637 .57248 L .46838 .57423 L 1 g
F
P
p
.002 w
.47621 .57716 m .47435 .57818 L p
.46838 .57423 L 1 g
F P
s
P
p
.002 w
.47435 .57818 m .46183 .58508 L p
.46838 .57423 L 1 g
F P
s
P
p
.002 w
.46838 .57423 m .46872 .57265 L p
.46185 .56991 L 1 g
F P
s
P
p
.48921 .57862 m .46838 .57423 L .47325 .57605 L 1 g
F
P
p
.48921 .57862 m .46816 .57523 L .47874 .57776 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45094 .56269 L p
1 g
F P
s
P
p
.46872 .57265 m .45094 .56269 L .46185 .56991 L 1 g
F
P
p
.46838 .57423 m .46722 .54883 L .47621 .57716 L 1 g
F
P
p
.4637 .57248 m .46388 .57125 L .46838 .57423 L 1 g
F
P
p
.46388 .57125 m .46722 .54883 L .46838 .57423 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46183 .58508 m .43624 .55667 L .44386 .55474 L p
1 g
F P
s
P
p
.002 w
.45094 .56269 m .45146 .56129 L p
.44378 .55462 L 1 g
F P
s
P
p
.002 w
.44386 .55474 m .43624 .55667 L p
.44026 .54951 L 1 g
F P
s
P
p
.44378 .55462 m .44367 .55452 L .44386 .55474 L 1 g
F
P
p
.44378 .55462 m .44386 .55474 L .45094 .56269 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43853 .54702 L p
1 g
F P
s
P
p
.002 w
.43624 .55667 m .42578 .52855 L p
.43853 .54702 L 1 g
F P
s
P
p
.43965 .55059 m .43853 .54702 L .44026 .54951 L 1 g
F
P
p
.43624 .55667 m .43853 .54702 L .43965 .55059 L 1 g
F
P
p
.002 w
.43853 .54702 m .43925 .54566 L p
.43622 .53966 L 1 g
F P
s
P
p
.45146 .56129 m .43853 .54702 L .44378 .55462 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43269 .52846 L p
1 g
F P
s
P
p
.43925 .54566 m .43269 .52846 L .43622 .53966 L 1 g
F
P
p
.44026 .54951 m .43827 .54619 L .45681 .52 L 1 g
F
P
p
.002 w
.42253 .51983 m .42999 .51987 L p
.43269 .52846 L 1 g
F P
s
P
p
.43238 .53632 m .42253 .51983 L .43269 .52846 L 1 g
F
P
p
.002 w
.43269 .52846 m .43346 .52734 L p
.43316 .51872 L 1 g
F P
s
P
p
.002 w
.43304 .51988 m .42899 .51986 L p
.43416 .5091 L 1 g
F P
s
P
p
.002 w
.42899 .51986 m .42253 .51983 L p
.43415 .50911 L 1 g
F P
s
P
p
.43415 .50911 m .43416 .5091 L .42899 .51986 L 1 g
F
P
p
.002 w
.43416 .50908 m .43485 .50826 L p
.43728 .50257 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.42253 .51983 m .42269 .4785 L .43694 .48234 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43416 .50908 L p
1 g
F P
s
P
p
.43346 .52734 m .43416 .50908 L .43316 .51872 L 1 g
F
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44274 .49119 L p
1 g
F P
s
P
p
.002 w
.43694 .48234 m .44583 .48474 L p
.44274 .49119 L 1 g
F P
s
P
p
.43416 .50908 m .43527 .4984 L .44274 .49119 L 1 g
F
P
p
.43527 .4984 m .43694 .48234 L .44274 .49119 L 1 g
F
P
p
.002 w
.44274 .49119 m .44166 .49233 L p
.43728 .50257 L 1 g
F P
s
P
p
.43485 .50826 m .44274 .49119 L .43728 .50257 L 1 g
F
P
p
.002 w
.44274 .49119 m .44339 .4905 L p
.45056 .48363 L 1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45721 .48781 m .44864 .4855 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.45769 .47671 m .45826 .47608 L p
.46745 .47205 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.46189 .47475 m .47757 .46715 L .50122 .47365 L 1 g
F
P
p
.002 w
.47757 .46715 m .47786 .46667 L p
.48914 .46552 L 1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50122 .47365 m .48691 .46586 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46718 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.50774 .46514 m .52245 .46718 L .54097 .48043 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54245 .47686 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56618 .50949 L p
1 g
F P
s
P
p
.002 w
.56518 .50732 m .56456 .50425 L p
.56605 .5077 L 1 g
F P
s
P
p
.57637 .5316 m .56618 .50949 L .56605 .5077 L 1 g
F
P
p
.56618 .50949 m .56518 .50732 L .56605 .5077 L 1 g
F
P
p
.002 w
.56618 .50949 m .56515 .50826 L p
.56691 .51966 L 1 g
F P
s
P
p
.002 w
.57068 .53458 m .568 .53508 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.5665 .51383 m .56867 .52461 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56867 .52461 m .57068 .53458 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56756 .52882 m .56654 .52734 L p
.56429 .53969 L 1 g
F P
s
P
p
.002 w
.57068 .53458 m .57451 .56099 L p
.56319 .54271 L 1 g
F P
s
P
p
.002 w
.5658 .53548 m .57068 .53458 L p
.56319 .54271 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54933 .56342 L p
1 g
F P
s
P
p
.56075 .54566 m .54933 .56342 L .55051 .5619 L 1 g
F
P
p
.002 w
.55473 .55646 m .55265 .56515 L p
.55196 .56002 L 1 g
F P
s
P
p
.56075 .54566 m .55051 .5619 L .55499 .5561 L 1 g
F
P
p
.002 w
.55265 .56515 m .54842 .56459 L p
.54933 .56342 L 1 g
F P
s
P
p
.55213 .5613 m .54933 .56342 L .55196 .56002 L 1 g
F
P
p
.55265 .56515 m .54933 .56342 L .55213 .5613 L 1 g
F
P
p
.002 w
.54933 .56342 m .54854 .56129 L p
.54044 .56901 L 1 g
F P
s
P
p
.002 w
.55265 .56515 m .54448 .58883 L p
.53604 .57167 L 1 g
F P
s
P
p
.002 w
.54788 .56452 m .55265 .56515 L p
.53604 .57167 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .5808 L p
1 g
F P
s
P
p
.53128 .57265 m .51095 .5808 L .51448 .57986 L 1 g
F
P
p
.002 w
.51857 .57878 m .51373 .58495 L p
.51364 .58008 L 1 g
F P
s
P
p
.53128 .57265 m .51448 .57986 L .52086 .57799 L 1 g
F
P
p
.002 w
.51373 .58495 m .50745 .58172 L p
.51095 .5808 L 1 g
F P
s
P
p
.51365 .5807 m .51095 .5808 L .51364 .58008 L 1 g
F
P
p
.51373 .58495 m .51095 .5808 L .51365 .5807 L 1 g
F
P
p
.002 w
.51095 .5808 m .51079 .57862 L p
.50027 .58072 L 1 g
F P
s
P
p
.002 w
.51373 .58495 m .51276 .58591 L p
.50395 .58088 L 1 g
F P
s
P
p
.002 w
.50599 .58097 m .51373 .58495 L p
.50395 .58088 L 1 g
F P
s
P
p
.50027 .58072 m .50599 .58097 L .51095 .5808 L 1 g
F
P
p
.48967 .58038 m .48964 .58026 L .51276 .58591 L 1 g
F
P
p
.48964 .58026 m .50395 .58088 L .51276 .58591 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58024 L p
1 g
F P
s
P
p
.48967 .58038 m .48909 .58024 L .48964 .58026 L 1 g
F
P
p
.49611 .60236 m .47828 .57977 L .48967 .58038 L 1 g
F
P
p
.47828 .57977 m .47621 .57716 L .48909 .58024 L 1 g
F
P
p
.47828 .57977 m .48909 .58024 L .48967 .58038 L 1 g
F
P
p
.002 w
.51276 .58591 m .49611 .60236 L p
.48967 .58038 L 1 g
F P
s
P
p
.50027 .58072 m .48899 .58158 L .49751 .58127 L 1 g
F
P
p
.51079 .57862 m .4965 .58056 L .50027 .58072 L 1 g
F
P
p
.4965 .58056 m .48899 .58158 L .50027 .58072 L 1 g
F
P
p
.002 w
.48909 .58024 m .48899 .58158 L p
.4965 .58056 L 1 g
F P
s
P
p
.51079 .57862 m .48909 .58024 L .4965 .58056 L 1 g
F
P
p
.002 w
.47621 .57716 m .48699 .57122 L p
.48964 .58026 L 1 g
F P
s
P
p
.48909 .58024 m .47621 .57716 L .48964 .58026 L 1 g
F
P
p
.51095 .5808 m .48699 .57122 L .51364 .58008 L 1 g
F
P
p
.002 w
.50745 .58172 m .50599 .58097 L p
.51095 .5808 L 1 g
F P
s
P
p
.002 w
.50599 .58097 m .48699 .57122 L p
.51095 .5808 L 1 g
F P
s
P
p
.002 w
.48899 .58158 m .48889 .583 L p
.49751 .58127 L 1 g
F P
s
P
p
.48964 .58026 m .48699 .57122 L .50395 .58088 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58119 L p
1 g
F P
s
P
p
.002 w
.51098 .58119 m .51095 .5808 L p
.50821 .58107 L 1 g
F P
s
P
p
.50821 .58107 m .48889 .583 L .51098 .58119 L 1 g
F
P
p
.50027 .58072 m .49751 .58127 L .50599 .58097 L 1 g
F
P
p
.002 w
.48699 .57122 m .50599 .58097 L p
.50395 .58088 L 1 g
F P
s
P
p
.49751 .58127 m .48889 .583 L .51095 .5808 L 1 g
F
P
p
.51448 .57986 m .51099 .58136 L .51857 .57878 L 1 g
F
P
p
.51448 .57986 m .51857 .57878 L .52086 .57799 L 1 g
F
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.48699 .57122 m .51313 .55272 L p
.51364 .58008 L 1 g
F P
s
P
p
.002 w
.51313 .55272 m .53145 .56233 L .51857 .57878 L p
1 g
F P
s
P
p
.51364 .58008 m .51313 .55272 L .51857 .57878 L 1 g
F
P
p
.002 w
.51095 .5808 m .51099 .58136 L p
.51448 .57986 L 1 g
F P
s
P
p
.002 w
.51373 .58495 m .51857 .57878 L p
.53149 .57437 L 1 g
F P
s
P
p
.002 w
.51099 .58136 m .51111 .583 L p
.52086 .57799 L 1 g
F P
s
P
p
.002 w
.54448 .58883 m .514 .58498 L p
.53164 .57432 L 1 g
F P
s
P
p
.002 w
.53164 .57432 m .53128 .57265 L p
.52086 .57799 L 1 g
F P
s
P
p
.53652 .57266 m .53164 .57432 L .53604 .57167 L 1 g
F
P
p
.54448 .58883 m .53164 .57432 L .53652 .57266 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.514 .58498 m .51373 .58495 L p
.53604 .57167 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53164 .57432 L p
1 g
F P
s
P
p
.52086 .57799 m .51111 .583 L .53164 .57432 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53604 .57167 m .53149 .57437 L .53145 .56233 L 1 g
F
P
p
.002 w
.51857 .57878 m .53145 .56233 L p
.53149 .57437 L 1 g
F P
s
P
p
.55051 .5619 m .55473 .55646 L .55499 .5561 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.54933 .56342 m .53145 .56233 L .55196 .56002 L 1 g
F
P
p
.002 w
.54842 .56459 m .54788 .56452 L p
.54933 .56342 L 1 g
F P
s
P
p
.54044 .56901 m .54788 .56452 L .54933 .56342 L 1 g
F
P
p
.002 w
.54788 .56452 m .53145 .56233 L p
.54933 .56342 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5494 .5636 L p
1 g
F P
s
P
p
.002 w
.5494 .5636 m .54933 .56342 L p
.54812 .56437 L 1 g
F P
s
P
p
.54812 .56437 m .5322 .57686 L .5494 .5636 L 1 g
F
P
p
.54044 .56901 m .53479 .5744 L .54788 .56452 L 1 g
F
P
p
.002 w
.53145 .56233 m .54788 .56452 L p
.53604 .57167 L 1 g
F P
s
P
p
.53479 .5744 m .5322 .57686 L .54933 .56342 L 1 g
F
P
p
.55051 .5619 m .54941 .56364 L .55473 .55646 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53145 .56233 m .54861 .53514 L p
.55196 .56002 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54861 .53514 m .55945 .53666 L .55473 .55646 L p
1 g
F P
s
P
p
.55196 .56002 m .54861 .53514 L .55473 .55646 L 1 g
F
P
p
.002 w
.54933 .56342 m .54941 .56364 L p
.55051 .5619 L 1 g
F P
s
P
p
.002 w
.55265 .56515 m .55473 .55646 L p
.56023 .54903 L 1 g
F P
s
P
p
.002 w
.54941 .56364 m .54998 .56518 L p
.55499 .5561 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.57451 .56099 m .55529 .56465 L p
.56157 .54721 L 1 g
F P
s
P
p
.002 w
.56157 .54721 m .56075 .54566 L p
.55499 .5561 L 1 g
F P
s
P
p
.56397 .54397 m .56157 .54721 L .56319 .54271 L 1 g
F
P
p
.57451 .56099 m .56157 .54721 L .56397 .54397 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56233 .54865 L p
1 g
F P
s
P
p
.56654 .52734 m .56233 .54865 L .56337 .5447 L 1 g
F
P
p
.56691 .51966 m .5665 .51383 L .56618 .50949 L 1 g
F
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56756 .52882 m .55945 .53666 L .5665 .51383 L 1 g
F
P
p
.002 w
.568 .53508 m .5658 .53548 L p
.56756 .52882 L 1 g
F P
s
P
p
.56429 .53969 m .5658 .53548 L .56756 .52882 L 1 g
F
P
p
.002 w
.5658 .53548 m .55945 .53666 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56233 .54865 m .56257 .5491 L p
.56337 .5447 L 1 g
F P
s
P
p
.002 w
.55529 .56465 m .55265 .56515 L p
.56319 .54271 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56157 .54721 L p
1 g
F P
s
P
p
.55499 .5561 m .54998 .56518 L .56157 .54721 L 1 g
F
P
p
.56319 .54271 m .56023 .54903 L .55945 .53666 L 1 g
F
P
p
.002 w
.55473 .55646 m .55945 .53666 L p
.56023 .54903 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56798 .52944 L p
1 g
F P
s
P
p
.002 w
.56798 .52944 m .56756 .52882 L p
.56617 .53446 L 1 g
F P
s
P
p
.56617 .53446 m .56257 .5491 L .56798 .52944 L 1 g
F
P
p
.56429 .53969 m .56337 .5447 L .5658 .53548 L 1 g
F
P
p
.002 w
.55945 .53666 m .5658 .53548 L p
.56319 .54271 L 1 g
F P
s
P
p
.56337 .5447 m .56257 .5491 L .56756 .52882 L 1 g
F
P
p
.56691 .51966 m .56692 .51974 L .5665 .51383 L 1 g
F
P
p
.002 w
.56436 .50554 m .56456 .50425 L .56518 .50732 L p
1 g
F P
s
P
p
.55661 .4905 m .56618 .50949 L .56436 .50554 L 1 g
F
P
p
.55661 .4905 m .56436 .50554 L .56397 .5047 L 1 g
F
P
p
.002 w
.56392 .50461 m .56456 .50425 L .56402 .50481 L p
1 g
F P
s
P
p
.56391 .50458 m .56397 .5047 L .56393 .50461 L 1 g
F
P
p
.55661 .4905 m .56397 .5047 L .56391 .50458 L 1 g
F
P
p
.55661 .4905 m .56393 .50461 L .56386 .50448 L 1 g
F
P
p
.55661 .4905 m .56388 .50452 L .56381 .50436 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.5326 .52217 m .52921 .51207 L .56383 .50441 L p
1 g
F P
s
P
p
.002 w
.56383 .50441 m .56456 .50425 L .56392 .50461 L p
1 g
F P
s
P
p
.002 w
.56392 .50461 m .5326 .52217 L p
.56383 .50441 L 1 g
F P
s
P
p
.55661 .4905 m .56384 .50442 L .56375 .50423 L 1 g
F
P
p
.55661 .4905 m .56379 .50431 L .56311 .50294 L 1 g
F
P
p
.002 w
.52921 .51207 m .52955 .50093 L .56371 .50417 L p
1 g
F P
s
P
p
.002 w
.56371 .50417 m .56456 .50425 L .56383 .50441 L p
1 g
F P
s
P
p
.002 w
.56383 .50441 m .52921 .51207 L p
.56371 .50417 L 1 g
F P
s
P
p
.56386 .50448 m .56393 .50461 L .56388 .50452 L 1 g
F
P
p
.56381 .50436 m .56388 .50452 L .56384 .50442 L 1 g
F
P
p
.002 w
.52955 .50093 m .53361 .48997 L .56352 .50377 L p
1 g
F P
s
P
p
.002 w
.56352 .50377 m .56456 .50425 L .56371 .50417 L p
1 g
F P
s
P
p
.002 w
.56371 .50417 m .52955 .50093 L p
.56352 .50377 L 1 g
F P
s
P
p
.002 w
.56296 .50263 m .56456 .50425 L .56352 .50377 L p
1 g
F P
s
P
p
.002 w
.5508 .47336 m .56456 .50425 L .56296 .50263 L p
1 g
F P
s
P
p
.55742 .49136 m .55886 .49275 L .56296 .50263 L 1 g
F
P
p
.002 w
.56402 .50481 m .56456 .50425 L .56414 .50507 L p
1 g
F P
s
P
p
.002 w
.56414 .50507 m .56456 .50425 L .56436 .50554 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55742 .49136 L p
1 g
F P
s
P
p
.54174 .47608 m .55742 .49136 L .55067 .48482 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56296 .50263 m .54097 .48043 L .54393 .4783 L p
1 g
F P
s
P
p
.002 w
.54097 .48043 m .53302 .47231 L p
.54245 .47686 L 1 g
F P
s
P
p
.54174 .47608 m .55067 .48482 L .54393 .4783 L 1 g
F
P
p
.002 w
.54245 .47686 m .54174 .47608 L p
.54393 .4783 L 1 g
F P
s
P
p
.002 w
.54454 .47786 m .54393 .4783 L p
.54245 .47686 L 1 g
F P
s
P
p
.002 w
.54393 .4783 m .54097 .48043 L p
.54245 .47686 L 1 g
F P
s
P
p
.002 w
.54253 .47694 m .54245 .47686 L p
.54393 .4783 L 1 g
F P
s
P
p
.002 w
.54393 .4783 m .54915 .47455 L p
.55742 .49136 L 1 g
F P
s
P
p
.54393 .4783 m .55742 .49136 L .56296 .50263 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54253 .47694 L p
1 g
F P
s
P
p
.55067 .48482 m .55834 .49233 L .54253 .47694 L 1 g
F
P
p
.002 w
.55742 .49136 m .55834 .49233 L p
.55067 .48482 L 1 g
F P
s
P
p
.002 w
.54915 .47455 m .5508 .47336 L p
.55886 .49275 L 1 g
F P
s
P
p
.54915 .47455 m .55886 .49275 L .55742 .49136 L 1 g
F
P
p
.002 w
.53361 .48997 m .54097 .48043 L .56296 .50263 L p
1 g
F P
s
P
p
.002 w
.56352 .50377 m .53361 .48997 L p
.56296 .50263 L 1 g
F P
s
P
p
.56375 .50423 m .56384 .50442 L .56379 .50431 L 1 g
F
P
p
.56311 .50294 m .56379 .50431 L .56342 .50352 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.53932 .53014 m .5326 .52217 L .56392 .50461 L p
1 g
F P
s
P
p
.002 w
.56402 .50481 m .53932 .53014 L p
.56392 .50461 L 1 g
F P
s
P
p
.56342 .50352 m .56402 .50481 L .56355 .50378 L 1 g
F
P
p
.56402 .50481 m .56436 .50554 L .56423 .50526 L 1 g
F
P
p
.56402 .50481 m .56423 .50526 L .56355 .50378 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54861 .53514 m .53932 .53014 L .56402 .50481 L p
1 g
F P
s
P
p
.002 w
.56414 .50507 m .54861 .53514 L p
.56402 .50481 L 1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55945 .53666 m .54861 .53514 L .56414 .50507 L p
1 g
F P
s
P
p
.002 w
.56436 .50554 m .55945 .53666 L p
.56414 .50507 L 1 g
F P
s
P
p
.56355 .50378 m .56459 .50604 L .56713 .51061 L 1 g
F
P
p
.56459 .50604 m .56518 .50732 L .5652 .50736 L 1 g
F
P
p
.56459 .50604 m .5652 .50736 L .56713 .51061 L 1 g
F
P
p
.002 w
.56618 .50949 m .56619 .50949 L p
.56518 .50732 L 1 g
F P
s
P
p
.002 w
.56619 .50949 m .56713 .51061 L p
.56518 .50732 L 1 g
F P
s
P
p
.002 w
.55945 .53666 m .56436 .50554 L p
.5665 .51383 L 1 g
F P
s
P
p
.002 w
.56518 .50732 m .5665 .51383 L p
.56436 .50554 L 1 g
F P
s
P
p
.002 w
.57637 .5316 m .57068 .53458 L .56518 .50732 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56618 .50949 L p
1 g
F P
s
P
p
.56692 .51974 m .56854 .53025 L .56618 .50949 L 1 g
F
P
p
.002 w
.56456 .50425 m .58111 .52913 L .57637 .5316 L p
1 g
F P
s
P
p
.002 w
.54245 .47686 m .54252 .47693 L p
.54072 .47602 L 1 g
F P
s
P
p
.52214 .46667 m .54245 .47686 L .54072 .47602 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5508 .47336 m .54454 .47786 L p
.51575 .4547 L 1 g
F P
s
P
p
.52214 .46667 m .54252 .47693 L .5334 .4725 L 1 g
F
P
p
.002 w
.53302 .47231 m .54097 .48043 L p
.52245 .46718 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46718 L p
1 g
F P
s
P
p
.002 w
.52245 .46718 m .52214 .46667 L p
.5334 .4725 L 1 g
F P
s
P
p
.5334 .4725 m .54302 .47747 L .52245 .46718 L 1 g
F
P
p
.002 w
.51575 .4547 m .52885 .46806 L p
.52245 .46718 L 1 g
F P
s
P
p
.5 .4634 m .52245 .46718 L .51443 .46607 L 1 g
F
P
p
.5 .4634 m .5227 .4676 L .51681 .46663 L 1 g
F
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.50122 .47365 m .50774 .46514 L p
.54097 .48043 L 1 g
F P
s
P
p
.002 w
.50774 .46514 m .50122 .47365 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .4634 L p
.51681 .46663 L 1 g
F P
s
P
p
.51681 .46663 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46406 L p
1 g
F P
s
P
p
.002 w
.5 .46406 m .5 .46442 L p
.49002 .46543 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46406 L .49002 .46543 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47734 .46753 L p
1 g
F P
s
P
p
.002 w
.47734 .46753 m .47718 .46778 L p
.47089 .47054 L 1 g
F P
s
P
p
.45826 .47608 m .47734 .46753 L .47089 .47054 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43416 .50908 m .44274 .49119 L .45721 .48781 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45724 .47719 L p
1 g
F P
s
P
p
.44339 .4905 m .45724 .47719 L .45229 .48198 L 1 g
F
P
p
.45056 .48363 m .44864 .4855 L .44274 .49119 L 1 g
F
P
p
.002 w
.44583 .48474 m .44864 .4855 L p
.44274 .49119 L 1 g
F P
s
P
p
.002 w
.44864 .4855 m .45721 .48781 L p
.44274 .49119 L 1 g
F P
s
P
p
.002 w
.45724 .47719 m .45698 .47747 L p
.45229 .48198 L 1 g
F P
s
P
p
.42269 .4785 m .46305 .4715 L .45769 .47671 L 1 g
F
P
p
.002 w
.44864 .4855 m .44244 .48382 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.44244 .48382 m .42269 .4785 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.46863 .4559 m .48376 .46415 L p
.47757 .46715 L 1 g
F P
s
P
p
.46745 .47205 m .46189 .47475 L .45769 .47671 L 1 g
F
P
p
.002 w
.46189 .47475 m .46393 .46902 L p
.47757 .46715 L 1 g
F P
s
P
p
.002 w
.46393 .46902 m .46863 .4559 L p
.47757 .46715 L 1 g
F P
s
P
p
.46863 .4559 m .50987 .46238 L .5 .46387 L 1 g
F
P
p
.48914 .46552 m .48691 .46586 L .47757 .46715 L 1 g
F
P
p
.002 w
.48691 .46586 m .47605 .45995 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.47605 .45995 m .46863 .4559 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.50774 .46514 m .5106 .46142 L p
.52245 .46718 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5106 .46142 m .51575 .4547 L p
.52245 .46718 L 1 g
F P
s
P
p
.002 w
.53302 .47231 m .51575 .4547 L p
.54454 .47786 L 1 g
F P
s
P
p
.002 w
.52885 .46806 m .53302 .47231 L p
.52245 .46718 L 1 g
F P
s
P
p
.002 w
.54252 .47693 m .54302 .47747 L p
.5334 .4725 L 1 g
F P
s
P
p
.002 w
.52245 .46718 m .5227 .4676 L p
.51443 .46607 L 1 g
F P
s
P
p
.002 w
.50987 .46238 m .50774 .46514 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.5227 .4676 m .52282 .46778 L p
.51681 .46663 L 1 g
F P
s
P
p
.48914 .46552 m .49002 .46543 L .48691 .46586 L 1 g
F
P
p
.002 w
.51575 .4547 m .50987 .46238 L p
.46863 .4559 L 1 g
F P
s
P
p
.002 w
.48376 .46415 m .48691 .46586 L p
.47757 .46715 L 1 g
F P
s
P
p
.002 w
.48691 .46586 m .50122 .47365 L p
.47757 .46715 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47757 .46715 L p
1 g
F P
s
P
p
.49002 .46543 m .5 .46442 L .47757 .46715 L 1 g
F
P
p
.46745 .47205 m .47089 .47054 L .46189 .47475 L 1 g
F
P
p
.002 w
.45721 .48781 m .46189 .47475 L p
.50122 .47365 L 1 g
F P
s
P
p
.002 w
.46305 .4715 m .46189 .47475 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.46189 .47475 m .45721 .48781 L p
.45769 .47671 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .47671 L p
1 g
F P
s
P
p
.47089 .47054 m .47718 .46778 L .45769 .47671 L 1 g
F
P
p
.45056 .48363 m .45229 .48198 L .44864 .4855 L 1 g
F
P
p
.002 w
.46863 .4559 m .46305 .4715 L p
.42269 .4785 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44274 .49119 L p
1 g
F P
s
P
p
.45229 .48198 m .45698 .47747 L .44274 .49119 L 1 g
F
P
p
.43416 .5091 m .43416 .50908 L .45721 .48781 L 1 g
F
P
p
.42253 .51983 m .43694 .48234 L .43416 .5091 L 1 g
F
P
p
.002 w
.43416 .50908 m .43287 .51061 L p
.43316 .51872 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43416 .50908 L p
1 g
F P
s
P
p
.43728 .50257 m .44166 .49233 L .43416 .50908 L 1 g
F
P
p
.43316 .51872 m .43313 .51774 L .43304 .51988 L 1 g
F
P
p
.43316 .51872 m .43304 .51988 L .43269 .52846 L 1 g
F
P
p
.002 w
.45721 .48781 m .45681 .52 L .43304 .51988 L p
1 g
F P
s
P
p
.43416 .5091 m .45721 .48781 L .43304 .51988 L 1 g
F
P
p
.002 w
.42999 .51987 m .45681 .52 L p
.43827 .54619 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43269 .52846 L p
1 g
F P
s
P
p
.43313 .51774 m .43287 .51061 L .43269 .52846 L 1 g
F
P
p
.43827 .54619 m .43238 .53632 L .43269 .52846 L 1 g
F
P
p
.002 w
.43269 .52846 m .43146 .53025 L p
.43622 .53966 L 1 g
F P
s
P
p
.002 w
.42578 .52855 m .42253 .51983 L p
.44026 .54951 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43853 .54702 L p
1 g
F P
s
P
p
.43622 .53966 m .43146 .53025 L .43853 .54702 L 1 g
F
P
p
.002 w
.43853 .54702 m .43743 .5491 L p
.44378 .55462 L 1 g
F P
s
P
p
.002 w
.45681 .52 m .46722 .54883 L .44386 .55474 L p
1 g
F P
s
P
p
.44026 .54951 m .45681 .52 L .44386 .55474 L 1 g
F
P
p
.002 w
.44386 .55474 m .46722 .54883 L p
.46312 .57637 L 1 g
F P
s
P
p
.46183 .58508 m .44386 .55474 L .46312 .57637 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45094 .56269 L p
1 g
F P
s
P
p
.44367 .55452 m .43743 .5491 L .45094 .56269 L 1 g
F
P
p
.002 w
.45094 .56269 m .45002 .56518 L p
.46185 .56991 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46838 .57423 L p
1 g
F P
s
P
p
.46185 .56991 m .45002 .56518 L .46838 .57423 L 1 g
F
P
p
.002 w
.46838 .57423 m .46816 .57523 L p
.47325 .57605 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46722 .54883 m .48699 .57122 L .47621 .57716 L p
1 g
F P
s
P
p
.002 w
.46816 .57523 m .4678 .57686 L p
.47874 .57776 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58024 L p
1 g
F P
s
P
p
.47874 .57776 m .4678 .57686 L .48909 .58024 L 1 g
F
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.55265 .56515 m .57451 .56099 L .57601 .5827 L p
1 g
F P
s
P
p
.002 w
.57601 .5827 m .54448 .58883 L .55265 .56515 L p
1 g
F P
s
P
p
.002 w
.66805 .43654 m .65116 .40226 L .66187 .37824 L p
1 g
F P
s
P
p
.002 w
.62835 .34727 m .66187 .37824 L .65116 .40226 L p
1 g
F P
s
P
p
.002 w
.66187 .37824 m .62835 .34727 L .63006 .3214 L p
1 g
F P
s
P
p
.002 w
.63006 .3214 m .58052 .30159 L .57454 .27781 L p
1 g
F P
s
P
p
.002 w
.51379 .27591 m .57454 .27781 L .58052 .30159 L p
1 g
F P
s
P
p
.002 w
.58052 .30159 m .63006 .3214 L .62835 .34727 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.61136 .53436 m .62261 .51463 L .64535 .51592 L p
1 g
F P
s
P
p
.002 w
.65229 .48494 m .64535 .51592 L .62261 .51463 L p
1 g
F P
s
P
p
.002 w
.65229 .48494 m .649 .45449 L .66805 .43654 L p
1 g
F P
s
P
p
.002 w
.65116 .40226 m .66805 .43654 L .649 .45449 L p
1 g
F P
s
P
p
.002 w
.3995 .33263 m .36047 .38469 L .34366 .37011 L p
1 g
F P
s
P
p
.002 w
.34366 .37011 m .38421 .31586 L .3995 .33263 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.51379 .27591 m .45288 .29481 L .4398 .27653 L p
1 g
F P
s
P
p
.002 w
.38421 .31586 m .4398 .27653 L .45288 .29481 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52592 .46011 L
s
P
p
.002 w
.45288 .29481 m .3995 .33263 L .38421 .31586 L p
1 g
F P
s
P
p
.002 w
.62261 .51463 m .62731 .49317 L .65229 .48494 L p
1 g
F P
s
P
p
.002 w
.649 .45449 m .65229 .48494 L .62731 .49317 L p
1 g
F P
s
P
p
.002 w
.38209 .40114 m .36335 .4563 L .34049 .44429 L p
1 g
F P
s
P
p
.002 w
.34049 .44429 m .36047 .38469 L .38209 .40114 L p
1 g
F P
s
P
p
.002 w
.42253 .51983 m .43624 .55667 L .40789 .56055 L p
1 g
F P
s
P
p
.002 w
.40789 .56055 m .39123 .51696 L .42253 .51983 L p
1 g
F P
s
P
p
.002 w
.39104 .46786 m .39123 .51696 L .36394 .51157 L p
1 g
F P
s
P
p
.002 w
.36394 .51157 m .36335 .4563 L .39104 .46786 L p
1 g
F P
s
P
p
.002 w
.58052 .30159 m .52423 .30012 L .51379 .27591 L p
1 g
F P
s
P
p
.002 w
.45288 .29481 m .51379 .27591 L .52423 .30012 L p
1 g
F P
s
P
p
.002 w
.649 .45449 m .63557 .42778 L .65116 .40226 L p
1 g
F P
s
P
p
.002 w
.6227 .3764 m .65116 .40226 L .63557 .42778 L p
1 g
F P
s
P
p
.002 w
.65116 .40226 m .6227 .3764 L .62835 .34727 L p
1 g
F P
s
P
p
.002 w
.58421 .33 m .62835 .34727 L .6227 .3764 L p
1 g
F P
s
P
p
.002 w
.62835 .34727 m .58421 .33 L .58052 .30159 L p
1 g
F P
s
P
p
.002 w
.57068 .53458 m .58111 .52913 L .59476 .55035 L p
1 g
F P
s
P
p
.002 w
.59476 .55035 m .57451 .56099 L .57068 .53458 L p
1 g
F P
s
P
p
.002 w
.61136 .53436 m .59476 .55035 L .58111 .52913 L p
1 g
F P
s
P
p
.002 w
.58111 .52913 m .58965 .52089 L .61136 .53436 L p
1 g
F P
s
P
p
.002 w
.62261 .51463 m .61136 .53436 L .58965 .52089 L p
1 g
F P
s
P
p
.002 w
.52423 .30012 m .58052 .30159 L .58421 .33 L p
1 g
F P
s
P
p
.002 w
.62731 .49317 m .62489 .4722 L .649 .45449 L p
1 g
F P
s
P
p
.002 w
.63557 .42778 m .649 .45449 L .62489 .4722 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.58965 .52089 m .59541 .51073 L .62261 .51463 L p
1 g
F P
s
P
p
.002 w
.62731 .49317 m .62261 .51463 L .59541 .51073 L p
1 g
F P
s
P
p
.002 w
.41837 .35294 m .38209 .40114 L .36047 .38469 L p
1 g
F P
s
P
p
.002 w
.36047 .38469 m .3995 .33263 L .41837 .35294 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.52423 .30012 m .46783 .31783 L .45288 .29481 L p
1 g
F P
s
P
p
.002 w
.3995 .33263 m .45288 .29481 L .46783 .31783 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.59541 .51073 m .59776 .49971 L .62731 .49317 L p
1 g
F P
s
P
p
.002 w
.62489 .4722 m .62731 .49317 L .59776 .49971 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.49974 .53721 m .51313 .55272 L .48699 .57122 L p
1 g
F P
s
P
p
.002 w
.48699 .57122 m .46722 .54883 L .49974 .53721 L p
1 g
F P
s
P
p
.002 w
.46783 .31783 m .41837 .35294 L .3995 .33263 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40793 .41893 m .39104 .46786 L .36335 .4563 L p
1 g
F P
s
P
p
.002 w
.36335 .4563 m .38209 .40114 L .40793 .41893 L p
1 g
F P
s
P
p
.002 w
.42269 .4785 m .42253 .51983 L .39123 .51696 L p
1 g
F P
s
P
p
.002 w
.39123 .51696 m .39104 .46786 L .42269 .4785 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.62489 .4722 m .61548 .45394 L .63557 .42778 L p
1 g
F P
s
P
p
.002 w
.61314 .40782 m .63557 .42778 L .61548 .45394 L p
1 g
F P
s
P
p
.002 w
.63557 .42778 m .61314 .40782 L .6227 .3764 L p
1 g
F P
s
P
p
.002 w
.53932 .53014 m .54861 .53514 L .53145 .56233 L p
1 g
F P
s
P
p
.002 w
.53145 .56233 m .51313 .55272 L .53932 .53014 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5854 .36217 m .6227 .3764 L .61314 .40782 L p
1 g
F P
s
P
p
.002 w
.6227 .3764 m .5854 .36217 L .58421 .33 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.58421 .33 m .5342 .32901 L .52423 .30012 L p
1 g
F P
s
P
p
.002 w
.46783 .31783 m .52423 .30012 L .5342 .32901 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59776 .49971 m .59643 .489 L .62489 .4722 L p
1 g
F P
s
P
p
.002 w
.61548 .45394 m .62489 .4722 L .59643 .489 L p
1 g
F P
s
P
p
.002 w
.5342 .32901 m .58421 .33 L .5854 .36217 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58965 .52089 m .58111 .52913 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.59541 .51073 m .58965 .52089 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59776 .49971 m .59541 .51073 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5326 .52217 m .53932 .53014 L .51313 .55272 L p
1 g
F P
s
P
p
.002 w
.51313 .55272 m .49974 .53721 L .5326 .52217 L p
1 g
F P
s
P
p
.002 w
.49283 .51739 m .49974 .53721 L .46722 .54883 L p
1 g
F P
s
P
p
.002 w
.46722 .54883 m .45681 .52 L .49283 .51739 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.44024 .37618 m .40793 .41893 L .38209 .40114 L p
1 g
F P
s
P
p
.002 w
.38209 .40114 m .41837 .35294 L .44024 .37618 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59643 .489 m .59776 .49971 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.59995 .44042 m .61548 .45394 L .59153 .47975 L p
1 g
F P
s
P
p
.002 w
.59643 .489 m .59153 .47975 L .61548 .45394 L p
1 g
F P
s
P
p
.002 w
.61548 .45394 m .59995 .44042 L .61314 .40782 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.5342 .32901 m .48415 .34494 L .46783 .31783 L p
1 g
F P
s
P
p
.002 w
.41837 .35294 m .46783 .31783 L .48415 .34494 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.58397 .39701 m .61314 .40782 L .59995 .44042 L p
1 g
F P
s
P
p
.002 w
.61314 .40782 m .58397 .39701 L .5854 .36217 L p
1 g
F P
s
P
p
.002 w
.43713 .43742 m .42269 .4785 L .39104 .46786 L p
1 g
F P
s
P
p
.002 w
.39104 .46786 m .40793 .41893 L .43713 .43742 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59153 .47975 m .59643 .489 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.48415 .34494 m .44024 .37618 L .41837 .35294 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.54331 .36164 m .5854 .36217 L .58397 .39701 L p
1 g
F P
s
P
p
.002 w
.5854 .36217 m .54331 .36164 L .5342 .32901 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.48415 .34494 m .5342 .32901 L .54331 .36164 L p
1 g
F P
s
P
p
.002 w
.52921 .51207 m .5326 .52217 L .49974 .53721 L p
1 g
F P
s
P
p
.002 w
.49974 .53721 m .49283 .51739 L .52921 .51207 L p
1 g
F P
s
P
p
.002 w
.58356 .47297 m .59153 .47975 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.59153 .47975 m .58356 .47297 L .59995 .44042 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5799 .43323 m .59995 .44042 L .58356 .47297 L p
1 g
F P
s
P
p
.002 w
.59995 .44042 m .5799 .43323 L .58397 .39701 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4933 .49538 m .49283 .51739 L .45681 .52 L p
1 g
F P
s
P
p
.002 w
.45681 .52 m .45721 .48781 L .4933 .49538 L p
1 g
F P
s
P
p
.002 w
.57335 .46944 m .58356 .47297 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.56201 .46956 m .57335 .46944 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.5508 .47336 m .56201 .46956 L .56456 .50425 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.58356 .47297 m .57335 .46944 L .5799 .43323 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.46438 .40153 m .43713 .43742 L .40793 .41893 L p
1 g
F P
s
P
p
.002 w
.40793 .41893 m .44024 .37618 L .46438 .40153 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42269 .4785 m .43713 .43742 L .46863 .4559 L p
1 g
F P
s
P
p
.002 w
.55118 .39685 m .58397 .39701 L .5799 .43323 L p
1 g
F P
s
P
p
.002 w
.58397 .39701 m .55118 .39685 L .54331 .36164 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.004 w
.56456 .50425 m
.56534 .50514 L
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.004 w
.56643 .50638 m
.56662 .5066 L
s
P
p
.002 w
.52955 .50093 m .52921 .51207 L .49283 .51739 L p
1 g
F P
s
P
p
.002 w
.49283 .51739 m .4933 .49538 L .52955 .50093 L p
1 g
F P
s
P
p
.002 w
.54331 .36164 m .50127 .37523 L .48415 .34494 L p
1 g
F P
s
P
p
.002 w
.44024 .37618 m .48415 .34494 L .50127 .37523 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57335 .46944 m .56201 .46956 L .5575 .4333 L p
1 g
F P
s
P
p
.002 w
.5575 .4333 m .5799 .43323 L .57335 .46944 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.50127 .37523 m .54331 .36164 L .55118 .39685 L p
1 g
F P
s
P
p
.002 w
.50127 .37523 m .46438 .40153 L .44024 .37618 L p
1 g
F P
s
P
p
.002 w
.5799 .43323 m .5575 .4333 L .55118 .39685 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.53361 .48997 m .52955 .50093 L .4933 .49538 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.004 w
.56662 .5066 m
.56724 .50731 L
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.56201 .46956 m .5508 .47336 L .53527 .44072 L p
1 g
F P
s
P
p
.002 w
.53527 .44072 m .5575 .4333 L .56201 .46956 L p
1 g
F P
s
P
p
.002 w
.50122 .47365 m .4933 .49538 L .45721 .48781 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.54097 .48043 m .53361 .48997 L .50122 .47365 L p
1 g
F P
s
P
p
.002 w
.4933 .49538 m .50122 .47365 L .53361 .48997 L p
1 g
F P
s
P
p
.002 w
.51575 .4547 m .53527 .44072 L .5508 .47336 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.48988 .42805 m .46863 .4559 L .43713 .43742 L p
1 g
F P
s
P
p
.002 w
.43713 .43742 m .46438 .40153 L .48988 .42805 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.51854 .40757 m .55118 .39685 L .5575 .4333 L p
1 g
F P
s
P
p
.002 w
.55118 .39685 m .51854 .40757 L .50127 .37523 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.004 w
.56834 .50856 m
.56915 .50949 L
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.004 w
.57026 .51075 m
.5711 .51171 L
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.5575 .4333 m .53527 .44072 L .51854 .40757 L p
1 g
F P
s
P
p
.002 w
.46438 .40153 m .50127 .37523 L .51854 .40757 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51854 .40757 m .48988 .42805 L .46438 .40153 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.46863 .4559 m .48988 .42805 L .51575 .4547 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53527 .44072 m .51575 .4547 L .48988 .42805 L p
1 g
F P
s
P
p
.002 w
.48988 .42805 m .51854 .40757 L .53527 .44072 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.004 w
.57219 .51296 m
.57302 .5139 L
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.004 w
.57414 .51519 m
.57497 .51613 L
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.004 w
.5761 .51743 m
.57694 .51838 L
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.004 w
.57808 .51968 m
.57892 .52064 L
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.58007 .52196 m
.58092 .52292 L
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.004 w
.58207 .52425 m
.58293 .52522 L
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.58495 .52753 m
.60379 .54905 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .79441 .42152 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60379 .54905 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.504651)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.504651)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46937 .48367 m .50869 .4697 L .49551 .44455 L p
1 g
F P
s
P
p
.002 w
.49551 .44455 m .46275 .45608 L .46937 .48367 L p
1 g
F P
s
P
p
.002 w
.52416 .42449 m .49551 .44455 L .50869 .4697 L p
1 g
F P
s
P
p
.002 w
.46275 .45608 m .49551 .44455 L .48247 .41913 L p
1 g
F P
s
P
p
.002 w
.49551 .44455 m .52416 .42449 L .50467 .40356 L p
1 g
F P
s
P
p
.002 w
.50467 .40356 m .48247 .41913 L .49551 .44455 L p
1 g
F P
s
P
p
.002 w
.48247 .41913 m .45706 .42799 L .46275 .45608 L p
1 g
F P
s
P
p
.002 w
.45706 .42799 m .48247 .41913 L .4698 .39388 L p
1 g
F P
s
P
p
.002 w
.48247 .41913 m .50467 .40356 L .48499 .38321 L p
1 g
F P
s
P
p
.002 w
.48499 .38321 m .4698 .39388 L .48247 .41913 L p
1 g
F P
s
P
p
.002 w
.50869 .4697 m .54311 .44561 L .52416 .42449 L p
1 g
F P
s
P
p
.002 w
.54594 .39778 m .52416 .42449 L .54311 .44561 L p
1 g
F P
s
P
p
.002 w
.52416 .42449 m .54594 .39778 L .52145 .3828 L p
1 g
F P
s
P
p
.002 w
.52145 .3828 m .50467 .40356 L .52416 .42449 L p
1 g
F P
s
P
p
.002 w
.50467 .40356 m .52145 .3828 L .49642 .36896 L p
1 g
F P
s
P
p
.002 w
.49642 .36896 m .48499 .38321 L .50467 .40356 L p
1 g
F P
s
P
p
.002 w
.4768 .51022 m .52176 .49411 L .50869 .4697 L p
1 g
F P
s
P
p
.002 w
.50869 .4697 m .46937 .48367 L .4768 .51022 L p
1 g
F P
s
P
p
.002 w
.54311 .44561 m .50869 .4697 L .52176 .49411 L p
1 g
F P
s
P
p
.002 w
.42901 .45787 m .46275 .45608 L .45706 .42799 L p
1 g
F P
s
P
p
.002 w
.45706 .42799 m .43094 .42921 L .42901 .45787 L p
1 g
F P
s
P
p
.002 w
.43094 .42921 m .45706 .42799 L .4524 .39989 L p
1 g
F P
s
P
p
.002 w
.4698 .39388 m .4524 .39989 L .45706 .42799 L p
1 g
F P
s
P
p
.002 w
.42881 .48607 m .46937 .48367 L .46275 .45608 L p
1 g
F P
s
P
p
.002 w
.46275 .45608 m .42901 .45787 L .42881 .48607 L p
1 g
F P
s
P
p
.002 w
.52176 .49411 m .56119 .46656 L .54311 .44561 L p
1 g
F P
s
P
p
.002 w
.56942 .41363 m .54311 .44561 L .56119 .46656 L p
1 g
F P
s
P
p
.002 w
.54311 .44561 m .56942 .41363 L .54594 .39778 L p
1 g
F P
s
P
p
.002 w
.4524 .39989 m .4698 .39388 L .45774 .36926 L p
1 g
F P
s
P
p
.002 w
.4698 .39388 m .48499 .38321 L .46549 .36381 L p
1 g
F P
s
P
p
.002 w
.46549 .36381 m .45774 .36926 L .4698 .39388 L p
1 g
F P
s
P
p
.002 w
.48499 .38321 m .49642 .36896 L .47129 .35652 L p
1 g
F P
s
P
p
.002 w
.47129 .35652 m .46549 .36381 L .48499 .38321 L p
1 g
F P
s
P
p
.002 w
.53109 .35888 m .52145 .3828 L .54594 .39778 L p
1 g
F P
s
P
p
.002 w
.52145 .3828 m .53109 .35888 L .50288 .35258 L p
1 g
F P
s
P
p
.002 w
.50288 .35258 m .49642 .36896 L .52145 .3828 L p
1 g
F P
s
P
p
.002 w
.55863 .36695 m .54594 .39778 L .56942 .41363 L p
1 g
F P
s
P
p
.002 w
.54594 .39778 m .55863 .36695 L .53109 .35888 L p
1 g
F P
s
P
p
.002 w
.4524 .39989 m .43454 .40061 L .43094 .42921 L p
1 g
F P
s
P
p
.002 w
.43454 .40061 m .4524 .39989 L .44886 .3723 L p
1 g
F P
s
P
p
.002 w
.45774 .36926 m .44886 .3723 L .4524 .39989 L p
1 g
F P
s
P
p
.002 w
.43037 .51326 m .4768 .51022 L .46937 .48367 L p
1 g
F P
s
P
p
.002 w
.46937 .48367 m .42881 .48607 L .43037 .51326 L p
1 g
F P
s
P
p
.002 w
.49642 .36896 m .50288 .35258 L .47451 .34816 L p
1 g
F P
s
P
p
.002 w
.47451 .34816 m .47129 .35652 L .49642 .36896 L p
1 g
F P
s
P
p
.002 w
.48492 .53524 m .5345 .51731 L .52176 .49411 L p
1 g
F P
s
P
p
.002 w
.52176 .49411 m .4768 .51022 L .48492 .53524 L p
1 g
F P
s
P
p
.002 w
.56119 .46656 m .52176 .49411 L .5345 .51731 L p
1 g
F P
s
P
p
.002 w
.39761 .44952 m .42901 .45787 L .43094 .42921 L p
1 g
F P
s
P
p
.002 w
.43094 .42921 m .40673 .42252 L .39761 .44952 L p
1 g
F P
s
P
p
.002 w
.40673 .42252 m .43094 .42921 L .43454 .40061 L p
1 g
F P
s
P
p
.002 w
.5345 .51731 m .57803 .48694 L .56119 .46656 L p
1 g
F P
s
P
p
.002 w
.59146 .43007 m .56119 .46656 L .57803 .48694 L p
1 g
F P
s
P
p
.002 w
.56119 .46656 m .59146 .43007 L .56942 .41363 L p
1 g
F P
s
P
p
.002 w
.58497 .37666 m .56942 .41363 L .59146 .43007 L p
1 g
F P
s
P
p
.002 w
.56942 .41363 m .58497 .37666 L .55863 .36695 L p
1 g
F P
s
P
p
.002 w
.43454 .40061 m .41808 .39589 L .40673 .42252 L p
1 g
F P
s
P
p
.002 w
.41808 .39589 m .43454 .40061 L .43977 .37261 L p
1 g
F P
s
P
p
.002 w
.44886 .3723 m .43977 .37261 L .43454 .40061 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .44886 .3723 L .45774 .36926 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .45774 .36926 L .46549 .36381 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .46549 .36381 L .47129 .35652 L closepath p
1 g
F P
s
P
p
.002 w
.39092 .47637 m .42881 .48607 L .42901 .45787 L p
1 g
F P
s
P
p
.002 w
.42901 .45787 m .39761 .44952 L .39092 .47637 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .43977 .37261 L .44886 .3723 L closepath p
1 g
F P
s
P
p
.002 w
.50363 .33572 m .50288 .35258 L .53109 .35888 L p
1 g
F P
s
P
p
.002 w
.50288 .35258 m .50363 .33572 L .4748 .33961 L p
1 g
F P
s
P
p
.002 w
.4748 .33961 m .47451 .34816 L .50288 .35258 L p
1 g
F P
s
P
p
.002 w
.53246 .33416 m .53109 .35888 L .55863 .36695 L p
1 g
F P
s
P
p
.002 w
.53109 .35888 m .53246 .33416 L .50363 .33572 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .47129 .35652 L .47451 .34816 L closepath p
1 g
F P
s
P
p
.002 w
.43369 .53889 m .48492 .53524 L .4768 .51022 L p
1 g
F P
s
P
p
.002 w
.4768 .51022 m .43037 .51326 L .43369 .53889 L p
1 g
F P
s
P
p
.002 w
.43977 .37261 m .43143 .37013 L .41808 .39589 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .43143 .37013 L .43977 .37261 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .47451 .34816 L .4748 .33961 L closepath p
1 g
F P
s
P
p
.002 w
.56073 .33497 m .55863 .36695 L .58497 .37666 L p
1 g
F P
s
P
p
.002 w
.55863 .36695 m .56073 .33497 L .53246 .33416 L p
1 g
F P
s
P
p
.002 w
.387 .40844 m .40673 .42252 L .41808 .39589 L p
1 g
F P
s
P
p
.002 w
.41808 .39589 m .40476 .38615 L .387 .40844 L p
1 g
F P
s
P
p
.002 w
.40476 .38615 m .41808 .39589 L .43143 .37013 L p
1 g
F P
s
P
p
.002 w
.38685 .50253 m .43037 .51326 L .42881 .48607 L p
1 g
F P
s
P
p
.002 w
.42881 .48607 m .39092 .47637 L .38685 .50253 L p
1 g
F P
s
P
p
.002 w
.43143 .37013 m .42474 .36512 L .40476 .38615 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .42474 .36512 L .43143 .37013 L closepath p
1 g
F P
s
P
p
.002 w
.57803 .48694 m .6116 .44679 L .59146 .43007 L p
1 g
F P
s
P
p
.002 w
.60957 .38784 m .59146 .43007 L .6116 .44679 L p
1 g
F P
s
P
p
.002 w
.59146 .43007 m .60957 .38784 L .58497 .37666 L p
1 g
F P
s
P
p
.002 w
.4936 .55818 m .54665 .53885 L .5345 .51731 L p
1 g
F P
s
P
p
.002 w
.5345 .51731 m .48492 .53524 L .4936 .55818 L p
1 g
F P
s
P
p
.002 w
.57803 .48694 m .5345 .51731 L .54665 .53885 L p
1 g
F P
s
P
p
.002 w
.37183 .43156 m .39761 .44952 L .40673 .42252 L p
1 g
F P
s
P
p
.002 w
.40673 .42252 m .387 .40844 L .37183 .43156 L p
1 g
F P
s
P
p
.002 w
.4721 .33177 m .4748 .33961 L .50363 .33572 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .4748 .33961 L .4721 .33177 L closepath p
1 g
F P
s
P
p
.002 w
.49849 .32018 m .50363 .33572 L .53246 .33416 L p
1 g
F P
s
P
p
.002 w
.50363 .33572 m .49849 .32018 L .4721 .33177 L p
1 g
F P
s
P
p
.002 w
.54665 .53885 m .59329 .50634 L .57803 .48694 L p
1 g
F P
s
P
p
.002 w
.6116 .44679 m .57803 .48694 L .59329 .50634 L p
1 g
F P
s
P
p
.002 w
.39609 .37232 m .40476 .38615 L .42474 .36512 L p
1 g
F P
s
P
p
.002 w
.42474 .36512 m .42044 .35807 L .39609 .37232 L p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .42044 .35807 L .42474 .36512 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .4721 .33177 L .46667 .32551 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .46667 .32551 L .45908 .32153 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .45908 .32153 L .45014 .32029 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .45014 .32029 L .44085 .32194 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .44085 .32194 L .43223 .32632 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .43223 .32632 L .42525 .33294 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .42525 .33294 L .42068 .34105 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .42068 .34105 L .41903 .34975 L closepath p
1 g
F P
s
P
p
.002 w
.44653 .34574 m .41903 .34975 L .42044 .35807 L closepath p
1 g
F P
s
P
p
.002 w
.58788 .33817 m .58497 .37666 L .60957 .38784 L p
1 g
F P
s
P
p
.002 w
.58497 .37666 m .58788 .33817 L .56073 .33497 L p
1 g
F P
s
P
p
.002 w
.52518 .31121 m .53246 .33416 L .56073 .33497 L p
1 g
F P
s
P
p
.002 w
.53246 .33416 m .52518 .31121 L .49849 .32018 L p
1 g
F P
s
P
p
.002 w
.46667 .32551 m .4721 .33177 L .49849 .32018 L p
1 g
F P
s
P
p
.002 w
.35962 .45507 m .39092 .47637 L .39761 .44952 L p
1 g
F P
s
P
p
.002 w
.39761 .44952 m .37183 .43156 L .35962 .45507 L p
1 g
F P
s
P
p
.002 w
.37398 .38824 m .387 .40844 L .40476 .38615 L p
1 g
F P
s
P
p
.002 w
.40476 .38615 m .39609 .37232 L .37398 .38824 L p
1 g
F P
s
P
p
.002 w
.43877 .56239 m .4936 .55818 L .48492 .53524 L p
1 g
F P
s
P
p
.002 w
.48492 .53524 m .43369 .53889 L .43877 .56239 L p
1 g
F P
s
P
p
.002 w
.39311 .35585 m .39609 .37232 L .42044 .35807 L p
1 g
F P
s
P
p
.002 w
.42044 .35807 m .41903 .34975 L .39311 .35585 L p
1 g
F P
s
P
p
.002 w
.38557 .52744 m .43369 .53889 L .43037 .51326 L p
1 g
F P
s
P
p
.002 w
.43037 .51326 m .38685 .50253 L .38557 .52744 L p
1 g
F P
s
P
p
.002 w
.49849 .32018 m .48789 .30766 L .46667 .32551 L p
1 g
F P
s
P
p
.002 w
.45908 .32153 m .46667 .32551 L .48789 .30766 L p
1 g
F P
s
P
p
.002 w
.48789 .30766 m .49849 .32018 L .52518 .31121 L p
1 g
F P
s
P
p
.002 w
.59329 .50634 m .62939 .46348 L .6116 .44679 L p
1 g
F P
s
P
p
.002 w
.63191 .40032 m .6116 .44679 L .62939 .46348 L p
1 g
F P
s
P
p
.002 w
.6116 .44679 m .63191 .40032 L .60957 .38784 L p
1 g
F P
s
P
p
.002 w
.55164 .30511 m .56073 .33497 L .58788 .33817 L p
1 g
F P
s
P
p
.002 w
.56073 .33497 m .55164 .30511 L .52518 .31121 L p
1 g
F P
s
P
p
.002 w
.39626 .33851 m .39311 .35585 L .41903 .34975 L p
1 g
F P
s
P
p
.002 w
.41903 .34975 m .42068 .34105 L .39626 .33851 L p
1 g
F P
s
P
p
.002 w
.35464 .40554 m .37183 .43156 L .387 .40844 L p
1 g
F P
s
P
p
.002 w
.387 .40844 m .37398 .38824 L .35464 .40554 L p
1 g
F P
s
P
p
.002 w
.48789 .30766 m .4729 .2996 L .45908 .32153 L p
1 g
F P
s
P
p
.002 w
.45014 .32029 m .45908 .32153 L .4729 .2996 L p
1 g
F P
s
P
p
.002 w
.61332 .34377 m .60957 .38784 L .63191 .40032 L p
1 g
F P
s
P
p
.002 w
.60957 .38784 m .61332 .34377 L .58788 .33817 L p
1 g
F P
s
P
p
.002 w
.50267 .57851 m .55794 .55823 L .54665 .53885 L p
1 g
F P
s
P
p
.002 w
.54665 .53885 m .4936 .55818 L .50267 .57851 L p
1 g
F P
s
P
p
.002 w
.59329 .50634 m .54665 .53885 L .55794 .55823 L p
1 g
F P
s
P
p
.002 w
.35073 .47848 m .38685 .50253 L .39092 .47637 L p
1 g
F P
s
P
p
.002 w
.39092 .47637 m .35962 .45507 L .35073 .47848 L p
1 g
F P
s
P
p
.002 w
.36933 .36396 m .37398 .38824 L .39609 .37232 L p
1 g
F P
s
P
p
.002 w
.39609 .37232 m .39311 .35585 L .36933 .36396 L p
1 g
F P
s
P
p
.002 w
.4053 .32226 m .39626 .33851 L .42068 .34105 L p
1 g
F P
s
P
p
.002 w
.42068 .34105 m .42525 .33294 L .4053 .32226 L p
1 g
F P
s
P
p
.002 w
.55794 .55823 m .6066 .52435 L .59329 .50634 L p
1 g
F P
s
P
p
.002 w
.62939 .46348 m .59329 .50634 L .6066 .52435 L p
1 g
F P
s
P
p
.002 w
.4729 .2996 m .45511 .297 L .45014 .32029 L p
1 g
F P
s
P
p
.002 w
.44085 .32194 m .45014 .32029 L .45511 .297 L p
1 g
F P
s
P
p
.002 w
.50978 .29258 m .52518 .31121 L .55164 .30511 L p
1 g
F P
s
P
p
.002 w
.52518 .31121 m .50978 .29258 L .48789 .30766 L p
1 g
F P
s
P
p
.002 w
.41924 .30899 m .4053 .32226 L .42525 .33294 L p
1 g
F P
s
P
p
.002 w
.42525 .33294 m .43223 .32632 L .41924 .30899 L p
1 g
F P
s
P
p
.002 w
.4729 .2996 m .48789 .30766 L .50978 .29258 L p
1 g
F P
s
P
p
.002 w
.45511 .297 m .43651 .30024 L .44085 .32194 L p
1 g
F P
s
P
p
.002 w
.43223 .32632 m .44085 .32194 L .43651 .30024 L p
1 g
F P
s
P
p
.002 w
.43651 .30024 m .41924 .30899 L .43223 .32632 L p
1 g
F P
s
P
p
.002 w
.38719 .55051 m .43877 .56239 L .43369 .53889 L p
1 g
F P
s
P
p
.002 w
.43369 .53889 m .38557 .52744 L .38719 .55051 L p
1 g
F P
s
P
p
.002 w
.57732 .30207 m .58788 .33817 L .61332 .34377 L p
1 g
F P
s
P
p
.002 w
.58788 .33817 m .57732 .30207 L .55164 .30511 L p
1 g
F P
s
P
p
.002 w
.44557 .58316 m .50267 .57851 L .4936 .55818 L p
1 g
F P
s
P
p
.002 w
.4936 .55818 m .43877 .56239 L .44557 .58316 L p
1 g
F P
s
P
p
.002 w
.33856 .42389 m .35962 .45507 L .37183 .43156 L p
1 g
F P
s
P
p
.002 w
.37183 .43156 m .35464 .40554 L .33856 .42389 L p
1 g
F P
s
P
p
.002 w
.37382 .33824 m .36933 .36396 L .39311 .35585 L p
1 g
F P
s
P
p
.002 w
.39311 .35585 m .39626 .33851 L .37382 .33824 L p
1 g
F P
s
P
p
.002 w
.34829 .374 m .35464 .40554 L .37398 .38824 L p
1 g
F P
s
P
p
.002 w
.37398 .38824 m .36933 .36396 L .34829 .374 L p
1 g
F P
s
P
p
.002 w
.6066 .52435 m .64438 .47978 L .62939 .46348 L p
1 g
F P
s
P
p
.002 w
.65144 .41387 m .62939 .46348 L .64438 .47978 L p
1 g
F P
s
P
p
.002 w
.62939 .46348 m .65144 .41387 L .63191 .40032 L p
1 g
F P
s
P
p
.002 w
.50978 .29258 m .48773 .28047 L .4729 .2996 L p
1 g
F P
s
P
p
.002 w
.45511 .297 m .4729 .2996 L .48773 .28047 L p
1 g
F P
s
P
p
.002 w
.34547 .50126 m .38557 .52744 L .38685 .50253 L p
1 g
F P
s
P
p
.002 w
.38685 .50253 m .35073 .47848 L .34547 .50126 L p
1 g
F P
s
P
p
.002 w
.63647 .35172 m .63191 .40032 L .65144 .41387 L p
1 g
F P
s
P
p
.002 w
.63191 .40032 m .63647 .35172 L .61332 .34377 L p
1 g
F P
s
P
p
.002 w
.5319 .28069 m .55164 .30511 L .57732 .30207 L p
1 g
F P
s
P
p
.002 w
.55164 .30511 m .5319 .28069 L .50978 .29258 L p
1 g
F P
s
P
p
.002 w
.48773 .28047 m .50978 .29258 L .5319 .28069 L p
1 g
F P
s
P
p
.002 w
.38716 .31403 m .37382 .33824 L .39626 .33851 L p
1 g
F P
s
P
p
.002 w
.39626 .33851 m .4053 .32226 L .38716 .31403 L p
1 g
F P
s
P
p
.002 w
.51197 .59567 m .56811 .57494 L .55794 .55823 L p
1 g
F P
s
P
p
.002 w
.55794 .55823 m .50267 .57851 L .51197 .59567 L p
1 g
F P
s
P
p
.002 w
.6066 .52435 m .55794 .55823 L .56811 .57494 L p
1 g
F P
s
P
p
.002 w
.48773 .28047 m .46136 .27646 L .45511 .297 L p
1 g
F P
s
P
p
.002 w
.43651 .30024 m .45511 .297 L .46136 .27646 L p
1 g
F P
s
P
p
.002 w
.56811 .57494 m .6176 .54052 L .6066 .52435 L p
1 g
F P
s
P
p
.002 w
.64438 .47978 m .6066 .52435 L .6176 .54052 L p
1 g
F P
s
P
p
.002 w
.32623 .44293 m .35073 .47848 L .35962 .45507 L p
1 g
F P
s
P
p
.002 w
.35962 .45507 m .33856 .42389 L .32623 .44293 L p
1 g
F P
s
P
p
.002 w
.60163 .30225 m .61332 .34377 L .63647 .35172 L p
1 g
F P
s
P
p
.002 w
.61332 .34377 m .60163 .30225 L .57732 .30207 L p
1 g
F P
s
P
p
.002 w
.40791 .29422 m .38716 .31403 L .4053 .32226 L p
1 g
F P
s
P
p
.002 w
.4053 .32226 m .41924 .30899 L .40791 .29422 L p
1 g
F P
s
P
p
.002 w
.46136 .27646 m .43367 .28119 L .43651 .30024 L p
1 g
F P
s
P
p
.002 w
.41924 .30899 m .43651 .30024 L .43367 .28119 L p
1 g
F P
s
P
p
.002 w
.39182 .57115 m .44557 .58316 L .43877 .56239 L p
1 g
F P
s
P
p
.002 w
.43877 .56239 m .38719 .55051 L .39182 .57115 L p
1 g
F P
s
P
p
.002 w
.43367 .28119 m .40791 .29422 L .41924 .30899 L p
1 g
F P
s
P
p
.002 w
.35395 .34036 m .34829 .374 L .36933 .36396 L p
1 g
F P
s
P
p
.002 w
.36933 .36396 m .37382 .33824 L .35395 .34036 L p
1 g
F P
s
P
p
.002 w
.33058 .38581 m .33856 .42389 L .35464 .40554 L p
1 g
F P
s
P
p
.002 w
.35464 .40554 m .34829 .374 L .33058 .38581 L p
1 g
F P
s
P
p
.002 w
.45401 .60063 m .51197 .59567 L .50267 .57851 L p
1 g
F P
s
P
p
.002 w
.50267 .57851 m .44557 .58316 L .45401 .60063 L p
1 g
F P
s
P
p
.002 w
.55378 .27235 m .57732 .30207 L .60163 .30225 L p
1 g
F P
s
P
p
.002 w
.57732 .30207 m .55378 .27235 L .5319 .28069 L p
1 g
F P
s
P
p
.002 w
.34411 .52288 m .38719 .55051 L .38557 .52744 L p
1 g
F P
s
P
p
.002 w
.38557 .52744 m .34547 .50126 L .34411 .52288 L p
1 g
F P
s
P
p
.002 w
.5319 .28069 m .50329 .26468 L .48773 .28047 L p
1 g
F P
s
P
p
.002 w
.46136 .27646 m .48773 .28047 L .50329 .26468 L p
1 g
F P
s
P
p
.002 w
.64438 .47978 m .66762 .42824 L .65144 .41387 L p
1 g
F P
s
P
p
.002 w
.65672 .36193 m .65144 .41387 L .66762 .42824 L p
1 g
F P
s
P
p
.002 w
.65144 .41387 m .65672 .36193 L .63647 .35172 L p
1 g
F P
s
P
p
.002 w
.6176 .54052 m .65611 .49533 L .64438 .47978 L p
1 g
F P
s
P
p
.002 w
.66762 .42824 m .64438 .47978 L .65611 .49533 L p
1 g
F P
s
P
p
.002 w
.50329 .26468 m .5319 .28069 L .55378 .27235 L p
1 g
F P
s
P
p
.002 w
.37133 .30856 m .35395 .34036 L .37382 .33824 L p
1 g
F P
s
P
p
.002 w
.37382 .33824 m .38716 .31403 L .37133 .30856 L p
1 g
F P
s
P
p
.002 w
.31811 .46224 m .34547 .50126 L .35073 .47848 L p
1 g
F P
s
P
p
.002 w
.35073 .47848 m .32623 .44293 L .31811 .46224 L p
1 g
F P
s
P
p
.002 w
.62398 .30579 m .63647 .35172 L .65672 .36193 L p
1 g
F P
s
P
p
.002 w
.63647 .35172 m .62398 .30579 L .60163 .30225 L p
1 g
F P
s
P
p
.002 w
.50329 .26468 m .46883 .25925 L .46136 .27646 L p
1 g
F P
s
P
p
.002 w
.43367 .28119 m .46136 .27646 L .46883 .25925 L p
1 g
F P
s
P
p
.002 w
.52128 .60911 m .57686 .58848 L .56811 .57494 L p
1 g
F P
s
P
p
.002 w
.56811 .57494 m .51197 .59567 L .52128 .60911 L p
1 g
F P
s
P
p
.002 w
.6176 .54052 m .56811 .57494 L .57686 .58848 L p
1 g
F P
s
P
p
.002 w
.57686 .58848 m .62591 .55439 L .6176 .54052 L p
1 g
F P
s
P
p
.002 w
.65611 .49533 m .6176 .54052 L .62591 .55439 L p
1 g
F P
s
P
p
.002 w
.31676 .39921 m .32623 .44293 L .33856 .42389 L p
1 g
F P
s
P
p
.002 w
.33856 .42389 m .33058 .38581 L .31676 .39921 L p
1 g
F P
s
P
p
.002 w
.33724 .34494 m .33058 .38581 L .34829 .374 L p
1 g
F P
s
P
p
.002 w
.34829 .374 m .35395 .34036 L .33724 .34494 L p
1 g
F P
s
P
p
.002 w
.39948 .58875 m .45401 .60063 L .44557 .58316 L p
1 g
F P
s
P
p
.002 w
.44557 .58316 m .39182 .57115 L .39948 .58875 L p
1 g
F P
s
P
p
.002 w
.39857 .28248 m .37133 .30856 L .38716 .31403 L p
1 g
F P
s
P
p
.002 w
.38716 .31403 m .40791 .29422 L .39857 .28248 L p
1 g
F P
s
P
p
.002 w
.46883 .25925 m .43246 .26536 L .43367 .28119 L p
1 g
F P
s
P
p
.002 w
.40791 .29422 m .43367 .28119 L .43246 .26536 L p
1 g
F P
s
P
p
.002 w
.5749 .26791 m .60163 .30225 L .62398 .30579 L p
1 g
F P
s
P
p
.002 w
.60163 .30225 m .5749 .26791 L .55378 .27235 L p
1 g
F P
s
P
p
.002 w
.43246 .26536 m .39857 .28248 L .40791 .29422 L p
1 g
F P
s
P
p
.002 w
.34689 .54273 m .39182 .57115 L .38719 .55051 L p
1 g
F P
s
P
p
.002 w
.38719 .55051 m .34411 .52288 L .34689 .54273 L p
1 g
F P
s
P
p
.002 w
.46397 .6142 m .52128 .60911 L .51197 .59567 L p
1 g
F P
s
P
p
.002 w
.51197 .59567 m .45401 .60063 L .46397 .6142 L p
1 g
F P
s
P
p
.002 w
.55378 .27235 m .51927 .25272 L .50329 .26468 L p
1 g
F P
s
P
p
.002 w
.46883 .25925 m .50329 .26468 L .51927 .25272 L p
1 g
F P
s
P
p
.002 w
.51927 .25272 m .55378 .27235 L .5749 .26791 L p
1 g
F P
s
P
p
.002 w
.65611 .49533 m .67994 .44315 L .66762 .42824 L p
1 g
F P
s
P
p
.002 w
.67348 .37426 m .66762 .42824 L .67994 .44315 L p
1 g
F P
s
P
p
.002 w
.66762 .42824 m .67348 .37426 L .65672 .36193 L p
1 g
F P
s
P
p
.002 w
.62591 .55439 m .66416 .50974 L .65611 .49533 L p
1 g
F P
s
P
p
.002 w
.67994 .44315 m .65611 .49533 L .66416 .50974 L p
1 g
F P
s
P
p
.002 w
.31462 .48136 m .34411 .52288 L .34547 .50126 L p
1 g
F P
s
P
p
.002 w
.34547 .50126 m .31811 .46224 L .31462 .48136 L p
1 g
F P
s
P
p
.002 w
.64375 .31275 m .65672 .36193 L .67348 .37426 L p
1 g
F P
s
P
p
.002 w
.65672 .36193 m .64375 .31275 L .62398 .30579 L p
1 g
F P
s
P
p
.002 w
.35831 .30613 m .33724 .34494 L .35395 .34036 L p
1 g
F P
s
P
p
.002 w
.35395 .34036 m .37133 .30856 L .35831 .30613 L p
1 g
F P
s
P
p
.002 w
.51927 .25272 m .4774 .24595 L .46883 .25925 L p
1 g
F P
s
P
p
.002 w
.43246 .26536 m .46883 .25925 L .4774 .24595 L p
1 g
F P
s
P
p
.002 w
.3074 .41393 m .31811 .46224 L .32623 .44293 L p
1 g
F P
s
P
p
.002 w
.32623 .44293 m .31676 .39921 L .3074 .41393 L p
1 g
F P
s
P
p
.002 w
.32427 .35201 m .31676 .39921 L .33058 .38581 L p
1 g
F P
s
P
p
.002 w
.33058 .38581 m .33724 .34494 L .32427 .35201 L p
1 g
F P
s
P
p
.002 w
.53039 .6183 m .58391 .59836 L .57686 .58848 L p
1 g
F P
s
P
p
.002 w
.57686 .58848 m .52128 .60911 L .53039 .6183 L p
1 g
F P
s
P
p
.002 w
.62591 .55439 m .57686 .58848 L .58391 .59836 L p
1 g
F P
s
P
p
.002 w
.59473 .26766 m .62398 .30579 L .64375 .31275 L p
1 g
F P
s
P
p
.002 w
.62398 .30579 m .59473 .26766 L .5749 .26791 L p
1 g
F P
s
P
p
.002 w
.41015 .60269 m .46397 .6142 L .45401 .60063 L p
1 g
F P
s
P
p
.002 w
.45401 .60063 m .39948 .58875 L .41015 .60269 L p
1 g
F P
s
P
p
.002 w
.58391 .59836 m .6312 .56551 L .62591 .55439 L p
1 g
F P
s
P
p
.002 w
.66416 .50974 m .62591 .55439 L .6312 .56551 L p
1 g
F P
s
P
p
.002 w
.39158 .27423 m .35831 .30613 L .37133 .30856 L p
1 g
F P
s
P
p
.002 w
.37133 .30856 m .39857 .28248 L .39158 .27423 L p
1 g
F P
s
P
p
.002 w
.35393 .56023 m .39948 .58875 L .39182 .57115 L p
1 g
F P
s
P
p
.002 w
.39182 .57115 m .34689 .54273 L .35393 .56023 L p
1 g
F P
s
P
p
.002 w
.4774 .24595 m .43301 .25332 L .43246 .26536 L p
1 g
F P
s
P
p
.002 w
.39857 .28248 m .43246 .26536 L .43301 .25332 L p
1 g
F P
s
P
p
.002 w
.5749 .26791 m .5353 .24508 L .51927 .25272 L p
1 g
F P
s
P
p
.002 w
.4774 .24595 m .51927 .25272 L .5353 .24508 L p
1 g
F P
s
P
p
.002 w
.5353 .24508 m .5749 .26791 L .59473 .26766 L p
1 g
F P
s
P
p
.002 w
.43301 .25332 m .39158 .27423 L .39857 .28248 L p
1 g
F P
s
P
p
.002 w
.4753 .62332 m .53039 .6183 L .52128 .60911 L p
1 g
F P
s
P
p
.002 w
.52128 .60911 m .46397 .6142 L .4753 .62332 L p
1 g
F P
s
P
p
.002 w
.66416 .50974 m .68788 .45826 L .67994 .44315 L p
1 g
F P
s
P
p
.002 w
.68616 .38853 m .67994 .44315 L .68788 .45826 L p
1 g
F P
s
P
p
.002 w
.67994 .44315 m .68616 .38853 L .67348 .37426 L p
1 g
F P
s
P
p
.002 w
.31608 .49976 m .34689 .54273 L .34411 .52288 L p
1 g
F P
s
P
p
.002 w
.34411 .52288 m .31462 .48136 L .31608 .49976 L p
1 g
F P
s
P
p
.002 w
.6312 .56551 m .6681 .52258 L .66416 .50974 L p
1 g
F P
s
P
p
.002 w
.68788 .45826 m .66416 .50974 L .6681 .52258 L p
1 g
F P
s
P
p
.002 w
.66031 .32312 m .67348 .37426 L .68616 .38853 L p
1 g
F P
s
P
p
.002 w
.67348 .37426 m .66031 .32312 L .64375 .31275 L p
1 g
F P
s
P
p
.002 w
.34862 .30698 m .32427 .35201 L .33724 .34494 L p
1 g
F P
s
P
p
.002 w
.33724 .34494 m .35831 .30613 L .34862 .30698 L p
1 g
F P
s
P
p
.002 w
.30298 .42967 m .31462 .48136 L .31811 .46224 L p
1 g
F P
s
P
p
.002 w
.31811 .46224 m .3074 .41393 L .30298 .42967 L p
1 g
F P
s
P
p
.002 w
.61268 .27182 m .64375 .31275 L .66031 .32312 L p
1 g
F P
s
P
p
.002 w
.64375 .31275 m .61268 .27182 L .59473 .26766 L p
1 g
F P
s
P
p
.002 w
.31561 .36151 m .3074 .41393 L .31676 .39921 L p
1 g
F P
s
P
p
.002 w
.31676 .39921 m .32427 .35201 L .31561 .36151 L p
1 g
F P
s
P
p
.002 w
.5353 .24508 m .48692 .23711 L .4774 .24595 L p
1 g
F P
s
P
p
.002 w
.43301 .25332 m .4774 .24595 L .48692 .23711 L p
1 g
F P
s
P
p
.002 w
.4237 .6124 m .4753 .62332 L .46397 .6142 L p
1 g
F P
s
P
p
.002 w
.46397 .6142 m .41015 .60269 L .4237 .6124 L p
1 g
F P
s
P
p
.002 w
.36527 .57476 m .41015 .60269 L .39948 .58875 L p
1 g
F P
s
P
p
.002 w
.39948 .58875 m .35393 .56023 L .36527 .57476 L p
1 g
F P
s
P
p
.002 w
.53905 .62273 m .58898 .60409 L .58391 .59836 L p
1 g
F P
s
P
p
.002 w
.58391 .59836 m .53039 .6183 L .53905 .62273 L p
1 g
F P
s
P
p
.002 w
.6312 .56551 m .58391 .59836 L .58898 .60409 L p
1 g
F P
s
P
p
.002 w
.58898 .60409 m .63314 .57342 L .6312 .56551 L p
1 g
F P
s
P
p
.002 w
.6681 .52258 m .6312 .56551 L .63314 .57342 L p
1 g
F P
s
P
p
.002 w
.55098 .24221 m .59473 .26766 L .61268 .27182 L p
1 g
F P
s
P
p
.002 w
.59473 .26766 m .55098 .24221 L .5353 .24508 L p
1 g
F P
s
P
p
.002 w
.38725 .2699 m .34862 .30698 L .35831 .30613 L p
1 g
F P
s
P
p
.002 w
.35831 .30613 m .39158 .27423 L .38725 .2699 L p
1 g
F P
s
P
p
.002 w
.48692 .23711 m .5353 .24508 L .55098 .24221 L p
1 g
F P
s
P
p
.002 w
.48692 .23711 m .43541 .24561 L .43301 .25332 L p
1 g
F P
s
P
p
.002 w
.39158 .27423 m .43301 .25332 L .43541 .24561 L p
1 g
F P
s
P
p
.002 w
.32274 .51691 m .35393 .56023 L .34689 .54273 L p
1 g
F P
s
P
p
.002 w
.34689 .54273 m .31608 .49976 L .32274 .51691 L p
1 g
F P
s
P
p
.002 w
.6681 .52258 m .69101 .47319 L .68788 .45826 L p
1 g
F P
s
P
p
.002 w
.69421 .40447 m .68788 .45826 L .69101 .47319 L p
1 g
F P
s
P
p
.002 w
.68788 .45826 m .69421 .40447 L .68616 .38853 L p
1 g
F P
s
P
p
.002 w
.43541 .24561 m .38725 .2699 L .39158 .27423 L p
1 g
F P
s
P
p
.002 w
.48777 .62747 m .53905 .62273 L .53039 .6183 L p
1 g
F P
s
P
p
.002 w
.53039 .6183 m .4753 .62332 L .48777 .62747 L p
1 g
F P
s
P
p
.002 w
.67306 .33681 m .68616 .38853 L .69421 .40447 L p
1 g
F P
s
P
p
.002 w
.68616 .38853 m .67306 .33681 L .66031 .32312 L p
1 g
F P
s
P
p
.002 w
.63314 .57342 m .66759 .53342 L .6681 .52258 L p
1 g
F P
s
P
p
.002 w
.69101 .47319 m .6681 .52258 L .66759 .53342 L p
1 g
F P
s
P
p
.002 w
.30392 .44604 m .31608 .49976 L .31462 .48136 L p
1 g
F P
s
P
p
.002 w
.31462 .48136 m .30298 .42967 L .30392 .44604 L p
1 g
F P
s
P
p
.002 w
.34271 .31131 m .31561 .36151 L .32427 .35201 L p
1 g
F P
s
P
p
.002 w
.32427 .35201 m .34862 .30698 L .34271 .31131 L p
1 g
F P
s
P
p
.002 w
.62819 .28052 m .66031 .32312 L .67306 .33681 L p
1 g
F P
s
P
p
.002 w
.66031 .32312 m .62819 .28052 L .61268 .27182 L p
1 g
F P
s
P
p
.002 w
.31177 .37334 m .30298 .42967 L .3074 .41393 L p
1 g
F P
s
P
p
.002 w
.3074 .41393 m .31561 .36151 L .31177 .37334 L p
1 g
F P
s
P
p
.002 w
.55098 .24221 m .4972 .23326 L .48692 .23711 L p
1 g
F P
s
P
p
.002 w
.43541 .24561 m .48692 .23711 L .4972 .23326 L p
1 g
F P
s
P
p
.002 w
.38084 .58576 m .4237 .6124 L .41015 .60269 L p
1 g
F P
s
P
p
.002 w
.41015 .60269 m .36527 .57476 L .38084 .58576 L p
1 g
F P
s
P
p
.002 w
.43991 .61737 m .48777 .62747 L .4753 .62332 L p
1 g
F P
s
P
p
.002 w
.4753 .62332 m .4237 .6124 L .43991 .61737 L p
1 g
F P
s
P
p
.002 w
.56585 .24444 m .61268 .27182 L .62819 .28052 L p
1 g
F P
s
P
p
.002 w
.61268 .27182 m .56585 .24444 L .55098 .24221 L p
1 g
F P
s
P
p
.002 w
.54698 .62198 m .59179 .60524 L .58898 .60409 L p
1 g
F P
s
P
p
.002 w
.58898 .60409 m .53905 .62273 L .54698 .62198 L p
1 g
F P
s
P
p
.002 w
.63314 .57342 m .58898 .60409 L .59179 .60524 L p
1 g
F P
s
P
p
.002 w
.4972 .23326 m .55098 .24221 L .56585 .24444 L p
1 g
F P
s
P
p
.002 w
.59179 .60524 m .63146 .5777 L .63314 .57342 L p
1 g
F P
s
P
p
.002 w
.66759 .53342 m .63314 .57342 L .63146 .5777 L p
1 g
F P
s
P
p
.002 w
.33467 .53223 m .36527 .57476 L .35393 .56023 L p
1 g
F P
s
P
p
.002 w
.35393 .56023 m .32274 .51691 L .33467 .53223 L p
1 g
F P
s
P
p
.002 w
.38588 .26987 m .34271 .31131 L .34862 .30698 L p
1 g
F P
s
P
p
.002 w
.34862 .30698 m .38725 .2699 L .38588 .26987 L p
1 g
F P
s
P
p
.002 w
.66759 .53342 m .68894 .48752 L .69101 .47319 L p
1 g
F P
s
P
p
.002 w
.69101 .47319 m .69716 .42172 L .69421 .40447 L p
1 g
F P
s
P
p
.002 w
.69716 .42172 m .69101 .47319 L .68894 .48752 L p
1 g
F P
s
P
p
.002 w
.4972 .23326 m .43972 .24272 L .43541 .24561 L p
1 g
F P
s
P
p
.002 w
.38725 .2699 m .43541 .24561 L .43972 .24272 L p
1 g
F P
s
P
p
.002 w
.69421 .40447 m .68143 .35363 L .67306 .33681 L p
1 g
F P
s
P
p
.002 w
.68143 .35363 m .69421 .40447 L .69716 .42172 L p
1 g
F P
s
P
p
.002 w
.50109 .62622 m .54698 .62198 L .53905 .62273 L p
1 g
F P
s
P
p
.002 w
.53905 .62273 m .48777 .62747 L .50109 .62622 L p
1 g
F P
s
P
p
.002 w
.43972 .24272 m .38588 .26987 L .38725 .2699 L p
1 g
F P
s
P
p
.002 w
.3105 .4626 m .32274 .51691 L .31608 .49976 L p
1 g
F P
s
P
p
.002 w
.31608 .49976 m .30392 .44604 L .3105 .4626 L p
1 g
F P
s
P
p
.002 w
.63146 .5777 m .66236 .54183 L .66759 .53342 L p
1 g
F P
s
P
p
.002 w
.68894 .48752 m .66759 .53342 L .66236 .54183 L p
1 g
F P
s
P
p
.002 w
.67306 .33681 m .64066 .29377 L .62819 .28052 L p
1 g
F P
s
P
p
.002 w
.64066 .29377 m .67306 .33681 L .68143 .35363 L p
1 g
F P
s
P
p
.002 w
.34103 .31921 m .31177 .37334 L .31561 .36151 L p
1 g
F P
s
P
p
.002 w
.31561 .36151 m .34271 .31131 L .34103 .31921 L p
1 g
F P
s
P
p
.002 w
.31316 .38729 m .30392 .44604 L .30298 .42967 L p
1 g
F P
s
P
p
.002 w
.30298 .42967 m .31177 .37334 L .31316 .38729 L p
1 g
F P
s
P
p
.002 w
.40038 .59269 m .43991 .61737 L .4237 .6124 L p
1 g
F P
s
P
p
.002 w
.4237 .6124 m .38084 .58576 L .40038 .59269 L p
1 g
F P
s
P
p
.002 w
.56585 .24444 m .50799 .23481 L .4972 .23326 L p
1 g
F P
s
P
p
.002 w
.43972 .24272 m .4972 .23326 L .50799 .23481 L p
1 g
F P
s
P
p
.002 w
.62819 .28052 m .57945 .25202 L .56585 .24444 L p
1 g
F P
s
P
p
.002 w
.57945 .25202 m .62819 .28052 L .64066 .29377 L p
1 g
F P
s
P
p
.002 w
.45846 .61717 m .50109 .62622 L .48777 .62747 L p
1 g
F P
s
P
p
.002 w
.48777 .62747 m .43991 .61737 L .45846 .61717 L p
1 g
F P
s
P
p
.002 w
.3518 .54515 m .38084 .58576 L .36527 .57476 L p
1 g
F P
s
P
p
.002 w
.36527 .57476 m .33467 .53223 L .3518 .54515 L p
1 g
F P
s
P
p
.002 w
.50799 .23481 m .56585 .24444 L .57945 .25202 L p
1 g
F P
s
P
p
.002 w
.55393 .61574 m .59213 .60149 L .59179 .60524 L p
1 g
F P
s
P
p
.002 w
.59179 .60524 m .54698 .62198 L .55393 .61574 L p
1 g
F P
s
P
p
.002 w
.63146 .5777 m .59179 .60524 L .59213 .60149 L p
1 g
F P
s
P
p
.002 w
.66236 .54183 m .68143 .50081 L .68894 .48752 L p
1 g
F P
s
P
p
.004 w
.68742 .5105 m
.77508 .54791 L
s
P
p
.004 w
.68081 .50768 m
.68742 .5105 L
s
P
p
.004 w
.5 .43051 m
.67867 .50676 L
s
P
p
.004 w
.67948 .50711 m
.68081 .50768 L
s
P
p
.002 w
.69463 .43987 m .68894 .48752 L .68143 .50081 L p
1 g
F P
s
P
p
.002 w
.68894 .48752 m .69463 .43987 L .69716 .42172 L p
1 g
F P
s
P
p
.002 w
.38771 .27443 m .34103 .31921 L .34271 .31131 L p
1 g
F P
s
P
p
.002 w
.34271 .31131 m .38588 .26987 L .38771 .27443 L p
1 g
F P
s
P
p
.002 w
.68494 .37324 m .69716 .42172 L .69463 .43987 L p
1 g
F P
s
P
p
.002 w
.69716 .42172 m .68494 .37324 L .68143 .35363 L p
1 g
F P
s
P
p
.002 w
.59213 .60149 m .62597 .57799 L .63146 .5777 L p
1 g
F P
s
P
p
.002 w
.66236 .54183 m .63146 .5777 L .62597 .57799 L p
1 g
F P
s
P
p
.002 w
.50799 .23481 m .44593 .24505 L .43972 .24272 L p
1 g
F P
s
P
p
.002 w
.38588 .26987 m .43972 .24272 L .44593 .24505 L p
1 g
F P
s
P
p
.002 w
.32284 .47883 m .33467 .53223 L .32274 .51691 L p
1 g
F P
s
P
p
.002 w
.32274 .51691 m .3105 .4626 L .32284 .47883 L p
1 g
F P
s
P
p
.002 w
.51492 .61929 m .55393 .61574 L .54698 .62198 L p
1 g
F P
s
P
p
.002 w
.54698 .62198 m .50109 .62622 L .51492 .61929 L p
1 g
F P
s
P
p
.002 w
.44593 .24505 m .38771 .27443 L .38588 .26987 L p
1 g
F P
s
P
p
.002 w
.64956 .31143 m .68143 .35363 L .68494 .37324 L p
1 g
F P
s
P
p
.002 w
.68143 .35363 m .64956 .31143 L .64066 .29377 L p
1 g
F P
s
P
p
.002 w
.62597 .57799 m .65227 .54742 L .66236 .54183 L p
1 g
F P
s
P
p
.002 w
.68143 .50081 m .66236 .54183 L .65227 .54742 L p
1 g
F P
s
P
p
.002 w
.34388 .33068 m .31316 .38729 L .31177 .37334 L p
1 g
F P
s
P
p
.002 w
.31177 .37334 m .34103 .31921 L .34388 .33068 L p
1 g
F P
s
P
p
.002 w
.32006 .40306 m .3105 .4626 L .30392 .44604 L p
1 g
F P
s
P
p
.002 w
.30392 .44604 m .31316 .38729 L .32006 .40306 L p
1 g
F P
s
P
p
.002 w
.4235 .59512 m .45846 .61717 L .43991 .61737 L p
1 g
F P
s
P
p
.002 w
.43991 .61737 m .40038 .59269 L .4235 .59512 L p
1 g
F P
s
P
p
.002 w
.59129 .26503 m .64066 .29377 L .64956 .31143 L p
1 g
F P
s
P
p
.002 w
.64066 .29377 m .59129 .26503 L .57945 .25202 L p
1 g
F P
s
P
p
.002 w
.57945 .25202 m .519 .24205 L .50799 .23481 L p
1 g
F P
s
P
p
.002 w
.44593 .24505 m .50799 .23481 L .519 .24205 L p
1 g
F P
s
P
p
.002 w
.4789 .61151 m .51492 .61929 L .50109 .62622 L p
1 g
F P
s
P
p
.002 w
.50109 .62622 m .45846 .61717 L .4789 .61151 L p
1 g
F P
s
P
p
.002 w
.37386 .55514 m .40038 .59269 L .38084 .58576 L p
1 g
F P
s
P
p
.002 w
.38084 .58576 m .3518 .54515 L .37386 .55514 L p
1 g
F P
s
P
p
.002 w
.519 .24205 m .57945 .25202 L .59129 .26503 L p
1 g
F P
s
P
p
.002 w
.68143 .50081 m .68639 .45842 L .69463 .43987 L p
1 g
F P
s
P
p
.002 w
.68321 .3952 m .69463 .43987 L .68639 .45842 L p
1 g
F P
s
P
p
.002 w
.69463 .43987 m .68321 .3952 L .68494 .37324 L p
1 g
F P
s
P
p
.002 w
.65227 .54742 m .66838 .51259 L .68143 .50081 L p
1 g
F P
s
P
p
.002 w
.68639 .45842 m .68143 .50081 L .66838 .51259 L p
1 g
F P
s
P
p
.002 w
.55959 .60385 m .58981 .5926 L .59213 .60149 L p
1 g
F P
s
P
p
.002 w
.59213 .60149 m .55393 .61574 L .55959 .60385 L p
1 g
F P
s
P
p
.002 w
.62597 .57799 m .59213 .60149 L .58981 .5926 L p
1 g
F P
s
P
p
.002 w
.34084 .49418 m .3518 .54515 L .33467 .53223 L p
1 g
F P
s
P
p
.002 w
.33467 .53223 m .32284 .47883 L .34084 .49418 L p
1 g
F P
s
P
p
.002 w
.3929 .28374 m .34388 .33068 L .34103 .31921 L p
1 g
F P
s
P
p
.002 w
.34103 .31921 m .38771 .27443 L .3929 .28374 L p
1 g
F P
s
P
p
.002 w
.58981 .5926 m .61658 .574 L .62597 .57799 L p
1 g
F P
s
P
p
.002 w
.65227 .54742 m .62597 .57799 L .61658 .574 L p
1 g
F P
s
P
p
.002 w
.65441 .33317 m .68494 .37324 L .68321 .3952 L p
1 g
F P
s
P
p
.002 w
.68494 .37324 m .65441 .33317 L .64956 .31143 L p
1 g
F P
s
P
p
.002 w
.519 .24205 m .45399 .25288 L .44593 .24505 L p
1 g
F P
s
P
p
.002 w
.38771 .27443 m .44593 .24505 L .45399 .25288 L p
1 g
F P
s
P
p
.002 w
.52885 .60657 m .55959 .60385 L .55393 .61574 L p
1 g
F P
s
P
p
.002 w
.55393 .61574 m .51492 .61929 L .52885 .60657 L p
1 g
F P
s
P
p
.002 w
.45399 .25288 m .3929 .28374 L .38771 .27443 L p
1 g
F P
s
P
p
.002 w
.33255 .42022 m .32284 .47883 L .3105 .4626 L p
1 g
F P
s
P
p
.002 w
.3105 .4626 m .32006 .40306 L .33255 .42022 L p
1 g
F P
s
P
p
.002 w
.61658 .574 m .63732 .54983 L .65227 .54742 L p
1 g
F P
s
P
p
.002 w
.66838 .51259 m .65227 .54742 L .63732 .54983 L p
1 g
F P
s
P
p
.002 w
.35147 .34557 m .32006 .40306 L .31316 .38729 L p
1 g
F P
s
P
p
.002 w
.31316 .38729 m .34388 .33068 L .35147 .34557 L p
1 g
F P
s
P
p
.002 w
.4496 .59275 m .4789 .61151 L .45846 .61717 L p
1 g
F P
s
P
p
.002 w
.45846 .61717 m .4235 .59512 L .4496 .59275 L p
1 g
F P
s
P
p
.002 w
.60089 .28338 m .64956 .31143 L .65441 .33317 L p
1 g
F P
s
P
p
.002 w
.64956 .31143 m .60089 .28338 L .59129 .26503 L p
1 g
F P
s
P
p
.002 w
.40032 .56171 m .4235 .59512 L .40038 .59269 L p
1 g
F P
s
P
p
.002 w
.40038 .59269 m .37386 .55514 L .40032 .56171 L p
1 g
F P
s
P
p
.002 w
.59129 .26503 m .52989 .25512 L .519 .24205 L p
1 g
F P
s
P
p
.002 w
.45399 .25288 m .519 .24205 L .52989 .25512 L p
1 g
F P
s
P
p
.002 w
.50063 .60031 m .52885 .60657 L .51492 .61929 L p
1 g
F P
s
P
p
.002 w
.51492 .61929 m .4789 .61151 L .50063 .60031 L p
1 g
F P
s
P
p
.002 w
.52989 .25512 m .59129 .26503 L .60089 .28338 L p
1 g
F P
s
P
p
.002 w
.66838 .51259 m .67241 .47678 L .68639 .45842 L p
1 g
F P
s
P
p
.002 w
.67605 .4189 m .68639 .45842 L .67241 .47678 L p
1 g
F P
s
P
p
.002 w
.68639 .45842 m .67605 .4189 L .68321 .3952 L p
1 g
F P
s
P
p
.002 w
.36417 .5081 m .37386 .55514 L .3518 .54515 L p
1 g
F P
s
P
p
.002 w
.3518 .54515 m .34084 .49418 L .36417 .5081 L p
1 g
F P
s
P
p
.002 w
.63732 .54983 m .6499 .52238 L .66838 .51259 L p
1 g
F P
s
P
p
.002 w
.67241 .47678 m .66838 .51259 L .6499 .52238 L p
1 g
F P
s
P
p
.002 w
.65485 .3585 m .68321 .3952 L .67605 .4189 L p
1 g
F P
s
P
p
.002 w
.68321 .3952 m .65485 .3585 L .65441 .33317 L p
1 g
F P
s
P
p
.002 w
.56371 .58634 m .58473 .57855 L .58981 .5926 L p
1 g
F P
s
P
p
.002 w
.58981 .5926 m .55959 .60385 L .56371 .58634 L p
1 g
F P
s
P
p
.002 w
.61658 .574 m .58981 .5926 L .58473 .57855 L p
1 g
F P
s
P
p
.004 w
.59408 .57965 m
.60614 .59876 L
s
P
p
.002 w
.40148 .29781 m .35147 .34557 L .34388 .33068 L p
1 g
F P
s
P
p
.002 w
.34388 .33068 m .3929 .28374 L .40148 .29781 L p
1 g
F P
s
P
p
.002 w
.58473 .57855 m .60335 .56561 L .61658 .574 L p
1 g
F P
s
P
p
.002 w
.63732 .54983 m .61658 .574 L .60335 .56561 L p
1 g
F P
s
P
p
.002 w
.3505 .43827 m .34084 .49418 L .32284 .47883 L p
1 g
F P
s
P
p
.002 w
.32284 .47883 m .33255 .42022 L .3505 .43827 L p
1 g
F P
s
P
p
.002 w
.52989 .25512 m .46374 .2663 L .45399 .25288 L p
1 g
F P
s
P
p
.002 w
.3929 .28374 m .45399 .25288 L .46374 .2663 L p
1 g
F P
s
P
p
.002 w
.54241 .58814 m .56371 .58634 L .55959 .60385 L p
1 g
F P
s
P
p
.002 w
.55959 .60385 m .52885 .60657 L .54241 .58814 L p
1 g
F P
s
P
p
.002 w
.60781 .30674 m .65441 .33317 L .65485 .3585 L p
1 g
F P
s
P
p
.002 w
.65441 .33317 m .60781 .30674 L .60089 .28338 L p
1 g
F P
s
P
p
.002 w
.47792 .58546 m .50063 .60031 L .4789 .61151 L p
1 g
F P
s
P
p
.002 w
.4789 .61151 m .4496 .59275 L .47792 .58546 L p
1 g
F P
s
P
p
.002 w
.3638 .36357 m .33255 .42022 L .32006 .40306 L p
1 g
F P
s
P
p
.002 w
.32006 .40306 m .35147 .34557 L .3638 .36357 L p
1 g
F P
s
P
p
.002 w
.60335 .56561 m .61772 .54879 L .63732 .54983 L p
1 g
F P
s
P
p
.002 w
.6499 .52238 m .63732 .54983 L .61772 .54879 L p
1 g
F P
s
P
p
.002 w
.46374 .2663 m .40148 .29781 L .3929 .28374 L p
1 g
F P
s
P
p
.002 w
.43047 .5645 m .4496 .59275 L .4235 .59512 L p
1 g
F P
s
P
p
.002 w
.4235 .59512 m .40032 .56171 L .43047 .5645 L p
1 g
F P
s
P
p
.002 w
.6499 .52238 m .65286 .49434 L .67241 .47678 L p
1 g
F P
s
P
p
.002 w
.66343 .44364 m .67241 .47678 L .65286 .49434 L p
1 g
F P
s
P
p
.002 w
.67241 .47678 m .66343 .44364 L .67605 .4189 L p
1 g
F P
s
P
p
.002 w
.523 .58368 m .54241 .58814 L .52885 .60657 L p
1 g
F P
s
P
p
.002 w
.52885 .60657 m .50063 .60031 L .523 .58368 L p
1 g
F P
s
P
p
.002 w
.54029 .2739 m .60089 .28338 L .60781 .30674 L p
1 g
F P
s
P
p
.002 w
.60089 .28338 m .54029 .2739 L .52989 .25512 L p
1 g
F P
s
P
p
.002 w
.46374 .2663 m .52989 .25512 L .54029 .2739 L p
1 g
F P
s
P
p
.002 w
.39221 .52002 m .40032 .56171 L .37386 .55514 L p
1 g
F P
s
P
p
.002 w
.37386 .55514 m .36417 .5081 L .39221 .52002 L p
1 g
F P
s
P
p
.002 w
.65066 .3867 m .67605 .4189 L .66343 .44364 L p
1 g
F P
s
P
p
.002 w
.67605 .4189 m .65066 .3867 L .65485 .3585 L p
1 g
F P
s
P
p
.002 w
.61772 .54879 m .62632 .52976 L .6499 .52238 L p
1 g
F P
s
P
p
.002 w
.65286 .49434 m .6499 .52238 L .62632 .52976 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37352 .45658 m .36417 .5081 L .34084 .49418 L p
1 g
F P
s
P
p
.002 w
.34084 .49418 m .3505 .43827 L .37352 .45658 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.41337 .31641 m .3638 .36357 L .35147 .34557 L p
1 g
F P
s
P
p
.002 w
.35147 .34557 m .40148 .29781 L .41337 .31641 L p
1 g
F P
s
P
p
.002 w
.61168 .33452 m .65485 .3585 L .65066 .3867 L p
1 g
F P
s
P
p
.002 w
.65485 .3585 m .61168 .33452 L .60781 .30674 L p
1 g
F P
s
P
p
.002 w
.56606 .56349 m .5769 .5595 L .58473 .57855 L p
1 g
F P
s
P
p
.002 w
.58473 .57855 m .56371 .58634 L .56606 .56349 L p
1 g
F P
s
P
p
.002 w
.60335 .56561 m .58473 .57855 L .5769 .5595 L p
1 g
F P
s
P
p
.002 w
.5769 .5595 m .58651 .55282 L .60335 .56561 L p
1 g
F P
s
P
p
.002 w
.61772 .54879 m .60335 .56561 L .58651 .55282 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.45965 .57119 m .46831 .57452 L .47792 .58546 L 1 g
F
P
p
.002 w
.47154 .57576 m .4725 .57721 L p
.46831 .57452 L 1 g
F P
s
P
p
.002 w
.4725 .57721 m .47792 .58546 L p
.46831 .57452 L 1 g
F P
s
P
p
.002 w
.47792 .58546 m .4496 .59275 L p
.45965 .57119 L 1 g
F P
s
P
p
.002 w
.46831 .57452 m .46872 .57265 L p
.46003 .56918 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46824 .57483 L p
1 g
F P
s
P
p
.48921 .57862 m .46824 .57483 L .47861 .57775 L 1 g
F
P
p
.002 w
.48906 .5807 m .48921 .57862 L p
.47861 .57775 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46333 .56328 m .49779 .55798 L p
.48267 .57889 L 1 g
F P
s
P
p
.002 w
.47792 .58546 m .47154 .57576 L p
.48267 .57889 L 1 g
F P
s
P
p
.002 w
.47154 .57576 m .46333 .56328 L p
.48267 .57889 L 1 g
F P
s
P
p
.002 w
.48934 .58077 m .47792 .58546 L p
.48166 .58029 L 1 g
F P
s
P
p
.48166 .58029 m .48267 .57889 L .48906 .5807 L 1 g
F
P
p
.48166 .58029 m .48906 .5807 L .48934 .58077 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .5807 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .5807 L .48947 .58072 L 1 g
F
P
p
.51079 .57862 m .48947 .58072 L .50042 .58069 L 1 g
F
P
p
.48906 .5807 m .47621 .57755 L .4797 .57889 L 1 g
F
P
p
.002 w
.50063 .60031 m .47792 .58546 L .48934 .58077 L p
1 g
F P
s
P
p
.002 w
.48893 .58244 m .48905 .58072 L p
.4797 .57889 L 1 g
F P
s
P
p
.002 w
.48905 .58072 m .48906 .5807 L p
.4797 .57889 L 1 g
F P
s
P
p
.002 w
.48934 .58077 m .48947 .58072 L p
.48953 .58081 L 1 g
F P
s
P
p
.50063 .60031 m .48934 .58077 L .48953 .58081 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.50063 .60031 m .48947 .58072 L .50565 .58068 L 1 g
F
P
p
.002 w
.523 .58368 m .50063 .60031 L p
.50537 .58178 L 1 g
F P
s
P
p
.50537 .58178 m .50565 .58068 L .50846 .58117 L 1 g
F
P
p
.50537 .58178 m .50846 .58117 L .523 .58368 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58067 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .58067 L .51677 .5795 L 1 g
F
P
p
.53128 .57265 m .51677 .5795 L .51994 .57847 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.523 .58368 m .51677 .5795 L p
.527 .57617 L 1 g
F P
s
P
p
.002 w
.53254 .57436 m .523 .58368 L p
.52595 .57813 L 1 g
F P
s
P
p
.52595 .57813 m .527 .57617 L .53171 .57463 L 1 g
F
P
p
.52595 .57813 m .53171 .57463 L .53254 .57436 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57463 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57463 L .53318 .57374 L 1 g
F
P
p
.54854 .56129 m .53318 .57374 L .53998 .56945 L 1 g
F
P
p
.002 w
.54241 .58814 m .523 .58368 L .53254 .57436 L p
1 g
F P
s
P
p
.002 w
.51848 .58065 m .523 .58368 L p
.50565 .58068 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58067 L p
1 g
F P
s
P
p
.002 w
.51094 .58067 m .51079 .57862 L p
.50042 .58069 L 1 g
F P
s
P
p
.50042 .58069 m .48889 .583 L .51094 .58067 L 1 g
F
P
p
.002 w
.50754 .57331 m .51677 .5795 L p
.50565 .58068 L 1 g
F P
s
P
p
.002 w
.51677 .5795 m .51848 .58065 L p
.51094 .58067 L 1 g
F P
s
P
p
.50565 .58068 m .51677 .5795 L .51094 .58067 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53211 .57643 L p
1 g
F P
s
P
p
.002 w
.53211 .57643 m .53172 .57466 L p
.52267 .57832 L 1 g
F P
s
P
p
.52267 .57832 m .51111 .583 L .53211 .57643 L 1 g
F
P
p
.002 w
.53172 .57466 m .53128 .57265 L p
.5167 .58013 L 1 g
F P
s
P
p
.5167 .58013 m .51111 .583 L .53172 .57466 L 1 g
F
P
p
.002 w
.53254 .57436 m .53318 .57374 L p
.53338 .57405 L 1 g
F P
s
P
p
.54241 .58814 m .53254 .57436 L .53338 .57405 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54241 .58814 m .53318 .57374 L .54473 .56645 L 1 g
F
P
p
.002 w
.55511 .56436 m .54241 .58814 L p
.54473 .56645 L 1 g
F P
s
P
p
.002 w
.54999 .56313 m .55511 .56436 L p
.54703 .56599 L 1 g
F P
s
P
p
.54473 .56645 m .54937 .56352 L .54703 .56599 L 1 g
F
P
p
.54937 .56352 m .54999 .56313 L .54703 .56599 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54937 .56352 L p
1 g
F P
s
P
p
.56075 .54566 m .54937 .56352 L .54979 .56309 L 1 g
F
P
p
.002 w
.55511 .56436 m .54979 .56309 L p
.56161 .54729 L 1 g
F P
s
P
p
.002 w
.56225 .54643 m .55887 .55492 L p
.56161 .54729 L 1 g
F P
s
P
p
.002 w
.55887 .55492 m .55511 .56436 L p
.56161 .54729 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56161 .54729 L p
1 g
F P
s
P
p
.56654 .52734 m .56161 .54729 L .56423 .54001 L 1 g
F
P
p
.56075 .54566 m .54979 .56309 L .55492 .55623 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56606 .56349 m .55549 .56433 L p
.56225 .54643 L 1 g
F P
s
P
p
.002 w
.55549 .56433 m .55511 .56436 L .55887 .55492 L p
1 g
F P
s
P
p
.002 w
.55887 .55492 m .56225 .54643 L p
.55549 .56433 L 1 g
F P
s
P
p
.002 w
.56646 .53587 m .56225 .54643 L p
.56176 .54688 L 1 g
F P
s
P
p
.002 w
.56162 .54729 m .56075 .54566 L p
.55469 .55664 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56512 .53752 m .56646 .53587 L p
.56176 .54688 L 1 g
F P
s
P
p
.002 w
.56225 .54643 m .56646 .53587 L .56639 .54085 L p
1 g
F P
s
P
p
.002 w
.56639 .54085 m .56606 .56349 L p
.56225 .54643 L 1 g
F P
s
P
p
.002 w
.5769 .5595 m .56606 .56349 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.58651 .55282 m .5769 .5595 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.59388 .54413 m .58651 .55282 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.59823 .53435 m .59388 .54413 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.59907 .52448 m .59823 .53435 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.56545 .53659 m .56646 .53587 L .56512 .53752 L p
1 g
F P
s
P
p
.002 w
.59628 .5156 m .59907 .52448 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.56654 .52734 m .56421 .54011 L .56545 .53659 L 1 g
F
P
p
.56654 .52734 m .56545 .53659 L .56558 .53621 L 1 g
F
P
p
.002 w
.56566 .53595 m .56646 .53587 L .56558 .53621 L p
1 g
F P
s
P
p
.56563 .53606 m .56558 .53621 L .56563 .53607 L 1 g
F
P
p
.56654 .52734 m .56558 .53621 L .56563 .53606 L 1 g
F
P
p
.56654 .52734 m .56563 .53607 L .56567 .53593 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.5326 .54874 m .53133 .53923 L .56566 .53595 L p
1 g
F P
s
P
p
.002 w
.56558 .53621 m .5326 .54874 L p
.56566 .53595 L 1 g
F P
s
P
p
.56654 .52734 m .56567 .53595 L .56571 .53581 L 1 g
F
P
p
.56654 .52734 m .56571 .53584 L .56575 .53569 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.53133 .53923 m .53378 .5291 L .56574 .53572 L p
1 g
F P
s
P
p
.002 w
.56574 .53572 m .56646 .53587 L .56566 .53595 L p
1 g
F P
s
P
p
.002 w
.56566 .53595 m .53133 .53923 L p
.56574 .53572 L 1 g
F P
s
P
p
.56567 .53593 m .56563 .53607 L .56567 .53595 L 1 g
F
P
p
.56571 .53581 m .56567 .53595 L .56571 .53584 L 1 g
F
P
p
.56654 .52734 m .56574 .53573 L .56579 .53557 L 1 g
F
P
p
.56654 .52734 m .56578 .53562 L .56583 .53544 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.53378 .5291 m .53972 .51947 L .56581 .53547 L p
1 g
F P
s
P
p
.002 w
.56581 .53547 m .56646 .53587 L .56574 .53572 L p
1 g
F P
s
P
p
.002 w
.56574 .53572 m .53378 .5291 L p
.56581 .53547 L 1 g
F P
s
P
p
.002 w
.56756 .52882 m .56654 .52734 L p
.56582 .53549 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53972 .51947 m .54851 .51144 L .56591 .53512 L p
1 g
F P
s
P
p
.002 w
.56591 .53512 m .56646 .53587 L .56581 .53547 L p
1 g
F P
s
P
p
.002 w
.56581 .53547 m .53972 .51947 L p
.56591 .53512 L 1 g
F P
s
P
p
.56575 .53569 m .56571 .53584 L .56574 .53573 L 1 g
F
P
p
.56579 .53557 m .56574 .53573 L .56578 .53562 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.54851 .51144 m .55916 .50591 L .5661 .53439 L p
1 g
F P
s
P
p
.002 w
.5661 .53439 m .56646 .53587 L .56591 .53512 L p
1 g
F P
s
P
p
.002 w
.56591 .53512 m .54851 .51144 L p
.5661 .53439 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.57048 .5035 m .57406 .50382 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56756 .52882 L p
1 g
F P
s
P
p
.56515 .50826 m .56756 .52882 L .56756 .52878 L 1 g
F
P
p
.002 w
.56748 .52768 m .57048 .5035 L p
.56756 .52882 L 1 g
F P
s
P
p
.56515 .50826 m .56756 .52878 L .5669 .51963 L 1 g
F
P
p
.56756 .52878 m .56756 .52883 L .56748 .52768 L 1 g
F
P
p
.56756 .52878 m .56748 .52768 L .5669 .51963 L 1 g
F
P
p
.002 w
.57406 .50382 m .58119 .50446 L p
.56761 .52957 L 1 g
F P
s
P
p
.56756 .52882 m .56761 .52957 L .56713 .53045 L 1 g
F
P
p
.57406 .50382 m .56761 .52957 L .56756 .52882 L 1 g
F
P
p
.002 w
.56713 .53045 m .56748 .52768 L p
.56756 .52882 L 1 g
F P
s
P
p
.002 w
.56756 .52882 m .56756 .52883 L p
.56756 .52878 L 1 g
F P
s
P
p
.002 w
.56582 .50449 m .57048 .5035 L .56898 .51556 L p
1 g
F P
s
P
p
.002 w
.56898 .51556 m .56748 .52768 L p
.56618 .50948 L 1 g
F P
s
P
p
.56582 .50449 m .56898 .51556 L .56618 .50948 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56618 .50948 L p
1 g
F P
s
P
p
.55661 .4905 m .56618 .50948 L .56405 .50487 L 1 g
F
P
p
.002 w
.55187 .48009 m .54987 .473 L p
.5585 .49241 L 1 g
F P
s
P
p
.5585 .49241 m .56405 .50487 L .5574 .49134 L 1 g
F
P
p
.5585 .49241 m .5574 .49134 L .55187 .48009 L 1 g
F
P
p
.55661 .4905 m .56405 .50487 L .56288 .5025 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.57048 .5035 m .56405 .50487 L p
.54987 .473 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55916 .50591 m .56405 .50487 L p
.56713 .53045 L 1 g
F P
s
P
p
.002 w
.56405 .50487 m .56582 .50449 L p
.56606 .50923 L 1 g
F P
s
P
p
.002 w
.58119 .50446 m .56784 .53292 L p
.56761 .52957 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56621 .50953 L p
1 g
F P
s
P
p
.002 w
.56621 .50953 m .56515 .50826 L p
.56693 .5198 L 1 g
F P
s
P
p
.56693 .5198 m .56854 .53025 L .56621 .50953 L 1 g
F
P
p
.002 w
.56646 .53587 m .56713 .53045 L p
.56761 .52957 L 1 g
F P
s
P
p
.002 w
.56784 .53292 m .56646 .53587 L p
.56761 .52957 L 1 g
F P
s
P
p
.56405 .50487 m .56606 .50923 L .56713 .53045 L 1 g
F
P
p
.002 w
.56748 .52768 m .56713 .53045 L p
.56582 .50449 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55818 .49216 L p
1 g
F P
s
P
p
.002 w
.55818 .49216 m .55661 .4905 L p
.56348 .50364 L 1 g
F P
s
P
p
.56348 .50364 m .56713 .51061 L .55818 .49216 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5574 .49134 L p
1 g
F P
s
P
p
.54174 .47608 m .5574 .49134 L .55417 .48821 L 1 g
F
P
p
.002 w
.55417 .48821 m .55916 .50591 L p
.54244 .47685 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47685 L p
1 g
F P
s
P
p
.52214 .46667 m .54244 .47685 L .54244 .47685 L 1 g
F
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54244 .47685 m .52866 .48397 L .51608 .4663 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46714 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46714 L .51608 .4663 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51608 .4663 m .52866 .48397 L p
.49864 .4641 L 1 g
F P
s
P
p
.5 .46388 m .51608 .4663 L .49864 .4641 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.48207 .47812 m .49694 .46437 L p
.52866 .48397 L 1 g
F P
s
P
p
.49694 .46437 m .49864 .4641 L .52866 .48397 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49694 .46437 m .48207 .47812 L .47199 .4699 L p
1 g
F P
s
P
p
.47758 .46714 m .49694 .46437 L .47199 .4699 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47758 .46714 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44658 .48747 m .44952 .48462 L .48207 .47812 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47199 .4699 m .48207 .47812 L p
.44952 .48462 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45785 .47653 L p
1 g
F P
s
P
p
.44339 .4905 m .45785 .47653 L .44865 .48546 L 1 g
F
P
p
.434 .48771 m .45785 .47653 L .44952 .48462 L 1 g
F
P
p
.45785 .47653 m .47199 .4699 L .44952 .48462 L 1 g
F
P
p
.002 w
.45785 .47653 m .45698 .47747 L p
.44865 .48546 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44265 .49129 L p
1 g
F P
s
P
p
.43485 .50826 m .44265 .49129 L .44131 .49395 L 1 g
F
P
p
.002 w
.44063 .49531 m .43187 .49134 L p
.44426 .48808 L 1 g
F P
s
P
p
.43485 .50826 m .44239 .49156 L .43796 .50099 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.48207 .47812 m .46518 .50643 L .44063 .49531 L p
1 g
F P
s
P
p
.002 w
.44265 .49129 m .44339 .4905 L p
.44865 .48546 L 1 g
F P
s
P
p
.44426 .48808 m .48207 .47812 L .44063 .49531 L 1 g
F
P
p
.002 w
.44265 .49129 m .44239 .49156 L p
.44131 .49395 L 1 g
F P
s
P
p
.002 w
.42411 .52944 m .43187 .49134 L .43549 .49298 L p
1 g
F P
s
P
p
.002 w
.43549 .49298 m .44063 .49531 L p
.43419 .50861 L 1 g
F P
s
P
p
.42411 .52944 m .43549 .49298 L .43419 .50861 L 1 g
F
P
p
.002 w
.43253 .5287 m .43346 .52734 L p
.43322 .52038 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43415 .50909 L p
1 g
F P
s
P
p
.43346 .52734 m .43415 .50909 L .43322 .52038 L 1 g
F
P
p
.002 w
.44063 .49531 m .46518 .50643 L p
.43287 .52453 L 1 g
F P
s
P
p
.42475 .52908 m .43415 .50909 L .43287 .52453 L 1 g
F
P
p
.42411 .52944 m .44063 .49531 L .42475 .52908 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.43415 .50909 m .44063 .49531 L .43287 .52453 L 1 g
F
P
p
.002 w
.43415 .50909 m .43287 .51061 L p
.43322 .52038 L 1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43314 .53114 m .42411 .52944 L p
.43165 .52522 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43236 .52894 L p
1 g
F P
s
P
p
.002 w
.43047 .5645 m .42411 .52944 L .43314 .53114 L p
1 g
F P
s
P
p
.43047 .5645 m .43255 .53849 L .44115 .55374 L 1 g
F
P
p
.43255 .53849 m .43314 .53114 L .43867 .54675 L 1 g
F
P
p
.43255 .53849 m .43867 .54675 L .44115 .55374 L 1 g
F
P
p
.43925 .54566 m .43236 .52894 L .43603 .5393 L 1 g
F
P
p
.002 w
.43759 .5488 m .43925 .54566 L p
.43437 .53601 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43867 .54675 L p
1 g
F P
s
P
p
.45146 .56129 m .43867 .54675 L .44581 .55638 L 1 g
F
P
p
.002 w
.43314 .53114 m .45879 .53596 L p
.44269 .55218 L 1 g
F P
s
P
p
.44115 .55374 m .43867 .54675 L .44269 .55218 L 1 g
F
P
p
.43867 .54675 m .43314 .53114 L .44269 .55218 L 1 g
F
P
p
.002 w
.45079 .5631 m .45146 .56129 L p
.44581 .55638 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .5631 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .5631 L .45156 .56372 L 1 g
F
P
p
.46872 .57265 m .45156 .56372 L .46003 .56918 L 1 g
F
P
p
.002 w
.46333 .56328 m .47154 .57576 L p
.46831 .57452 L 1 g
F P
s
P
p
.45965 .57119 m .46046 .56945 L .46831 .57452 L 1 g
F
P
p
.46046 .56945 m .46333 .56328 L .46831 .57452 L 1 g
F
P
p
.002 w
.4496 .59275 m .43047 .5645 L .45156 .56372 L p
1 g
F P
s
P
p
.002 w
.45156 .56372 m .46333 .56328 L p
.46046 .56945 L 1 g
F P
s
P
p
.4496 .59275 m .45156 .56372 L .46046 .56945 L 1 g
F
P
p
.45667 .56784 m .45156 .56372 L .45002 .56518 L 1 g
F
P
p
.002 w
.45156 .56372 m .43047 .5645 L p
.44026 .55463 L 1 g
F P
s
P
p
.002 w
.45079 .5631 m .45075 .5632 L p
.45156 .56372 L 1 g
F P
s
P
p
.002 w
.45075 .5632 m .45002 .56518 L p
.45156 .56372 L 1 g
F P
s
P
p
.46003 .56918 m .45156 .56372 L .45667 .56784 L 1 g
F
P
p
.002 w
.45879 .53596 m .46333 .56328 L .45156 .56372 L p
1 g
F P
s
P
p
.44026 .55463 m .45879 .53596 L .45156 .56372 L 1 g
F
P
p
.002 w
.43867 .54675 m .43743 .5491 L p
.44581 .55638 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .5631 L p
1 g
F P
s
P
p
.44581 .55638 m .43743 .5491 L .45079 .5631 L 1 g
F
P
p
.002 w
.43236 .52894 m .43146 .53025 L p
.43603 .5393 L 1 g
F P
s
P
p
.002 w
.46518 .50643 m .45879 .53596 L .43314 .53114 L p
1 g
F P
s
P
p
.43165 .52522 m .46518 .50643 L .43314 .53114 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43759 .5488 L p
1 g
F P
s
P
p
.43437 .53601 m .43146 .53025 L .43759 .5488 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43253 .5287 L p
1 g
F P
s
P
p
.43322 .52038 m .43287 .51061 L .43253 .5287 L 1 g
F
P
p
.002 w
.44239 .49156 m .44166 .49233 L p
.43796 .50099 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44265 .49129 L p
1 g
F P
s
P
p
.44865 .48546 m .45698 .47747 L .44265 .49129 L 1 g
F
P
p
.002 w
.43187 .49134 m .434 .48771 L p
.44952 .48462 L 1 g
F P
s
P
p
.43187 .49134 m .44952 .48462 L .44658 .48747 L 1 g
F
P
p
.45826 .47608 m .47758 .46714 L .46909 .47133 L 1 g
F
P
p
.002 w
.45725 .47718 m .45826 .47608 L p
.46909 .47133 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.434 .48771 m .45337 .45468 L .47199 .4699 L p
1 g
F P
s
P
p
.46909 .47133 m .47199 .4699 L .47718 .46778 L 1 g
F
P
p
.002 w
.47758 .46714 m .47746 .46733 L p
.47199 .4699 L 1 g
F P
s
P
p
.002 w
.47746 .46733 m .47718 .46778 L p
.47199 .4699 L 1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.46995 .46823 m .45337 .45468 L p
.48745 .46226 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .49694 .46437 L 1 g
F
P
p
.48821 .46562 m .49694 .46437 L .4907 .46536 L 1 g
F
P
p
.47786 .46667 m .49694 .46437 L .48821 .46562 L 1 g
F
P
p
.002 w
.47737 .46749 m .47786 .46667 L p
.4907 .46536 L 1 g
F P
s
P
p
.48745 .46226 m .49694 .46437 L .47758 .46714 L 1 g
F
P
p
.48745 .46226 m .47758 .46714 L .46995 .46823 L 1 g
F
P
p
.002 w
.47199 .4699 m .46995 .46823 L p
.47758 .46714 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45725 .47718 L p
1 g
F P
s
P
p
.46909 .47133 m .47718 .46778 L .45725 .47718 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.50765 .45446 m .49694 .46437 L p
.45337 .45468 L 1 g
F P
s
P
p
.4907 .46536 m .49694 .46437 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46388 m .5 .46393 L p
.49694 .46437 L 1 g
F P
s
P
p
.002 w
.5 .46393 m .5 .46442 L p
.49694 .46437 L 1 g
F P
s
P
p
.002 w
.49694 .46437 m .49782 .46356 L p
.49864 .4641 L 1 g
F P
s
P
p
.49782 .46356 m .5 .46388 L .49864 .4641 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47737 .46749 L p
1 g
F P
s
P
p
.4907 .46536 m .5 .46442 L .47737 .46749 L 1 g
F
P
p
.51148 .46561 m .51608 .4663 L .5128 .46586 L 1 g
F
P
p
.5 .4634 m .51608 .4663 L .51148 .46561 L 1 g
F
P
p
.52242 .46714 m .54244 .47685 L .51608 .4663 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49782 .46356 m .50765 .45446 L .51608 .4663 L p
1 g
F P
s
P
p
.002 w
.51608 .4663 m .51366 .46289 L p
.52242 .46714 L 1 g
F P
s
P
p
.002 w
.52242 .46714 m .52282 .46778 L p
.5128 .46586 L 1 g
F P
s
P
p
.53231 .47193 m .54244 .47685 L .53624 .47397 L 1 g
F
P
p
.52214 .46667 m .54244 .47685 L .53231 .47193 L 1 g
F
P
p
.54174 .47608 m .55417 .48821 L .55037 .48453 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.56405 .50487 m .55916 .50591 L .55417 .48821 L p
1 g
F P
s
P
p
.002 w
.55417 .48821 m .55187 .48009 L p
.5574 .49134 L 1 g
F P
s
P
p
.5574 .49134 m .56405 .50487 L .55417 .48821 L 1 g
F
P
p
.002 w
.55834 .49233 m .55534 .48942 L p
.54949 .48369 L 1 g
F P
s
P
p
.54174 .47608 m .55088 .48503 L .54949 .48369 L 1 g
F
P
p
.55088 .48503 m .55834 .49233 L .54949 .48369 L 1 g
F
P
p
.002 w
.55534 .48942 m .54302 .47747 L .54244 .47685 L p
1 g
F P
s
P
p
.002 w
.54244 .47685 m .54174 .47608 L p
.55534 .48942 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.50765 .45446 m .52918 .46392 L .54244 .47685 L 1 g
F
P
p
.002 w
.54987 .473 m .54244 .47684 L p
.52918 .46392 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54244 .47685 L p
.52918 .46392 L 1 g
F P
s
P
p
.002 w
.52866 .48397 m .54244 .47685 L p
.55916 .50591 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52278 .46772 L p
1 g
F P
s
P
p
.002 w
.52278 .46772 m .52214 .46667 L p
.53624 .47397 L 1 g
F P
s
P
p
.53624 .47397 m .54302 .47747 L .52278 .46772 L 1 g
F
P
p
.002 w
.51366 .46289 m .50765 .45446 L p
.54244 .47685 L 1 g
F P
s
P
p
.002 w
.54244 .47685 m .54302 .47747 L p
.53624 .47397 L 1 g
F P
s
P
p
.55037 .48453 m .55417 .48821 L .55088 .48503 L 1 g
F
P
p
.002 w
.54244 .47684 m .54987 .473 L .55417 .48821 L p
1 g
F P
s
P
p
.002 w
.5574 .49134 m .55834 .49233 L p
.55088 .48503 L 1 g
F P
s
P
p
.56288 .5025 m .56405 .50487 L .56348 .50364 L 1 g
F
P
p
.002 w
.56618 .50948 m .56713 .51061 L p
.56348 .50364 L 1 g
F P
s
P
p
.002 w
.56756 .52883 m .56854 .53025 L p
.5669 .51963 L 1 g
F P
s
P
p
.002 w
.56713 .53045 m .56646 .53587 L .5661 .53439 L p
1 g
F P
s
P
p
.002 w
.5661 .53439 m .55916 .50591 L p
.56713 .53045 L 1 g
F P
s
P
p
.56583 .53544 m .56578 .53562 L .56582 .53549 L 1 g
F
P
p
.002 w
.56792 .52935 m .56756 .52882 L p
.56582 .53549 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.53742 .5566 m .5326 .54874 L .56558 .53621 L p
1 g
F P
s
P
p
.002 w
.56558 .53621 m .56646 .53587 L .56545 .53659 L p
1 g
F P
s
P
p
.002 w
.56545 .53659 m .53742 .5566 L p
.56558 .53621 L 1 g
F P
s
P
p
.002 w
.56797 .52943 m .56792 .52935 L p
.56545 .53659 L 1 g
F P
s
P
p
.002 w
.59011 .50866 m .59628 .5156 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.58119 .50446 m .59011 .50866 L .56646 .53587 L closepath p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56797 .52943 L p
1 g
F P
s
P
p
.56421 .54011 m .56257 .5491 L .56797 .52943 L 1 g
F
P
p
.002 w
.54521 .56199 m .53742 .5566 L .56545 .53659 L p
1 g
F P
s
P
p
.002 w
.56512 .53752 m .54521 .56199 L p
.56545 .53659 L 1 g
F P
s
P
p
.002 w
.54521 .56199 m .56512 .53752 L p
.56176 .54688 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53549 .5747 L p
.54854 .56129 L 1 g
F P
s
P
p
.002 w
.53549 .5747 m .54998 .56518 L .5494 .5636 L p
1 g
F P
s
P
p
.002 w
.5494 .5636 m .54854 .56129 L p
.53549 .5747 L 1 g
F P
s
P
p
.002 w
.54979 .56309 m .54521 .56199 L p
.56225 .54643 L 1 g
F P
s
P
p
.002 w
.56161 .54729 m .56162 .54729 L p
.56423 .54001 L 1 g
F P
s
P
p
.002 w
.56162 .54729 m .56257 .5491 L p
.56422 .54007 L 1 g
F P
s
P
p
.56423 .54001 m .56162 .54729 L .56422 .54007 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56162 .54729 L p
1 g
F P
s
P
p
.55469 .55664 m .54998 .56518 L .56162 .54729 L 1 g
F
P
p
.55492 .55623 m .54979 .56309 L .553 .55971 L 1 g
F
P
p
.002 w
.54521 .56199 m .54999 .56313 L p
.54473 .56645 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54998 .56518 L p
.553 .55971 L 1 g
F P
s
P
p
.002 w
.53318 .57374 m .54521 .56199 L p
.54473 .56645 L 1 g
F P
s
P
p
.53953 .56988 m .53318 .57374 L .5322 .57686 L 1 g
F
P
p
.002 w
.53742 .5566 m .54521 .56199 L .53318 .57374 L p
1 g
F P
s
P
p
.002 w
.53318 .57374 m .53254 .57436 L p
.53262 .57408 L 1 g
F P
s
P
p
.53262 .57408 m .53742 .5566 L .53318 .57374 L 1 g
F
P
p
.527 .57617 m .53742 .5566 L .53254 .57436 L 1 g
F
P
p
.002 w
.53171 .57463 m .53172 .57466 L p
.53318 .57374 L 1 g
F P
s
P
p
.002 w
.53172 .57466 m .5322 .57686 L p
.53318 .57374 L 1 g
F P
s
P
p
.53998 .56945 m .53318 .57374 L .53953 .56988 L 1 g
F
P
p
.002 w
.50754 .57331 m .53742 .5566 L p
.527 .57617 L 1 g
F P
s
P
p
.002 w
.51677 .5795 m .50754 .57331 L p
.527 .57617 L 1 g
F P
s
P
p
.51866 .57912 m .51677 .5795 L .51111 .583 L 1 g
F
P
p
.002 w
.51094 .58067 m .51099 .58138 L p
.51677 .5795 L 1 g
F P
s
P
p
.002 w
.51099 .58138 m .51111 .583 L p
.51677 .5795 L 1 g
F P
s
P
p
.51994 .57847 m .51677 .5795 L .51866 .57912 L 1 g
F
P
p
.002 w
.48947 .58072 m .50754 .57331 L p
.50565 .58068 L 1 g
F P
s
P
p
.49796 .58119 m .48947 .58072 L .48889 .583 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.48267 .57889 m .49779 .55798 L .48934 .58077 L 1 g
F
P
p
.002 w
.48906 .5807 m .48905 .58072 L p
.48947 .58072 L 1 g
F P
s
P
p
.002 w
.48905 .58072 m .48889 .583 L p
.48947 .58072 L 1 g
F P
s
P
p
.50042 .58069 m .48947 .58072 L .49796 .58119 L 1 g
F
P
p
.002 w
.49779 .55798 m .50754 .57331 L .48934 .58077 L p
1 g
F P
s
P
p
.47861 .57775 m .47621 .57755 L .48906 .5807 L 1 g
F
P
p
.002 w
.46824 .57483 m .4678 .57686 L p
.47861 .57775 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46831 .57452 L p
1 g
F P
s
P
p
.46003 .56918 m .45002 .56518 L .46831 .57452 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48893 .58244 L p
1 g
F P
s
P
p
.47621 .57755 m .4678 .57686 L .48893 .58244 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.004 w
.5 .43051 m
.51796 .45899 L
s
P
p
.004 w
.53793 .49064 m
.55043 .51045 L
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.55511 .56436 m .56606 .56349 L .56371 .58634 L p
1 g
F P
s
P
p
.002 w
.56371 .58634 m .54241 .58814 L .55511 .56436 L p
1 g
F P
s
P
p
.002 w
.54029 .2739 m .47495 .28518 L .46374 .2663 L p
1 g
F P
s
P
p
.002 w
.40148 .29781 m .46374 .2663 L .47495 .28518 L p
1 g
F P
s
P
p
.002 w
.3807 .3842 m .3505 .43827 L .33255 .42022 L p
1 g
F P
s
P
p
.002 w
.33255 .42022 m .3638 .36357 L .3807 .3842 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.58651 .55282 m .59388 .54413 L .61772 .54879 L p
1 g
F P
s
P
p
.002 w
.62632 .52976 m .61772 .54879 L .59388 .54413 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.62632 .52976 m .62819 .51045 L .65286 .49434 L p
1 g
F P
s
P
p
.002 w
.64558 .4686 m .65286 .49434 L .62819 .51045 L p
1 g
F P
s
P
p
.002 w
.65286 .49434 m .64558 .4686 L .66343 .44364 L p
1 g
F P
s
P
p
.002 w
.47495 .28518 m .41337 .31641 L .40148 .29781 L p
1 g
F P
s
P
p
.002 w
.42411 .52944 m .43047 .5645 L .40032 .56171 L p
1 g
F P
s
P
p
.002 w
.40032 .56171 m .39221 .52002 L .42411 .52944 L p
1 g
F P
s
P
p
.002 w
.54982 .29805 m .60781 .30674 L .61168 .33452 L p
1 g
F P
s
P
p
.002 w
.60781 .30674 m .54982 .29805 L .54029 .2739 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.6418 .41689 m .66343 .44364 L .64558 .4686 L p
1 g
F P
s
P
p
.002 w
.66343 .44364 m .6418 .41689 L .65066 .3867 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.47495 .28518 m .54029 .2739 L .54982 .29805 L p
1 g
F P
s
P
p
.002 w
.59388 .54413 m .59823 .53435 L .62632 .52976 L p
1 g
F P
s
P
p
.002 w
.62819 .51045 m .62632 .52976 L .59823 .53435 L p
1 g
F P
s
P
p
.002 w
.61224 .3659 m .65066 .3867 L .6418 .41689 L p
1 g
F P
s
P
p
.002 w
.65066 .3867 m .61224 .3659 L .61168 .33452 L p
1 g
F P
s
P
p
.002 w
.40095 .47451 m .39221 .52002 L .36417 .5081 L p
1 g
F P
s
P
p
.002 w
.36417 .5081 m .37352 .45658 L .40095 .47451 L p
1 g
F P
s
P
p
.002 w
.4283 .33911 m .3807 .3842 L .3638 .36357 L p
1 g
F P
s
P
p
.002 w
.3638 .36357 m .41337 .31641 L .4283 .33911 L p
1 g
F P
s
P
p
.002 w
.62296 .49289 m .62819 .51045 L .59907 .52448 L p
1 g
F P
s
P
p
.002 w
.59823 .53435 m .59907 .52448 L .62819 .51045 L p
1 g
F P
s
P
p
.002 w
.62819 .51045 m .62296 .49289 L .64558 .4686 L p
1 g
F P
s
P
p
.002 w
.62846 .44804 m .64558 .4686 L .62296 .49289 L p
1 g
F P
s
P
p
.002 w
.64558 .4686 m .62846 .44804 L .6418 .41689 L p
1 g
F P
s
P
p
.002 w
.40173 .4068 m .37352 .45658 L .3505 .43827 L p
1 g
F P
s
P
p
.002 w
.3505 .43827 m .3807 .3842 L .40173 .4068 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.54982 .29805 m .48729 .30912 L .47495 .28518 L p
1 g
F P
s
P
p
.002 w
.41337 .31641 m .47495 .28518 L .48729 .30912 L p
1 g
F P
s
P
p
.002 w
.55808 .32692 m .61168 .33452 L .61224 .3659 L p
1 g
F P
s
P
p
.002 w
.61168 .33452 m .55808 .32692 L .54982 .29805 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.48729 .30912 m .4283 .33911 L .41337 .31641 L p
1 g
F P
s
P
p
.002 w
.5326 .54874 m .53742 .5566 L .50754 .57331 L p
1 g
F P
s
P
p
.002 w
.50754 .57331 m .49779 .55798 L .5326 .54874 L p
1 g
F P
s
P
p
.002 w
.60935 .39986 m .6418 .41689 L .62846 .44804 L p
1 g
F P
s
P
p
.002 w
.6418 .41689 m .60935 .39986 L .61224 .3659 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.48729 .30912 m .54982 .29805 L .55808 .32692 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.43187 .49134 m .42411 .52944 L .39221 .52002 L p
1 g
F P
s
P
p
.002 w
.39221 .52002 m .40095 .47451 L .43187 .49134 L p
1 g
F P
s
P
p
.002 w
.59907 .52448 m .59628 .5156 L .62296 .49289 L p
1 g
F P
s
P
p
.002 w
.61103 .47901 m .62296 .49289 L .59628 .5156 L p
1 g
F P
s
P
p
.002 w
.62296 .49289 m .61103 .47901 L .62846 .44804 L p
1 g
F P
s
P
p
.002 w
.49498 .53926 m .49779 .55798 L .46333 .56328 L p
1 g
F P
s
P
p
.002 w
.46333 .56328 m .45879 .53596 L .49498 .53926 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.60306 .43515 m .62846 .44804 L .61103 .47901 L p
1 g
F P
s
P
p
.002 w
.62846 .44804 m .60306 .43515 L .60935 .39986 L p
1 g
F P
s
P
p
.002 w
.56472 .35962 m .61224 .3659 L .60935 .39986 L p
1 g
F P
s
P
p
.002 w
.61224 .3659 m .56472 .35962 L .55808 .32692 L p
1 g
F P
s
P
p
.002 w
.42624 .4306 m .40095 .47451 L .37352 .45658 L p
1 g
F P
s
P
p
.002 w
.37352 .45658 m .40173 .4068 L .42624 .4306 L p
1 g
F P
s
P
p
.002 w
.59628 .5156 m .59011 .50866 L .61103 .47901 L p
1 g
F P
s
P
p
.002 w
.44585 .36524 m .40173 .4068 L .3807 .3842 L p
1 g
F P
s
P
p
.002 w
.3807 .3842 m .4283 .33911 L .44585 .36524 L p
1 g
F P
s
P
p
.002 w
.53133 .53923 m .5326 .54874 L .49779 .55798 L p
1 g
F P
s
P
p
.002 w
.49779 .55798 m .49498 .53926 L .53133 .53923 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55808 .32692 m .50034 .33745 L .48729 .30912 L p
1 g
F P
s
P
p
.002 w
.4283 .33911 m .48729 .30912 L .50034 .33745 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.59355 .47047 m .61103 .47901 L .59011 .50866 L p
1 g
F P
s
P
p
.002 w
.61103 .47901 m .59355 .47047 L .60306 .43515 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59011 .50866 m .58119 .50446 L .59355 .47047 L p
1 g
F P
s
P
p
.002 w
.50034 .33745 m .55808 .32692 L .56472 .35962 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.50034 .33745 m .44585 .36524 L .4283 .33911 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56944 .39499 m .60935 .39986 L .60306 .43515 L p
1 g
F P
s
P
p
.002 w
.60935 .39986 m .56944 .39499 L .56472 .35962 L p
1 g
F P
s
P
p
.002 w
.49958 .51918 m .49498 .53926 L .45879 .53596 L p
1 g
F P
s
P
p
.002 w
.45879 .53596 m .46518 .50643 L .49958 .51918 L p
1 g
F P
s
P
p
.002 w
.53378 .5291 m .53133 .53923 L .49498 .53926 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58119 .50446 m .57048 .5035 L .57237 .46834 L p
1 g
F P
s
P
p
.002 w
.57237 .46834 m .59355 .47047 L .58119 .50446 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.49498 .53926 m .49958 .51918 L .53378 .5291 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45337 .45468 m .43187 .49134 L .40095 .47451 L p
1 g
F P
s
P
p
.002 w
.40095 .47451 m .42624 .4306 L .45337 .45468 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53972 .51947 m .53378 .5291 L .49958 .51918 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.57203 .4317 m .60306 .43515 L .59355 .47047 L p
1 g
F P
s
P
p
.002 w
.60306 .43515 m .57203 .4317 L .56944 .39499 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.59355 .47047 m .57237 .46834 L .57203 .4317 L p
1 g
F P
s
P
p
.002 w
.54987 .473 m .57237 .46834 L .57048 .5035 L p
1 g
F P
s
P
p
.002 w
.46542 .39391 m .42624 .4306 L .40173 .4068 L p
1 g
F P
s
P
p
.002 w
.40173 .4068 m .44585 .36524 L .46542 .39391 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54851 .51144 m .53972 .51947 L .51123 .5 L p
1 g
F P
s
P
p
.002 w
.49958 .51918 m .51123 .5 L .53972 .51947 L p
1 g
F P
s
P
p
.002 w
.51364 .36923 m .56472 .35962 L .56944 .39499 L p
1 g
F P
s
P
p
.002 w
.56472 .35962 m .51364 .36923 L .50034 .33745 L p
1 g
F P
s
P
p
.002 w
.55916 .50591 m .54851 .51144 L .52866 .48397 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.51123 .5 m .52866 .48397 L .54851 .51144 L p
1 g
F P
s
P
p
.002 w
.44585 .36524 m .50034 .33745 L .51364 .36923 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.51123 .5 m .49958 .51918 L .46518 .50643 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51364 .36923 m .46542 .39391 L .44585 .36524 L p
1 g
F P
s
P
p
.002 w
.46518 .50643 m .48207 .47812 L .51123 .5 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57237 .46834 m .54987 .473 L .5389 .43835 L p
1 g
F P
s
P
p
.002 w
.5389 .43835 m .57203 .4317 L .57237 .46834 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52666 .4033 m .56944 .39499 L .57203 .4317 L p
1 g
F P
s
P
p
.002 w
.56944 .39499 m .52666 .4033 L .51364 .36923 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.48629 .42404 m .45337 .45468 L .42624 .4306 L p
1 g
F P
s
P
p
.002 w
.42624 .4306 m .46542 .39391 L .48629 .42404 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.57203 .4317 m .5389 .43835 L .52666 .4033 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.52866 .48397 m .51123 .5 L .48207 .47812 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50765 .45446 m .5389 .43835 L .54987 .473 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.46542 .39391 m .51364 .36923 L .52666 .4033 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45337 .45468 m .48629 .42404 L .50765 .45446 L p
1 g
F P
s
P
p
.002 w
.52666 .4033 m .48629 .42404 L .46542 .39391 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.5389 .43835 m .50765 .45446 L .48629 .42404 L p
1 g
F P
s
P
p
.002 w
.48629 .42404 m .52666 .4033 L .5389 .43835 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.58889 .57143 m
.59408 .57965 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .77508 .54791 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60614 .59876 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.510078)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.510078)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45693 .45944 m .49791 .45219 L .48945 .42491 L p
1 g
F P
s
P
p
.002 w
.48945 .42491 m .45525 .43085 L .45693 .45944 L p
1 g
F P
s
P
p
.002 w
.52129 .41049 m .48945 .42491 L .49791 .45219 L p
1 g
F P
s
P
p
.002 w
.45525 .43085 m .48945 .42491 L .48122 .39771 L p
1 g
F P
s
P
p
.002 w
.48945 .42491 m .52129 .41049 L .50594 .38649 L p
1 g
F P
s
P
p
.002 w
.50594 .38649 m .48122 .39771 L .48945 .42491 L p
1 g
F P
s
P
p
.002 w
.45967 .48749 m .50647 .47907 L .49791 .45219 L p
1 g
F P
s
P
p
.002 w
.49791 .45219 m .45693 .45944 L .45967 .48749 L p
1 g
F P
s
P
p
.002 w
.5361 .43495 m .49791 .45219 L .50647 .47907 L p
1 g
F P
s
P
p
.002 w
.49791 .45219 m .5361 .43495 L .52129 .41049 L p
1 g
F P
s
P
p
.002 w
.54776 .38893 m .52129 .41049 L .5361 .43495 L p
1 g
F P
s
P
p
.002 w
.52129 .41049 m .54776 .38893 L .52639 .36964 L p
1 g
F P
s
P
p
.002 w
.52639 .36964 m .50594 .38649 L .52129 .41049 L p
1 g
F P
s
P
p
.002 w
.50647 .47907 m .55011 .45943 L .5361 .43495 L p
1 g
F P
s
P
p
.002 w
.568 .40925 m .5361 .43495 L .55011 .45943 L p
1 g
F P
s
P
p
.002 w
.5361 .43495 m .568 .40925 L .54776 .38893 L p
1 g
F P
s
P
p
.002 w
.48122 .39771 m .45465 .40225 L .45525 .43085 L p
1 g
F P
s
P
p
.002 w
.45465 .40225 m .48122 .39771 L .47338 .37109 L p
1 g
F P
s
P
p
.002 w
.48122 .39771 m .50594 .38649 L .49033 .36337 L p
1 g
F P
s
P
p
.002 w
.49033 .36337 m .47338 .37109 L .48122 .39771 L p
1 g
F P
s
P
p
.002 w
.50594 .38649 m .52639 .36964 L .50428 .35176 L p
1 g
F P
s
P
p
.002 w
.50428 .35176 m .49033 .36337 L .50594 .38649 L p
1 g
F P
s
P
p
.002 w
.41689 .4559 m .45693 .45944 L .45525 .43085 L p
1 g
F P
s
P
p
.002 w
.45525 .43085 m .42191 .42767 L .41689 .4559 L p
1 g
F P
s
P
p
.002 w
.42191 .42767 m .45525 .43085 L .45465 .40225 L p
1 g
F P
s
P
p
.002 w
.46343 .51447 m .51496 .50505 L .50647 .47907 L p
1 g
F P
s
P
p
.002 w
.50647 .47907 m .45967 .48749 L .46343 .51447 L p
1 g
F P
s
P
p
.002 w
.55011 .45943 m .50647 .47907 L .51496 .50505 L p
1 g
F P
s
P
p
.002 w
.41387 .48376 m .45967 .48749 L .45693 .45944 L p
1 g
F P
s
P
p
.002 w
.45693 .45944 m .41689 .4559 L .41387 .48376 L p
1 g
F P
s
P
p
.002 w
.45465 .40225 m .42881 .39959 L .42191 .42767 L p
1 g
F P
s
P
p
.002 w
.42881 .39959 m .45465 .40225 L .45515 .37415 L p
1 g
F P
s
P
p
.002 w
.47338 .37109 m .45515 .37415 L .45465 .40225 L p
1 g
F P
s
P
p
.002 w
.51496 .50505 m .56306 .48347 L .55011 .45943 L p
1 g
F P
s
P
p
.002 w
.58671 .43024 m .55011 .45943 L .56306 .48347 L p
1 g
F P
s
P
p
.002 w
.55011 .45943 m .58671 .43024 L .568 .40925 L p
1 g
F P
s
P
p
.002 w
.56623 .36214 m .54776 .38893 L .568 .40925 L p
1 g
F P
s
P
p
.002 w
.54776 .38893 m .56623 .36214 L .54051 .34876 L p
1 g
F P
s
P
p
.002 w
.54051 .34876 m .52639 .36964 L .54776 .38893 L p
1 g
F P
s
P
p
.002 w
.45515 .37415 m .47338 .37109 L .46608 .34554 L p
1 g
F P
s
P
p
.002 w
.47338 .37109 m .49033 .36337 L .47474 .34159 L p
1 g
F P
s
P
p
.002 w
.47474 .34159 m .46608 .34554 L .47338 .37109 L p
1 g
F P
s
P
p
.002 w
.52639 .36964 m .54051 .34876 L .5138 .3374 L p
1 g
F P
s
P
p
.002 w
.5138 .3374 m .50428 .35176 L .52639 .36964 L p
1 g
F P
s
P
p
.002 w
.49033 .36337 m .50428 .35176 L .48184 .33562 L p
1 g
F P
s
P
p
.002 w
.48184 .33562 m .47474 .34159 L .49033 .36337 L p
1 g
F P
s
P
p
.002 w
.41295 .5107 m .46343 .51447 L .45967 .48749 L p
1 g
F P
s
P
p
.002 w
.45967 .48749 m .41387 .48376 L .41295 .5107 L p
1 g
F P
s
P
p
.002 w
.59048 .37729 m .568 .40925 L .58671 .43024 L p
1 g
F P
s
P
p
.002 w
.568 .40925 m .59048 .37729 L .56623 .36214 L p
1 g
F P
s
P
p
.002 w
.45515 .37415 m .43748 .37221 L .42881 .39959 L p
1 g
F P
s
P
p
.002 w
.43748 .37221 m .45515 .37415 L .45676 .34708 L p
1 g
F P
s
P
p
.002 w
.46608 .34554 m .45676 .34708 L .45515 .37415 L p
1 g
F P
s
P
p
.002 w
.46817 .53986 m .52322 .52964 L .51496 .50505 L p
1 g
F P
s
P
p
.002 w
.51496 .50505 m .46343 .51447 L .46817 .53986 L p
1 g
F P
s
P
p
.002 w
.56306 .48347 m .51496 .50505 L .52322 .52964 L p
1 g
F P
s
P
p
.002 w
.39269 .41544 m .42191 .42767 L .42881 .39959 L p
1 g
F P
s
P
p
.002 w
.42881 .39959 m .4063 .38988 L .39269 .41544 L p
1 g
F P
s
P
p
.002 w
.4063 .38988 m .42881 .39959 L .43748 .37221 L p
1 g
F P
s
P
p
.002 w
.38162 .44159 m .41689 .4559 L .42191 .42767 L p
1 g
F P
s
P
p
.002 w
.42191 .42767 m .39269 .41544 L .38162 .44159 L p
1 g
F P
s
P
p
.002 w
.50428 .35176 m .5138 .3374 L .48661 .32827 L p
1 g
F P
s
P
p
.002 w
.48661 .32827 m .48184 .33562 L .50428 .35176 L p
1 g
F P
s
P
p
.002 w
.52322 .52964 m .57467 .50661 L .56306 .48347 L p
1 g
F P
s
P
p
.002 w
.60354 .45151 m .56306 .48347 L .57467 .50661 L p
1 g
F P
s
P
p
.002 w
.56306 .48347 m .60354 .45151 L .58671 .43024 L p
1 g
F P
s
P
p
.002 w
.43748 .37221 m .42219 .3654 L .4063 .38988 L p
1 g
F P
s
P
p
.002 w
.42219 .3654 m .43748 .37221 L .44776 .34603 L p
1 g
F P
s
P
p
.002 w
.45676 .34708 m .44776 .34603 L .43748 .37221 L p
1 g
F P
s
P
p
.002 w
.61275 .39393 m .58671 .43024 L .60354 .45151 L p
1 g
F P
s
P
p
.002 w
.58671 .43024 m .61275 .39393 L .59048 .37729 L p
1 g
F P
s
P
p
.002 w
.37336 .46782 m .41387 .48376 L .41689 .4559 L p
1 g
F P
s
P
p
.002 w
.41689 .4559 m .38162 .44159 L .37336 .46782 L p
1 g
F P
s
P
p
.002 w
.54669 .32586 m .54051 .34876 L .56623 .36214 L p
1 g
F P
s
P
p
.002 w
.54051 .34876 m .54669 .32586 L .51781 .32173 L p
1 g
F P
s
P
p
.002 w
.51781 .32173 m .5138 .3374 L .54051 .34876 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .45676 .34708 L .46608 .34554 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .46608 .34554 L .47474 .34159 L closepath p
1 g
F P
s
P
p
.002 w
.41419 .53617 m .46817 .53986 L .46343 .51447 L p
1 g
F P
s
P
p
.002 w
.46343 .51447 m .41295 .5107 L .41419 .53617 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .47474 .34159 L .48184 .33562 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .44776 .34603 L .45676 .34708 L closepath p
1 g
F P
s
P
p
.002 w
.5138 .3374 m .51781 .32173 L .48855 .32029 L p
1 g
F P
s
P
p
.002 w
.48855 .32029 m .48661 .32827 L .5138 .3374 L p
1 g
F P
s
P
p
.002 w
.57461 .33264 m .56623 .36214 L .59048 .37729 L p
1 g
F P
s
P
p
.002 w
.56623 .36214 m .57461 .33264 L .54669 .32586 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .48184 .33562 L .48661 .32827 L closepath p
1 g
F P
s
P
p
.002 w
.44776 .34603 m .44002 .34248 L .42219 .3654 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .44002 .34248 L .44776 .34603 L closepath p
1 g
F P
s
P
p
.002 w
.36816 .49359 m .41295 .5107 L .41387 .48376 L p
1 g
F P
s
P
p
.002 w
.41387 .48376 m .37336 .46782 L .36816 .49359 L p
1 g
F P
s
P
p
.002 w
.38953 .3739 m .4063 .38988 L .42219 .3654 L p
1 g
F P
s
P
p
.002 w
.42219 .3654 m .41091 .35435 L .38953 .3739 L p
1 g
F P
s
P
p
.002 w
.41091 .35435 m .42219 .3654 L .44002 .34248 L p
1 g
F P
s
P
p
.002 w
.47381 .56309 m .53109 .55231 L .52322 .52964 L p
1 g
F P
s
P
p
.002 w
.52322 .52964 m .46817 .53986 L .47381 .56309 L p
1 g
F P
s
P
p
.002 w
.57467 .50661 m .52322 .52964 L .53109 .55231 L p
1 g
F P
s
P
p
.002 w
.37069 .39507 m .39269 .41544 L .4063 .38988 L p
1 g
F P
s
P
p
.002 w
.4063 .38988 m .38953 .3739 L .37069 .39507 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .48661 .32827 L .48855 .32029 L closepath p
1 g
F P
s
P
p
.002 w
.601 .34195 m .59048 .37729 L .61275 .39393 L p
1 g
F P
s
P
p
.002 w
.59048 .37729 m .601 .34195 L .57461 .33264 L p
1 g
F P
s
P
p
.002 w
.57467 .50661 m .6181 .47266 L .60354 .45151 L p
1 g
F P
s
P
p
.002 w
.63256 .41176 m .60354 .45151 L .6181 .47266 L p
1 g
F P
s
P
p
.002 w
.60354 .45151 m .63256 .41176 L .61275 .39393 L p
1 g
F P
s
P
p
.002 w
.44002 .34248 m .43439 .3368 L .41091 .35435 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .43439 .3368 L .44002 .34248 L closepath p
1 g
F P
s
P
p
.002 w
.53109 .55231 m .58468 .52839 L .57467 .50661 L p
1 g
F P
s
P
p
.002 w
.6181 .47266 m .57467 .50661 L .58468 .52839 L p
1 g
F P
s
P
p
.002 w
.35484 .41746 m .38162 .44159 L .39269 .41544 L p
1 g
F P
s
P
p
.002 w
.39269 .41544 m .37069 .39507 L .35484 .41746 L p
1 g
F P
s
P
p
.002 w
.51578 .30638 m .51781 .32173 L .54669 .32586 L p
1 g
F P
s
P
p
.002 w
.51781 .32173 m .51578 .30638 L .4874 .31253 L p
1 g
F P
s
P
p
.002 w
.4874 .31253 m .48855 .32029 L .51781 .32173 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .48855 .32029 L .4874 .31253 L closepath p
1 g
F P
s
P
p
.002 w
.41765 .55958 m .47381 .56309 L .46817 .53986 L p
1 g
F P
s
P
p
.002 w
.46817 .53986 m .41419 .53617 L .41765 .55958 L p
1 g
F P
s
P
p
.002 w
.40495 .34014 m .41091 .35435 L .43439 .3368 L p
1 g
F P
s
P
p
.002 w
.43439 .3368 m .43148 .32956 L .40495 .34014 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .43148 .32956 L .43439 .3368 L closepath p
1 g
F P
s
P
p
.002 w
.54406 .30328 m .54669 .32586 L .57461 .33264 L p
1 g
F P
s
P
p
.002 w
.54669 .32586 m .54406 .30328 L .51578 .30638 L p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .4874 .31253 L .48326 .30584 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .48326 .30584 L .47654 .30096 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .47654 .30096 L .46797 .29846 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .46797 .29846 L .45848 .29863 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .45848 .29863 L .44913 .30147 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .44913 .30147 L .44098 .30666 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .44098 .30666 L .43494 .31362 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .43494 .31362 L .43166 .32154 L closepath p
1 g
F P
s
P
p
.002 w
.45948 .32158 m .43166 .32154 L .43148 .32956 L closepath p
1 g
F P
s
P
p
.002 w
.38045 .35315 m .38953 .3739 L .41091 .35435 L p
1 g
F P
s
P
p
.002 w
.41091 .35435 m .40495 .34014 L .38045 .35315 L p
1 g
F P
s
P
p
.002 w
.36621 .51835 m .41419 .53617 L .41295 .5107 L p
1 g
F P
s
P
p
.002 w
.41295 .5107 m .36816 .49359 L .36621 .51835 L p
1 g
F P
s
P
p
.002 w
.62527 .35365 m .61275 .39393 L .63256 .41176 L p
1 g
F P
s
P
p
.002 w
.61275 .39393 m .62527 .35365 L .601 .34195 L p
1 g
F P
s
P
p
.002 w
.48326 .30584 m .4874 .31253 L .51578 .30638 L p
1 g
F P
s
P
p
.002 w
.34239 .44062 m .37336 .46782 L .38162 .44159 L p
1 g
F P
s
P
p
.002 w
.38162 .44159 m .35484 .41746 L .34239 .44062 L p
1 g
F P
s
P
p
.002 w
.40509 .32426 m .40495 .34014 L .43148 .32956 L p
1 g
F P
s
P
p
.002 w
.43148 .32956 m .43166 .32154 L .40509 .32426 L p
1 g
F P
s
P
p
.002 w
.57163 .30335 m .57461 .33264 L .601 .34195 L p
1 g
F P
s
P
p
.002 w
.57461 .33264 m .57163 .30335 L .54406 .30328 L p
1 g
F P
s
P
p
.002 w
.35856 .36837 m .37069 .39507 L .38953 .3739 L p
1 g
F P
s
P
p
.002 w
.38953 .3739 m .38045 .35315 L .35856 .36837 L p
1 g
F P
s
P
p
.002 w
.50779 .29303 m .51578 .30638 L .54406 .30328 L p
1 g
F P
s
P
p
.002 w
.51578 .30638 m .50779 .29303 L .48326 .30584 L p
1 g
F P
s
P
p
.002 w
.58468 .52839 m .63003 .49326 L .6181 .47266 L p
1 g
F P
s
P
p
.002 w
.64944 .43045 m .6181 .47266 L .63003 .49326 L p
1 g
F P
s
P
p
.002 w
.6181 .47266 m .64944 .43045 L .63256 .41176 L p
1 g
F P
s
P
p
.002 w
.48028 .58361 m .5384 .57254 L .53109 .55231 L p
1 g
F P
s
P
p
.002 w
.53109 .55231 m .47381 .56309 L .48028 .58361 L p
1 g
F P
s
P
p
.002 w
.58468 .52839 m .53109 .55231 L .5384 .57254 L p
1 g
F P
s
P
p
.002 w
.47654 .30096 m .48326 .30584 L .50779 .29303 L p
1 g
F P
s
P
p
.002 w
.41146 .30843 m .40509 .32426 L .43166 .32154 L p
1 g
F P
s
P
p
.002 w
.43166 .32154 m .43494 .31362 L .41146 .30843 L p
1 g
F P
s
P
p
.002 w
.5384 .57254 m .59283 .5483 L .58468 .52839 L p
1 g
F P
s
P
p
.002 w
.63003 .49326 m .58468 .52839 L .59283 .5483 L p
1 g
F P
s
P
p
.002 w
.38037 .32974 m .38045 .35315 L .40495 .34014 L p
1 g
F P
s
P
p
.002 w
.40495 .34014 m .40509 .32426 L .38037 .32974 L p
1 g
F P
s
P
p
.002 w
.50779 .29303 m .49457 .2832 L .47654 .30096 L p
1 g
F P
s
P
p
.002 w
.46797 .29846 m .47654 .30096 L .49457 .2832 L p
1 g
F P
s
P
p
.002 w
.33373 .46406 m .36816 .49359 L .37336 .46782 L p
1 g
F P
s
P
p
.002 w
.37336 .46782 m .34239 .44062 L .33373 .46406 L p
1 g
F P
s
P
p
.002 w
.42346 .29448 m .41146 .30843 L .43494 .31362 L p
1 g
F P
s
P
p
.002 w
.43494 .31362 m .44098 .30666 L .42346 .29448 L p
1 g
F P
s
P
p
.002 w
.64684 .36758 m .63256 .41176 L .64944 .43045 L p
1 g
F P
s
P
p
.002 w
.63256 .41176 m .64684 .36758 L .62527 .35365 L p
1 g
F P
s
P
p
.002 w
.33982 .38552 m .35484 .41746 L .37069 .39507 L p
1 g
F P
s
P
p
.002 w
.37069 .39507 m .35856 .36837 L .33982 .38552 L p
1 g
F P
s
P
p
.002 w
.59789 .30668 m .601 .34195 L .62527 .35365 L p
1 g
F P
s
P
p
.002 w
.601 .34195 m .59789 .30668 L .57163 .30335 L p
1 g
F P
s
P
p
.002 w
.53256 .28347 m .54406 .30328 L .57163 .30335 L p
1 g
F P
s
P
p
.002 w
.54406 .30328 m .53256 .28347 L .50779 .29303 L p
1 g
F P
s
P
p
.002 w
.42334 .58034 m .48028 .58361 L .47381 .56309 L p
1 g
F P
s
P
p
.002 w
.47381 .56309 m .41765 .55958 L .42334 .58034 L p
1 g
F P
s
P
p
.002 w
.49457 .2832 m .47751 .27809 L .46797 .29846 L p
1 g
F P
s
P
p
.002 w
.45848 .29863 m .46797 .29846 L .47751 .27809 L p
1 g
F P
s
P
p
.002 w
.36769 .54149 m .41765 .55958 L .41419 .53617 L p
1 g
F P
s
P
p
.002 w
.41419 .53617 m .36621 .51835 L .36769 .54149 L p
1 g
F P
s
P
p
.002 w
.43976 .28404 m .42346 .29448 L .44098 .30666 L p
1 g
F P
s
P
p
.002 w
.44098 .30666 m .44913 .30147 L .43976 .28404 L p
1 g
F P
s
P
p
.002 w
.49457 .2832 m .50779 .29303 L .53256 .28347 L p
1 g
F P
s
P
p
.002 w
.47751 .27809 m .45851 .27836 L .45848 .29863 L p
1 g
F P
s
P
p
.002 w
.44913 .30147 m .45848 .29863 L .45851 .27836 L p
1 g
F P
s
P
p
.002 w
.45851 .27836 m .43976 .28404 L .44913 .30147 L p
1 g
F P
s
P
p
.002 w
.35811 .33797 m .35856 .36837 L .38045 .35315 L p
1 g
F P
s
P
p
.002 w
.38045 .35315 m .38037 .32974 L .35811 .33797 L p
1 g
F P
s
P
p
.002 w
.3896 .30625 m .38037 .32974 L .40509 .32426 L p
1 g
F P
s
P
p
.002 w
.40509 .32426 m .41146 .30843 L .3896 .30625 L p
1 g
F P
s
P
p
.002 w
.59283 .5483 m .63896 .51284 L .63003 .49326 L p
1 g
F P
s
P
p
.002 w
.66291 .44963 m .63003 .49326 L .63896 .51284 L p
1 g
F P
s
P
p
.002 w
.63003 .49326 m .66291 .44963 L .64944 .43045 L p
1 g
F P
s
P
p
.002 w
.32478 .40431 m .34239 .44062 L .35484 .41746 L p
1 g
F P
s
P
p
.002 w
.35484 .41746 m .33982 .38552 L .32478 .40431 L p
1 g
F P
s
P
p
.002 w
.55706 .27748 m .57163 .30335 L .59789 .30668 L p
1 g
F P
s
P
p
.002 w
.57163 .30335 m .55706 .27748 L .53256 .28347 L p
1 g
F P
s
P
p
.002 w
.3292 .48725 m .36621 .51835 L .36816 .49359 L p
1 g
F P
s
P
p
.002 w
.36816 .49359 m .33373 .46406 L .3292 .48725 L p
1 g
F P
s
P
p
.002 w
.62222 .31329 m .62527 .35365 L .64684 .36758 L p
1 g
F P
s
P
p
.002 w
.62527 .35365 m .62222 .31329 L .59789 .30668 L p
1 g
F P
s
P
p
.002 w
.48748 .60084 m .54496 .58977 L .5384 .57254 L p
1 g
F P
s
P
p
.002 w
.5384 .57254 m .48028 .58361 L .48748 .60084 L p
1 g
F P
s
P
p
.002 w
.59283 .5483 m .5384 .57254 L .54496 .58977 L p
1 g
F P
s
P
p
.002 w
.53256 .28347 m .51319 .26876 L .49457 .2832 L p
1 g
F P
s
P
p
.002 w
.47751 .27809 m .49457 .2832 L .51319 .26876 L p
1 g
F P
s
P
p
.002 w
.66515 .38349 m .64944 .43045 L .66291 .44963 L p
1 g
F P
s
P
p
.002 w
.64944 .43045 m .66515 .38349 L .64684 .36758 L p
1 g
F P
s
P
p
.002 w
.54496 .58977 m .59884 .56582 L .59283 .5483 L p
1 g
F P
s
P
p
.002 w
.63896 .51284 m .59283 .5483 L .59884 .56582 L p
1 g
F P
s
P
p
.002 w
.51319 .26876 m .53256 .28347 L .55706 .27748 L p
1 g
F P
s
P
p
.002 w
.40734 .28542 m .3896 .30625 L .41146 .30843 L p
1 g
F P
s
P
p
.002 w
.41146 .30843 m .42346 .29448 L .40734 .28542 L p
1 g
F P
s
P
p
.002 w
.37271 .5624 m .42334 .58034 L .41765 .55958 L p
1 g
F P
s
P
p
.002 w
.41765 .55958 m .36769 .54149 L .37271 .5624 L p
1 g
F P
s
P
p
.002 w
.51319 .26876 m .48793 .26102 L .47751 .27809 L p
1 g
F P
s
P
p
.002 w
.45851 .27836 m .47751 .27809 L .48793 .26102 L p
1 g
F P
s
P
p
.002 w
.43124 .59785 m .48748 .60084 L .48028 .58361 L p
1 g
F P
s
P
p
.002 w
.48028 .58361 m .42334 .58034 L .43124 .59785 L p
1 g
F P
s
P
p
.002 w
.33892 .34888 m .33982 .38552 L .35856 .36837 L p
1 g
F P
s
P
p
.002 w
.35856 .36837 m .35811 .33797 L .33892 .34888 L p
1 g
F P
s
P
p
.002 w
.43163 .26981 m .40734 .28542 L .42346 .29448 L p
1 g
F P
s
P
p
.002 w
.42346 .29448 m .43976 .28404 L .43163 .26981 L p
1 g
F P
s
P
p
.002 w
.36993 .30725 m .35811 .33797 L .38037 .32974 L p
1 g
F P
s
P
p
.002 w
.38037 .32974 m .3896 .30625 L .36993 .30725 L p
1 g
F P
s
P
p
.002 w
.48793 .26102 m .45962 .26134 L .45851 .27836 L p
1 g
F P
s
P
p
.002 w
.43976 .28404 m .45851 .27836 L .45962 .26134 L p
1 g
F P
s
P
p
.002 w
.58071 .27532 m .59789 .30668 L .62222 .31329 L p
1 g
F P
s
P
p
.002 w
.59789 .30668 m .58071 .27532 L .55706 .27748 L p
1 g
F P
s
P
p
.002 w
.31396 .42433 m .33373 .46406 L .34239 .44062 L p
1 g
F P
s
P
p
.002 w
.34239 .44062 m .32478 .40431 L .31396 .42433 L p
1 g
F P
s
P
p
.002 w
.45962 .26134 m .43163 .26981 L .43976 .28404 L p
1 g
F P
s
P
p
.002 w
.644 .32315 m .64684 .36758 L .66515 .38349 L p
1 g
F P
s
P
p
.002 w
.64684 .36758 m .644 .32315 L .62222 .31329 L p
1 g
F P
s
P
p
.002 w
.32909 .50963 m .36769 .54149 L .36621 .51835 L p
1 g
F P
s
P
p
.002 w
.36621 .51835 m .3292 .48725 L .32909 .50963 L p
1 g
F P
s
P
p
.002 w
.59884 .56582 m .64456 .53092 L .63896 .51284 L p
1 g
F P
s
P
p
.002 w
.67253 .46888 m .63896 .51284 L .64456 .53092 L p
1 g
F P
s
P
p
.002 w
.63896 .51284 m .67253 .46888 L .66291 .44963 L p
1 g
F P
s
P
p
.002 w
.55706 .27748 m .53202 .25811 L .51319 .26876 L p
1 g
F P
s
P
p
.002 w
.48793 .26102 m .51319 .26876 L .53202 .25811 L p
1 g
F P
s
P
p
.002 w
.53202 .25811 m .55706 .27748 L .58071 .27532 L p
1 g
F P
s
P
p
.002 w
.67962 .40109 m .66291 .44963 L .67253 .46888 L p
1 g
F P
s
P
p
.002 w
.66291 .44963 m .67962 .40109 L .66515 .38349 L p
1 g
F P
s
P
p
.002 w
.49528 .61421 m .55058 .60347 L .54496 .58977 L p
1 g
F P
s
P
p
.002 w
.54496 .58977 m .48748 .60084 L .49528 .61421 L p
1 g
F P
s
P
p
.002 w
.59884 .56582 m .54496 .58977 L .55058 .60347 L p
1 g
F P
s
P
p
.002 w
.39307 .27987 m .36993 .30725 L .3896 .30625 L p
1 g
F P
s
P
p
.002 w
.3896 .30625 m .40734 .28542 L .39307 .27987 L p
1 g
F P
s
P
p
.002 w
.32341 .36233 m .32478 .40431 L .33982 .38552 L p
1 g
F P
s
P
p
.002 w
.33982 .38552 m .33892 .34888 L .32341 .36233 L p
1 g
F P
s
P
p
.002 w
.55058 .60347 m .60248 .58043 L .59884 .56582 L p
1 g
F P
s
P
p
.002 w
.64456 .53092 m .59884 .56582 L .60248 .58043 L p
1 g
F P
s
P
p
.002 w
.38131 .58047 m .43124 .59785 L .42334 .58034 L p
1 g
F P
s
P
p
.002 w
.42334 .58034 m .37271 .5624 L .38131 .58047 L p
1 g
F P
s
P
p
.002 w
.60293 .2772 m .62222 .31329 L .644 .32315 L p
1 g
F P
s
P
p
.002 w
.62222 .31329 m .60293 .2772 L .58071 .27532 L p
1 g
F P
s
P
p
.002 w
.35303 .31158 m .33892 .34888 L .35811 .33797 L p
1 g
F P
s
P
p
.002 w
.35811 .33797 m .36993 .30725 L .35303 .31158 L p
1 g
F P
s
P
p
.002 w
.30781 .44515 m .3292 .48725 L .33373 .46406 L p
1 g
F P
s
P
p
.002 w
.33373 .46406 m .31396 .42433 L .30781 .44515 L p
1 g
F P
s
P
p
.002 w
.53202 .25811 m .49903 .24782 L .48793 .26102 L p
1 g
F P
s
P
p
.002 w
.45962 .26134 m .48793 .26102 L .49903 .24782 L p
1 g
F P
s
P
p
.002 w
.44126 .61151 m .49528 .61421 L .48748 .60084 L p
1 g
F P
s
P
p
.002 w
.48748 .60084 m .43124 .59785 L .44126 .61151 L p
1 g
F P
s
P
p
.002 w
.66258 .33616 m .66515 .38349 L .67962 .40109 L p
1 g
F P
s
P
p
.002 w
.66515 .38349 m .66258 .33616 L .644 .32315 L p
1 g
F P
s
P
p
.002 w
.425 .25929 m .39307 .27987 L .40734 .28542 L p
1 g
F P
s
P
p
.002 w
.40734 .28542 m .43163 .26981 L .425 .25929 L p
1 g
F P
s
P
p
.002 w
.33361 .53058 m .37271 .5624 L .36769 .54149 L p
1 g
F P
s
P
p
.002 w
.36769 .54149 m .32909 .50963 L .33361 .53058 L p
1 g
F P
s
P
p
.002 w
.49903 .24782 m .46185 .24816 L .45962 .26134 L p
1 g
F P
s
P
p
.002 w
.43163 .26981 m .45962 .26134 L .46185 .24816 L p
1 g
F P
s
P
p
.002 w
.46185 .24816 m .425 .25929 L .43163 .26981 L p
1 g
F P
s
P
p
.002 w
.55063 .25168 m .58071 .27532 L .60293 .2772 L p
1 g
F P
s
P
p
.002 w
.58071 .27532 m .55063 .25168 L .53202 .25811 L p
1 g
F P
s
P
p
.002 w
.49903 .24782 m .53202 .25811 L .55063 .25168 L p
1 g
F P
s
P
p
.002 w
.60248 .58043 m .64653 .54699 L .64456 .53092 L p
1 g
F P
s
P
p
.002 w
.67788 .48776 m .64456 .53092 L .64653 .54699 L p
1 g
F P
s
P
p
.002 w
.64456 .53092 m .67788 .48776 L .67253 .46888 L p
1 g
F P
s
P
p
.002 w
.68975 .42003 m .67253 .46888 L .67788 .48776 L p
1 g
F P
s
P
p
.002 w
.67253 .46888 m .68975 .42003 L .67962 .40109 L p
1 g
F P
s
P
p
.002 w
.31217 .37809 m .31396 .42433 L .32478 .40431 L p
1 g
F P
s
P
p
.002 w
.32478 .40431 m .32341 .36233 L .31217 .37809 L p
1 g
F P
s
P
p
.002 w
.38112 .27816 m .35303 .31158 L .36993 .30725 L p
1 g
F P
s
P
p
.002 w
.36993 .30725 m .39307 .27987 L .38112 .27816 L p
1 g
F P
s
P
p
.002 w
.62309 .28327 m .644 .32315 L .66258 .33616 L p
1 g
F P
s
P
p
.002 w
.644 .32315 m .62309 .28327 L .60293 .2772 L p
1 g
F P
s
P
p
.002 w
.30673 .46625 m .32909 .50963 L .3292 .48725 L p
1 g
F P
s
P
p
.002 w
.3292 .48725 m .30781 .44515 L .30673 .46625 L p
1 g
F P
s
P
p
.002 w
.50351 .62315 m .55508 .61308 L .55058 .60347 L p
1 g
F P
s
P
p
.002 w
.55058 .60347 m .49528 .61421 L .50351 .62315 L p
1 g
F P
s
P
p
.002 w
.60248 .58043 m .55058 .60347 L .55508 .61308 L p
1 g
F P
s
P
p
.002 w
.33948 .31931 m .32341 .36233 L .33892 .34888 L p
1 g
F P
s
P
p
.002 w
.33892 .34888 m .35303 .31158 L .33948 .31931 L p
1 g
F P
s
P
p
.002 w
.39346 .59508 m .44126 .61151 L .43124 .59785 L p
1 g
F P
s
P
p
.002 w
.43124 .59785 m .38131 .58047 L .39346 .59508 L p
1 g
F P
s
P
p
.002 w
.55508 .61308 m .60351 .59161 L .60248 .58043 L p
1 g
F P
s
P
p
.002 w
.64653 .54699 m .60248 .58043 L .60351 .59161 L p
1 g
F P
s
P
p
.002 w
.67734 .35213 m .67962 .40109 L .68975 .42003 L p
1 g
F P
s
P
p
.002 w
.67962 .40109 m .67734 .35213 L .66258 .33616 L p
1 g
F P
s
P
p
.002 w
.55063 .25168 m .51059 .23902 L .49903 .24782 L p
1 g
F P
s
P
p
.002 w
.46185 .24816 m .49903 .24782 L .51059 .23902 L p
1 g
F P
s
P
p
.002 w
.34286 .54947 m .38131 .58047 L .37271 .5624 L p
1 g
F P
s
P
p
.002 w
.37271 .5624 m .33361 .53058 L .34286 .54947 L p
1 g
F P
s
P
p
.002 w
.45328 .62075 m .50351 .62315 L .49528 .61421 L p
1 g
F P
s
P
p
.002 w
.49528 .61421 m .44126 .61151 L .45328 .62075 L p
1 g
F P
s
P
p
.002 w
.56853 .24985 m .60293 .2772 L .62309 .28327 L p
1 g
F P
s
P
p
.002 w
.60293 .2772 m .56853 .24985 L .55063 .25168 L p
1 g
F P
s
P
p
.002 w
.42013 .25297 m .38112 .27816 L .39307 .27987 L p
1 g
F P
s
P
p
.002 w
.39307 .27987 m .425 .25929 L .42013 .25297 L p
1 g
F P
s
P
p
.002 w
.51059 .23902 m .55063 .25168 L .56853 .24985 L p
1 g
F P
s
P
p
.002 w
.30572 .39587 m .30781 .44515 L .31396 .42433 L p
1 g
F P
s
P
p
.002 w
.31396 .42433 m .31217 .37809 L .30572 .39587 L p
1 g
F P
s
P
p
.002 w
.51059 .23902 m .4652 .23937 L .46185 .24816 L p
1 g
F P
s
P
p
.002 w
.425 .25929 m .46185 .24816 L .4652 .23937 L p
1 g
F P
s
P
p
.002 w
.64653 .54699 m .67861 .50575 L .67788 .48776 L p
1 g
F P
s
P
p
.002 w
.69504 .43988 m .67788 .48776 L .67861 .50575 L p
1 g
F P
s
P
p
.002 w
.67788 .48776 m .69504 .43988 L .68975 .42003 L p
1 g
F P
s
P
p
.002 w
.4652 .23937 m .42013 .25297 L .425 .25929 L p
1 g
F P
s
P
p
.002 w
.60351 .59161 m .64459 .56053 L .64653 .54699 L p
1 g
F P
s
P
p
.002 w
.67861 .50575 m .64653 .54699 L .64459 .56053 L p
1 g
F P
s
P
p
.002 w
.64057 .29357 m .66258 .33616 L .67734 .35213 L p
1 g
F P
s
P
p
.002 w
.66258 .33616 m .64057 .29357 L .62309 .28327 L p
1 g
F P
s
P
p
.002 w
.31101 .48707 m .33361 .53058 L .32909 .50963 L p
1 g
F P
s
P
p
.002 w
.32909 .50963 m .30673 .46625 L .31101 .48707 L p
1 g
F P
s
P
p
.002 w
.37195 .28058 m .33948 .31931 L .35303 .31158 L p
1 g
F P
s
P
p
.002 w
.35303 .31158 m .38112 .27816 L .37195 .28058 L p
1 g
F P
s
P
p
.002 w
.32986 .33044 m .31217 .37809 L .32341 .36233 L p
1 g
F P
s
P
p
.002 w
.32341 .36233 m .33948 .31931 L .32986 .33044 L p
1 g
F P
s
P
p
.002 w
.68771 .37079 m .68975 .42003 L .69504 .43988 L p
1 g
F P
s
P
p
.002 w
.68975 .42003 m .68771 .37079 L .67734 .35213 L p
1 g
F P
s
P
p
.002 w
.40901 .60564 m .45328 .62075 L .44126 .61151 L p
1 g
F P
s
P
p
.002 w
.44126 .61151 m .39346 .59508 L .40901 .60564 L p
1 g
F P
s
P
p
.002 w
.51199 .62717 m .55826 .61811 L .55508 .61308 L p
1 g
F P
s
P
p
.002 w
.55508 .61308 m .50351 .62315 L .51199 .62717 L p
1 g
F P
s
P
p
.002 w
.60351 .59161 m .55508 .61308 L .55826 .61811 L p
1 g
F P
s
P
p
.002 w
.35683 .56567 m .39346 .59508 L .38131 .58047 L p
1 g
F P
s
P
p
.002 w
.38131 .58047 m .34286 .54947 L .35683 .56567 L p
1 g
F P
s
P
p
.002 w
.55826 .61811 m .60175 .59884 L .60351 .59161 L p
1 g
F P
s
P
p
.002 w
.64459 .56053 m .60351 .59161 L .60175 .59884 L p
1 g
F P
s
P
p
.002 w
.56853 .24985 m .52233 .23513 L .51059 .23902 L p
1 g
F P
s
P
p
.002 w
.4652 .23937 m .51059 .23902 L .52233 .23513 L p
1 g
F P
s
P
p
.002 w
.58522 .25293 m .62309 .28327 L .64057 .29357 L p
1 g
F P
s
P
p
.002 w
.62309 .28327 m .58522 .25293 L .56853 .24985 L p
1 g
F P
s
P
p
.002 w
.46707 .62507 m .51199 .62717 L .50351 .62315 L p
1 g
F P
s
P
p
.002 w
.50351 .62315 m .45328 .62075 L .46707 .62507 L p
1 g
F P
s
P
p
.002 w
.30451 .41527 m .30673 .46625 L .30781 .44515 L p
1 g
F P
s
P
p
.002 w
.30781 .44515 m .30572 .39587 L .30451 .41527 L p
1 g
F P
s
P
p
.002 w
.52233 .23513 m .56853 .24985 L .58522 .25293 L p
1 g
F P
s
P
p
.002 w
.41725 .2513 m .37195 .28058 L .38112 .27816 L p
1 g
F P
s
P
p
.002 w
.38112 .27816 m .42013 .25297 L .41725 .2513 L p
1 g
F P
s
P
p
.002 w
.64459 .56053 m .67444 .52235 L .67861 .50575 L p
1 g
F P
s
P
p
.002 w
.69512 .46017 m .67861 .50575 L .67444 .52235 L p
1 g
F P
s
P
p
.002 w
.67861 .50575 m .69512 .46017 L .69504 .43988 L p
1 g
F P
s
P
p
.002 w
.65474 .30805 m .67734 .35213 L .68771 .37079 L p
1 g
F P
s
P
p
.002 w
.67734 .35213 m .65474 .30805 L .64057 .29357 L p
1 g
F P
s
P
p
.002 w
.32078 .50699 m .34286 .54947 L .33361 .53058 L p
1 g
F P
s
P
p
.002 w
.33361 .53058 m .31101 .48707 L .32078 .50699 L p
1 g
F P
s
P
p
.002 w
.52233 .23513 m .46967 .23549 L .4652 .23937 L p
1 g
F P
s
P
p
.002 w
.42013 .25297 m .4652 .23937 L .46967 .23549 L p
1 g
F P
s
P
p
.002 w
.60175 .59884 m .63857 .57103 L .64459 .56053 L p
1 g
F P
s
P
p
.002 w
.67444 .52235 m .64459 .56053 L .63857 .57103 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.62862 .57416 L
s
P
p
.004 w
.63096 .57678 m
.6346 .58084 L
s
P
p
.004 w
.6346 .58084 m
.65698 .60584 L
s
P
p
.004 w
.65698 .60584 m
.6947 .64797 L
s
P
p
.002 w
.46967 .23549 m .41725 .2513 L .42013 .25297 L p
1 g
F P
s
P
p
.002 w
.32467 .34484 m .30572 .39587 L .31217 .37809 L p
1 g
F P
s
P
p
.002 w
.31217 .37809 m .32986 .33044 L .32467 .34484 L p
1 g
F P
s
P
p
.002 w
.69504 .43988 m .69317 .39175 L .68771 .37079 L p
1 g
F P
s
P
p
.002 w
.69317 .39175 m .69504 .43988 L .69512 .46017 L p
1 g
F P
s
P
p
.002 w
.36599 .28733 m .32986 .33044 L .33948 .31931 L p
1 g
F P
s
P
p
.002 w
.33948 .31931 m .37195 .28058 L .36599 .28733 L p
1 g
F P
s
P
p
.002 w
.42771 .61162 m .46707 .62507 L .45328 .62075 L p
1 g
F P
s
P
p
.002 w
.45328 .62075 m .40901 .60564 L .42771 .61162 L p
1 g
F P
s
P
p
.002 w
.37535 .57855 m .40901 .60564 L .39346 .59508 L p
1 g
F P
s
P
p
.002 w
.39346 .59508 m .35683 .56567 L .37535 .57855 L p
1 g
F P
s
P
p
.002 w
.64057 .29357 m .60015 .2611 L .58522 .25293 L p
1 g
F P
s
P
p
.002 w
.60015 .2611 m .64057 .29357 L .65474 .30805 L p
1 g
F P
s
P
p
.002 w
.52051 .62583 m .55995 .6181 L .55826 .61811 L p
1 g
F P
s
P
p
.002 w
.55826 .61811 m .51199 .62717 L .52051 .62583 L p
1 g
F P
s
P
p
.002 w
.60175 .59884 m .55826 .61811 L .55995 .6181 L p
1 g
F P
s
P
p
.002 w
.30887 .4358 m .31101 .48707 L .30673 .46625 L p
1 g
F P
s
P
p
.002 w
.30673 .46625 m .30451 .41527 L .30887 .4358 L p
1 g
F P
s
P
p
.002 w
.58522 .25293 m .53393 .23654 L .52233 .23513 L p
1 g
F P
s
P
p
.002 w
.46967 .23549 m .52233 .23513 L .53393 .23654 L p
1 g
F P
s
P
p
.002 w
.55995 .6181 m .59705 .60167 L .60175 .59884 L p
1 g
F P
s
P
p
.002 w
.63857 .57103 m .60175 .59884 L .59705 .60167 L p
1 g
F P
s
P
p
.002 w
.53393 .23654 m .58522 .25293 L .60015 .2611 L p
1 g
F P
s
P
p
.002 w
.68771 .37079 m .66502 .32649 L .65474 .30805 L p
1 g
F P
s
P
p
.002 w
.66502 .32649 m .68771 .37079 L .69317 .39175 L p
1 g
F P
s
P
p
.002 w
.48235 .62403 m .52051 .62583 L .51199 .62717 L p
1 g
F P
s
P
p
.002 w
.51199 .62717 m .46707 .62507 L .48235 .62403 L p
1 g
F P
s
P
p
.002 w
.33603 .52535 m .35683 .56567 L .34286 .54947 L p
1 g
F P
s
P
p
.002 w
.34286 .54947 m .32078 .50699 L .33603 .52535 L p
1 g
F P
s
P
p
.002 w
.63857 .57103 m .66521 .537 L .67444 .52235 L p
1 g
F P
s
P
p
.002 w
.67444 .52235 m .6897 .48032 L .69512 .46017 L p
1 g
F P
s
P
p
.002 w
.6897 .48032 m .67444 .52235 L .66521 .537 L p
1 g
F P
s
P
p
.002 w
.4166 .25465 m .36599 .28733 L .37195 .28058 L p
1 g
F P
s
P
p
.002 w
.37195 .28058 m .41725 .2513 L .4166 .25465 L p
1 g
F P
s
P
p
.002 w
.32434 .36227 m .30451 .41527 L .30572 .39587 L p
1 g
F P
s
P
p
.002 w
.30572 .39587 m .32467 .34484 L .32434 .36227 L p
1 g
F P
s
P
p
.002 w
.59705 .60167 m .62839 .57799 L .63857 .57103 L p
1 g
F P
s
P
p
.002 w
.66521 .537 m .63857 .57103 L .62839 .57799 L p
1 g
F P
s
P
p
.002 w
.69332 .4145 m .69512 .46017 L .6897 .48032 L p
1 g
F P
s
P
p
.002 w
.69512 .46017 m .69332 .4145 L .69317 .39175 L p
1 g
F P
s
P
p
.002 w
.53393 .23654 m .47519 .23696 L .46967 .23549 L p
1 g
F P
s
P
p
.002 w
.41725 .2513 m .46967 .23549 L .47519 .23696 L p
1 g
F P
s
P
p
.002 w
.47519 .23696 m .4166 .25465 L .41725 .2513 L p
1 g
F P
s
P
p
.002 w
.36363 .29849 m .32467 .34484 L .32986 .33044 L p
1 g
F P
s
P
p
.002 w
.32986 .33044 m .36599 .28733 L .36363 .29849 L p
1 g
F P
s
P
p
.002 w
.39806 .58758 m .42771 .61162 L .40901 .60564 L p
1 g
F P
s
P
p
.002 w
.40901 .60564 m .37535 .57855 L .39806 .58758 L p
1 g
F P
s
P
p
.002 w
.61278 .27442 m .65474 .30805 L .66502 .32649 L p
1 g
F P
s
P
p
.002 w
.65474 .30805 m .61278 .27442 L .60015 .2611 L p
1 g
F P
s
P
p
.002 w
.44914 .61259 m .48235 .62403 L .46707 .62507 L p
1 g
F P
s
P
p
.002 w
.46707 .62507 m .42771 .61162 L .44914 .61259 L p
1 g
F P
s
P
p
.002 w
.31893 .45686 m .32078 .50699 L .31101 .48707 L p
1 g
F P
s
P
p
.002 w
.31101 .48707 m .30887 .4358 L .31893 .45686 L p
1 g
F P
s
P
p
.002 w
.6709 .34855 m .69317 .39175 L .69332 .4145 L p
1 g
F P
s
P
p
.002 w
.69317 .39175 m .6709 .34855 L .66502 .32649 L p
1 g
F P
s
P
p
.002 w
.52879 .61882 m .56 .61273 L .55995 .6181 L p
1 g
F P
s
P
p
.002 w
.55995 .6181 m .52051 .62583 L .52879 .61882 L p
1 g
F P
s
P
p
.002 w
.59705 .60167 m .55995 .6181 L .56 .61273 L p
1 g
F P
s
P
p
.004 w
.56977 .61807 m
.57858 .64174 L
s
P
p
.002 w
.60015 .2611 m .54504 .24356 L .53393 .23654 L p
1 g
F P
s
P
p
.002 w
.47519 .23696 m .53393 .23654 L .54504 .24356 L p
1 g
F P
s
P
p
.002 w
.35652 .5415 m .37535 .57855 L .35683 .56567 L p
1 g
F P
s
P
p
.002 w
.35683 .56567 m .33603 .52535 L .35652 .5415 L p
1 g
F P
s
P
p
.002 w
.54504 .24356 m .60015 .2611 L .61278 .27442 L p
1 g
F P
s
P
p
.002 w
.56 .61273 m .58936 .59971 L .59705 .60167 L p
1 g
F P
s
P
p
.002 w
.62839 .57799 m .59705 .60167 L .58936 .59971 L p
1 g
F P
s
P
p
.002 w
.62839 .57799 m .65091 .54914 L .66521 .537 L p
1 g
F P
s
P
p
.002 w
.67867 .49973 m .66521 .537 L .65091 .54914 L p
1 g
F P
s
P
p
.002 w
.66521 .537 m .67867 .49973 L .6897 .48032 L p
1 g
F P
s
P
p
.002 w
.49873 .61734 m .52879 .61882 L .52051 .62583 L p
1 g
F P
s
P
p
.002 w
.52051 .62583 m .48235 .62403 L .49873 .61734 L p
1 g
F P
s
P
p
.002 w
.6879 .43843 m .6897 .48032 L .67867 .49973 L p
1 g
F P
s
P
p
.002 w
.6897 .48032 m .6879 .43843 L .69332 .4145 L p
1 g
F P
s
P
p
.002 w
.41833 .26323 m .36363 .29849 L .36599 .28733 L p
1 g
F P
s
P
p
.002 w
.36599 .28733 m .4166 .25465 L .41833 .26323 L p
1 g
F P
s
P
p
.002 w
.32915 .38236 m .30887 .4358 L .30451 .41527 L p
1 g
F P
s
P
p
.002 w
.30451 .41527 m .32434 .36227 L .32915 .38236 L p
1 g
F P
s
P
p
.002 w
.58936 .59971 m .61409 .58099 L .62839 .57799 L p
1 g
F P
s
P
p
.002 w
.65091 .54914 m .62839 .57799 L .61409 .58099 L p
1 g
F P
s
P
p
.002 w
.36518 .31398 m .32434 .36227 L .32467 .34484 L p
1 g
F P
s
P
p
.002 w
.32467 .34484 m .36363 .29849 L .36518 .31398 L p
1 g
F P
s
P
p
.002 w
.54504 .24356 m .48167 .2441 L .47519 .23696 L p
1 g
F P
s
P
p
.002 w
.4166 .25465 m .47519 .23696 L .48167 .2441 L p
1 g
F P
s
P
p
.002 w
.6226 .29277 m .66502 .32649 L .6709 .34855 L p
1 g
F P
s
P
p
.002 w
.66502 .32649 m .6226 .29277 L .61278 .27442 L p
1 g
F P
s
P
p
.002 w
.42442 .59226 m .44914 .61259 L .42771 .61162 L p
1 g
F P
s
P
p
.002 w
.42771 .61162 m .39806 .58758 L .42442 .59226 L p
1 g
F P
s
P
p
.002 w
.33466 .4778 m .33603 .52535 L .32078 .50699 L p
1 g
F P
s
P
p
.002 w
.32078 .50699 m .31893 .45686 L .33466 .4778 L p
1 g
F P
s
P
p
.002 w
.48167 .2441 m .41833 .26323 L .4166 .25465 L p
1 g
F P
s
P
p
.002 w
.47278 .60827 m .49873 .61734 L .48235 .62403 L p
1 g
F P
s
P
p
.002 w
.48235 .62403 m .44914 .61259 L .47278 .60827 L p
1 g
F P
s
P
p
.002 w
.67197 .3737 m .69332 .4145 L .6879 .43843 L p
1 g
F P
s
P
p
.002 w
.69332 .4145 m .67197 .3737 L .6709 .34855 L p
1 g
F P
s
P
p
.002 w
.38182 .55481 m .39806 .58758 L .37535 .57855 L p
1 g
F P
s
P
p
.002 w
.37535 .57855 m .35652 .5415 L .38182 .55481 L p
1 g
F P
s
P
p
.002 w
.55528 .25631 m .61278 .27442 L .6226 .29277 L p
1 g
F P
s
P
p
.002 w
.61278 .27442 m .55528 .25631 L .54504 .24356 L p
1 g
F P
s
P
p
.002 w
.48167 .2441 m .54504 .24356 L .55528 .25631 L p
1 g
F P
s
P
p
.002 w
.66208 .51775 m .65091 .54914 L .6317 .55828 L p
1 g
F P
s
P
p
.002 w
.61409 .58099 m .6317 .55828 L .65091 .54914 L p
1 g
F P
s
P
p
.002 w
.65091 .54914 m .66208 .51775 L .67867 .49973 L p
1 g
F P
s
P
p
.002 w
.53658 .60601 m .55829 .6018 L .56 .61273 L p
1 g
F P
s
P
p
.002 w
.56 .61273 m .52879 .61882 L .53658 .60601 L p
1 g
F P
s
P
p
.002 w
.58936 .59971 m .56 .61273 L .55829 .6018 L p
1 g
F P
s
P
p
.002 w
.67682 .46284 m .67867 .49973 L .66208 .51775 L p
1 g
F P
s
P
p
.002 w
.67867 .49973 m .67682 .46284 L .6879 .43843 L p
1 g
F P
s
P
p
.002 w
.55829 .6018 m .57874 .59272 L .58936 .59971 L p
1 g
F P
s
P
p
.002 w
.61409 .58099 m .58936 .59971 L .57874 .59272 L p
1 g
F P
s
P
p
.002 w
.33921 .40455 m .31893 .45686 L .30887 .4358 L p
1 g
F P
s
P
p
.002 w
.30887 .4358 m .32915 .38236 L .33921 .40455 L p
1 g
F P
s
P
p
.002 w
.51575 .60492 m .53658 .60601 L .52879 .61882 L p
1 g
F P
s
P
p
.002 w
.52879 .61882 m .49873 .61734 L .51575 .60492 L p
1 g
F P
s
P
p
.002 w
.42255 .27712 m .36518 .31398 L .36363 .29849 L p
1 g
F P
s
P
p
.002 w
.36363 .29849 m .41833 .26323 L .42255 .27712 L p
1 g
F P
s
P
p
.002 w
.62913 .31579 m .6709 .34855 L .67197 .3737 L p
1 g
F P
s
P
p
.002 w
.6709 .34855 m .62913 .31579 L .6226 .29277 L p
1 g
F P
s
P
p
.002 w
.35577 .49789 m .35652 .5415 L .33603 .52535 L p
1 g
F P
s
P
p
.002 w
.33603 .52535 m .33466 .4778 L .35577 .49789 L p
1 g
F P
s
P
p
.002 w
.45372 .59226 m .47278 .60827 L .44914 .61259 L p
1 g
F P
s
P
p
.002 w
.44914 .61259 m .42442 .59226 L .45372 .59226 L p
1 g
F P
s
P
p
.002 w
.57874 .59272 m .59588 .57968 L .61409 .58099 L p
1 g
F P
s
P
p
.002 w
.6317 .55828 m .61409 .58099 L .59588 .57968 L p
1 g
F P
s
P
p
.002 w
.3708 .33353 m .32915 .38236 L .32434 .36227 L p
1 g
F P
s
P
p
.002 w
.32434 .36227 m .36518 .31398 L .3708 .33353 L p
1 g
F P
s
P
p
.002 w
.66799 .40125 m .6879 .43843 L .67682 .46284 L p
1 g
F P
s
P
p
.002 w
.6879 .43843 m .66799 .40125 L .67197 .3737 L p
1 g
F P
s
P
p
.002 w
.55528 .25631 m .48895 .25702 L .48167 .2441 L p
1 g
F P
s
P
p
.002 w
.41833 .26323 m .48167 .2441 L .48895 .25702 L p
1 g
F P
s
P
p
.002 w
.41123 .5647 m .42442 .59226 L .39806 .58758 L p
1 g
F P
s
P
p
.002 w
.39806 .58758 m .38182 .55481 L .41123 .5647 L p
1 g
F P
s
P
p
.002 w
.49793 .59854 m .51575 .60492 L .49873 .61734 L p
1 g
F P
s
P
p
.002 w
.49873 .61734 m .47278 .60827 L .49793 .59854 L p
1 g
F P
s
P
p
.002 w
.48895 .25702 m .42255 .27712 L .41833 .26323 L p
1 g
F P
s
P
p
.002 w
.56427 .2747 m .6226 .29277 L .62913 .31579 L p
1 g
F P
s
P
p
.002 w
.6226 .29277 m .56427 .2747 L .55528 .25631 L p
1 g
F P
s
P
p
.002 w
.6317 .55828 m .64023 .53373 L .66208 .51775 L p
1 g
F P
s
P
p
.002 w
.66021 .48692 m .66208 .51775 L .64023 .53373 L p
1 g
F P
s
P
p
.002 w
.66208 .51775 m .66021 .48692 L .67682 .46284 L p
1 g
F P
s
P
p
.002 w
.59588 .57968 m .60796 .56394 L .6317 .55828 L p
1 g
F P
s
P
p
.002 w
.64023 .53373 m .6317 .55828 L .60796 .56394 L p
1 g
F P
s
P
p
.002 w
.35444 .42819 m .33466 .4778 L .31893 .45686 L p
1 g
F P
s
P
p
.002 w
.31893 .45686 m .33921 .40455 L .35444 .42819 L p
1 g
F P
s
P
p
.002 w
.48895 .25702 m .55528 .25631 L .56427 .2747 L p
1 g
F P
s
P
p
.002 w
.3817 .51639 m .38182 .55481 L .35652 .5415 L p
1 g
F P
s
P
p
.002 w
.35652 .5415 m .35577 .49789 L .3817 .51639 L p
1 g
F P
s
P
p
.002 w
.63199 .34295 m .67197 .3737 L .66799 .40125 L p
1 g
F P
s
P
p
.002 w
.67197 .3737 m .63199 .34295 L .62913 .31579 L p
1 g
F P
s
P
p
.002 w
.54357 .58748 m .55479 .58532 L .55829 .6018 L p
1 g
F P
s
P
p
.002 w
.55829 .6018 m .53658 .60601 L .54357 .58748 L p
1 g
F P
s
P
p
.002 w
.57874 .59272 m .55829 .6018 L .55479 .58532 L p
1 g
F P
s
P
p
.002 w
.55479 .58532 m .56534 .58063 L .57874 .59272 L p
1 g
F P
s
P
p
.002 w
.59588 .57968 m .57874 .59272 L .56534 .58063 L p
1 g
F P
s
P
p
.002 w
.48504 .58742 m .49793 .59854 L .47278 .60827 L p
1 g
F P
s
P
p
.002 w
.47278 .60827 m .45372 .59226 L .48504 .58742 L p
1 g
F P
s
P
p
.002 w
.65888 .43034 m .67682 .46284 L .66021 .48692 L p
1 g
F P
s
P
p
.002 w
.67682 .46284 m .65888 .43034 L .66799 .40125 L p
1 g
F P
s
P
p
.002 w
.53287 .58686 m .54357 .58748 L .53658 .60601 L p
1 g
F P
s
P
p
.002 w
.53658 .60601 m .51575 .60492 L .53287 .58686 L p
1 g
F P
s
P
p
.002 w
.44385 .57074 m .45372 .59226 L .42442 .59226 L p
1 g
F P
s
P
p
.002 w
.42442 .59226 m .41123 .5647 L .44385 .57074 L p
1 g
F P
s
P
p
.002 w
.42926 .29616 m .3708 .33353 L .36518 .31398 L p
1 g
F P
s
P
p
.002 w
.36518 .31398 m .42255 .27712 L .42926 .29616 L p
1 g
F P
s
P
p
.002 w
.38054 .35669 m .33921 .40455 L .32915 .38236 L p
1 g
F P
s
P
p
.002 w
.32915 .38236 m .3708 .33353 L .38054 .35669 L p
1 g
F P
s
P
p
.002 w
.56534 .58063 m .57415 .57388 L .59588 .57968 L p
1 g
F P
s
P
p
.002 w
.60796 .56394 m .59588 .57968 L .57415 .57388 L p
1 g
F P
s
P
p
.002 w
.5238 .58352 m .53287 .58686 L .51575 .60492 L p
1 g
F P
s
P
p
.002 w
.51575 .60492 m .49793 .59854 L .5238 .58352 L p
1 g
F P
s
P
p
.002 w
.60796 .56394 m .61364 .54705 L .64023 .53373 L p
1 g
F P
s
P
p
.002 w
.63845 .50984 m .64023 .53373 L .61364 .54705 L p
1 g
F P
s
P
p
.002 w
.64023 .53373 m .63845 .50984 L .66021 .48692 L p
1 g
F P
s
P
p
.002 w
.56427 .2747 m .49685 .27565 L .48895 .25702 L p
1 g
F P
s
P
p
.002 w
.42255 .27712 m .48895 .25702 L .49685 .27565 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.57163 .29841 m .62913 .31579 L .63199 .34295 L p
1 g
F P
s
P
p
.002 w
.62913 .31579 m .57163 .29841 L .56427 .2747 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37448 .45248 m .35577 .49789 L .33466 .4778 L p
1 g
F P
s
P
p
.002 w
.33466 .4778 m .35444 .42819 L .37448 .45248 L p
1 g
F P
s
P
p
.002 w
.49685 .27565 m .42926 .29616 L .42255 .27712 L p
1 g
F P
s
P
p
.002 w
.61364 .54705 m .60796 .56394 L .58029 .56577 L p
1 g
F P
s
P
p
.002 w
.57415 .57388 m .58029 .56577 L .60796 .56394 L p
1 g
F P
s
P
p
.002 w
.41167 .53259 m .41123 .5647 L .38182 .55481 L p
1 g
F P
s
P
p
.002 w
.38182 .55481 m .3817 .51639 L .41167 .53259 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.63092 .37345 m .66799 .40125 L .65888 .43034 L p
1 g
F P
s
P
p
.002 w
.66799 .40125 m .63092 .37345 L .63199 .34295 L p
1 g
F P
s
P
p
.002 w
.64479 .46002 m .66021 .48692 L .63845 .50984 L p
1 g
F P
s
P
p
.002 w
.66021 .48692 m .64479 .46002 L .65888 .43034 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53873 .53462 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.49685 .27565 m .56427 .2747 L .57163 .29841 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48504 .58742 m .45372 .59226 L p
.4738 .57641 L 1 g
F P
s
P
p
.002 w
.48137 .57898 m .48504 .58742 L p
.4738 .57641 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45372 .59226 m .44385 .57074 L .45966 .5716 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57454 L p
1 g
F P
s
P
p
.48921 .57862 m .46831 .57454 L .47746 .57766 L 1 g
F
P
p
.002 w
.45966 .5716 m .46372 .57182 L p
.46831 .57454 L 1 g
F P
s
P
p
.45372 .59226 m .45966 .5716 L .4738 .57641 L 1 g
F
P
p
.002 w
.46372 .57182 m .44385 .57074 L p
.45519 .56594 L 1 g
F P
s
P
p
.002 w
.46831 .57454 m .46872 .57265 L p
.4577 .56825 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45085 .56294 L p
1 g
F P
s
P
p
.002 w
.44385 .57074 m .44425 .55839 L p
.45085 .56294 L 1 g
F P
s
P
p
.45387 .5665 m .45085 .56294 L .45519 .56594 L 1 g
F
P
p
.44385 .57074 m .45085 .56294 L .45387 .5665 L 1 g
F
P
p
.002 w
.45085 .56294 m .45146 .56129 L p
.44399 .5548 L 1 g
F P
s
P
p
.002 w
.44435 .55529 m .44385 .57074 L p
.43953 .54874 L 1 g
F P
s
P
p
.44399 .5548 m .44378 .55462 L .44435 .55529 L 1 g
F
P
p
.44399 .5548 m .44435 .55529 L .45085 .56294 L 1 g
F
P
p
.002 w
.44385 .57074 m .41123 .5647 L p
.43953 .54874 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43842 .54723 L p
1 g
F P
s
P
p
.41123 .5647 m .43436 .54171 L .43842 .54723 L 1 g
F
P
p
.43907 .549 m .43842 .54723 L .43953 .54874 L 1 g
F
P
p
.41123 .5647 m .43842 .54723 L .43907 .549 L 1 g
F
P
p
.002 w
.43842 .54723 m .43925 .54566 L p
.43555 .53833 L 1 g
F P
s
P
p
.41167 .53259 m .43243 .5269 L .43281 .52829 L 1 g
F
P
p
.002 w
.43672 .54266 m .43202 .54077 L p
.43281 .52829 L 1 g
F P
s
P
p
.002 w
.43202 .54077 m .41167 .53259 L p
.43281 .52829 L 1 g
F P
s
P
p
.002 w
.43281 .52829 m .43346 .52734 L p
.43325 .52133 L 1 g
F P
s
P
p
.43555 .53833 m .43672 .54266 L .43842 .54723 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.45146 .56129 m .43842 .54723 L .44124 .55107 L 1 g
F
P
p
.43953 .54874 m .43842 .54723 L .44466 .54585 L 1 g
F
P
p
.002 w
.43436 .54171 m .43672 .54266 L p
.43842 .54723 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43189 .52963 L p
1 g
F P
s
P
p
.43925 .54566 m .43189 .52963 L .43394 .53515 L 1 g
F
P
p
.002 w
.43672 .54266 m .44466 .54585 L p
.43842 .54723 L 1 g
F P
s
P
p
.002 w
.43189 .52963 m .43146 .53025 L p
.43394 .53515 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.43281 .52829 m .4565 .52031 L .43672 .54266 L 1 g
F
P
p
.43243 .5269 m .43291 .52677 L .43281 .52829 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43401 .50925 L p
1 g
F P
s
P
p
.43346 .52734 m .43401 .50925 L .43325 .52133 L 1 g
F
P
p
.43291 .52677 m .4565 .52031 L .43281 .52829 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.41167 .53259 m .42643 .49944 L .43559 .5058 L p
1 g
F P
s
P
p
.002 w
.43401 .50925 m .43485 .50826 L p
.438 .5009 L 1 g
F P
s
P
p
.002 w
.43559 .5058 m .42643 .49944 L p
.43899 .49888 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.42643 .49944 m .45261 .47114 L p
.44279 .49114 L 1 g
F P
s
P
p
.4346 .49907 m .44279 .49114 L .43899 .49888 L 1 g
F
P
p
.42643 .49944 m .44279 .49114 L .4346 .49907 L 1 g
F
P
p
.002 w
.44325 .49079 m .44166 .49233 L p
.43485 .50826 L 1 g
F P
s
P
p
.002 w
.44334 .49061 m .44339 .4905 L p
.44279 .49114 L 1 g
F P
s
P
p
.002 w
.44279 .49114 m .44339 .4905 L p
.44881 .48531 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43899 .49888 m .44322 .49072 L .47836 .49714 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45766 .47674 L p
1 g
F P
s
P
p
.44339 .4905 m .45766 .47674 L .44881 .48531 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45766 .47674 m .45826 .47608 L p
.46674 .47236 L 1 g
F P
s
P
p
.46794 .47177 m .50781 .47922 L .45992 .4757 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.45436 .46924 m .49238 .4459 L .49764 .45726 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.46794 .47177 m .47764 .46703 L .50781 .47922 L 1 g
F
P
p
.47764 .46703 m .5 .46387 L .50781 .47922 L 1 g
F
P
p
.002 w
.5 .46387 m .5 .4634 L p
.50999 .46532 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.50781 .47922 m .50076 .464 L p
.5224 .4671 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56616 .50946 L p
1 g
F P
s
P
p
.55661 .4905 m .56616 .50946 L .56612 .50939 L 1 g
F
P
p
.002 w
.56824 .50234 m .56629 .50974 L p
.56616 .50946 L 1 g
F P
s
P
p
.002 w
.56296 .50264 m .56561 .50249 L p
.56616 .50946 L 1 g
F P
s
P
p
.002 w
.56561 .50249 m .56824 .50234 L p
.56616 .50946 L 1 g
F P
s
P
p
.002 w
.56616 .50946 m .56515 .50826 L p
.56685 .51928 L 1 g
F P
s
P
p
.002 w
.56982 .53708 m .56807 .53669 L p
.56754 .52866 L 1 g
F P
s
P
p
.56629 .50974 m .56834 .52557 L .56754 .52866 L 1 g
F
P
p
.56834 .52557 m .56982 .53708 L .56754 .52866 L 1 g
F
P
p
.002 w
.56751 .52876 m .56654 .52734 L p
.56424 .53996 L 1 g
F P
s
P
p
.002 w
.56982 .53708 m .5613 .54816 L p
.56162 .54729 L 1 g
F P
s
P
p
.002 w
.5656 .53615 m .56933 .53697 L p
.56162 .54729 L 1 g
F P
s
P
p
.002 w
.56933 .53697 m .56982 .53708 L p
.56162 .54729 L 1 g
F P
s
P
p
.002 w
.56162 .54729 m .56075 .54566 L p
.55487 .55631 L 1 g
F P
s
P
p
.56424 .53996 m .5656 .53615 L .56751 .52876 L 1 g
F
P
p
.002 w
.5613 .54816 m .54949 .56354 L p
.54956 .56343 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5494 .56361 L p
1 g
F P
s
P
p
.002 w
.54941 .5636 m .54949 .56354 L p
.54945 .56358 L 1 g
F P
s
P
p
.52875 .58534 m .5494 .56361 L .54945 .56358 L 1 g
F
P
p
.5494 .56361 m .54941 .5636 L .54945 .56358 L 1 g
F
P
p
.002 w
.54949 .56354 m .53287 .58686 L .52875 .58534 L p
1 g
F P
s
P
p
.002 w
.5494 .56361 m .54854 .56129 L p
.53986 .56956 L 1 g
F P
s
P
p
.002 w
.5238 .58352 m .52119 .5812 L p
.53171 .57464 L 1 g
F P
s
P
p
.002 w
.54939 .56362 m .53806 .57243 L p
.53171 .57464 L 1 g
F P
s
P
p
.002 w
.53806 .57243 m .5238 .58352 L p
.53171 .57464 L 1 g
F P
s
P
p
.002 w
.53171 .57464 m .53128 .57265 L p
.51855 .57918 L 1 g
F P
s
P
p
.002 w
.51886 .57911 m .5238 .58352 L p
.5154 .57986 L 1 g
F P
s
P
p
.51855 .57918 m .51831 .5793 L .51886 .57911 L 1 g
F
P
p
.51855 .57918 m .51886 .57911 L .53171 .57464 L 1 g
F
P
p
.002 w
.5238 .58352 m .49793 .59854 L p
.5154 .57986 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58081 L p
1 g
F P
s
P
p
.49793 .59854 m .49762 .58366 L .51095 .58081 L 1 g
F
P
p
.51456 .58075 m .51095 .58081 L .5154 .57986 L 1 g
F
P
p
.49793 .59854 m .51095 .58081 L .51456 .58075 L 1 g
F
P
p
.002 w
.51095 .58081 m .51079 .57862 L p
.49983 .58081 L 1 g
F P
s
P
p
.002 w
.50695 .58088 m .48504 .58742 L p
.4963 .58078 L 1 g
F P
s
P
p
.49983 .58081 m .49879 .58102 L .50695 .58088 L 1 g
F
P
p
.49983 .58081 m .50695 .58088 L .51095 .58081 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58071 L p
1 g
F P
s
P
p
.002 w
.48504 .58742 m .48209 .58065 L p
.48905 .58071 L 1 g
F P
s
P
p
.49439 .58191 m .48905 .58071 L .4963 .58078 L 1 g
F
P
p
.48504 .58742 m .48905 .58071 L .49439 .58191 L 1 g
F
P
p
.48921 .57862 m .47746 .57766 L .48137 .57898 L 1 g
F
P
p
.002 w
.48905 .58071 m .48921 .57862 L p
.48137 .57898 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58071 L .49983 .58081 L 1 g
F
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.48905 .58071 m .47859 .57262 L .4963 .58078 L 1 g
F
P
p
.002 w
.48209 .58065 m .48137 .57898 L p
.48905 .58071 L 1 g
F P
s
P
p
.002 w
.48137 .57898 m .47859 .57262 L p
.48905 .58071 L 1 g
F P
s
P
p
.48137 .57898 m .4678 .57686 L .48899 .58158 L 1 g
F
P
p
.47746 .57766 m .47431 .5774 L .48137 .57898 L 1 g
F
P
p
.47431 .5774 m .4678 .57686 L .48137 .57898 L 1 g
F
P
p
.002 w
.48899 .58158 m .48905 .58071 L p
.48137 .57898 L 1 g
F P
s
P
p
.002 w
.48905 .58071 m .48889 .583 L p
.49983 .58081 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.47859 .57262 m .51424 .5702 L p
.4963 .58078 L 1 g
F P
s
P
p
.002 w
.51424 .5702 m .51735 .57777 L .50695 .58088 L p
1 g
F P
s
P
p
.4963 .58078 m .51424 .5702 L .50695 .58088 L 1 g
F
P
p
.53128 .57265 m .51095 .58081 L .5154 .57986 L 1 g
F
P
p
.002 w
.49762 .58366 m .51735 .57777 L p
.5154 .57986 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51095 .58081 L p
1 g
F P
s
P
p
.49879 .58102 m .48889 .583 L .51095 .58081 L 1 g
F
P
p
.002 w
.51095 .58081 m .51103 .58184 L p
.5154 .57986 L 1 g
F P
s
P
p
.002 w
.49793 .59854 m .48504 .58742 L .49762 .58366 L p
1 g
F P
s
P
p
.53128 .57265 m .51103 .58184 L .51831 .5793 L 1 g
F
P
p
.53986 .56956 m .54939 .56362 L .5494 .56361 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53171 .57464 m .51735 .57777 L .54939 .56362 L 1 g
F
P
p
.002 w
.52119 .5812 m .51886 .57911 L p
.53171 .57464 L 1 g
F P
s
P
p
.002 w
.51886 .57911 m .51735 .57777 L p
.53171 .57464 L 1 g
F P
s
P
p
.002 w
.51103 .58184 m .51111 .583 L p
.51831 .5793 L 1 g
F P
s
P
p
.002 w
.51735 .57777 m .51886 .57911 L p
.5154 .57986 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57464 L p
1 g
F P
s
P
p
.51831 .5793 m .51111 .583 L .53171 .57464 L 1 g
F
P
p
.53986 .56956 m .53975 .56967 L .54939 .56362 L 1 g
F
P
p
.56075 .54566 m .5494 .56361 L .54941 .5636 L 1 g
F
P
p
.002 w
.54945 .56356 m .54949 .56354 L .54941 .5636 L p
1 g
F P
s
P
p
.54944 .56357 m .54941 .5636 L .54944 .56357 L 1 g
F
P
p
.56075 .54566 m .54941 .5636 L .54944 .56357 L 1 g
F
P
p
.56075 .54566 m .54944 .56357 L .55487 .55631 L 1 g
F
P
p
.54944 .56357 m .54941 .56363 L .54948 .56353 L 1 g
F
P
p
.54944 .56357 m .54946 .56355 L .55487 .55631 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51424 .5702 m .51486 .56161 L .54947 .56354 L p
1 g
F P
s
P
p
.002 w
.54947 .56354 m .54949 .56354 L .54946 .56355 L p
1 g
F P
s
P
p
.002 w
.54946 .56355 m .51424 .5702 L p
.54947 .56354 L 1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51486 .56161 m .51921 .55293 L .54947 .56354 L p
1 g
F P
s
P
p
.002 w
.54947 .56354 m .54949 .56354 L .54947 .56354 L p
1 g
F P
s
P
p
.002 w
.54947 .56354 m .51486 .56161 L p
.54947 .56354 L 1 g
F P
s
P
p
.54947 .56354 m .54947 .56354 L .54947 .56354 L 1 g
F
P
p
.54947 .56354 m .54947 .56354 L .55487 .55631 L 1 g
F
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.51921 .55293 m .52683 .54513 L .54948 .56353 L p
1 g
F P
s
P
p
.002 w
.54948 .56353 m .54949 .56354 L .54947 .56354 L p
1 g
F P
s
P
p
.002 w
.54947 .56354 m .51921 .55293 L p
.54948 .56353 L 1 g
F P
s
P
p
.54947 .56354 m .54948 .56353 L .55487 .55631 L 1 g
F
P
p
.002 w
.52683 .54513 m .5369 .53911 L .54948 .56353 L p
1 g
F P
s
P
p
.002 w
.54948 .56353 m .54949 .56354 L .54948 .56353 L p
1 g
F P
s
P
p
.002 w
.54948 .56353 m .52683 .54513 L p
.54948 .56353 L 1 g
F P
s
P
p
.54947 .56354 m .54947 .56354 L .54948 .56353 L 1 g
F
P
p
.54947 .56354 m .54948 .56354 L .54948 .56353 L 1 g
F
P
p
.54947 .56354 m .54948 .56353 L .55487 .55631 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5369 .53911 m .54828 .53555 L .54949 .56352 L p
1 g
F P
s
P
p
.002 w
.54949 .56352 m .54949 .56354 L .54948 .56353 L p
1 g
F P
s
P
p
.002 w
.54948 .56353 m .5369 .53911 L p
.54949 .56352 L 1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54828 .53555 m .55968 .53485 L .54951 .5635 L p
1 g
F P
s
P
p
.002 w
.54951 .5635 m .54949 .56354 L .54949 .56352 L p
1 g
F P
s
P
p
.002 w
.54949 .56352 m .54828 .53555 L p
.54951 .5635 L 1 g
F P
s
P
p
.54948 .56354 m .54948 .56353 L .54951 .5635 L 1 g
F
P
p
.54948 .56354 m .54951 .5635 L .55487 .55631 L 1 g
F
P
p
.002 w
.51735 .57777 m .51424 .5702 L .54946 .56355 L p
1 g
F P
s
P
p
.002 w
.54946 .56355 m .54949 .56354 L .54945 .56356 L p
1 g
F P
s
P
p
.002 w
.54945 .56356 m .51735 .57777 L p
.54946 .56355 L 1 g
F P
s
P
p
.002 w
.51735 .57777 m .54945 .56356 L p
.54939 .56362 L 1 g
F P
s
P
p
.002 w
.54941 .5636 m .54939 .56362 L p
.54945 .56356 L 1 g
F P
s
P
p
.002 w
.52875 .58534 m .5238 .58352 L .54941 .5636 L p
1 g
F P
s
P
p
.002 w
.55479 .58532 m .54357 .58748 L .54948 .56356 L p
1 g
F P
s
P
p
.002 w
.54948 .56356 m .54949 .56354 L .54949 .56356 L p
1 g
F P
s
P
p
.002 w
.54949 .56356 m .55479 .58532 L p
.54948 .56356 L 1 g
F P
s
P
p
.002 w
.56534 .58063 m .55479 .58532 L .54949 .56356 L p
1 g
F P
s
P
p
.002 w
.54949 .56356 m .54949 .56354 L .5495 .56355 L p
1 g
F P
s
P
p
.002 w
.5495 .56355 m .56534 .58063 L p
.54949 .56356 L 1 g
F P
s
P
p
.002 w
.54357 .58748 m .53287 .58686 L .54949 .56354 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54941 .56362 L p
1 g
F P
s
P
p
.002 w
.54941 .56362 m .5494 .56362 L p
.54938 .56364 L 1 g
F P
s
P
p
.54938 .56364 m .5322 .57686 L .54941 .56362 L 1 g
F
P
p
.002 w
.5494 .56362 m .5494 .56361 L p
.54938 .56363 L 1 g
F P
s
P
p
.54938 .56363 m .5322 .57686 L .5494 .56362 L 1 g
F
P
p
.53975 .56967 m .5322 .57686 L .5494 .56361 L 1 g
F
P
p
.002 w
.5494 .56361 m .54941 .56363 L p
.54944 .56357 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56162 .5473 L p
1 g
F P
s
P
p
.002 w
.5613 .54816 m .56982 .53708 L p
.55813 .5569 L 1 g
F P
s
P
p
.002 w
.56162 .5473 m .56235 .54868 L p
.5638 .5413 L 1 g
F P
s
P
p
.56654 .52734 m .56162 .5473 L .5638 .5413 L 1 g
F
P
p
.002 w
.56982 .53708 m .57759 .54195 L .55813 .5569 L p
1 g
F P
s
P
p
.002 w
.55813 .5569 m .54949 .56354 L .5613 .54816 L p
1 g
F P
s
P
p
.56654 .52734 m .56235 .54868 L .56335 .54483 L 1 g
F
P
p
.56685 .51928 m .5662 .51006 L .56616 .50946 L 1 g
F
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.5662 .51006 m .56629 .50974 L p
.56807 .53669 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56771 .52904 L p
1 g
F P
s
P
p
.56515 .50826 m .56771 .52904 L .56702 .5204 L 1 g
F
P
p
.56431 .50552 m .56616 .50946 L .5647 .50628 L 1 g
F
P
p
.55661 .4905 m .56612 .50939 L .56431 .50552 L 1 g
F
P
p
.56612 .50939 m .56616 .50946 L .56431 .50552 L 1 g
F
P
p
.002 w
.56629 .50974 m .56824 .50234 L p
.56883 .51527 L 1 g
F P
s
P
p
.55661 .4905 m .5666 .50999 L .56304 .5028 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56824 .50234 m .56296 .50264 L p
.55763 .49187 L 1 g
F P
s
P
p
.55732 .49125 m .56824 .50234 L .55763 .49187 L 1 g
F
P
p
.55406 .48468 m .56639 .50004 L .55732 .49125 L 1 g
F
P
p
.56639 .50004 m .56824 .50234 L .55732 .49125 L 1 g
F
P
p
.002 w
.55732 .49125 m .55661 .4905 L p
.56304 .5028 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55732 .49125 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55732 .49125 L p
1 g
F P
s
P
p
.56304 .5028 m .56713 .51061 L .55732 .49125 L 1 g
F
P
p
.54174 .47608 m .55732 .49125 L .54942 .4836 L 1 g
F
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54246 .47686 m .55763 .49187 L .54229 .47674 L 1 g
F
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.54942 .4836 L 1 g
F P
s
P
p
.55406 .48468 m .55732 .49125 L .54246 .47686 L 1 g
F
P
p
.55732 .49125 m .55763 .49187 L .54246 .47686 L 1 g
F
P
p
.55084 .48067 m .55406 .48468 L .54229 .47674 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54239 .47679 L p
1 g
F P
s
P
p
.54942 .4836 m .55834 .49233 L .54239 .47679 L 1 g
F
P
p
.002 w
.55732 .49125 m .55834 .49233 L p
.54942 .4836 L 1 g
F P
s
P
p
.56296 .50264 m .56616 .50946 L .55968 .53485 L 1 g
F
P
p
.002 w
.56629 .50974 m .5662 .51006 L p
.56616 .50946 L 1 g
F P
s
P
p
.002 w
.5662 .51006 m .55968 .53485 L p
.56616 .50946 L 1 g
F P
s
P
p
.002 w
.56771 .52904 m .56854 .53025 L p
.56702 .5204 L 1 g
F P
s
P
p
.002 w
.55968 .53485 m .5662 .51006 L p
.56751 .52876 L 1 g
F P
s
P
p
.002 w
.56807 .53669 m .5656 .53615 L p
.56751 .52876 L 1 g
F P
s
P
p
.002 w
.5656 .53615 m .55968 .53485 L p
.56751 .52876 L 1 g
F P
s
P
p
.002 w
.56235 .54868 m .56257 .5491 L p
.56335 .54483 L 1 g
F P
s
P
p
.5656 .53615 m .56162 .54729 L .54956 .56343 L 1 g
F
P
p
.56162 .54729 m .5613 .54816 L .54956 .56343 L 1 g
F
P
p
.002 w
.54949 .56354 m .55968 .53485 L .5656 .53615 L p
1 g
F P
s
P
p
.002 w
.57415 .57388 m .56534 .58063 L .54949 .56354 L closepath p
1 g
F P
s
P
p
.002 w
.58029 .56577 m .57415 .57388 L .54949 .56354 L closepath p
1 g
F P
s
P
p
.002 w
.58306 .55713 m .58029 .56577 L .54949 .56354 L closepath p
1 g
F P
s
P
p
.002 w
.58215 .54889 m .58306 .55713 L .54949 .56354 L closepath p
1 g
F P
s
P
p
.002 w
.57759 .54195 m .58215 .54889 L .54949 .56354 L closepath p
1 g
F P
s
P
p
.002 w
.54941 .56363 m .54998 .56518 L p
.55487 .55631 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56162 .54729 L p
1 g
F P
s
P
p
.55487 .55631 m .54998 .56518 L .56162 .54729 L 1 g
F
P
p
.56424 .53996 m .56335 .54483 L .5656 .53615 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56751 .52876 L p
1 g
F P
s
P
p
.56335 .54483 m .56257 .5491 L .56751 .52876 L 1 g
F
P
p
.56685 .51928 m .56702 .5204 L .5662 .51006 L 1 g
F
P
p
.56883 .51527 m .56982 .53708 L .56629 .50974 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56616 .50946 L p
1 g
F P
s
P
p
.56702 .5204 m .56854 .53025 L .56616 .50946 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54554 .5036 m .56296 .50264 L p
.55968 .53485 L 1 g
F P
s
P
p
.002 w
.56616 .50946 m .56616 .50946 L p
.56612 .50939 L 1 g
F P
s
P
p
.002 w
.56616 .50946 m .5666 .50999 L p
.5647 .50628 L 1 g
F P
s
P
p
.002 w
.54554 .5036 m .54229 .47674 L p
.55763 .49187 L 1 g
F P
s
P
p
.002 w
.56296 .50264 m .54554 .5036 L p
.55763 .49187 L 1 g
F P
s
P
p
.002 w
.5666 .50999 m .56713 .51061 L p
.56304 .5028 L 1 g
F P
s
P
p
.002 w
.50781 .47922 m .53183 .47176 L p
.54554 .5036 L 1 g
F P
s
P
p
.002 w
.54229 .47674 m .54554 .5036 L p
.53183 .47176 L 1 g
F P
s
P
p
.52214 .46667 m .54239 .47679 L .53873 .47511 L 1 g
F
P
p
.52214 .46667 m .54269 .47712 L .53481 .47323 L 1 g
F
P
p
.002 w
.53183 .47176 m .50781 .47922 L p
.5224 .4671 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5224 .4671 L p
1 g
F P
s
P
p
.002 w
.5224 .4671 m .52214 .46667 L p
.53481 .47323 L 1 g
F P
s
P
p
.53481 .47323 m .54302 .47747 L .5224 .4671 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52279 .46774 L p
1 g
F P
s
P
p
.002 w
.52279 .46774 m .52282 .46778 L p
.52091 .46742 L 1 g
F P
s
P
p
.5 .4634 m .52279 .46774 L .52091 .46742 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46387 L p
1 g
F P
s
P
p
.002 w
.5 .46387 m .5 .46442 L p
.48618 .46582 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46387 L .48618 .46582 L 1 g
F
P
p
.002 w
.47764 .46703 m .47786 .46667 L p
.48618 .46582 L 1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44322 .49072 m .45766 .47674 L .47836 .49714 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47723 .46771 L p
1 g
F P
s
P
p
.45826 .47608 m .47723 .46771 L .47487 .4688 L 1 g
F
P
p
.46674 .47236 m .45992 .4757 L .45766 .47674 L 1 g
F
P
p
.002 w
.45938 .47507 m .45992 .4757 L p
.45766 .47674 L 1 g
F P
s
P
p
.002 w
.45992 .4757 m .47836 .49714 L p
.45766 .47674 L 1 g
F P
s
P
p
.002 w
.47723 .46771 m .47718 .46778 L p
.47487 .4688 L 1 g
F P
s
P
p
.45436 .46924 m .49764 .45726 L .47764 .46703 L 1 g
F
P
p
.45767 .46986 m .47764 .46703 L .46794 .47177 L 1 g
F
P
p
.45436 .46924 m .47764 .46703 L .45767 .46986 L 1 g
F
P
p
.002 w
.49764 .45726 m .50066 .46378 L p
.5 .46387 L 1 g
F P
s
P
p
.47764 .46703 m .4882 .46187 L .5 .46387 L 1 g
F
P
p
.4882 .46187 m .49764 .45726 L .5 .46387 L 1 g
F
P
p
.49238 .4459 m .53912 .4695 L .5224 .4671 L 1 g
F
P
p
.50999 .46532 m .50076 .464 L .5 .46387 L 1 g
F
P
p
.002 w
.50076 .464 m .49621 .45417 L p
.5224 .4671 L 1 g
F P
s
P
p
.002 w
.49621 .45417 m .49238 .4459 L p
.5224 .4671 L 1 g
F P
s
P
p
.002 w
.53183 .47176 m .54133 .46881 L .54229 .47674 L p
1 g
F P
s
P
p
.53873 .47511 m .54229 .47674 L .54269 .47712 L 1 g
F
P
p
.002 w
.54239 .47679 m .54239 .47679 L p
.54229 .47674 L 1 g
F P
s
P
p
.002 w
.54239 .47679 m .54269 .47712 L p
.54229 .47674 L 1 g
F P
s
P
p
.002 w
.54229 .47674 m .54133 .46881 L p
.55084 .48067 L 1 g
F P
s
P
p
.002 w
.53912 .4695 m .53183 .47176 L p
.5224 .4671 L 1 g
F P
s
P
p
.002 w
.54269 .47712 m .54302 .47747 L p
.53481 .47323 L 1 g
F P
s
P
p
.50999 .46532 m .52091 .46742 L .50076 .464 L 1 g
F
P
p
.002 w
.54133 .46881 m .53912 .4695 L p
.49238 .4459 L 1 g
F P
s
P
p
.002 w
.50066 .46378 m .50076 .464 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.50076 .464 m .50781 .47922 L p
.5 .46387 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46387 L p
1 g
F P
s
P
p
.52091 .46742 m .52282 .46778 L .5 .46387 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46703 L p
1 g
F P
s
P
p
.48618 .46582 m .5 .46442 L .47764 .46703 L 1 g
F
P
p
.002 w
.50781 .47922 m .47836 .49714 L .45992 .4757 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45755 .47685 L p
1 g
F P
s
P
p
.002 w
.45755 .47685 m .45766 .47674 L p
.45971 .4758 L 1 g
F P
s
P
p
.45971 .4758 m .47718 .46778 L .45755 .47685 L 1 g
F
P
p
.46674 .47236 m .47487 .4688 L .45992 .4757 L 1 g
F
P
p
.002 w
.45992 .4757 m .45436 .46924 L p
.46794 .47177 L 1 g
F P
s
P
p
.47487 .4688 m .47718 .46778 L .45766 .47674 L 1 g
F
P
p
.002 w
.45436 .46924 m .45938 .47507 L p
.45766 .47674 L 1 g
F P
s
P
p
.44322 .49072 m .44821 .4811 L .45766 .47674 L 1 g
F
P
p
.44821 .4811 m .45436 .46924 L .45766 .47674 L 1 g
F
P
p
.002 w
.45766 .47674 m .45698 .47747 L p
.44881 .48531 L 1 g
F P
s
P
p
.002 w
.45261 .47114 m .45436 .46924 L p
.43899 .49888 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44279 .49114 L p
1 g
F P
s
P
p
.44881 .48531 m .45698 .47747 L .44279 .49114 L 1 g
F
P
p
.41167 .53259 m .43559 .5058 L .42502 .52893 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43373 .50959 L p
1 g
F P
s
P
p
.002 w
.43373 .50959 m .43401 .50925 L p
.43538 .50623 L 1 g
F P
s
P
p
.43538 .50623 m .44166 .49233 L .43373 .50959 L 1 g
F
P
p
.438 .5009 m .44046 .49516 L .43559 .5058 L 1 g
F
P
p
.438 .5009 m .43559 .5058 L .43401 .50925 L 1 g
F
P
p
.002 w
.47836 .49714 m .4565 .52031 L .43559 .5058 L p
1 g
F P
s
P
p
.43899 .49888 m .47836 .49714 L .43559 .5058 L 1 g
F
P
p
.002 w
.43559 .5058 m .4565 .52031 L p
.42502 .52893 L 1 g
F P
s
P
p
.44046 .49516 m .44166 .49233 L .43401 .50925 L 1 g
F
P
p
.002 w
.43401 .50925 m .43287 .51061 L p
.43325 .52133 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43281 .52829 L p
1 g
F P
s
P
p
.43325 .52133 m .43287 .51061 L .43281 .52829 L 1 g
F
P
p
.43555 .53833 m .43394 .53515 L .43672 .54266 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.4565 .52031 m .44466 .54585 L .43672 .54266 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43842 .54723 L p
1 g
F P
s
P
p
.43394 .53515 m .43146 .53025 L .43842 .54723 L 1 g
F
P
p
.002 w
.43842 .54723 m .43807 .54789 L p
.44124 .55107 L 1 g
F P
s
P
p
.002 w
.41123 .5647 m .41167 .53259 L .43436 .54171 L p
1 g
F P
s
P
p
.45146 .56129 m .43807 .54789 L .44378 .55462 L 1 g
F
P
p
.46872 .57265 m .45085 .56294 L .4597 .56905 L 1 g
F
P
p
.45085 .56294 m .44466 .54585 L .45519 .56594 L 1 g
F
P
p
.002 w
.44425 .55839 m .44435 .55529 L p
.45085 .56294 L 1 g
F P
s
P
p
.002 w
.44435 .55529 m .44466 .54585 L p
.45085 .56294 L 1 g
F P
s
P
p
.002 w
.43807 .54789 m .43743 .5491 L p
.44378 .55462 L 1 g
F P
s
P
p
.002 w
.44466 .54585 m .44435 .55529 L p
.43953 .54874 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45085 .56294 L p
1 g
F P
s
P
p
.44378 .55462 m .43743 .5491 L .45085 .56294 L 1 g
F
P
p
.002 w
.45085 .56294 m .45002 .56518 L p
.4597 .56905 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44466 .54585 m .47948 .55565 L p
.45519 .56594 L 1 g
F P
s
P
p
.002 w
.47948 .55565 m .47859 .57262 L .46372 .57182 L p
1 g
F P
s
P
p
.45519 .56594 m .47948 .55565 L .46372 .57182 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46822 .57492 L p
1 g
F P
s
P
p
.002 w
.46822 .57492 m .46831 .57454 L p
.46582 .57326 L 1 g
F P
s
P
p
.46582 .57326 m .45002 .56518 L .46822 .57492 L 1 g
F
P
p
.4577 .56825 m .45002 .56518 L .46831 .57454 L 1 g
F
P
p
.4738 .57641 m .46831 .57454 L .47859 .57262 L 1 g
F
P
p
.002 w
.46372 .57182 m .47859 .57262 L p
.46831 .57454 L 1 g
F P
s
P
p
.002 w
.46831 .57454 m .4678 .57686 L p
.47746 .57766 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58158 L p
1 g
F P
s
P
p
.002 w
.47859 .57262 m .48137 .57898 L p
.4738 .57641 L 1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.39422 .38278 m .35444 .42819 L .33921 .40455 L p
1 g
F P
s
P
p
.002 w
.33921 .40455 m .38054 .35669 L .39422 .38278 L p
1 g
F P
s
P
p
.002 w
.58029 .56577 m .58306 .55713 L .61364 .54705 L p
1 g
F P
s
P
p
.002 w
.61215 .53076 m .61364 .54705 L .58306 .55713 L p
1 g
F P
s
P
p
.002 w
.61364 .54705 m .61215 .53076 L .63845 .50984 L p
1 g
F P
s
P
p
.002 w
.43837 .31995 m .38054 .35669 L .3708 .33353 L p
1 g
F P
s
P
p
.002 w
.3708 .33353 m .42926 .29616 L .43837 .31995 L p
1 g
F P
s
P
p
.002 w
.62611 .48922 m .63845 .50984 L .61215 .53076 L p
1 g
F P
s
P
p
.002 w
.63845 .50984 m .62611 .48922 L .64479 .46002 L p
1 g
F P
s
P
p
.002 w
.39875 .47653 m .3817 .51639 L .35577 .49789 L p
1 g
F P
s
P
p
.002 w
.35577 .49789 m .37448 .45248 L .39875 .47653 L p
1 g
F P
s
P
p
.002 w
.62584 .4063 m .65888 .43034 L .64479 .46002 L p
1 g
F P
s
P
p
.002 w
.65888 .43034 m .62584 .4063 L .63092 .37345 L p
1 g
F P
s
P
p
.002 w
.57702 .32685 m .63199 .34295 L .63092 .37345 L p
1 g
F P
s
P
p
.002 w
.63199 .34295 m .57702 .32685 L .57163 .29841 L p
1 g
F P
s
P
p
.002 w
.57163 .29841 m .50512 .29964 L .49685 .27565 L p
1 g
F P
s
P
p
.002 w
.42926 .29616 m .49685 .27565 L .50512 .29964 L p
1 g
F P
s
P
p
.002 w
.50512 .29964 m .43837 .31995 L .42926 .29616 L p
1 g
F P
s
P
p
.002 w
.58306 .55713 m .58215 .54889 L .61215 .53076 L p
1 g
F P
s
P
p
.002 w
.60344 .51687 m .61215 .53076 L .58215 .54889 L p
1 g
F P
s
P
p
.002 w
.61215 .53076 m .60344 .51687 L .62611 .48922 L p
1 g
F P
s
P
p
.002 w
.50512 .29964 m .57163 .29841 L .57702 .32685 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61683 .44035 m .64479 .46002 L .62611 .48922 L p
1 g
F P
s
P
p
.002 w
.64479 .46002 m .61683 .44035 L .62584 .4063 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.42643 .49944 m .41167 .53259 L .3817 .51639 L p
1 g
F P
s
P
p
.002 w
.3817 .51639 m .39875 .47653 L .42643 .49944 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41149 .41093 m .37448 .45248 L .35444 .42819 L p
1 g
F P
s
P
p
.002 w
.35444 .42819 m .39422 .38278 L .41149 .41093 L p
1 g
F P
s
P
p
.002 w
.58215 .54889 m .57759 .54195 L .60344 .51687 L p
1 g
F P
s
P
p
.002 w
.51486 .56161 m .51424 .5702 L .47859 .57262 L p
1 g
F P
s
P
p
.002 w
.47859 .57262 m .47948 .55565 L .51486 .56161 L p
1 g
F P
s
P
p
.002 w
.58016 .35913 m .63092 .37345 L .62584 .4063 L p
1 g
F P
s
P
p
.002 w
.63092 .37345 m .58016 .35913 L .57702 .32685 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.44963 .34784 m .39422 .38278 L .38054 .35669 L p
1 g
F P
s
P
p
.002 w
.38054 .35669 m .43837 .31995 L .44963 .34784 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60416 .47433 m .62611 .48922 L .60344 .51687 L p
1 g
F P
s
P
p
.002 w
.62611 .48922 m .60416 .47433 L .61683 .44035 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.57759 .54195 m .56982 .53708 L .58829 .50698 L p
1 g
F P
s
P
p
.002 w
.58829 .50698 m .60344 .51687 L .57759 .54195 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.60344 .51687 m .58829 .50698 L .60416 .47433 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51921 .55293 m .51486 .56161 L .47948 .55565 L p
1 g
F P
s
P
p
.002 w
.57702 .32685 m .51346 .32835 L .50512 .29964 L p
1 g
F P
s
P
p
.002 w
.43837 .31995 m .50512 .29964 L .51346 .32835 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51346 .32835 m .57702 .32685 L .58016 .35913 L p
1 g
F P
s
P
p
.002 w
.58086 .39416 m .62584 .4063 L .61683 .44035 L p
1 g
F P
s
P
p
.002 w
.62584 .4063 m .58086 .39416 L .58016 .35913 L p
1 g
F P
s
P
p
.002 w
.48782 .53836 m .47948 .55565 L .44466 .54585 L p
1 g
F P
s
P
p
.002 w
.44466 .54585 m .4565 .52031 L .48782 .53836 L p
1 g
F P
s
P
p
.002 w
.43179 .44013 m .39875 .47653 L .37448 .45248 L p
1 g
F P
s
P
p
.002 w
.37448 .45248 m .41149 .41093 L .43179 .44013 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.56824 .50234 m .58829 .50698 L .56982 .53708 L p
1 g
F P
s
P
p
.002 w
.47948 .55565 m .48782 .53836 L .51921 .55293 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51346 .32835 m .44963 .34784 L .43837 .31995 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.52683 .54513 m .51921 .55293 L .48782 .53836 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55968 .53485 m .54828 .53555 L .54554 .5036 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.5369 .53911 m .52683 .54513 L .50283 .52275 L p
1 g
F P
s
P
p
.002 w
.48782 .53836 m .50283 .52275 L .52683 .54513 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.57905 .43064 m .61683 .44035 L .60416 .47433 L p
1 g
F P
s
P
p
.002 w
.61683 .44035 m .57905 .43064 L .58086 .39416 L p
1 g
F P
s
P
p
.002 w
.58829 .50698 m .56824 .50234 L .57479 .46717 L p
1 g
F P
s
P
p
.002 w
.57479 .46717 m .60416 .47433 L .58829 .50698 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46271 .3789 m .41149 .41093 L .39422 .38278 L p
1 g
F P
s
P
p
.002 w
.39422 .38278 m .44963 .34784 L .46271 .3789 L p
1 g
F P
s
P
p
.002 w
.54828 .53555 m .5369 .53911 L .52284 .51068 L p
1 g
F P
s
P
p
.002 w
.52284 .51068 m .54554 .5036 L .54828 .53555 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.50283 .52275 m .52284 .51068 L .5369 .53911 L p
1 g
F P
s
P
p
.002 w
.60416 .47433 m .57479 .46717 L .57905 .43064 L p
1 g
F P
s
P
p
.002 w
.45436 .46924 m .42643 .49944 L .39875 .47653 L p
1 g
F P
s
P
p
.002 w
.39875 .47653 m .43179 .44013 L .45436 .46924 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.50283 .52275 m .48782 .53836 L .4565 .52031 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.52156 .36086 m .58016 .35913 L .58086 .39416 L p
1 g
F P
s
P
p
.002 w
.58016 .35913 m .52156 .36086 L .51346 .32835 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.44963 .34784 m .51346 .32835 L .52156 .36086 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.4565 .52031 m .47836 .49714 L .50283 .52275 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54133 .46881 m .57479 .46717 L .56824 .50234 L p
1 g
F P
s
P
p
.002 w
.52156 .36086 m .46271 .3789 L .44963 .34784 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.52284 .51068 m .50283 .52275 L .47836 .49714 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47714 .41201 m .43179 .44013 L .41149 .41093 L p
1 g
F P
s
P
p
.002 w
.41149 .41093 m .46271 .3789 L .47714 .41201 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.5291 .39601 m .58086 .39416 L .57905 .43064 L p
1 g
F P
s
P
p
.002 w
.58086 .39416 m .5291 .39601 L .52156 .36086 L p
1 g
F P
s
P
p
.002 w
.54554 .5036 m .52284 .51068 L .50781 .47922 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.47836 .49714 m .50781 .47922 L .52284 .51068 L p
1 g
F P
s
P
p
.002 w
.57479 .46717 m .54133 .46881 L .53578 .43248 L p
1 g
F P
s
P
p
.002 w
.53578 .43248 m .57905 .43064 L .57479 .46717 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57905 .43064 m .53578 .43248 L .5291 .39601 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.46271 .3789 m .52156 .36086 L .5291 .39601 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49238 .4459 m .45436 .46924 L .43179 .44013 L p
1 g
F P
s
P
p
.002 w
.43179 .44013 m .47714 .41201 L .49238 .4459 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.5291 .39601 m .47714 .41201 L .46271 .3789 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49238 .4459 m .53578 .43248 L .54133 .46881 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.47714 .41201 m .5291 .39601 L .53578 .43248 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.56653 .60936 m
.56977 .61807 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.53578 .43248 m .49238 .4459 L .47714 .41201 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .6947 .64797 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .57858 .64174 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.515504)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.515504)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45199 .46825 m .49952 .46904 L .49662 .4408 L p
1 g
F P
s
P
p
.002 w
.49662 .4408 m .45497 .43999 L .45199 .46825 L p
1 g
F P
s
P
p
.002 w
.53744 .43177 m .49662 .4408 L .49952 .46904 L p
1 g
F P
s
P
p
.002 w
.45497 .43999 m .49662 .4408 L .4938 .41237 L p
1 g
F P
s
P
p
.002 w
.49662 .4408 m .53744 .43177 L .52788 .40477 L p
1 g
F P
s
P
p
.002 w
.52788 .40477 m .4938 .41237 L .49662 .4408 L p
1 g
F P
s
P
p
.002 w
.4938 .41237 m .45902 .41161 L .45497 .43999 L p
1 g
F P
s
P
p
.002 w
.45902 .41161 m .4938 .41237 L .49112 .38427 L p
1 g
F P
s
P
p
.002 w
.4938 .41237 m .52788 .40477 L .51761 .37831 L p
1 g
F P
s
P
p
.002 w
.51761 .37831 m .49112 .38427 L .4938 .41237 L p
1 g
F P
s
P
p
.002 w
.49952 .46904 m .54613 .45881 L .53744 .43177 L p
1 g
F P
s
P
p
.002 w
.57376 .41364 m .53744 .43177 L .54613 .45881 L p
1 g
F P
s
P
p
.002 w
.53744 .43177 m .57376 .41364 L .55808 .38946 L p
1 g
F P
s
P
p
.002 w
.55808 .38946 m .52788 .40477 L .53744 .43177 L p
1 g
F P
s
P
p
.002 w
.52788 .40477 m .55808 .38946 L .54099 .36628 L p
1 g
F P
s
P
p
.002 w
.54099 .36628 m .51761 .37831 L .52788 .40477 L p
1 g
F P
s
P
p
.002 w
.45015 .49585 m .50246 .49659 L .49952 .46904 L p
1 g
F P
s
P
p
.002 w
.49952 .46904 m .45199 .46825 L .45015 .49585 L p
1 g
F P
s
P
p
.002 w
.54613 .45881 m .49952 .46904 L .50246 .49659 L p
1 g
F P
s
P
p
.002 w
.41626 .42931 m .45497 .43999 L .45902 .41161 L p
1 g
F P
s
P
p
.002 w
.45902 .41161 m .42681 .40246 L .41626 .42931 L p
1 g
F P
s
P
p
.002 w
.42681 .40246 m .45902 .41161 L .46409 .3836 L p
1 g
F P
s
P
p
.002 w
.49112 .38427 m .46409 .3836 L .45902 .41161 L p
1 g
F P
s
P
p
.002 w
.40771 .45636 m .45199 .46825 L .45497 .43999 L p
1 g
F P
s
P
p
.002 w
.45497 .43999 m .41626 .42931 L .40771 .45636 L p
1 g
F P
s
P
p
.002 w
.46409 .3836 m .49112 .38427 L .48863 .35699 L p
1 g
F P
s
P
p
.002 w
.49112 .38427 m .51761 .37831 L .50681 .35288 L p
1 g
F P
s
P
p
.002 w
.50681 .35288 m .48863 .35699 L .49112 .38427 L p
1 g
F P
s
P
p
.002 w
.50246 .49659 m .55376 .48542 L .54613 .45881 L p
1 g
F P
s
P
p
.002 w
.58771 .43837 m .54613 .45881 L .55376 .48542 L p
1 g
F P
s
P
p
.002 w
.54613 .45881 m .58771 .43837 L .57376 .41364 L p
1 g
F P
s
P
p
.002 w
.51761 .37831 m .54099 .36628 L .52279 .34453 L p
1 g
F P
s
P
p
.002 w
.52279 .34453 m .50681 .35288 L .51761 .37831 L p
1 g
F P
s
P
p
.002 w
.46409 .3836 m .43913 .37632 L .42681 .40246 L p
1 g
F P
s
P
p
.002 w
.43913 .37632 m .46409 .3836 L .47008 .35649 L p
1 g
F P
s
P
p
.002 w
.48863 .35699 m .47008 .35649 L .46409 .3836 L p
1 g
F P
s
P
p
.002 w
.40133 .48309 m .45015 .49585 L .45199 .46825 L p
1 g
F P
s
P
p
.002 w
.45199 .46825 m .40771 .45636 L .40133 .48309 L p
1 g
F P
s
P
p
.002 w
.44952 .52227 m .50538 .52292 L .50246 .49659 L p
1 g
F P
s
P
p
.002 w
.50246 .49659 m .45015 .49585 L .44952 .52227 L p
1 g
F P
s
P
p
.002 w
.55376 .48542 m .50246 .49659 L .50538 .52292 L p
1 g
F P
s
P
p
.002 w
.58144 .36773 m .55808 .38946 L .57376 .41364 L p
1 g
F P
s
P
p
.002 w
.55808 .38946 m .58144 .36773 L .55892 .34925 L p
1 g
F P
s
P
p
.002 w
.55892 .34925 m .54099 .36628 L .55808 .38946 L p
1 g
F P
s
P
p
.002 w
.47008 .35649 m .48863 .35699 L .48638 .33108 L p
1 g
F P
s
P
p
.002 w
.48863 .35699 m .50681 .35288 L .49568 .32896 L p
1 g
F P
s
P
p
.002 w
.49568 .32896 m .48638 .33108 L .48863 .35699 L p
1 g
F P
s
P
p
.002 w
.60206 .38786 m .57376 .41364 L .58771 .43837 L p
1 g
F P
s
P
p
.002 w
.57376 .41364 m .60206 .38786 L .58144 .36773 L p
1 g
F P
s
P
p
.002 w
.54099 .36628 m .55892 .34925 L .53493 .33276 L p
1 g
F P
s
P
p
.002 w
.53493 .33276 m .52279 .34453 L .54099 .36628 L p
1 g
F P
s
P
p
.002 w
.50538 .52292 m .56019 .51108 L .55376 .48542 L p
1 g
F P
s
P
p
.002 w
.59966 .46319 m .55376 .48542 L .56019 .51108 L p
1 g
F P
s
P
p
.002 w
.55376 .48542 m .59966 .46319 L .58771 .43837 L p
1 g
F P
s
P
p
.002 w
.50681 .35288 m .52279 .34453 L .50382 .32465 L p
1 g
F P
s
P
p
.002 w
.50382 .32465 m .49568 .32896 L .50681 .35288 L p
1 g
F P
s
P
p
.002 w
.38422 .40945 m .41626 .42931 L .42681 .40246 L p
1 g
F P
s
P
p
.002 w
.42681 .40246 m .40031 .38561 L .38422 .40945 L p
1 g
F P
s
P
p
.002 w
.40031 .38561 m .42681 .40246 L .43913 .37632 L p
1 g
F P
s
P
p
.002 w
.47008 .35649 m .45301 .35138 L .43913 .37632 L p
1 g
F P
s
P
p
.002 w
.45301 .35138 m .47008 .35649 L .47689 .3308 L p
1 g
F P
s
P
p
.002 w
.48638 .33108 m .47689 .3308 L .47008 .35649 L p
1 g
F P
s
P
p
.002 w
.43913 .37632 m .41875 .36303 L .40031 .38561 L p
1 g
F P
s
P
p
.002 w
.41875 .36303 m .43913 .37632 L .45301 .35138 L p
1 g
F P
s
P
p
.002 w
.39731 .50899 m .44952 .52227 L .45015 .49585 L p
1 g
F P
s
P
p
.002 w
.45015 .49585 m .40133 .48309 L .39731 .50899 L p
1 g
F P
s
P
p
.002 w
.37084 .43408 m .40771 .45636 L .41626 .42931 L p
1 g
F P
s
P
p
.002 w
.41626 .42931 m .38422 .40945 L .37084 .43408 L p
1 g
F P
s
P
p
.002 w
.62035 .40925 m .58771 .43837 L .59966 .46319 L p
1 g
F P
s
P
p
.002 w
.58771 .43837 m .62035 .40925 L .60206 .38786 L p
1 g
F P
s
P
p
.002 w
.52279 .34453 m .53493 .33276 L .50993 .31859 L p
1 g
F P
s
P
p
.002 w
.50993 .31859 m .50382 .32465 L .52279 .34453 L p
1 g
F P
s
P
p
.002 w
.45301 .35138 m .43919 .34214 L .41875 .36303 L p
1 g
F P
s
P
p
.002 w
.43919 .34214 m .45301 .35138 L .4682 .32813 L p
1 g
F P
s
P
p
.002 w
.47689 .3308 m .4682 .32813 L .45301 .35138 L p
1 g
F P
s
P
p
.002 w
.45013 .54696 m .50823 .5475 L .50538 .52292 L p
1 g
F P
s
P
p
.002 w
.50538 .52292 m .44952 .52227 L .45013 .54696 L p
1 g
F P
s
P
p
.002 w
.56019 .51108 m .50538 .52292 L .50823 .5475 L p
1 g
F P
s
P
p
.002 w
.36051 .45902 m .40133 .48309 L .40771 .45636 L p
1 g
F P
s
P
p
.002 w
.40771 .45636 m .37084 .43408 L .36051 .45902 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .47689 .3308 L .48638 .33108 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .48638 .33108 L .49568 .32896 L closepath p
1 g
F P
s
P
p
.002 w
.56942 .32881 m .55892 .34925 L .58144 .36773 L p
1 g
F P
s
P
p
.002 w
.55892 .34925 m .56942 .32881 L .54188 .31871 L p
1 g
F P
s
P
p
.002 w
.54188 .31871 m .53493 .33276 L .55892 .34925 L p
1 g
F P
s
P
p
.002 w
.50823 .5475 m .56526 .53527 L .56019 .51108 L p
1 g
F P
s
P
p
.002 w
.60933 .48761 m .56019 .51108 L .56526 .53527 L p
1 g
F P
s
P
p
.002 w
.56019 .51108 m .60933 .48761 L .59966 .46319 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .49568 .32896 L .50382 .32465 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .4682 .32813 L .47689 .3308 L closepath p
1 g
F P
s
P
p
.002 w
.5954 .34152 m .58144 .36773 L .60206 .38786 L p
1 g
F P
s
P
p
.002 w
.58144 .36773 m .5954 .34152 L .56942 .32881 L p
1 g
F P
s
P
p
.002 w
.53493 .33276 m .54188 .31871 L .51336 .31141 L p
1 g
F P
s
P
p
.002 w
.51336 .31141 m .50993 .31859 L .53493 .33276 L p
1 g
F P
s
P
p
.002 w
.3958 .53349 m .45013 .54696 L .44952 .52227 L p
1 g
F P
s
P
p
.002 w
.44952 .52227 m .39731 .50899 L .3958 .53349 L p
1 g
F P
s
P
p
.002 w
.6359 .43151 m .59966 .46319 L .60933 .48761 L p
1 g
F P
s
P
p
.002 w
.59966 .46319 m .6359 .43151 L .62035 .40925 L p
1 g
F P
s
P
p
.002 w
.38238 .36245 m .40031 .38561 L .41875 .36303 L p
1 g
F P
s
P
p
.002 w
.41875 .36303 m .40517 .34491 L .38238 .36245 L p
1 g
F P
s
P
p
.002 w
.40517 .34491 m .41875 .36303 L .43919 .34214 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .50382 .32465 L .50993 .31859 L closepath p
1 g
F P
s
P
p
.002 w
.4682 .32813 m .46122 .32335 L .43919 .34214 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .46122 .32335 L .4682 .32813 L closepath p
1 g
F P
s
P
p
.002 w
.43919 .34214 m .43012 .32964 L .40517 .34491 L p
1 g
F P
s
P
p
.002 w
.43012 .32964 m .43919 .34214 L .46122 .32335 L p
1 g
F P
s
P
p
.002 w
.36228 .38195 m .38422 .40945 L .40031 .38561 L p
1 g
F P
s
P
p
.002 w
.40031 .38561 m .38238 .36245 L .36228 .38195 L p
1 g
F P
s
P
p
.002 w
.61928 .35662 m .60206 .38786 L .62035 .40925 L p
1 g
F P
s
P
p
.002 w
.60206 .38786 m .61928 .35662 L .5954 .34152 L p
1 g
F P
s
P
p
.002 w
.35352 .48375 m .39731 .50899 L .40133 .48309 L p
1 g
F P
s
P
p
.002 w
.40133 .48309 m .36051 .45902 L .35352 .48375 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .50993 .31859 L .51336 .31141 L closepath p
1 g
F P
s
P
p
.002 w
.46122 .32335 m .45672 .31694 L .43012 .32964 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .45672 .31694 L .46122 .32335 L closepath p
1 g
F P
s
P
p
.002 w
.45202 .56936 m .51095 .56978 L .50823 .5475 L p
1 g
F P
s
P
p
.002 w
.50823 .5475 m .45013 .54696 L .45202 .56936 L p
1 g
F P
s
P
p
.002 w
.56526 .53527 m .50823 .5475 L .51095 .56978 L p
1 g
F P
s
P
p
.002 w
.34534 .40303 m .37084 .43408 L .38422 .40945 L p
1 g
F P
s
P
p
.002 w
.38422 .40945 m .36228 .38195 L .34534 .40303 L p
1 g
F P
s
P
p
.002 w
.54281 .30383 m .54188 .31871 L .56942 .32881 L p
1 g
F P
s
P
p
.002 w
.54188 .31871 m .54281 .30383 L .5137 .30387 L p
1 g
F P
s
P
p
.002 w
.5137 .30387 m .51336 .31141 L .54188 .31871 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .51336 .31141 L .5137 .30387 L closepath p
1 g
F P
s
P
p
.002 w
.42688 .31514 m .43012 .32964 L .45672 .31694 L p
1 g
F P
s
P
p
.002 w
.45672 .31694 m .4552 .30957 L .42688 .31514 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .4552 .30957 L .45672 .31694 L closepath p
1 g
F P
s
P
p
.002 w
.64051 .37383 m .62035 .40925 L .6359 .43151 L p
1 g
F P
s
P
p
.002 w
.62035 .40925 m .64051 .37383 L .61928 .35662 L p
1 g
F P
s
P
p
.002 w
.40005 .32369 m .40517 .34491 L .43012 .32964 L p
1 g
F P
s
P
p
.002 w
.43012 .32964 m .42688 .31514 L .40005 .32369 L p
1 g
F P
s
P
p
.002 w
.57115 .30699 m .56942 .32881 L .5954 .34152 L p
1 g
F P
s
P
p
.002 w
.56942 .32881 m .57115 .30699 L .54281 .30383 L p
1 g
F P
s
P
p
.002 w
.56526 .53527 m .61646 .51115 L .60933 .48761 L p
1 g
F P
s
P
p
.002 w
.64831 .45418 m .60933 .48761 L .61646 .51115 L p
1 g
F P
s
P
p
.002 w
.60933 .48761 m .64831 .45418 L .6359 .43151 L p
1 g
F P
s
P
p
.002 w
.51095 .56978 m .56881 .55745 L .56526 .53527 L p
1 g
F P
s
P
p
.002 w
.61646 .51115 m .56526 .53527 L .56881 .55745 L p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .5137 .30387 L .51087 .29677 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .51087 .29677 L .50515 .2909 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .50515 .2909 L .49714 .28694 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .49714 .28694 L .48771 .28534 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .48771 .28534 L .47793 .28629 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .47793 .28629 L .46889 .28968 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .46889 .28968 L .46161 .29514 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .46161 .29514 L .45688 .30202 L closepath p
1 g
F P
s
P
p
.002 w
.48442 .30706 m .45688 .30202 L .4552 .30957 L closepath p
1 g
F P
s
P
p
.002 w
.39692 .55601 m .45202 .56936 L .45013 .54696 L p
1 g
F P
s
P
p
.002 w
.45013 .54696 m .3958 .53349 L .39692 .55601 L p
1 g
F P
s
P
p
.002 w
.51087 .29677 m .5137 .30387 L .54281 .30383 L p
1 g
F P
s
P
p
.002 w
.37532 .33512 m .38238 .36245 L .40517 .34491 L p
1 g
F P
s
P
p
.002 w
.40517 .34491 m .40005 .32369 L .37532 .33512 L p
1 g
F P
s
P
p
.002 w
.42998 .30016 m .42688 .31514 L .4552 .30957 L p
1 g
F P
s
P
p
.002 w
.4552 .30957 m .45688 .30202 L .42998 .30016 L p
1 g
F P
s
P
p
.002 w
.33204 .42527 m .36051 .45902 L .37084 .43408 L p
1 g
F P
s
P
p
.002 w
.37084 .43408 m .34534 .40303 L .33204 .42527 L p
1 g
F P
s
P
p
.002 w
.35014 .50772 m .3958 .53349 L .39731 .50899 L p
1 g
F P
s
P
p
.002 w
.39731 .50899 m .35352 .48375 L .35014 .50772 L p
1 g
F P
s
P
p
.002 w
.5981 .31333 m .5954 .34152 L .61928 .35662 L p
1 g
F P
s
P
p
.002 w
.5954 .34152 m .5981 .31333 L .57115 .30699 L p
1 g
F P
s
P
p
.002 w
.53745 .2897 m .54281 .30383 L .57115 .30699 L p
1 g
F P
s
P
p
.002 w
.54281 .30383 m .53745 .2897 L .51087 .29677 L p
1 g
F P
s
P
p
.002 w
.50515 .2909 m .51087 .29677 L .53745 .2897 L p
1 g
F P
s
P
p
.002 w
.43922 .28638 m .42998 .30016 L .45688 .30202 L p
1 g
F P
s
P
p
.002 w
.45688 .30202 m .46161 .29514 L .43922 .28638 L p
1 g
F P
s
P
p
.002 w
.35331 .34925 m .36228 .38195 L .38238 .36245 L p
1 g
F P
s
P
p
.002 w
.38238 .36245 m .37532 .33512 L .35331 .34925 L p
1 g
F P
s
P
p
.002 w
.65856 .39285 m .6359 .43151 L .64831 .45418 L p
1 g
F P
s
P
p
.002 w
.6359 .43151 m .65856 .39285 L .64051 .37383 L p
1 g
F P
s
P
p
.002 w
.40429 .3016 m .40005 .32369 L .42688 .31514 L p
1 g
F P
s
P
p
.002 w
.42688 .31514 m .42998 .30016 L .40429 .3016 L p
1 g
F P
s
P
p
.002 w
.45521 .58889 m .51348 .5892 L .51095 .56978 L p
1 g
F P
s
P
p
.002 w
.51095 .56978 m .45202 .56936 L .45521 .58889 L p
1 g
F P
s
P
p
.002 w
.56881 .55745 m .51095 .56978 L .51348 .5892 L p
1 g
F P
s
P
p
.002 w
.53745 .2897 m .52623 .27794 L .50515 .2909 L p
1 g
F P
s
P
p
.002 w
.49714 .28694 m .50515 .2909 L .52623 .27794 L p
1 g
F P
s
P
p
.002 w
.62304 .32282 m .61928 .35662 L .64051 .37383 L p
1 g
F P
s
P
p
.002 w
.61928 .35662 m .62304 .32282 L .5981 .31333 L p
1 g
F P
s
P
p
.002 w
.4537 .2754 m .43922 .28638 L .46161 .29514 L p
1 g
F P
s
P
p
.002 w
.46161 .29514 m .46889 .28968 L .4537 .2754 L p
1 g
F P
s
P
p
.002 w
.56881 .55745 m .62081 .53326 L .61646 .51115 L p
1 g
F P
s
P
p
.002 w
.6572 .4768 m .61646 .51115 L .62081 .53326 L p
1 g
F P
s
P
p
.002 w
.61646 .51115 m .6572 .4768 L .64831 .45418 L p
1 g
F P
s
P
p
.002 w
.3228 .44819 m .35352 .48375 L .36051 .45902 L p
1 g
F P
s
P
p
.002 w
.36051 .45902 m .33204 .42527 L .3228 .44819 L p
1 g
F P
s
P
p
.002 w
.56357 .28611 m .57115 .30699 L .5981 .31333 L p
1 g
F P
s
P
p
.002 w
.57115 .30699 m .56357 .28611 L .53745 .2897 L p
1 g
F P
s
P
p
.002 w
.52623 .27794 m .5103 .26992 L .49714 .28694 L p
1 g
F P
s
P
p
.002 w
.48771 .28534 m .49714 .28694 L .5103 .26992 L p
1 g
F P
s
P
p
.002 w
.4718 .26855 m .4537 .2754 L .46889 .28968 L p
1 g
F P
s
P
p
.002 w
.46889 .28968 m .47793 .28629 L .4718 .26855 L p
1 g
F P
s
P
p
.002 w
.51348 .5892 m .57071 .57707 L .56881 .55745 L p
1 g
F P
s
P
p
.002 w
.62081 .53326 m .56881 .55745 L .57071 .57707 L p
1 g
F P
s
P
p
.002 w
.5103 .26992 m .49143 .26665 L .48771 .28534 L p
1 g
F P
s
P
p
.002 w
.47793 .28629 m .48771 .28534 L .49143 .26665 L p
1 g
F P
s
P
p
.002 w
.52623 .27794 m .53745 .2897 L .56357 .28611 L p
1 g
F P
s
P
p
.002 w
.49143 .26665 m .4718 .26855 L .47793 .28629 L p
1 g
F P
s
P
p
.002 w
.33459 .36585 m .34534 .40303 L .36228 .38195 L p
1 g
F P
s
P
p
.002 w
.36228 .38195 m .35331 .34925 L .33459 .36585 L p
1 g
F P
s
P
p
.002 w
.38046 .30642 m .37532 .33512 L .40005 .32369 L p
1 g
F P
s
P
p
.002 w
.40005 .32369 m .40429 .3016 L .38046 .30642 L p
1 g
F P
s
P
p
.002 w
.3506 .53035 m .39692 .55601 L .3958 .53349 L p
1 g
F P
s
P
p
.002 w
.3958 .53349 m .35014 .50772 L .3506 .53035 L p
1 g
F P
s
P
p
.002 w
.40076 .57596 m .45521 .58889 L .45202 .56936 L p
1 g
F P
s
P
p
.002 w
.45202 .56936 m .39692 .55601 L .40076 .57596 L p
1 g
F P
s
P
p
.002 w
.41777 .28111 m .40429 .3016 L .42998 .30016 L p
1 g
F P
s
P
p
.002 w
.42998 .30016 m .43922 .28638 L .41777 .28111 L p
1 g
F P
s
P
p
.002 w
.67291 .41331 m .64831 .45418 L .6572 .4768 L p
1 g
F P
s
P
p
.002 w
.64831 .45418 m .67291 .41331 L .65856 .39285 L p
1 g
F P
s
P
p
.002 w
.64535 .33532 m .64051 .37383 L .65856 .39285 L p
1 g
F P
s
P
p
.002 w
.64051 .37383 m .64535 .33532 L .62304 .32282 L p
1 g
F P
s
P
p
.002 w
.58866 .28616 m .5981 .31333 L .62304 .32282 L p
1 g
F P
s
P
p
.002 w
.5981 .31333 m .58866 .28616 L .56357 .28611 L p
1 g
F P
s
P
p
.002 w
.56357 .28611 m .54719 .26856 L .52623 .27794 L p
1 g
F P
s
P
p
.002 w
.5103 .26992 m .52623 .27794 L .54719 .26856 L p
1 g
F P
s
P
p
.002 w
.31802 .47129 m .35014 .50772 L .35352 .48375 L p
1 g
F P
s
P
p
.002 w
.35352 .48375 m .3228 .44819 L .31802 .47129 L p
1 g
F P
s
P
p
.002 w
.43919 .26469 m .41777 .28111 L .43922 .28638 L p
1 g
F P
s
P
p
.002 w
.43922 .28638 m .4537 .2754 L .43919 .26469 L p
1 g
F P
s
P
p
.002 w
.35909 .31465 m .35331 .34925 L .37532 .33512 L p
1 g
F P
s
P
p
.002 w
.37532 .33512 m .38046 .30642 L .35909 .31465 L p
1 g
F P
s
P
p
.002 w
.31976 .38462 m .33204 .42527 L .34534 .40303 L p
1 g
F P
s
P
p
.002 w
.34534 .40303 m .33459 .36585 L .31976 .38462 L p
1 g
F P
s
P
p
.002 w
.54719 .26856 m .56357 .28611 L .58866 .28616 L p
1 g
F P
s
P
p
.002 w
.57071 .57707 m .62215 .55339 L .62081 .53326 L p
1 g
F P
s
P
p
.002 w
.66225 .49884 m .62081 .53326 L .62215 .55339 L p
1 g
F P
s
P
p
.002 w
.62081 .53326 m .66225 .49884 L .6572 .4768 L p
1 g
F P
s
P
p
.002 w
.45969 .60496 m .51574 .60517 L .51348 .5892 L p
1 g
F P
s
P
p
.002 w
.51348 .5892 m .45521 .58889 L .45969 .60496 L p
1 g
F P
s
P
p
.002 w
.57071 .57707 m .51348 .5892 L .51574 .60517 L p
1 g
F P
s
P
p
.002 w
.39779 .27961 m .38046 .30642 L .40429 .3016 L p
1 g
F P
s
P
p
.002 w
.40429 .3016 m .41777 .28111 L .39779 .27961 L p
1 g
F P
s
P
p
.002 w
.54719 .26856 m .52363 .25653 L .5103 .26992 L p
1 g
F P
s
P
p
.002 w
.49143 .26665 m .5103 .26992 L .52363 .25653 L p
1 g
F P
s
P
p
.002 w
.46618 .2544 m .43919 .26469 L .4537 .2754 L p
1 g
F P
s
P
p
.002 w
.4537 .2754 m .4718 .26855 L .46618 .2544 L p
1 g
F P
s
P
p
.002 w
.35506 .55103 m .40076 .57596 L .39692 .55601 L p
1 g
F P
s
P
p
.002 w
.39692 .55601 m .3506 .53035 L .35506 .55103 L p
1 g
F P
s
P
p
.002 w
.51574 .60517 m .57082 .59356 L .57071 .57707 L p
1 g
F P
s
P
p
.002 w
.62215 .55339 m .57071 .57707 L .57082 .59356 L p
1 g
F P
s
P
p
.002 w
.6644 .35065 m .65856 .39285 L .67291 .41331 L p
1 g
F P
s
P
p
.002 w
.65856 .39285 m .6644 .35065 L .64535 .33532 L p
1 g
F P
s
P
p
.002 w
.6121 .29001 m .62304 .32282 L .64535 .33532 L p
1 g
F P
s
P
p
.002 w
.62304 .32282 m .6121 .29001 L .58866 .28616 L p
1 g
F P
s
P
p
.002 w
.68309 .43477 m .6572 .4768 L .66225 .49884 L p
1 g
F P
s
P
p
.002 w
.6572 .4768 m .68309 .43477 L .67291 .41331 L p
1 g
F P
s
P
p
.002 w
.52363 .25653 m .49551 .25157 L .49143 .26665 L p
1 g
F P
s
P
p
.002 w
.4718 .26855 m .49143 .26665 L .49551 .25157 L p
1 g
F P
s
P
p
.002 w
.49551 .25157 m .46618 .2544 L .4718 .26855 L p
1 g
F P
s
P
p
.002 w
.40738 .59275 m .45969 .60496 L .45521 .58889 L p
1 g
F P
s
P
p
.002 w
.45521 .58889 m .40076 .57596 L .40738 .59275 L p
1 g
F P
s
P
p
.002 w
.34084 .32624 m .33459 .36585 L .35331 .34925 L p
1 g
F P
s
P
p
.002 w
.35331 .34925 m .35909 .31465 L .34084 .32624 L p
1 g
F P
s
P
p
.002 w
.30934 .40518 m .3228 .44819 L .33204 .42527 L p
1 g
F P
s
P
p
.002 w
.33204 .42527 m .31976 .38462 L .30934 .40518 L p
1 g
F P
s
P
p
.002 w
.318 .49399 m .3506 .53035 L .35014 .50772 L p
1 g
F P
s
P
p
.002 w
.35014 .50772 m .31802 .47129 L .318 .49399 L p
1 g
F P
s
P
p
.002 w
.58866 .28616 m .56757 .26316 L .54719 .26856 L p
1 g
F P
s
P
p
.002 w
.52363 .25653 m .54719 .26856 L .56757 .26316 L p
1 g
F P
s
P
p
.002 w
.56757 .26316 m .58866 .28616 L .6121 .29001 L p
1 g
F P
s
P
p
.002 w
.42577 .25799 m .39779 .27961 L .41777 .28111 L p
1 g
F P
s
P
p
.002 w
.41777 .28111 m .43919 .26469 L .42577 .25799 L p
1 g
F P
s
P
p
.002 w
.37985 .2821 m .35909 .31465 L .38046 .30642 L p
1 g
F P
s
P
p
.002 w
.38046 .30642 m .39779 .27961 L .37985 .2821 L p
1 g
F P
s
P
p
.002 w
.57082 .59356 m .6203 .57097 L .62215 .55339 L p
1 g
F P
s
P
p
.002 w
.66314 .51977 m .62215 .55339 L .6203 .57097 L p
1 g
F P
s
P
p
.002 w
.62215 .55339 m .66314 .51977 L .66225 .49884 L p
1 g
F P
s
P
p
.002 w
.63325 .29771 m .64535 .33532 L .6644 .35065 L p
1 g
F P
s
P
p
.002 w
.64535 .33532 m .63325 .29771 L .6121 .29001 L p
1 g
F P
s
P
p
.002 w
.67959 .36856 m .67291 .41331 L .68309 .43477 L p
1 g
F P
s
P
p
.002 w
.67291 .41331 m .67959 .36856 L .6644 .35065 L p
1 g
F P
s
P
p
.002 w
.46541 .61699 m .51767 .61713 L .51574 .60517 L p
1 g
F P
s
P
p
.002 w
.51574 .60517 m .45969 .60496 L .46541 .61699 L p
1 g
F P
s
P
p
.002 w
.57082 .59356 m .51574 .60517 L .51767 .61713 L p
1 g
F P
s
P
p
.002 w
.56757 .26316 m .53682 .24727 L .52363 .25653 L p
1 g
F P
s
P
p
.002 w
.49551 .25157 m .52363 .25653 L .53682 .24727 L p
1 g
F P
s
P
p
.002 w
.68866 .45676 m .66225 .49884 L .66314 .51977 L p
1 g
F P
s
P
p
.002 w
.66225 .49884 m .68866 .45676 L .68309 .43477 L p
1 g
F P
s
P
p
.002 w
.36361 .56914 m .40738 .59275 L .40076 .57596 L p
1 g
F P
s
P
p
.002 w
.40076 .57596 m .35506 .55103 L .36361 .56914 L p
1 g
F P
s
P
p
.002 w
.46124 .2444 m .42577 .25799 L .43919 .26469 L p
1 g
F P
s
P
p
.002 w
.43919 .26469 m .46618 .2544 L .46124 .2444 L p
1 g
F P
s
P
p
.002 w
.32631 .34106 m .31976 .38462 L .33459 .36585 L p
1 g
F P
s
P
p
.002 w
.33459 .36585 m .34084 .32624 L .32631 .34106 L p
1 g
F P
s
P
p
.002 w
.51767 .61713 m .56905 .60634 L .57082 .59356 L p
1 g
F P
s
P
p
.002 w
.6203 .57097 m .57082 .59356 L .56905 .60634 L p
1 g
F P
s
P
p
.002 w
.30381 .42707 m .31802 .47129 L .3228 .44819 L p
1 g
F P
s
P
p
.002 w
.3228 .44819 m .30934 .40518 L .30381 .42707 L p
1 g
F P
s
P
p
.002 w
.53682 .24727 m .49987 .24068 L .49551 .25157 L p
1 g
F P
s
P
p
.002 w
.46618 .2544 m .49551 .25157 L .49987 .24068 L p
1 g
F P
s
P
p
.002 w
.41676 .60577 m .46541 .61699 L .45969 .60496 L p
1 g
F P
s
P
p
.002 w
.45969 .60496 m .40738 .59275 L .41676 .60577 L p
1 g
F P
s
P
p
.002 w
.49987 .24068 m .46124 .2444 L .46618 .2544 L p
1 g
F P
s
P
p
.002 w
.32296 .51566 m .35506 .55103 L .3506 .53035 L p
1 g
F P
s
P
p
.002 w
.3506 .53035 m .318 .49399 L .32296 .51566 L p
1 g
F P
s
P
p
.002 w
.58683 .26204 m .6121 .29001 L .63325 .29771 L p
1 g
F P
s
P
p
.002 w
.6121 .29001 m .58683 .26204 L .56757 .26316 L p
1 g
F P
s
P
p
.002 w
.53682 .24727 m .56757 .26316 L .58683 .26204 L p
1 g
F P
s
P
p
.002 w
.41381 .25571 m .37985 .2821 L .39779 .27961 L p
1 g
F P
s
P
p
.002 w
.39779 .27961 m .42577 .25799 L .41381 .25571 L p
1 g
F P
s
P
p
.002 w
.36453 .28874 m .34084 .32624 L .35909 .31465 L p
1 g
F P
s
P
p
.002 w
.35909 .31465 m .37985 .2821 L .36453 .28874 L p
1 g
F P
s
P
p
.002 w
.65145 .30926 m .6644 .35065 L .67959 .36856 L p
1 g
F P
s
P
p
.002 w
.6644 .35065 m .65145 .30926 L .63325 .29771 L p
1 g
F P
s
P
p
.002 w
.69036 .3887 m .68309 .43477 L .68866 .45676 L p
1 g
F P
s
P
p
.002 w
.68309 .43477 m .69036 .3887 L .67959 .36856 L p
1 g
F P
s
P
p
.002 w
.56905 .60634 m .61514 .58543 L .6203 .57097 L p
1 g
F P
s
P
p
.002 w
.65966 .53901 m .6203 .57097 L .61514 .58543 L p
1 g
F P
s
P
p
.002 w
.6203 .57097 m .65966 .53901 L .66314 .51977 L p
1 g
F P
s
P
p
.002 w
.68927 .47873 m .66314 .51977 L .65966 .53901 L p
1 g
F P
s
P
p
.002 w
.66314 .51977 m .68927 .47873 L .68866 .45676 L p
1 g
F P
s
P
p
.002 w
.3161 .35886 m .30934 .40518 L .31976 .38462 L p
1 g
F P
s
P
p
.002 w
.31976 .38462 m .32631 .34106 L .3161 .35886 L p
1 g
F P
s
P
p
.002 w
.30356 .44975 m .318 .49399 L .31802 .47129 L p
1 g
F P
s
P
p
.002 w
.31802 .47129 m .30381 .42707 L .30356 .44975 L p
1 g
F P
s
P
p
.002 w
.37622 .58406 m .41676 .60577 L .40738 .59275 L p
1 g
F P
s
P
p
.002 w
.40738 .59275 m .36361 .56914 L .37622 .58406 L p
1 g
F P
s
P
p
.002 w
.58683 .26204 m .54952 .24261 L .53682 .24727 L p
1 g
F P
s
P
p
.002 w
.49987 .24068 m .53682 .24727 L .54952 .24261 L p
1 g
F P
s
P
p
.002 w
.47232 .62443 m .51921 .62452 L .51767 .61713 L p
1 g
F P
s
P
p
.002 w
.51767 .61713 m .46541 .61699 L .47232 .62443 L p
1 g
F P
s
P
p
.002 w
.56905 .60634 m .51767 .61713 L .51921 .62452 L p
1 g
F P
s
P
p
.002 w
.45714 .23907 m .41381 .25571 L .42577 .25799 L p
1 g
F P
s
P
p
.002 w
.42577 .25799 m .46124 .2444 L .45714 .23907 L p
1 g
F P
s
P
p
.002 w
.60442 .26548 m .63325 .29771 L .65145 .30926 L p
1 g
F P
s
P
p
.002 w
.63325 .29771 m .60442 .26548 L .58683 .26204 L p
1 g
F P
s
P
p
.002 w
.33302 .53566 m .36361 .56914 L .35506 .55103 L p
1 g
F P
s
P
p
.002 w
.35506 .55103 m .32296 .51566 L .33302 .53566 L p
1 g
F P
s
P
p
.002 w
.51921 .62452 m .56532 .61486 L .56905 .60634 L p
1 g
F P
s
P
p
.004 w
.55309 .6231 m
.57535 .70384 L
s
P
p
.004 w
.55242 .62066 m
.55309 .6231 L
s
P
p
.004 w
.55161 .61773 m
.55242 .62066 L
s
P
p
.004 w
.5 .43051 m
.55012 .61232 L
s
P
p
.002 w
.61514 .58543 m .56905 .60634 L .56532 .61486 L p
1 g
F P
s
P
p
.002 w
.54952 .24261 m .58683 .26204 L .60442 .26548 L p
1 g
F P
s
P
p
.002 w
.4288 .61446 m .47232 .62443 L .46541 .61699 L p
1 g
F P
s
P
p
.002 w
.46541 .61699 m .41676 .60577 L .4288 .61446 L p
1 g
F P
s
P
p
.002 w
.54952 .24261 m .50442 .23452 L .49987 .24068 L p
1 g
F P
s
P
p
.002 w
.46124 .2444 m .49987 .24068 L .50442 .23452 L p
1 g
F P
s
P
p
.002 w
.6661 .32453 m .67959 .36856 L .69036 .3887 L p
1 g
F P
s
P
p
.002 w
.67959 .36856 m .6661 .32453 L .65145 .30926 L p
1 g
F P
s
P
p
.002 w
.50442 .23452 m .45714 .23907 L .46124 .2444 L p
1 g
F P
s
P
p
.002 w
.35239 .29959 m .32631 .34106 L .34084 .32624 L p
1 g
F P
s
P
p
.002 w
.34084 .32624 m .36453 .28874 L .35239 .29959 L p
1 g
F P
s
P
p
.002 w
.69622 .41063 m .68866 .45676 L .68927 .47873 L p
1 g
F P
s
P
p
.002 w
.68866 .45676 m .69622 .41063 L .69036 .3887 L p
1 g
F P
s
P
p
.002 w
.40375 .25818 m .36453 .28874 L .37985 .2821 L p
1 g
F P
s
P
p
.002 w
.37985 .2821 m .41381 .25571 L .40375 .25818 L p
1 g
F P
s
P
p
.002 w
.31071 .3793 m .30381 .42707 L .30934 .40518 L p
1 g
F P
s
P
p
.002 w
.30934 .40518 m .3161 .35886 L .31071 .3793 L p
1 g
F P
s
P
p
.002 w
.30885 .47261 m .32296 .51566 L .318 .49399 L p
1 g
F P
s
P
p
.002 w
.318 .49399 m .30356 .44975 L .30885 .47261 L p
1 g
F P
s
P
p
.002 w
.56532 .61486 m .6066 .5962 L .61514 .58543 L p
1 g
F P
s
P
p
.002 w
.65168 .55595 m .61514 .58543 L .6066 .5962 L p
1 g
F P
s
P
p
.002 w
.61514 .58543 m .65168 .55595 L .65966 .53901 L p
1 g
F P
s
P
p
.002 w
.68467 .50009 m .65966 .53901 L .65168 .55595 L p
1 g
F P
s
P
p
.002 w
.65966 .53901 m .68467 .50009 L .68927 .47873 L p
1 g
F P
s
P
p
.002 w
.61977 .27361 m .65145 .30926 L .6661 .32453 L p
1 g
F P
s
P
p
.002 w
.65145 .30926 m .61977 .27361 L .60442 .26548 L p
1 g
F P
s
P
p
.002 w
.39275 .59519 m .4288 .61446 L .41676 .60577 L p
1 g
F P
s
P
p
.002 w
.41676 .60577 m .37622 .58406 L .39275 .59519 L p
1 g
F P
s
P
p
.002 w
.60442 .26548 m .56139 .24296 L .54952 .24261 L p
1 g
F P
s
P
p
.002 w
.50442 .23452 m .54952 .24261 L .56139 .24296 L p
1 g
F P
s
P
p
.002 w
.34812 .55333 m .37622 .58406 L .36361 .56914 L p
1 g
F P
s
P
p
.002 w
.36361 .56914 m .33302 .53566 L .34812 .55333 L p
1 g
F P
s
P
p
.002 w
.45407 .23885 m .40375 .25818 L .41381 .25571 L p
1 g
F P
s
P
p
.002 w
.41381 .25571 m .45714 .23907 L .45407 .23885 L p
1 g
F P
s
P
p
.002 w
.69036 .3887 m .67658 .34328 L .6661 .32453 L p
1 g
F P
s
P
p
.002 w
.67658 .34328 m .69036 .3887 L .69622 .41063 L p
1 g
F P
s
P
p
.002 w
.4803 .62678 m .52027 .62685 L .51921 .62452 L p
1 g
F P
s
P
p
.002 w
.51921 .62452 m .47232 .62443 L .4803 .62678 L p
1 g
F P
s
P
p
.002 w
.56532 .61486 m .51921 .62452 L .52027 .62685 L p
1 g
F P
s
P
p
.002 w
.56139 .24296 m .60442 .26548 L .61977 .27361 L p
1 g
F P
s
P
p
.002 w
.68927 .47873 m .69676 .43381 L .69622 .41063 L p
1 g
F P
s
P
p
.002 w
.69676 .43381 m .68927 .47873 L .68467 .50009 L p
1 g
F P
s
P
p
.002 w
.34397 .31457 m .3161 .35886 L .32631 .34106 L p
1 g
F P
s
P
p
.002 w
.32631 .34106 m .35239 .29959 L .34397 .31457 L p
1 g
F P
s
P
p
.002 w
.52027 .62685 m .55961 .61861 L .56532 .61486 L p
1 g
F P
s
P
p
.002 w
.6066 .5962 m .56532 .61486 L .55961 .61861 L p
1 g
F P
s
P
p
.004 w
.52649 .64038 m
.5298 .66663 L
s
P
p
.002 w
.44333 .61831 m .4803 .62678 L .47232 .62443 L p
1 g
F P
s
P
p
.002 w
.47232 .62443 m .4288 .61446 L .44333 .61831 L p
1 g
F P
s
P
p
.002 w
.56139 .24296 m .50904 .23355 L .50442 .23452 L p
1 g
F P
s
P
p
.002 w
.45714 .23907 m .50442 .23452 L .50904 .23355 L p
1 g
F P
s
P
p
.002 w
.39599 .26564 m .35239 .29959 L .36453 .28874 L p
1 g
F P
s
P
p
.002 w
.36453 .28874 m .40375 .25818 L .39599 .26564 L p
1 g
F P
s
P
p
.002 w
.50904 .23355 m .45407 .23885 L .45714 .23907 L p
1 g
F P
s
P
p
.002 w
.31057 .40188 m .30356 .44975 L .30381 .42707 L p
1 g
F P
s
P
p
.002 w
.30381 .42707 m .31071 .3793 L .31057 .40188 L p
1 g
F P
s
P
p
.002 w
.31978 .49497 m .33302 .53566 L .32296 .51566 L p
1 g
F P
s
P
p
.002 w
.32296 .51566 m .30885 .47261 L .31978 .49497 L p
1 g
F P
s
P
p
.002 w
.6066 .5962 m .63915 .56999 L .65168 .55595 L p
1 g
F P
s
P
p
.002 w
.65168 .55595 m .67472 .52019 L .68467 .50009 L p
1 g
F P
s
P
p
.002 w
.67472 .52019 m .65168 .55595 L .63915 .56999 L p
1 g
F P
s
P
p
.002 w
.55961 .61861 m .59471 .60276 L .6066 .5962 L p
1 g
F P
s
P
p
.002 w
.63915 .56999 m .6066 .5962 L .59471 .60276 L p
1 g
F P
s
P
p
.002 w
.6661 .32453 m .63231 .28649 L .61977 .27361 L p
1 g
F P
s
P
p
.002 w
.63231 .28649 m .6661 .32453 L .67658 .34328 L p
1 g
F P
s
P
p
.002 w
.6824 .36514 m .69622 .41063 L .69676 .43381 L p
1 g
F P
s
P
p
.002 w
.69622 .41063 m .6824 .36514 L .67658 .34328 L p
1 g
F P
s
P
p
.002 w
.36805 .56803 m .39275 .59519 L .37622 .58406 L p
1 g
F P
s
P
p
.002 w
.37622 .58406 m .34812 .55333 L .36805 .56803 L p
1 g
F P
s
P
p
.002 w
.41293 .60201 m .44333 .61831 L .4288 .61446 L p
1 g
F P
s
P
p
.002 w
.4288 .61446 m .39275 .59519 L .41293 .60201 L p
1 g
F P
s
P
p
.002 w
.61977 .27361 m .57201 .24863 L .56139 .24296 L p
1 g
F P
s
P
p
.002 w
.50904 .23355 m .56139 .24296 L .57201 .24863 L p
1 g
F P
s
P
p
.002 w
.69171 .45761 m .68467 .50009 L .67472 .52019 L p
1 g
F P
s
P
p
.002 w
.68467 .50009 m .69171 .45761 L .69676 .43381 L p
1 g
F P
s
P
p
.002 w
.33975 .33347 m .31071 .3793 L .3161 .35886 L p
1 g
F P
s
P
p
.002 w
.3161 .35886 m .34397 .31457 L .33975 .33347 L p
1 g
F P
s
P
p
.002 w
.57201 .24863 m .61977 .27361 L .63231 .28649 L p
1 g
F P
s
P
p
.002 w
.45217 .24409 m .39599 .26564 L .40375 .25818 L p
1 g
F P
s
P
p
.002 w
.40375 .25818 m .45407 .23885 L .45217 .24409 L p
1 g
F P
s
P
p
.002 w
.48918 .62364 m .52081 .6237 L .52027 .62685 L p
1 g
F P
s
P
p
.002 w
.52027 .62685 m .4803 .62678 L .48918 .62364 L p
1 g
F P
s
P
p
.002 w
.55961 .61861 m .52027 .62685 L .52081 .6237 L p
1 g
F P
s
P
p
.002 w
.31593 .42603 m .30885 .47261 L .30356 .44975 L p
1 g
F P
s
P
p
.002 w
.30356 .44975 m .31057 .40188 L .31593 .42603 L p
1 g
F P
s
P
p
.002 w
.33626 .5161 m .34812 .55333 L .33302 .53566 L p
1 g
F P
s
P
p
.002 w
.33302 .53566 m .31978 .49497 L .33626 .5161 L p
1 g
F P
s
P
p
.002 w
.52081 .6237 m .55195 .61718 L .55961 .61861 L p
1 g
F P
s
P
p
.002 w
.59471 .60276 m .55961 .61861 L .55195 .61718 L p
1 g
F P
s
P
p
.002 w
.39091 .27818 m .34397 .31457 L .35239 .29959 L p
1 g
F P
s
P
p
.002 w
.35239 .29959 m .39599 .26564 L .39091 .27818 L p
1 g
F P
s
P
p
.002 w
.46005 .61693 m .48918 .62364 L .4803 .62678 L p
1 g
F P
s
P
p
.002 w
.4803 .62678 m .44333 .61831 L .46005 .61693 L p
1 g
F P
s
P
p
.002 w
.57201 .24863 m .51361 .23817 L .50904 .23355 L p
1 g
F P
s
P
p
.002 w
.45407 .23885 m .50904 .23355 L .51361 .23817 L p
1 g
F P
s
P
p
.002 w
.51361 .23817 m .45217 .24409 L .45407 .23885 L p
1 g
F P
s
P
p
.002 w
.59471 .60276 m .62221 .58058 L .63915 .56999 L p
1 g
F P
s
P
p
.002 w
.65945 .53837 m .63915 .56999 L .62221 .58058 L p
1 g
F P
s
P
p
.002 w
.63915 .56999 m .65945 .53837 L .67472 .52019 L p
1 g
F P
s
P
p
.002 w
.64151 .30399 m .67658 .34328 L .6824 .36514 L p
1 g
F P
s
P
p
.002 w
.67658 .34328 m .64151 .30399 L .63231 .28649 L p
1 g
F P
s
P
p
.002 w
.68312 .38958 m .69676 .43381 L .69171 .45761 L p
1 g
F P
s
P
p
.002 w
.69676 .43381 m .68312 .38958 L .6824 .36514 L p
1 g
F P
s
P
p
.002 w
.55195 .61718 m .57964 .60464 L .59471 .60276 L p
1 g
F P
s
P
p
.002 w
.62221 .58058 m .59471 .60276 L .57964 .60464 L p
1 g
F P
s
P
p
.002 w
.39239 .57915 m .41293 .60201 L .39275 .59519 L p
1 g
F P
s
P
p
.002 w
.39275 .59519 m .36805 .56803 L .39239 .57915 L p
1 g
F P
s
P
p
.002 w
.68099 .48134 m .67472 .52019 L .65945 .53837 L p
1 g
F P
s
P
p
.002 w
.67472 .52019 m .68099 .48134 L .69171 .45761 L p
1 g
F P
s
P
p
.002 w
.43631 .60408 m .46005 .61693 L .44333 .61831 L p
1 g
F P
s
P
p
.002 w
.44333 .61831 m .41293 .60201 L .43631 .60408 L p
1 g
F P
s
P
p
.002 w
.3401 .35588 m .31057 .40188 L .31071 .3793 L p
1 g
F P
s
P
p
.002 w
.31071 .3793 m .33975 .33347 L .3401 .35588 L p
1 g
F P
s
P
p
.002 w
.32687 .451 m .31978 .49497 L .30885 .47261 L p
1 g
F P
s
P
p
.002 w
.30885 .47261 m .31593 .42603 L .32687 .451 L p
1 g
F P
s
P
p
.002 w
.63231 .28649 m .58099 .25977 L .57201 .24863 L p
1 g
F P
s
P
p
.002 w
.51361 .23817 m .57201 .24863 L .58099 .25977 L p
1 g
F P
s
P
p
.002 w
.58099 .25977 m .63231 .28649 L .64151 .30399 L p
1 g
F P
s
P
p
.002 w
.35797 .53526 m .36805 .56803 L .34812 .55333 L p
1 g
F P
s
P
p
.002 w
.34812 .55333 m .33626 .5161 L .35797 .53526 L p
1 g
F P
s
P
p
.002 w
.45158 .255 m .39091 .27818 L .39599 .26564 L p
1 g
F P
s
P
p
.002 w
.39599 .26564 m .45217 .24409 L .45158 .255 L p
1 g
F P
s
P
p
.002 w
.38885 .2957 m .33975 .33347 L .34397 .31457 L p
1 g
F P
s
P
p
.002 w
.34397 .31457 m .39091 .27818 L .38885 .2957 L p
1 g
F P
s
P
p
.002 w
.49875 .61475 m .52077 .61482 L .52081 .6237 L p
1 g
F P
s
P
p
.002 w
.52081 .6237 m .48918 .62364 L .49875 .61475 L p
1 g
F P
s
P
p
.002 w
.55195 .61718 m .52081 .6237 L .52077 .61482 L p
1 g
F P
s
P
p
.002 w
.52077 .61482 m .54246 .61026 L .55195 .61718 L p
1 g
F P
s
P
p
.002 w
.57964 .60464 m .55195 .61718 L .54246 .61026 L p
1 g
F P
s
P
p
.002 w
.6469 .32579 m .6824 .36514 L .68312 .38958 L p
1 g
F P
s
P
p
.002 w
.6824 .36514 m .6469 .32579 L .64151 .30399 L p
1 g
F P
s
P
p
.002 w
.67851 .41594 m .69171 .45761 L .68099 .48134 L p
1 g
F P
s
P
p
.002 w
.69171 .45761 m .67851 .41594 L .68312 .38958 L p
1 g
F P
s
P
p
.002 w
.57964 .60464 m .60114 .58718 L .62221 .58058 L p
1 g
F P
s
P
p
.002 w
.63911 .55398 m .62221 .58058 L .60114 .58718 L p
1 g
F P
s
P
p
.002 w
.62221 .58058 m .63911 .55398 L .65945 .53837 L p
1 g
F P
s
P
p
.002 w
.47857 .61004 m .49875 .61475 L .48918 .62364 L p
1 g
F P
s
P
p
.002 w
.48918 .62364 m .46005 .61693 L .47857 .61004 L p
1 g
F P
s
P
p
.002 w
.58099 .25977 m .51798 .24859 L .51361 .23817 L p
1 g
F P
s
P
p
.002 w
.45217 .24409 m .51361 .23817 L .51798 .24859 L p
1 g
F P
s
P
p
.002 w
.66467 .50423 m .65945 .53837 L .63911 .55398 L p
1 g
F P
s
P
p
.002 w
.65945 .53837 m .66467 .50423 L .68099 .48134 L p
1 g
F P
s
P
p
.002 w
.51798 .24859 m .45158 .255 L .45217 .24409 L p
1 g
F P
s
P
p
.002 w
.42054 .58618 m .43631 .60408 L .41293 .60201 L p
1 g
F P
s
P
p
.002 w
.41293 .60201 m .39239 .57915 L .42054 .58618 L p
1 g
F P
s
P
p
.002 w
.34522 .38124 m .31593 .42603 L .31057 .40188 L p
1 g
F P
s
P
p
.002 w
.31057 .40188 m .3401 .35588 L .34522 .38124 L p
1 g
F P
s
P
p
.002 w
.60114 .58718 m .57964 .60464 L .56166 .60151 L p
1 g
F P
s
P
p
.002 w
.54246 .61026 m .56166 .60151 L .57964 .60464 L p
1 g
F P
s
P
p
.002 w
.34325 .476 m .33626 .5161 L .31978 .49497 L p
1 g
F P
s
P
p
.002 w
.31978 .49497 m .32687 .451 L .34325 .476 L p
1 g
F P
s
P
p
.002 w
.46229 .6011 m .47857 .61004 L .46005 .61693 L p
1 g
F P
s
P
p
.002 w
.46005 .61693 m .43631 .60408 L .46229 .6011 L p
1 g
F P
s
P
p
.002 w
.38439 .55174 m .39239 .57915 L .36805 .56803 L p
1 g
F P
s
P
p
.002 w
.36805 .56803 m .35797 .53526 L .38439 .55174 L p
1 g
F P
s
P
p
.002 w
.58795 .27636 m .64151 .30399 L .6469 .32579 L p
1 g
F P
s
P
p
.002 w
.64151 .30399 m .58795 .27636 L .58099 .25977 L p
1 g
F P
s
P
p
.002 w
.51798 .24859 m .58099 .25977 L .58795 .27636 L p
1 g
F P
s
P
p
.002 w
.66848 .44342 m .68099 .48134 L .66467 .50423 L p
1 g
F P
s
P
p
.002 w
.68099 .48134 m .66848 .44342 L .67851 .41594 L p
1 g
F P
s
P
p
.002 w
.6481 .3514 m .68312 .38958 L .67851 .41594 L p
1 g
F P
s
P
p
.002 w
.68312 .38958 m .6481 .3514 L .6469 .32579 L p
1 g
F P
s
P
p
.002 w
.45241 .27158 m .38885 .2957 L .39091 .27818 L p
1 g
F P
s
P
p
.002 w
.39091 .27818 m .45158 .255 L .45241 .27158 L p
1 g
F P
s
P
p
.002 w
.39004 .3179 m .3401 .35588 L .33975 .33347 L p
1 g
F P
s
P
p
.002 w
.33975 .33347 m .38885 .2957 L .39004 .3179 L p
1 g
F P
s
P
p
.002 w
.56166 .60151 m .57642 .5894 L .60114 .58718 L p
1 g
F P
s
P
p
.002 w
.61411 .5664 m .60114 .58718 L .57642 .5894 L p
1 g
F P
s
P
p
.002 w
.60114 .58718 m .61411 .5664 L .63911 .55398 L p
1 g
F P
s
P
p
.002 w
.64311 .52547 m .63911 .55398 L .61411 .5664 L p
1 g
F P
s
P
p
.002 w
.63911 .55398 m .64311 .52547 L .66467 .50423 L p
1 g
F P
s
P
p
.002 w
.50874 .60005 m .52012 .6001 L .52077 .61482 L p
1 g
F P
s
P
p
.002 w
.52077 .61482 m .49875 .61475 L .50874 .60005 L p
1 g
F P
s
P
p
.002 w
.54246 .61026 m .52077 .61482 L .52012 .6001 L p
1 g
F P
s
P
p
.002 w
.45168 .58873 m .46229 .6011 L .43631 .60408 L p
1 g
F P
s
P
p
.002 w
.43631 .60408 m .42054 .58618 L .45168 .58873 L p
1 g
F P
s
P
p
.002 w
.36468 .50015 m .35797 .53526 L .33626 .5161 L p
1 g
F P
s
P
p
.002 w
.33626 .5161 m .34325 .476 L .36468 .50015 L p
1 g
F P
s
P
p
.002 w
.52012 .6001 m .53132 .59774 L .54246 .61026 L p
1 g
F P
s
P
p
.002 w
.56166 .60151 m .54246 .61026 L .53132 .59774 L p
1 g
F P
s
P
p
.002 w
.49837 .59759 m .50874 .60005 L .49875 .61475 L p
1 g
F P
s
P
p
.002 w
.49875 .61475 m .47857 .61004 L .49837 .59759 L p
1 g
F P
s
P
p
.002 w
.35516 .40879 m .32687 .451 L .31593 .42603 L p
1 g
F P
s
P
p
.002 w
.31593 .42603 m .34522 .38124 L .35516 .40879 L p
1 g
F P
s
P
p
.002 w
.41474 .56489 m .42054 .58618 L .39239 .57915 L p
1 g
F P
s
P
p
.002 w
.39239 .57915 m .38439 .55174 L .41474 .56489 L p
1 g
F P
s
P
p
.002 w
.58795 .27636 m .522 .26484 L .51798 .24859 L p
1 g
F P
s
P
p
.002 w
.45158 .255 m .51798 .24859 L .522 .26484 L p
1 g
F P
s
P
p
.002 w
.522 .26484 m .45241 .27158 L .45158 .255 L p
1 g
F P
s
P
p
.002 w
.57642 .5894 m .56166 .60151 L .5412 .5932 L p
1 g
F P
s
P
p
.002 w
.53132 .59774 m .5412 .5932 L .56166 .60151 L p
1 g
F P
s
P
p
.002 w
.4901 .59294 m .49837 .59759 L .47857 .61004 L p
1 g
F P
s
P
p
.002 w
.47857 .61004 m .46229 .6011 L .4901 .59294 L p
1 g
F P
s
P
p
.002 w
.65319 .47112 m .66467 .50423 L .64311 .52547 L p
1 g
F P
s
P
p
.002 w
.66467 .50423 m .65319 .47112 L .66848 .44342 L p
1 g
F P
s
P
p
.002 w
.59253 .29815 m .6469 .32579 L .6481 .3514 L p
1 g
F P
s
P
p
.002 w
.6469 .32579 m .59253 .29815 L .58795 .27636 L p
1 g
F P
s
P
p
.002 w
.64488 .3801 m .67851 .41594 L .66848 .44342 L p
1 g
F P
s
P
p
.002 w
.67851 .41594 m .64488 .3801 L .6481 .3514 L p
1 g
F P
s
P
p
.002 w
.522 .26484 m .58795 .27636 L .59253 .29815 L p
1 g
F P
s
P
p
.002 w
.57642 .5894 m .58513 .57508 L .61411 .5664 L p
1 g
F P
s
P
p
.002 w
.61685 .54431 m .61411 .5664 L .58513 .57508 L p
1 g
F P
s
P
p
.002 w
.61411 .5664 m .61685 .54431 L .64311 .52547 L p
1 g
F P
s
P
p
.002 w
.39055 .52256 m .38439 .55174 L .35797 .53526 L p
1 g
F P
s
P
p
.002 w
.35797 .53526 m .36468 .50015 L .39055 .52256 L p
1 g
F P
s
P
p
.002 w
.39461 .34423 m .34522 .38124 L .3401 .35588 L p
1 g
F P
s
P
p
.002 w
.3401 .35588 m .39004 .3179 L .39461 .34423 L p
1 g
F P
s
P
p
.002 w
.5412 .5932 m .5487 .58694 L .57642 .5894 L p
1 g
F P
s
P
p
.002 w
.58513 .57508 m .57642 .5894 L .5487 .58694 L p
1 g
F P
s
P
p
.002 w
.44804 .57416 m .45168 .58873 L .42054 .58618 L p
1 g
F P
s
P
p
.002 w
.42054 .58618 m .41474 .56489 L .44804 .57416 L p
1 g
F P
s
P
p
.002 w
.45471 .29358 m .39004 .3179 L .38885 .2957 L p
1 g
F P
s
P
p
.002 w
.38885 .2957 m .45241 .27158 L .45471 .29358 L p
1 g
F P
s
P
p
.002 w
.48482 .58659 m .4901 .59294 L .46229 .6011 L p
1 g
F P
s
P
p
.002 w
.46229 .6011 m .45168 .58873 L .48482 .58659 L p
1 g
F P
s
P
p
.002 w
.36974 .43761 m .34325 .476 L .32687 .451 L p
1 g
F P
s
P
p
.002 w
.32687 .451 m .35516 .40879 L .36974 .43761 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51468 .54686 L
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63302 .49807 m .64311 .52547 L .61685 .54431 L p
1 g
F P
s
P
p
.002 w
.64311 .52547 m .63302 .49807 L .65319 .47112 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.52012 .6001 m .50874 .60005 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.53132 .59774 m .52012 .6001 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.5412 .5932 m .53132 .59774 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.50874 .60005 m .49837 .59759 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63718 .41099 m .66848 .44342 L .65319 .47112 L p
1 g
F P
s
P
p
.002 w
.66848 .44342 m .63718 .41099 L .64488 .3801 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.59446 .32465 m .6481 .3514 L .64488 .3801 L p
1 g
F P
s
P
p
.002 w
.6481 .3514 m .59446 .32465 L .59253 .29815 L p
1 g
F P
s
P
p
.002 w
.5487 .58694 m .5412 .5932 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.5487 .58694 m .55302 .57961 L .58513 .57508 L p
1 g
F P
s
P
p
.002 w
.5867 .56001 m .58513 .57508 L .55302 .57961 L p
1 g
F P
s
P
p
.002 w
.58513 .57508 m .5867 .56001 L .61685 .54431 L p
1 g
F P
s
P
p
.002 w
.41999 .5424 m .41474 .56489 L .38439 .55174 L p
1 g
F P
s
P
p
.002 w
.38439 .55174 m .39055 .52256 L .41999 .5424 L p
1 g
F P
s
P
p
.002 w
.59253 .29815 m .5255 .28669 L .522 .26484 L p
1 g
F P
s
P
p
.002 w
.45241 .27158 m .522 .26484 L .5255 .28669 L p
1 g
F P
s
P
p
.002 w
.49837 .59759 m .4901 .59294 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.5255 .28669 m .45471 .29358 L .45241 .27158 L p
1 g
F P
s
P
p
.002 w
.48482 .58659 m .45168 .58873 L p
.48233 .57942 L 1 g
F P
s
P
p
.002 w
.48327 .57973 m .48482 .58659 L p
.48233 .57942 L 1 g
F P
s
P
p
.48921 .57862 m .47709 .57762 L .48327 .57973 L 1 g
F
P
p
.47709 .57762 m .48039 .57878 L .48327 .57973 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.44804 .57416 m .46393 .57302 L .46831 .57455 L 1 g
F
P
p
.002 w
.48039 .57878 m .47345 .57779 L p
.46831 .57455 L 1 g
F P
s
P
p
.002 w
.47345 .57779 m .44804 .57416 L p
.46831 .57455 L 1 g
F P
s
P
p
.002 w
.46831 .57455 m .46872 .57265 L p
.4593 .56889 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57455 L p
1 g
F P
s
P
p
.002 w
.46831 .57455 m .4678 .57686 L p
.47709 .57762 L 1 g
F P
s
P
p
.48921 .57862 m .46831 .57455 L .47709 .57762 L 1 g
F
P
p
.46393 .57302 m .48532 .57149 L .48039 .57878 L 1 g
F
P
p
.002 w
.44804 .57416 m .41474 .56489 L p
.44615 .55985 L 1 g
F P
s
P
p
.44615 .55985 m .45066 .56343 L .44804 .57416 L 1 g
F
P
p
.002 w
.45078 .56353 m .45077 .56357 L p
.45066 .56343 L 1 g
F P
s
P
p
.002 w
.45077 .56357 m .44804 .57416 L p
.45066 .56343 L 1 g
F P
s
P
p
.002 w
.45066 .56343 m .45146 .56129 L p
.44379 .55463 L 1 g
F P
s
P
p
.41999 .5424 m .43578 .54324 L .43849 .54709 L 1 g
F
P
p
.002 w
.44386 .55473 m .4404 .55294 L p
.43849 .54709 L 1 g
F P
s
P
p
.002 w
.4404 .55294 m .41999 .5424 L p
.43849 .54709 L 1 g
F P
s
P
p
.002 w
.43849 .54709 m .43925 .54566 L p
.43579 .53882 L 1 g
F P
s
P
p
.44379 .55463 m .44386 .55473 L .45066 .56343 L 1 g
F
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43825 .54754 L p
1 g
F P
s
P
p
.45146 .56129 m .43825 .54754 L .44377 .55461 L 1 g
F
P
p
.002 w
.45197 .55891 m .45078 .56353 L p
.45066 .56343 L 1 g
F P
s
P
p
.44615 .55985 m .44767 .5596 L .45066 .56343 L 1 g
F
P
p
.44767 .5596 m .45197 .55891 L .45066 .56343 L 1 g
F
P
p
.002 w
.43825 .54754 m .43743 .5491 L p
.44377 .55461 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.43849 .54709 m .46327 .54469 L .44386 .55473 L 1 g
F
P
p
.43578 .54324 m .43726 .54332 L .43849 .54709 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4325 .52874 L p
1 g
F P
s
P
p
.43925 .54566 m .4325 .52874 L .43579 .53882 L 1 g
F
P
p
.43726 .54332 m .46327 .54469 L .43849 .54709 L 1 g
F
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4362 .52126 m .46327 .54469 L p
.43206 .54304 L 1 g
F P
s
P
p
.002 w
.41999 .5424 m .43259 .52597 L p
.43206 .54304 L 1 g
F P
s
P
p
.002 w
.4325 .52874 m .43346 .52734 L p
.43312 .51762 L 1 g
F P
s
P
p
.43312 .51762 m .43309 .51792 L .4325 .52874 L 1 g
F
P
p
.43311 .51742 m .43259 .52597 L .4325 .52874 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.41097 .49492 m .43518 .49925 L .43407 .50919 L 1 g
F
P
p
.002 w
.43308 .518 m .43091 .51573 L p
.43407 .50919 L 1 g
F P
s
P
p
.002 w
.43091 .51573 m .41097 .49492 L p
.43407 .50919 L 1 g
F P
s
P
p
.002 w
.43407 .50919 m .43485 .50826 L p
.4374 .50229 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43407 .50919 L p
1 g
F P
s
P
p
.002 w
.43407 .50919 m .43287 .51061 L p
.43312 .51762 L 1 g
F P
s
P
p
.43346 .52734 m .43407 .50919 L .43312 .51762 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4428 .49113 L p
1 g
F P
s
P
p
.43518 .49925 m .43858 .49986 L .43407 .50919 L 1 g
F
P
p
.43485 .50826 m .4428 .49113 L .4374 .50229 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4428 .49113 m .44339 .4905 L p
.45052 .48367 L 1 g
F P
s
P
p
.45677 .47759 m .49407 .49292 L .45039 .48379 L 1 g
F
P
p
.45052 .48367 m .45063 .48356 L .45039 .48379 L 1 g
F
P
p
.45052 .48367 m .45039 .48379 L .4428 .49113 L 1 g
F
P
p
.002 w
.49407 .49292 m .46185 .50402 L .45039 .48379 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45778 .4766 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45677 .47759 m .45912 .47596 L .49407 .49292 L 1 g
F
P
p
.002 w
.45778 .4766 m .45826 .47608 L p
.4655 .4729 L 1 g
F P
s
P
p
.45912 .47596 m .4776 .46711 L .49407 .49292 L 1 g
F
P
p
.002 w
.4776 .46711 m .47786 .46667 L p
.48949 .46549 L 1 g
F P
s
P
p
.49498 .46459 m .52896 .48941 L .4875 .46581 L 1 g
F
P
p
.48949 .46549 m .49164 .46527 L .4875 .46581 L 1 g
F
P
p
.48949 .46549 m .4875 .46581 L .4776 .46711 L 1 g
F
P
p
.002 w
.52896 .48941 m .49407 .49292 L .4875 .46581 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48554 .4577 m .53076 .45317 L .53048 .45881 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56593 .50919 L p
1 g
F P
s
P
p
.002 w
.5606 .49777 m .5622 .4939 L p
.5636 .50419 L 1 g
F P
s
P
p
.55661 .4905 m .56593 .50919 L .56221 .50121 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56755 .5288 L p
1 g
F P
s
P
p
.002 w
.58977 .50573 m .56795 .53373 L p
.56763 .52986 L 1 g
F P
s
P
p
.56515 .50826 m .56755 .5288 L .56666 .51808 L 1 g
F
P
p
.56716 .53036 m .56763 .52986 L .56767 .53409 L 1 g
F
P
p
.002 w
.56795 .53373 m .56767 .53409 L p
.56763 .52986 L 1 g
F P
s
P
p
.002 w
.57476 .49929 m .58977 .50573 L p
.56763 .52986 L 1 g
F P
s
P
p
.56755 .5288 m .56763 .52986 L .56716 .53036 L 1 g
F
P
p
.57476 .49929 m .56763 .52986 L .56755 .5288 L 1 g
F
P
p
.002 w
.56593 .50919 m .56515 .50826 L p
.56666 .51808 L 1 g
F P
s
P
p
.56654 .52734 m .56432 .5395 L .56436 .53939 L 1 g
F
P
p
.002 w
.56542 .53644 m .56767 .53409 L p
.56374 .54111 L 1 g
F P
s
P
p
.002 w
.56755 .5288 m .56654 .52734 L p
.56436 .53939 L 1 g
F P
s
P
p
.002 w
.58073 .54581 m .5566 .56098 L p
.56318 .545 L 1 g
F P
s
P
p
.002 w
.56767 .53409 m .56984 .53604 L p
.56318 .545 L 1 g
F P
s
P
p
.002 w
.56984 .53604 m .58073 .54581 L p
.56318 .545 L 1 g
F P
s
P
p
.002 w
.56156 .54718 m .56075 .54566 L p
.55515 .55581 L 1 g
F P
s
P
p
.56767 .53409 m .5566 .56098 L .56374 .54111 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56172 .54748 L p
1 g
F P
s
P
p
.002 w
.56172 .54748 m .56257 .5491 L p
.56423 .53998 L 1 g
F P
s
P
p
.56654 .52734 m .56172 .54748 L .56423 .53998 L 1 g
F
P
p
.56436 .53939 m .56624 .53416 L .56755 .5288 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54882 .52628 m .56638 .53356 L p
.54372 .55904 L 1 g
F P
s
P
p
.002 w
.56638 .53356 m .56767 .53409 L .56542 .53644 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56542 .53644 m .54372 .55904 L p
.56638 .53356 L 1 g
F P
s
P
p
.002 w
.5566 .56098 m .55044 .56485 L p
.56374 .54111 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.55364 .57197 m .52618 .57808 L p
.53386 .57389 L 1 g
F P
s
P
p
.002 w
.53171 .57464 m .53128 .57265 L p
.5185 .57921 L 1 g
F P
s
P
p
.002 w
.51866 .57916 m .51883 .57972 L .5184 .57923 L p
1 g
F P
s
P
p
.5185 .57921 m .51848 .57921 L .51854 .5792 L 1 g
F
P
p
.5185 .57921 m .51854 .5792 L .53171 .57464 L 1 g
F
P
p
.51848 .57921 m .51865 .57917 L .53171 .57464 L 1 g
F
P
p
.51844 .57924 m .51892 .57909 L .53171 .57464 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58084 L p
1 g
F P
s
P
p
.50088 .58334 m .50006 .58315 L .51271 .58084 L 1 g
F
P
p
.002 w
.51883 .57972 m .5133 .58083 L p
.51271 .58084 L 1 g
F P
s
P
p
.002 w
.5133 .58083 m .50088 .58334 L p
.51271 .58084 L 1 g
F P
s
P
p
.002 w
.51096 .58084 m .51079 .57862 L p
.49949 .58088 L 1 g
F P
s
P
p
.53128 .57265 m .51096 .58084 L .51644 .57968 L 1 g
F
P
p
.002 w
.51763 .57942 m .51883 .57972 L .51644 .57968 L p
1 g
F P
s
P
p
.51723 .57951 m .51644 .57968 L .51721 .57952 L 1 g
F
P
p
.53128 .57265 m .51644 .57968 L .51723 .57951 L 1 g
F
P
p
.53128 .57265 m .51721 .57952 L .51766 .57941 L 1 g
F
P
p
.002 w
.48904 .58091 m .48921 .57862 L p
.48327 .57973 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58091 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58091 L .49949 .58088 L 1 g
F
P
p
.002 w
.48315 .57917 m .51644 .57968 L p
.51096 .58084 L 1 g
F P
s
P
p
.50006 .58315 m .49053 .58091 L .51096 .58084 L 1 g
F
P
p
.49053 .58091 m .48315 .57917 L .51096 .58084 L 1 g
F
P
p
.002 w
.50088 .58334 m .48482 .58659 L .48327 .57973 L p
1 g
F P
s
P
p
.002 w
.48327 .57973 m .48315 .57917 L p
.50088 .58334 L 1 g
F P
s
P
p
.002 w
.48904 .58091 m .48889 .583 L p
.49949 .58088 L 1 g
F P
s
P
p
.002 w
.48315 .57917 m .48532 .57149 L .51763 .57942 L p
1 g
F P
s
P
p
.002 w
.51644 .57968 m .48315 .57917 L p
.51763 .57942 L 1 g
F P
s
P
p
.53128 .57265 m .51763 .57943 L .51849 .57921 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48532 .57149 m .49116 .56439 L .5181 .57931 L p
1 g
F P
s
P
p
.002 w
.5181 .57931 m .51883 .57972 L .51763 .57942 L p
1 g
F P
s
P
p
.002 w
.51763 .57942 m .48532 .57149 L p
.5181 .57931 L 1 g
F P
s
P
p
.51766 .57941 m .51721 .57952 L .51763 .57943 L 1 g
F
P
p
.002 w
.5184 .57923 m .51883 .57972 L .5181 .57931 L p
1 g
F P
s
P
p
.51849 .57921 m .51763 .57943 L .51837 .57927 L 1 g
F
P
p
.002 w
.49116 .56439 m .50006 .55868 L .5184 .57923 L p
1 g
F P
s
P
p
.002 w
.5181 .57931 m .49116 .56439 L p
.5184 .57923 L 1 g
F P
s
P
p
.002 w
.51644 .57968 m .51883 .57972 L p
.50006 .58315 L 1 g
F P
s
P
p
.002 w
.4901 .59294 m .48482 .58659 L .5133 .58083 L p
1 g
F P
s
P
p
.002 w
.5133 .58083 m .51883 .57972 L .51647 .5808 L p
1 g
F P
s
P
p
.002 w
.51647 .5808 m .4901 .59294 L p
.5133 .58083 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58086 L p
1 g
F P
s
P
p
.002 w
.51096 .58086 m .51096 .58084 L p
.51079 .58086 L 1 g
F P
s
P
p
.51079 .58086 m .48889 .583 L .51096 .58086 L 1 g
F
P
p
.49949 .58088 m .48889 .583 L .51096 .58084 L 1 g
F
P
p
.002 w
.51096 .58084 m .51111 .583 L p
.51837 .57927 L 1 g
F P
s
P
p
.002 w
.50006 .55868 m .51104 .555 L .51866 .57916 L p
1 g
F P
s
P
p
.002 w
.5184 .57923 m .50006 .55868 L p
.51866 .57916 L 1 g
F P
s
P
p
.002 w
.51893 .57908 m .51883 .57972 L .51866 .57916 L p
1 g
F P
s
P
p
.51835 .57928 m .51973 .57882 L .53171 .57464 L 1 g
F
P
p
.002 w
.51104 .555 m .52286 .5538 L .51893 .57908 L p
1 g
F P
s
P
p
.002 w
.51866 .57916 m .51104 .555 L p
.51893 .57908 L 1 g
F P
s
P
p
.51848 .57921 m .51844 .57924 L .51865 .57917 L 1 g
F
P
p
.51844 .57924 m .51835 .57928 L .51892 .57909 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52286 .5538 m .53418 .5552 L .5193 .57896 L p
1 g
F P
s
P
p
.002 w
.5193 .57896 m .51883 .57972 L .51893 .57908 L p
1 g
F P
s
P
p
.002 w
.51893 .57908 m .52286 .5538 L p
.5193 .57896 L 1 g
F P
s
P
p
.51825 .57934 m .52352 .57751 L .53171 .57464 L 1 g
F
P
p
.002 w
.53418 .5552 m .54372 .55904 L .52003 .57872 L p
1 g
F P
s
P
p
.002 w
.52003 .57872 m .51883 .57972 L .5193 .57896 L p
1 g
F P
s
P
p
.002 w
.5193 .57896 m .53418 .5552 L p
.52003 .57872 L 1 g
F P
s
P
p
.51835 .57928 m .51825 .57934 L .51973 .57882 L 1 g
F
P
p
.51825 .57934 m .51813 .5794 L .52352 .57751 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57464 L p
1 g
F P
s
P
p
.54854 .56129 m .53171 .57464 L .53216 .57437 L 1 g
F
P
p
.002 w
.54917 .56375 m .54922 .56379 L p
.53825 .57058 L 1 g
F P
s
P
p
.002 w
.54922 .56379 m .55044 .56485 L .54651 .5667 L p
1 g
F P
s
P
p
.002 w
.54651 .5667 m .53825 .57058 L p
.54922 .56379 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54939 .56357 L p
1 g
F P
s
P
p
.56075 .54566 m .54939 .56357 L .54961 .56327 L 1 g
F
P
p
.002 w
.55044 .56485 m .54922 .56379 L p
.54939 .56357 L 1 g
F P
s
P
p
.55535 .55555 m .55241 .56112 L .54939 .56357 L 1 g
F
P
p
.55241 .56112 m .55044 .56485 L .54939 .56357 L 1 g
F
P
p
.002 w
.55044 .56485 m .5517 .56765 L p
.53386 .57389 L 1 g
F P
s
P
p
.002 w
.5517 .56765 m .55364 .57197 L p
.53386 .57389 L 1 g
F P
s
P
p
.002 w
.53825 .57058 m .55044 .56485 L p
.52618 .57808 L 1 g
F P
s
P
p
.002 w
.52618 .57808 m .55364 .57197 L p
.52352 .5797 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .53633 .57415 L p
.54854 .56129 L 1 g
F P
s
P
p
.002 w
.54939 .56357 m .54854 .56129 L p
.53633 .57415 L 1 g
F P
s
P
p
.55515 .55581 m .5494 .5636 L .55295 .5598 L 1 g
F
P
p
.56075 .54566 m .54961 .56327 L .55515 .55581 L 1 g
F
P
p
.54961 .56327 m .5494 .5636 L .55515 .55581 L 1 g
F
P
p
.54854 .56129 m .53199 .5745 L .53982 .5696 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54922 .56379 m .54372 .55904 L p
.55535 .55555 L 1 g
F P
s
P
p
.002 w
.53633 .57415 m .54998 .56518 L .54939 .56357 L p
1 g
F P
s
P
p
.002 w
.54372 .55904 m .56542 .53644 L p
.55535 .55555 L 1 g
F P
s
P
p
.002 w
.54939 .56357 m .5494 .5636 L p
.54961 .56327 L 1 g
F P
s
P
p
.002 w
.5494 .5636 m .54998 .56518 L p
.55295 .5598 L 1 g
F P
s
P
p
.53982 .5696 m .53173 .57471 L .53926 .57013 L 1 g
F
P
p
.53199 .5745 m .53173 .57471 L .53982 .5696 L 1 g
F
P
p
.002 w
.54372 .55904 m .54917 .56375 L p
.52352 .57751 L 1 g
F P
s
P
p
.002 w
.53825 .57058 m .52352 .57751 L p
.54917 .56375 L 1 g
F P
s
P
p
.002 w
.52352 .57751 m .51883 .57972 L .52003 .57872 L p
1 g
F P
s
P
p
.002 w
.52003 .57872 m .54372 .55904 L p
.52352 .57751 L 1 g
F P
s
P
p
.002 w
.52618 .57808 m .51883 .57972 L .53825 .57058 L p
1 g
F P
s
P
p
.002 w
.52352 .5797 m .51883 .57972 L .52618 .57808 L p
1 g
F P
s
P
p
.002 w
.55302 .57961 m .5487 .58694 L .51883 .57972 L closepath p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53171 .57464 L p
1 g
F P
s
P
p
.51813 .5794 m .51111 .583 L .53171 .57464 L 1 g
F
P
p
.002 w
.53171 .57464 m .53173 .57471 L p
.53216 .57437 L 1 g
F P
s
P
p
.002 w
.53173 .57471 m .5322 .57686 L p
.53926 .57013 L 1 g
F P
s
P
p
.002 w
.55364 .57197 m .55302 .57961 L .52352 .5797 L p
1 g
F P
s
P
p
.56374 .54111 m .55044 .56485 L .56542 .53644 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56156 .54718 L p
1 g
F P
s
P
p
.55515 .55581 m .54998 .56518 L .56156 .54718 L 1 g
F
P
p
.56436 .53939 m .56265 .54884 L .56624 .53416 L 1 g
F
P
p
.002 w
.56257 .5491 m .56265 .54884 L p
.56436 .53939 L 1 g
F P
s
P
p
.56432 .5395 m .56257 .5491 L .56436 .53939 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5622 .4939 m .56477 .49501 L p
.56569 .50868 L 1 g
F P
s
P
p
.5622 .4939 m .56569 .50868 L .5636 .50419 L 1 g
F
P
p
.002 w
.56477 .49501 m .57476 .49929 L p
.56755 .5288 L 1 g
F P
s
P
p
.56477 .49501 m .56755 .5288 L .56716 .53036 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5622 .4939 m .55849 .4934 L p
.55678 .49003 L 1 g
F P
s
P
p
.55661 .4905 m .56221 .50121 L .5606 .49777 L 1 g
F
P
p
.002 w
.55849 .4934 m .5622 .4939 L .5606 .49777 L p
1 g
F P
s
P
p
.002 w
.5578 .49176 m .55758 .49153 L p
.5606 .49777 L 1 g
F P
s
P
p
.002 w
.55758 .49153 m .55661 .4905 L p
.5606 .49777 L 1 g
F P
s
P
p
.002 w
.52896 .48941 m .55849 .4934 L p
.54882 .52628 L 1 g
F P
s
P
p
.002 w
.5606 .49777 m .54882 .52628 L p
.55849 .4934 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55749 .49144 L p
1 g
F P
s
P
p
.002 w
.52896 .48941 m .52989 .4708 L p
.55399 .48803 L 1 g
F P
s
P
p
.55399 .48803 m .55602 .49001 L .52896 .48941 L 1 g
F
P
p
.54174 .47608 m .55749 .49144 L .54863 .48282 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55849 .4934 m .52896 .48941 L p
.55602 .49001 L 1 g
F P
s
P
p
.55678 .49003 m .55749 .49144 L .55602 .49001 L 1 g
F
P
p
.55749 .49144 m .55849 .4934 L .55602 .49001 L 1 g
F
P
p
.002 w
.55834 .49233 m .5578 .49176 L p
.56363 .50354 L 1 g
F P
s
P
p
.56221 .50121 m .56713 .51061 L .5578 .49176 L 1 g
F
P
p
.002 w
.54218 .47656 m .54174 .47608 L p
.54863 .48282 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.55257 .48143 m .5622 .4939 L .52989 .4708 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54218 .47656 L p
1 g
F P
s
P
p
.54863 .48282 m .55834 .49233 L .54218 .47656 L 1 g
F
P
p
.002 w
.55749 .49144 m .55834 .49233 L p
.54863 .48282 L 1 g
F P
s
P
p
.55399 .48803 m .55678 .49003 L .55602 .49001 L 1 g
F
P
p
.002 w
.56713 .51061 m .56554 .50732 L p
.56363 .50354 L 1 g
F P
s
P
p
.002 w
.56554 .50732 m .55834 .49233 L p
.56363 .50354 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.5636 .50419 m .56569 .50868 L .56716 .53036 L 1 g
F
P
p
.002 w
.56767 .53409 m .54882 .52628 L .5606 .49777 L p
1 g
F P
s
P
p
.5636 .50419 m .56767 .53409 L .5606 .49777 L 1 g
F
P
p
.002 w
.56265 .54884 m .56854 .53025 L .56755 .5288 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56593 .50919 L p
1 g
F P
s
P
p
.56666 .51808 m .56854 .53025 L .56593 .50919 L 1 g
F
P
p
.002 w
.56755 .5288 m .56854 .53025 L p
.56666 .51808 L 1 g
F P
s
P
p
.002 w
.58073 .54581 m .56767 .53409 L .58977 .50573 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56265 .54884 L p
.5644 .55256 L 1 g
F P
s
P
p
.002 w
.56265 .54884 m .56257 .5491 L .56258 .54912 L p
1 g
F P
s
P
p
.002 w
.56258 .54912 m .5644 .55256 L p
.56265 .54884 L 1 g
F P
s
P
p
.002 w
.56593 .50919 m .56713 .51061 L p
.56221 .50121 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54218 .47656 L p
1 g
F P
s
P
p
.52214 .46667 m .54218 .47656 L .53454 .47298 L 1 g
F
P
p
.52214 .46667 m .54269 .47712 L .53475 .4732 L 1 g
F
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52989 .4708 m .52896 .48941 L p
.51431 .46589 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46709 L p
1 g
F P
s
P
p
.5 .4634 m .52239 .46709 L .50848 .46503 L 1 g
F
P
p
.51179 .46185 m .52239 .46709 L .51431 .46589 L 1 g
F
P
p
.52239 .46709 m .52989 .4708 L .51431 .46589 L 1 g
F
P
p
.49498 .46459 m .5 .46377 L .52896 .48941 L 1 g
F
P
p
.002 w
.5 .46377 m .5 .4634 L p
.50848 .46503 L 1 g
F P
s
P
p
.5 .46377 m .51179 .46185 L .51431 .46589 L 1 g
F
P
p
.5 .46377 m .51431 .46589 L .52896 .48941 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46377 L p
1 g
F P
s
P
p
.50848 .46503 m .52282 .46778 L .5 .46377 L 1 g
F
P
p
.002 w
.52239 .46709 m .52282 .46778 L p
.50848 .46503 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52989 .4708 m .53076 .45317 L p
.55257 .48143 L 1 g
F P
s
P
p
.002 w
.54218 .47656 m .54269 .47712 L p
.53454 .47298 L 1 g
F P
s
P
p
.002 w
.54269 .47712 m .54302 .47747 L p
.53475 .4732 L 1 g
F P
s
P
p
.002 w
.53048 .45881 m .52989 .4708 L p
.51179 .46185 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46377 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46377 L .49207 .46507 L 1 g
F
P
p
.48554 .4577 m .53048 .45881 L .49498 .46459 L 1 g
F
P
p
.002 w
.5 .46377 m .5 .46417 L p
.49207 .46507 L 1 g
F P
s
P
p
.002 w
.5 .46417 m .5 .46442 L p
.49164 .46527 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46417 L .49164 .46527 L 1 g
F
P
p
.002 w
.48554 .4577 m .48675 .46272 L p
.4776 .46711 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4776 .46711 L p
1 g
F P
s
P
p
.002 w
.4776 .46711 m .47718 .46778 L p
.4655 .4729 L 1 g
F P
s
P
p
.45826 .47608 m .4776 .46711 L .4655 .4729 L 1 g
F
P
p
.45912 .47596 m .47059 .46803 L .4776 .46711 L 1 g
F
P
p
.47059 .46803 m .48554 .4577 L .4776 .46711 L 1 g
F
P
p
.002 w
.4875 .46581 m .48554 .4577 L p
.49498 .46459 L 1 g
F P
s
P
p
.002 w
.48675 .46272 m .4875 .46581 L p
.4776 .46711 L 1 g
F P
s
P
p
.002 w
.4875 .46581 m .49407 .49292 L p
.4776 .46711 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .4776 .46711 L p
1 g
F P
s
P
p
.49164 .46527 m .5 .46442 L .4776 .46711 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.47253 .46225 m .48554 .4577 L p
.45677 .47759 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45778 .4766 L p
1 g
F P
s
P
p
.4655 .4729 m .47718 .46778 L .45778 .4766 L 1 g
F
P
p
.002 w
.45778 .4766 m .45698 .47747 L p
.45052 .48367 L 1 g
F P
s
P
p
.44339 .4905 m .45778 .4766 L .45052 .48367 L 1 g
F
P
p
.002 w
.44388 .47229 m .47253 .46225 L p
.45677 .47759 L 1 g
F P
s
P
p
.002 w
.45039 .48379 m .44388 .47229 L p
.45677 .47759 L 1 g
F P
s
P
p
.002 w
.41097 .49492 m .44388 .47229 L .45039 .48379 L p
1 g
F P
s
P
p
.002 w
.45039 .48379 m .46185 .50402 L p
.43451 .49913 L 1 g
F P
s
P
p
.41097 .49492 m .45039 .48379 L .43451 .49913 L 1 g
F
P
p
.002 w
.4428 .49113 m .44166 .49233 L p
.4374 .50229 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4428 .49113 L p
1 g
F P
s
P
p
.45063 .48356 m .45698 .47747 L .4428 .49113 L 1 g
F
P
p
.43407 .50919 m .46185 .50402 L .43308 .518 L 1 g
F
P
p
.43858 .49986 m .46185 .50402 L .43407 .50919 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43407 .50919 L p
1 g
F P
s
P
p
.4374 .50229 m .44166 .49233 L .43407 .50919 L 1 g
F
P
p
.002 w
.46185 .50402 m .4362 .52126 L .43308 .518 L p
1 g
F P
s
P
p
.43312 .51762 m .43311 .51742 L .43309 .51792 L 1 g
F
P
p
.002 w
.41999 .5424 m .39055 .52256 L p
.43287 .52135 L 1 g
F P
s
P
p
.002 w
.43259 .52597 m .41999 .5424 L p
.43287 .52135 L 1 g
F P
s
P
p
.002 w
.39055 .52256 m .41097 .49492 L .43308 .518 L p
1 g
F P
s
P
p
.002 w
.43308 .518 m .4362 .52126 L p
.43287 .52135 L 1 g
F P
s
P
p
.39055 .52256 m .43308 .518 L .43287 .52135 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43241 .52887 L p
1 g
F P
s
P
p
.002 w
.43241 .52887 m .4325 .52874 L p
.43254 .52667 L 1 g
F P
s
P
p
.43254 .52667 m .43287 .51061 L .43241 .52887 L 1 g
F
P
p
.43311 .51742 m .43297 .51344 L .43259 .52597 L 1 g
F
P
p
.002 w
.4362 .52126 m .43259 .52597 L p
.43287 .52135 L 1 g
F P
s
P
p
.002 w
.43259 .52597 m .4362 .52126 L p
.43206 .54304 L 1 g
F P
s
P
p
.43297 .51344 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.002 w
.4325 .52874 m .43146 .53025 L p
.43579 .53882 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43849 .54709 L p
1 g
F P
s
P
p
.43579 .53882 m .43146 .53025 L .43849 .54709 L 1 g
F
P
p
.44379 .55463 m .44377 .55461 L .44386 .55473 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46327 .54469 m .45197 .55891 L .44386 .55473 L p
1 g
F P
s
P
p
.002 w
.41474 .56489 m .41999 .5424 L .45197 .55891 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45066 .56343 L p
1 g
F P
s
P
p
.44377 .55461 m .43743 .5491 L .45066 .56343 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45066 .56345 L p
1 g
F P
s
P
p
.002 w
.44804 .57416 m .45078 .56353 L p
.46567 .5729 L 1 g
F P
s
P
p
.002 w
.45066 .56345 m .45002 .56518 L p
.4593 .56889 L 1 g
F P
s
P
p
.46872 .57265 m .45066 .56345 L .4593 .56889 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45197 .55891 m .48532 .57149 L p
.46567 .5729 L 1 g
F P
s
P
p
.002 w
.45078 .56353 m .45197 .55891 L p
.46567 .5729 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .46831 .57455 L p
.45802 .56928 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4664 .57594 L p
.45802 .56928 L 1 g
F P
s
P
p
.002 w
.4664 .57594 m .4678 .57686 L p
.45802 .56928 L 1 g
F P
s
P
p
.4593 .56889 m .45002 .56518 L .46831 .57455 L 1 g
F
P
p
.002 w
.48532 .57149 m .48315 .57917 L .48039 .57878 L p
1 g
F P
s
P
p
.47709 .57762 m .47683 .5776 L .48039 .57878 L 1 g
F
P
p
.002 w
.48899 .58162 m .48904 .58091 L p
.48327 .57973 L 1 g
F P
s
P
p
.002 w
.45168 .58873 m .44804 .57416 L .48315 .57917 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58162 L p
1 g
F P
s
P
p
.47683 .5776 m .4678 .57686 L .48899 .58162 L 1 g
F
P
p
.002 w
.48315 .57917 m .48327 .57973 L p
.48233 .57942 L 1 g
F P
s
P
p
.002 w
.38855 .46669 m .36468 .50015 L .34325 .476 L p
1 g
F P
s
P
p
.002 w
.34325 .476 m .36974 .43761 L .38855 .46669 L p
1 g
F P
s
P
p
.002 w
.60859 .52327 m .61685 .54431 L .5867 .56001 L p
1 g
F P
s
P
p
.002 w
.61685 .54431 m .60859 .52327 L .63302 .49807 L p
1 g
F P
s
P
p
.002 w
.40254 .37392 m .35516 .40879 L .34522 .38124 L p
1 g
F P
s
P
p
.002 w
.34522 .38124 m .39461 .34423 L .40254 .37392 L p
1 g
F P
s
P
p
.002 w
.5255 .28669 m .59253 .29815 L .59446 .32465 L p
1 g
F P
s
P
p
.002 w
.62517 .44301 m .65319 .47112 L .63302 .49807 L p
1 g
F P
s
P
p
.002 w
.65319 .47112 m .62517 .44301 L .63718 .41099 L p
1 g
F P
s
P
p
.002 w
.55302 .57961 m .55364 .57197 L .5867 .56001 L p
1 g
F P
s
P
p
.002 w
.45848 .32048 m .39461 .34423 L .39004 .3179 L p
1 g
F P
s
P
p
.002 w
.39004 .3179 m .45471 .29358 L .45848 .32048 L p
1 g
F P
s
P
p
.002 w
.58073 .54581 m .5867 .56001 L .55364 .57197 L p
1 g
F P
s
P
p
.002 w
.5867 .56001 m .58073 .54581 L .60859 .52327 L p
1 g
F P
s
P
p
.002 w
.59354 .35511 m .64488 .3801 L .63718 .41099 L p
1 g
F P
s
P
p
.002 w
.64488 .3801 m .59354 .35511 L .59446 .32465 L p
1 g
F P
s
P
p
.002 w
.41097 .49492 m .39055 .52256 L .36468 .50015 L p
1 g
F P
s
P
p
.002 w
.36468 .50015 m .38855 .46669 L .41097 .49492 L p
1 g
F P
s
P
p
.002 w
.55364 .57197 m .55044 .56485 L .58073 .54581 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.60918 .47499 m .63302 .49807 L .60859 .52327 L p
1 g
F P
s
P
p
.002 w
.63302 .49807 m .60918 .47499 L .62517 .44301 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.41365 .40596 m .36974 .43761 L .35516 .40879 L p
1 g
F P
s
P
p
.002 w
.35516 .40879 m .40254 .37392 L .41365 .40596 L p
1 g
F P
s
P
p
.002 w
.59446 .32465 m .52833 .31366 L .5255 .28669 L p
1 g
F P
s
P
p
.002 w
.45471 .29358 m .5255 .28669 L .52833 .31366 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.52833 .31366 m .45848 .32048 L .45471 .29358 L p
1 g
F P
s
P
p
.002 w
.58977 .50573 m .60859 .52327 L .58073 .54581 L p
1 g
F P
s
P
p
.002 w
.60859 .52327 m .58977 .50573 L .60918 .47499 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.52833 .31366 m .59446 .32465 L .59354 .35511 L p
1 g
F P
s
P
p
.002 w
.49116 .56439 m .48532 .57149 L .45197 .55891 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.58971 .38851 m .63718 .41099 L .62517 .44301 L p
1 g
F P
s
P
p
.002 w
.63718 .41099 m .58971 .38851 L .59354 .35511 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45197 .55891 m .46327 .54469 L .49116 .56439 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46363 .3515 m .40254 .37392 L .39461 .34423 L p
1 g
F P
s
P
p
.002 w
.39461 .34423 m .45848 .32048 L .46363 .3515 L p
1 g
F P
s
P
p
.002 w
.54372 .55904 m .53418 .5552 L .54882 .52628 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50006 .55868 m .49116 .56439 L .46327 .54469 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.4276 .43917 m .38855 .46669 L .36974 .43761 L p
1 g
F P
s
P
p
.002 w
.36974 .43761 m .41365 .40596 L .4276 .43917 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.53418 .5552 m .52286 .5538 L .52628 .52336 L p
1 g
F P
s
P
p
.002 w
.52628 .52336 m .54882 .52628 L .53418 .5552 L p
1 g
F P
s
P
p
.002 w
.51104 .555 m .50006 .55868 L .48083 .53317 L p
1 g
F P
s
P
p
.002 w
.46327 .54469 m .48083 .53317 L .50006 .55868 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58305 .42368 m .62517 .44301 L .60918 .47499 L p
1 g
F P
s
P
p
.002 w
.62517 .44301 m .58305 .42368 L .58971 .38851 L p
1 g
F P
s
P
p
.002 w
.52286 .5538 m .51104 .555 L .50268 .52575 L p
1 g
F P
s
P
p
.002 w
.50268 .52575 m .52628 .52336 L .52286 .5538 L p
1 g
F P
s
P
p
.002 w
.48083 .53317 m .50268 .52575 L .51104 .555 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59354 .35511 m .53036 .34495 L .52833 .31366 L p
1 g
F P
s
P
p
.002 w
.45848 .32048 m .52833 .31366 L .53036 .34495 L p
1 g
F P
s
P
p
.002 w
.53036 .34495 m .59354 .35511 L .58971 .38851 L p
1 g
F P
s
P
p
.002 w
.48083 .53317 m .46327 .54469 L .4362 .52126 L p
1 g
F P
s
P
p
.002 w
.57376 .45927 m .60918 .47499 L .58977 .50573 L p
1 g
F P
s
P
p
.002 w
.60918 .47499 m .57376 .45927 L .58305 .42368 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53036 .34495 m .46363 .3515 L .45848 .32048 L p
1 g
F P
s
P
p
.002 w
.44388 .47229 m .41097 .49492 L .38855 .46669 L p
1 g
F P
s
P
p
.002 w
.38855 .46669 m .4276 .43917 L .44388 .47229 L p
1 g
F P
s
P
p
.002 w
.58977 .50573 m .5622 .4939 L .57376 .45927 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.47001 .38558 m .41365 .40596 L .40254 .37392 L p
1 g
F P
s
P
p
.002 w
.40254 .37392 m .46363 .3515 L .47001 .38558 L p
1 g
F P
s
P
p
.002 w
.4362 .52126 m .46185 .50402 L .48083 .53317 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54882 .52628 m .52628 .52336 L .52896 .48941 L p
1 g
F P
s
P
p
.002 w
.50268 .52575 m .48083 .53317 L .46185 .50402 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53147 .3795 m .58971 .38851 L .58305 .42368 L p
1 g
F P
s
P
p
.002 w
.58971 .38851 m .53147 .3795 L .53036 .34495 L p
1 g
F P
s
P
p
.002 w
.52628 .52336 m .50268 .52575 L .49407 .49292 L p
1 g
F P
s
P
p
.002 w
.49407 .49292 m .52896 .48941 L .52628 .52336 L p
1 g
F P
s
P
p
.002 w
.46185 .50402 m .49407 .49292 L .50268 .52575 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46363 .3515 m .53036 .34495 L .53147 .3795 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47741 .42144 m .4276 .43917 L .41365 .40596 L p
1 g
F P
s
P
p
.002 w
.41365 .40596 m .47001 .38558 L .47741 .42144 L p
1 g
F P
s
P
p
.002 w
.53076 .45317 m .57376 .45927 L .5622 .4939 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53147 .3795 m .47001 .38558 L .46363 .3515 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.53161 .41605 m .58305 .42368 L .57376 .45927 L p
1 g
F P
s
P
p
.002 w
.58305 .42368 m .53161 .41605 L .53147 .3795 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.52515 .62978 m
.52649 .64038 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57376 .45927 m .53076 .45317 L .53161 .41605 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.48554 .4577 m .44388 .47229 L .4276 .43917 L p
1 g
F P
s
P
p
.002 w
.4276 .43917 m .47741 .42144 L .48554 .4577 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.47001 .38558 m .53147 .3795 L .53161 .41605 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53161 .41605 m .47741 .42144 L .47001 .38558 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53076 .45317 m .48554 .4577 L .47741 .42144 L p
1 g
F P
s
P
p
.002 w
.47741 .42144 m .53161 .41605 L .53076 .45317 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .57535 .70384 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .5298 .66663 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.52093)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.52093)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44968 .45756 m .4961 .46828 L .49925 .44006 L p
1 g
F P
s
P
p
.002 w
.49925 .44006 m .45859 .43058 L .44968 .45756 L p
1 g
F P
s
P
p
.002 w
.54099 .43976 m .49925 .44006 L .4961 .46828 L p
1 g
F P
s
P
p
.002 w
.45859 .43058 m .49925 .44006 L .50241 .41168 L p
1 g
F P
s
P
p
.002 w
.49925 .44006 m .54099 .43976 L .53726 .41134 L p
1 g
F P
s
P
p
.002 w
.53726 .41134 m .50241 .41168 L .49925 .44006 L p
1 g
F P
s
P
p
.002 w
.50241 .41168 m .46848 .40368 L .45859 .43058 L p
1 g
F P
s
P
p
.002 w
.46848 .40368 m .50241 .41168 L .50553 .38362 L p
1 g
F P
s
P
p
.002 w
.50241 .41168 m .53726 .41134 L .53262 .3833 L p
1 g
F P
s
P
p
.002 w
.53262 .3833 m .50553 .38362 L .50241 .41168 L p
1 g
F P
s
P
p
.002 w
.44192 .48413 m .49302 .49582 L .4961 .46828 L p
1 g
F P
s
P
p
.002 w
.4961 .46828 m .44968 .45756 L .44192 .48413 L p
1 g
F P
s
P
p
.002 w
.54373 .46804 m .4961 .46828 L .49302 .49582 L p
1 g
F P
s
P
p
.002 w
.4961 .46828 m .54373 .46804 L .54099 .43976 L p
1 g
F P
s
P
p
.002 w
.4227 .41206 m .45859 .43058 L .46848 .40368 L p
1 g
F P
s
P
p
.002 w
.46848 .40368 m .43864 .38803 L .4227 .41206 L p
1 g
F P
s
P
p
.002 w
.43864 .38803 m .46848 .40368 L .47916 .37735 L p
1 g
F P
s
P
p
.002 w
.50553 .38362 m .47916 .37735 L .46848 .40368 L p
1 g
F P
s
P
p
.002 w
.40857 .43668 m .44968 .45756 L .45859 .43058 L p
1 g
F P
s
P
p
.002 w
.45859 .43058 m .4227 .41206 L .40857 .43668 L p
1 g
F P
s
P
p
.002 w
.56978 .40264 m .53726 .41134 L .54099 .43976 L p
1 g
F P
s
P
p
.002 w
.53726 .41134 m .56978 .40264 L .55783 .37638 L p
1 g
F P
s
P
p
.002 w
.55783 .37638 m .53262 .3833 L .53726 .41134 L p
1 g
F P
s
P
p
.002 w
.58004 .42958 m .54099 .43976 L .54373 .46804 L p
1 g
F P
s
P
p
.002 w
.54099 .43976 m .58004 .42958 L .56978 .40264 L p
1 g
F P
s
P
p
.002 w
.47916 .37735 m .50553 .38362 L .50854 .35642 L p
1 g
F P
s
P
p
.002 w
.50553 .38362 m .53262 .3833 L .52714 .35616 L p
1 g
F P
s
P
p
.002 w
.52714 .35616 m .50854 .35642 L .50553 .38362 L p
1 g
F P
s
P
p
.002 w
.47916 .37735 m .45607 .36505 L .43864 .38803 L p
1 g
F P
s
P
p
.002 w
.45607 .36505 m .47916 .37735 L .49045 .35207 L p
1 g
F P
s
P
p
.002 w
.50854 .35642 m .49045 .35207 L .47916 .37735 L p
1 g
F P
s
P
p
.002 w
.39652 .46144 m .44192 .48413 L .44968 .45756 L p
1 g
F P
s
P
p
.002 w
.44968 .45756 m .40857 .43668 L .39652 .46144 L p
1 g
F P
s
P
p
.002 w
.53262 .3833 m .55783 .37638 L .54439 .3513 L p
1 g
F P
s
P
p
.002 w
.54439 .3513 m .52714 .35616 L .53262 .3833 L p
1 g
F P
s
P
p
.002 w
.58839 .45672 m .54373 .46804 L .54542 .49567 L p
1 g
F P
s
P
p
.002 w
.49302 .49582 m .54542 .49567 L .54373 .46804 L p
1 g
F P
s
P
p
.002 w
.54373 .46804 m .58839 .45672 L .58004 .42958 L p
1 g
F P
s
P
p
.002 w
.43546 .50978 m .49006 .52216 L .49302 .49582 L p
1 g
F P
s
P
p
.002 w
.49302 .49582 m .44192 .48413 L .43546 .50978 L p
1 g
F P
s
P
p
.002 w
.54542 .49567 m .49302 .49582 L .49006 .52216 L p
1 g
F P
s
P
p
.002 w
.49045 .35207 m .50854 .35642 L .5114 .33058 L p
1 g
F P
s
P
p
.002 w
.50854 .35642 m .52714 .35616 L .52091 .33043 L p
1 g
F P
s
P
p
.002 w
.52091 .33043 m .5114 .33058 L .50854 .35642 L p
1 g
F P
s
P
p
.002 w
.39506 .38598 m .4227 .41206 L .43864 .38803 L p
1 g
F P
s
P
p
.002 w
.43864 .38803 m .41585 .36605 L .39506 .38598 L p
1 g
F P
s
P
p
.002 w
.41585 .36605 m .43864 .38803 L .45607 .36505 L p
1 g
F P
s
P
p
.002 w
.5968 .3862 m .56978 .40264 L .58004 .42958 L p
1 g
F P
s
P
p
.002 w
.56978 .40264 m .5968 .3862 L .57862 .36341 L p
1 g
F P
s
P
p
.002 w
.57862 .36341 m .55783 .37638 L .56978 .40264 L p
1 g
F P
s
P
p
.002 w
.45607 .36505 m .4386 .34782 L .41585 .36605 L p
1 g
F P
s
P
p
.002 w
.4386 .34782 m .45607 .36505 L .47468 .34354 L p
1 g
F P
s
P
p
.002 w
.49045 .35207 m .47468 .34354 L .45607 .36505 L p
1 g
F P
s
P
p
.002 w
.47468 .34354 m .49045 .35207 L .50214 .32834 L p
1 g
F P
s
P
p
.002 w
.5114 .33058 m .50214 .32834 L .49045 .35207 L p
1 g
F P
s
P
p
.002 w
.38685 .48585 m .43546 .50978 L .44192 .48413 L p
1 g
F P
s
P
p
.002 w
.44192 .48413 m .39652 .46144 L .38685 .48585 L p
1 g
F P
s
P
p
.002 w
.52714 .35616 m .54439 .3513 L .5297 .32789 L p
1 g
F P
s
P
p
.002 w
.5297 .32789 m .52091 .33043 L .52714 .35616 L p
1 g
F P
s
P
p
.002 w
.55783 .37638 m .57862 .36341 L .5585 .34228 L p
1 g
F P
s
P
p
.002 w
.5585 .34228 m .54439 .3513 L .55783 .37638 L p
1 g
F P
s
P
p
.002 w
.59466 .48352 m .54542 .49567 L .54603 .52211 L p
1 g
F P
s
P
p
.002 w
.49006 .52216 m .54603 .52211 L .54542 .49567 L p
1 g
F P
s
P
p
.002 w
.54542 .49567 m .59466 .48352 L .58839 .45672 L p
1 g
F P
s
P
p
.002 w
.37666 .40723 m .40857 .43668 L .4227 .41206 L p
1 g
F P
s
P
p
.002 w
.4227 .41206 m .39506 .38598 L .37666 .40723 L p
1 g
F P
s
P
p
.002 w
.61269 .41022 m .58004 .42958 L .58839 .45672 L p
1 g
F P
s
P
p
.002 w
.58004 .42958 m .61269 .41022 L .5968 .3862 L p
1 g
F P
s
P
p
.002 w
.47468 .34354 m .46286 .33163 L .4386 .34782 L p
1 g
F P
s
P
p
.002 w
.46286 .33163 m .47468 .34354 L .49412 .32393 L p
1 g
F P
s
P
p
.002 w
.50214 .32834 m .49412 .32393 L .47468 .34354 L p
1 g
F P
s
P
p
.002 w
.54439 .3513 m .5585 .34228 L .53684 .32323 L p
1 g
F P
s
P
p
.002 w
.53684 .32323 m .5297 .32789 L .54439 .3513 L p
1 g
F P
s
P
p
.002 w
.36109 .4294 m .39652 .46144 L .40857 .43668 L p
1 g
F P
s
P
p
.002 w
.40857 .43668 m .37666 .40723 L .36109 .4294 L p
1 g
F P
s
P
p
.002 w
.43048 .534 m .48729 .54677 L .49006 .52216 L p
1 g
F P
s
P
p
.002 w
.49006 .52216 m .43546 .50978 L .43048 .534 L p
1 g
F P
s
P
p
.002 w
.54603 .52211 m .49006 .52216 L .48729 .54677 L p
1 g
F P
s
P
p
.002 w
.62593 .435 m .58839 .45672 L .59466 .48352 L p
1 g
F P
s
P
p
.002 w
.58839 .45672 m .62593 .435 L .61269 .41022 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .50214 .32834 L .5114 .33058 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .5114 .33058 L .52091 .33043 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .49412 .32393 L .50214 .32834 L closepath p
1 g
F P
s
P
p
.002 w
.37982 .50942 m .43048 .534 L .43546 .50978 L p
1 g
F P
s
P
p
.002 w
.43546 .50978 m .38685 .48585 L .37982 .50942 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .52091 .33043 L .5297 .32789 L closepath p
1 g
F P
s
P
p
.002 w
.59867 .50947 m .54603 .52211 L .5455 .54683 L p
1 g
F P
s
P
p
.002 w
.48729 .54677 m .5455 .54683 L .54603 .52211 L p
1 g
F P
s
P
p
.002 w
.54603 .52211 m .59867 .50947 L .59466 .48352 L p
1 g
F P
s
P
p
.002 w
.40263 .33971 m .41585 .36605 L .4386 .34782 L p
1 g
F P
s
P
p
.002 w
.4386 .34782 m .42868 .32729 L .40263 .33971 L p
1 g
F P
s
P
p
.002 w
.42868 .32729 m .4386 .34782 L .46286 .33163 L p
1 g
F P
s
P
p
.002 w
.59276 .34555 m .57862 .36341 L .5968 .3862 L p
1 g
F P
s
P
p
.002 w
.57862 .36341 m .59276 .34555 L .56796 .32995 L p
1 g
F P
s
P
p
.002 w
.56796 .32995 m .5585 .34228 L .57862 .36341 L p
1 g
F P
s
P
p
.002 w
.46286 .33163 m .45631 .31753 L .42868 .32729 L p
1 g
F P
s
P
p
.002 w
.45631 .31753 m .46286 .33163 L .48817 .31781 L p
1 g
F P
s
P
p
.002 w
.49412 .32393 m .48817 .31781 L .46286 .33163 L p
1 g
F P
s
P
p
.002 w
.5585 .34228 m .56796 .32995 L .54154 .3169 L p
1 g
F P
s
P
p
.002 w
.54154 .3169 m .53684 .32323 L .5585 .34228 L p
1 g
F P
s
P
p
.002 w
.37872 .35457 m .39506 .38598 L .41585 .36605 L p
1 g
F P
s
P
p
.002 w
.41585 .36605 m .40263 .33971 L .37872 .35457 L p
1 g
F P
s
P
p
.002 w
.61543 .3634 m .5968 .3862 L .61269 .41022 L p
1 g
F P
s
P
p
.002 w
.5968 .3862 m .61543 .3634 L .59276 .34555 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .48817 .31781 L .49412 .32393 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .5297 .32789 L .53684 .32323 L closepath p
1 g
F P
s
P
p
.002 w
.34873 .45205 m .38685 .48585 L .39652 .46144 L p
1 g
F P
s
P
p
.002 w
.39652 .46144 m .36109 .4294 L .34873 .45205 L p
1 g
F P
s
P
p
.002 w
.63621 .46006 m .59466 .48352 L .59867 .50947 L p
1 g
F P
s
P
p
.002 w
.59466 .48352 m .63621 .46006 L .62593 .435 L p
1 g
F P
s
P
p
.002 w
.48817 .31781 m .48495 .31061 L .45631 .31753 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .48495 .31061 L .48817 .31781 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .53684 .32323 L .54154 .3169 L closepath p
1 g
F P
s
P
p
.002 w
.3575 .37162 m .37666 .40723 L .39506 .38598 L p
1 g
F P
s
P
p
.002 w
.39506 .38598 m .37872 .35457 L .3575 .37162 L p
1 g
F P
s
P
p
.002 w
.63546 .38316 m .61269 .41022 L .62593 .435 L p
1 g
F P
s
P
p
.002 w
.61269 .41022 m .63546 .38316 L .61543 .3634 L p
1 g
F P
s
P
p
.002 w
.42713 .55625 m .48477 .5691 L .48729 .54677 L p
1 g
F P
s
P
p
.002 w
.48729 .54677 m .43048 .534 L .42713 .55625 L p
1 g
F P
s
P
p
.002 w
.5455 .54683 m .48729 .54677 L .48477 .5691 L p
1 g
F P
s
P
p
.002 w
.45584 .30267 m .45631 .31753 L .48495 .31061 L p
1 g
F P
s
P
p
.002 w
.48495 .31061 m .48484 .30308 L .45584 .30267 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .48484 .30308 L .48495 .31061 L closepath p
1 g
F P
s
P
p
.002 w
.54328 .30958 m .54154 .3169 L .56796 .32995 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .54154 .3169 L .54328 .30958 L closepath p
1 g
F P
s
P
p
.002 w
.42761 .30549 m .42868 .32729 L .45631 .31753 L p
1 g
F P
s
P
p
.002 w
.45631 .31753 m .45584 .30267 L .42761 .30549 L p
1 g
F P
s
P
p
.002 w
.57165 .31555 m .56796 .32995 L .59276 .34555 L p
1 g
F P
s
P
p
.002 w
.56796 .32995 m .57165 .31555 L .54328 .30958 L p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .54328 .30958 L .54183 .30204 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .54183 .30204 L .53731 .29511 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .53731 .29511 L .53019 .28957 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .53019 .28957 L .52124 .28606 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .52124 .28606 L .51146 .28497 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .51146 .28497 L .50197 .28643 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .50197 .28643 L .49381 .29027 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .49381 .29027 L .4879 .29604 L closepath p
1 g
F P
s
P
p
.002 w
.51403 .30666 m .4879 .29604 L .48484 .30308 L closepath p
1 g
F P
s
P
p
.002 w
.37568 .5316 m .42713 .55625 L .43048 .534 L p
1 g
F P
s
P
p
.002 w
.43048 .534 m .37982 .50942 L .37568 .5316 L p
1 g
F P
s
P
p
.002 w
.60028 .534 m .5455 .54683 L .54381 .56927 L p
1 g
F P
s
P
p
.002 w
.48477 .5691 m .54381 .56927 L .5455 .54683 L p
1 g
F P
s
P
p
.002 w
.5455 .54683 m .60028 .534 L .59867 .50947 L p
1 g
F P
s
P
p
.002 w
.40079 .31154 m .40263 .33971 L .42868 .32729 L p
1 g
F P
s
P
p
.002 w
.42868 .32729 m .42761 .30549 L .40079 .31154 L p
1 g
F P
s
P
p
.002 w
.33951 .39053 m .36109 .4294 L .37666 .40723 L p
1 g
F P
s
P
p
.002 w
.37666 .40723 m .3575 .37162 L .33951 .39053 L p
1 g
F P
s
P
p
.002 w
.59854 .32451 m .59276 .34555 L .61543 .3634 L p
1 g
F P
s
P
p
.002 w
.59276 .34555 m .59854 .32451 L .57165 .31555 L p
1 g
F P
s
P
p
.002 w
.33996 .4747 m .37982 .50942 L .38685 .48585 L p
1 g
F P
s
P
p
.002 w
.38685 .48585 m .34873 .45205 L .33996 .4747 L p
1 g
F P
s
P
p
.002 w
.65238 .40445 m .62593 .435 L .63621 .46006 L p
1 g
F P
s
P
p
.002 w
.62593 .435 m .65238 .40445 L .63546 .38316 L p
1 g
F P
s
P
p
.002 w
.64323 .48487 m .59867 .50947 L .60028 .534 L p
1 g
F P
s
P
p
.002 w
.59867 .50947 m .64323 .48487 L .63621 .46006 L p
1 g
F P
s
P
p
.002 w
.46166 .28865 m .45584 .30267 L .48484 .30308 L p
1 g
F P
s
P
p
.002 w
.48484 .30308 m .4879 .29604 L .46166 .28865 L p
1 g
F P
s
P
p
.002 w
.54183 .30204 m .54328 .30958 L .57165 .31555 L p
1 g
F P
s
P
p
.002 w
.37599 .32077 m .37872 .35457 L .40263 .33971 L p
1 g
F P
s
P
p
.002 w
.40263 .33971 m .40079 .31154 L .37599 .32077 L p
1 g
F P
s
P
p
.002 w
.62334 .3363 m .61543 .3634 L .63546 .38316 L p
1 g
F P
s
P
p
.002 w
.61543 .3634 m .62334 .3363 L .59854 .32451 L p
1 g
F P
s
P
p
.002 w
.47327 .27708 m .46166 .28865 L .4879 .29604 L p
1 g
F P
s
P
p
.002 w
.4879 .29604 m .49381 .29027 L .47327 .27708 L p
1 g
F P
s
P
p
.002 w
.57165 .31555 m .56902 .3006 L .54183 .30204 L p
1 g
F P
s
P
p
.002 w
.53731 .29511 m .54183 .30204 L .56902 .3006 L p
1 g
F P
s
P
p
.002 w
.43587 .28475 m .42761 .30549 L .45584 .30267 L p
1 g
F P
s
P
p
.002 w
.45584 .30267 m .46166 .28865 L .43587 .28475 L p
1 g
F P
s
P
p
.002 w
.56902 .3006 m .57165 .31555 L .59854 .32451 L p
1 g
F P
s
P
p
.002 w
.32528 .41095 m .34873 .45205 L .36109 .4294 L p
1 g
F P
s
P
p
.002 w
.36109 .4294 m .33951 .39053 L .32528 .41095 L p
1 g
F P
s
P
p
.002 w
.66571 .42687 m .63621 .46006 L .64323 .48487 L p
1 g
F P
s
P
p
.002 w
.63621 .46006 m .66571 .42687 L .65238 .40445 L p
1 g
F P
s
P
p
.002 w
.42554 .57596 m .48255 .58858 L .48477 .5691 L p
1 g
F P
s
P
p
.002 w
.48477 .5691 m .42713 .55625 L .42554 .57596 L p
1 g
F P
s
P
p
.002 w
.54381 .56927 m .48477 .5691 L .48255 .58858 L p
1 g
F P
s
P
p
.002 w
.4895 .26931 m .47327 .27708 L .49381 .29027 L p
1 g
F P
s
P
p
.002 w
.49381 .29027 m .50197 .28643 L .4895 .26931 L p
1 g
F P
s
P
p
.002 w
.56902 .3006 m .56019 .28674 L .53731 .29511 L p
1 g
F P
s
P
p
.002 w
.53019 .28957 m .53731 .29511 L .56019 .28674 L p
1 g
F P
s
P
p
.002 w
.35385 .33309 m .3575 .37162 L .37872 .35457 L p
1 g
F P
s
P
p
.002 w
.37872 .35457 m .37599 .32077 L .35385 .33309 L p
1 g
F P
s
P
p
.002 w
.64546 .35076 m .63546 .38316 L .65238 .40445 L p
1 g
F P
s
P
p
.002 w
.63546 .38316 m .64546 .35076 L .62334 .3363 L p
1 g
F P
s
P
p
.002 w
.33514 .49683 m .37568 .5316 L .37982 .50942 L p
1 g
F P
s
P
p
.002 w
.37982 .50942 m .33996 .4747 L .33514 .49683 L p
1 g
F P
s
P
p
.002 w
.50852 .26632 m .4895 .26931 L .50197 .28643 L p
1 g
F P
s
P
p
.002 w
.50197 .28643 m .51146 .28497 L .50852 .26632 L p
1 g
F P
s
P
p
.002 w
.54381 .56927 m .59937 .55655 L .60028 .534 L p
1 g
F P
s
P
p
.002 w
.64673 .5089 m .60028 .534 L .59937 .55655 L p
1 g
F P
s
P
p
.002 w
.60028 .534 m .64673 .5089 L .64323 .48487 L p
1 g
F P
s
P
p
.002 w
.56019 .28674 m .54604 .2756 L .53019 .28957 L p
1 g
F P
s
P
p
.002 w
.52124 .28606 m .53019 .28957 L .54604 .2756 L p
1 g
F P
s
P
p
.002 w
.41112 .28454 m .40079 .31154 L .42761 .30549 L p
1 g
F P
s
P
p
.002 w
.42761 .30549 m .43587 .28475 L .41112 .28454 L p
1 g
F P
s
P
p
.002 w
.59499 .30246 m .59854 .32451 L .62334 .3363 L p
1 g
F P
s
P
p
.002 w
.59854 .32451 m .59499 .30246 L .56902 .3006 L p
1 g
F P
s
P
p
.002 w
.37465 .55185 m .42554 .57596 L .42713 .55625 L p
1 g
F P
s
P
p
.002 w
.42713 .55625 m .37568 .5316 L .37465 .55185 L p
1 g
F P
s
P
p
.002 w
.48255 .58858 m .54093 .58884 L .54381 .56927 L p
1 g
F P
s
P
p
.002 w
.59937 .55655 m .54381 .56927 L .54093 .58884 L p
1 g
F P
s
P
p
.002 w
.52813 .2685 m .50852 .26632 L .51146 .28497 L p
1 g
F P
s
P
p
.002 w
.51146 .28497 m .52124 .28606 L .52813 .2685 L p
1 g
F P
s
P
p
.002 w
.54604 .2756 m .52813 .2685 L .52124 .28606 L p
1 g
F P
s
P
p
.002 w
.45286 .26749 m .43587 .28475 L .46166 .28865 L p
1 g
F P
s
P
p
.002 w
.46166 .28865 m .47327 .27708 L .45286 .26749 L p
1 g
F P
s
P
p
.002 w
.56019 .28674 m .56902 .3006 L .59499 .30246 L p
1 g
F P
s
P
p
.002 w
.31528 .43245 m .33996 .4747 L .34873 .45205 L p
1 g
F P
s
P
p
.002 w
.34873 .45205 m .32528 .41095 L .31528 .43245 L p
1 g
F P
s
P
p
.002 w
.67505 .44992 m .64323 .48487 L .64673 .5089 L p
1 g
F P
s
P
p
.002 w
.64323 .48487 m .67505 .44992 L .66571 .42687 L p
1 g
F P
s
P
p
.002 w
.33499 .34831 m .33951 .39053 L .3575 .37162 L p
1 g
F P
s
P
p
.002 w
.3575 .37162 m .35385 .33309 L .33499 .34831 L p
1 g
F P
s
P
p
.002 w
.6643 .36765 m .65238 .40445 L .66571 .42687 L p
1 g
F P
s
P
p
.002 w
.65238 .40445 m .6643 .36765 L .64546 .35076 L p
1 g
F P
s
P
p
.002 w
.38803 .28816 m .37599 .32077 L .40079 .31154 L p
1 g
F P
s
P
p
.002 w
.40079 .31154 m .41112 .28454 L .38803 .28816 L p
1 g
F P
s
P
p
.002 w
.61912 .30768 m .62334 .3363 L .64546 .35076 L p
1 g
F P
s
P
p
.002 w
.62334 .3363 m .61912 .30768 L .59499 .30246 L p
1 g
F P
s
P
p
.002 w
.47688 .25582 m .45286 .26749 L .47327 .27708 L p
1 g
F P
s
P
p
.002 w
.47327 .27708 m .4895 .26931 L .47688 .25582 L p
1 g
F P
s
P
p
.002 w
.59499 .30246 m .58215 .28187 L .56019 .28674 L p
1 g
F P
s
P
p
.002 w
.54604 .2756 m .56019 .28674 L .58215 .28187 L p
1 g
F P
s
P
p
.002 w
.42585 .59256 m .48072 .60464 L .48255 .58858 L p
1 g
F P
s
P
p
.002 w
.48255 .58858 m .42554 .57596 L .42585 .59256 L p
1 g
F P
s
P
p
.002 w
.54093 .58884 m .48255 .58858 L .48072 .60464 L p
1 g
F P
s
P
p
.002 w
.43304 .26189 m .41112 .28454 L .43587 .28475 L p
1 g
F P
s
P
p
.002 w
.43587 .28475 m .45286 .26749 L .43304 .26189 L p
1 g
F P
s
P
p
.002 w
.58215 .28187 m .59499 .30246 L .61912 .30768 L p
1 g
F P
s
P
p
.002 w
.33455 .5179 m .37465 .55185 L .37568 .5316 L p
1 g
F P
s
P
p
.002 w
.37568 .5316 m .33514 .49683 L .33455 .5179 L p
1 g
F P
s
P
p
.002 w
.54093 .58884 m .59583 .57653 L .59937 .55655 L p
1 g
F P
s
P
p
.002 w
.64649 .53155 m .59937 .55655 L .59583 .57653 L p
1 g
F P
s
P
p
.002 w
.59937 .55655 m .64649 .53155 L .64673 .5089 L p
1 g
F P
s
P
p
.002 w
.50524 .2513 m .47688 .25582 L .4895 .26931 L p
1 g
F P
s
P
p
.002 w
.4895 .26931 m .50852 .26632 L .50524 .2513 L p
1 g
F P
s
P
p
.002 w
.58215 .28187 m .56123 .2652 L .54604 .2756 L p
1 g
F P
s
P
p
.002 w
.52813 .2685 m .54604 .2756 L .56123 .2652 L p
1 g
F P
s
P
p
.002 w
.37691 .56959 m .42585 .59256 L .42554 .57596 L p
1 g
F P
s
P
p
.002 w
.42554 .57596 m .37465 .55185 L .37691 .56959 L p
1 g
F P
s
P
p
.002 w
.48072 .60464 m .53688 .60496 L .54093 .58884 L p
1 g
F P
s
P
p
.002 w
.59583 .57653 m .54093 .58884 L .53688 .60496 L p
1 g
F P
s
P
p
.002 w
.53454 .25456 m .50524 .2513 L .50852 .26632 L p
1 g
F P
s
P
p
.002 w
.50852 .26632 m .52813 .2685 L .53454 .25456 L p
1 g
F P
s
P
p
.002 w
.56123 .2652 m .53454 .25456 L .52813 .2685 L p
1 g
F P
s
P
p
.002 w
.32001 .36618 m .32528 .41095 L .33951 .39053 L p
1 g
F P
s
P
p
.002 w
.33951 .39053 m .33499 .34831 L .32001 .36618 L p
1 g
F P
s
P
p
.002 w
.36723 .29569 m .35385 .33309 L .37599 .32077 L p
1 g
F P
s
P
p
.002 w
.37599 .32077 m .38803 .28816 L .36723 .29569 L p
1 g
F P
s
P
p
.002 w
.6793 .38664 m .66571 .42687 L .67505 .44992 L p
1 g
F P
s
P
p
.002 w
.66571 .42687 m .6793 .38664 L .6643 .36765 L p
1 g
F P
s
P
p
.002 w
.64079 .31628 m .64546 .35076 L .6643 .36765 L p
1 g
F P
s
P
p
.002 w
.64546 .35076 m .64079 .31628 L .61912 .30768 L p
1 g
F P
s
P
p
.002 w
.30994 .45453 m .33514 .49683 L .33996 .4747 L p
1 g
F P
s
P
p
.002 w
.33996 .4747 m .31528 .43245 L .30994 .45453 L p
1 g
F P
s
P
p
.002 w
.68 .47309 m .64673 .5089 L .64649 .53155 L p
1 g
F P
s
P
p
.002 w
.64673 .5089 m .68 .47309 L .67505 .44992 L p
1 g
F P
s
P
p
.002 w
.46441 .24648 m .43304 .26189 L .45286 .26749 L p
1 g
F P
s
P
p
.002 w
.45286 .26749 m .47688 .25582 L .46441 .24648 L p
1 g
F P
s
P
p
.002 w
.61912 .30768 m .60264 .28075 L .58215 .28187 L p
1 g
F P
s
P
p
.002 w
.56123 .2652 m .58215 .28187 L .60264 .28075 L p
1 g
F P
s
P
p
.002 w
.41432 .26061 m .38803 .28816 L .41112 .28454 L p
1 g
F P
s
P
p
.002 w
.41112 .28454 m .43304 .26189 L .41432 .26061 L p
1 g
F P
s
P
p
.002 w
.60264 .28075 m .61912 .30768 L .64079 .31628 L p
1 g
F P
s
P
p
.002 w
.33841 .53732 m .37691 .56959 L .37465 .55185 L p
1 g
F P
s
P
p
.002 w
.37465 .55185 m .33455 .5179 L .33841 .53732 L p
1 g
F P
s
P
p
.002 w
.53688 .60496 m .58964 .59333 L .59583 .57653 L p
1 g
F P
s
P
p
.002 w
.64235 .55223 m .59583 .57653 L .58964 .59333 L p
1 g
F P
s
P
p
.002 w
.59583 .57653 m .64235 .55223 L .64649 .53155 L p
1 g
F P
s
P
p
.002 w
.42815 .60549 m .47932 .6167 L .48072 .60464 L p
1 g
F P
s
P
p
.002 w
.48072 .60464 m .42585 .59256 L .42815 .60549 L p
1 g
F P
s
P
p
.002 w
.53688 .60496 m .48072 .60464 L .47932 .6167 L p
1 g
F P
s
P
p
.002 w
.34936 .30713 m .33499 .34831 L .35385 .33309 L p
1 g
F P
s
P
p
.002 w
.35385 .33309 m .36723 .29569 L .34936 .30713 L p
1 g
F P
s
P
p
.002 w
.30947 .38634 m .31528 .43245 L .32528 .41095 L p
1 g
F P
s
P
p
.002 w
.32528 .41095 m .32001 .36618 L .30947 .38634 L p
1 g
F P
s
P
p
.002 w
.65935 .3282 m .6643 .36765 L .6793 .38664 L p
1 g
F P
s
P
p
.002 w
.6643 .36765 m .65935 .3282 L .64079 .31628 L p
1 g
F P
s
P
p
.002 w
.68991 .40737 m .67505 .44992 L .68 .47309 L p
1 g
F P
s
P
p
.002 w
.67505 .44992 m .68991 .40737 L .6793 .38664 L p
1 g
F P
s
P
p
.002 w
.50169 .24047 m .46441 .24648 L .47688 .25582 L p
1 g
F P
s
P
p
.002 w
.47688 .25582 m .50524 .2513 L .50169 .24047 L p
1 g
F P
s
P
p
.002 w
.60264 .28075 m .57536 .25882 L .56123 .2652 L p
1 g
F P
s
P
p
.002 w
.53454 .25456 m .56123 .2652 L .57536 .25882 L p
1 g
F P
s
P
p
.002 w
.30963 .47666 m .33455 .5179 L .33514 .49683 L p
1 g
F P
s
P
p
.002 w
.33514 .49683 m .30994 .45453 L .30963 .47666 L p
1 g
F P
s
P
p
.002 w
.68027 .49581 m .64649 .53155 L .64235 .55223 L p
1 g
F P
s
P
p
.002 w
.64649 .53155 m .68027 .49581 L .68 .47309 L p
1 g
F P
s
P
p
.002 w
.38257 .58423 m .42815 .60549 L .42585 .59256 L p
1 g
F P
s
P
p
.002 w
.42585 .59256 m .37691 .56959 L .38257 .58423 L p
1 g
F P
s
P
p
.002 w
.58964 .59333 m .53688 .60496 L .53169 .61705 L p
1 g
F P
s
P
p
.002 w
.47932 .6167 m .53169 .61705 L .53688 .60496 L p
1 g
F P
s
P
p
.002 w
.54028 .24476 m .50169 .24047 L .50524 .2513 L p
1 g
F P
s
P
p
.002 w
.50524 .2513 m .53454 .25456 L .54028 .24476 L p
1 g
F P
s
P
p
.002 w
.57536 .25882 m .54028 .24476 L .53454 .25456 L p
1 g
F P
s
P
p
.002 w
.39726 .26392 m .36723 .29569 L .38803 .28816 L p
1 g
F P
s
P
p
.002 w
.38803 .28816 m .41432 .26061 L .39726 .26392 L p
1 g
F P
s
P
p
.002 w
.6211 .28361 m .64079 .31628 L .65935 .3282 L p
1 g
F P
s
P
p
.002 w
.64079 .31628 m .6211 .28361 L .60264 .28075 L p
1 g
F P
s
P
p
.002 w
.45242 .24177 m .41432 .26061 L .43304 .26189 L p
1 g
F P
s
P
p
.002 w
.43304 .26189 m .46441 .24648 L .45242 .24177 L p
1 g
F P
s
P
p
.002 w
.57536 .25882 m .60264 .28075 L .6211 .28361 L p
1 g
F P
s
P
p
.002 w
.33505 .32236 m .32001 .36618 L .33499 .34831 L p
1 g
F P
s
P
p
.002 w
.33499 .34831 m .34936 .30713 L .33505 .32236 L p
1 g
F P
s
P
p
.002 w
.67419 .34328 m .6793 .38664 L .68991 .40737 L p
1 g
F P
s
P
p
.002 w
.6793 .38664 m .67419 .34328 L .65935 .3282 L p
1 g
F P
s
P
p
.002 w
.30389 .40837 m .30994 .45453 L .31528 .43245 L p
1 g
F P
s
P
p
.002 w
.31528 .43245 m .30947 .38634 L .30389 .40837 L p
1 g
F P
s
P
p
.002 w
.69567 .42936 m .68 .47309 L .68027 .49581 L p
1 g
F P
s
P
p
.002 w
.68 .47309 m .69567 .42936 L .68991 .40737 L p
1 g
F P
s
P
p
.002 w
.34686 .55448 m .38257 .58423 L .37691 .56959 L p
1 g
F P
s
P
p
.002 w
.37691 .56959 m .33841 .53732 L .34686 .55448 L p
1 g
F P
s
P
p
.002 w
.53169 .61705 m .58078 .60636 L .58964 .59333 L p
1 g
F P
s
P
p
.002 w
.63421 .57032 m .58964 .59333 L .58078 .60636 L p
1 g
F P
s
P
p
.002 w
.58964 .59333 m .63421 .57032 L .64235 .55223 L p
1 g
F P
s
P
p
.002 w
.31459 .49823 m .33841 .53732 L .33455 .5179 L p
1 g
F P
s
P
p
.002 w
.33455 .5179 m .30963 .47666 L .31459 .49823 L p
1 g
F P
s
P
p
.002 w
.67561 .51747 m .64235 .55223 L .63421 .57032 L p
1 g
F P
s
P
p
.002 w
.64235 .55223 m .67561 .51747 L .68027 .49581 L p
1 g
F P
s
P
p
.002 w
.4325 .61418 m .47843 .62422 L .47932 .6167 L p
1 g
F P
s
P
p
.004 w
.44182 .70739 m
.46014 .62022 L
s
P
p
.002 w
.47932 .6167 m .42815 .60549 L .4325 .61418 L p
1 g
F P
s
P
p
.002 w
.53169 .61705 m .47932 .6167 L .47843 .62422 L p
1 g
F P
s
P
p
.002 w
.49794 .23437 m .45242 .24177 L .46441 .24648 L p
1 g
F P
s
P
p
.002 w
.46441 .24648 m .50169 .24047 L .49794 .23437 L p
1 g
F P
s
P
p
.002 w
.6211 .28361 m .588 .25684 L .57536 .25882 L p
1 g
F P
s
P
p
.002 w
.54028 .24476 m .57536 .25882 L .588 .25684 L p
1 g
F P
s
P
p
.002 w
.3917 .59522 m .4325 .61418 L .42815 .60549 L p
1 g
F P
s
P
p
.002 w
.42815 .60549 m .38257 .58423 L .3917 .59522 L p
1 g
F P
s
P
p
.002 w
.47843 .62422 m .52542 .62455 L .53169 .61705 L p
1 g
F P
s
P
p
.002 w
.58078 .60636 m .53169 .61705 L .52542 .62455 L p
1 g
F P
s
P
p
.002 w
.38241 .27199 m .34936 .30713 L .36723 .29569 L p
1 g
F P
s
P
p
.002 w
.36723 .29569 m .39726 .26392 L .38241 .27199 L p
1 g
F P
s
P
p
.002 w
.63692 .29058 m .65935 .3282 L .67419 .34328 L p
1 g
F P
s
P
p
.002 w
.65935 .3282 m .63692 .29058 L .6211 .28361 L p
1 g
F P
s
P
p
.002 w
.54517 .23962 m .49794 .23437 L .50169 .24047 L p
1 g
F P
s
P
p
.002 w
.50169 .24047 m .54028 .24476 L .54517 .23962 L p
1 g
F P
s
P
p
.002 w
.588 .25684 m .54517 .23962 L .54028 .24476 L p
1 g
F P
s
P
p
.002 w
.44124 .24209 m .39726 .26392 L .41432 .26061 L p
1 g
F P
s
P
p
.002 w
.41432 .26061 m .45242 .24177 L .44124 .24209 L p
1 g
F P
s
P
p
.002 w
.588 .25684 m .6211 .28361 L .63692 .29058 L p
1 g
F P
s
P
p
.002 w
.32488 .34115 m .30947 .38634 L .32001 .36618 L p
1 g
F P
s
P
p
.002 w
.32001 .36618 m .33505 .32236 L .32488 .34115 L p
1 g
F P
s
P
p
.002 w
.68472 .36128 m .68991 .40737 L .69567 .42936 L p
1 g
F P
s
P
p
.002 w
.68991 .40737 m .68472 .36128 L .67419 .34328 L p
1 g
F P
s
P
p
.002 w
.30364 .43172 m .30963 .47666 L .30994 .45453 L p
1 g
F P
s
P
p
.002 w
.30994 .45453 m .30389 .40837 L .30364 .43172 L p
1 g
F P
s
P
p
.002 w
.69619 .45208 m .68027 .49581 L .67561 .51747 L p
1 g
F P
s
P
p
.002 w
.68027 .49581 m .69619 .45208 L .69567 .42936 L p
1 g
F P
s
P
p
.002 w
.35991 .56879 m .3917 .59522 L .38257 .58423 L p
1 g
F P
s
P
p
.002 w
.38257 .58423 m .34686 .55448 L .35991 .56879 L p
1 g
F P
s
P
p
.002 w
.52542 .62455 m .56935 .61505 L .58078 .60636 L p
1 g
F P
s
P
p
.002 w
.62209 .58519 m .58078 .60636 L .56935 .61505 L p
1 g
F P
s
P
p
.002 w
.58078 .60636 m .62209 .58519 L .63421 .57032 L p
1 g
F P
s
P
p
.002 w
.32494 .51859 m .34686 .55448 L .33841 .53732 L p
1 g
F P
s
P
p
.002 w
.33841 .53732 m .31459 .49823 L .32494 .51859 L p
1 g
F P
s
P
p
.002 w
.66594 .53741 m .63421 .57032 L .62209 .58519 L p
1 g
F P
s
P
p
.002 w
.63421 .57032 m .66594 .53741 L .67561 .51747 L p
1 g
F P
s
P
p
.002 w
.49409 .23349 m .44124 .24209 L .45242 .24177 L p
1 g
F P
s
P
p
.002 w
.45242 .24177 m .49794 .23437 L .49409 .23349 L p
1 g
F P
s
P
p
.002 w
.63692 .29058 m .59872 .2596 L .588 .25684 L p
1 g
F P
s
P
p
.002 w
.54517 .23962 m .588 .25684 L .59872 .2596 L p
1 g
F P
s
P
p
.002 w
.37033 .28485 m .33505 .32236 L .34936 .30713 L p
1 g
F P
s
P
p
.002 w
.34936 .30713 m .38241 .27199 L .37033 .28485 L p
1 g
F P
s
P
p
.002 w
.67419 .34328 m .64954 .3017 L .63692 .29058 L p
1 g
F P
s
P
p
.002 w
.64954 .3017 m .67419 .34328 L .68472 .36128 L p
1 g
F P
s
P
p
.002 w
.43893 .61812 m .47809 .62668 L .47843 .62422 L p
1 g
F P
s
P
p
.002 w
.47843 .62422 m .4325 .61418 L .43893 .61812 L p
1 g
F P
s
P
p
.004 w
.46129 .61476 m
.5 .43051 L
s
P
p
.002 w
.52542 .62455 m .47843 .62422 L .47809 .62668 L p
1 g
F P
s
P
p
.002 w
.31937 .36312 m .30389 .40837 L .30947 .38634 L p
1 g
F P
s
P
p
.002 w
.30947 .38634 m .32488 .34115 L .31937 .36312 L p
1 g
F P
s
P
p
.002 w
.69567 .42936 m .69042 .38185 L .68472 .36128 L p
1 g
F P
s
P
p
.002 w
.69042 .38185 m .69567 .42936 L .69619 .45208 L p
1 g
F P
s
P
p
.004 w
.47317 .66731 m
.47616 .64099 L
s
P
p
.002 w
.40424 .60202 m .43893 .61812 L .4325 .61418 L p
1 g
F P
s
P
p
.002 w
.4325 .61418 m .3917 .59522 L .40424 .60202 L p
1 g
F P
s
P
p
.002 w
.56935 .61505 m .52542 .62455 L .51817 .62697 L p
1 g
F P
s
P
p
.002 w
.47809 .62668 m .51817 .62697 L .52542 .62455 L p
1 g
F P
s
P
p
.002 w
.43126 .24775 m .38241 .27199 L .39726 .26392 L p
1 g
F P
s
P
p
.002 w
.39726 .26392 m .44124 .24209 L .43126 .24775 L p
1 g
F P
s
P
p
.002 w
.59872 .2596 m .63692 .29058 L .64954 .3017 L p
1 g
F P
s
P
p
.002 w
.30899 .45576 m .31459 .49823 L .30963 .47666 L p
1 g
F P
s
P
p
.002 w
.30963 .47666 m .30364 .43172 L .30899 .45576 L p
1 g
F P
s
P
p
.002 w
.67561 .51747 m .6912 .47491 L .69619 .45208 L p
1 g
F P
s
P
p
.002 w
.6912 .47491 m .67561 .51747 L .66594 .53741 L p
1 g
F P
s
P
p
.002 w
.54901 .23959 m .49409 .23349 L .49794 .23437 L p
1 g
F P
s
P
p
.002 w
.49794 .23437 m .54517 .23962 L .54901 .23959 L p
1 g
F P
s
P
p
.002 w
.59872 .2596 m .54901 .23959 L .54517 .23962 L p
1 g
F P
s
P
p
.002 w
.34063 .53706 m .35991 .56879 L .34686 .55448 L p
1 g
F P
s
P
p
.002 w
.34686 .55448 m .32494 .51859 L .34063 .53706 L p
1 g
F P
s
P
p
.002 w
.56935 .61505 m .6061 .59627 L .62209 .58519 L p
1 g
F P
s
P
p
.002 w
.62209 .58519 m .65126 .55498 L .66594 .53741 L p
1 g
F P
s
P
p
.002 w
.65126 .55498 m .62209 .58519 L .6061 .59627 L p
1 g
F P
s
P
p
.002 w
.37742 .57966 m .40424 .60202 L .3917 .59522 L p
1 g
F P
s
P
p
.002 w
.3917 .59522 m .35991 .56879 L .37742 .57966 L p
1 g
F P
s
P
p
.002 w
.51817 .62697 m .55551 .6189 L .56935 .61505 L p
1 g
F P
s
P
p
.002 w
.6061 .59627 m .56935 .61505 L .55551 .6189 L p
1 g
F P
s
P
p
.002 w
.36153 .30239 m .32488 .34115 L .33505 .32236 L p
1 g
F P
s
P
p
.002 w
.33505 .32236 m .37033 .28485 L .36153 .30239 L p
1 g
F P
s
P
p
.002 w
.6584 .3169 m .68472 .36128 L .69042 .38185 L p
1 g
F P
s
P
p
.002 w
.68472 .36128 m .6584 .3169 L .64954 .3017 L p
1 g
F P
s
P
p
.002 w
.31893 .38773 m .30364 .43172 L .30389 .40837 L p
1 g
F P
s
P
p
.002 w
.30389 .40837 m .31937 .36312 L .31893 .38773 L p
1 g
F P
s
P
p
.002 w
.69087 .40449 m .69619 .45208 L .6912 .47491 L p
1 g
F P
s
P
p
.002 w
.69619 .45208 m .69087 .40449 L .69042 .38185 L p
1 g
F P
s
P
p
.002 w
.49023 .23819 m .43126 .24775 L .44124 .24209 L p
1 g
F P
s
P
p
.002 w
.44124 .24209 m .49409 .23349 L .49023 .23819 L p
1 g
F P
s
P
p
.002 w
.64954 .3017 m .60711 .2673 L .59872 .2596 L p
1 g
F P
s
P
p
.002 w
.54901 .23959 m .59872 .2596 L .60711 .2673 L p
1 g
F P
s
P
p
.002 w
.32002 .47977 m .32494 .51859 L .31459 .49823 L p
1 g
F P
s
P
p
.002 w
.31459 .49823 m .30899 .45576 L .32002 .47977 L p
1 g
F P
s
P
p
.002 w
.6806 .49718 m .66594 .53741 L .65126 .55498 L p
1 g
F P
s
P
p
.002 w
.66594 .53741 m .6806 .49718 L .6912 .47491 L p
1 g
F P
s
P
p
.002 w
.44737 .6169 m .47837 .62368 L .47809 .62668 L p
1 g
F P
s
P
p
.002 w
.47809 .62668 m .43893 .61812 L .44737 .6169 L p
1 g
F P
s
P
p
.002 w
.51817 .62697 m .47809 .62668 L .47837 .62368 L p
1 g
F P
s
P
p
.002 w
.42284 .25892 m .37033 .28485 L .38241 .27199 L p
1 g
F P
s
P
p
.002 w
.38241 .27199 m .43126 .24775 L .42284 .25892 L p
1 g
F P
s
P
p
.002 w
.60711 .2673 m .64954 .3017 L .6584 .3169 L p
1 g
F P
s
P
p
.002 w
.42003 .60417 m .44737 .6169 L .43893 .61812 L p
1 g
F P
s
P
p
.002 w
.43893 .61812 m .40424 .60202 L .42003 .60417 L p
1 g
F P
s
P
p
.002 w
.47837 .62368 m .51009 .6239 L .51817 .62697 L p
1 g
F P
s
P
p
.002 w
.55551 .6189 m .51817 .62697 L .51009 .6239 L p
1 g
F P
s
P
p
.002 w
.55161 .24502 m .49023 .23819 L .49409 .23349 L p
1 g
F P
s
P
p
.002 w
.49409 .23349 m .54901 .23959 L .55161 .24502 L p
1 g
F P
s
P
p
.002 w
.60711 .2673 m .55161 .24502 L .54901 .23959 L p
1 g
F P
s
P
p
.002 w
.36141 .553 m .37742 .57966 L .35991 .56879 L p
1 g
F P
s
P
p
.002 w
.35991 .56879 m .34063 .53706 L .36141 .553 L p
1 g
F P
s
P
p
.002 w
.55551 .6189 m .58653 .603 L .6061 .59627 L p
1 g
F P
s
P
p
.002 w
.63179 .56955 m .6061 .59627 L .58653 .603 L p
1 g
F P
s
P
p
.002 w
.6061 .59627 m .63179 .56955 L .65126 .55498 L p
1 g
F P
s
P
p
.002 w
.35649 .32431 m .31937 .36312 L .32488 .34115 L p
1 g
F P
s
P
p
.002 w
.32488 .34115 m .36153 .30239 L .35649 .32431 L p
1 g
F P
s
P
p
.002 w
.66302 .33594 m .69042 .38185 L .69087 .40449 L p
1 g
F P
s
P
p
.002 w
.69042 .38185 m .66302 .33594 L .6584 .3169 L p
1 g
F P
s
P
p
.002 w
.39908 .58659 m .42003 .60417 L .40424 .60202 L p
1 g
F P
s
P
p
.002 w
.40424 .60202 m .37742 .57966 L .39908 .58659 L p
1 g
F P
s
P
p
.002 w
.51009 .6239 m .53952 .61751 L .55551 .6189 L p
1 g
F P
s
P
p
.002 w
.58653 .603 m .55551 .6189 L .53952 .61751 L p
1 g
F P
s
P
p
.002 w
.32378 .41433 m .30899 .45576 L .30364 .43172 L p
1 g
F P
s
P
p
.002 w
.30364 .43172 m .31893 .38773 L .32378 .41433 L p
1 g
F P
s
P
p
.002 w
.6858 .4286 m .6912 .47491 L .6806 .49718 L p
1 g
F P
s
P
p
.002 w
.6912 .47491 m .6858 .4286 L .69087 .40449 L p
1 g
F P
s
P
p
.002 w
.33663 .50297 m .34063 .53706 L .32494 .51859 L p
1 g
F P
s
P
p
.002 w
.32494 .51859 m .32002 .47977 L .33663 .50297 L p
1 g
F P
s
P
p
.002 w
.66446 .51817 m .65126 .55498 L .63179 .56955 L p
1 g
F P
s
P
p
.002 w
.65126 .55498 m .66446 .51817 L .6806 .49718 L p
1 g
F P
s
P
p
.002 w
.48649 .24871 m .42284 .25892 L .43126 .24775 L p
1 g
F P
s
P
p
.002 w
.43126 .24775 m .49023 .23819 L .48649 .24871 L p
1 g
F P
s
P
p
.002 w
.6584 .3169 m .61275 .28004 L .60711 .2673 L p
1 g
F P
s
P
p
.002 w
.55161 .24502 m .60711 .2673 L .61275 .28004 L p
1 g
F P
s
P
p
.002 w
.41637 .27558 m .36153 .30239 L .37033 .28485 L p
1 g
F P
s
P
p
.002 w
.37033 .28485 m .42284 .25892 L .41637 .27558 L p
1 g
F P
s
P
p
.002 w
.61275 .28004 m .6584 .3169 L .66302 .33594 L p
1 g
F P
s
P
p
.002 w
.4577 .61021 m .47928 .61494 L .47837 .62368 L p
1 g
F P
s
P
p
.002 w
.47837 .62368 m .44737 .6169 L .4577 .61021 L p
1 g
F P
s
P
p
.002 w
.51009 .6239 m .47837 .62368 L .47928 .61494 L p
1 g
F P
s
P
p
.002 w
.43875 .60133 m .4577 .61021 L .44737 .6169 L p
1 g
F P
s
P
p
.002 w
.44737 .6169 m .42003 .60417 L .43875 .60133 L p
1 g
F P
s
P
p
.002 w
.53952 .61751 m .51009 .6239 L .50137 .61509 L p
1 g
F P
s
P
p
.002 w
.47928 .61494 m .50137 .61509 L .51009 .6239 L p
1 g
F P
s
P
p
.002 w
.38682 .56576 m .39908 .58659 L .37742 .57966 L p
1 g
F P
s
P
p
.002 w
.37742 .57966 m .36141 .553 L .38682 .56576 L p
1 g
F P
s
P
p
.002 w
.53952 .61751 m .56377 .60497 L .58653 .603 L p
1 g
F P
s
P
p
.002 w
.60792 .58051 m .58653 .603 L .56377 .60497 L p
1 g
F P
s
P
p
.002 w
.58653 .603 m .60792 .58051 L .63179 .56955 L p
1 g
F P
s
P
p
.002 w
.35556 .35008 m .31893 .38773 L .31937 .36312 L p
1 g
F P
s
P
p
.002 w
.31937 .36312 m .35649 .32431 L .35556 .35008 L p
1 g
F P
s
P
p
.002 w
.334 .44208 m .32002 .47977 L .30899 .45576 L p
1 g
F P
s
P
p
.002 w
.30899 .45576 m .32378 .41433 L .334 .44208 L p
1 g
F P
s
P
p
.002 w
.66303 .35842 m .69087 .40449 L .6858 .4286 L p
1 g
F P
s
P
p
.002 w
.69087 .40449 m .66303 .35842 L .66302 .33594 L p
1 g
F P
s
P
p
.002 w
.55283 .25609 m .48649 .24871 L .49023 .23819 L p
1 g
F P
s
P
p
.002 w
.49023 .23819 m .55161 .24502 L .55283 .25609 L p
1 g
F P
s
P
p
.002 w
.61275 .28004 m .55283 .25609 L .55161 .24502 L p
1 g
F P
s
P
p
.002 w
.67512 .45347 m .6806 .49718 L .66446 .51817 L p
1 g
F P
s
P
p
.002 w
.6806 .49718 m .67512 .45347 L .6858 .4286 L p
1 g
F P
s
P
p
.002 w
.35845 .52455 m .36141 .553 L .34063 .53706 L p
1 g
F P
s
P
p
.002 w
.34063 .53706 m .33663 .50297 L .35845 .52455 L p
1 g
F P
s
P
p
.002 w
.64308 .53714 m .63179 .56955 L .60792 .58051 L p
1 g
F P
s
P
p
.002 w
.63179 .56955 m .64308 .53714 L .66446 .51817 L p
1 g
F P
s
P
p
.002 w
.42439 .58914 m .43875 .60133 L .42003 .60417 L p
1 g
F P
s
P
p
.002 w
.42003 .60417 m .39908 .58659 L .42439 .58914 L p
1 g
F P
s
P
p
.002 w
.50137 .61509 m .52178 .6106 L .53952 .61751 L p
1 g
F P
s
P
p
.002 w
.56377 .60497 m .53952 .61751 L .52178 .6106 L p
1 g
F P
s
P
p
.002 w
.41216 .29748 m .35649 .32431 L .36153 .30239 L p
1 g
F P
s
P
p
.002 w
.36153 .30239 m .41637 .27558 L .41216 .29748 L p
1 g
F P
s
P
p
.002 w
.61529 .29771 m .66302 .33594 L .66303 .35842 L p
1 g
F P
s
P
p
.002 w
.66302 .33594 m .61529 .29771 L .61275 .28004 L p
1 g
F P
s
P
p
.002 w
.483 .26506 m .41637 .27558 L .42284 .25892 L p
1 g
F P
s
P
p
.002 w
.42284 .25892 m .48649 .24871 L .483 .26506 L p
1 g
F P
s
P
p
.002 w
.55283 .25609 m .61275 .28004 L .61529 .29771 L p
1 g
F P
s
P
p
.002 w
.34942 .47009 m .33663 .50297 L .32002 .47977 L p
1 g
F P
s
P
p
.002 w
.32002 .47977 m .334 .44208 L .34942 .47009 L p
1 g
F P
s
P
p
.002 w
.65897 .4783 m .66446 .51817 L .64308 .53714 L p
1 g
F P
s
P
p
.002 w
.66446 .51817 m .65897 .4783 L .67512 .45347 L p
1 g
F P
s
P
p
.002 w
.35895 .37899 m .32378 .41433 L .31893 .38773 L p
1 g
F P
s
P
p
.002 w
.31893 .38773 m .35556 .35008 L .35895 .37899 L p
1 g
F P
s
P
p
.002 w
.41619 .5748 m .42439 .58914 L .39908 .58659 L p
1 g
F P
s
P
p
.002 w
.39908 .58659 m .38682 .56576 L .41619 .5748 L p
1 g
F P
s
P
p
.002 w
.65818 .38377 m .6858 .4286 L .67512 .45347 L p
1 g
F P
s
P
p
.002 w
.6858 .4286 m .65818 .38377 L .66303 .35842 L p
1 g
F P
s
P
p
.002 w
.52178 .6106 m .53843 .60186 L .56377 .60497 L p
1 g
F P
s
P
p
.002 w
.58024 .58735 m .56377 .60497 L .53843 .60186 L p
1 g
F P
s
P
p
.002 w
.56377 .60497 m .58024 .58735 L .60792 .58051 L p
1 g
F P
s
P
p
.002 w
.4697 .59793 m .48085 .60039 L .47928 .61494 L p
1 g
F P
s
P
p
.002 w
.47928 .61494 m .4577 .61021 L .4697 .59793 L p
1 g
F P
s
P
p
.002 w
.50137 .61509 m .47928 .61494 L .48085 .60039 L p
1 g
F P
s
P
p
.002 w
.38491 .54374 m .38682 .56576 L .36141 .553 L p
1 g
F P
s
P
p
.002 w
.36141 .553 m .35845 .52455 L .38491 .54374 L p
1 g
F P
s
P
p
.002 w
.61696 .55339 m .60792 .58051 L .58024 .58735 L p
1 g
F P
s
P
p
.002 w
.60792 .58051 m .61696 .55339 L .64308 .53714 L p
1 g
F P
s
P
p
.002 w
.45996 .59332 m .4697 .59793 L .4577 .61021 L p
1 g
F P
s
P
p
.002 w
.4577 .61021 m .43875 .60133 L .45996 .59332 L p
1 g
F P
s
P
p
.002 w
.52178 .6106 m .50137 .61509 L .49226 .60045 L p
1 g
F P
s
P
p
.002 w
.48085 .60039 m .49226 .60045 L .50137 .61509 L p
1 g
F P
s
P
p
.002 w
.55253 .27279 m .483 .26506 L .48649 .24871 L p
1 g
F P
s
P
p
.002 w
.48649 .24871 m .55283 .25609 L .55253 .27279 L p
1 g
F P
s
P
p
.002 w
.61529 .29771 m .55253 .27279 L .55283 .25609 L p
1 g
F P
s
P
p
.002 w
.45267 .58703 m .45996 .59332 L .43875 .60133 L p
1 g
F P
s
P
p
.002 w
.43875 .60133 m .42439 .58914 L .45267 .58703 L p
1 g
F P
s
P
p
.002 w
.49226 .60045 m .50275 .5981 L .52178 .6106 L p
1 g
F P
s
P
p
.002 w
.53843 .60186 m .52178 .6106 L .50275 .5981 L p
1 g
F P
s
P
p
.002 w
.36964 .49735 m .35845 .52455 L .33663 .50297 L p
1 g
F P
s
P
p
.002 w
.33663 .50297 m .34942 .47009 L .36964 .49735 L p
1 g
F P
s
P
p
.002 w
.41048 .32412 m .35556 .35008 L .35649 .32431 L p
1 g
F P
s
P
p
.002 w
.35649 .32431 m .41216 .29748 L .41048 .32412 L p
1 g
F P
s
P
p
.002 w
.63769 .50222 m .64308 .53714 L .61696 .55339 L p
1 g
F P
s
P
p
.002 w
.64308 .53714 m .63769 .50222 L .65897 .4783 L p
1 g
F P
s
P
p
.002 w
.61448 .31999 m .66303 .35842 L .65818 .38377 L p
1 g
F P
s
P
p
.002 w
.66303 .35842 m .61448 .31999 L .61529 .29771 L p
1 g
F P
s
P
p
.002 w
.36671 .41011 m .334 .44208 L .32378 .41433 L p
1 g
F P
s
P
p
.002 w
.32378 .41433 m .35895 .37899 L .36671 .41011 L p
1 g
F P
s
P
p
.002 w
.64843 .41122 m .67512 .45347 L .65897 .4783 L p
1 g
F P
s
P
p
.002 w
.67512 .45347 m .64843 .41122 L .65818 .38377 L p
1 g
F P
s
P
p
.002 w
.41519 .55979 m .41619 .5748 L .38682 .56576 L p
1 g
F P
s
P
p
.002 w
.38682 .56576 m .38491 .54374 L .41519 .55979 L p
1 g
F P
s
P
p
.002 w
.53843 .60186 m .54953 .58968 L .58024 .58735 L p
1 g
F P
s
P
p
.002 w
.58687 .56627 m .58024 .58735 L .54953 .58968 L p
1 g
F P
s
P
p
.002 w
.58024 .58735 m .58687 .56627 L .61696 .55339 L p
1 g
F P
s
P
p
.002 w
.4799 .28702 m .41216 .29748 L .41637 .27558 L p
1 g
F P
s
P
p
.002 w
.41637 .27558 m .483 .26506 L .4799 .28702 L p
1 g
F P
s
P
p
.002 w
.55253 .27279 m .61529 .29771 L .61448 .31999 L p
1 g
F P
s
P
p
.002 w
.44862 .57969 m .45267 .58703 L .42439 .58914 L p
1 g
F P
s
P
p
.002 w
.42439 .58914 m .41619 .5748 L .44862 .57969 L p
1 g
F P
s
P
p
.002 w
.50275 .5981 m .51123 .59356 L .53843 .60186 L p
1 g
F P
s
P
p
.002 w
.54953 .58968 m .53843 .60186 L .51123 .59356 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.48677 .54729 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.48085 .60039 m .4697 .59793 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.49226 .60045 m .48085 .60039 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.4697 .59793 m .45996 .59332 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.50275 .5981 m .49226 .60045 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.39402 .52287 m .38491 .54374 L .35845 .52455 L p
1 g
F P
s
P
p
.002 w
.35845 .52455 m .36964 .49735 L .39402 .52287 L p
1 g
F P
s
P
p
.002 w
.61192 .52437 m .61696 .55339 L .58687 .56627 L p
1 g
F P
s
P
p
.002 w
.61696 .55339 m .61192 .52437 L .63769 .50222 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45996 .59332 m .45267 .58703 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.48464 .58092 m .51123 .59356 L p
.48387 .5809 L 1 g
F P
s
P
p
.002 w
.51676 .5873 m .51123 .59356 L .48464 .58092 L p
1 g
F P
s
P
p
.002 w
.48464 .58092 m .48305 .58016 L .48666 .58092 L p
1 g
F P
s
P
p
.002 w
.48666 .58092 m .51676 .5873 L p
.48464 .58092 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58092 L p
1 g
F P
s
P
p
.51079 .57862 m .48904 .58092 L .48919 .58092 L 1 g
F
P
p
.002 w
.51676 .5873 m .48666 .58092 L p
.48904 .58092 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58085 L p
1 g
F P
s
P
p
.002 w
.5185 .58082 m .51695 .58661 L p
.5 .58315 L 1 g
F P
s
P
p
.5185 .58082 m .5 .58315 L .51096 .58085 L 1 g
F
P
p
.53128 .57265 m .51096 .58085 L .51512 .57997 L 1 g
F
P
p
.002 w
.51855 .57922 m .51873 .57995 L .51512 .57997 L p
1 g
F P
s
P
p
.51841 .57925 m .51512 .57997 L .51833 .57929 L 1 g
F
P
p
.53128 .57265 m .51512 .57997 L .51841 .57925 L 1 g
F
P
p
.002 w
.48305 .58016 m .48413 .57991 L p
.48507 .58011 L 1 g
F P
s
P
p
.002 w
.48904 .58092 m .48921 .57862 L p
.47706 .57762 L 1 g
F P
s
P
p
.002 w
.44829 .57209 m .45011 .5684 L p
.46934 .57526 L 1 g
F P
s
P
p
.002 w
.48305 .58016 m .47383 .57802 L p
.46934 .57526 L 1 g
F P
s
P
p
.002 w
.47383 .57802 m .44829 .57209 L p
.46934 .57526 L 1 g
F P
s
P
p
.002 w
.46829 .57462 m .46872 .57265 L p
.45827 .56847 L 1 g
F P
s
P
p
.47706 .57762 m .4796 .57849 L .48904 .58092 L 1 g
F
P
p
.4796 .57849 m .48149 .57913 L .48904 .58092 L 1 g
F
P
p
.48142 .57912 m .48218 .57936 L .48904 .58092 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.4796 .57849 m .48305 .58016 L p
.45011 .5684 L 1 g
F P
s
P
p
.002 w
.44862 .57969 m .44829 .57209 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46793 .57626 L p
1 g
F P
s
P
p
.002 w
.46793 .57626 m .4678 .57686 L p
.47218 .57722 L 1 g
F P
s
P
p
.48921 .57862 m .46793 .57626 L .47218 .57722 L 1 g
F
P
p
.48208 .57934 m .48256 .57949 L .48904 .58092 L 1 g
F
P
p
.48244 .57946 m .48284 .57958 L .48904 .58092 L 1 g
F
P
p
.48267 .57954 m .48309 .57965 L .48904 .58092 L 1 g
F
P
p
.48284 .5796 m .48332 .57972 L .48904 .58092 L 1 g
F
P
p
.002 w
.48208 .57933 m .48305 .58016 L .4796 .57849 L p
1 g
F P
s
P
p
.002 w
.48267 .57952 m .48305 .58016 L .48208 .57933 L p
1 g
F P
s
P
p
.002 w
.48298 .57962 m .48305 .58016 L .48267 .57952 L p
1 g
F P
s
P
p
.002 w
.48321 .57969 m .48305 .58016 L .48298 .57962 L p
1 g
F P
s
P
p
.002 w
.48344 .57975 m .48305 .58016 L .48321 .57969 L p
1 g
F P
s
P
p
.002 w
.4837 .57981 m .48305 .58016 L .48344 .57975 L p
1 g
F P
s
P
p
.47091 .57712 m .48526 .58015 L .48904 .58092 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51127 .56518 m .51685 .5723 L .48413 .57991 L p
1 g
F P
s
P
p
.002 w
.48413 .57991 m .48305 .58016 L .4837 .57981 L p
1 g
F P
s
P
p
.002 w
.4837 .57981 m .51127 .56518 L p
.48413 .57991 L 1 g
F P
s
P
p
.002 w
.45178 .56504 m .42173 .54572 L p
.43411 .55026 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45064 .5635 L p
1 g
F P
s
P
p
.46872 .57265 m .45064 .5635 L .45151 .56419 L 1 g
F
P
p
.43411 .55026 m .45064 .5635 L .45178 .56504 L 1 g
F
P
p
.002 w
.45217 .56472 m .45179 .56503 L p
.45064 .5635 L 1 g
F P
s
P
p
.002 w
.45179 .56503 m .45178 .56504 L p
.45064 .5635 L 1 g
F P
s
P
p
.002 w
.45064 .5635 m .45146 .56129 L p
.4444 .55516 L 1 g
F P
s
P
p
.002 w
.45011 .5684 m .45178 .56504 L .45595 .56706 L p
1 g
F P
s
P
p
.46872 .57265 m .45151 .56419 L .45781 .5682 L 1 g
F
P
p
.46872 .57265 m .45781 .5682 L .45827 .56847 L 1 g
F
P
p
.45151 .56419 m .45217 .56472 L .45823 .56846 L 1 g
F
P
p
.002 w
.45595 .56706 m .4796 .57849 L p
.46829 .57462 L 1 g
F P
s
P
p
.45011 .5684 m .45595 .56706 L .46829 .57462 L 1 g
F
P
p
.45827 .56847 m .45781 .5682 L .45823 .56846 L 1 g
F
P
p
.45151 .56419 m .45056 .56372 L .45217 .56472 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43844 .54719 L p
1 g
F P
s
P
p
.43411 .55026 m .44326 .55363 L .45064 .5635 L 1 g
F
P
p
.45146 .56129 m .43844 .54719 L .4444 .55516 L 1 g
F
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43844 .54719 m .43925 .54566 L p
.43452 .53631 L 1 g
F P
s
P
p
.002 w
.42173 .54572 m .43412 .5352 L p
.44038 .55257 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43243 .52883 L p
1 g
F P
s
P
p
.43925 .54566 m .43243 .52883 L .43256 .52933 L 1 g
F
P
p
.41362 .50561 m .42863 .51331 L .43243 .52883 L 1 g
F
P
p
.002 w
.433 .53115 m .43232 .53024 L p
.43243 .52883 L 1 g
F P
s
P
p
.002 w
.43232 .53024 m .41362 .50561 L p
.43243 .52883 L 1 g
F P
s
P
p
.002 w
.43243 .52883 m .43346 .52734 L p
.43319 .51972 L 1 g
F P
s
P
p
.43925 .54566 m .43256 .52933 L .43432 .5359 L 1 g
F
P
p
.43256 .52933 m .43238 .52891 L .433 .53115 L 1 g
F
P
p
.43256 .52933 m .433 .53115 L .43432 .5359 L 1 g
F
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43407 .50918 L p
1 g
F P
s
P
p
.42863 .51331 m .43352 .51582 L .43243 .52883 L 1 g
F
P
p
.43346 .52734 m .43407 .50918 L .43319 .51972 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43407 .50918 m .43485 .50826 L p
.43847 .49979 L 1 g
F P
s
P
p
.002 w
.41362 .50561 m .44096 .49448 L p
.43146 .51477 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44245 .4915 L p
1 g
F P
s
P
p
.43485 .50826 m .44245 .4915 L .44208 .49224 L 1 g
F
P
p
.43071 .45938 m .45151 .47367 L .44245 .4915 L 1 g
F
P
p
.002 w
.44152 .49332 m .4413 .49262 L p
.44245 .4915 L 1 g
F P
s
P
p
.002 w
.4413 .49262 m .43071 .45938 L p
.44245 .4915 L 1 g
F P
s
P
p
.43485 .50826 m .44237 .49158 L .43919 .49812 L 1 g
F
P
p
.002 w
.44245 .4915 m .44339 .4905 L p
.44942 .48472 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44245 .4915 m .47533 .49004 L .44152 .49332 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45785 .47653 L p
1 g
F P
s
P
p
.44339 .4905 m .45785 .47653 L .44942 .48472 L 1 g
F
P
p
.45151 .47367 m .45695 .47741 L .44245 .4915 L 1 g
F
P
p
.45695 .47741 m .47533 .49004 L .44245 .4915 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47462 .46862 m .47533 .49004 L p
.45656 .47714 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47757 .46716 L p
1 g
F P
s
P
p
.002 w
.51019 .49393 m .47533 .49004 L .47462 .46862 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.47757 .46716 m .51019 .49393 L .47462 .46862 L 1 g
F
P
p
.002 w
.47757 .46716 m .47786 .46667 L p
.48669 .46577 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .48669 .46577 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46716 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.52244 .46716 m .54205 .50532 L .51733 .46651 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54218 .47656 L p
1 g
F P
s
P
p
.52214 .46667 m .54218 .47656 L .53056 .47103 L 1 g
F
P
p
.52367 .46775 m .54205 .50532 L .52244 .46716 L 1 g
F
P
p
.002 w
.52244 .46716 m .52214 .46667 L p
.53056 .47103 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.51932 .45885 m .52675 .46156 L p
.54205 .50532 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56589 .50914 L p
1 g
F P
s
P
p
.55661 .4905 m .56589 .50914 L .56061 .49815 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56752 .52876 L p
1 g
F P
s
P
p
.002 w
.58248 .54389 m .56811 .55114 L p
.56752 .52876 L 1 g
F P
s
P
p
.002 w
.56737 .52313 m .56875 .52503 L p
.56752 .52876 L 1 g
F P
s
P
p
.002 w
.56875 .52503 m .58248 .54389 L p
.56752 .52876 L 1 g
F P
s
P
p
.002 w
.56752 .52876 m .56654 .52734 L p
.56475 .53713 L 1 g
F P
s
P
p
.56515 .50826 m .56752 .52876 L .56737 .52313 L 1 g
F
P
p
.002 w
.56733 .52246 m .59255 .4967 L p
.56737 .52313 L 1 g
F P
s
P
p
.002 w
.56219 .47505 m .59255 .4967 L .57066 .51906 L p
1 g
F P
s
P
p
.002 w
.57066 .51906 m .56733 .52246 L p
.56589 .50914 L 1 g
F P
s
P
p
.56219 .47505 m .57066 .51906 L .56589 .50914 L 1 g
F
P
p
.56515 .50826 m .56737 .52313 L .56733 .52246 L 1 g
F
P
p
.56731 .52224 m .56733 .52246 L .56732 .52236 L 1 g
F
P
p
.56515 .50826 m .56733 .52246 L .56731 .52224 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.58248 .54389 m .56737 .52313 L p
.59255 .4967 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.5605 .47384 m .56219 .47505 L p
.56707 .52272 L 1 g
F P
s
P
p
.002 w
.56733 .52246 m .56707 .52272 L p
.56219 .47505 L 1 g
F P
s
P
p
.002 w
.55727 .4912 m .55661 .4905 L p
.56061 .49815 L 1 g
F P
s
P
p
.55727 .4912 m .56707 .52272 L .55283 .48692 L 1 g
F
P
p
.56366 .49737 m .56499 .50728 L .55727 .4912 L 1 g
F
P
p
.56499 .50728 m .56707 .52272 L .55727 .4912 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55727 .4912 L p
1 g
F P
s
P
p
.56061 .49815 m .56713 .51061 L .55727 .4912 L 1 g
F
P
p
.56732 .52236 m .56733 .52246 L .56735 .52254 L 1 g
F
P
p
.56733 .52246 m .56737 .52313 L .56736 .52271 L 1 g
F
P
p
.56733 .52246 m .56736 .52271 L .56735 .52254 L 1 g
F
P
p
.002 w
.56737 .52313 m .56707 .52272 L .56733 .52246 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54933 .5634 L p
1 g
F P
s
P
p
.002 w
.55375 .57525 m .53606 .57762 L p
.54933 .5634 L 1 g
F P
s
P
p
.002 w
.55079 .56184 m .55091 .5624 L p
.54933 .5634 L 1 g
F P
s
P
p
.002 w
.55091 .5624 m .55375 .57525 L p
.54933 .5634 L 1 g
F P
s
P
p
.002 w
.54933 .5634 m .54854 .56129 L p
.5404 .56905 L 1 g
F P
s
P
p
.56075 .54566 m .54933 .5634 L .55079 .56184 L 1 g
F
P
p
.002 w
.55334 .55859 m .58248 .54389 L p
.55079 .56184 L 1 g
F P
s
P
p
.55107 .56148 m .55079 .56184 L .55097 .56164 L 1 g
F
P
p
.56075 .54566 m .55079 .56184 L .55107 .56148 L 1 g
F
P
p
.002 w
.55375 .57525 m .55079 .56184 L p
.58248 .54389 L 1 g
F P
s
P
p
.56075 .54566 m .54954 .56398 L .55463 .55676 L 1 g
F
P
p
.002 w
.55079 .56184 m .5504 .56007 L .55334 .55859 L p
1 g
F P
s
P
p
.002 w
.53606 .57762 m .51873 .57995 L p
.52249 .57782 L 1 g
F P
s
P
p
.002 w
.53169 .57455 m .53128 .57265 L p
.51828 .57932 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57455 L p
1 g
F P
s
P
p
.54933 .5634 m .54251 .57071 L .53169 .57455 L 1 g
F
P
p
.54251 .57071 m .53606 .57762 L .52249 .57782 L 1 g
F
P
p
.002 w
.53169 .57455 m .5322 .57686 L p
.5404 .56905 L 1 g
F P
s
P
p
.54854 .56129 m .53169 .57455 L .5404 .56905 L 1 g
F
P
p
.55079 .56184 m .54933 .5634 L .52249 .57782 L 1 g
F
P
p
.54933 .5634 m .53169 .57455 L .52249 .57782 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5504 .56007 m .55079 .56184 L p
.51873 .57995 L 1 g
F P
s
P
p
.002 w
.51873 .57995 m .5185 .58082 L p
.51168 .58069 L 1 g
F P
s
P
p
.51096 .58085 m .5 .58315 L .48904 .58092 L 1 g
F
P
p
.002 w
.51695 .58661 m .51676 .5873 L p
.48904 .58092 L 1 g
F P
s
P
p
.49947 .58088 m .48904 .58093 L .49904 .58097 L 1 g
F
P
p
.51079 .57862 m .48919 .58092 L .49947 .58088 L 1 g
F
P
p
.48919 .58092 m .48904 .58093 L .49947 .58088 L 1 g
F
P
p
.002 w
.51099 .58135 m .51079 .57862 L p
.49818 .58114 L 1 g
F P
s
P
p
.002 w
.48305 .58016 m .51512 .57997 L p
.51168 .58069 L 1 g
F P
s
P
p
.002 w
.51512 .57997 m .51873 .57995 L p
.51168 .58069 L 1 g
F P
s
P
p
.002 w
.48666 .58092 m .48305 .58016 L p
.5185 .58082 L 1 g
F P
s
P
p
.002 w
.51676 .5873 m .51873 .57995 L .55375 .57525 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5321 .57639 L p
1 g
F P
s
P
p
.002 w
.5321 .57639 m .53169 .57455 L p
.52205 .57851 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51873 .57995 m .51685 .5723 L .5504 .56007 L p
1 g
F P
s
P
p
.52205 .57851 m .51111 .583 L .5321 .57639 L 1 g
F
P
p
.51828 .57932 m .51111 .583 L .53169 .57455 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54933 .5634 L p
1 g
F P
s
P
p
.5404 .56905 m .5322 .57686 L .54933 .5634 L 1 g
F
P
p
.002 w
.54933 .5634 m .54954 .56398 L p
.55097 .56164 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56811 .55114 m .55853 .55597 L p
.56776 .53812 L 1 g
F P
s
P
p
.002 w
.55853 .55597 m .55334 .55859 L p
.56148 .54703 L 1 g
F P
s
P
p
.56776 .53812 m .55853 .55597 L .56148 .54703 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56148 .54703 L p
1 g
F P
s
P
p
.56654 .52734 m .56148 .54703 L .56475 .53713 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56148 .54703 L p
1 g
F P
s
P
p
.002 w
.56148 .54703 m .56075 .54566 L p
.55463 .55676 L 1 g
F P
s
P
p
.55463 .55676 m .54998 .56518 L .56148 .54703 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56737 .52313 m .56776 .53812 L .5504 .56007 L 1 g
F
P
p
.002 w
.55334 .55859 m .5504 .56007 L p
.56776 .53812 L 1 g
F P
s
P
p
.002 w
.56148 .54703 m .56257 .5491 L p
.56475 .53713 L 1 g
F P
s
P
p
.002 w
.54954 .56398 m .54998 .56518 L p
.55463 .55676 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56752 .52876 L p
1 g
F P
s
P
p
.56475 .53713 m .56257 .5491 L .56752 .52876 L 1 g
F
P
p
.002 w
.56752 .52876 m .56854 .53025 L p
.56735 .52254 L 1 g
F P
s
P
p
.002 w
.56707 .52272 m .56737 .52313 L p
.5504 .56007 L 1 g
F P
s
P
p
.002 w
.56589 .50914 m .56713 .51061 L p
.56061 .49815 L 1 g
F P
s
P
p
.5605 .47384 m .56366 .49737 L .55727 .4912 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55727 .4912 L p
1 g
F P
s
P
p
.54174 .47608 m .55727 .4912 L .55435 .48838 L 1 g
F
P
p
.54174 .47608 m .55763 .49159 L .54938 .48356 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55283 .48692 m .55414 .48469 L p
.55727 .4912 L 1 g
F P
s
P
p
.002 w
.55414 .48469 m .5605 .47384 L p
.55727 .4912 L 1 g
F P
s
P
p
.002 w
.55727 .4912 m .55763 .49159 L p
.55435 .48838 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56707 .52272 m .54205 .50532 L .55283 .48692 L p
1 g
F P
s
P
p
.002 w
.55283 .48692 m .54205 .50532 L p
.52675 .46156 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52675 .46156 m .5605 .47384 L .55283 .48692 L p
1 g
F P
s
P
p
.002 w
.55763 .49159 m .55834 .49233 L p
.54938 .48356 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46716 L p
1 g
F P
s
P
p
.53056 .47103 m .54302 .47747 L .52244 .46716 L 1 g
F
P
p
.51932 .45885 m .52345 .46729 L .52244 .46716 L 1 g
F
P
p
.5 .4634 m .52244 .46716 L .51904 .46673 L 1 g
F
P
p
.5 .4634 m .52255 .46734 L .51071 .46546 L 1 g
F
P
p
.002 w
.51733 .46651 m .51774 .46493 L p
.52244 .46716 L 1 g
F P
s
P
p
.002 w
.51774 .46493 m .51932 .45885 L p
.52244 .46716 L 1 g
F P
s
P
p
.52345 .46729 m .52367 .46775 L .52244 .46716 L 1 g
F
P
p
.002 w
.54218 .47656 m .54302 .47747 L p
.53056 .47103 L 1 g
F P
s
P
p
.002 w
.52244 .46716 m .52255 .46734 L p
.51904 .46673 L 1 g
F P
s
P
p
.002 w
.54205 .50532 m .51019 .49393 L .51733 .46651 L p
1 g
F P
s
P
p
.002 w
.47412 .45382 m .51932 .45885 L .51733 .46651 L p
1 g
F P
s
P
p
.002 w
.51733 .46651 m .51019 .49393 L p
.48023 .46061 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.47412 .45382 m .51733 .46651 L .48023 .46061 L 1 g
F
P
p
.002 w
.52255 .46734 m .52282 .46778 L p
.51071 .46546 L 1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .46442 L p
.48669 .46577 L 1 g
F P
s
P
p
.47412 .45382 m .48348 .46422 L .47757 .46716 L 1 g
F
P
p
.45826 .47608 m .47757 .46716 L .46967 .47108 L 1 g
F
P
p
.002 w
.47462 .46862 m .47458 .46761 L p
.47757 .46716 L 1 g
F P
s
P
p
.002 w
.47458 .46761 m .47412 .45382 L p
.47757 .46716 L 1 g
F P
s
P
p
.48348 .46422 m .48509 .46601 L .47757 .46716 L 1 g
F
P
p
.48509 .46601 m .51019 .49393 L .47757 .46716 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47757 .46716 L p
1 g
F P
s
P
p
.48669 .46577 m .5 .46442 L .47757 .46716 L 1 g
F
P
p
.002 w
.47757 .46716 m .47718 .46778 L p
.46967 .47108 L 1 g
F P
s
P
p
.002 w
.43071 .45938 m .47412 .45382 L .47462 .46862 L p
1 g
F P
s
P
p
.002 w
.45785 .47653 m .45826 .47608 L p
.46599 .47269 L 1 g
F P
s
P
p
.43071 .45938 m .47462 .46862 L .45656 .47714 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45785 .47653 L p
1 g
F P
s
P
p
.46599 .47269 m .47718 .46778 L .45785 .47653 L 1 g
F
P
p
.002 w
.45785 .47653 m .45698 .47747 L p
.44942 .48472 L 1 g
F P
s
P
p
.002 w
.44245 .4915 m .44237 .49158 L p
.44208 .49224 L 1 g
F P
s
P
p
.002 w
.41362 .50561 m .3945 .47462 L p
.44123 .49392 L 1 g
F P
s
P
p
.002 w
.44096 .49448 m .41362 .50561 L p
.44123 .49392 L 1 g
F P
s
P
p
.002 w
.3945 .47462 m .43071 .45938 L .44152 .49332 L p
1 g
F P
s
P
p
.002 w
.44152 .49332 m .44178 .49414 L p
.44123 .49392 L 1 g
F P
s
P
p
.3945 .47462 m .44152 .49332 L .44123 .49392 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43342 .50996 L p
1 g
F P
s
P
p
.002 w
.43342 .50996 m .43407 .50918 L p
.43744 .50171 L 1 g
F P
s
P
p
.43744 .50171 m .44166 .49233 L .43342 .50996 L 1 g
F
P
p
.002 w
.44237 .49158 m .44166 .49233 L p
.43919 .49812 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44245 .4915 L p
1 g
F P
s
P
p
.44942 .48472 m .45698 .47747 L .44245 .4915 L 1 g
F
P
p
.002 w
.47533 .49004 m .44178 .49414 L .44152 .49332 L p
1 g
F P
s
P
p
.002 w
.44178 .49414 m .44096 .49448 L p
.44123 .49392 L 1 g
F P
s
P
p
.002 w
.44178 .49414 m .45455 .52661 L p
.43146 .51477 L 1 g
F P
s
P
p
.002 w
.44096 .49448 m .44178 .49414 L p
.43146 .51477 L 1 g
F P
s
P
p
.43847 .49979 m .44166 .49233 L .43407 .50918 L 1 g
F
P
p
.002 w
.43407 .50918 m .43287 .51061 L p
.43319 .51972 L 1 g
F P
s
P
p
.43243 .52883 m .45455 .52661 L .433 .53115 L 1 g
F
P
p
.43352 .51582 m .45455 .52661 L .43243 .52883 L 1 g
F
P
p
.002 w
.39402 .52287 m .41362 .50561 L .43232 .53024 L p
1 g
F P
s
P
p
.002 w
.43232 .53024 m .433 .53115 L p
.43216 .53333 L 1 g
F P
s
P
p
.43216 .53333 m .433 .53115 L .43372 .53375 L 1 g
F
P
p
.39402 .52287 m .43232 .53024 L .43216 .53333 L 1 g
F
P
p
.002 w
.42173 .54572 m .39402 .52287 L p
.43372 .53375 L 1 g
F P
s
P
p
.002 w
.43412 .5352 m .42173 .54572 L p
.43372 .53375 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43778 .54843 L p
1 g
F P
s
P
p
.002 w
.43778 .54843 m .43844 .54719 L p
.43539 .53979 L 1 g
F P
s
P
p
.43539 .53979 m .43146 .53025 L .43778 .54843 L 1 g
F
P
p
.002 w
.433 .53115 m .43531 .53419 L p
.43372 .53375 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43238 .52891 L p
1 g
F P
s
P
p
.002 w
.43238 .52891 m .43243 .52883 L p
.43248 .52694 L 1 g
F P
s
P
p
.43248 .52694 m .43287 .51061 L .43238 .52891 L 1 g
F
P
p
.43319 .51972 m .43287 .51061 L .43243 .52883 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45455 .52661 m .43531 .53419 L .433 .53115 L p
1 g
F P
s
P
p
.002 w
.43243 .52883 m .43238 .52891 L p
.43256 .52933 L 1 g
F P
s
P
p
.002 w
.43238 .52891 m .43146 .53025 L p
.43432 .5359 L 1 g
F P
s
P
p
.002 w
.43531 .53419 m .43412 .5352 L p
.43372 .53375 L 1 g
F P
s
P
p
.002 w
.43531 .53419 m .45875 .55932 L p
.44038 .55257 L 1 g
F P
s
P
p
.002 w
.43412 .5352 m .43531 .53419 L p
.44038 .55257 L 1 g
F P
s
P
p
.43452 .53631 m .43146 .53025 L .43844 .54719 L 1 g
F
P
p
.002 w
.43844 .54719 m .43743 .5491 L p
.4444 .55516 L 1 g
F P
s
P
p
.002 w
.45875 .55932 m .45217 .56472 L p
.45064 .5635 L 1 g
F P
s
P
p
.44326 .55363 m .45875 .55932 L .45064 .5635 L 1 g
F
P
p
.002 w
.45178 .56504 m .44829 .57209 L .41519 .55979 L p
1 g
F P
s
P
p
.002 w
.41519 .55979 m .42173 .54572 L .45178 .56504 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45064 .5635 L p
1 g
F P
s
P
p
.4444 .55516 m .43743 .5491 L .45064 .5635 L 1 g
F
P
p
.002 w
.45064 .5635 m .45056 .56372 L p
.45151 .56419 L 1 g
F P
s
P
p
.002 w
.45178 .56504 m .45217 .56472 L p
.45561 .56684 L 1 g
F P
s
P
p
.002 w
.4796 .57849 m .45178 .56504 L p
.48208 .57933 L 1 g
F P
s
P
p
.002 w
.45056 .56372 m .45002 .56518 L p
.45823 .56846 L 1 g
F P
s
P
p
.002 w
.45875 .55932 m .48208 .57933 L p
.45561 .56684 L 1 g
F P
s
P
p
.002 w
.45217 .56472 m .45875 .55932 L p
.45561 .56684 L 1 g
F P
s
P
p
.4796 .57849 m .48142 .57912 L .48149 .57913 L 1 g
F
P
p
.48142 .57912 m .48208 .57934 L .48218 .57936 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45875 .55932 m .46848 .55561 L .48267 .57952 L p
1 g
F P
s
P
p
.002 w
.48208 .57933 m .45875 .55932 L p
.48267 .57952 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.46848 .55561 m .4799 .55433 L .48298 .57962 L p
1 g
F P
s
P
p
.002 w
.48267 .57952 m .46848 .55561 L p
.48298 .57962 L 1 g
F P
s
P
p
.48208 .57934 m .48244 .57946 L .48256 .57949 L 1 g
F
P
p
.48244 .57946 m .48267 .57954 L .48284 .57958 L 1 g
F
P
p
.002 w
.4799 .55433 m .49171 .55565 L .48321 .57969 L p
1 g
F P
s
P
p
.002 w
.48298 .57962 m .4799 .55433 L p
.48321 .57969 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.49171 .55565 m .50258 .55941 L .48344 .57975 L p
1 g
F P
s
P
p
.002 w
.48321 .57969 m .49171 .55565 L p
.48344 .57975 L 1 g
F P
s
P
p
.48267 .57954 m .48284 .5796 L .48309 .57965 L 1 g
F
P
p
.48284 .5796 m .48296 .57964 L .48332 .57972 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50258 .55941 m .51127 .56518 L .4837 .57981 L p
1 g
F P
s
P
p
.002 w
.48344 .57975 m .50258 .55941 L p
.4837 .57981 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57462 L p
1 g
F P
s
P
p
.45827 .56847 m .45002 .56518 L .46829 .57462 L 1 g
F
P
p
.47706 .57762 m .47091 .57712 L .48296 .57964 L 1 g
F
P
p
.002 w
.51512 .57997 m .48526 .58015 L p
.51855 .57922 L 1 g
F P
s
P
p
.002 w
.48526 .58015 m .48305 .58016 L p
.48507 .58011 L 1 g
F P
s
P
p
.51855 .57922 m .48526 .58015 L .48507 .58011 L 1 g
F
P
p
.47091 .57712 m .47007 .57705 L .48526 .58015 L 1 g
F
P
p
.002 w
.51123 .59356 m .50275 .5981 L .48387 .5809 L p
1 g
F P
s
P
p
.002 w
.48387 .5809 m .48305 .58016 L .48464 .58092 L p
1 g
F P
s
P
p
.002 w
.45267 .58703 m .44862 .57969 L .48305 .58016 L closepath p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58094 L p
1 g
F P
s
P
p
.002 w
.48904 .58094 m .48904 .58092 L p
.48771 .58066 L 1 g
F P
s
P
p
.48771 .58066 m .4678 .57686 L .48904 .58094 L 1 g
F
P
p
.002 w
.51685 .5723 m .51855 .57922 L p
.48507 .58011 L 1 g
F P
s
P
p
.002 w
.48413 .57991 m .51685 .5723 L p
.48507 .58011 L 1 g
F P
s
P
p
.002 w
.51096 .58085 m .51111 .583 L p
.51833 .57929 L 1 g
F P
s
P
p
.47007 .57705 m .4678 .57686 L .48904 .58092 L 1 g
F
P
p
.002 w
.48904 .58092 m .48904 .58093 L p
.48919 .58092 L 1 g
F P
s
P
p
.002 w
.48904 .58093 m .48889 .583 L p
.49904 .58097 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51099 .58135 L p
1 g
F P
s
P
p
.49818 .58114 m .48889 .583 L .51099 .58135 L 1 g
F
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44829 .57209 m .44862 .57969 L .41619 .5748 L p
1 g
F P
s
P
p
.002 w
.41619 .5748 m .41519 .55979 L .44829 .57209 L p
1 g
F P
s
P
p
.002 w
.51123 .59356 m .51676 .5873 L .54953 .58968 L p
1 g
F P
s
P
p
.002 w
.55375 .57525 m .54953 .58968 L .51676 .5873 L p
1 g
F P
s
P
p
.002 w
.54953 .58968 m .55375 .57525 L .58687 .56627 L p
1 g
F P
s
P
p
.002 w
.37868 .44239 m .34942 .47009 L .334 .44208 L p
1 g
F P
s
P
p
.002 w
.334 .44208 m .36671 .41011 L .37868 .44239 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55062 .29488 m .4799 .28702 L .483 .26506 L p
1 g
F P
s
P
p
.002 w
.483 .26506 m .55253 .27279 L .55062 .29488 L p
1 g
F P
s
P
p
.002 w
.61448 .31999 m .55062 .29488 L .55253 .27279 L p
1 g
F P
s
P
p
.002 w
.63394 .43989 m .65897 .4783 L .63769 .50222 L p
1 g
F P
s
P
p
.002 w
.65897 .4783 m .63394 .43989 L .64843 .41122 L p
1 g
F P
s
P
p
.002 w
.41151 .35473 m .35895 .37899 L .35556 .35008 L p
1 g
F P
s
P
p
.002 w
.35556 .35008 m .41048 .32412 L .41151 .35473 L p
1 g
F P
s
P
p
.002 w
.61017 .34634 m .65818 .38377 L .64843 .41122 L p
1 g
F P
s
P
p
.002 w
.65818 .38377 m .61017 .34634 L .61448 .31999 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.42173 .54572 m .41519 .55979 L .38491 .54374 L p
1 g
F P
s
P
p
.002 w
.38491 .54374 m .39402 .52287 L .42173 .54572 L p
1 g
F P
s
P
p
.002 w
.58248 .54389 m .58687 .56627 L .55375 .57525 L p
1 g
F P
s
P
p
.002 w
.58687 .56627 m .58248 .54389 L .61192 .52437 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.47731 .31408 m .41048 .32412 L .41216 .29748 L p
1 g
F P
s
P
p
.002 w
.41216 .29748 m .4799 .28702 L .47731 .31408 L p
1 g
F P
s
P
p
.002 w
.55062 .29488 m .61448 .31999 L .61017 .34634 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.3945 .47462 m .36964 .49735 L .34942 .47009 L p
1 g
F P
s
P
p
.002 w
.34942 .47009 m .37868 .44239 L .3945 .47462 L p
1 g
F P
s
P
p
.002 w
.61511 .46874 m .63769 .50222 L .61192 .52437 L p
1 g
F P
s
P
p
.002 w
.63769 .50222 m .61511 .46874 L .63394 .43989 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.41529 .38831 m .36671 .41011 L .35895 .37899 L p
1 g
F P
s
P
p
.002 w
.35895 .37899 m .41151 .35473 L .41529 .38831 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.60236 .37598 m .64843 .41122 L .63394 .43989 L p
1 g
F P
s
P
p
.002 w
.64843 .41122 m .60236 .37598 L .61017 .34634 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.41362 .50561 m .39402 .52287 L .36964 .49735 L p
1 g
F P
s
P
p
.002 w
.36964 .49735 m .3945 .47462 L .41362 .50561 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.59255 .4967 m .61192 .52437 L .58248 .54389 L p
1 g
F P
s
P
p
.002 w
.61192 .52437 m .59255 .4967 L .61511 .46874 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.5471 .32185 m .47731 .31408 L .4799 .28702 L p
1 g
F P
s
P
p
.002 w
.4799 .28702 m .55062 .29488 L .5471 .32185 L p
1 g
F P
s
P
p
.002 w
.61017 .34634 m .5471 .32185 L .55062 .29488 L p
1 g
F P
s
P
p
.002 w
.51685 .5723 m .51127 .56518 L .53963 .54583 L p
1 g
F P
s
P
p
.002 w
.53963 .54583 m .5504 .56007 L .51685 .5723 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.47536 .34545 m .41151 .35473 L .41048 .32412 L p
1 g
F P
s
P
p
.002 w
.41048 .32412 m .47731 .31408 L .47536 .34545 L p
1 g
F P
s
P
p
.002 w
.5504 .56007 m .53963 .54583 L .56707 .52272 L p
1 g
F P
s
P
p
.002 w
.5471 .32185 m .61017 .34634 L .60236 .37598 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46848 .55561 m .45875 .55932 L .43531 .53419 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.51127 .56518 m .50258 .55941 L .52249 .53419 L p
1 g
F P
s
P
p
.002 w
.52249 .53419 m .53963 .54583 L .51127 .56518 L p
1 g
F P
s
P
p
.002 w
.42177 .42364 m .37868 .44239 L .36671 .41011 L p
1 g
F P
s
P
p
.002 w
.36671 .41011 m .41529 .38831 L .42177 .42364 L p
1 g
F P
s
P
p
.002 w
.59122 .4079 m .63394 .43989 L .61511 .46874 L p
1 g
F P
s
P
p
.002 w
.63394 .43989 m .59122 .4079 L .60236 .37598 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4799 .55433 m .46848 .55561 L .45455 .52661 L p
1 g
F P
s
P
p
.002 w
.43531 .53419 m .45455 .52661 L .46848 .55561 L p
1 g
F P
s
P
p
.002 w
.50258 .55941 m .49171 .55565 L .50087 .52659 L p
1 g
F P
s
P
p
.002 w
.50087 .52659 m .52249 .53419 L .50258 .55941 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.49171 .55565 m .4799 .55433 L .47729 .52396 L p
1 g
F P
s
P
p
.002 w
.45455 .52661 m .47729 .52396 L .4799 .55433 L p
1 g
F P
s
P
p
.002 w
.47729 .52396 m .50087 .52659 L .49171 .55565 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53963 .54583 m .52249 .53419 L .54205 .50532 L p
1 g
F P
s
P
p
.002 w
.54205 .50532 m .56707 .52272 L .53963 .54583 L p
1 g
F P
s
P
p
.002 w
.43071 .45938 m .3945 .47462 L .37868 .44239 L p
1 g
F P
s
P
p
.002 w
.37868 .44239 m .42177 .42364 L .43071 .45938 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.5771 .44094 m .61511 .46874 L .59255 .4967 L p
1 g
F P
s
P
p
.002 w
.61511 .46874 m .5771 .44094 L .59122 .4079 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.54203 .35288 m .47536 .34545 L .47731 .31408 L p
1 g
F P
s
P
p
.002 w
.47731 .31408 m .5471 .32185 L .54203 .35288 L p
1 g
F P
s
P
p
.002 w
.60236 .37598 m .54203 .35288 L .5471 .32185 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.47414 .38008 m .41529 .38831 L .41151 .35473 L p
1 g
F P
s
P
p
.002 w
.41151 .35473 m .47536 .34545 L .47414 .38008 L p
1 g
F P
s
P
p
.002 w
.54203 .35288 m .60236 .37598 L .59122 .4079 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59255 .4967 m .5605 .47384 L .5771 .44094 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.47729 .52396 m .45455 .52661 L .44178 .49414 L p
1 g
F P
s
P
p
.002 w
.52249 .53419 m .50087 .52659 L .51019 .49393 L p
1 g
F P
s
P
p
.002 w
.51019 .49393 m .54205 .50532 L .52249 .53419 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50087 .52659 m .47729 .52396 L .47533 .49004 L p
1 g
F P
s
P
p
.002 w
.44178 .49414 m .47533 .49004 L .47729 .52396 L p
1 g
F P
s
P
p
.002 w
.47533 .49004 m .51019 .49393 L .50087 .52659 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47372 .41667 m .42177 .42364 L .41529 .38831 L p
1 g
F P
s
P
p
.002 w
.41529 .38831 m .47414 .38008 L .47372 .41667 L p
1 g
F P
s
P
p
.002 w
.53555 .38692 m .59122 .4079 L .5771 .44094 L p
1 g
F P
s
P
p
.002 w
.59122 .4079 m .53555 .38692 L .54203 .35288 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.004 w
.47616 .64099 m
.47734 .63049 L
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53555 .38692 m .47414 .38008 L .47536 .34545 L p
1 g
F P
s
P
p
.002 w
.47536 .34545 m .54203 .35288 L .53555 .38692 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47412 .45382 m .43071 .45938 L .42177 .42364 L p
1 g
F P
s
P
p
.002 w
.42177 .42364 m .47372 .41667 L .47412 .45382 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.52788 .42271 m .5771 .44094 L .5605 .47384 L p
1 g
F P
s
P
p
.002 w
.5771 .44094 m .52788 .42271 L .53555 .38692 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.5605 .47384 m .51932 .45885 L .52788 .42271 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.52788 .42271 m .47372 .41667 L .47414 .38008 L p
1 g
F P
s
P
p
.002 w
.47414 .38008 m .53555 .38692 L .52788 .42271 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51932 .45885 m .47412 .45382 L .47372 .41667 L p
1 g
F P
s
P
p
.002 w
.47372 .41667 m .52788 .42271 L .51932 .45885 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .44182 .70739 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .47317 .66731 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.526357)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.526357)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.54149 .42946 m .50732 .423 L .49849 .45017 L p
1 g
F P
s
P
p
.002 w
.46058 .43244 m .49849 .45017 L .50732 .423 L p
1 g
F P
s
P
p
.002 w
.50732 .423 m .47571 .40816 L .46058 .43244 L p
1 g
F P
s
P
p
.002 w
.50732 .423 m .54149 .42946 L .54254 .4009 L p
1 g
F P
s
P
p
.002 w
.54254 .4009 m .51598 .39595 L .50732 .423 L p
1 g
F P
s
P
p
.002 w
.47571 .40816 m .50732 .423 L .51598 .39595 L p
1 g
F P
s
P
p
.002 w
.53945 .45802 m .49849 .45017 L .48967 .47697 L p
1 g
F P
s
P
p
.002 w
.44633 .4568 m .48967 .47697 L .49849 .45017 L p
1 g
F P
s
P
p
.002 w
.49849 .45017 m .46058 .43244 L .44633 .4568 L p
1 g
F P
s
P
p
.002 w
.49849 .45017 m .53945 .45802 L .54149 .42946 L p
1 g
F P
s
P
p
.002 w
.42918 .4064 m .46058 .43244 L .47571 .40816 L p
1 g
F P
s
P
p
.002 w
.47571 .40816 m .44966 .38631 L .42918 .4064 L p
1 g
F P
s
P
p
.002 w
.44966 .38631 m .47571 .40816 L .49145 .38439 L p
1 g
F P
s
P
p
.002 w
.51598 .39595 m .49145 .38439 L .47571 .40816 L p
1 g
F P
s
P
p
.002 w
.51598 .39595 m .54254 .4009 L .54255 .37287 L p
1 g
F P
s
P
p
.002 w
.54255 .37287 m .52433 .36952 L .51598 .39595 L p
1 g
F P
s
P
p
.002 w
.49145 .38439 m .51598 .39595 L .52433 .36952 L p
1 g
F P
s
P
p
.002 w
.41028 .42724 m .44633 .4568 L .46058 .43244 L p
1 g
F P
s
P
p
.002 w
.46058 .43244 m .42918 .4064 L .41028 .42724 L p
1 g
F P
s
P
p
.002 w
.57503 .42686 m .54149 .42946 L .53945 .45802 L p
1 g
F P
s
P
p
.002 w
.54149 .42946 m .57503 .42686 L .56853 .39871 L p
1 g
F P
s
P
p
.002 w
.56853 .39871 m .54254 .4009 L .54149 .42946 L p
1 g
F P
s
P
p
.002 w
.49145 .38439 m .47133 .36732 L .44966 .38631 L p
1 g
F P
s
P
p
.002 w
.47133 .36732 m .49145 .38439 L .50751 .36157 L p
1 g
F P
s
P
p
.002 w
.52433 .36952 m .50751 .36157 L .49145 .38439 L p
1 g
F P
s
P
p
.002 w
.43323 .48078 m .48101 .50293 L .48967 .47697 L p
1 g
F P
s
P
p
.002 w
.48967 .47697 m .44633 .4568 L .43323 .48078 L p
1 g
F P
s
P
p
.002 w
.53643 .48606 m .48967 .47697 L .48101 .50293 L p
1 g
F P
s
P
p
.002 w
.48967 .47697 m .53643 .48606 L .53945 .45802 L p
1 g
F P
s
P
p
.002 w
.57971 .45517 m .53945 .45802 L .53643 .48606 L p
1 g
F P
s
P
p
.002 w
.53945 .45802 m .57971 .45517 L .57503 .42686 L p
1 g
F P
s
P
p
.002 w
.54254 .4009 m .56853 .39871 L .56034 .37125 L p
1 g
F P
s
P
p
.002 w
.56034 .37125 m .54255 .37287 L .54254 .4009 L p
1 g
F P
s
P
p
.002 w
.39335 .44844 m .43323 .48078 L .44633 .4568 L p
1 g
F P
s
P
p
.002 w
.44633 .4568 m .41028 .42724 L .39335 .44844 L p
1 g
F P
s
P
p
.002 w
.52433 .36952 m .54255 .37287 L .54152 .34589 L p
1 g
F P
s
P
p
.002 w
.54152 .34589 m .5322 .3442 L .52433 .36952 L p
1 g
F P
s
P
p
.002 w
.50751 .36157 m .52433 .36952 L .5322 .3442 L p
1 g
F P
s
P
p
.002 w
.48101 .50293 m .53249 .51307 L .53643 .48606 L p
1 g
F P
s
P
p
.002 w
.58247 .48311 m .53643 .48606 L .53249 .51307 L p
1 g
F P
s
P
p
.002 w
.53643 .48606 m .58247 .48311 L .57971 .45517 L p
1 g
F P
s
P
p
.002 w
.4074 .37428 m .42918 .4064 L .44966 .38631 L p
1 g
F P
s
P
p
.002 w
.44966 .38631 m .43179 .35939 L .4074 .37428 L p
1 g
F P
s
P
p
.002 w
.43179 .35939 m .44966 .38631 L .47133 .36732 L p
1 g
F P
s
P
p
.002 w
.50751 .36157 m .4938 .34979 L .47133 .36732 L p
1 g
F P
s
P
p
.002 w
.4938 .34979 m .50751 .36157 L .52361 .34012 L p
1 g
F P
s
P
p
.002 w
.5322 .3442 m .52361 .34012 L .50751 .36157 L p
1 g
F P
s
P
p
.002 w
.47133 .36732 m .45769 .34633 L .43179 .35939 L p
1 g
F P
s
P
p
.002 w
.45769 .34633 m .47133 .36732 L .4938 .34979 L p
1 g
F P
s
P
p
.002 w
.54255 .37287 m .56034 .37125 L .55059 .345 L p
1 g
F P
s
P
p
.002 w
.55059 .345 m .54152 .34589 L .54255 .37287 L p
1 g
F P
s
P
p
.002 w
.38503 .39075 m .41028 .42724 L .42918 .4064 L p
1 g
F P
s
P
p
.002 w
.42918 .4064 m .4074 .37428 L .38503 .39075 L p
1 g
F P
s
P
p
.002 w
.53249 .51307 m .48101 .50293 L .47267 .52754 L p
1 g
F P
s
P
p
.002 w
.42156 .50393 m .47267 .52754 L .48101 .50293 L p
1 g
F P
s
P
p
.002 w
.48101 .50293 m .43323 .48078 L .42156 .50393 L p
1 g
F P
s
P
p
.002 w
.60467 .41524 m .57503 .42686 L .57971 .45517 L p
1 g
F P
s
P
p
.002 w
.57503 .42686 m .60467 .41524 L .59138 .38947 L p
1 g
F P
s
P
p
.002 w
.59138 .38947 m .56853 .39871 L .57503 .42686 L p
1 g
F P
s
P
p
.002 w
.56853 .39871 m .59138 .38947 L .57587 .36477 L p
1 g
F P
s
P
p
.002 w
.57587 .36477 m .56034 .37125 L .56853 .39871 L p
1 g
F P
s
P
p
.002 w
.4938 .34979 m .48462 .33536 L .45769 .34633 L p
1 g
F P
s
P
p
.002 w
.48462 .33536 m .4938 .34979 L .51664 .33407 L p
1 g
F P
s
P
p
.002 w
.52361 .34012 m .51664 .33407 L .4938 .34979 L p
1 g
F P
s
P
p
.002 w
.61547 .44159 m .57971 .45517 L .58247 .48311 L p
1 g
F P
s
P
p
.002 w
.57971 .45517 m .61547 .44159 L .60467 .41524 L p
1 g
F P
s
P
p
.002 w
.37876 .46959 m .42156 .50393 L .43323 .48078 L p
1 g
F P
s
P
p
.002 w
.43323 .48078 m .39335 .44844 L .37876 .46959 L p
1 g
F P
s
P
p
.002 w
.56034 .37125 m .57587 .36477 L .55845 .34163 L p
1 g
F P
s
P
p
.002 w
.55845 .34163 m .55059 .345 L .56034 .37125 L p
1 g
F P
s
P
p
.002 w
.47267 .52754 m .52767 .53851 L .53249 .51307 L p
1 g
F P
s
P
p
.002 w
.58323 .51014 m .53249 .51307 L .52767 .53851 L p
1 g
F P
s
P
p
.002 w
.53249 .51307 m .58323 .51014 L .58247 .48311 L p
1 g
F P
s
P
p
.002 w
.36517 .4085 m .39335 .44844 L .41028 .42724 L p
1 g
F P
s
P
p
.002 w
.41028 .42724 m .38503 .39075 L .36517 .4085 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .5322 .3442 L .54152 .34589 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .52361 .34012 L .5322 .3442 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .51664 .33407 L .52361 .34012 L closepath p
1 g
F P
s
P
p
.002 w
.42413 .32992 m .43179 .35939 L .45769 .34633 L p
1 g
F P
s
P
p
.002 w
.45769 .34633 m .45208 .32347 L .42413 .32992 L p
1 g
F P
s
P
p
.002 w
.45208 .32347 m .45769 .34633 L .48462 .33536 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .54152 .34589 L .55059 .345 L closepath p
1 g
F P
s
P
p
.002 w
.48462 .33536 m .481 .31972 L .45208 .32347 L p
1 g
F P
s
P
p
.002 w
.481 .31972 m .48462 .33536 L .51204 .32668 L p
1 g
F P
s
P
p
.002 w
.51664 .33407 m .51204 .32668 L .48462 .33536 L p
1 g
F P
s
P
p
.002 w
.62352 .468 m .58247 .48311 L .58323 .51014 L p
1 g
F P
s
P
p
.002 w
.58247 .48311 m .62352 .468 L .61547 .44159 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .51204 .32668 L .51664 .33407 L closepath p
1 g
F P
s
P
p
.002 w
.39774 .33898 m .4074 .37428 L .43179 .35939 L p
1 g
F P
s
P
p
.002 w
.43179 .35939 m .42413 .32992 L .39774 .33898 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .55059 .345 L .55845 .34163 L closepath p
1 g
F P
s
P
p
.002 w
.60865 .37392 m .59138 .38947 L .60467 .41524 L p
1 g
F P
s
P
p
.002 w
.59138 .38947 m .60865 .37392 L .58749 .35401 L p
1 g
F P
s
P
p
.002 w
.58749 .35401 m .57587 .36477 L .59138 .38947 L p
1 g
F P
s
P
p
.002 w
.57587 .36477 m .58749 .35401 L .56427 .33609 L p
1 g
F P
s
P
p
.002 w
.56427 .33609 m .55845 .34163 L .57587 .36477 L p
1 g
F P
s
P
p
.002 w
.52767 .53851 m .47267 .52754 L .46482 .55029 L p
1 g
F P
s
P
p
.002 w
.41159 .52578 m .46482 .55029 L .47267 .52754 L p
1 g
F P
s
P
p
.002 w
.47267 .52754 m .42156 .50393 L .41159 .52578 L p
1 g
F P
s
P
p
.002 w
.51204 .32668 m .51031 .31872 L .481 .31972 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .51031 .31872 L .51204 .32668 L closepath p
1 g
F P
s
P
p
.002 w
.62729 .39544 m .60467 .41524 L .61547 .44159 L p
1 g
F P
s
P
p
.002 w
.60467 .41524 m .62729 .39544 L .60865 .37392 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .55845 .34163 L .56427 .33609 L closepath p
1 g
F P
s
P
p
.002 w
.36688 .49026 m .41159 .52578 L .42156 .50393 L p
1 g
F P
s
P
p
.002 w
.42156 .50393 m .37876 .46959 L .36688 .49026 L p
1 g
F P
s
P
p
.002 w
.34831 .42718 m .37876 .46959 L .39335 .44844 L p
1 g
F P
s
P
p
.002 w
.39335 .44844 m .36517 .4085 L .34831 .42718 L p
1 g
F P
s
P
p
.002 w
.37349 .35052 m .38503 .39075 L .4074 .37428 L p
1 g
F P
s
P
p
.002 w
.4074 .37428 m .39774 .33898 L .37349 .35052 L p
1 g
F P
s
P
p
.002 w
.46482 .55029 m .52205 .56183 L .52767 .53851 L p
1 g
F P
s
P
p
.002 w
.58191 .5357 m .52767 .53851 L .52205 .56183 L p
1 g
F P
s
P
p
.002 w
.52767 .53851 m .58191 .5357 L .58323 .51014 L p
1 g
F P
s
P
p
.002 w
.48345 .30451 m .481 .31972 L .51031 .31872 L p
1 g
F P
s
P
p
.002 w
.51031 .31872 m .51167 .31104 L .48345 .30451 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .51167 .31104 L .51031 .31872 L closepath p
1 g
F P
s
P
p
.002 w
.45534 .30107 m .45208 .32347 L .481 .31972 L p
1 g
F P
s
P
p
.002 w
.481 .31972 m .48345 .30451 L .45534 .30107 L p
1 g
F P
s
P
p
.002 w
.56738 .32896 m .56427 .33609 L .58749 .35401 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .56427 .33609 L .56738 .32896 L closepath p
1 g
F P
s
P
p
.002 w
.62859 .49394 m .58323 .51014 L .58191 .5357 L p
1 g
F P
s
P
p
.002 w
.58323 .51014 m .62859 .49394 L .62352 .468 L p
1 g
F P
s
P
p
.002 w
.64297 .41816 m .61547 .44159 L .62352 .468 L p
1 g
F P
s
P
p
.002 w
.61547 .44159 m .64297 .41816 L .62729 .39544 L p
1 g
F P
s
P
p
.002 w
.59386 .34003 m .58749 .35401 L .60865 .37392 L p
1 g
F P
s
P
p
.002 w
.58749 .35401 m .59386 .34003 L .56738 .32896 L p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .56738 .32896 L .56742 .321 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .56742 .321 L .56435 .31307 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .56435 .31307 L .55847 .30606 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .55847 .30606 L .55043 .30076 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .55043 .30076 L .54112 .29777 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .54112 .29777 L .53159 .29742 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .53159 .29742 L .5229 .29975 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .5229 .29975 L .51602 .30447 L closepath p
1 g
F P
s
P
p
.002 w
.53944 .3205 m .51602 .30447 L .51167 .31104 L closepath p
1 g
F P
s
P
p
.002 w
.42793 .30087 m .42413 .32992 L .45208 .32347 L p
1 g
F P
s
P
p
.002 w
.45208 .32347 m .45534 .30107 L .42793 .30087 L p
1 g
F P
s
P
p
.002 w
.49186 .29139 m .48345 .30451 L .51167 .31104 L p
1 g
F P
s
P
p
.002 w
.51167 .31104 m .51602 .30447 L .49186 .29139 L p
1 g
F P
s
P
p
.002 w
.35196 .36436 m .36517 .4085 L .38503 .39075 L p
1 g
F P
s
P
p
.002 w
.38503 .39075 m .37349 .35052 L .35196 .36436 L p
1 g
F P
s
P
p
.002 w
.56742 .321 m .56738 .32896 L .59386 .34003 L p
1 g
F P
s
P
p
.002 w
.61832 .35352 m .60865 .37392 L .62729 .39544 L p
1 g
F P
s
P
p
.002 w
.60865 .37392 m .61832 .35352 L .59386 .34003 L p
1 g
F P
s
P
p
.002 w
.52205 .56183 m .46482 .55029 L .45764 .57064 L p
1 g
F P
s
P
p
.002 w
.40357 .54583 m .45764 .57064 L .46482 .55029 L p
1 g
F P
s
P
p
.002 w
.46482 .55029 m .41159 .52578 L .40357 .54583 L p
1 g
F P
s
P
p
.002 w
.40183 .30398 m .39774 .33898 L .42413 .32992 L p
1 g
F P
s
P
p
.002 w
.42413 .32992 m .42793 .30087 L .40183 .30398 L p
1 g
F P
s
P
p
.002 w
.50542 .28186 m .49186 .29139 L .51602 .30447 L p
1 g
F P
s
P
p
.002 w
.51602 .30447 m .5229 .29975 L .50542 .28186 L p
1 g
F P
s
P
p
.002 w
.46745 .28159 m .45534 .30107 L .48345 .30451 L p
1 g
F P
s
P
p
.002 w
.48345 .30451 m .49186 .29139 L .46745 .28159 L p
1 g
F P
s
P
p
.002 w
.33492 .44645 m .36688 .49026 L .37876 .46959 L p
1 g
F P
s
P
p
.002 w
.37876 .46959 m .34831 .42718 L .33492 .44645 L p
1 g
F P
s
P
p
.002 w
.59386 .34003 m .59416 .32426 L .56742 .321 L p
1 g
F P
s
P
p
.002 w
.56435 .31307 m .56742 .321 L .59416 .32426 L p
1 g
F P
s
P
p
.002 w
.65531 .44161 m .62352 .468 L .62859 .49394 L p
1 g
F P
s
P
p
.002 w
.62352 .468 m .65531 .44161 L .64297 .41816 L p
1 g
F P
s
P
p
.002 w
.35809 .50999 m .40357 .54583 L .41159 .52578 L p
1 g
F P
s
P
p
.002 w
.41159 .52578 m .36688 .49026 L .35809 .50999 L p
1 g
F P
s
P
p
.002 w
.59416 .32426 m .59386 .34003 L .61832 .35352 L p
1 g
F P
s
P
p
.002 w
.64019 .3692 m .62729 .39544 L .64297 .41816 L p
1 g
F P
s
P
p
.002 w
.62729 .39544 m .64019 .3692 L .61832 .35352 L p
1 g
F P
s
P
p
.002 w
.52272 .2771 m .50542 .28186 L .5229 .29975 L p
1 g
F P
s
P
p
.002 w
.5229 .29975 m .53159 .29742 L .52272 .2771 L p
1 g
F P
s
P
p
.002 w
.45764 .57064 m .51571 .58247 L .52205 .56183 L p
1 g
F P
s
P
p
.002 w
.57848 .55922 m .52205 .56183 L .51571 .58247 L p
1 g
F P
s
P
p
.002 w
.52205 .56183 m .57848 .55922 L .58191 .5357 L p
1 g
F P
s
P
p
.002 w
.6305 .51885 m .58191 .5357 L .57848 .55922 L p
1 g
F P
s
P
p
.002 w
.58191 .5357 m .6305 .51885 L .62859 .49394 L p
1 g
F P
s
P
p
.002 w
.59416 .32426 m .58821 .30845 L .56435 .31307 L p
1 g
F P
s
P
p
.002 w
.55847 .30606 m .56435 .31307 L .58821 .30845 L p
1 g
F P
s
P
p
.002 w
.33374 .38028 m .34831 .42718 L .36517 .4085 L p
1 g
F P
s
P
p
.002 w
.36517 .4085 m .35196 .36436 L .33374 .38028 L p
1 g
F P
s
P
p
.002 w
.5418 .27773 m .52272 .2771 L .53159 .29742 L p
1 g
F P
s
P
p
.002 w
.53159 .29742 m .54112 .29777 L .5418 .27773 L p
1 g
F P
s
P
p
.002 w
.4433 .27541 m .42793 .30087 L .45534 .30107 L p
1 g
F P
s
P
p
.002 w
.45534 .30107 m .46745 .28159 L .4433 .27541 L p
1 g
F P
s
P
p
.002 w
.37765 .31044 m .37349 .35052 L .39774 .33898 L p
1 g
F P
s
P
p
.002 w
.39774 .33898 m .40183 .30398 L .37765 .31044 L p
1 g
F P
s
P
p
.002 w
.58821 .30845 m .57656 .29438 L .55847 .30606 L p
1 g
F P
s
P
p
.002 w
.55043 .30076 m .55847 .30606 L .57656 .29438 L p
1 g
F P
s
P
p
.002 w
.56048 .28372 m .5418 .27773 L .54112 .29777 L p
1 g
F P
s
P
p
.002 w
.54112 .29777 m .55043 .30076 L .56048 .28372 L p
1 g
F P
s
P
p
.002 w
.57656 .29438 m .56048 .28372 L .55043 .30076 L p
1 g
F P
s
P
p
.002 w
.48734 .26733 m .46745 .28159 L .49186 .29139 L p
1 g
F P
s
P
p
.002 w
.49186 .29139 m .50542 .28186 L .48734 .26733 L p
1 g
F P
s
P
p
.002 w
.61906 .33031 m .61832 .35352 L .64019 .3692 L p
1 g
F P
s
P
p
.002 w
.61832 .35352 m .61906 .33031 L .59416 .32426 L p
1 g
F P
s
P
p
.002 w
.58821 .30845 m .59416 .32426 L .61906 .33031 L p
1 g
F P
s
P
p
.002 w
.66392 .46532 m .62859 .49394 L .6305 .51885 L p
1 g
F P
s
P
p
.002 w
.62859 .49394 m .66392 .46532 L .65531 .44161 L p
1 g
F P
s
P
p
.002 w
.65893 .3868 m .64297 .41816 L .65531 .44161 L p
1 g
F P
s
P
p
.002 w
.64297 .41816 m .65893 .3868 L .64019 .3692 L p
1 g
F P
s
P
p
.002 w
.32545 .46587 m .35809 .50999 L .36688 .49026 L p
1 g
F P
s
P
p
.002 w
.36688 .49026 m .33492 .44645 L .32545 .46587 L p
1 g
F P
s
P
p
.002 w
.51571 .58247 m .45764 .57064 L .45132 .58805 L p
1 g
F P
s
P
p
.002 w
.39779 .56355 m .45132 .58805 L .45764 .57064 L p
1 g
F P
s
P
p
.002 w
.45764 .57064 m .40357 .54583 L .39779 .56355 L p
1 g
F P
s
P
p
.002 w
.41999 .2731 m .40183 .30398 L .42793 .30087 L p
1 g
F P
s
P
p
.002 w
.42793 .30087 m .4433 .27541 L .41999 .2731 L p
1 g
F P
s
P
p
.002 w
.51297 .26011 m .48734 .26733 L .50542 .28186 L p
1 g
F P
s
P
p
.002 w
.50542 .28186 m .52272 .2771 L .51297 .26011 L p
1 g
F P
s
P
p
.002 w
.35604 .32025 m .35196 .36436 L .37349 .35052 L p
1 g
F P
s
P
p
.002 w
.37349 .35052 m .37765 .31044 L .35604 .32025 L p
1 g
F P
s
P
p
.002 w
.35271 .52829 m .39779 .56355 L .40357 .54583 L p
1 g
F P
s
P
p
.002 w
.40357 .54583 m .35809 .50999 L .35271 .52829 L p
1 g
F P
s
P
p
.002 w
.61906 .33031 m .61046 .30684 L .58821 .30845 L p
1 g
F P
s
P
p
.002 w
.57656 .29438 m .58821 .30845 L .61046 .30684 L p
1 g
F P
s
P
p
.002 w
.51571 .58247 m .57293 .5801 L .57848 .55922 L p
1 g
F P
s
P
p
.002 w
.62907 .54213 m .57848 .55922 L .57293 .5801 L p
1 g
F P
s
P
p
.002 w
.57848 .55922 m .62907 .54213 L .6305 .51885 L p
1 g
F P
s
P
p
.002 w
.31939 .39797 m .33492 .44645 L .34831 .42718 L p
1 g
F P
s
P
p
.002 w
.34831 .42718 m .33374 .38028 L .31939 .39797 L p
1 g
F P
s
P
p
.002 w
.46905 .25662 m .4433 .27541 L .46745 .28159 L p
1 g
F P
s
P
p
.002 w
.46745 .28159 m .48734 .26733 L .46905 .25662 L p
1 g
F P
s
P
p
.002 w
.45132 .58805 m .50875 .59985 L .51571 .58247 L p
1 g
F P
s
P
p
.002 w
.57293 .5801 m .51571 .58247 L .50875 .59985 L p
1 g
F P
s
P
p
.002 w
.64151 .3391 m .64019 .3692 L .65893 .3868 L p
1 g
F P
s
P
p
.002 w
.64019 .3692 m .64151 .3391 L .61906 .33031 L p
1 g
F P
s
P
p
.002 w
.54142 .26097 m .51297 .26011 L .52272 .2771 L p
1 g
F P
s
P
p
.002 w
.52272 .2771 m .5418 .27773 L .54142 .26097 L p
1 g
F P
s
P
p
.002 w
.61046 .30684 m .61906 .33031 L .64151 .3391 L p
1 g
F P
s
P
p
.002 w
.67399 .40599 m .65531 .44161 L .66392 .46532 L p
1 g
F P
s
P
p
.002 w
.65531 .44161 m .67399 .40599 L .65893 .3868 L p
1 g
F P
s
P
p
.002 w
.61046 .30684 m .59326 .28585 L .57656 .29438 L p
1 g
F P
s
P
p
.002 w
.56048 .28372 m .57656 .29438 L .59326 .28585 L p
1 g
F P
s
P
p
.002 w
.66846 .48874 m .6305 .51885 L .62907 .54213 L p
1 g
F P
s
P
p
.002 w
.6305 .51885 m .66846 .48874 L .66392 .46532 L p
1 g
F P
s
P
p
.002 w
.5693 .2699 m .54142 .26097 L .5418 .27773 L p
1 g
F P
s
P
p
.002 w
.5418 .27773 m .56048 .28372 L .5693 .2699 L p
1 g
F P
s
P
p
.002 w
.59326 .28585 m .5693 .2699 L .56048 .28372 L p
1 g
F P
s
P
p
.002 w
.3981 .27491 m .37765 .31044 L .40183 .30398 L p
1 g
F P
s
P
p
.002 w
.40183 .30398 m .41999 .2731 L .3981 .27491 L p
1 g
F P
s
P
p
.002 w
.33764 .33329 m .33374 .38028 L .35196 .36436 L p
1 g
F P
s
P
p
.002 w
.35196 .36436 m .35604 .32025 L .33764 .33329 L p
1 g
F P
s
P
p
.002 w
.32032 .48499 m .35271 .52829 L .35809 .50999 L p
1 g
F P
s
P
p
.002 w
.35809 .50999 m .32545 .46587 L .32032 .48499 L p
1 g
F P
s
P
p
.002 w
.50254 .24701 m .46905 .25662 L .48734 .26733 L p
1 g
F P
s
P
p
.002 w
.48734 .26733 m .51297 .26011 L .50254 .24701 L p
1 g
F P
s
P
p
.002 w
.66089 .35054 m .65893 .3868 L .67399 .40599 L p
1 g
F P
s
P
p
.002 w
.65893 .3868 m .66089 .35054 L .64151 .3391 L p
1 g
F P
s
P
p
.002 w
.50875 .59985 m .45132 .58805 L .44604 .60198 L p
1 g
F P
s
P
p
.002 w
.39448 .57843 m .44604 .60198 L .45132 .58805 L p
1 g
F P
s
P
p
.002 w
.45132 .58805 m .39779 .56355 L .39448 .57843 L p
1 g
F P
s
P
p
.002 w
.45096 .25017 m .41999 .2731 L .4433 .27541 L p
1 g
F P
s
P
p
.002 w
.4433 .27541 m .46905 .25662 L .45096 .25017 L p
1 g
F P
s
P
p
.002 w
.64151 .3391 m .63053 .30843 L .61046 .30684 L p
1 g
F P
s
P
p
.002 w
.59326 .28585 m .61046 .30684 L .63053 .30843 L p
1 g
F P
s
P
p
.002 w
.30943 .4171 m .32545 .46587 L .33492 .44645 L p
1 g
F P
s
P
p
.002 w
.33492 .44645 m .31939 .39797 L .30943 .4171 L p
1 g
F P
s
P
p
.002 w
.50875 .59985 m .56527 .59775 L .57293 .5801 L p
1 g
F P
s
P
p
.002 w
.6242 .56318 m .57293 .5801 L .56527 .59775 L p
1 g
F P
s
P
p
.002 w
.57293 .5801 m .6242 .56318 L .62907 .54213 L p
1 g
F P
s
P
p
.002 w
.68487 .42637 m .66392 .46532 L .66846 .48874 L p
1 g
F P
s
P
p
.002 w
.66392 .46532 m .68487 .42637 L .67399 .40599 L p
1 g
F P
s
P
p
.002 w
.35106 .54466 m .39448 .57843 L .39779 .56355 L p
1 g
F P
s
P
p
.002 w
.39779 .56355 m .35271 .52829 L .35106 .54466 L p
1 g
F P
s
P
p
.002 w
.63053 .30843 m .64151 .3391 L .66089 .35054 L p
1 g
F P
s
P
p
.002 w
.44604 .60198 m .5013 .61341 L .50875 .59985 L p
1 g
F P
s
P
p
.002 w
.56527 .59775 m .50875 .59985 L .5013 .61341 L p
1 g
F P
s
P
p
.002 w
.66866 .5113 m .62907 .54213 L .6242 .56318 L p
1 g
F P
s
P
p
.002 w
.62907 .54213 m .66866 .5113 L .66846 .48874 L p
1 g
F P
s
P
p
.002 w
.53992 .24806 m .50254 .24701 L .51297 .26011 L p
1 g
F P
s
P
p
.002 w
.51297 .26011 m .54142 .26097 L .53992 .24806 L p
1 g
F P
s
P
p
.002 w
.37824 .28097 m .35604 .32025 L .37765 .31044 L p
1 g
F P
s
P
p
.002 w
.37765 .31044 m .3981 .27491 L .37824 .28097 L p
1 g
F P
s
P
p
.002 w
.63053 .30843 m .6081 .28084 L .59326 .28585 L p
1 g
F P
s
P
p
.002 w
.5693 .2699 m .59326 .28585 L .6081 .28084 L p
1 g
F P
s
P
p
.002 w
.32306 .34938 m .31939 .39797 L .33374 .38028 L p
1 g
F P
s
P
p
.002 w
.33374 .38028 m .33764 .33329 L .32306 .34938 L p
1 g
F P
s
P
p
.002 w
.57663 .25981 m .53992 .24806 L .54142 .26097 L p
1 g
F P
s
P
p
.002 w
.54142 .26097 m .5693 .2699 L .57663 .25981 L p
1 g
F P
s
P
p
.002 w
.6081 .28084 m .57663 .25981 L .5693 .2699 L p
1 g
F P
s
P
p
.002 w
.67659 .36448 m .67399 .40599 L .68487 .42637 L p
1 g
F P
s
P
p
.002 w
.67399 .40599 m .67659 .36448 L .66089 .35054 L p
1 g
F P
s
P
p
.002 w
.43354 .24836 m .3981 .27491 L .41999 .2731 L p
1 g
F P
s
P
p
.002 w
.41999 .2731 m .45096 .25017 L .43354 .24836 L p
1 g
F P
s
P
p
.002 w
.49163 .23835 m .45096 .25017 L .46905 .25662 L p
1 g
F P
s
P
p
.002 w
.46905 .25662 m .50254 .24701 L .49163 .23835 L p
1 g
F P
s
P
p
.002 w
.31987 .50332 m .35106 .54466 L .35271 .52829 L p
1 g
F P
s
P
p
.002 w
.35271 .52829 m .32032 .48499 L .31987 .50332 L p
1 g
F P
s
P
p
.002 w
.30435 .43723 m .32032 .48499 L .32545 .46587 L p
1 g
F P
s
P
p
.002 w
.32545 .46587 m .30943 .4171 L .30435 .43723 L p
1 g
F P
s
P
p
.002 w
.69111 .4475 m .66846 .48874 L .66866 .5113 L p
1 g
F P
s
P
p
.002 w
.66846 .48874 m .69111 .4475 L .68487 .42637 L p
1 g
F P
s
P
p
.002 w
.66089 .35054 m .64783 .31333 L .63053 .30843 L p
1 g
F P
s
P
p
.002 w
.6081 .28084 m .63053 .30843 L .64783 .31333 L p
1 g
F P
s
P
p
.002 w
.5013 .61341 m .5556 .61156 L .56527 .59775 L p
1 g
F P
s
P
p
.002 w
.61584 .58137 m .56527 .59775 L .5556 .61156 L p
1 g
F P
s
P
p
.002 w
.56527 .59775 m .61584 .58137 L .6242 .56318 L p
1 g
F P
s
P
p
.002 w
.64783 .31333 m .66089 .35054 L .67659 .36448 L p
1 g
F P
s
P
p
.002 w
.5013 .61341 m .44604 .60198 L .44199 .61188 L p
1 g
F P
s
P
p
.002 w
.39387 .58994 m .44199 .61188 L .44604 .60198 L p
1 g
F P
s
P
p
.002 w
.44604 .60198 m .39448 .57843 L .39387 .58994 L p
1 g
F P
s
P
p
.002 w
.36104 .29135 m .33764 .33329 L .35604 .32025 L p
1 g
F P
s
P
p
.002 w
.35604 .32025 m .37824 .28097 L .36104 .29135 L p
1 g
F P
s
P
p
.002 w
.35338 .55857 m .39387 .58994 L .39448 .57843 L p
1 g
F P
s
P
p
.002 w
.39448 .57843 m .35106 .54466 L .35338 .55857 L p
1 g
F P
s
P
p
.002 w
.6643 .53239 m .6242 .56318 L .61584 .58137 L p
1 g
F P
s
P
p
.002 w
.6242 .56318 m .6643 .53239 L .66866 .5113 L p
1 g
F P
s
P
p
.002 w
.44199 .61188 m .49353 .62259 L .5013 .61341 L p
1 g
F P
s
P
p
.002 w
.5556 .61156 m .5013 .61341 L .49353 .62259 L p
1 g
F P
s
P
p
.002 w
.53728 .23956 m .49163 .23835 L .50254 .24701 L p
1 g
F P
s
P
p
.002 w
.50254 .24701 m .53992 .24806 L .53728 .23956 L p
1 g
F P
s
P
p
.002 w
.31288 .36824 m .30943 .4171 L .31939 .39797 L p
1 g
F P
s
P
p
.002 w
.31939 .39797 m .32306 .34938 L .31288 .36824 L p
1 g
F P
s
P
p
.002 w
.64783 .31333 m .62062 .27967 L .6081 .28084 L p
1 g
F P
s
P
p
.002 w
.57663 .25981 m .6081 .28084 L .62062 .27967 L p
1 g
F P
s
P
p
.002 w
.68803 .38068 m .68487 .42637 L .69111 .4475 L p
1 g
F P
s
P
p
.002 w
.68487 .42637 m .68803 .38068 L .67659 .36448 L p
1 g
F P
s
P
p
.002 w
.41729 .25152 m .37824 .28097 L .3981 .27491 L p
1 g
F P
s
P
p
.002 w
.3981 .27491 m .43354 .24836 L .41729 .25152 L p
1 g
F P
s
P
p
.002 w
.58219 .25394 m .53728 .23956 L .53992 .24806 L p
1 g
F P
s
P
p
.002 w
.53992 .24806 m .57663 .25981 L .58219 .25394 L p
1 g
F P
s
P
p
.002 w
.4805 .23461 m .43354 .24836 L .45096 .25017 L p
1 g
F P
s
P
p
.002 w
.45096 .25017 m .49163 .23835 L .4805 .23461 L p
1 g
F P
s
P
p
.002 w
.69233 .46884 m .66866 .5113 L .6643 .53239 L p
1 g
F P
s
P
p
.002 w
.66866 .5113 m .69233 .46884 L .69111 .4475 L p
1 g
F P
s
P
p
.002 w
.62062 .27967 m .58219 .25394 L .57663 .25981 L p
1 g
F P
s
P
p
.002 w
.32439 .52031 m .35338 .55857 L .35106 .54466 L p
1 g
F P
s
P
p
.002 w
.35106 .54466 m .31987 .50332 L .32439 .52031 L p
1 g
F P
s
P
p
.002 w
.30452 .45786 m .31987 .50332 L .32032 .48499 L p
1 g
F P
s
P
p
.002 w
.32032 .48499 m .30435 .43723 L .30452 .45786 L p
1 g
F P
s
P
p
.002 w
.66175 .3216 m .67659 .36448 L .68803 .38068 L p
1 g
F P
s
P
p
.002 w
.67659 .36448 m .66175 .3216 L .64783 .31333 L p
1 g
F P
s
P
p
.002 w
.62062 .27967 m .64783 .31333 L .66175 .3216 L p
1 g
F P
s
P
p
.002 w
.34712 .30597 m .32306 .34938 L .33764 .33329 L p
1 g
F P
s
P
p
.002 w
.33764 .33329 m .36104 .29135 L .34712 .30597 L p
1 g
F P
s
P
p
.002 w
.49353 .62259 m .54404 .62098 L .5556 .61156 L p
1 g
F P
s
P
p
.002 w
.60403 .59609 m .5556 .61156 L .54404 .62098 L p
1 g
F P
s
P
p
.002 w
.5556 .61156 m .60403 .59609 L .61584 .58137 L p
1 g
F P
s
P
p
.002 w
.65529 .55139 m .61584 .58137 L .60403 .59609 L p
1 g
F P
s
P
p
.002 w
.61584 .58137 m .65529 .55139 L .6643 .53239 L p
1 g
F P
s
P
p
.002 w
.49353 .62259 m .44199 .61188 L .43935 .61723 L p
1 g
F P
s
P
p
.002 w
.39615 .59755 m .43935 .61723 L .44199 .61188 L p
1 g
F P
s
P
p
.002 w
.44199 .61188 m .39387 .58994 L .39615 .59755 L p
1 g
F P
s
P
p
.002 w
.30761 .38949 m .30435 .43723 L .30943 .4171 L p
1 g
F P
s
P
p
.002 w
.30943 .4171 m .31288 .36824 L .30761 .38949 L p
1 g
F P
s
P
p
.002 w
.35987 .5695 m .39615 .59755 L .39387 .58994 L p
1 g
F P
s
P
p
.002 w
.39387 .58994 m .35338 .55857 L .35987 .5695 L p
1 g
F P
s
P
p
.002 w
.69469 .39884 m .69111 .4475 L .69233 .46884 L p
1 g
F P
s
P
p
.002 w
.69111 .4475 m .69469 .39884 L .68803 .38068 L p
1 g
F P
s
P
p
.002 w
.43935 .61723 m .4856 .62687 L .49353 .62259 L p
1 g
F P
s
P
p
.002 w
.54404 .62098 m .49353 .62259 L .4856 .62687 L p
1 g
F P
s
P
p
.002 w
.53349 .23599 m .4805 .23461 L .49163 .23835 L p
1 g
F P
s
P
p
.002 w
.49163 .23835 m .53728 .23956 L .53349 .23599 L p
1 g
F P
s
P
p
.002 w
.40275 .25983 m .36104 .29135 L .37824 .28097 L p
1 g
F P
s
P
p
.002 w
.37824 .28097 m .41729 .25152 L .40275 .25983 L p
1 g
F P
s
P
p
.002 w
.66175 .3216 m .63033 .28261 L .62062 .27967 L p
1 g
F P
s
P
p
.002 w
.58219 .25394 m .62062 .27967 L .63033 .28261 L p
1 g
F P
s
P
p
.002 w
.68825 .48984 m .6643 .53239 L .65529 .55139 L p
1 g
F P
s
P
p
.002 w
.6643 .53239 m .68825 .48984 L .69233 .46884 L p
1 g
F P
s
P
p
.004 w
.38044 .58106 m
.5 .43051 L
s
P
p
.004 w
.36797 .59676 m
.3783 .58375 L
s
P
p
.004 w
.31922 .65814 m
.36797 .59676 L
s
P
p
.002 w
.46945 .23621 m .41729 .25152 L .43354 .24836 L p
1 g
F P
s
P
p
.002 w
.43354 .24836 m .4805 .23461 L .46945 .23621 L p
1 g
F P
s
P
p
.002 w
.31021 .47843 m .32439 .52031 L .31987 .50332 L p
1 g
F P
s
P
p
.002 w
.31987 .50332 m .30452 .45786 L .31021 .47843 L p
1 g
F P
s
P
p
.002 w
.67173 .33321 m .68803 .38068 L .69469 .39884 L p
1 g
F P
s
P
p
.002 w
.68803 .38068 m .67173 .33321 L .66175 .3216 L p
1 g
F P
s
P
p
.002 w
.58571 .2527 m .53349 .23599 L .53728 .23956 L p
1 g
F P
s
P
p
.002 w
.53728 .23956 m .58219 .25394 L .58571 .2527 L p
1 g
F P
s
P
p
.002 w
.33706 .32464 m .31288 .36824 L .32306 .34938 L p
1 g
F P
s
P
p
.002 w
.32306 .34938 m .34712 .30597 L .33706 .32464 L p
1 g
F P
s
P
p
.002 w
.33401 .53541 m .35987 .5695 L .35338 .55857 L p
1 g
F P
s
P
p
.002 w
.35338 .55857 m .32439 .52031 L .33401 .53541 L p
1 g
F P
s
P
p
.002 w
.63033 .28261 m .58571 .2527 L .58219 .25394 L p
1 g
F P
s
P
p
.002 w
.63033 .28261 m .66175 .3216 L .67173 .33321 L p
1 g
F P
s
P
p
.002 w
.4856 .62687 m .53079 .62547 L .54404 .62098 L p
1 g
F P
s
P
p
.002 w
.5889 .60674 m .54404 .62098 L .53079 .62547 L p
1 g
F P
s
P
p
.002 w
.54404 .62098 m .5889 .60674 L .60403 .59609 L p
1 g
F P
s
P
p
.002 w
.60403 .59609 m .64163 .56766 L .65529 .55139 L p
1 g
F P
s
P
p
.002 w
.64163 .56766 m .60403 .59609 L .5889 .60674 L p
1 g
F P
s
P
p
.002 w
.30765 .41259 m .30452 .45786 L .30435 .43723 L p
1 g
F P
s
P
p
.002 w
.30435 .43723 m .30761 .38949 L .30765 .41259 L p
1 g
F P
s
P
p
.002 w
.69233 .46884 m .69611 .41853 L .69469 .39884 L p
1 g
F P
s
P
p
.002 w
.69611 .41853 m .69233 .46884 L .68825 .48984 L p
1 g
F P
s
P
p
.002 w
.40145 .60081 m .4383 .6176 L .43935 .61723 L p
1 g
F P
s
P
p
.004 w
.42361 .64362 m
.43216 .61975 L
s
P
p
.002 w
.43935 .61723 m .39615 .59755 L .40145 .60081 L p
1 g
F P
s
P
p
.002 w
.4856 .62687 m .43935 .61723 L .4383 .6176 L p
1 g
F P
s
P
p
.002 w
.39044 .27334 m .34712 .30597 L .36104 .29135 L p
1 g
F P
s
P
p
.002 w
.36104 .29135 m .40275 .25983 L .39044 .27334 L p
1 g
F P
s
P
p
.002 w
.37058 .57694 m .40145 .60081 L .39615 .59755 L p
1 g
F P
s
P
p
.002 w
.39615 .59755 m .35987 .5695 L .37058 .57694 L p
1 g
F P
s
P
p
.002 w
.65529 .55139 m .67871 .50986 L .68825 .48984 L p
1 g
F P
s
P
p
.002 w
.67871 .50986 m .65529 .55139 L .64163 .56766 L p
1 g
F P
s
P
p
.002 w
.52858 .23777 m .46945 .23621 L .4805 .23461 L p
1 g
F P
s
P
p
.002 w
.4805 .23461 m .53349 .23599 L .52858 .23777 L p
1 g
F P
s
P
p
.002 w
.4383 .6176 m .47773 .62582 L .4856 .62687 L p
1 g
F P
s
P
p
.002 w
.53079 .62547 m .4856 .62687 L .47773 .62582 L p
1 g
F P
s
P
p
.002 w
.67173 .33321 m .63679 .28984 L .63033 .28261 L p
1 g
F P
s
P
p
.002 w
.58571 .2527 m .63033 .28261 L .63679 .28984 L p
1 g
F P
s
P
p
.002 w
.45882 .24345 m .40275 .25983 L .41729 .25152 L p
1 g
F P
s
P
p
.002 w
.41729 .25152 m .46945 .23621 L .45882 .24345 L p
1 g
F P
s
P
p
.002 w
.33136 .34699 m .30761 .38949 L .31288 .36824 L p
1 g
F P
s
P
p
.002 w
.31288 .36824 m .33706 .32464 L .33136 .34699 L p
1 g
F P
s
P
p
.002 w
.32154 .49831 m .33401 .53541 L .32439 .52031 L p
1 g
F P
s
P
p
.002 w
.32439 .52031 m .31021 .47843 L .32154 .49831 L p
1 g
F P
s
P
p
.002 w
.69469 .39884 m .67725 .34803 L .67173 .33321 L p
1 g
F P
s
P
p
.002 w
.67725 .34803 m .69469 .39884 L .69611 .41853 L p
1 g
F P
s
P
p
.002 w
.34874 .54807 m .37058 .57694 L .35987 .5695 L p
1 g
F P
s
P
p
.002 w
.35987 .5695 m .33401 .53541 L .34874 .54807 L p
1 g
F P
s
P
p
.002 w
.63679 .28984 m .67173 .33321 L .67725 .34803 L p
1 g
F P
s
P
p
.002 w
.58696 .25646 m .52858 .23777 L .53349 .23599 L p
1 g
F P
s
P
p
.002 w
.53349 .23599 m .58571 .2527 L .58696 .25646 L p
1 g
F P
s
P
p
.002 w
.53079 .62547 m .57071 .61281 L .5889 .60674 L p
1 g
F P
s
P
p
.002 w
.62349 .58057 m .5889 .60674 L .57071 .61281 L p
1 g
F P
s
P
p
.002 w
.5889 .60674 m .62349 .58057 L .64163 .56766 L p
1 g
F P
s
P
p
.002 w
.31326 .43694 m .31021 .47843 L .30452 .45786 L p
1 g
F P
s
P
p
.002 w
.30452 .45786 m .30765 .41259 L .31326 .43694 L p
1 g
F P
s
P
p
.002 w
.63679 .28984 m .58696 .25646 L .58571 .2527 L p
1 g
F P
s
P
p
.002 w
.47773 .62582 m .51614 .62462 L .53079 .62547 L p
1 g
F P
s
P
p
.002 w
.57071 .61281 m .53079 .62547 L .51614 .62462 L p
1 g
F P
s
P
p
.002 w
.69197 .43926 m .68825 .48984 L .67871 .50986 L p
1 g
F P
s
P
p
.002 w
.68825 .48984 m .69197 .43926 L .69611 .41853 L p
1 g
F P
s
P
p
.002 w
.38088 .29192 m .33706 .32464 L .34712 .30597 L p
1 g
F P
s
P
p
.002 w
.34712 .30597 m .39044 .27334 L .38088 .29192 L p
1 g
F P
s
P
p
.002 w
.66373 .52825 m .64163 .56766 L .62349 .58057 L p
1 g
F P
s
P
p
.002 w
.64163 .56766 m .66373 .52825 L .67871 .50986 L p
1 g
F P
s
P
p
.002 w
.47773 .62582 m .4383 .6176 L .43896 .61264 L p
1 g
F P
s
P
p
.002 w
.40979 .59934 m .43896 .61264 L .4383 .6176 L p
1 g
F P
s
P
p
.002 w
.4383 .6176 m .40145 .60081 L .40979 .59934 L p
1 g
F P
s
P
p
.002 w
.38546 .58047 m .40979 .59934 L .40145 .60081 L p
1 g
F P
s
P
p
.002 w
.40145 .60081 m .37058 .57694 L .38546 .58047 L p
1 g
F P
s
P
p
.002 w
.33042 .37249 m .30765 .41259 L .30761 .38949 L p
1 g
F P
s
P
p
.002 w
.30761 .38949 m .33136 .34699 L .33042 .37249 L p
1 g
F P
s
P
p
.002 w
.52262 .24521 m .45882 .24345 L .46945 .23621 L p
1 g
F P
s
P
p
.002 w
.46945 .23621 m .52858 .23777 L .52262 .24521 L p
1 g
F P
s
P
p
.002 w
.43896 .61264 m .47017 .61913 L .47773 .62582 L p
1 g
F P
s
P
p
.002 w
.51614 .62462 m .47773 .62582 L .47017 .61913 L p
1 g
F P
s
P
p
.002 w
.67788 .36579 m .69611 .41853 L .69197 .43926 L p
1 g
F P
s
P
p
.002 w
.69611 .41853 m .67788 .36579 L .67725 .34803 L p
1 g
F P
s
P
p
.002 w
.44897 .25644 m .39044 .27334 L .40275 .25983 L p
1 g
F P
s
P
p
.002 w
.40275 .25983 m .45882 .24345 L .44897 .25644 L p
1 g
F P
s
P
p
.002 w
.33842 .51684 m .34874 .54807 L .33401 .53541 L p
1 g
F P
s
P
p
.002 w
.33401 .53541 m .32154 .49831 L .33842 .51684 L p
1 g
F P
s
P
p
.002 w
.67725 .34803 m .63959 .30141 L .63679 .28984 L p
1 g
F P
s
P
p
.002 w
.58696 .25646 m .63679 .28984 L .63959 .30141 L p
1 g
F P
s
P
p
.002 w
.32451 .4618 m .32154 .49831 L .31021 .47843 L p
1 g
F P
s
P
p
.002 w
.31021 .47843 m .31326 .43694 L .32451 .4618 L p
1 g
F P
s
P
p
.002 w
.51614 .62462 m .54984 .61386 L .57071 .61281 L p
1 g
F P
s
P
p
.002 w
.60121 .58958 m .57071 .61281 L .54984 .61386 L p
1 g
F P
s
P
p
.002 w
.57071 .61281 m .60121 .58958 L .62349 .58057 L p
1 g
F P
s
P
p
.002 w
.68212 .46043 m .67871 .50986 L .66373 .52825 L p
1 g
F P
s
P
p
.002 w
.67871 .50986 m .68212 .46043 L .69197 .43926 L p
1 g
F P
s
P
p
.002 w
.63959 .30141 m .67725 .34803 L .67788 .36579 L p
1 g
F P
s
P
p
.002 w
.3684 .55775 m .38546 .58047 L .37058 .57694 L p
1 g
F P
s
P
p
.002 w
.37058 .57694 m .34874 .54807 L .3684 .55775 L p
1 g
F P
s
P
p
.002 w
.58574 .26543 m .52262 .24521 L .52858 .23777 L p
1 g
F P
s
P
p
.002 w
.52858 .23777 m .58696 .25646 L .58574 .26543 L p
1 g
F P
s
P
p
.002 w
.47017 .61913 m .50044 .61813 L .51614 .62462 L p
1 g
F P
s
P
p
.002 w
.54984 .61386 m .51614 .62462 L .50044 .61813 L p
1 g
F P
s
P
p
.002 w
.63959 .30141 m .58574 .26543 L .58696 .25646 L p
1 g
F P
s
P
p
.002 w
.64353 .54436 m .62349 .58057 L .60121 .58958 L p
1 g
F P
s
P
p
.002 w
.62349 .58057 m .64353 .54436 L .66373 .52825 L p
1 g
F P
s
P
p
.002 w
.37451 .31523 m .33136 .34699 L .33706 .32464 L p
1 g
F P
s
P
p
.002 w
.33706 .32464 m .38088 .29192 L .37451 .31523 L p
1 g
F P
s
P
p
.002 w
.33449 .40042 m .31326 .43694 L .30765 .41259 L p
1 g
F P
s
P
p
.002 w
.30765 .41259 m .33042 .37249 L .33449 .40042 L p
1 g
F P
s
P
p
.002 w
.67332 .38611 m .69197 .43926 L .68212 .46043 L p
1 g
F P
s
P
p
.002 w
.69197 .43926 m .67332 .38611 L .67788 .36579 L p
1 g
F P
s
P
p
.002 w
.47017 .61913 m .43896 .61264 L .44144 .60214 L p
1 g
F P
s
P
p
.002 w
.42113 .59287 m .44144 .60214 L .43896 .61264 L p
1 g
F P
s
P
p
.002 w
.43896 .61264 m .40979 .59934 L .42113 .59287 L p
1 g
F P
s
P
p
.002 w
.44026 .27509 m .38088 .29192 L .39044 .27334 L p
1 g
F P
s
P
p
.002 w
.39044 .27334 m .44897 .25644 L .44026 .27509 L p
1 g
F P
s
P
p
.002 w
.36055 .53336 m .3684 .55775 L .34874 .54807 L p
1 g
F P
s
P
p
.002 w
.34874 .54807 m .33842 .51684 L .36055 .53336 L p
1 g
F P
s
P
p
.002 w
.51576 .25843 m .44897 .25644 L .45882 .24345 L p
1 g
F P
s
P
p
.002 w
.45882 .24345 m .52262 .24521 L .51576 .25843 L p
1 g
F P
s
P
p
.002 w
.40427 .57973 m .42113 .59287 L .40979 .59934 L p
1 g
F P
s
P
p
.002 w
.40979 .59934 m .38546 .58047 L .40427 .57973 L p
1 g
F P
s
P
p
.002 w
.44144 .60214 m .46316 .60663 L .47017 .61913 L p
1 g
F P
s
P
p
.002 w
.50044 .61813 m .47017 .61913 L .46316 .60663 L p
1 g
F P
s
P
p
.002 w
.34125 .48636 m .33842 .51684 L .32154 .49831 L p
1 g
F P
s
P
p
.002 w
.32154 .49831 m .32451 .4618 L .34125 .48636 L p
1 g
F P
s
P
p
.002 w
.66659 .48137 m .66373 .52825 L .64353 .54436 L p
1 g
F P
s
P
p
.002 w
.66373 .52825 m .66659 .48137 L .68212 .46043 L p
1 g
F P
s
P
p
.002 w
.67788 .36579 m .63841 .31725 L .63959 .30141 L p
1 g
F P
s
P
p
.002 w
.58574 .26543 m .63959 .30141 L .63841 .31725 L p
1 g
F P
s
P
p
.002 w
.50044 .61813 m .5268 .60958 L .54984 .61386 L p
1 g
F P
s
P
p
.002 w
.5753 .59421 m .54984 .61386 L .5268 .60958 L p
1 g
F P
s
P
p
.002 w
.54984 .61386 m .5753 .59421 L .60121 .58958 L p
1 g
F P
s
P
p
.002 w
.63841 .31725 m .67788 .36579 L .67332 .38611 L p
1 g
F P
s
P
p
.002 w
.39259 .56399 m .40427 .57973 L .38546 .58047 L p
1 g
F P
s
P
p
.002 w
.38546 .58047 m .3684 .55775 L .39259 .56399 L p
1 g
F P
s
P
p
.002 w
.61854 .55755 m .60121 .58958 L .5753 .59421 L p
1 g
F P
s
P
p
.002 w
.60121 .58958 m .61854 .55755 L .64353 .54436 L p
1 g
F P
s
P
p
.002 w
.37173 .3427 m .33042 .37249 L .33136 .34699 L p
1 g
F P
s
P
p
.002 w
.33136 .34699 m .37451 .31523 L .37173 .3427 L p
1 g
F P
s
P
p
.002 w
.46316 .60663 m .48414 .60588 L .50044 .61813 L p
1 g
F P
s
P
p
.002 w
.5268 .60958 m .50044 .61813 L .48414 .60588 L p
1 g
F P
s
P
p
.002 w
.34362 .42992 m .32451 .4618 L .31326 .43694 L p
1 g
F P
s
P
p
.002 w
.31326 .43694 m .33449 .40042 L .34362 .42992 L p
1 g
F P
s
P
p
.002 w
.58193 .27965 m .51576 .25843 L .52262 .24521 L p
1 g
F P
s
P
p
.002 w
.52262 .24521 m .58574 .26543 L .58193 .27965 L p
1 g
F P
s
P
p
.002 w
.63841 .31725 m .58193 .27965 L .58574 .26543 L p
1 g
F P
s
P
p
.002 w
.66345 .40843 m .68212 .46043 L .66659 .48137 L p
1 g
F P
s
P
p
.002 w
.68212 .46043 m .66345 .40843 L .67332 .38611 L p
1 g
F P
s
P
p
.002 w
.36309 .50976 m .36055 .53336 L .33842 .51684 L p
1 g
F P
s
P
p
.002 w
.33842 .51684 m .34125 .48636 L .36309 .50976 L p
1 g
F P
s
P
p
.002 w
.64568 .50137 m .64353 .54436 L .61854 .55755 L p
1 g
F P
s
P
p
.002 w
.64353 .54436 m .64568 .50137 L .66659 .48137 L p
1 g
F P
s
P
p
.002 w
.38739 .54721 m .39259 .56399 L .3684 .55775 L p
1 g
F P
s
P
p
.002 w
.3684 .55775 m .36055 .53336 L .38739 .54721 L p
1 g
F P
s
P
p
.002 w
.43305 .29907 m .37451 .31523 L .38088 .29192 L p
1 g
F P
s
P
p
.002 w
.38088 .29192 m .44026 .27509 L .43305 .29907 L p
1 g
F P
s
P
p
.002 w
.50815 .27733 m .44026 .27509 L .44897 .25644 L p
1 g
F P
s
P
p
.002 w
.44897 .25644 m .51576 .25843 L .50815 .27733 L p
1 g
F P
s
P
p
.002 w
.46316 .60663 m .44144 .60214 L .44575 .5861 L p
1 g
F P
s
P
p
.002 w
.43527 .5813 m .44575 .5861 L .44144 .60214 L p
1 g
F P
s
P
p
.002 w
.44144 .60214 m .42113 .59287 L .43527 .5813 L p
1 g
F P
s
P
p
.002 w
.48414 .60588 m .50226 .59987 L .5268 .60958 L p
1 g
F P
s
P
p
.002 w
.54646 .59411 m .5268 .60958 L .50226 .59987 L p
1 g
F P
s
P
p
.002 w
.5268 .60958 m .54646 .59411 L .5753 .59421 L p
1 g
F P
s
P
p
.002 w
.42661 .57451 m .43527 .5813 L .42113 .59287 L p
1 g
F P
s
P
p
.002 w
.42113 .59287 m .40427 .57973 L .42661 .57451 L p
1 g
F P
s
P
p
.002 w
.58942 .56726 m .5753 .59421 L .54646 .59411 L p
1 g
F P
s
P
p
.002 w
.5753 .59421 m .58942 .56726 L .61854 .55755 L p
1 g
F P
s
P
p
.002 w
.44575 .5861 m .45697 .58841 L .46316 .60663 L p
1 g
F P
s
P
p
.002 w
.48414 .60588 m .46316 .60663 L .45697 .58841 L p
1 g
F P
s
P
p
.002 w
.37277 .37352 m .33449 .40042 L .33042 .37249 L p
1 g
F P
s
P
p
.002 w
.33042 .37249 m .37173 .3427 L .37277 .37352 L p
1 g
F P
s
P
p
.002 w
.63306 .33706 m .67332 .38611 L .66345 .40843 L p
1 g
F P
s
P
p
.002 w
.67332 .38611 m .63306 .33706 L .63841 .31725 L p
1 g
F P
s
P
p
.002 w
.58193 .27965 m .63841 .31725 L .63306 .33706 L p
1 g
F P
s
P
p
.002 w
.35765 .45999 m .34125 .48636 L .32451 .4618 L p
1 g
F P
s
P
p
.002 w
.32451 .4618 m .34362 .42992 L .35765 .45999 L p
1 g
F P
s
P
p
.002 w
.42069 .5664 m .42661 .57451 L .40427 .57973 L p
1 g
F P
s
P
p
.002 w
.40427 .57973 m .39259 .56399 L .42069 .5664 L p
1 g
F P
s
P
p
.002 w
.45697 .58841 m .46776 .58797 L .48414 .60588 L p
1 g
F P
s
P
p
.002 w
.50226 .59987 m .48414 .60588 L .46776 .58797 L p
1 g
F P
s
P
p
.002 w
.64835 .43207 m .66659 .48137 L .64568 .50137 L p
1 g
F P
s
P
p
.002 w
.66659 .48137 m .64835 .43207 L .66345 .40843 L p
1 g
F P
s
P
p
.002 w
.61989 .51968 m .61854 .55755 L .58942 .56726 L p
1 g
F P
s
P
p
.002 w
.61854 .55755 m .61989 .51968 L .64568 .50137 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.38941 .53115 m .38739 .54721 L .36055 .53336 L p
1 g
F P
s
P
p
.002 w
.36055 .53336 m .36309 .50976 L .38941 .53115 L p
1 g
F P
s
P
p
.002 w
.57551 .29895 m .50815 .27733 L .51576 .25843 L p
1 g
F P
s
P
p
.002 w
.51576 .25843 m .58193 .27965 L .57551 .29895 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.4624 .5354 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63306 .33706 m .57551 .29895 L .58193 .27965 L p
1 g
F P
s
P
p
.002 w
.41817 .55783 m .42069 .5664 L .39259 .56399 L p
1 g
F P
s
P
p
.002 w
.39259 .56399 m .38739 .54721 L .41817 .55783 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.42769 .32775 m .37173 .3427 L .37451 .31523 L p
1 g
F P
s
P
p
.002 w
.37451 .31523 m .43305 .29907 L .42769 .32775 L p
1 g
F P
s
P
p
.002 w
.50226 .59987 m .51558 .58911 L .54646 .59411 L p
1 g
F P
s
P
p
.002 w
.55707 .57306 m .54646 .59411 L .51558 .58911 L p
1 g
F P
s
P
p
.002 w
.54646 .59411 m .55707 .57306 L .58942 .56726 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.46776 .58797 m .477 .58482 L .50226 .59987 L p
1 g
F P
s
P
p
.002 w
.51558 .58911 m .50226 .59987 L .477 .58482 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37619 .48957 m .36309 .50976 L .34125 .48636 L p
1 g
F P
s
P
p
.002 w
.34125 .48636 m .35765 .45999 L .37619 .48957 L p
1 g
F P
s
P
p
.002 w
.37771 .40668 m .34362 .42992 L .33449 .40042 L p
1 g
F P
s
P
p
.002 w
.33449 .40042 m .37277 .37352 L .37771 .40668 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.50004 .30154 m .43305 .29907 L .44026 .27509 L p
1 g
F P
s
P
p
.002 w
.44026 .27509 m .50815 .27733 L .50004 .30154 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.6235 .36037 m .66345 .40843 L .64835 .43207 L p
1 g
F P
s
P
p
.002 w
.66345 .40843 m .6235 .36037 L .63306 .33706 L p
1 g
F P
s
P
p
.002 w
.45697 .58841 m .44575 .5861 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.44575 .5861 m .43527 .5813 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.43527 .5813 m .42661 .57451 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.46776 .58797 m .45697 .58841 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.59002 .53561 m .58942 .56726 L .55707 .57306 L p
1 g
F P
s
P
p
.002 w
.58942 .56726 m .59002 .53561 L .61989 .51968 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.57551 .29895 m .63306 .33706 L .6235 .36037 L p
1 g
F P
s
P
p
.002 w
.41935 .54971 m .41817 .55783 L .38739 .54721 L p
1 g
F P
s
P
p
.002 w
.38739 .54721 m .38941 .53115 L .41935 .54971 L p
1 g
F P
s
P
p
.002 w
.62837 .45625 m .64568 .50137 L .61989 .51968 L p
1 g
F P
s
P
p
.002 w
.64568 .50137 m .62837 .45625 L .64835 .43207 L p
1 g
F P
s
P
p
.002 w
.42661 .57451 m .42069 .5664 L .45159 .56477 L p
1 g
F P
s
P
p
.002 w
.42069 .5664 m .41817 .55783 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.41817 .55783 m .41935 .54971 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.41935 .54971 m .42417 .54293 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.002 w
.45063 .56352 m .45146 .56129 L p
.44411 .55491 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45063 .56352 L p
1 g
F P
s
P
p
.002 w
.45188 .56476 m .45111 .56416 L p
.45067 .56355 L 1 g
F P
s
P
p
.002 w
.45142 .56415 m .45188 .56476 L p
.45067 .56355 L 1 g
F P
s
P
p
.002 w
.42417 .54293 m .43171 .53851 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.45111 .56416 m .4419 .5569 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.4419 .5569 m .42417 .54293 L p
.43837 .54732 L 1 g
F P
s
P
p
.41423 .50804 m .43166 .52545 L .43205 .53555 L 1 g
F
P
p
.002 w
.43252 .52871 m .43346 .52734 L p
.43317 .51914 L 1 g
F P
s
P
p
.002 w
.43837 .54732 m .43925 .54566 L p
.4345 .53627 L 1 g
F P
s
P
p
.4345 .53627 m .43488 .53769 L .43837 .54732 L 1 g
F
P
p
.434 .53527 m .43785 .54591 L .43837 .54732 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43488 .53771 m .43215 .53825 L p
.43166 .52545 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44244 .53622 m .43488 .53771 L p
.43252 .52871 L 1 g
F P
s
P
p
.43166 .52545 m .43267 .52646 L .43252 .52871 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43384 .50946 L p
1 g
F P
s
P
p
.43346 .52734 m .43384 .50946 L .43317 .51914 L 1 g
F
P
p
.43267 .52646 m .44244 .53622 L .43252 .52871 L 1 g
F
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.41423 .50804 m .43458 .5038 L .43523 .50644 L p
1 g
F P
s
P
p
.002 w
.43458 .5038 m .4339 .49976 L p
.44182 .49208 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.4364 .50393 m .43458 .5038 L p
.4441 .4884 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44201 .49197 L p
1 g
F P
s
P
p
.002 w
.44201 .49197 m .44166 .49233 L p
.43984 .4966 L 1 g
F P
s
P
p
.43485 .50826 m .44201 .49197 L .43984 .4966 L 1 g
F
P
p
.002 w
.43384 .50946 m .43485 .50826 L p
.43858 .49953 L 1 g
F P
s
P
p
.43858 .49953 m .43668 .50338 L .43384 .50946 L 1 g
F
P
p
.43984 .4966 m .43523 .50644 L .43384 .50946 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.45741 .50542 m .4539 .53709 L p
.43562 .50559 L 1 g
F P
s
P
p
.002 w
.43458 .5038 m .4364 .50393 L p
.43562 .50559 L 1 g
F P
s
P
p
.002 w
.4364 .50393 m .45741 .50542 L p
.43562 .50559 L 1 g
F P
s
P
p
.002 w
.44269 .49124 m .44339 .4905 L p
.44934 .4848 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45741 .50542 m .4364 .50393 L p
.44269 .49124 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45765 .47675 L p
1 g
F P
s
P
p
.44339 .4905 m .45765 .47675 L .44934 .4848 L 1 g
F
P
p
.4441 .4884 m .44476 .48924 L .44269 .49124 L 1 g
F
P
p
.44476 .48924 m .45741 .50542 L .44269 .49124 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.46231 .47084 m .46845 .43464 L p
.48511 .46338 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49573 .4817 m .46698 .47236 L p
.47761 .46709 L 1 g
F P
s
P
p
.48651 .46579 m .49573 .4817 L .47761 .46709 L 1 g
F
P
p
.002 w
.47761 .46709 m .47786 .46667 L p
.48659 .46578 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.46845 .43464 m .51172 .44867 L .50471 .46314 L p
1 g
F P
s
P
p
.002 w
.52478 .4999 m .49573 .4817 L .50405 .46451 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52236 .46704 L p
1 g
F P
s
P
p
.5 .4634 m .52236 .46704 L .51112 .46548 L 1 g
F
P
p
.51618 .46618 m .52478 .4999 L .50405 .46451 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47675 L p
1 g
F P
s
P
p
.52339 .46754 m .53414 .47276 L .52478 .4999 L 1 g
F
P
p
.52214 .46667 m .54235 .47675 L .53026 .47087 L 1 g
F
P
p
.002 w
.54394 .4783 m .52478 .4999 L p
.53414 .47276 L 1 g
F P
s
P
p
.53518 .46975 m .54235 .47675 L .53414 .47276 L 1 g
F
P
p
.54235 .47675 m .54394 .4783 L .53414 .47276 L 1 g
F
P
p
.51618 .46618 m .52339 .46754 L .52478 .4999 L 1 g
F
P
p
.002 w
.52236 .46704 m .52214 .46667 L p
.53026 .47087 L 1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54587 .47029 m .54919 .47239 L p
.51618 .46618 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52236 .46704 L p
1 g
F P
s
P
p
.53026 .47087 m .54302 .47747 L .52236 .46704 L 1 g
F
P
p
.002 w
.54235 .47675 m .54302 .47747 L p
.53026 .47087 L 1 g
F P
s
P
p
.52339 .46754 m .53518 .46975 L .53414 .47276 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5661 .50939 L p
1 g
F P
s
P
p
.55661 .4905 m .5661 .50939 L .566 .50918 L 1 g
F
P
p
.002 w
.57206 .50551 m .56615 .5095 L p
.5661 .50938 L 1 g
F P
s
P
p
.5582 .4921 m .56487 .49855 L .5661 .50938 L 1 g
F
P
p
.56487 .49855 m .57206 .50551 L .5661 .50938 L 1 g
F
P
p
.002 w
.5661 .50939 m .56515 .50826 L p
.56656 .51741 L 1 g
F P
s
P
p
.56656 .51741 m .56612 .50953 L .5661 .50939 L 1 g
F
P
p
.56992 .51782 m .56698 .52484 L .56615 .5095 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.56698 .52484 m .56612 .50963 L .56615 .5095 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56717 .52826 L p
1 g
F P
s
P
p
.57627 .50266 m .56807 .5442 L .56717 .52826 L 1 g
F
P
p
.57046 .51654 m .56717 .52826 L .56698 .52484 L 1 g
F
P
p
.57627 .50266 m .56717 .52826 L .57046 .51654 L 1 g
F
P
p
.002 w
.56717 .52826 m .56654 .52734 L p
.56487 .53646 L 1 g
F P
s
P
p
.56515 .50826 m .56717 .52826 L .56656 .51741 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54913 .56287 L p
1 g
F P
s
P
p
.002 w
.55707 .57306 m .53969 .57384 L p
.54913 .56287 L 1 g
F P
s
P
p
.002 w
.55706 .55366 m .55706 .55744 L p
.54913 .56287 L 1 g
F P
s
P
p
.002 w
.55706 .55744 m .55707 .57306 L p
.54913 .56287 L 1 g
F P
s
P
p
.002 w
.54913 .56287 m .54854 .56129 L p
.54112 .56836 L 1 g
F P
s
P
p
.56075 .54566 m .54913 .56287 L .55505 .55599 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58065 L p
1 g
F P
s
P
p
.002 w
.51558 .58911 m .49779 .58361 L p
.51094 .58065 L 1 g
F P
s
P
p
.002 w
.5207 .57845 m .5197 .58053 L p
.51094 .58065 L 1 g
F P
s
P
p
.002 w
.5197 .58053 m .51558 .58911 L p
.51094 .58065 L 1 g
F P
s
P
p
.002 w
.51094 .58065 m .51079 .57862 L p
.49995 .58079 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .58065 L .51905 .57882 L 1 g
F
P
p
.51858 .57916 m .5111 .58283 L .5125 .58228 L 1 g
F
P
p
.53128 .57265 m .51792 .57939 L .51858 .57916 L 1 g
F
P
p
.51792 .57939 m .5111 .58283 L .51858 .57916 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .57471 L p
1 g
F P
s
P
p
.55707 .57306 m .51888 .58225 L .52693 .57752 L 1 g
F
P
p
.54854 .56129 m .53173 .57471 L .53265 .57416 L 1 g
F
P
p
.54913 .56287 m .54248 .5706 L .53592 .57192 L 1 g
F
P
p
.54854 .56129 m .53265 .57416 L .54112 .56836 L 1 g
F
P
p
.002 w
.53343 .57413 m .53265 .57416 L p
.54248 .5706 L 1 g
F P
s
P
p
.002 w
.51888 .58225 m .5207 .57845 L p
.52693 .57752 L 1 g
F P
s
P
p
.002 w
.53343 .57413 m .55707 .57306 L p
.5207 .57845 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53265 .57416 m .52254 .57462 L p
.53592 .57192 L 1 g
F P
s
P
p
.54248 .5706 m .53265 .57416 L .53592 .57192 L 1 g
F
P
p
.002 w
.5207 .57845 m .52254 .57462 L .53265 .57416 L p
1 g
F P
s
P
p
.002 w
.53265 .57416 m .53343 .57413 L p
.53173 .57471 L 1 g
F P
s
P
p
.53173 .57471 m .5207 .57845 L .53265 .57416 L 1 g
F
P
p
.002 w
.53969 .57384 m .53343 .57413 L p
.54248 .5706 L 1 g
F P
s
P
p
.53884 .57053 m .53265 .57416 L .5322 .57686 L 1 g
F
P
p
.002 w
.53173 .57471 m .53175 .57479 L p
.53265 .57416 L 1 g
F P
s
P
p
.002 w
.53175 .57479 m .5322 .57686 L p
.53265 .57416 L 1 g
F P
s
P
p
.54112 .56836 m .53265 .57416 L .53884 .57053 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55707 .57306 m .55706 .55958 L p
.59002 .53561 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5617 .54745 L p
1 g
F P
s
P
p
.56654 .52734 m .5617 .54745 L .56193 .54686 L 1 g
F
P
p
.59002 .53561 m .55706 .55958 L .5617 .54745 L 1 g
F
P
p
.002 w
.56204 .54656 m .56251 .54637 L p
.5617 .54745 L 1 g
F P
s
P
p
.002 w
.56251 .54637 m .59002 .53561 L p
.5617 .54745 L 1 g
F P
s
P
p
.002 w
.5617 .54745 m .56075 .54566 L p
.55671 .55413 L 1 g
F P
s
P
p
.56654 .52734 m .56193 .54686 L .56487 .53646 L 1 g
F
P
p
.56193 .54686 m .56176 .54757 L .56204 .54656 L 1 g
F
P
p
.56193 .54686 m .56204 .54656 L .56487 .53646 L 1 g
F
P
p
.002 w
.54998 .56518 m .5537 .56044 L p
.55671 .55413 L 1 g
F P
s
P
p
.56075 .54566 m .55432 .55733 L .55671 .55413 L 1 g
F
P
p
.55432 .55733 m .54998 .56518 L .55671 .55413 L 1 g
F
P
p
.002 w
.55706 .54851 m .56204 .54656 L p
.5617 .54745 L 1 g
F P
s
P
p
.002 w
.55706 .55958 m .55706 .55366 L p
.5617 .54745 L 1 g
F P
s
P
p
.002 w
.55706 .55366 m .55706 .54851 L p
.5617 .54745 L 1 g
F P
s
P
p
.002 w
.56176 .54757 m .5617 .54745 L p
.5537 .56044 L 1 g
F P
s
P
p
.55671 .55413 m .5537 .56044 L .5617 .54745 L 1 g
F
P
p
.002 w
.5617 .54745 m .56176 .54757 L p
.56193 .54686 L 1 g
F P
s
P
p
.56717 .52826 m .56772 .53805 L .56318 .54251 L 1 g
F
P
p
.002 w
.56807 .5442 m .56251 .54637 L p
.56772 .53805 L 1 g
F P
s
P
p
.002 w
.56251 .54637 m .55706 .54851 L p
.56772 .53805 L 1 g
F P
s
P
p
.002 w
.56176 .54757 m .56257 .5491 L p
.56487 .53646 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56698 .52484 m .56717 .52826 L .55706 .54851 L 1 g
F
P
p
.56717 .52826 m .56318 .54251 L .55706 .54851 L 1 g
F
P
p
.002 w
.5537 .56044 m .56257 .5491 L .56176 .54757 L p
1 g
F P
s
P
p
.55706 .55366 m .54913 .56287 L .52254 .57462 L 1 g
F
P
p
.54913 .56287 m .53592 .57192 L .52254 .57462 L 1 g
F
P
p
.002 w
.51558 .58911 m .51888 .58225 L p
.55707 .57306 L 1 g
F P
s
P
p
.002 w
.477 .58482 m .4818 .58082 L p
.51558 .58911 L 1 g
F P
s
P
p
.002 w
.4818 .58082 m .48314 .57969 L p
.4873 .5809 L 1 g
F P
s
P
p
.51558 .58911 m .4818 .58082 L .4873 .5809 L 1 g
F
P
p
.002 w
.48923 .58097 m .51558 .58911 L p
.4873 .5809 L 1 g
F P
s
P
p
.4873 .5809 m .48314 .57969 L .48904 .58093 L 1 g
F
P
p
.4873 .5809 m .48904 .58093 L .48923 .58097 L 1 g
F
P
p
.002 w
.48904 .58093 m .48921 .57862 L p
.47708 .57762 L 1 g
F P
s
P
p
.002 w
.477 .58482 m .46119 .57219 L p
.46829 .57462 L 1 g
F P
s
P
p
.002 w
.48314 .57969 m .48035 .58202 L p
.46829 .57462 L 1 g
F P
s
P
p
.002 w
.48035 .58202 m .477 .58482 L p
.46829 .57462 L 1 g
F P
s
P
p
.002 w
.46829 .57462 m .46872 .57265 L p
.45831 .56849 L 1 g
F P
s
P
p
.47708 .57762 m .48314 .57969 L .48904 .58093 L 1 g
F
P
p
.002 w
.46119 .57219 m .45188 .56476 L p
.45348 .56552 L 1 g
F P
s
P
p
.46829 .57462 m .46119 .57219 L .45348 .56552 L 1 g
F
P
p
.46872 .57265 m .45063 .56352 L .45142 .56415 L 1 g
F
P
p
.46872 .57265 m .45142 .56415 L .45176 .56442 L 1 g
F
P
p
.002 w
.45189 .56452 m .45188 .56476 L .45176 .56442 L p
1 g
F P
s
P
p
.45184 .56448 m .45176 .56442 L .45184 .56448 L 1 g
F
P
p
.46872 .57265 m .45176 .56442 L .45184 .56448 L 1 g
F
P
p
.46872 .57265 m .45184 .56448 L .4519 .56452 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.44244 .53622 m .4539 .53709 L .45189 .56452 L p
1 g
F P
s
P
p
.002 w
.45176 .56442 m .44244 .53622 L p
.45189 .56452 L 1 g
F P
s
P
p
.46872 .57265 m .45189 .56452 L .45195 .56456 L 1 g
F
P
p
.46872 .57265 m .45194 .56455 L .45199 .56459 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.4539 .53709 m .46525 .54079 L .45198 .56458 L p
1 g
F P
s
P
p
.002 w
.45198 .56458 m .45188 .56476 L .45189 .56452 L p
1 g
F P
s
P
p
.002 w
.45189 .56452 m .4539 .53709 L p
.45198 .56458 L 1 g
F P
s
P
p
.4519 .56452 m .45184 .56448 L .45189 .56452 L 1 g
F
P
p
.45195 .56456 m .45189 .56452 L .45194 .56455 L 1 g
F
P
p
.46872 .57265 m .45197 .56458 L .45204 .56462 L 1 g
F
P
p
.002 w
.46525 .54079 m .47519 .5469 L .45205 .56463 L p
1 g
F P
s
P
p
.002 w
.45205 .56463 m .45188 .56476 L .45198 .56458 L p
1 g
F P
s
P
p
.002 w
.45198 .56458 m .46525 .54079 L p
.45205 .56463 L 1 g
F P
s
P
p
.46872 .57265 m .45201 .56461 L .45208 .56465 L 1 g
F
P
p
.46872 .57265 m .45204 .56464 L .45208 .56466 L 1 g
F
P
p
.002 w
.47519 .5469 m .4826 .55472 L .45212 .56468 L p
1 g
F P
s
P
p
.002 w
.45212 .56468 m .45188 .56476 L .45205 .56463 L p
1 g
F P
s
P
p
.002 w
.45205 .56463 m .47519 .5469 L p
.45212 .56468 L 1 g
F P
s
P
p
.45199 .56459 m .45194 .56455 L .45197 .56458 L 1 g
F
P
p
.45204 .56462 m .45197 .56458 L .45201 .56461 L 1 g
F
P
p
.46872 .57265 m .45204 .56464 L .45831 .56849 L 1 g
F
P
p
.002 w
.4826 .55472 m .4867 .56335 L .45222 .56475 L p
1 g
F P
s
P
p
.002 w
.45222 .56475 m .45188 .56476 L .45212 .56468 L p
1 g
F P
s
P
p
.002 w
.45212 .56468 m .4826 .55472 L p
.45222 .56475 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.4867 .56335 m .48705 .57183 L .45241 .56487 L p
1 g
F P
s
P
p
.002 w
.45241 .56487 m .45188 .56476 L .45222 .56475 L p
1 g
F P
s
P
p
.002 w
.45222 .56475 m .4867 .56335 L p
.45241 .56487 L 1 g
F P
s
P
p
.45208 .56465 m .45201 .56461 L .45204 .56464 L 1 g
F
P
p
.45208 .56466 m .45204 .56464 L .45206 .56465 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.48705 .57183 m .48368 .57925 L .45326 .56539 L p
1 g
F P
s
P
p
.002 w
.45326 .56539 m .45188 .56476 L .45241 .56487 L p
1 g
F P
s
P
p
.002 w
.45241 .56487 m .48705 .57183 L p
.45326 .56539 L 1 g
F P
s
P
p
.002 w
.44244 .53622 m .45176 .56442 L p
.43785 .54591 L 1 g
F P
s
P
p
.002 w
.45176 .56442 m .45188 .56476 L .45142 .56415 L p
1 g
F P
s
P
p
.002 w
.45142 .56415 m .43785 .54591 L p
.45176 .56442 L 1 g
F P
s
P
p
.45206 .56465 m .45142 .56415 L .45204 .56464 L 1 g
F
P
p
.002 w
.45188 .56476 m .45326 .56539 L p
.45348 .56552 L 1 g
F P
s
P
p
.45831 .56849 m .45204 .56464 L .45543 .56734 L 1 g
F
P
p
.002 w
.48368 .57925 m .48314 .57969 L p
.45348 .56552 L 1 g
F P
s
P
p
.002 w
.45326 .56539 m .48368 .57925 L p
.45348 .56552 L 1 g
F P
s
P
p
.48314 .57969 m .46829 .57462 L .45348 .56552 L 1 g
F
P
p
.002 w
.45159 .56477 m .45188 .56476 L .45165 .56485 L p
1 g
F P
s
P
p
.002 w
.45165 .56485 m .42661 .57451 L p
.45159 .56477 L 1 g
F P
s
P
p
.002 w
.477 .58482 m .46776 .58797 L .45188 .56476 L closepath p
1 g
F P
s
P
p
.45543 .56734 m .45204 .56464 L .45002 .56518 L 1 g
F
P
p
.002 w
.43171 .53851 m .43215 .53825 L p
.45111 .56416 L 1 g
F P
s
P
p
.002 w
.45063 .56352 m .45055 .56373 L p
.45204 .56464 L 1 g
F P
s
P
p
.002 w
.45055 .56373 m .45002 .56518 L p
.45204 .56464 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57462 L p
1 g
F P
s
P
p
.45831 .56849 m .45002 .56518 L .46829 .57462 L 1 g
F
P
p
.47708 .57762 m .47075 .5771 L .48314 .57969 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58093 L p
1 g
F P
s
P
p
.002 w
.4891 .58093 m .48923 .58097 L p
.48904 .58093 L 1 g
F P
s
P
p
.002 w
.48904 .58093 m .48904 .58093 L p
.48905 .58093 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58093 L .48905 .58093 L 1 g
F
P
p
.51079 .57862 m .48904 .58093 L .49995 .58079 L 1 g
F
P
p
.002 w
.48314 .57969 m .48368 .57925 L .4891 .58093 L p
1 g
F P
s
P
p
.48904 .58093 m .48314 .57969 L .4891 .58093 L 1 g
F
P
p
.5207 .57845 m .51094 .58065 L .48368 .57925 L 1 g
F
P
p
.51094 .58065 m .5 .58311 L .49068 .58091 L 1 g
F
P
p
.51094 .58065 m .49068 .58091 L .48368 .57925 L 1 g
F
P
p
.002 w
.49779 .58361 m .48923 .58097 L p
.5 .58311 L 1 g
F P
s
P
p
.002 w
.48923 .58097 m .48368 .57925 L p
.5 .58311 L 1 g
F P
s
P
p
.002 w
.48904 .58093 m .48889 .583 L p
.49995 .58079 L 1 g
F P
s
P
p
.49995 .58079 m .49853 .58107 L .51094 .58065 L 1 g
F
P
p
.49853 .58107 m .48889 .583 L .50592 .58118 L 1 g
F
P
p
.49853 .58107 m .50592 .58118 L .51094 .58065 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51099 .58126 L p
1 g
F P
s
P
p
.002 w
.51099 .58126 m .51094 .58065 L p
.50592 .58118 L 1 g
F P
s
P
p
.50592 .58118 m .48889 .583 L .51099 .58126 L 1 g
F
P
p
.002 w
.48904 .58093 m .48904 .58093 L p
.46923 .57698 L 1 g
F P
s
P
p
.47075 .5771 m .46923 .57698 L .48904 .58093 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58093 L p
1 g
F P
s
P
p
.46923 .57698 m .4678 .57686 L .48904 .58093 L 1 g
F
P
p
.002 w
.51094 .58065 m .5111 .58283 L p
.51905 .57882 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.52254 .57462 m .5207 .57845 L p
.48368 .57925 L 1 g
F P
s
P
p
.002 w
.5111 .58283 m .51111 .583 L p
.5125 .58228 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54913 .56287 L p
1 g
F P
s
P
p
.54112 .56836 m .5322 .57686 L .54913 .56287 L 1 g
F
P
p
.002 w
.54913 .56287 m .54998 .56518 L p
.55505 .55599 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55706 .54851 m .55706 .55366 L p
.52254 .57462 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56717 .52826 L p
1 g
F P
s
P
p
.56487 .53646 m .56257 .5491 L .56717 .52826 L 1 g
F
P
p
.002 w
.56717 .52826 m .56854 .53025 L p
.56656 .51741 L 1 g
F P
s
P
p
.002 w
.57627 .50266 m .59002 .53561 L .56807 .5442 L p
1 g
F P
s
P
p
.56698 .52484 m .55706 .54851 L .56612 .50963 L 1 g
F
P
p
.002 w
.56612 .50953 m .56615 .5095 L p
.56612 .50963 L 1 g
F P
s
P
p
.54919 .47239 m .5582 .4921 L .54906 .47443 L 1 g
F
P
p
.5582 .4921 m .56615 .5095 L .5572 .49113 L 1 g
F
P
p
.5582 .4921 m .5572 .49113 L .54906 .47443 L 1 g
F
P
p
.55661 .4905 m .566 .50918 L .56083 .49857 L 1 g
F
P
p
.54174 .47608 m .54941 .48359 L .5493 .48349 L 1 g
F
P
p
.002 w
.56615 .5095 m .57627 .50266 L p
.56992 .51782 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5572 .49113 L p
1 g
F P
s
P
p
.54174 .47608 m .5572 .49113 L .54941 .48359 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54854 .48275 m .5661 .50939 L .54599 .52312 L 1 g
F
P
p
.002 w
.54244 .47685 m .54174 .47608 L p
.5493 .48349 L 1 g
F P
s
P
p
.54906 .47443 m .5572 .49113 L .54854 .48275 L 1 g
F
P
p
.5572 .49113 m .5661 .50939 L .54854 .48275 L 1 g
F
P
p
.002 w
.54599 .52312 m .52478 .4999 L .54919 .47239 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54244 .47685 L p
1 g
F P
s
P
p
.5493 .48349 m .55834 .49233 L .54244 .47685 L 1 g
F
P
p
.5493 .48349 m .5583 .4923 L .55772 .49173 L 1 g
F
P
p
.54941 .48359 m .5583 .4923 L .5493 .48349 L 1 g
F
P
p
.56083 .49857 m .56611 .5094 L .56365 .50397 L 1 g
F
P
p
.566 .50918 m .56611 .5094 L .56083 .49857 L 1 g
F
P
p
.002 w
.56615 .5095 m .56612 .50953 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56612 .50953 m .54599 .52312 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .5094 L p
1 g
F P
s
P
p
.002 w
.56611 .5094 m .5661 .50939 L p
.56612 .50952 L 1 g
F P
s
P
p
.56612 .50952 m .56854 .53025 L .56611 .5094 L 1 g
F
P
p
.56656 .51741 m .56827 .52849 L .56612 .50953 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55706 .54851 m .54599 .52312 L .56612 .50953 L p
1 g
F P
s
P
p
.56612 .50963 m .55706 .54851 L .56612 .50953 L 1 g
F
P
p
.56827 .52849 m .56854 .53025 L .5661 .50939 L 1 g
F
P
p
.002 w
.5572 .49113 m .5583 .4923 L p
.54941 .48359 L 1 g
F P
s
P
p
.002 w
.54919 .47239 m .57627 .50266 L .57206 .50551 L p
1 g
F P
s
P
p
.54919 .47239 m .57206 .50551 L .5582 .4921 L 1 g
F
P
p
.002 w
.5661 .50939 m .56611 .5094 L p
.566 .50918 L 1 g
F P
s
P
p
.002 w
.56611 .5094 m .56713 .51061 L p
.56365 .50397 L 1 g
F P
s
P
p
.002 w
.54919 .47239 m .54394 .4783 L p
.53518 .46975 L 1 g
F P
s
P
p
.002 w
.5583 .4923 m .55834 .49233 L p
.55772 .49173 L 1 g
F P
s
P
p
.5101 .46534 m .52274 .46766 L .51795 .46685 L 1 g
F
P
p
.5 .4634 m .51112 .46548 L .5101 .46534 L 1 g
F
P
p
.51112 .46548 m .52274 .46766 L .5101 .46534 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51172 .44867 m .54587 .47029 L p
.51618 .46618 L 1 g
F P
s
P
p
.002 w
.50405 .46451 m .49573 .4817 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .4634 L p
.51795 .46685 L 1 g
F P
s
P
p
.51795 .46685 m .52282 .46778 L .5 .46382 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.46845 .43464 m .50471 .46314 L .5 .46382 L 1 g
F
P
p
.47786 .46667 m .5 .46382 L .48659 .46578 L 1 g
F
P
p
.48378 .46109 m .5 .46382 L .48651 .46579 L 1 g
F
P
p
.46845 .43464 m .5 .46382 L .48378 .46109 L 1 g
F
P
p
.002 w
.50405 .46451 m .51172 .44867 L p
.51618 .46618 L 1 g
F P
s
P
p
.002 w
.52236 .46704 m .52274 .46766 L p
.51112 .46548 L 1 g
F P
s
P
p
.002 w
.52274 .46766 m .52282 .46778 L p
.51795 .46685 L 1 g
F P
s
P
p
.48651 .46579 m .5 .46382 L .49573 .4817 L 1 g
F
P
p
.002 w
.50471 .46314 m .50405 .46451 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .46442 L p
.48659 .46578 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47761 .46709 L p
1 g
F P
s
P
p
.48659 .46578 m .5 .46442 L .47761 .46709 L 1 g
F
P
p
.48511 .46338 m .48651 .46579 L .47761 .46709 L 1 g
F
P
p
.002 w
.45765 .47675 m .45826 .47608 L p
.46877 .47147 L 1 g
F P
s
P
p
.46877 .47147 m .46763 .47204 L .45765 .47675 L 1 g
F
P
p
.46957 .47112 m .46174 .47486 L .45765 .47675 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47744 .46736 L p
1 g
F P
s
P
p
.002 w
.47744 .46736 m .47718 .46778 L p
.46957 .47112 L 1 g
F P
s
P
p
.45826 .47608 m .47744 .46736 L .46957 .47112 L 1 g
F
P
p
.002 w
.49573 .4817 m .48004 .51279 L p
.46363 .47396 L 1 g
F P
s
P
p
.002 w
.46231 .47084 m .46698 .47236 L p
.46363 .47396 L 1 g
F P
s
P
p
.002 w
.46698 .47236 m .49573 .4817 L p
.46363 .47396 L 1 g
F P
s
P
p
.002 w
.46698 .47236 m .46231 .47084 L p
.48511 .46338 L 1 g
F P
s
P
p
.46877 .47147 m .46957 .47112 L .46763 .47204 L 1 g
F
P
p
.46363 .47396 m .48004 .51279 L .46174 .47486 L 1 g
F
P
p
.46957 .47112 m .47549 .46853 L .46174 .47486 L 1 g
F
P
p
.002 w
.48004 .51279 m .45741 .50542 L .46174 .47486 L p
1 g
F P
s
P
p
.002 w
.46174 .47486 m .46231 .47084 L p
.46363 .47396 L 1 g
F P
s
P
p
.002 w
.42865 .46864 m .46231 .47084 L .46174 .47486 L p
1 g
F P
s
P
p
.002 w
.46174 .47486 m .45741 .50542 L p
.44099 .48442 L 1 g
F P
s
P
p
.42865 .46864 m .46174 .47486 L .44099 .48442 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47675 L p
1 g
F P
s
P
p
.47549 .46853 m .47718 .46778 L .45765 .47675 L 1 g
F
P
p
.002 w
.45765 .47675 m .45698 .47747 L p
.44934 .4848 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44269 .49124 L p
1 g
F P
s
P
p
.44934 .4848 m .45698 .47747 L .44269 .49124 L 1 g
F
P
p
.42865 .46864 m .4441 .4884 L .44182 .49208 L 1 g
F
P
p
.002 w
.4339 .49976 m .42865 .46864 L p
.44182 .49208 L 1 g
F P
s
P
p
.43858 .49953 m .43984 .4966 L .43668 .50338 L 1 g
F
P
p
.002 w
.43523 .50644 m .43458 .5038 L p
.43562 .50559 L 1 g
F P
s
P
p
.43984 .4966 m .4411 .49366 L .43523 .50644 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.4539 .53709 m .44244 .53622 L .43523 .50644 L p
1 g
F P
s
P
p
.43562 .50559 m .4539 .53709 L .43523 .50644 L 1 g
F
P
p
.002 w
.43523 .50644 m .44244 .53622 L p
.42812 .52192 L 1 g
F P
s
P
p
.41423 .50804 m .43523 .50644 L .42812 .52192 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43384 .50946 L p
1 g
F P
s
P
p
.4411 .49366 m .44166 .49233 L .43384 .50946 L 1 g
F
P
p
.002 w
.43384 .50946 m .43287 .51061 L p
.43317 .51914 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43252 .52871 L p
1 g
F P
s
P
p
.43317 .51914 m .43287 .51061 L .43252 .52871 L 1 g
F
P
p
.002 w
.43215 .53825 m .43189 .53781 L p
.43205 .53555 L 1 g
F P
s
P
p
.002 w
.43189 .53781 m .41423 .50804 L p
.43205 .53555 L 1 g
F P
s
P
p
.4345 .53627 m .434 .53527 L .43488 .53769 L 1 g
F
P
p
.002 w
.43785 .54591 m .43215 .53825 L .43488 .53771 L p
1 g
F P
s
P
p
.434 .53527 m .43378 .53484 L .43785 .54591 L 1 g
F
P
p
.002 w
.43488 .53771 m .44244 .53622 L p
.43785 .54591 L 1 g
F P
s
P
p
.002 w
.43215 .53825 m .45142 .56415 L p
.45067 .56355 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43837 .54732 L p
1 g
F P
s
P
p
.43378 .53484 m .43146 .53025 L .43837 .54732 L 1 g
F
P
p
.002 w
.4506 .5636 m .45063 .56352 L p
.44105 .55224 L 1 g
F P
s
P
p
.44411 .55491 m .44105 .55224 L .45063 .56352 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4506 .5636 L p
1 g
F P
s
P
p
.44105 .55224 m .43743 .5491 L .4506 .5636 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.39863 .51756 m .38941 .53115 L .36309 .50976 L p
1 g
F P
s
P
p
.002 w
.36309 .50976 m .37619 .48957 L .39863 .51756 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.38649 .44101 m .35765 .45999 L .34362 .42992 L p
1 g
F P
s
P
p
.002 w
.34362 .42992 m .37771 .40668 L .38649 .44101 L p
1 g
F P
s
P
p
.002 w
.42444 .36025 m .37277 .37352 L .37173 .3427 L p
1 g
F P
s
P
p
.002 w
.37173 .3427 m .42769 .32775 L .42444 .36025 L p
1 g
F P
s
P
p
.002 w
.56657 .32293 m .50004 .30154 L .50815 .27733 L p
1 g
F P
s
P
p
.002 w
.50815 .27733 m .57551 .29895 L .56657 .32293 L p
1 g
F P
s
P
p
.002 w
.6235 .36037 m .56657 .32293 L .57551 .29895 L p
1 g
F P
s
P
p
.002 w
.48368 .57925 m .48705 .57183 L .52254 .57462 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42417 .54293 m .41935 .54971 L .38941 .53115 L p
1 g
F P
s
P
p
.002 w
.38941 .53115 m .39863 .51756 L .42417 .54293 L p
1 g
F P
s
P
p
.002 w
.60407 .48008 m .61989 .51968 L .59002 .53561 L p
1 g
F P
s
P
p
.002 w
.61989 .51968 m .60407 .48008 L .62837 .45625 L p
1 g
F P
s
P
p
.002 w
.60988 .3865 m .64835 .43207 L .62837 .45625 L p
1 g
F P
s
P
p
.002 w
.64835 .43207 m .60988 .3865 L .6235 .36037 L p
1 g
F P
s
P
p
.002 w
.4917 .33043 m .42769 .32775 L .43305 .29907 L p
1 g
F P
s
P
p
.002 w
.43305 .29907 m .50004 .30154 L .4917 .33043 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.52219 .55787 m .52254 .57462 L .48705 .57183 L p
1 g
F P
s
P
p
.002 w
.52254 .57462 m .52219 .55787 L .55706 .54851 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39881 .47522 m .37619 .48957 L .35765 .45999 L p
1 g
F P
s
P
p
.002 w
.35765 .45999 m .38649 .44101 L .39881 .47522 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.56657 .32293 m .6235 .36037 L .60988 .3865 L p
1 g
F P
s
P
p
.002 w
.48705 .57183 m .4867 .56335 L .52219 .55787 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42348 .39546 m .37771 .40668 L .37277 .37352 L p
1 g
F P
s
P
p
.002 w
.37277 .37352 m .42444 .36025 L .42348 .39546 L p
1 g
F P
s
P
p
.002 w
.59002 .53561 m .57627 .50266 L .60407 .48008 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41423 .50804 m .39863 .51756 L .37619 .48957 L p
1 g
F P
s
P
p
.002 w
.37619 .48957 m .39881 .47522 L .41423 .50804 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43215 .53825 m .42417 .54293 L .39863 .51756 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.39863 .51756 m .41423 .50804 L .43215 .53825 L p
1 g
F P
s
P
p
.002 w
.4867 .56335 m .4826 .55472 L .51437 .54069 L p
1 g
F P
s
P
p
.002 w
.51437 .54069 m .52219 .55787 L .4867 .56335 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.54599 .52312 m .55706 .54851 L .52219 .55787 L p
1 g
F P
s
P
p
.002 w
.59255 .41457 m .62837 .45625 L .60407 .48008 L p
1 g
F P
s
P
p
.002 w
.62837 .45625 m .59255 .41457 L .60988 .3865 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.52219 .55787 m .51437 .54069 L .54599 .52312 L p
1 g
F P
s
P
p
.002 w
.55532 .35092 m .4917 .33043 L .50004 .30154 L p
1 g
F P
s
P
p
.002 w
.50004 .30154 m .56657 .32293 L .55532 .35092 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.60988 .3865 m .55532 .35092 L .56657 .32293 L p
1 g
F P
s
P
p
.002 w
.48344 .36304 m .42444 .36025 L .42769 .32775 L p
1 g
F P
s
P
p
.002 w
.42769 .32775 m .4917 .33043 L .48344 .36304 L p
1 g
F P
s
P
p
.002 w
.4826 .55472 m .47519 .5469 L .49979 .52504 L p
1 g
F P
s
P
p
.002 w
.49979 .52504 m .51437 .54069 L .4826 .55472 L p
1 g
F P
s
P
p
.002 w
.4249 .43206 m .38649 .44101 L .37771 .40668 L p
1 g
F P
s
P
p
.002 w
.37771 .40668 m .42348 .39546 L .4249 .43206 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.47519 .5469 m .46525 .54079 L .48004 .51279 L p
1 g
F P
s
P
p
.002 w
.48004 .51279 m .49979 .52504 L .47519 .5469 L p
1 g
F P
s
P
p
.002 w
.55532 .35092 m .60988 .3865 L .59255 .41457 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46525 .54079 m .4539 .53709 L .45741 .50542 L p
1 g
F P
s
P
p
.002 w
.45741 .50542 m .48004 .51279 L .46525 .54079 L p
1 g
F P
s
P
p
.002 w
.43458 .5038 m .41423 .50804 L .39881 .47522 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.57207 .44357 m .60407 .48008 L .57627 .50266 L p
1 g
F P
s
P
p
.002 w
.60407 .48008 m .57207 .44357 L .59255 .41457 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42865 .46864 m .39881 .47522 L .38649 .44101 L p
1 g
F P
s
P
p
.002 w
.38649 .44101 m .4249 .43206 L .42865 .46864 L p
1 g
F P
s
P
p
.002 w
.51437 .54069 m .49979 .52504 L .52478 .4999 L p
1 g
F P
s
P
p
.002 w
.52478 .4999 m .54599 .52312 L .51437 .54069 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.39881 .47522 m .42865 .46864 L .43458 .5038 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57627 .50266 m .54919 .47239 L .57207 .44357 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.47559 .39823 m .42348 .39546 L .42444 .36025 L p
1 g
F P
s
P
p
.002 w
.42444 .36025 m .48344 .36304 L .47559 .39823 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5421 .38198 m .48344 .36304 L .4917 .33043 L p
1 g
F P
s
P
p
.002 w
.4917 .33043 m .55532 .35092 L .5421 .38198 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.59255 .41457 m .5421 .38198 L .55532 .35092 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.49979 .52504 m .48004 .51279 L .49573 .4817 L p
1 g
F P
s
P
p
.002 w
.49573 .4817 m .52478 .4999 L .49979 .52504 L p
1 g
F P
s
P
p
.002 w
.5421 .38198 m .59255 .41457 L .57207 .44357 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.46845 .43464 m .4249 .43206 L .42348 .39546 L p
1 g
F P
s
P
p
.002 w
.42348 .39546 m .47559 .39823 L .46845 .43464 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.004 w
.43216 .61975 m
.43541 .61068 L
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46231 .47084 m .42865 .46864 L .4249 .43206 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.4249 .43206 m .46845 .43464 L .46231 .47084 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.52738 .41499 m .57207 .44357 L .54919 .47239 L p
1 g
F P
s
P
p
.002 w
.57207 .44357 m .52738 .41499 L .5421 .38198 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52738 .41499 m .47559 .39823 L .48344 .36304 L p
1 g
F P
s
P
p
.002 w
.48344 .36304 m .5421 .38198 L .52738 .41499 L p
1 g
F P
s
P
p
.002 w
.54919 .47239 m .51172 .44867 L .52738 .41499 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51172 .44867 m .46845 .43464 L .47559 .39823 L p
1 g
F P
s
P
p
.002 w
.47559 .39823 m .52738 .41499 L .51172 .44867 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .31922 .65814 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .42361 .64362 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.531783)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.531783)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45457 .44221 m .48858 .46683 L .50214 .44187 L p
1 g
F P
s
P
p
.002 w
.50214 .44187 m .47384 .42134 L .45457 .44221 L p
1 g
F P
s
P
p
.002 w
.53473 .45402 m .50214 .44187 L .48858 .46683 L p
1 g
F P
s
P
p
.002 w
.47384 .42134 m .50214 .44187 L .51562 .41669 L p
1 g
F P
s
P
p
.002 w
.50214 .44187 m .53473 .45402 L .5409 .42604 L p
1 g
F P
s
P
p
.002 w
.5409 .42604 m .51562 .41669 L .50214 .44187 L p
1 g
F P
s
P
p
.002 w
.51562 .41669 m .4937 .40075 L .47384 .42134 L p
1 g
F P
s
P
p
.002 w
.4937 .40075 m .51562 .41669 L .52877 .39173 L p
1 g
F P
s
P
p
.002 w
.51562 .41669 m .5409 .42604 L .5461 .39808 L p
1 g
F P
s
P
p
.002 w
.5461 .39808 m .52877 .39173 L .51562 .41669 L p
1 g
F P
s
P
p
.002 w
.42887 .4099 m .45457 .44221 L .47384 .42134 L p
1 g
F P
s
P
p
.002 w
.47384 .42134 m .45258 .39436 L .42887 .4099 L p
1 g
F P
s
P
p
.002 w
.45258 .39436 m .47384 .42134 L .4937 .40075 L p
1 g
F P
s
P
p
.002 w
.4937 .40075 m .47732 .37977 L .45258 .39436 L p
1 g
F P
s
P
p
.002 w
.52877 .39173 m .51378 .3808 L .4937 .40075 L p
1 g
F P
s
P
p
.002 w
.47732 .37977 m .4937 .40075 L .51378 .3808 L p
1 g
F P
s
P
p
.002 w
.43624 .46297 m .47519 .49112 L .48858 .46683 L p
1 g
F P
s
P
p
.002 w
.48858 .46683 m .45457 .44221 L .43624 .46297 L p
1 g
F P
s
P
p
.002 w
.52769 .48153 m .48858 .46683 L .47519 .49112 L p
1 g
F P
s
P
p
.002 w
.48858 .46683 m .52769 .48153 L .53473 .45402 L p
1 g
F P
s
P
p
.002 w
.56707 .42782 m .5409 .42604 L .53473 .45402 L p
1 g
F P
s
P
p
.002 w
.5409 .42604 m .56707 .42782 L .56399 .39919 L p
1 g
F P
s
P
p
.002 w
.56399 .39919 m .5461 .39808 L .5409 .42604 L p
1 g
F P
s
P
p
.002 w
.56851 .45653 m .53473 .45402 L .52769 .48153 L p
1 g
F P
s
P
p
.002 w
.53473 .45402 m .56851 .45653 L .56707 .42782 L p
1 g
F P
s
P
p
.002 w
.40665 .42612 m .43624 .46297 L .45457 .44221 L p
1 g
F P
s
P
p
.002 w
.45457 .44221 m .42887 .4099 L .40665 .42612 L p
1 g
F P
s
P
p
.002 w
.51378 .3808 m .52877 .39173 L .54137 .36745 L p
1 g
F P
s
P
p
.002 w
.52877 .39173 m .5461 .39808 L .55022 .37067 L p
1 g
F P
s
P
p
.002 w
.55022 .37067 m .54137 .36745 L .52877 .39173 L p
1 g
F P
s
P
p
.002 w
.51378 .3808 m .50264 .3664 L .47732 .37977 L p
1 g
F P
s
P
p
.002 w
.54137 .36745 m .53373 .36186 L .51378 .3808 L p
1 g
F P
s
P
p
.002 w
.50264 .3664 m .51378 .3808 L .53373 .36186 L p
1 g
F P
s
P
p
.002 w
.44053 .36346 m .45258 .39436 L .47732 .37977 L p
1 g
F P
s
P
p
.002 w
.47732 .37977 m .46819 .35579 L .44053 .36346 L p
1 g
F P
s
P
p
.002 w
.46819 .35579 m .47732 .37977 L .50264 .3664 L p
1 g
F P
s
P
p
.002 w
.5461 .39808 m .56399 .39919 L .55933 .37118 L p
1 g
F P
s
P
p
.002 w
.55933 .37118 m .55022 .37067 L .5461 .39808 L p
1 g
F P
s
P
p
.002 w
.47519 .49112 m .51991 .50805 L .52769 .48153 L p
1 g
F P
s
P
p
.002 w
.56829 .48479 m .52769 .48153 L .51991 .50805 L p
1 g
F P
s
P
p
.002 w
.52769 .48153 m .56829 .48479 L .56851 .45653 L p
1 g
F P
s
P
p
.002 w
.41408 .37284 m .42887 .4099 L .45258 .39436 L p
1 g
F P
s
P
p
.002 w
.45258 .39436 m .44053 .36346 L .41408 .37284 L p
1 g
F P
s
P
p
.002 w
.50264 .3664 m .49654 .34998 L .46819 .35579 L p
1 g
F P
s
P
p
.002 w
.49654 .34998 m .50264 .3664 L .52808 .3545 L p
1 g
F P
s
P
p
.002 w
.53373 .36186 m .52808 .3545 L .50264 .3664 L p
1 g
F P
s
P
p
.002 w
.4192 .48325 m .46221 .51427 L .47519 .49112 L p
1 g
F P
s
P
p
.002 w
.47519 .49112 m .43624 .46297 L .4192 .48325 L p
1 g
F P
s
P
p
.002 w
.51991 .50805 m .47519 .49112 L .46221 .51427 L p
1 g
F P
s
P
p
.002 w
.5915 .42173 m .56707 .42782 L .56851 .45653 L p
1 g
F P
s
P
p
.002 w
.56707 .42782 m .5915 .42173 L .58062 .39488 L p
1 g
F P
s
P
p
.002 w
.58062 .39488 m .56399 .39919 L .56707 .42782 L p
1 g
F P
s
P
p
.002 w
.56399 .39919 m .58062 .39488 L .56776 .36891 L p
1 g
F P
s
P
p
.002 w
.56776 .36891 m .55933 .37118 L .56399 .39919 L p
1 g
F P
s
P
p
.002 w
.38637 .44271 m .4192 .48325 L .43624 .46297 L p
1 g
F P
s
P
p
.002 w
.43624 .46297 m .40665 .42612 L .38637 .44271 L p
1 g
F P
s
P
p
.002 w
.60019 .44895 m .56851 .45653 L .56829 .48479 L p
1 g
F P
s
P
p
.002 w
.56851 .45653 m .60019 .44895 L .5915 .42173 L p
1 g
F P
s
P
p
.002 w
.38939 .3838 m .40665 .42612 L .42887 .4099 L p
1 g
F P
s
P
p
.002 w
.42887 .4099 m .41408 .37284 L .38939 .3838 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .53373 .36186 L .54137 .36745 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .54137 .36745 L .55022 .37067 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .52808 .3545 L .53373 .36186 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .55022 .37067 L .55933 .37118 L closepath p
1 g
F P
s
P
p
.002 w
.46221 .51427 m .51152 .53308 L .51991 .50805 L p
1 g
F P
s
P
p
.002 w
.56638 .51206 m .51991 .50805 L .51152 .53308 L p
1 g
F P
s
P
p
.002 w
.51991 .50805 m .56638 .51206 L .56829 .48479 L p
1 g
F P
s
P
p
.002 w
.46739 .3312 m .46819 .35579 L .49654 .34998 L p
1 g
F P
s
P
p
.002 w
.49654 .34998 m .49618 .33321 L .46739 .3312 L p
1 g
F P
s
P
p
.002 w
.49618 .33321 m .49654 .34998 L .52504 .34612 L p
1 g
F P
s
P
p
.002 w
.52808 .3545 m .52504 .34612 L .49654 .34998 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .52504 .34612 L .52808 .3545 L closepath p
1 g
F P
s
P
p
.002 w
.43915 .33163 m .44053 .36346 L .46819 .35579 L p
1 g
F P
s
P
p
.002 w
.46819 .35579 m .46739 .3312 L .43915 .33163 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .55933 .37118 L .56776 .36891 L closepath p
1 g
F P
s
P
p
.002 w
.60649 .47602 m .56829 .48479 L .56638 .51206 L p
1 g
F P
s
P
p
.002 w
.56829 .48479 m .60649 .47602 L .60019 .44895 L p
1 g
F P
s
P
p
.002 w
.52504 .34612 m .52495 .33762 L .49618 .33321 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .52495 .33762 L .52504 .34612 L closepath p
1 g
F P
s
P
p
.002 w
.5942 .38552 m .58062 .39488 L .5915 .42173 L p
1 g
F P
s
P
p
.002 w
.58062 .39488 m .5942 .38552 L .57459 .36408 L p
1 g
F P
s
P
p
.002 w
.57459 .36408 m .56776 .36891 L .58062 .39488 L p
1 g
F P
s
P
p
.002 w
.41203 .33453 m .41408 .37284 L .44053 .36346 L p
1 g
F P
s
P
p
.002 w
.44053 .36346 m .43915 .33163 L .41203 .33453 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .56776 .36891 L .57459 .36408 L closepath p
1 g
F P
s
P
p
.002 w
.40381 .50264 m .4499 .53582 L .46221 .51427 L p
1 g
F P
s
P
p
.002 w
.46221 .51427 m .4192 .48325 L .40381 .50264 L p
1 g
F P
s
P
p
.002 w
.51152 .53308 m .46221 .51427 L .4499 .53582 L p
1 g
F P
s
P
p
.002 w
.61162 .40821 m .5915 .42173 L .60019 .44895 L p
1 g
F P
s
P
p
.002 w
.5915 .42173 m .61162 .40821 L .5942 .38552 L p
1 g
F P
s
P
p
.002 w
.36699 .39614 m .38637 .44271 L .40665 .42612 L p
1 g
F P
s
P
p
.002 w
.40665 .42612 m .38939 .3838 L .36699 .39614 L p
1 g
F P
s
P
p
.002 w
.50171 .31789 m .49618 .33321 L .52495 .33762 L p
1 g
F P
s
P
p
.002 w
.52495 .33762 m .52785 .32989 L .50171 .31789 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .52785 .32989 L .52495 .33762 L closepath p
1 g
F P
s
P
p
.002 w
.36849 .45937 m .40381 .50264 L .4192 .48325 L p
1 g
F P
s
P
p
.002 w
.4192 .48325 m .38637 .44271 L .36849 .45937 L p
1 g
F P
s
P
p
.002 w
.47524 .30856 m .46739 .3312 L .49618 .33321 L p
1 g
F P
s
P
p
.002 w
.49618 .33321 m .50171 .31789 L .47524 .30856 L p
1 g
F P
s
P
p
.002 w
.57907 .35719 m .57459 .36408 L .5942 .38552 L p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .57459 .36408 L .57907 .35719 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .57907 .35719 L .58069 .34896 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .58069 .34896 L .57924 .34028 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .57924 .34028 L .57486 .33212 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .57486 .33212 L .56801 .32539 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .56801 .32539 L .55946 .32084 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .55946 .32084 L .55017 .31898 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .55017 .31898 L .54116 .32001 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .54116 .32001 L .53345 .3238 L closepath p
1 g
F P
s
P
p
.002 w
.55316 .34431 m .53345 .3238 L .52785 .32989 L closepath p
1 g
F P
s
P
p
.002 w
.62646 .43174 m .60019 .44895 L .60649 .47602 L p
1 g
F P
s
P
p
.002 w
.60019 .44895 m .62646 .43174 L .61162 .40821 L p
1 g
F P
s
P
p
.002 w
.4499 .53582 m .50266 .55608 L .51152 .53308 L p
1 g
F P
s
P
p
.002 w
.56278 .53779 m .51152 .53308 L .50266 .55608 L p
1 g
F P
s
P
p
.002 w
.51152 .53308 m .56278 .53779 L .56638 .51206 L p
1 g
F P
s
P
p
.002 w
.38661 .33992 m .38939 .3838 L .41408 .37284 L p
1 g
F P
s
P
p
.002 w
.41408 .37284 m .41203 .33453 L .38661 .33992 L p
1 g
F P
s
P
p
.002 w
.60324 .372 m .5942 .38552 L .61162 .40821 L p
1 g
F P
s
P
p
.002 w
.5942 .38552 m .60324 .372 L .57907 .35719 L p
1 g
F P
s
P
p
.002 w
.51265 .30568 m .50171 .31789 L .52785 .32989 L p
1 g
F P
s
P
p
.002 w
.52785 .32989 m .53345 .3238 L .51265 .30568 L p
1 g
F P
s
P
p
.002 w
.44898 .30215 m .43915 .33163 L .46739 .3312 L p
1 g
F P
s
P
p
.002 w
.46739 .3312 m .47524 .30856 L .44898 .30215 L p
1 g
F P
s
P
p
.002 w
.61023 .50239 m .56638 .51206 L .56278 .53779 L p
1 g
F P
s
P
p
.002 w
.56638 .51206 m .61023 .50239 L .60649 .47602 L p
1 g
F P
s
P
p
.002 w
.58069 .34896 m .57907 .35719 L .60324 .372 L p
1 g
F P
s
P
p
.002 w
.5279 .29802 m .51265 .30568 L .53345 .3238 L p
1 g
F P
s
P
p
.002 w
.53345 .3238 m .54116 .32001 L .5279 .29802 L p
1 g
F P
s
P
p
.002 w
.49116 .29039 m .47524 .30856 L .50171 .31789 L p
1 g
F P
s
P
p
.002 w
.50171 .31789 m .51265 .30568 L .49116 .29039 L p
1 g
F P
s
P
p
.002 w
.62516 .38848 m .61162 .40821 L .62646 .43174 L p
1 g
F P
s
P
p
.002 w
.61162 .40821 m .62516 .38848 L .60324 .372 L p
1 g
F P
s
P
p
.002 w
.34743 .40967 m .36849 .45937 L .38637 .44271 L p
1 g
F P
s
P
p
.002 w
.38637 .44271 m .36699 .39614 L .34743 .40967 L p
1 g
F P
s
P
p
.002 w
.60324 .372 m .60663 .35572 L .58069 .34896 L p
1 g
F P
s
P
p
.002 w
.57924 .34028 m .58069 .34896 L .60663 .35572 L p
1 g
F P
s
P
p
.002 w
.63836 .45563 m .60649 .47602 L .61023 .50239 L p
1 g
F P
s
P
p
.002 w
.60649 .47602 m .63836 .45563 L .62646 .43174 L p
1 g
F P
s
P
p
.002 w
.42348 .29887 m .41203 .33453 L .43915 .33163 L p
1 g
F P
s
P
p
.002 w
.43915 .33163 m .44898 .30215 L .42348 .29887 L p
1 g
F P
s
P
p
.002 w
.39045 .52072 m .43854 .55528 L .4499 .53582 L p
1 g
F P
s
P
p
.002 w
.4499 .53582 m .40381 .50264 L .39045 .52072 L p
1 g
F P
s
P
p
.002 w
.50266 .55608 m .4499 .53582 L .43854 .55528 L p
1 g
F P
s
P
p
.002 w
.54583 .29585 m .5279 .29802 L .54116 .32001 L p
1 g
F P
s
P
p
.002 w
.54116 .32001 m .55017 .31898 L .54583 .29585 L p
1 g
F P
s
P
p
.002 w
.60663 .35572 m .60324 .372 L .62516 .38848 L p
1 g
F P
s
P
p
.002 w
.36349 .34776 m .36699 .39614 L .38939 .3838 L p
1 g
F P
s
P
p
.002 w
.38939 .3838 m .38661 .33992 L .36349 .34776 L p
1 g
F P
s
P
p
.002 w
.60663 .35572 m .60389 .33844 L .57924 .34028 L p
1 g
F P
s
P
p
.002 w
.57486 .33212 m .57924 .34028 L .60389 .33844 L p
1 g
F P
s
P
p
.002 w
.35347 .47575 m .39045 .52072 L .40381 .50264 L p
1 g
F P
s
P
p
.002 w
.40381 .50264 m .36849 .45937 L .35347 .47575 L p
1 g
F P
s
P
p
.002 w
.56443 .2995 m .54583 .29585 L .55017 .31898 L p
1 g
F P
s
P
p
.002 w
.55017 .31898 m .55946 .32084 L .56443 .2995 L p
1 g
F P
s
P
p
.002 w
.60389 .33844 m .59522 .3221 L .57486 .33212 L p
1 g
F P
s
P
p
.002 w
.56801 .32539 m .57486 .33212 L .59522 .3221 L p
1 g
F P
s
P
p
.002 w
.50266 .55608 m .55751 .56141 L .56278 .53779 L p
1 g
F P
s
P
p
.002 w
.61126 .52751 m .56278 .53779 L .55751 .56141 L p
1 g
F P
s
P
p
.002 w
.56278 .53779 m .61126 .52751 L .61023 .50239 L p
1 g
F P
s
P
p
.002 w
.4694 .27832 m .44898 .30215 L .47524 .30856 L p
1 g
F P
s
P
p
.002 w
.47524 .30856 m .49116 .29039 L .4694 .27832 L p
1 g
F P
s
P
p
.002 w
.58155 .30859 m .56443 .2995 L .55946 .32084 L p
1 g
F P
s
P
p
.002 w
.55946 .32084 m .56801 .32539 L .58155 .30859 L p
1 g
F P
s
P
p
.002 w
.59522 .3221 m .58155 .30859 L .56801 .32539 L p
1 g
F P
s
P
p
.002 w
.51361 .27886 m .49116 .29039 L .51265 .30568 L p
1 g
F P
s
P
p
.002 w
.51265 .30568 m .5279 .29802 L .51361 .27886 L p
1 g
F P
s
P
p
.002 w
.43854 .55528 m .4935 .57652 L .50266 .55608 L p
1 g
F P
s
P
p
.002 w
.55751 .56141 m .50266 .55608 L .4935 .57652 L p
1 g
F P
s
P
p
.002 w
.64432 .40634 m .62646 .43174 L .63836 .45563 L p
1 g
F P
s
P
p
.002 w
.62646 .43174 m .64432 .40634 L .62516 .38848 L p
1 g
F P
s
P
p
.002 w
.39932 .29891 m .38661 .33992 L .41203 .33453 L p
1 g
F P
s
P
p
.002 w
.41203 .33453 m .42348 .29887 L .39932 .29891 L p
1 g
F P
s
P
p
.002 w
.62516 .38848 m .63042 .36451 L .60663 .35572 L p
1 g
F P
s
P
p
.002 w
.60389 .33844 m .60663 .35572 L .63042 .36451 L p
1 g
F P
s
P
p
.002 w
.64699 .4794 m .61023 .50239 L .61126 .52751 L p
1 g
F P
s
P
p
.002 w
.61023 .50239 m .64699 .4794 L .63836 .45563 L p
1 g
F P
s
P
p
.002 w
.63042 .36451 m .62516 .38848 L .64432 .40634 L p
1 g
F P
s
P
p
.002 w
.33124 .42413 m .35347 .47575 L .36849 .45937 L p
1 g
F P
s
P
p
.002 w
.36849 .45937 m .34743 .40967 L .33124 .42413 L p
1 g
F P
s
P
p
.002 w
.5402 .27548 m .51361 .27886 L .5279 .29802 L p
1 g
F P
s
P
p
.002 w
.5279 .29802 m .54583 .29585 L .5402 .27548 L p
1 g
F P
s
P
p
.002 w
.34327 .35797 m .34743 .40967 L .36699 .39614 L p
1 g
F P
s
P
p
.002 w
.36699 .39614 m .36349 .34776 L .34327 .35797 L p
1 g
F P
s
P
p
.002 w
.44786 .26986 m .42348 .29887 L .44898 .30215 L p
1 g
F P
s
P
p
.002 w
.44898 .30215 m .4694 .27832 L .44786 .26986 L p
1 g
F P
s
P
p
.002 w
.63042 .36451 m .62655 .33889 L .60389 .33844 L p
1 g
F P
s
P
p
.002 w
.59522 .3221 m .60389 .33844 L .62655 .33889 L p
1 g
F P
s
P
p
.002 w
.37947 .53705 m .42839 .57216 L .43854 .55528 L p
1 g
F P
s
P
p
.002 w
.43854 .55528 m .39045 .52072 L .37947 .53705 L p
1 g
F P
s
P
p
.002 w
.4935 .57652 m .43854 .55528 L .42839 .57216 L p
1 g
F P
s
P
p
.002 w
.49855 .26306 m .4694 .27832 L .49116 .29039 L p
1 g
F P
s
P
p
.002 w
.49116 .29039 m .51361 .27886 L .49855 .26306 L p
1 g
F P
s
P
p
.002 w
.66024 .42523 m .63836 .45563 L .64699 .4794 L p
1 g
F P
s
P
p
.002 w
.63836 .45563 m .66024 .42523 L .64432 .40634 L p
1 g
F P
s
P
p
.002 w
.34177 .49148 m .37947 .53705 L .39045 .52072 L p
1 g
F P
s
P
p
.002 w
.39045 .52072 m .35347 .47575 L .34177 .49148 L p
1 g
F P
s
P
p
.002 w
.5679 .28084 m .5402 .27548 L .54583 .29585 L p
1 g
F P
s
P
p
.002 w
.54583 .29585 m .56443 .2995 L .5679 .28084 L p
1 g
F P
s
P
p
.002 w
.4935 .57652 m .55063 .58233 L .55751 .56141 L p
1 g
F P
s
P
p
.002 w
.60946 .5508 m .55751 .56141 L .55063 .58233 L p
1 g
F P
s
P
p
.002 w
.55751 .56141 m .60946 .5508 L .61126 .52751 L p
1 g
F P
s
P
p
.002 w
.62655 .33889 m .61378 .31455 L .59522 .3221 L p
1 g
F P
s
P
p
.002 w
.58155 .30859 m .59522 .3221 L .61378 .31455 L p
1 g
F P
s
P
p
.002 w
.3771 .30239 m .36349 .34776 L .38661 .33992 L p
1 g
F P
s
P
p
.002 w
.38661 .33992 m .39932 .29891 L .3771 .30239 L p
1 g
F P
s
P
p
.002 w
.59344 .29439 m .5679 .28084 L .56443 .2995 L p
1 g
F P
s
P
p
.002 w
.56443 .2995 m .58155 .30859 L .59344 .29439 L p
1 g
F P
s
P
p
.002 w
.42839 .57216 m .48422 .59384 L .4935 .57652 L p
1 g
F P
s
P
p
.002 w
.55063 .58233 m .4935 .57652 L .48422 .59384 L p
1 g
F P
s
P
p
.002 w
.64432 .40634 m .65147 .37522 L .63042 .36451 L p
1 g
F P
s
P
p
.002 w
.62655 .33889 m .63042 .36451 L .65147 .37522 L p
1 g
F P
s
P
p
.002 w
.65147 .37522 m .64432 .40634 L .66024 .42523 L p
1 g
F P
s
P
p
.002 w
.61378 .31455 m .59344 .29439 L .58155 .30859 L p
1 g
F P
s
P
p
.002 w
.65205 .50252 m .61126 .52751 L .60946 .5508 L p
1 g
F P
s
P
p
.002 w
.61126 .52751 m .65205 .50252 L .64699 .4794 L p
1 g
F P
s
P
p
.002 w
.42703 .26537 m .39932 .29891 L .42348 .29887 L p
1 g
F P
s
P
p
.002 w
.42348 .29887 m .44786 .26986 L .42703 .26537 L p
1 g
F P
s
P
p
.002 w
.53333 .25847 m .49855 .26306 L .51361 .27886 L p
1 g
F P
s
P
p
.002 w
.51361 .27886 m .5402 .27548 L .53333 .25847 L p
1 g
F P
s
P
p
.002 w
.31896 .43923 m .34177 .49148 L .35347 .47575 L p
1 g
F P
s
P
p
.002 w
.35347 .47575 m .33124 .42413 L .31896 .43923 L p
1 g
F P
s
P
p
.002 w
.32655 .37041 m .33124 .42413 L .34743 .40967 L p
1 g
F P
s
P
p
.002 w
.34743 .40967 m .34327 .35797 L .32655 .37041 L p
1 g
F P
s
P
p
.002 w
.67242 .44478 m .64699 .4794 L .65205 .50252 L p
1 g
F P
s
P
p
.002 w
.64699 .4794 m .67242 .44478 L .66024 .42523 L p
1 g
F P
s
P
p
.002 w
.48303 .25115 m .44786 .26986 L .4694 .27832 L p
1 g
F P
s
P
p
.002 w
.4694 .27832 m .49855 .26306 L .48303 .25115 L p
1 g
F P
s
P
p
.002 w
.65147 .37522 m .64664 .34174 L .62655 .33889 L p
1 g
F P
s
P
p
.002 w
.61378 .31455 m .62655 .33889 L .64664 .34174 L p
1 g
F P
s
P
p
.002 w
.37125 .55119 m .41974 .58595 L .42839 .57216 L p
1 g
F P
s
P
p
.002 w
.42839 .57216 m .37947 .53705 L .37125 .55119 L p
1 g
F P
s
P
p
.002 w
.48422 .59384 m .42839 .57216 L .41974 .58595 L p
1 g
F P
s
P
p
.002 w
.35745 .30939 m .34327 .35797 L .36349 .34776 L p
1 g
F P
s
P
p
.002 w
.36349 .34776 m .3771 .30239 L .35745 .30939 L p
1 g
F P
s
P
p
.002 w
.48422 .59384 m .5422 .59998 L .55063 .58233 L p
1 g
F P
s
P
p
.002 w
.60474 .57164 m .55063 .58233 L .5422 .59998 L p
1 g
F P
s
P
p
.002 w
.55063 .58233 m .60474 .57164 L .60946 .5508 L p
1 g
F P
s
P
p
.002 w
.56972 .26542 m .53333 .25847 L .5402 .27548 L p
1 g
F P
s
P
p
.002 w
.5402 .27548 m .5679 .28084 L .56972 .26542 L p
1 g
F P
s
P
p
.002 w
.66919 .38769 m .66024 .42523 L .67242 .44478 L p
1 g
F P
s
P
p
.002 w
.66024 .42523 m .66919 .38769 L .65147 .37522 L p
1 g
F P
s
P
p
.002 w
.33382 .50617 m .37125 .55119 L .37947 .53705 L p
1 g
F P
s
P
p
.002 w
.37947 .53705 m .34177 .49148 L .33382 .50617 L p
1 g
F P
s
P
p
.002 w
.64664 .34174 m .65147 .37522 L .66919 .38769 L p
1 g
F P
s
P
p
.002 w
.64664 .34174 m .63001 .30977 L .61378 .31455 L p
1 g
F P
s
P
p
.002 w
.59344 .29439 m .61378 .31455 L .63001 .30977 L p
1 g
F P
s
P
p
.002 w
.65327 .52444 m .60946 .5508 L .60474 .57164 L p
1 g
F P
s
P
p
.002 w
.60946 .5508 m .65327 .52444 L .65205 .50252 L p
1 g
F P
s
P
p
.002 w
.41974 .58595 m .47502 .60751 L .48422 .59384 L p
1 g
F P
s
P
p
.002 w
.5422 .59998 m .48422 .59384 L .47502 .60751 L p
1 g
F P
s
P
p
.002 w
.60332 .28323 m .56972 .26542 L .5679 .28084 L p
1 g
F P
s
P
p
.002 w
.5679 .28084 m .59344 .29439 L .60332 .28323 L p
1 g
F P
s
P
p
.002 w
.63001 .30977 m .60332 .28323 L .59344 .29439 L p
1 g
F P
s
P
p
.002 w
.40745 .26515 m .3771 .30239 L .39932 .29891 L p
1 g
F P
s
P
p
.002 w
.39932 .29891 m .42703 .26537 L .40745 .26515 L p
1 g
F P
s
P
p
.002 w
.52531 .2454 m .48303 .25115 L .49855 .26306 L p
1 g
F P
s
P
p
.002 w
.49855 .26306 m .53333 .25847 L .52531 .2454 L p
1 g
F P
s
P
p
.002 w
.68042 .46455 m .65205 .50252 L .65327 .52444 L p
1 g
F P
s
P
p
.002 w
.65205 .50252 m .68042 .46455 L .67242 .44478 L p
1 g
F P
s
P
p
.002 w
.31393 .3849 m .31896 .43923 L .33124 .42413 L p
1 g
F P
s
P
p
.002 w
.33124 .42413 m .32655 .37041 L .31393 .3849 L p
1 g
F P
s
P
p
.002 w
.46742 .2436 m .42703 .26537 L .44786 .26986 L p
1 g
F P
s
P
p
.002 w
.44786 .26986 m .48303 .25115 L .46742 .2436 L p
1 g
F P
s
P
p
.002 w
.31109 .45464 m .33382 .50617 L .34177 .49148 L p
1 g
F P
s
P
p
.002 w
.34177 .49148 m .31896 .43923 L .31109 .45464 L p
1 g
F P
s
P
p
.002 w
.66919 .38769 m .66355 .34703 L .64664 .34174 L p
1 g
F P
s
P
p
.002 w
.63001 .30977 m .64664 .34174 L .66355 .34703 L p
1 g
F P
s
P
p
.002 w
.34098 .3199 m .32655 .37041 L .34327 .35797 L p
1 g
F P
s
P
p
.002 w
.34327 .35797 m .35745 .30939 L .34098 .3199 L p
1 g
F P
s
P
p
.002 w
.68302 .40171 m .67242 .44478 L .68042 .46455 L p
1 g
F P
s
P
p
.002 w
.67242 .44478 m .68302 .40171 L .66919 .38769 L p
1 g
F P
s
P
p
.002 w
.66355 .34703 m .66919 .38769 L .68302 .40171 L p
1 g
F P
s
P
p
.002 w
.47502 .60751 m .53234 .61376 L .5422 .59998 L p
1 g
F P
s
P
p
.002 w
.59709 .58943 m .5422 .59998 L .53234 .61376 L p
1 g
F P
s
P
p
.002 w
.5422 .59998 m .59709 .58943 L .60474 .57164 L p
1 g
F P
s
P
p
.002 w
.36614 .56267 m .41289 .59615 L .41974 .58595 L p
1 g
F P
s
P
p
.002 w
.41974 .58595 m .37125 .55119 L .36614 .56267 L p
1 g
F P
s
P
p
.002 w
.47502 .60751 m .41974 .58595 L .41289 .59615 L p
1 g
F P
s
P
p
.002 w
.56975 .2538 m .52531 .2454 L .53333 .25847 L p
1 g
F P
s
P
p
.002 w
.53333 .25847 m .56972 .26542 L .56975 .2538 L p
1 g
F P
s
P
p
.002 w
.65043 .54456 m .60474 .57164 L .59709 .58943 L p
1 g
F P
s
P
p
.002 w
.60474 .57164 m .65043 .54456 L .65327 .52444 L p
1 g
F P
s
P
p
.002 w
.33002 .5194 m .36614 .56267 L .37125 .55119 L p
1 g
F P
s
P
p
.002 w
.37125 .55119 m .33382 .50617 L .33002 .5194 L p
1 g
F P
s
P
p
.002 w
.66355 .34703 m .64341 .30803 L .63001 .30977 L p
1 g
F P
s
P
p
.002 w
.60332 .28323 m .63001 .30977 L .64341 .30803 L p
1 g
F P
s
P
p
.002 w
.38969 .26942 m .35745 .30939 L .3771 .30239 L p
1 g
F P
s
P
p
.002 w
.3771 .30239 m .40745 .26515 L .38969 .26942 L p
1 g
F P
s
P
p
.002 w
.41289 .59615 m .46612 .61698 L .47502 .60751 L p
1 g
F P
s
P
p
.002 w
.53234 .61376 m .47502 .60751 L .46612 .61698 L p
1 g
F P
s
P
p
.002 w
.61083 .27556 m .56975 .2538 L .56972 .26542 L p
1 g
F P
s
P
p
.002 w
.56972 .26542 m .60332 .28323 L .61083 .27556 L p
1 g
F P
s
P
p
.002 w
.68385 .48407 m .65327 .52444 L .65043 .54456 L p
1 g
F P
s
P
p
.002 w
.65327 .52444 m .68385 .48407 L .68042 .46455 L p
1 g
F P
s
P
p
.002 w
.64341 .30803 m .61083 .27556 L .60332 .28323 L p
1 g
F P
s
P
p
.002 w
.51629 .23683 m .46742 .2436 L .48303 .25115 L p
1 g
F P
s
P
p
.002 w
.48303 .25115 m .52531 .2454 L .51629 .23683 L p
1 g
F P
s
P
p
.002 w
.4521 .24087 m .40745 .26515 L .42703 .26537 L p
1 g
F P
s
P
p
.002 w
.42703 .26537 m .46742 .2436 L .4521 .24087 L p
1 g
F P
s
P
p
.002 w
.30594 .40116 m .31109 .45464 L .31896 .43923 L p
1 g
F P
s
P
p
.002 w
.31896 .43923 m .31393 .3849 L .30594 .40116 L p
1 g
F P
s
P
p
.002 w
.30808 .46999 m .33002 .5194 L .33382 .50617 L p
1 g
F P
s
P
p
.002 w
.33382 .50617 m .31109 .45464 L .30808 .46999 L p
1 g
F P
s
P
p
.002 w
.3283 .33384 m .31393 .3849 L .32655 .37041 L p
1 g
F P
s
P
p
.002 w
.32655 .37041 m .34098 .3199 L .3283 .33384 L p
1 g
F P
s
P
p
.002 w
.6924 .417 m .68042 .46455 L .68385 .48407 L p
1 g
F P
s
P
p
.002 w
.68042 .46455 m .6924 .417 L .68302 .40171 L p
1 g
F P
s
P
p
.002 w
.68302 .40171 m .6767 .35477 L .66355 .34703 L p
1 g
F P
s
P
p
.002 w
.64341 .30803 m .66355 .34703 L .6767 .35477 L p
1 g
F P
s
P
p
.002 w
.6767 .35477 m .68302 .40171 L .6924 .417 L p
1 g
F P
s
P
p
.002 w
.46612 .61698 m .52123 .62312 L .53234 .61376 L p
1 g
F P
s
P
p
.002 w
.58654 .60357 m .53234 .61376 L .52123 .62312 L p
1 g
F P
s
P
p
.002 w
.53234 .61376 m .58654 .60357 L .59709 .58943 L p
1 g
F P
s
P
p
.002 w
.64341 .56229 m .59709 .58943 L .58654 .60357 L p
1 g
F P
s
P
p
.002 w
.59709 .58943 m .64341 .56229 L .65043 .54456 L p
1 g
F P
s
P
p
.002 w
.56786 .24652 m .51629 .23683 L .52531 .2454 L p
1 g
F P
s
P
p
.002 w
.52531 .2454 m .56975 .2538 L .56786 .24652 L p
1 g
F P
s
P
p
.002 w
.37433 .27831 m .34098 .3199 L .35745 .30939 L p
1 g
F P
s
P
p
.002 w
.35745 .30939 m .38969 .26942 L .37433 .27831 L p
1 g
F P
s
P
p
.002 w
.36446 .57103 m .40811 .60228 L .41289 .59615 L p
1 g
F P
s
P
p
.002 w
.41289 .59615 m .36614 .56267 L .36446 .57103 L p
1 g
F P
s
P
p
.002 w
.46612 .61698 m .41289 .59615 L .40811 .60228 L p
1 g
F P
s
P
p
.002 w
.33074 .53072 m .36446 .57103 L .36614 .56267 L p
1 g
F P
s
P
p
.002 w
.36614 .56267 m .33002 .5194 L .33074 .53072 L p
1 g
F P
s
P
p
.002 w
.6767 .35477 m .65345 .30954 L .64341 .30803 L p
1 g
F P
s
P
p
.002 w
.61083 .27556 m .64341 .30803 L .65345 .30954 L p
1 g
F P
s
P
p
.002 w
.68236 .50282 m .65043 .54456 L .64341 .56229 L p
1 g
F P
s
P
p
.002 w
.65043 .54456 m .68236 .50282 L .68385 .48407 L p
1 g
F P
s
P
p
.002 w
.4375 .2433 m .38969 .26942 L .40745 .26515 L p
1 g
F P
s
P
p
.002 w
.40745 .26515 m .4521 .24087 L .4375 .2433 L p
1 g
F P
s
P
p
.002 w
.40811 .60228 m .45778 .62175 L .46612 .61698 L p
1 g
F P
s
P
p
.002 w
.52123 .62312 m .46612 .61698 L .45778 .62175 L p
1 g
F P
s
P
p
.002 w
.50644 .23326 m .4521 .24087 L .46742 .2436 L p
1 g
F P
s
P
p
.002 w
.46742 .2436 m .51629 .23683 L .50644 .23326 L p
1 g
F P
s
P
p
.002 w
.61563 .27181 m .56786 .24652 L .56975 .2538 L p
1 g
F P
s
P
p
.002 w
.56975 .2538 m .61083 .27556 L .61563 .27181 L p
1 g
F P
s
P
p
.002 w
.30306 .41884 m .30808 .46999 L .31109 .45464 L p
1 g
F P
s
P
p
.002 w
.31109 .45464 m .30594 .40116 L .30306 .41884 L p
1 g
F P
s
P
p
.002 w
.65345 .30954 m .61563 .27181 L .61083 .27556 L p
1 g
F P
s
P
p
.002 w
.69684 .43323 m .68385 .48407 L .68236 .50282 L p
1 g
F P
s
P
p
.002 w
.68385 .48407 m .69684 .43323 L .6924 .417 L p
1 g
F P
s
P
p
.002 w
.31998 .35099 m .30594 .40116 L .31393 .3849 L p
1 g
F P
s
P
p
.002 w
.31393 .3849 m .3283 .33384 L .31998 .35099 L p
1 g
F P
s
P
p
.002 w
.3103 .48483 m .33074 .53072 L .33002 .5194 L p
1 g
F P
s
P
p
.002 w
.33002 .5194 m .30808 .46999 L .3103 .48483 L p
1 g
F P
s
P
p
.002 w
.6924 .417 m .68552 .3649 L .6767 .35477 L p
1 g
F P
s
P
p
.002 w
.65345 .30954 m .6767 .35477 L .68552 .3649 L p
1 g
F P
s
P
p
.002 w
.68552 .3649 m .6924 .417 L .69684 .43323 L p
1 g
F P
s
P
p
.002 w
.52123 .62312 m .57321 .61347 L .58654 .60357 L p
1 g
F P
s
P
p
.002 w
.63217 .57701 m .58654 .60357 L .57321 .61347 L p
1 g
F P
s
P
p
.002 w
.58654 .60357 m .63217 .57701 L .64341 .56229 L p
1 g
F P
s
P
p
.002 w
.36195 .29183 m .3283 .33384 L .34098 .3199 L p
1 g
F P
s
P
p
.002 w
.34098 .3199 m .37433 .27831 L .36195 .29183 L p
1 g
F P
s
P
p
.002 w
.45778 .62175 m .50909 .62753 L .52123 .62312 L p
1 g
F P
s
P
p
.002 w
.57321 .61347 m .52123 .62312 L .50909 .62753 L p
1 g
F P
s
P
p
.002 w
.564 .24406 m .50644 .23326 L .51629 .23683 L p
1 g
F P
s
P
p
.002 w
.51629 .23683 m .56786 .24652 L .564 .24406 L p
1 g
F P
s
P
p
.002 w
.67575 .52023 m .64341 .56229 L .63217 .57701 L p
1 g
F P
s
P
p
.002 w
.64341 .56229 m .67575 .52023 L .68236 .50282 L p
1 g
F P
s
P
p
.002 w
.36647 .57584 m .40568 .6039 L .40811 .60228 L p
1 g
F P
s
P
p
.002 w
.40811 .60228 m .36446 .57103 L .36647 .57584 L p
1 g
F P
s
P
p
.002 w
.45778 .62175 m .40811 .60228 L .40568 .6039 L p
1 g
F P
s
P
p
.002 w
.33623 .53972 m .36647 .57584 L .36446 .57103 L p
1 g
F P
s
P
p
.002 w
.36446 .57103 m .33074 .53072 L .33623 .53972 L p
1 g
F P
s
P
p
.002 w
.4241 .25113 m .37433 .27831 L .38969 .26942 L p
1 g
F P
s
P
p
.002 w
.38969 .26942 m .4375 .2433 L .4241 .25113 L p
1 g
F P
s
P
p
.002 w
.68552 .3649 m .65965 .3145 L .65345 .30954 L p
1 g
F P
s
P
p
.002 w
.61563 .27181 m .65345 .30954 L .65965 .3145 L p
1 g
F P
s
P
p
.002 w
.49599 .23512 m .4375 .2433 L .4521 .24087 L p
1 g
F P
s
P
p
.002 w
.4521 .24087 m .50644 .23326 L .49599 .23512 L p
1 g
F P
s
P
p
.004 w
.23243 .56317 m
.29171 .53378 L
s
P
p
.002 w
.40568 .6039 m .45026 .6214 L .45778 .62175 L p
1 g
F P
s
P
p
.002 w
.50909 .62753 m .45778 .62175 L .45026 .6214 L p
1 g
F P
s
P
p
.002 w
.30567 .43751 m .3103 .48483 L .30808 .46999 L p
1 g
F P
s
P
p
.002 w
.30808 .46999 m .30306 .41884 L .30567 .43751 L p
1 g
F P
s
P
p
.002 w
.6174 .27233 m .564 .24406 L .56786 .24652 L p
1 g
F P
s
P
p
.002 w
.56786 .24652 m .61563 .27181 L .6174 .27233 L p
1 g
F P
s
P
p
.002 w
.68236 .50282 m .69594 .45001 L .69684 .43323 L p
1 g
F P
s
P
p
.002 w
.69594 .45001 m .68236 .50282 L .67575 .52023 L p
1 g
F P
s
P
p
.002 w
.31649 .37103 m .30306 .41884 L .30594 .40116 L p
1 g
F P
s
P
p
.002 w
.30594 .40116 m .31998 .35099 L .31649 .37103 L p
1 g
F P
s
P
p
.002 w
.65965 .3145 m .6174 .27233 L .61563 .27181 L p
1 g
F P
s
P
p
.002 w
.31799 .49872 m .33623 .53972 L .33074 .53072 L p
1 g
F P
s
P
p
.002 w
.33074 .53072 m .3103 .48483 L .31799 .49872 L p
1 g
F P
s
P
p
.004 w
.32602 .51677 m
.5 .43051 L
s
P
p
.004 w
.32382 .51786 m
.32512 .51722 L
s
P
p
.004 w
.31866 .52042 m
.32382 .51786 L
s
P
p
.004 w
.31741 .52104 m
.31866 .52042 L
s
P
p
.004 w
.29171 .53378 m
.31741 .52104 L
s
P
p
.002 w
.69684 .43323 m .6895 .37728 L .68552 .3649 L p
1 g
F P
s
P
p
.002 w
.65965 .3145 m .68552 .3649 L .6895 .37728 L p
1 g
F P
s
P
p
.002 w
.6895 .37728 m .69684 .43323 L .69594 .45001 L p
1 g
F P
s
P
p
.002 w
.35308 .30983 m .31998 .35099 L .3283 .33384 L p
1 g
F P
s
P
p
.002 w
.3283 .33384 m .36195 .29183 L .35308 .30983 L p
1 g
F P
s
P
p
.002 w
.50909 .62753 m .5573 .61862 L .57321 .61347 L p
1 g
F P
s
P
p
.002 w
.57321 .61347 m .6168 .58815 L .63217 .57701 L p
1 g
F P
s
P
p
.002 w
.6168 .58815 m .57321 .61347 L .5573 .61862 L p
1 g
F P
s
P
p
.002 w
.45026 .6214 m .49619 .62658 L .50909 .62753 L p
1 g
F P
s
P
p
.002 w
.5573 .61862 m .50909 .62753 L .49619 .62658 L p
1 g
F P
s
P
p
.002 w
.63217 .57701 m .66391 .53574 L .67575 .52023 L p
1 g
F P
s
P
p
.002 w
.66391 .53574 m .63217 .57701 L .6168 .58815 L p
1 g
F P
s
P
p
.002 w
.55815 .24681 m .49599 .23512 L .50644 .23326 L p
1 g
F P
s
P
p
.002 w
.50644 .23326 m .564 .24406 L .55815 .24681 L p
1 g
F P
s
P
p
.002 w
.41237 .26445 m .36195 .29183 L .37433 .27831 L p
1 g
F P
s
P
p
.002 w
.37433 .27831 m .4241 .25113 L .41237 .26445 L p
1 g
F P
s
P
p
.002 w
.37237 .57674 m .40581 .60069 L .40568 .6039 L p
1 g
F P
s
P
p
.002 w
.40568 .6039 m .36647 .57584 L .37237 .57674 L p
1 g
F P
s
P
p
.002 w
.45026 .6214 m .40568 .6039 L .40581 .60069 L p
1 g
F P
s
P
p
.002 w
.48522 .24269 m .4241 .25113 L .4375 .2433 L p
1 g
F P
s
P
p
.002 w
.4375 .2433 m .49599 .23512 L .48522 .24269 L p
1 g
F P
s
P
p
.002 w
.34664 .54597 m .37237 .57674 L .36647 .57584 L p
1 g
F P
s
P
p
.002 w
.36647 .57584 m .33623 .53972 L .34664 .54597 L p
1 g
F P
s
P
p
.002 w
.6895 .37728 m .66159 .32296 L .65965 .3145 L p
1 g
F P
s
P
p
.002 w
.6174 .27233 m .65965 .3145 L .66159 .32296 L p
1 g
F P
s
P
p
.002 w
.68941 .46687 m .67575 .52023 L .66391 .53574 L p
1 g
F P
s
P
p
.002 w
.67575 .52023 m .68941 .46687 L .69594 .45001 L p
1 g
F P
s
P
p
.002 w
.31398 .45664 m .31799 .49872 L .3103 .48483 L p
1 g
F P
s
P
p
.002 w
.3103 .48483 m .30567 .43751 L .31398 .45664 L p
1 g
F P
s
P
p
.002 w
.3182 .39348 m .30567 .43751 L .30306 .41884 L p
1 g
F P
s
P
p
.002 w
.30306 .41884 m .31649 .37103 L .3182 .39348 L p
1 g
F P
s
P
p
.002 w
.40581 .60069 m .44383 .61559 L .45026 .6214 L p
1 g
F P
s
P
p
.002 w
.49619 .62658 m .45026 .6214 L .44383 .61559 L p
1 g
F P
s
P
p
.002 w
.6159 .27741 m .55815 .24681 L .564 .24406 L p
1 g
F P
s
P
p
.002 w
.564 .24406 m .6174 .27233 L .6159 .27741 L p
1 g
F P
s
P
p
.002 w
.66159 .32296 m .6159 .27741 L .6174 .27233 L p
1 g
F P
s
P
p
.002 w
.68823 .39169 m .69594 .45001 L .68941 .46687 L p
1 g
F P
s
P
p
.002 w
.69594 .45001 m .68823 .39169 L .6895 .37728 L p
1 g
F P
s
P
p
.002 w
.33124 .51117 m .34664 .54597 L .33623 .53972 L p
1 g
F P
s
P
p
.002 w
.33623 .53972 m .31799 .49872 L .33124 .51117 L p
1 g
F P
s
P
p
.002 w
.66159 .32296 m .6895 .37728 L .68823 .39169 L p
1 g
F P
s
P
p
.002 w
.34819 .33198 m .31649 .37103 L .31998 .35099 L p
1 g
F P
s
P
p
.002 w
.31998 .35099 m .35308 .30983 L .34819 .33198 L p
1 g
F P
s
P
p
.002 w
.49619 .62658 m .53916 .61859 L .5573 .61862 L p
1 g
F P
s
P
p
.002 w
.59753 .59517 m .5573 .61862 L .53916 .61859 L p
1 g
F P
s
P
p
.002 w
.5573 .61862 m .59753 .59517 L .6168 .58815 L p
1 g
F P
s
P
p
.002 w
.64692 .54876 m .6168 .58815 L .59753 .59517 L p
1 g
F P
s
P
p
.002 w
.6168 .58815 m .64692 .54876 L .66391 .53574 L p
1 g
F P
s
P
p
.002 w
.44383 .61559 m .48288 .61995 L .49619 .62658 L p
1 g
F P
s
P
p
.002 w
.53916 .61859 m .49619 .62658 L .48288 .61995 L p
1 g
F P
s
P
p
.002 w
.40279 .28314 m .35308 .30983 L .36195 .29183 L p
1 g
F P
s
P
p
.002 w
.36195 .29183 m .41237 .26445 L .40279 .28314 L p
1 g
F P
s
P
p
.002 w
.55034 .25504 m .48522 .24269 L .49599 .23512 L p
1 g
F P
s
P
p
.002 w
.49599 .23512 m .55815 .24681 L .55034 .25504 L p
1 g
F P
s
P
p
.002 w
.67715 .4833 m .66391 .53574 L .64692 .54876 L p
1 g
F P
s
P
p
.002 w
.66391 .53574 m .67715 .4833 L .68941 .46687 L p
1 g
F P
s
P
p
.002 w
.47445 .25609 m .41237 .26445 L .4241 .25113 L p
1 g
F P
s
P
p
.002 w
.4241 .25113 m .48522 .24269 L .47445 .25609 L p
1 g
F P
s
P
p
.002 w
.38222 .57344 m .40868 .59239 L .40581 .60069 L p
1 g
F P
s
P
p
.002 w
.40581 .60069 m .37237 .57674 L .38222 .57344 L p
1 g
F P
s
P
p
.002 w
.44383 .61559 m .40581 .60069 L .40868 .59239 L p
1 g
F P
s
P
p
.002 w
.32533 .41774 m .31398 .45664 L .30567 .43751 L p
1 g
F P
s
P
p
.002 w
.30567 .43751 m .3182 .39348 L .32533 .41774 L p
1 g
F P
s
P
p
.002 w
.32803 .47566 m .33124 .51117 L .31799 .49872 L p
1 g
F P
s
P
p
.002 w
.31799 .49872 m .31398 .45664 L .32803 .47566 L p
1 g
F P
s
P
p
.002 w
.68823 .39169 m .65892 .3349 L .66159 .32296 L p
1 g
F P
s
P
p
.002 w
.6159 .27741 m .66159 .32296 L .65892 .3349 L p
1 g
F P
s
P
p
.002 w
.36195 .54911 m .38222 .57344 L .37237 .57674 L p
1 g
F P
s
P
p
.002 w
.37237 .57674 m .34664 .54597 L .36195 .54911 L p
1 g
F P
s
P
p
.002 w
.40868 .59239 m .43876 .60415 L .44383 .61559 L p
1 g
F P
s
P
p
.002 w
.48288 .61995 m .44383 .61559 L .43876 .60415 L p
1 g
F P
s
P
p
.002 w
.34766 .35775 m .3182 .39348 L .31649 .37103 L p
1 g
F P
s
P
p
.002 w
.31649 .37103 m .34819 .33198 L .34766 .35775 L p
1 g
F P
s
P
p
.002 w
.68142 .4078 m .68941 .46687 L .67715 .4833 L p
1 g
F P
s
P
p
.002 w
.68941 .46687 m .68142 .4078 L .68823 .39169 L p
1 g
F P
s
P
p
.002 w
.61094 .28717 m .55034 .25504 L .55815 .24681 L p
1 g
F P
s
P
p
.002 w
.55815 .24681 m .6159 .27741 L .61094 .28717 L p
1 g
F P
s
P
p
.002 w
.65892 .3349 m .68823 .39169 L .68142 .4078 L p
1 g
F P
s
P
p
.002 w
.48288 .61995 m .51921 .61308 L .53916 .61859 L p
1 g
F P
s
P
p
.002 w
.57476 .59764 m .53916 .61859 L .51921 .61308 L p
1 g
F P
s
P
p
.002 w
.53916 .61859 m .57476 .59764 L .59753 .59517 L p
1 g
F P
s
P
p
.002 w
.65892 .3349 m .61094 .28717 L .6159 .27741 L p
1 g
F P
s
P
p
.002 w
.34994 .5217 m .36195 .54911 L .34664 .54597 L p
1 g
F P
s
P
p
.002 w
.34664 .54597 m .33124 .51117 L .34994 .5217 L p
1 g
F P
s
P
p
.002 w
.62507 .55875 m .59753 .59517 L .57476 .59764 L p
1 g
F P
s
P
p
.002 w
.59753 .59517 m .62507 .55875 L .64692 .54876 L p
1 g
F P
s
P
p
.002 w
.43876 .60415 m .46955 .60752 L .48288 .61995 L p
1 g
F P
s
P
p
.002 w
.51921 .61308 m .48288 .61995 L .46955 .60752 L p
1 g
F P
s
P
p
.002 w
.39578 .30685 m .34819 .33198 L .35308 .30983 L p
1 g
F P
s
P
p
.002 w
.35308 .30983 m .40279 .28314 L .39578 .30685 L p
1 g
F P
s
P
p
.002 w
.65923 .49872 m .64692 .54876 L .62507 .55875 L p
1 g
F P
s
P
p
.002 w
.64692 .54876 m .65923 .49872 L .67715 .4833 L p
1 g
F P
s
P
p
.002 w
.54072 .26882 m .47445 .25609 L .48522 .24269 L p
1 g
F P
s
P
p
.002 w
.48522 .24269 m .55034 .25504 L .54072 .26882 L p
1 g
F P
s
P
p
.002 w
.33786 .44307 m .32803 .47566 L .31398 .45664 L p
1 g
F P
s
P
p
.002 w
.31398 .45664 m .32533 .41774 L .33786 .44307 L p
1 g
F P
s
P
p
.002 w
.46405 .27519 m .40279 .28314 L .41237 .26445 L p
1 g
F P
s
P
p
.002 w
.41237 .26445 m .47445 .25609 L .46405 .27519 L p
1 g
F P
s
P
p
.002 w
.34763 .49391 m .34994 .5217 L .33124 .51117 L p
1 g
F P
s
P
p
.002 w
.33124 .51117 m .32803 .47566 L .34763 .49391 L p
1 g
F P
s
P
p
.002 w
.39597 .56577 m .41437 .57896 L .40868 .59239 L p
1 g
F P
s
P
p
.002 w
.40868 .59239 m .38222 .57344 L .39597 .56577 L p
1 g
F P
s
P
p
.004 w
.39463 .60137 m
.40659 .58197 L
s
P
p
.002 w
.43876 .60415 m .40868 .59239 L .41437 .57896 L p
1 g
F P
s
P
p
.002 w
.35168 .38643 m .32533 .41774 L .3182 .39348 L p
1 g
F P
s
P
p
.002 w
.3182 .39348 m .34766 .35775 L .35168 .38643 L p
1 g
F P
s
P
p
.002 w
.68142 .4078 m .65144 .35015 L .65892 .3349 L p
1 g
F P
s
P
p
.002 w
.61094 .28717 m .65892 .3349 L .65144 .35015 L p
1 g
F P
s
P
p
.002 w
.38194 .54884 m .39597 .56577 L .38222 .57344 L p
1 g
F P
s
P
p
.002 w
.38222 .57344 m .36195 .54911 L .38194 .54884 L p
1 g
F P
s
P
p
.002 w
.66898 .42517 m .67715 .4833 L .65923 .49872 L p
1 g
F P
s
P
p
.002 w
.67715 .4833 m .66898 .42517 L .68142 .4078 L p
1 g
F P
s
P
p
.002 w
.41437 .57896 m .4353 .58711 L .43876 .60415 L p
1 g
F P
s
P
p
.002 w
.46955 .60752 m .43876 .60415 L .4353 .58711 L p
1 g
F P
s
P
p
.002 w
.46955 .60752 m .49802 .60198 L .51921 .61308 L p
1 g
F P
s
P
p
.002 w
.54906 .59524 m .51921 .61308 L .49802 .60198 L p
1 g
F P
s
P
p
.002 w
.51921 .61308 m .54906 .59524 L .57476 .59764 L p
1 g
F P
s
P
p
.002 w
.59885 .56523 m .57476 .59764 L .54906 .59524 L p
1 g
F P
s
P
p
.002 w
.57476 .59764 m .59885 .56523 L .62507 .55875 L p
1 g
F P
s
P
p
.002 w
.65144 .35015 m .68142 .4078 L .66898 .42517 L p
1 g
F P
s
P
p
.002 w
.60248 .3016 m .54072 .26882 L .55034 .25504 L p
1 g
F P
s
P
p
.002 w
.55034 .25504 m .61094 .28717 L .60248 .3016 L p
1 g
F P
s
P
p
.002 w
.37374 .52985 m .38194 .54884 L .36195 .54911 L p
1 g
F P
s
P
p
.002 w
.36195 .54911 m .34994 .5217 L .37374 .52985 L p
1 g
F P
s
P
p
.002 w
.65144 .35015 m .60248 .3016 L .61094 .28717 L p
1 g
F P
s
P
p
.002 w
.39173 .335 m .34766 .35775 L .34819 .33198 L p
1 g
F P
s
P
p
.002 w
.34819 .33198 m .39578 .30685 L .39173 .335 L p
1 g
F P
s
P
p
.002 w
.4353 .58711 m .45665 .58937 L .46955 .60752 L p
1 g
F P
s
P
p
.002 w
.49802 .60198 m .46955 .60752 L .45665 .58937 L p
1 g
F P
s
P
p
.002 w
.63601 .51258 m .62507 .55875 L .59885 .56523 L p
1 g
F P
s
P
p
.002 w
.62507 .55875 m .63601 .51258 L .65923 .49872 L p
1 g
F P
s
P
p
.002 w
.35558 .46863 m .34763 .49391 L .32803 .47566 L p
1 g
F P
s
P
p
.002 w
.32803 .47566 m .33786 .44307 L .35558 .46863 L p
1 g
F P
s
P
p
.002 w
.4544 .29964 m .39578 .30685 L .40279 .28314 L p
1 g
F P
s
P
p
.002 w
.40279 .28314 m .46405 .27519 L .4544 .29964 L p
1 g
F P
s
P
p
.002 w
.52952 .28799 m .46405 .27519 L .47445 .25609 L p
1 g
F P
s
P
p
.002 w
.47445 .25609 m .54072 .26882 L .52952 .28799 L p
1 g
F P
s
P
p
.002 w
.37233 .51073 m .37374 .52985 L .34994 .5217 L p
1 g
F P
s
P
p
.002 w
.34994 .5217 m .34763 .49391 L .37233 .51073 L p
1 g
F P
s
P
p
.002 w
.36029 .41709 m .33786 .44307 L .32533 .41774 L p
1 g
F P
s
P
p
.002 w
.32533 .41774 m .35168 .38643 L .36029 .41709 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.65104 .44327 m .65923 .49872 L .63601 .51258 L p
1 g
F P
s
P
p
.002 w
.65923 .49872 m .65104 .44327 L .66898 .42517 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49802 .60198 m .52118 .58785 L .54906 .59524 L p
1 g
F P
s
P
p
.002 w
.56897 .56783 m .54906 .59524 L .52118 .58785 L p
1 g
F P
s
P
p
.002 w
.54906 .59524 m .56897 .56783 L .59885 .56523 L p
1 g
F P
s
P
p
.002 w
.45665 .58937 m .47625 .58541 L .49802 .60198 L p
1 g
F P
s
P
p
.002 w
.52118 .58785 m .49802 .60198 L .47625 .58541 L p
1 g
F P
s
P
p
.002 w
.66898 .42517 m .63913 .36838 L .65144 .35015 L p
1 g
F P
s
P
p
.002 w
.60248 .3016 m .65144 .35015 L .63913 .36838 L p
1 g
F P
s
P
p
.002 w
.41337 .55373 m .42286 .56055 L .41437 .57896 L p
1 g
F P
s
P
p
.002 w
.41437 .57896 m .39597 .56577 L .41337 .55373 L p
1 g
F P
s
P
p
.002 w
.4353 .58711 m .41437 .57896 L .42286 .56055 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.40618 .54499 m .41337 .55373 L .39597 .56577 L p
1 g
F P
s
P
p
.002 w
.39597 .56577 m .38194 .54884 L .40618 .54499 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.42286 .56055 m .43366 .56473 L .4353 .58711 L p
1 g
F P
s
P
p
.002 w
.45665 .58937 m .4353 .58711 L .43366 .56473 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.63913 .36838 m .66898 .42517 L .65104 .44327 L p
1 g
F P
s
P
p
.002 w
.39088 .36673 m .35168 .38643 L .34766 .35775 L p
1 g
F P
s
P
p
.002 w
.34766 .35775 m .39173 .335 L .39088 .36673 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.40204 .53523 m .40618 .54499 L .38194 .54884 L p
1 g
F P
s
P
p
.002 w
.38194 .54884 m .37374 .52985 L .40204 .53523 L p
1 g
F P
s
P
p
.002 w
.60807 .52431 m .59885 .56523 L .56897 .56783 L p
1 g
F P
s
P
p
.002 w
.59885 .56523 m .60807 .52431 L .63601 .51258 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.59061 .32046 m .52952 .28799 L .54072 .26882 L p
1 g
F P
s
P
p
.002 w
.54072 .26882 m .60248 .3016 L .59061 .32046 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.37802 .4935 m .37233 .51073 L .34763 .49391 L p
1 g
F P
s
P
p
.002 w
.34763 .49391 m .35558 .46863 L .37802 .4935 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.004 w
.44893 .51332 m
.5 .43051 L
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.63913 .36838 m .59061 .32046 L .60248 .3016 L p
1 g
F P
s
P
p
.002 w
.43366 .56473 m .44464 .56584 L .45665 .58937 L p
1 g
F P
s
P
p
.002 w
.47625 .58541 m .45665 .58937 L .44464 .56584 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.37331 .44868 m .35558 .46863 L .33786 .44307 L p
1 g
F P
s
P
p
.002 w
.33786 .44307 m .36029 .41709 L .37331 .44868 L p
1 g
F P
s
P
p
.002 w
.4459 .32876 m .39173 .335 L .39578 .30685 L p
1 g
F P
s
P
p
.002 w
.39578 .30685 m .4544 .29964 L .4459 .32876 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.40144 .52547 m .40204 .53523 L .37374 .52985 L p
1 g
F P
s
P
p
.002 w
.37374 .52985 m .37233 .51073 L .40144 .52547 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51705 .31215 m .4544 .29964 L .46405 .27519 L p
1 g
F P
s
P
p
.002 w
.46405 .27519 m .52952 .28799 L .51705 .31215 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.628 .4615 m .63601 .51258 L .60807 .52431 L p
1 g
F P
s
P
p
.002 w
.63601 .51258 m .628 .4615 L .65104 .44327 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47625 .58541 m .4837 .58075 L p
.52118 .58785 L 1 g
F P
s
P
p
.002 w
.4837 .58075 m .48496 .57996 L p
.48869 .58077 L 1 g
F P
s
P
p
.52118 .58785 m .4837 .58075 L .48869 .58077 L 1 g
F
P
p
.51079 .57862 m .49971 .58084 L .50464 .58086 L 1 g
F
P
p
.002 w
.52696 .57967 m .52118 .58785 L .50664 .58171 L p
1 g
F P
s
P
p
.002 w
.50664 .58171 m .50464 .58086 L p
.51093 .58053 L 1 g
F P
s
P
p
.52696 .57967 m .50664 .58171 L .51093 .58053 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58053 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58053 L .52175 .57754 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.53128 .57265 m .52175 .57754 L .53009 .57524 L 1 g
F
P
p
.002 w
.55187 .56704 m .56897 .56783 L p
.53102 .57506 L 1 g
F P
s
P
p
.53102 .57506 m .53009 .57524 L .53171 .57463 L 1 g
F
P
p
.53102 .57506 m .53171 .57463 L .55187 .56704 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53171 .57463 L p
1 g
F P
s
P
p
.002 w
.52118 .58785 m .53009 .57524 L p
.56897 .56783 L 1 g
F P
s
P
p
.54854 .56129 m .53171 .57463 L .54005 .56938 L 1 g
F
P
p
.002 w
.53171 .57463 m .53128 .57265 L p
.53009 .57524 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54854 .56129 m .54005 .56938 L .54433 .56669 L 1 g
F
P
p
.002 w
.57421 .54306 m .56897 .56783 L .54619 .56678 L p
1 g
F P
s
P
p
.002 w
.54619 .56678 m .54433 .56669 L p
.54914 .56289 L 1 g
F P
s
P
p
.57421 .54306 m .54619 .56678 L .54914 .56289 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54914 .56289 L p
1 g
F P
s
P
p
.56075 .54566 m .54914 .56289 L .55687 .5527 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56135 .54679 L p
1 g
F P
s
P
p
.002 w
.57626 .53341 m .57421 .54306 L p
.55937 .55219 L 1 g
F P
s
P
p
.57626 .53341 m .55937 .55219 L .5603 .54964 L 1 g
F
P
p
.56654 .52734 m .56135 .54679 L .5646 .53794 L 1 g
F
P
p
.002 w
.56135 .54679 m .56075 .54566 L p
.55687 .5527 L 1 g
F P
s
P
p
.56354 .54391 m .5554 .55463 L .53639 .56632 L 1 g
F
P
p
.57626 .53341 m .5603 .54964 L .56354 .54391 L 1 g
F
P
p
.5603 .54964 m .5554 .55463 L .56135 .54679 L 1 g
F
P
p
.5603 .54964 m .56135 .54679 L .56354 .54391 L 1 g
F
P
p
.56654 .52734 m .5646 .53794 L .56558 .53528 L 1 g
F
P
p
.002 w
.57211 .51035 m .57626 .53341 L .56783 .53489 L p
1 g
F P
s
P
p
.002 w
.56783 .53489 m .56558 .53528 L p
.56735 .52852 L 1 g
F P
s
P
p
.57211 .51035 m .56783 .53489 L .56735 .52852 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56735 .52852 L p
1 g
F P
s
P
p
.56515 .50826 m .56735 .52852 L .56647 .51681 L 1 g
F
P
p
.002 w
.56735 .52852 m .56654 .52734 L p
.56558 .53528 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56589 .50914 m .56515 .50826 L p
.56647 .51681 L 1 g
F P
s
P
p
.002 w
.56558 .53528 m .54165 .53948 L p
.56639 .51582 L 1 g
F P
s
P
p
.57211 .51035 m .56735 .52852 L .56639 .51582 L 1 g
F
P
p
.56735 .52852 m .56558 .53528 L .56639 .51582 L 1 g
F
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56946 .49564 m .57211 .51035 L p
.5682 .51409 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56589 .50914 L p
1 g
F P
s
P
p
.55661 .4905 m .56589 .50914 L .56209 .50098 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.56378 .5046 m .5682 .51409 L .54165 .53948 L 1 g
F
P
p
.56946 .49564 m .5682 .51409 L .56378 .5046 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.55661 .4905 m .56209 .50098 L .56126 .49921 L 1 g
F
P
p
.54885 .45893 m .55945 .49331 L .54628 .46917 L 1 g
F
P
p
.55945 .49331 m .56126 .49921 L .55727 .4912 L 1 g
F
P
p
.55945 .49331 m .55727 .4912 L .54628 .46917 L 1 g
F
P
p
.002 w
.55727 .4912 m .55661 .4905 L p
.56126 .49921 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55727 .4912 L p
1 g
F P
s
P
p
.002 w
.55779 .49175 m .55727 .4912 L p
.56126 .49921 L 1 g
F P
s
P
p
.54174 .47608 m .55727 .4912 L .54779 .48201 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56126 .49921 m .536 .51021 L p
.54399 .47832 L 1 g
F P
s
P
p
.002 w
.54219 .47657 m .54174 .47608 L p
.54779 .48201 L 1 g
F P
s
P
p
.54628 .46917 m .55727 .4912 L .54399 .47832 L 1 g
F
P
p
.55727 .4912 m .56126 .49921 L .54399 .47832 L 1 g
F
P
p
.002 w
.54885 .45893 m .56946 .49564 L .56126 .49921 L p
1 g
F P
s
P
p
.002 w
.56126 .49921 m .56946 .49564 L p
.56378 .5046 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55779 .49175 L p
1 g
F P
s
P
p
.56209 .50098 m .56713 .51061 L .55779 .49175 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.536 .51021 m .51977 .48187 L .53232 .47197 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54219 .47657 L p
1 g
F P
s
P
p
.52214 .46667 m .54219 .47657 L .53284 .47221 L 1 g
F
P
p
.5442 .47751 m .536 .51021 L .53232 .47197 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53232 .47197 m .51977 .48187 L p
.51887 .46659 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46709 L p
1 g
F P
s
P
p
.5 .4634 m .52239 .46709 L .5104 .4654 L 1 g
F
P
p
.51879 .46532 m .52239 .46709 L .51887 .46659 L 1 g
F
P
p
.52239 .46709 m .53232 .47197 L .51887 .46659 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49468 .45789 m .51657 .42786 L p
.51887 .46659 L 1 g
F P
s
P
p
.002 w
.51977 .48187 m .50119 .4641 L p
.51887 .46659 L 1 g
F P
s
P
p
.5 .4634 m .5104 .4654 L .50119 .4641 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.50119 .4641 m .51977 .48187 L p
.4962 .46449 L 1 g
F P
s
P
p
.50119 .4641 m .4962 .46449 L .5 .46392 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.51977 .48187 m .49018 .50313 L p
.49399 .46483 L 1 g
F P
s
P
p
.4962 .46449 m .51977 .48187 L .49399 .46483 L 1 g
F
P
p
.47786 .46667 m .5 .46392 L .4899 .46545 L 1 g
F
P
p
.47786 .46667 m .4899 .46545 L .48895 .46559 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48895 .46559 m .47308 .4869 L p
.46979 .4709 L 1 g
F P
s
P
p
.47759 .46712 m .48895 .46559 L .46979 .4709 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46712 L p
1 g
F P
s
P
p
.45826 .47608 m .47759 .46712 L .46718 .47217 L 1 g
F
P
p
.002 w
.45757 .47683 m .45826 .47608 L p
.46718 .47217 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45204 .47556 m .46368 .44122 L p
.46876 .46592 L 1 g
F P
s
P
p
.002 w
.47308 .4869 m .45644 .47793 L p
.46876 .46592 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45752 .47689 L p
1 g
F P
s
P
p
.45213 .48211 m .4526 .51377 L .44912 .48503 L 1 g
F
P
p
.44339 .4905 m .45752 .47689 L .45084 .48337 L 1 g
F
P
p
.002 w
.47308 .4869 m .4526 .51377 L p
.45213 .48211 L 1 g
F P
s
P
p
.002 w
.45204 .47556 m .45644 .47793 L p
.45213 .48211 L 1 g
F P
s
P
p
.002 w
.45644 .47793 m .47308 .4869 L p
.45213 .48211 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.4526 .51377 m .44203 .50806 L .44912 .48503 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43071 .50541 m .42952 .47042 L p
.43895 .4988 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44262 .49132 L p
1 g
F P
s
P
p
.43485 .50826 m .44262 .49132 L .43869 .49933 L 1 g
F
P
p
.002 w
.4352 .50646 m .43071 .50541 L p
.43895 .4988 L 1 g
F P
s
P
p
.002 w
.42952 .47042 m .45052 .47521 L p
.44262 .49132 L 1 g
F P
s
P
p
.43796 .49582 m .44262 .49132 L .43895 .4988 L 1 g
F
P
p
.42952 .47042 m .44262 .49132 L .43796 .49582 L 1 g
F
P
p
.44339 .4905 m .45084 .48337 L .44912 .48503 L 1 g
F
P
p
.002 w
.44262 .49132 m .44339 .4905 L p
.44912 .48503 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.43895 .4988 m .44381 .49017 L .44203 .50806 L 1 g
F
P
p
.002 w
.45204 .47556 m .44912 .48503 L p
.44381 .49017 L 1 g
F P
s
P
p
.002 w
.44912 .48503 m .44203 .50806 L p
.44381 .49017 L 1 g
F P
s
P
p
.002 w
.45052 .47521 m .45204 .47556 L p
.43895 .4988 L 1 g
F P
s
P
p
.002 w
.44262 .49132 m .44174 .49225 L p
.43869 .49933 L 1 g
F P
s
P
p
.44912 .48503 m .45287 .48142 L .44251 .49143 L 1 g
F
P
p
.45084 .48337 m .45112 .4831 L .44912 .48503 L 1 g
F
P
p
.45112 .4831 m .45287 .48142 L .44912 .48503 L 1 g
F
P
p
.002 w
.44251 .49143 m .44262 .49132 L p
.44912 .48503 L 1 g
F P
s
P
p
.43851 .49969 m .44174 .49225 L .44116 .49351 L 1 g
F
P
p
.43485 .50826 m .43869 .49933 L .43851 .49969 L 1 g
F
P
p
.43869 .49933 m .44174 .49225 L .43851 .49969 L 1 g
F
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43161 .51424 m .43071 .50541 L .43401 .50618 L p
1 g
F P
s
P
p
.002 w
.43401 .50618 m .4352 .50646 L p
.43378 .50953 L 1 g
F P
s
P
p
.43401 .50618 m .43378 .50953 L .43161 .51424 L 1 g
F
P
p
.43346 .52734 m .43316 .51866 L .43272 .52506 L 1 g
F
P
p
.002 w
.43216 .53344 m .41992 .50612 L p
.43069 .52206 L 1 g
F P
s
P
p
.43069 .52206 m .43272 .52506 L .43247 .52878 L 1 g
F
P
p
.43069 .52206 m .43247 .52878 L .43216 .53344 L 1 g
F
P
p
.002 w
.43247 .52878 m .43346 .52734 L p
.43272 .52506 L 1 g
F P
s
P
p
.002 w
.434 .53754 m .43216 .53344 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43247 .52878 L p
1 g
F P
s
P
p
.43925 .54566 m .43247 .52878 L .4335 .53264 L 1 g
F
P
p
.43925 .54566 m .4335 .53264 L .4344 .53604 L 1 g
F
P
p
.002 w
.4346 .53676 m .434 .53754 L .4344 .53604 L p
1 g
F P
s
P
p
.43442 .53611 m .4344 .53604 L .43442 .53611 L 1 g
F
P
p
.43925 .54566 m .4344 .53604 L .43442 .53611 L 1 g
F
P
p
.002 w
.44464 .56584 m .43366 .56473 L .43395 .54142 L p
1 g
F P
s
P
p
.002 w
.43395 .54142 m .434 .53754 L .43698 .54547 L p
1 g
F P
s
P
p
.002 w
.43698 .54547 m .44464 .56584 L p
.43395 .54142 L 1 g
F P
s
P
p
.47625 .58541 m .4646 .5782 L .45762 .56805 L 1 g
F
P
p
.002 w
.46117 .57027 m .47625 .58541 L p
.45762 .56805 L 1 g
F P
s
P
p
.002 w
.44464 .56584 m .45133 .56442 L p
.4646 .5782 L 1 g
F P
s
P
p
.002 w
.45133 .56442 m .4517 .56435 L p
.4646 .5782 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45064 .56351 L p
1 g
F P
s
P
p
.002 w
.44464 .56584 m .44085 .55577 L p
.45064 .56351 L 1 g
F P
s
P
p
.002 w
.4517 .56435 m .45133 .56442 L p
.45064 .56351 L 1 g
F P
s
P
p
.002 w
.45133 .56442 m .44464 .56584 L p
.45064 .56351 L 1 g
F P
s
P
p
.002 w
.45064 .56351 m .45146 .56129 L p
.44415 .55494 L 1 g
F P
s
P
p
.46872 .57265 m .45064 .56351 L .45121 .56396 L 1 g
F
P
p
.46872 .57265 m .45058 .56365 L .45834 .5685 L 1 g
F
P
p
.43454 .53653 m .43441 .53608 L .43452 .53649 L 1 g
F
P
p
.43925 .54566 m .43441 .53608 L .43454 .53653 L 1 g
F
P
p
.43441 .53608 m .43441 .53608 L .43454 .53653 L 1 g
F
P
p
.43925 .54566 m .43452 .53649 L .43461 .53682 L 1 g
F
P
p
.43925 .54566 m .43459 .53678 L .43467 .53704 L 1 g
F
P
p
.43925 .54566 m .43465 .53699 L .43472 .53721 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.4526 .51377 m .46123 .5219 L .43471 .53713 L p
1 g
F P
s
P
p
.002 w
.43471 .53713 m .434 .53754 L .4346 .53676 L p
1 g
F P
s
P
p
.002 w
.4346 .53676 m .4526 .51377 L p
.43471 .53713 L 1 g
F P
s
P
p
.43925 .54566 m .43469 .53715 L .43476 .53736 L 1 g
F
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46123 .5219 m .46696 .53154 L .43479 .53739 L p
1 g
F P
s
P
p
.002 w
.43479 .53739 m .434 .53754 L .43471 .53713 L p
1 g
F P
s
P
p
.002 w
.43471 .53713 m .46123 .5219 L p
.43479 .53739 L 1 g
F P
s
P
p
.43461 .53682 m .43452 .53649 L .43459 .53678 L 1 g
F
P
p
.43467 .53704 m .43459 .53678 L .43465 .53699 L 1 g
F
P
p
.43925 .54566 m .43473 .5373 L .4348 .53749 L 1 g
F
P
p
.002 w
.43486 .53763 m .434 .53754 L .43479 .53739 L p
1 g
F P
s
P
p
.002 w
.43496 .53792 m .434 .53754 L .43486 .53763 L p
1 g
F P
s
P
p
.002 w
.43511 .53835 m .434 .53754 L .43496 .53792 L p
1 g
F P
s
P
p
.002 w
.43837 .54731 m .43925 .54566 L p
.43476 .53743 L 1 g
F P
s
P
p
.002 w
.46696 .53154 m .46916 .54159 L .43486 .53763 L p
1 g
F P
s
P
p
.002 w
.43479 .53739 m .46696 .53154 L p
.43486 .53763 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46916 .54159 m .46764 .55094 L .43496 .53792 L p
1 g
F P
s
P
p
.002 w
.43486 .53763 m .46916 .54159 L p
.43496 .53792 L 1 g
F P
s
P
p
.43472 .53721 m .43465 .53699 L .43469 .53715 L 1 g
F
P
p
.43476 .53736 m .43469 .53715 L .43473 .5373 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46764 .55094 m .46261 .55859 L .43511 .53835 L p
1 g
F P
s
P
p
.002 w
.43496 .53792 m .46764 .55094 L p
.43511 .53835 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46261 .55859 m .45464 .56373 L .4355 .53944 L p
1 g
F P
s
P
p
.002 w
.4355 .53944 m .434 .53754 L .43511 .53835 L p
1 g
F P
s
P
p
.002 w
.43511 .53835 m .46261 .55859 L p
.4355 .53944 L 1 g
F P
s
P
p
.4348 .53749 m .43473 .5373 L .43476 .53743 L 1 g
F
P
p
.4358 .54027 m .43789 .54666 L .434 .53754 L 1 g
F
P
p
.002 w
.44085 .55577 m .43698 .54547 L p
.43789 .54666 L 1 g
F P
s
P
p
.002 w
.43698 .54547 m .434 .53754 L p
.43789 .54666 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43837 .54731 L p
1 g
F P
s
P
p
.45146 .56129 m .43837 .54731 L .44415 .55494 L 1 g
F
P
p
.4517 .56435 m .44172 .55646 L .4358 .54027 L 1 g
F
P
p
.44172 .55646 m .44085 .55577 L .4358 .54027 L 1 g
F
P
p
.002 w
.43837 .54731 m .43743 .5491 L p
.44415 .55494 L 1 g
F P
s
P
p
.002 w
.45464 .56373 m .4517 .56435 L p
.4358 .54027 L 1 g
F P
s
P
p
.002 w
.434 .53754 m .4355 .53944 L p
.4358 .54027 L 1 g
F P
s
P
p
.002 w
.4355 .53944 m .45464 .56373 L p
.4358 .54027 L 1 g
F P
s
P
p
.002 w
.4344 .53604 m .434 .53754 L .4335 .53264 L p
1 g
F P
s
P
p
.002 w
.4335 .53264 m .434 .53754 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.42286 .56055 m .41337 .55373 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.43366 .56473 m .42286 .56055 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.41337 .55373 m .40618 .54499 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.40618 .54499 m .40204 .53523 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.40204 .53523 m .40144 .52547 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.40144 .52547 m .40446 .51676 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.40446 .51676 m .41084 .51005 L .434 .53754 L closepath p
1 g
F P
s
P
p
.002 w
.41084 .51005 m .41992 .50612 L .434 .53754 L closepath p
1 g
F P
s
P
p
.43476 .53743 m .43146 .53025 L .43771 .54856 L 1 g
F
P
p
.43441 .53608 m .43392 .53511 L .43476 .53743 L 1 g
F
P
p
.43392 .53511 m .43146 .53025 L .43476 .53743 L 1 g
F
P
p
.002 w
.43771 .54856 m .43837 .54731 L p
.43476 .53743 L 1 g
F P
s
P
p
.002 w
.45058 .56365 m .45064 .56351 L p
.44391 .55473 L 1 g
F P
s
P
p
.44415 .55494 m .44391 .55473 L .45064 .56351 L 1 g
F
P
p
.002 w
.45064 .56351 m .45058 .56365 L p
.45121 .56396 L 1 g
F P
s
P
p
.002 w
.4517 .56435 m .45464 .56373 L p
.45762 .56805 L 1 g
F P
s
P
p
.4646 .5782 m .4517 .56435 L .45762 .56805 L 1 g
F
P
p
.002 w
.45058 .56365 m .45002 .56518 L p
.45834 .5685 L 1 g
F P
s
P
p
.46872 .57265 m .45834 .5685 L .46117 .57027 L 1 g
F
P
p
.002 w
.4683 .57456 m .46872 .57265 L p
.46117 .57027 L 1 g
F P
s
P
p
.002 w
.48496 .57996 m .48119 .58232 L p
.47169 .57566 L 1 g
F P
s
P
p
.002 w
.48119 .58232 m .47625 .58541 L .46408 .5732 L p
1 g
F P
s
P
p
.002 w
.46408 .5732 m .46117 .57027 L p
.4683 .57456 L 1 g
F P
s
P
p
.48119 .58232 m .46408 .5732 L .4683 .57456 L 1 g
F
P
p
.002 w
.48905 .58078 m .48921 .57862 L p
.47797 .5777 L 1 g
F P
s
P
p
.48119 .58232 m .4683 .57456 L .47169 .57566 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46117 .57027 m .45464 .56373 L p
.47169 .57566 L 1 g
F P
s
P
p
.4683 .57456 m .46117 .57027 L .47169 .57566 L 1 g
F
P
p
.47053 .57708 m .4678 .57686 L .4854 .5801 L 1 g
F
P
p
.002 w
.51817 .58658 m .52118 .58785 L p
.48869 .58077 L 1 g
F P
s
P
p
.48869 .58077 m .48496 .57996 L .48905 .58078 L 1 g
F
P
p
.48869 .58077 m .48905 .58078 L .51817 .58658 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58078 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58078 L .49971 .58084 L 1 g
F
P
p
.47797 .5777 m .48496 .57996 L .48905 .58078 L 1 g
F
P
p
.002 w
.48496 .57996 m .49203 .57554 L .50464 .58086 L p
1 g
F P
s
P
p
.002 w
.50464 .58086 m .51817 .58658 L p
.48905 .58078 L 1 g
F P
s
P
p
.48905 .58078 m .48496 .57996 L .50464 .58086 L 1 g
F
P
p
.002 w
.48905 .58078 m .48889 .583 L p
.49971 .58084 L 1 g
F P
s
P
p
.48496 .57996 m .4854 .5801 L .48905 .58078 L 1 g
F
P
p
.47053 .57708 m .4854 .5801 L .48496 .57996 L 1 g
F
P
p
.47797 .5777 m .47053 .57708 L .48496 .57996 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48901 .58127 L p
1 g
F P
s
P
p
.002 w
.48901 .58127 m .48905 .58078 L p
.4854 .5801 L 1 g
F P
s
P
p
.4854 .5801 m .4678 .57686 L .48901 .58127 L 1 g
F
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.49203 .57554 m .48496 .57996 L p
.45464 .56373 L 1 g
F P
s
P
p
.48496 .57996 m .47169 .57566 L .45464 .56373 L 1 g
F
P
p
.002 w
.46827 .57472 m .4683 .57456 L p
.46117 .57027 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .57472 L p
1 g
F P
s
P
p
.45834 .5685 m .45002 .56518 L .46827 .57472 L 1 g
F
P
p
.002 w
.45464 .56373 m .46117 .57027 L p
.45762 .56805 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .44117 .55387 L p
.45058 .56365 L 1 g
F P
s
P
p
.002 w
.44117 .55387 m .45002 .56518 L .45058 .56365 L p
1 g
F P
s
P
p
.002 w
.45058 .56365 m .45058 .56365 L p
.44117 .55387 L 1 g
F P
s
P
p
.44391 .55473 m .43743 .5491 L .45058 .56365 L 1 g
F
P
p
.002 w
.44203 .50806 m .4526 .51377 L .4346 .53676 L p
1 g
F P
s
P
p
.002 w
.4344 .53604 m .44203 .50806 L p
.4346 .53676 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43378 .50953 L p
1 g
F P
s
P
p
.43161 .51424 m .43354 .5131 L .43282 .52364 L 1 g
F
P
p
.43346 .52734 m .43378 .50953 L .43316 .51866 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43378 .50953 L p
1 g
F P
s
P
p
.002 w
.43378 .50953 m .43485 .50826 L p
.44116 .49351 L 1 g
F P
s
P
p
.44116 .49351 m .44166 .49233 L .43378 .50953 L 1 g
F
P
p
.002 w
.4352 .50646 m .44203 .50806 L p
.43161 .51424 L 1 g
F P
s
P
p
.002 w
.43378 .50953 m .43287 .51061 L p
.43316 .51866 L 1 g
F P
s
P
p
.002 w
.44203 .50806 m .4344 .53604 L p
.43282 .52364 L 1 g
F P
s
P
p
.43354 .5131 m .44203 .50806 L .43282 .52364 L 1 g
F
P
p
.002 w
.4335 .53264 m .43161 .51424 L p
.4344 .53604 L 1 g
F P
s
P
p
.43442 .53611 m .4335 .53264 L .43441 .53608 L 1 g
F
P
p
.002 w
.43272 .52506 m .4335 .53264 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43247 .52878 m .43146 .53025 L p
.43441 .53608 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43771 .54856 L p
1 g
F P
s
P
p
.002 w
.43247 .52879 m .43247 .52878 L p
.43272 .52506 L 1 g
F P
s
P
p
.002 w
.41992 .50612 m .43071 .50541 L .43272 .52506 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43247 .52879 L p
1 g
F P
s
P
p
.43316 .51866 m .43287 .51061 L .43247 .52879 L 1 g
F
P
p
.002 w
.44203 .50806 m .4352 .50646 L p
.43895 .4988 L 1 g
F P
s
P
p
.002 w
.44174 .49225 m .44166 .49233 L p
.44116 .49351 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44251 .49143 L p
.45287 .48142 L 1 g
F P
s
P
p
.002 w
.45752 .47689 m .45698 .47747 L p
.45084 .48337 L 1 g
F P
s
P
p
.002 w
.44912 .48503 m .45204 .47556 L p
.45213 .48211 L 1 g
F P
s
P
p
.002 w
.45644 .47793 m .45204 .47556 L p
.46876 .46592 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44411 .48996 L p
.45287 .48142 L 1 g
F P
s
P
p
.002 w
.44411 .48996 m .44166 .49233 L p
.45287 .48142 L 1 g
F P
s
P
p
.002 w
.47759 .46712 m .47718 .46778 L p
.46718 .47217 L 1 g
F P
s
P
p
.46368 .44122 m .4862 .46294 L .46924 .46824 L 1 g
F
P
p
.002 w
.47759 .46712 m .47786 .46667 L p
.48895 .46559 L 1 g
F P
s
P
p
.4862 .46294 m .48895 .46559 L .47759 .46712 L 1 g
F
P
p
.4862 .46294 m .47759 .46712 L .46924 .46824 L 1 g
F
P
p
.46924 .46824 m .47759 .46712 L .46979 .4709 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45757 .47683 L p
1 g
F P
s
P
p
.46718 .47217 m .47718 .46778 L .45757 .47683 L 1 g
F
P
p
.002 w
.47746 .46732 m .47759 .46712 L p
.48895 .46559 L 1 g
F P
s
P
p
.002 w
.46368 .44122 m .49468 .45789 L .48895 .46559 L p
1 g
F P
s
P
p
.002 w
.49018 .50313 m .47308 .4869 L .49468 .45789 L p
1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .46442 L p
.4899 .46545 L 1 g
F P
s
P
p
.49417 .463 m .4962 .46449 L .49399 .46483 L 1 g
F
P
p
.5 .46392 m .4962 .46449 L .49417 .463 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47746 .46732 L p
1 g
F P
s
P
p
.4899 .46545 m .5 .46442 L .47746 .46732 L 1 g
F
P
p
.002 w
.5 .46394 m .5 .46392 L p
.50119 .4641 L 1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .4634 L p
.50119 .4641 L 1 g
F P
s
P
p
.002 w
.49468 .45789 m .50119 .4641 L p
.49417 .463 L 1 g
F P
s
P
p
.002 w
.50119 .4641 m .49468 .45789 L p
.51887 .46659 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46394 L p
1 g
F P
s
P
p
.5104 .4654 m .52282 .46778 L .5 .46394 L 1 g
F
P
p
.002 w
.52239 .46709 m .52282 .46778 L p
.5104 .4654 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52239 .46709 L p
1 g
F P
s
P
p
.002 w
.52239 .46709 m .52214 .46667 L p
.53335 .47247 L 1 g
F P
s
P
p
.53335 .47247 m .54302 .47747 L .52239 .46709 L 1 g
F
P
p
.002 w
.51657 .42786 m .54885 .45893 L .53232 .47197 L p
1 g
F P
s
P
p
.51657 .42786 m .53232 .47197 L .51879 .46532 L 1 g
F
P
p
.002 w
.53232 .47197 m .54885 .45893 L p
.5442 .47751 L 1 g
F P
s
P
p
.002 w
.54219 .47657 m .54302 .47747 L p
.53284 .47221 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54219 .47657 L p
1 g
F P
s
P
p
.54779 .48201 m .55834 .49233 L .54219 .47657 L 1 g
F
P
p
.002 w
.55727 .4912 m .55834 .49233 L p
.54779 .48201 L 1 g
F P
s
P
p
.002 w
.54165 .53948 m .536 .51021 L .56126 .49921 L p
1 g
F P
s
P
p
.56378 .5046 m .54165 .53948 L .56126 .49921 L 1 g
F
P
p
.002 w
.56589 .50914 m .56713 .51061 L p
.56209 .50098 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56589 .50914 L p
1 g
F P
s
P
p
.56647 .51681 m .56854 .53025 L .56589 .50914 L 1 g
F
P
p
.002 w
.56735 .52852 m .56854 .53025 L p
.56647 .51681 L 1 g
F P
s
P
p
.002 w
.56782 .5292 m .56735 .52852 L p
.56558 .53528 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.53639 .56632 m .54165 .53948 L .57626 .53341 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56782 .5292 L p
1 g
F P
s
P
p
.5646 .53794 m .56257 .5491 L .56782 .5292 L 1 g
F
P
p
.002 w
.56135 .54679 m .56257 .5491 L p
.5646 .53794 L 1 g
F P
s
P
p
.5603 .54964 m .55937 .55219 L .5554 .55463 L 1 g
F
P
p
.002 w
.54914 .56289 m .54854 .56129 L p
.54433 .56669 L 1 g
F P
s
P
p
.002 w
.54433 .56669 m .53639 .56632 L p
.57421 .54306 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56135 .54679 L p
1 g
F P
s
P
p
.55687 .5527 m .54998 .56518 L .56135 .54679 L 1 g
F
P
p
.002 w
.54914 .56289 m .54998 .56518 L p
.55687 .5527 L 1 g
F P
s
P
p
.002 w
.54937 .56352 m .54914 .56289 L p
.54433 .56669 L 1 g
F P
s
P
p
.002 w
.53009 .57524 m .53639 .56632 L .54433 .56669 L p
1 g
F P
s
P
p
.002 w
.54433 .56669 m .55187 .56704 L p
.53171 .57463 L 1 g
F P
s
P
p
.53171 .57463 m .53009 .57524 L .54433 .56669 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54937 .56352 L p
1 g
F P
s
P
p
.54005 .56938 m .5322 .57686 L .54937 .56352 L 1 g
F
P
p
.002 w
.53171 .57463 m .5322 .57686 L p
.54005 .56938 L 1 g
F P
s
P
p
.002 w
.53175 .57478 m .53171 .57463 L p
.53009 .57524 L 1 g
F P
s
P
p
.002 w
.53639 .56632 m .53009 .57524 L p
.49203 .57554 L 1 g
F P
s
P
p
.002 w
.53009 .57524 m .52696 .57967 L p
.51792 .5786 L 1 g
F P
s
P
p
.53009 .57524 m .51792 .5786 L .49203 .57554 L 1 g
F
P
p
.002 w
.51093 .58053 m .51079 .57862 L p
.50464 .58086 L 1 g
F P
s
P
p
.002 w
.50464 .58086 m .49203 .57554 L p
.52696 .57967 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53175 .57478 L p
1 g
F P
s
P
p
.52175 .57754 m .51111 .583 L .53175 .57478 L 1 g
F
P
p
.002 w
.51093 .58053 m .51111 .583 L p
.52175 .57754 L 1 g
F P
s
P
p
.002 w
.51096 .5809 m .51093 .58053 L p
.50464 .58086 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .5809 L p
1 g
F P
s
P
p
.49971 .58084 m .48889 .583 L .51096 .5809 L 1 g
F
P
p
.002 w
.39338 .40099 m .36029 .41709 L .35168 .38643 L p
1 g
F P
s
P
p
.002 w
.35168 .38643 m .39088 .36673 L .39338 .40099 L p
1 g
F P
s
P
p
.002 w
.56897 .56783 m .57626 .53341 L .60807 .52431 L p
1 g
F P
s
P
p
.002 w
.65104 .44327 m .62218 .38909 L .63913 .36838 L p
1 g
F P
s
P
p
.002 w
.59061 .32046 m .63913 .36838 L .62218 .38909 L p
1 g
F P
s
P
p
.002 w
.62218 .38909 m .65104 .44327 L .628 .4615 L p
1 g
F P
s
P
p
.002 w
.40446 .51676 m .40144 .52547 L .37233 .51073 L p
1 g
F P
s
P
p
.002 w
.37233 .51073 m .37802 .4935 L .40446 .51676 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.39036 .48006 m .37802 .4935 L .35558 .46863 L p
1 g
F P
s
P
p
.002 w
.35558 .46863 m .37331 .44868 L .39036 .48006 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.57557 .34331 m .51705 .31215 L .52952 .28799 L p
1 g
F P
s
P
p
.002 w
.52952 .28799 m .59061 .32046 L .57557 .34331 L p
1 g
F P
s
P
p
.002 w
.45464 .56373 m .46261 .55859 L .49203 .57554 L p
1 g
F P
s
P
p
.002 w
.5022 .56065 m .49203 .57554 L .46261 .55859 L p
1 g
F P
s
P
p
.002 w
.49203 .57554 m .5022 .56065 L .53639 .56632 L p
1 g
F P
s
P
p
.002 w
.43889 .36165 m .39088 .36673 L .39173 .335 L p
1 g
F P
s
P
p
.002 w
.39173 .335 m .4459 .32876 L .43889 .36165 L p
1 g
F P
s
P
p
.002 w
.6005 .47918 m .60807 .52431 L .57626 .53341 L p
1 g
F P
s
P
p
.002 w
.60807 .52431 m .6005 .47918 L .628 .4615 L p
1 g
F P
s
P
p
.002 w
.62218 .38909 m .57557 .34331 L .59061 .32046 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.54165 .53948 m .53639 .56632 L .5022 .56065 L p
1 g
F P
s
P
p
.002 w
.39921 .43653 m .37331 .44868 L .36029 .41709 L p
1 g
F P
s
P
p
.002 w
.36029 .41709 m .39338 .40099 L .39921 .43653 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.50373 .3406 m .4459 .32876 L .4544 .29964 L p
1 g
F P
s
P
p
.002 w
.4544 .29964 m .51705 .31215 L .50373 .3406 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.41084 .51005 m .40446 .51676 L .37802 .4935 L p
1 g
F P
s
P
p
.002 w
.37802 .4935 m .39036 .48006 L .41084 .51005 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.46261 .55859 m .46764 .55094 L .5022 .56065 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60101 .41164 m .628 .4615 L .6005 .47918 L p
1 g
F P
s
P
p
.002 w
.628 .4615 m .60101 .41164 L .62218 .38909 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5055 .54225 m .5022 .56065 L .46764 .55094 L p
1 g
F P
s
P
p
.002 w
.5022 .56065 m .5055 .54225 L .54165 .53948 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.57557 .34331 m .62218 .38909 L .60101 .41164 L p
1 g
F P
s
P
p
.002 w
.57626 .53341 m .56946 .49564 L .6005 .47918 L p
1 g
F P
s
P
p
.002 w
.40816 .47203 m .39036 .48006 L .37331 .44868 L p
1 g
F P
s
P
p
.002 w
.37331 .44868 m .39921 .43653 L .40816 .47203 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43369 .39712 m .39338 .40099 L .39088 .36673 L p
1 g
F P
s
P
p
.002 w
.39088 .36673 m .43889 .36165 L .43369 .39712 L p
1 g
F P
s
P
p
.002 w
.46764 .55094 m .46916 .54159 L .5055 .54225 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.41992 .50612 m .41084 .51005 L .39036 .48006 L p
1 g
F P
s
P
p
.002 w
.39036 .48006 m .40816 .47203 L .41992 .50612 L p
1 g
F P
s
P
p
.002 w
.5578 .36945 m .50373 .3406 L .51705 .31215 L p
1 g
F P
s
P
p
.002 w
.51705 .31215 m .57557 .34331 L .5578 .36945 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.536 .51021 m .54165 .53948 L .5055 .54225 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.60101 .41164 m .5578 .36945 L .57557 .34331 L p
1 g
F P
s
P
p
.002 w
.46916 .54159 m .46696 .53154 L .50139 .52233 L p
1 g
F P
s
P
p
.002 w
.50139 .52233 m .5055 .54225 L .46916 .54159 L p
1 g
F P
s
P
p
.002 w
.49004 .3724 m .43889 .36165 L .4459 .32876 L p
1 g
F P
s
P
p
.002 w
.4459 .32876 m .50373 .3406 L .49004 .3724 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.5055 .54225 m .50139 .52233 L .536 .51021 L p
1 g
F P
s
P
p
.002 w
.57627 .43521 m .6005 .47918 L .56946 .49564 L p
1 g
F P
s
P
p
.002 w
.6005 .47918 m .57627 .43521 L .60101 .41164 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.43052 .43386 m .39921 .43653 L .39338 .40099 L p
1 g
F P
s
P
p
.002 w
.39338 .40099 m .43369 .39712 L .43052 .43386 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43071 .50541 m .41992 .50612 L .40816 .47203 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.46696 .53154 m .46123 .5219 L .49018 .50313 L p
1 g
F P
s
P
p
.002 w
.49018 .50313 m .50139 .52233 L .46696 .53154 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.5578 .36945 m .60101 .41164 L .57627 .43521 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.40816 .47203 m .42952 .47042 L .43071 .50541 L p
1 g
F P
s
P
p
.002 w
.42952 .47042 m .40816 .47203 L .39921 .43653 L p
1 g
F P
s
P
p
.002 w
.39921 .43653 m .43052 .43386 L .42952 .47042 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.46123 .5219 m .4526 .51377 L .47308 .4869 L p
1 g
F P
s
P
p
.002 w
.47308 .4869 m .49018 .50313 L .46123 .5219 L p
1 g
F P
s
P
p
.002 w
.56946 .49564 m .54885 .45893 L .57627 .43521 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47651 .40638 m .43369 .39712 L .43889 .36165 L p
1 g
F P
s
P
p
.002 w
.43889 .36165 m .49004 .3724 L .47651 .40638 L p
1 g
F P
s
P
p
.002 w
.50139 .52233 m .49018 .50313 L .51977 .48187 L p
1 g
F P
s
P
p
.002 w
.51977 .48187 m .536 .51021 L .50139 .52233 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.53788 .39799 m .49004 .3724 L .50373 .3406 L p
1 g
F P
s
P
p
.002 w
.50373 .3406 m .5578 .36945 L .53788 .39799 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57627 .43521 m .53788 .39799 L .5578 .36945 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45204 .47556 m .42952 .47042 L .43052 .43386 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.53788 .39799 m .57627 .43521 L .54885 .45893 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.46368 .44122 m .43052 .43386 L .43369 .39712 L p
1 g
F P
s
P
p
.002 w
.43369 .39712 m .47651 .40638 L .46368 .44122 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.43052 .43386 m .46368 .44122 L .45204 .47556 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.51657 .42786 m .47651 .40638 L .49004 .3724 L p
1 g
F P
s
P
p
.002 w
.49004 .3724 m .53788 .39799 L .51657 .42786 L p
1 g
F P
s
P
p
.002 w
.54885 .45893 m .51657 .42786 L .53788 .39799 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.49468 .45789 m .46368 .44122 L .47651 .40638 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47651 .40638 m .51657 .42786 L .49468 .45789 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.004 w
.40659 .58197 m
.4118 .57353 L
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .23243 .56317 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39463 .60137 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.537209)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.537209)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45987 .43635 m .48456 .46122 L .50168 .4385 L p
1 g
F P
s
P
p
.002 w
.50168 .4385 m .48261 .41926 L .45987 .43635 L p
1 g
F P
s
P
p
.002 w
.52545 .45131 m .50168 .4385 L .48456 .46122 L p
1 g
F P
s
P
p
.002 w
.48261 .41926 m .50168 .4385 L .51875 .41561 L p
1 g
F P
s
P
p
.002 w
.50168 .4385 m .52545 .45131 L .53499 .42432 L p
1 g
F P
s
P
p
.002 w
.53499 .42432 m .51875 .41561 L .50168 .4385 L p
1 g
F P
s
P
p
.002 w
.44367 .40567 m .45987 .43635 L .48261 .41926 L p
1 g
F P
s
P
p
.002 w
.48261 .41926 m .47017 .3955 L .44367 .40567 L p
1 g
F P
s
P
p
.002 w
.47017 .3955 m .48261 .41926 L .50573 .40246 L p
1 g
F P
s
P
p
.002 w
.51875 .41561 m .50573 .40246 L .48261 .41926 L p
1 g
F P
s
P
p
.002 w
.50573 .40246 m .51875 .41561 L .53544 .39297 L p
1 g
F P
s
P
p
.002 w
.51875 .41561 m .53499 .42432 L .54372 .39738 L p
1 g
F P
s
P
p
.002 w
.54372 .39738 m .53544 .39297 L .51875 .41561 L p
1 g
F P
s
P
p
.002 w
.50573 .40246 m .4973 .38622 L .47017 .3955 L p
1 g
F P
s
P
p
.002 w
.4973 .38622 m .50573 .40246 L .52882 .38627 L p
1 g
F P
s
P
p
.002 w
.53544 .39297 m .52882 .38627 L .50573 .40246 L p
1 g
F P
s
P
p
.002 w
.48456 .46122 m .51527 .47785 L .52545 .45131 L p
1 g
F P
s
P
p
.002 w
.55155 .45634 m .52545 .45131 L .51527 .47785 L p
1 g
F P
s
P
p
.002 w
.52545 .45131 m .55155 .45634 L .5528 .42767 L p
1 g
F P
s
P
p
.002 w
.5528 .42767 m .53499 .42432 L .52545 .45131 L p
1 g
F P
s
P
p
.002 w
.43793 .45344 m .46768 .48337 L .48456 .46122 L p
1 g
F P
s
P
p
.002 w
.48456 .46122 m .45987 .43635 L .43793 .45344 L p
1 g
F P
s
P
p
.002 w
.51527 .47785 m .48456 .46122 L .46768 .48337 L p
1 g
F P
s
P
p
.002 w
.53499 .42432 m .5528 .42767 L .55278 .39904 L p
1 g
F P
s
P
p
.002 w
.55278 .39904 m .54372 .39738 L .53499 .42432 L p
1 g
F P
s
P
p
.002 w
.41828 .41654 m .43793 .45344 L .45987 .43635 L p
1 g
F P
s
P
p
.002 w
.45987 .43635 m .44367 .40567 L .41828 .41654 L p
1 g
F P
s
P
p
.002 w
.4657 .36962 m .47017 .3955 L .4973 .38622 L p
1 g
F P
s
P
p
.002 w
.4973 .38622 m .49436 .36856 L .4657 .36962 L p
1 g
F P
s
P
p
.002 w
.52882 .38627 m .52457 .378 L .4973 .38622 L p
1 g
F P
s
P
p
.002 w
.49436 .36856 m .4973 .38622 L .52457 .378 L p
1 g
F P
s
P
p
.002 w
.43767 .37216 m .44367 .40567 L .47017 .3955 L p
1 g
F P
s
P
p
.002 w
.47017 .3955 m .4657 .36962 L .43767 .37216 L p
1 g
F P
s
P
p
.002 w
.46768 .48337 m .50463 .50348 L .51527 .47785 L p
1 g
F P
s
P
p
.002 w
.54903 .48453 m .51527 .47785 L .50463 .50348 L p
1 g
F P
s
P
p
.002 w
.51527 .47785 m .54903 .48453 L .55155 .45634 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .52882 .38627 L .53544 .39297 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .53544 .39297 L .54372 .39738 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .52457 .378 L .52882 .38627 L closepath p
1 g
F P
s
P
p
.002 w
.57033 .42526 m .5528 .42767 L .55155 .45634 L p
1 g
F P
s
P
p
.002 w
.5528 .42767 m .57033 .42526 L .56166 .39776 L p
1 g
F P
s
P
p
.002 w
.56166 .39776 m .55278 .39904 L .5528 .42767 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .54372 .39738 L .55278 .39904 L closepath p
1 g
F P
s
P
p
.002 w
.57732 .45299 m .55155 .45634 L .54903 .48453 L p
1 g
F P
s
P
p
.002 w
.55155 .45634 m .57732 .45299 L .57033 .42526 L p
1 g
F P
s
P
p
.002 w
.52457 .378 m .52313 .36902 L .49436 .36856 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .52313 .36902 L .52457 .378 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .55278 .39904 L .56166 .39776 L closepath p
1 g
F P
s
P
p
.002 w
.41082 .37619 m .41828 .41654 L .44367 .40567 L p
1 g
F P
s
P
p
.002 w
.44367 .40567 m .43767 .37216 L .41082 .37619 L p
1 g
F P
s
P
p
.002 w
.4172 .47021 m .45136 .50453 L .46768 .48337 L p
1 g
F P
s
P
p
.002 w
.46768 .48337 m .43793 .45344 L .4172 .47021 L p
1 g
F P
s
P
p
.002 w
.50463 .50348 m .46768 .48337 L .45136 .50453 L p
1 g
F P
s
P
p
.002 w
.46978 .34424 m .4657 .36962 L .49436 .36856 L p
1 g
F P
s
P
p
.002 w
.49436 .36856 m .49728 .35132 L .46978 .34424 L p
1 g
F P
s
P
p
.002 w
.49728 .35132 m .49436 .36856 L .52313 .36902 L p
1 g
F P
s
P
p
.002 w
.52313 .36902 m .52467 .36029 L .49728 .35132 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .52467 .36029 L .52313 .36902 L closepath p
1 g
F P
s
P
p
.002 w
.39451 .42793 m .4172 .47021 L .43793 .45344 L p
1 g
F P
s
P
p
.002 w
.43793 .45344 m .41828 .41654 L .39451 .42793 L p
1 g
F P
s
P
p
.002 w
.56942 .39365 m .56166 .39776 L .57033 .42526 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .56166 .39776 L .56942 .39365 L closepath p
1 g
F P
s
P
p
.002 w
.44271 .3392 m .43767 .37216 L .4657 .36962 L p
1 g
F P
s
P
p
.002 w
.4657 .36962 m .46978 .34424 L .44271 .3392 L p
1 g
F P
s
P
p
.002 w
.58573 .41728 m .57033 .42526 L .57732 .45299 L p
1 g
F P
s
P
p
.002 w
.57033 .42526 m .58573 .41728 L .56942 .39365 L p
1 g
F P
s
P
p
.002 w
.50463 .50348 m .54527 .51171 L .54903 .48453 L p
1 g
F P
s
P
p
.002 w
.58246 .48042 m .54903 .48453 L .54527 .51171 L p
1 g
F P
s
P
p
.002 w
.54903 .48453 m .58246 .48042 L .57732 .45299 L p
1 g
F P
s
P
p
.002 w
.45136 .50453 m .49373 .52768 L .50463 .50348 L p
1 g
F P
s
P
p
.002 w
.54527 .51171 m .50463 .50348 L .49373 .52768 L p
1 g
F P
s
P
p
.002 w
.50582 .33634 m .49728 .35132 L .52467 .36029 L p
1 g
F P
s
P
p
.002 w
.52467 .36029 m .52907 .35276 L .50582 .33634 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .52907 .35276 L .52467 .36029 L closepath p
1 g
F P
s
P
p
.002 w
.57521 .38713 m .56942 .39365 L .58573 .41728 L p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .56942 .39365 L .57521 .38713 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .57521 .38713 L .57837 .37891 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .57837 .37891 L .57855 .36985 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .57855 .36985 L .5757 .36096 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .5757 .36096 L .57013 .35323 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .57013 .35323 L .56244 .34751 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .56244 .34751 L .5535 .34444 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .5535 .34444 L .5443 .34435 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .5443 .34435 L .53585 .34724 L closepath p
1 g
F P
s
P
p
.002 w
.55147 .37098 m .53585 .34724 L .52907 .35276 L closepath p
1 g
F P
s
P
p
.002 w
.48217 .32206 m .46978 .34424 L .49728 .35132 L p
1 g
F P
s
P
p
.002 w
.49728 .35132 m .50582 .33634 L .48217 .32206 L p
1 g
F P
s
P
p
.002 w
.60006 .44145 m .57732 .45299 L .58246 .48042 L p
1 g
F P
s
P
p
.002 w
.57732 .45299 m .60006 .44145 L .58573 .41728 L p
1 g
F P
s
P
p
.002 w
.38569 .38164 m .39451 .42793 L .41828 .41654 L p
1 g
F P
s
P
p
.002 w
.41828 .41654 m .41082 .37619 L .38569 .38164 L p
1 g
F P
s
P
p
.002 w
.51917 .32528 m .50582 .33634 L .52907 .35276 L p
1 g
F P
s
P
p
.002 w
.52907 .35276 m .53585 .34724 L .51917 .32528 L p
1 g
F P
s
P
p
.002 w
.4166 .33635 m .41082 .37619 L .43767 .37216 L p
1 g
F P
s
P
p
.002 w
.43767 .37216 m .44271 .3392 L .4166 .33635 L p
1 g
F P
s
P
p
.002 w
.5973 .4045 m .58573 .41728 L .60006 .44145 L p
1 g
F P
s
P
p
.002 w
.58573 .41728 m .5973 .4045 L .57521 .38713 L p
1 g
F P
s
P
p
.002 w
.57837 .37891 m .57521 .38713 L .5973 .4045 L p
1 g
F P
s
P
p
.002 w
.3981 .48632 m .43592 .52427 L .45136 .50453 L p
1 g
F P
s
P
p
.002 w
.45136 .50453 m .4172 .47021 L .3981 .48632 L p
1 g
F P
s
P
p
.002 w
.49373 .52768 m .45136 .50453 L .43592 .52427 L p
1 g
F P
s
P
p
.002 w
.53592 .31943 m .51917 .32528 L .53585 .34724 L p
1 g
F P
s
P
p
.002 w
.53585 .34724 m .5443 .34435 L .53592 .31943 L p
1 g
F P
s
P
p
.002 w
.45856 .31025 m .44271 .3392 L .46978 .34424 L p
1 g
F P
s
P
p
.002 w
.46978 .34424 m .48217 .32206 L .45856 .31025 L p
1 g
F P
s
P
p
.002 w
.37286 .43962 m .3981 .48632 L .4172 .47021 L p
1 g
F P
s
P
p
.002 w
.4172 .47021 m .39451 .42793 L .37286 .43962 L p
1 g
F P
s
P
p
.002 w
.49373 .52768 m .54034 .53734 L .54527 .51171 L p
1 g
F P
s
P
p
.002 w
.58564 .50702 m .54527 .51171 L .54034 .53734 L p
1 g
F P
s
P
p
.002 w
.54527 .51171 m .58564 .50702 L .58246 .48042 L p
1 g
F P
s
P
p
.002 w
.5973 .4045 m .60371 .38822 L .57837 .37891 L p
1 g
F P
s
P
p
.002 w
.57855 .36985 m .57837 .37891 L .60371 .38822 L p
1 g
F P
s
P
p
.002 w
.50172 .30557 m .48217 .32206 L .50582 .33634 L p
1 g
F P
s
P
p
.002 w
.50582 .33634 m .51917 .32528 L .50172 .30557 L p
1 g
F P
s
P
p
.002 w
.61212 .46568 m .58246 .48042 L .58564 .50702 L p
1 g
F P
s
P
p
.002 w
.58246 .48042 m .61212 .46568 L .60006 .44145 L p
1 g
F P
s
P
p
.002 w
.55425 .31951 m .53592 .31943 L .5443 .34435 L p
1 g
F P
s
P
p
.002 w
.5443 .34435 m .5535 .34444 L .55425 .31951 L p
1 g
F P
s
P
p
.002 w
.43592 .52427 m .48275 .54997 L .49373 .52768 L p
1 g
F P
s
P
p
.002 w
.54034 .53734 m .49373 .52768 L .48275 .54997 L p
1 g
F P
s
P
p
.002 w
.60371 .38822 m .60418 .37021 L .57855 .36985 L p
1 g
F P
s
P
p
.002 w
.5757 .36096 m .57855 .36985 L .60418 .37021 L p
1 g
F P
s
P
p
.002 w
.61728 .42275 m .60006 .44145 L .61212 .46568 L p
1 g
F P
s
P
p
.002 w
.60006 .44145 m .61728 .42275 L .5973 .4045 L p
1 g
F P
s
P
p
.002 w
.60371 .38822 m .5973 .4045 L .61728 .42275 L p
1 g
F P
s
P
p
.002 w
.57211 .32558 m .55425 .31951 L .5535 .34444 L p
1 g
F P
s
P
p
.002 w
.5535 .34444 m .56244 .34751 L .57211 .32558 L p
1 g
F P
s
P
p
.002 w
.60418 .37021 m .59858 .35247 L .5757 .36096 L p
1 g
F P
s
P
p
.002 w
.57013 .35323 m .5757 .36096 L .59858 .35247 L p
1 g
F P
s
P
p
.002 w
.58747 .337 m .57211 .32558 L .56244 .34751 L p
1 g
F P
s
P
p
.002 w
.56244 .34751 m .57013 .35323 L .58747 .337 L p
1 g
F P
s
P
p
.002 w
.59858 .35247 m .58747 .337 L .57013 .35323 L p
1 g
F P
s
P
p
.002 w
.39202 .33582 m .38569 .38164 L .41082 .37619 L p
1 g
F P
s
P
p
.002 w
.41082 .37619 m .4166 .33635 L .39202 .33582 L p
1 g
F P
s
P
p
.002 w
.36284 .38845 m .37286 .43962 L .39451 .42793 L p
1 g
F P
s
P
p
.002 w
.39451 .42793 m .38569 .38164 L .36284 .38845 L p
1 g
F P
s
P
p
.002 w
.52644 .29674 m .50172 .30557 L .51917 .32528 L p
1 g
F P
s
P
p
.002 w
.51917 .32528 m .53592 .31943 L .52644 .29674 L p
1 g
F P
s
P
p
.002 w
.43548 .30122 m .4166 .33635 L .44271 .3392 L p
1 g
F P
s
P
p
.002 w
.44271 .3392 m .45856 .31025 L .43548 .30122 L p
1 g
F P
s
P
p
.002 w
.48385 .28858 m .45856 .31025 L .48217 .32206 L p
1 g
F P
s
P
p
.002 w
.48217 .32206 m .50172 .30557 L .48385 .28858 L p
1 g
F P
s
P
p
.002 w
.61728 .42275 m .62695 .39878 L .60371 .38822 L p
1 g
F P
s
P
p
.002 w
.60418 .37021 m .60371 .38822 L .62695 .39878 L p
1 g
F P
s
P
p
.002 w
.38108 .50145 m .4217 .54216 L .43592 .52427 L p
1 g
F P
s
P
p
.002 w
.43592 .52427 m .3981 .48632 L .38108 .50145 L p
1 g
F P
s
P
p
.002 w
.48275 .54997 m .43592 .52427 L .4217 .54216 L p
1 g
F P
s
P
p
.002 w
.48275 .54997 m .53428 .56087 L .54034 .53734 L p
1 g
F P
s
P
p
.002 w
.58674 .53225 m .54034 .53734 L .53428 .56087 L p
1 g
F P
s
P
p
.002 w
.54034 .53734 m .58674 .53225 L .58564 .50702 L p
1 g
F P
s
P
p
.002 w
.62159 .4895 m .58564 .50702 L .58674 .53225 L p
1 g
F P
s
P
p
.002 w
.58564 .50702 m .62159 .4895 L .61212 .46568 L p
1 g
F P
s
P
p
.002 w
.35385 .4514 m .38108 .50145 L .3981 .48632 L p
1 g
F P
s
P
p
.002 w
.3981 .48632 m .37286 .43962 L .35385 .4514 L p
1 g
F P
s
P
p
.002 w
.55364 .29673 m .52644 .29674 L .53592 .31943 L p
1 g
F P
s
P
p
.002 w
.53592 .31943 m .55425 .31951 L .55364 .29673 L p
1 g
F P
s
P
p
.002 w
.63472 .44155 m .61212 .46568 L .62159 .4895 L p
1 g
F P
s
P
p
.002 w
.61212 .46568 m .63472 .44155 L .61728 .42275 L p
1 g
F P
s
P
p
.002 w
.62695 .39878 m .61728 .42275 L .63472 .44155 L p
1 g
F P
s
P
p
.002 w
.62695 .39878 m .62781 .3721 L .60418 .37021 L p
1 g
F P
s
P
p
.002 w
.59858 .35247 m .60418 .37021 L .62781 .3721 L p
1 g
F P
s
P
p
.002 w
.4217 .54216 m .47192 .56983 L .48275 .54997 L p
1 g
F P
s
P
p
.002 w
.53428 .56087 m .48275 .54997 L .47192 .56983 L p
1 g
F P
s
P
p
.002 w
.58023 .30569 m .55364 .29673 L .55425 .31951 L p
1 g
F P
s
P
p
.002 w
.55425 .31951 m .57211 .32558 L .58023 .30569 L p
1 g
F P
s
P
p
.002 w
.36953 .3377 m .36284 .38845 L .38569 .38164 L p
1 g
F P
s
P
p
.002 w
.38569 .38164 m .39202 .33582 L .36953 .3377 L p
1 g
F P
s
P
p
.002 w
.51604 .27685 m .48385 .28858 L .50172 .30557 L p
1 g
F P
s
P
p
.002 w
.50172 .30557 m .52644 .29674 L .51604 .27685 L p
1 g
F P
s
P
p
.002 w
.62781 .3721 m .61958 .34571 L .59858 .35247 L p
1 g
F P
s
P
p
.002 w
.58747 .337 m .59858 .35247 L .61958 .34571 L p
1 g
F P
s
P
p
.002 w
.41343 .29526 m .39202 .33582 L .4166 .33635 L p
1 g
F P
s
P
p
.002 w
.4166 .33635 m .43548 .30122 L .41343 .29526 L p
1 g
F P
s
P
p
.002 w
.4659 .27476 m .43548 .30122 L .45856 .31025 L p
1 g
F P
s
P
p
.002 w
.45856 .31025 m .48385 .28858 L .4659 .27476 L p
1 g
F P
s
P
p
.002 w
.6031 .32267 m .58023 .30569 L .57211 .32558 L p
1 g
F P
s
P
p
.002 w
.57211 .32558 m .58747 .337 L .6031 .32267 L p
1 g
F P
s
P
p
.002 w
.34285 .39654 m .35385 .4514 L .37286 .43962 L p
1 g
F P
s
P
p
.002 w
.37286 .43962 m .36284 .38845 L .34285 .39654 L p
1 g
F P
s
P
p
.002 w
.61958 .34571 m .6031 .32267 L .58747 .337 L p
1 g
F P
s
P
p
.002 w
.63472 .44155 m .64755 .4104 L .62695 .39878 L p
1 g
F P
s
P
p
.002 w
.62781 .3721 m .62695 .39878 L .64755 .4104 L p
1 g
F P
s
P
p
.002 w
.53428 .56087 m .58566 .55553 L .58674 .53225 L p
1 g
F P
s
P
p
.002 w
.62821 .51241 m .58674 .53225 L .58566 .55553 L p
1 g
F P
s
P
p
.002 w
.58674 .53225 m .62821 .51241 L .62159 .4895 L p
1 g
F P
s
P
p
.002 w
.47192 .56983 m .52718 .58173 L .53428 .56087 L p
1 g
F P
s
P
p
.002 w
.58566 .55553 m .53428 .56087 L .52718 .58173 L p
1 g
F P
s
P
p
.002 w
.64915 .46053 m .62159 .4895 L .62821 .51241 L p
1 g
F P
s
P
p
.002 w
.62159 .4895 m .64915 .46053 L .63472 .44155 L p
1 g
F P
s
P
p
.002 w
.64755 .4104 m .63472 .44155 L .64915 .46053 L p
1 g
F P
s
P
p
.002 w
.55164 .27668 m .51604 .27685 L .52644 .29674 L p
1 g
F P
s
P
p
.002 w
.52644 .29674 m .55364 .29673 L .55164 .27668 L p
1 g
F P
s
P
p
.002 w
.36658 .51523 m .40905 .55775 L .4217 .54216 L p
1 g
F P
s
P
p
.002 w
.4217 .54216 m .38108 .50145 L .36658 .51523 L p
1 g
F P
s
P
p
.002 w
.47192 .56983 m .4217 .54216 L .40905 .55775 L p
1 g
F P
s
P
p
.002 w
.33801 .46302 m .36658 .51523 L .38108 .50145 L p
1 g
F P
s
P
p
.002 w
.38108 .50145 m .35385 .4514 L .33801 .46302 L p
1 g
F P
s
P
p
.002 w
.64755 .4104 m .64885 .37554 L .62781 .3721 L p
1 g
F P
s
P
p
.002 w
.61958 .34571 m .62781 .3721 L .64885 .37554 L p
1 g
F P
s
P
p
.002 w
.40905 .55775 m .46147 .58674 L .47192 .56983 L p
1 g
F P
s
P
p
.002 w
.52718 .58173 m .47192 .56983 L .46147 .58674 L p
1 g
F P
s
P
p
.002 w
.5049 .26031 m .4659 .27476 L .48385 .28858 L p
1 g
F P
s
P
p
.002 w
.48385 .28858 m .51604 .27685 L .5049 .26031 L p
1 g
F P
s
P
p
.002 w
.34973 .34206 m .34285 .39654 L .36284 .38845 L p
1 g
F P
s
P
p
.002 w
.36284 .38845 m .36953 .3377 L .34973 .34206 L p
1 g
F P
s
P
p
.002 w
.39296 .29263 m .36953 .3377 L .39202 .33582 L p
1 g
F P
s
P
p
.002 w
.39202 .33582 m .41343 .29526 L .39296 .29263 L p
1 g
F P
s
P
p
.002 w
.58654 .28836 m .55164 .27668 L .55364 .29673 L p
1 g
F P
s
P
p
.002 w
.55364 .29673 m .58023 .30569 L .58654 .28836 L p
1 g
F P
s
P
p
.002 w
.44829 .26457 m .41343 .29526 L .43548 .30122 L p
1 g
F P
s
P
p
.002 w
.43548 .30122 m .4659 .27476 L .44829 .26457 L p
1 g
F P
s
P
p
.002 w
.64885 .37554 m .63818 .34092 L .61958 .34571 L p
1 g
F P
s
P
p
.002 w
.6031 .32267 m .61958 .34571 L .63818 .34092 L p
1 g
F P
s
P
p
.002 w
.3263 .40578 m .33801 .46302 L .35385 .4514 L p
1 g
F P
s
P
p
.002 w
.35385 .4514 m .34285 .39654 L .3263 .40578 L p
1 g
F P
s
P
p
.002 w
.61659 .31065 m .58654 .28836 L .58023 .30569 L p
1 g
F P
s
P
p
.002 w
.58023 .30569 m .6031 .32267 L .61659 .31065 L p
1 g
F P
s
P
p
.002 w
.64915 .46053 m .66495 .42288 L .64755 .4104 L p
1 g
F P
s
P
p
.002 w
.64885 .37554 m .64755 .4104 L .66495 .42288 L p
1 g
F P
s
P
p
.002 w
.63818 .34092 m .61659 .31065 L .6031 .32267 L p
1 g
F P
s
P
p
.002 w
.52718 .58173 m .58233 .57628 L .58566 .55553 L p
1 g
F P
s
P
p
.002 w
.6317 .53386 m .58566 .55553 L .58233 .57628 L p
1 g
F P
s
P
p
.002 w
.58566 .55553 m .6317 .53386 L .62821 .51241 L p
1 g
F P
s
P
p
.002 w
.66015 .47929 m .62821 .51241 L .6317 .53386 L p
1 g
F P
s
P
p
.002 w
.62821 .51241 m .66015 .47929 L .64915 .46053 L p
1 g
F P
s
P
p
.002 w
.66495 .42288 m .64915 .46053 L .66015 .47929 L p
1 g
F P
s
P
p
.002 w
.46147 .58674 m .51914 .59935 L .52718 .58173 L p
1 g
F P
s
P
p
.002 w
.58233 .57628 m .52718 .58173 L .51914 .59935 L p
1 g
F P
s
P
p
.002 w
.54822 .25995 m .5049 .26031 L .51604 .27685 L p
1 g
F P
s
P
p
.002 w
.51604 .27685 m .55164 .27668 L .54822 .25995 L p
1 g
F P
s
P
p
.002 w
.35504 .52729 m .39831 .57058 L .40905 .55775 L p
1 g
F P
s
P
p
.002 w
.40905 .55775 m .36658 .51523 L .35504 .52729 L p
1 g
F P
s
P
p
.002 w
.46147 .58674 m .40905 .55775 L .39831 .57058 L p
1 g
F P
s
P
p
.002 w
.32584 .47419 m .35504 .52729 L .36658 .51523 L p
1 g
F P
s
P
p
.002 w
.36658 .51523 m .33801 .46302 L .32584 .47419 L p
1 g
F P
s
P
p
.002 w
.66495 .42288 m .66672 .38052 L .64885 .37554 L p
1 g
F P
s
P
p
.002 w
.63818 .34092 m .64885 .37554 L .66672 .38052 L p
1 g
F P
s
P
p
.002 w
.49323 .24768 m .44829 .26457 L .4659 .27476 L p
1 g
F P
s
P
p
.002 w
.4659 .27476 m .5049 .26031 L .49323 .24768 L p
1 g
F P
s
P
p
.002 w
.37462 .29358 m .34973 .34206 L .36953 .3377 L p
1 g
F P
s
P
p
.002 w
.36953 .3377 m .39296 .29263 L .37462 .29358 L p
1 g
F P
s
P
p
.002 w
.43142 .25841 m .39296 .29263 L .41343 .29526 L p
1 g
F P
s
P
p
.002 w
.41343 .29526 m .44829 .26457 L .43142 .25841 L p
1 g
F P
s
P
p
.002 w
.33322 .34891 m .3263 .40578 L .34285 .39654 L p
1 g
F P
s
P
p
.002 w
.34285 .39654 m .34973 .34206 L .33322 .34891 L p
1 g
F P
s
P
p
.002 w
.39831 .57058 m .45166 .60016 L .46147 .58674 L p
1 g
F P
s
P
p
.002 w
.51914 .59935 m .46147 .58674 L .45166 .60016 L p
1 g
F P
s
P
p
.002 w
.59082 .27412 m .54822 .25995 L .55164 .27668 L p
1 g
F P
s
P
p
.002 w
.55164 .27668 m .58654 .28836 L .59082 .27412 L p
1 g
F P
s
P
p
.002 w
.66672 .38052 m .65384 .33831 L .63818 .34092 L p
1 g
F P
s
P
p
.002 w
.61659 .31065 m .63818 .34092 L .65384 .33831 L p
1 g
F P
s
P
p
.002 w
.66015 .47929 m .6786 .43597 L .66495 .42288 L p
1 g
F P
s
P
p
.002 w
.66672 .38052 m .66495 .42288 L .6786 .43597 L p
1 g
F P
s
P
p
.002 w
.31376 .41602 m .32584 .47419 L .33801 .46302 L p
1 g
F P
s
P
p
.002 w
.33801 .46302 m .3263 .40578 L .31376 .41602 L p
1 g
F P
s
P
p
.002 w
.62751 .30133 m .59082 .27412 L .58654 .28836 L p
1 g
F P
s
P
p
.002 w
.58654 .28836 m .61659 .31065 L .62751 .30133 L p
1 g
F P
s
P
p
.002 w
.65384 .33831 m .62751 .30133 L .61659 .31065 L p
1 g
F P
s
P
p
.002 w
.58233 .57628 m .63186 .5533 L .6317 .53386 L p
1 g
F P
s
P
p
.002 w
.66731 .49738 m .6317 .53386 L .63186 .5533 L p
1 g
F P
s
P
p
.002 w
.6317 .53386 m .66731 .49738 L .66015 .47929 L p
1 g
F P
s
P
p
.002 w
.51914 .59935 m .57673 .5939 L .58233 .57628 L p
1 g
F P
s
P
p
.002 w
.63186 .5533 m .58233 .57628 L .57673 .5939 L p
1 g
F P
s
P
p
.002 w
.6786 .43597 m .66015 .47929 L .66731 .49738 L p
1 g
F P
s
P
p
.002 w
.45166 .60016 m .51032 .61315 L .51914 .59935 L p
1 g
F P
s
P
p
.002 w
.57673 .5939 m .51914 .59935 L .51032 .61315 L p
1 g
F P
s
P
p
.002 w
.54338 .24713 m .49323 .24768 L .5049 .26031 L p
1 g
F P
s
P
p
.002 w
.5049 .26031 m .54822 .25995 L .54338 .24713 L p
1 g
F P
s
P
p
.002 w
.3469 .53725 m .38985 .58019 L .39831 .57058 L p
1 g
F P
s
P
p
.002 w
.39831 .57058 m .35504 .52729 L .3469 .53725 L p
1 g
F P
s
P
p
.002 w
.45166 .60016 m .39831 .57058 L .38985 .58019 L p
1 g
F P
s
P
p
.002 w
.48129 .23948 m .43142 .25841 L .44829 .26457 L p
1 g
F P
s
P
p
.002 w
.44829 .26457 m .49323 .24768 L .48129 .23948 L p
1 g
F P
s
P
p
.002 w
.6786 .43597 m .68083 .38702 L .66672 .38052 L p
1 g
F P
s
P
p
.002 w
.65384 .33831 m .66672 .38052 L .68083 .38702 L p
1 g
F P
s
P
p
.002 w
.31787 .48464 m .3469 .53725 L .35504 .52729 L p
1 g
F P
s
P
p
.002 w
.35504 .52729 m .32584 .47419 L .31787 .48464 L p
1 g
F P
s
P
p
.002 w
.35898 .29826 m .33322 .34891 L .34973 .34206 L p
1 g
F P
s
P
p
.002 w
.34973 .34206 m .37462 .29358 L .35898 .29826 L p
1 g
F P
s
P
p
.002 w
.41578 .25667 m .37462 .29358 L .39296 .29263 L p
1 g
F P
s
P
p
.002 w
.39296 .29263 m .43142 .25841 L .41578 .25667 L p
1 g
F P
s
P
p
.002 w
.32061 .35823 m .31376 .41602 L .3263 .40578 L p
1 g
F P
s
P
p
.002 w
.3263 .40578 m .33322 .34891 L .32061 .35823 L p
1 g
F P
s
P
p
.002 w
.38985 .58019 m .44275 .60959 L .45166 .60016 L p
1 g
F P
s
P
p
.002 w
.51032 .61315 m .45166 .60016 L .44275 .60959 L p
1 g
F P
s
P
p
.002 w
.59283 .26351 m .54338 .24713 L .54822 .25995 L p
1 g
F P
s
P
p
.002 w
.54822 .25995 m .59082 .27412 L .59283 .26351 L p
1 g
F P
s
P
p
.002 w
.66731 .49738 m .68798 .4494 L .6786 .43597 L p
1 g
F P
s
P
p
.002 w
.68083 .38702 m .6786 .43597 L .68798 .4494 L p
1 g
F P
s
P
p
.002 w
.68083 .38702 m .66599 .33806 L .65384 .33831 L p
1 g
F P
s
P
p
.002 w
.62751 .30133 m .65384 .33831 L .66599 .33806 L p
1 g
F P
s
P
p
.002 w
.30578 .42705 m .31787 .48464 L .32584 .47419 L p
1 g
F P
s
P
p
.002 w
.32584 .47419 m .31376 .41602 L .30578 .42705 L p
1 g
F P
s
P
p
.002 w
.63186 .5533 m .67024 .51433 L .66731 .49738 L p
1 g
F P
s
P
p
.002 w
.68798 .4494 m .66731 .49738 L .67024 .51433 L p
1 g
F P
s
P
p
.002 w
.57673 .5939 m .62848 .57016 L .63186 .5533 L p
1 g
F P
s
P
p
.002 w
.67024 .51433 m .63186 .5533 L .62848 .57016 L p
1 g
F P
s
P
p
.002 w
.51032 .61315 m .56887 .6078 L .57673 .5939 L p
1 g
F P
s
P
p
.002 w
.62848 .57016 m .57673 .5939 L .56887 .6078 L p
1 g
F P
s
P
p
.002 w
.63546 .2951 m .59283 .26351 L .59082 .27412 L p
1 g
F P
s
P
p
.002 w
.59082 .27412 m .62751 .30133 L .63546 .2951 L p
1 g
F P
s
P
p
.002 w
.66599 .33806 m .63546 .2951 L .62751 .30133 L p
1 g
F P
s
P
p
.002 w
.44275 .60959 m .50086 .62257 L .51032 .61315 L p
1 g
F P
s
P
p
.002 w
.56887 .6078 m .51032 .61315 L .50086 .62257 L p
1 g
F P
s
P
p
.002 w
.53716 .23877 m .48129 .23948 L .49323 .24768 L p
1 g
F P
s
P
p
.002 w
.49323 .24768 m .54338 .24713 L .53716 .23877 L p
1 g
F P
s
P
p
.002 w
.46939 .23619 m .41578 .25667 L .43142 .25841 L p
1 g
F P
s
P
p
.002 w
.43142 .25841 m .48129 .23948 L .46939 .23619 L p
1 g
F P
s
P
p
.002 w
.40184 .25966 m .35898 .29826 L .37462 .29358 L p
1 g
F P
s
P
p
.002 w
.37462 .29358 m .41578 .25667 L .40184 .25966 L p
1 g
F P
s
P
p
.002 w
.34663 .30676 m .32061 .35823 L .33322 .34891 L p
1 g
F P
s
P
p
.002 w
.33322 .34891 m .35898 .29826 L .34663 .30676 L p
1 g
F P
s
P
p
.002 w
.34257 .54473 m .38402 .58615 L .38985 .58019 L p
1 g
F P
s
P
p
.002 w
.38985 .58019 m .3469 .53725 L .34257 .54473 L p
1 g
F P
s
P
p
.002 w
.44275 .60959 m .38985 .58019 L .38402 .58615 L p
1 g
F P
s
P
p
.002 w
.68798 .4494 m .69061 .39495 L .68083 .38702 L p
1 g
F P
s
P
p
.002 w
.66599 .33806 m .68083 .38702 L .69061 .39495 L p
1 g
F P
s
P
p
.002 w
.31454 .49404 m .34257 .54473 L .3469 .53725 L p
1 g
F P
s
P
p
.002 w
.3469 .53725 m .31787 .48464 L .31454 .49404 L p
1 g
F P
s
P
p
.002 w
.31243 .36991 m .30578 .42705 L .31376 .41602 L p
1 g
F P
s
P
p
.002 w
.31376 .41602 m .32061 .35823 L .31243 .36991 L p
1 g
F P
s
P
p
.002 w
.38402 .58615 m .43503 .61454 L .44275 .60959 L p
1 g
F P
s
P
p
.002 w
.50086 .62257 m .44275 .60959 L .43503 .61454 L p
1 g
F P
s
P
p
.002 w
.59238 .25701 m .53716 .23877 L .54338 .24713 L p
1 g
F P
s
P
p
.002 w
.54338 .24713 m .59283 .26351 L .59238 .25701 L p
1 g
F P
s
P
p
.002 w
.67024 .51433 m .69262 .46284 L .68798 .4494 L p
1 g
F P
s
P
p
.002 w
.69061 .39495 m .68798 .4494 L .69262 .46284 L p
1 g
F P
s
P
p
.002 w
.62848 .57016 m .66865 .52965 L .67024 .51433 L p
1 g
F P
s
P
p
.002 w
.69262 .46284 m .67024 .51433 L .66865 .52965 L p
1 g
F P
s
P
p
.002 w
.56887 .6078 m .62148 .58386 L .62848 .57016 L p
1 g
F P
s
P
p
.002 w
.66865 .52965 m .62848 .57016 L .62148 .58386 L p
1 g
F P
s
P
p
.002 w
.69061 .39495 m .67413 .34033 L .66599 .33806 L p
1 g
F P
s
P
p
.002 w
.63546 .2951 m .66599 .33806 L .67413 .34033 L p
1 g
F P
s
P
p
.002 w
.30284 .43864 m .31454 .49404 L .31787 .48464 L p
1 g
F P
s
P
p
.002 w
.31787 .48464 m .30578 .42705 L .30284 .43864 L p
1 g
F P
s
P
p
.002 w
.50086 .62257 m .55881 .61741 L .56887 .6078 L p
1 g
F P
s
P
p
.002 w
.62148 .58386 m .56887 .6078 L .55881 .61741 L p
1 g
F P
s
P
p
.002 w
.64003 .29232 m .59238 .25701 L .59283 .26351 L p
1 g
F P
s
P
p
.002 w
.59283 .26351 m .63546 .2951 L .64003 .29232 L p
1 g
F P
s
P
p
.002 w
.67413 .34033 m .64003 .29232 L .63546 .2951 L p
1 g
F P
s
P
p
.002 w
.52964 .23538 m .46939 .23619 L .48129 .23948 L p
1 g
F P
s
P
p
.002 w
.48129 .23948 m .53716 .23877 L .52964 .23538 L p
1 g
F P
s
P
p
.002 w
.43503 .61454 m .491 .62711 L .50086 .62257 L p
1 g
F P
s
P
p
.002 w
.55881 .61741 m .50086 .62257 L .491 .62711 L p
1 g
F P
s
P
p
.002 w
.45785 .23822 m .40184 .25966 L .41578 .25667 L p
1 g
F P
s
P
p
.002 w
.41578 .25667 m .46939 .23619 L .45785 .23822 L p
1 g
F P
s
P
p
.002 w
.39009 .26756 m .34663 .30676 L .35898 .29826 L p
1 g
F P
s
P
p
.002 w
.35898 .29826 m .40184 .25966 L .39009 .26756 L p
1 g
F P
s
P
p
.002 w
.33809 .31908 m .31243 .36991 L .32061 .35823 L p
1 g
F P
s
P
p
.002 w
.32061 .35823 m .34663 .30676 L .33809 .31908 L p
1 g
F P
s
P
p
.002 w
.69262 .46284 m .69553 .40419 L .69061 .39495 L p
1 g
F P
s
P
p
.002 w
.67413 .34033 m .69061 .39495 L .69553 .40419 L p
1 g
F P
s
P
p
.002 w
.34242 .54938 m .38115 .58806 L .38402 .58615 L p
1 g
F P
s
P
p
.002 w
.38402 .58615 m .34257 .54473 L .34242 .54938 L p
1 g
F P
s
P
p
.002 w
.43503 .61454 m .38402 .58615 L .38115 .58806 L p
1 g
F P
s
P
p
.002 w
.30921 .38376 m .30284 .43864 L .30578 .42705 L p
1 g
F P
s
P
p
.002 w
.30578 .42705 m .31243 .36991 L .30921 .38376 L p
1 g
F P
s
P
p
.002 w
.31624 .50207 m .34242 .54938 L .34257 .54473 L p
1 g
F P
s
P
p
.002 w
.34257 .54473 m .31454 .49404 L .31624 .50207 L p
1 g
F P
s
P
p
.002 w
.38115 .58806 m .42878 .61459 L .43503 .61454 L p
1 g
F P
s
P
p
.002 w
.491 .62711 m .43503 .61454 L .42878 .61459 L p
1 g
F P
s
P
p
.002 w
.58932 .25509 m .52964 .23538 L .53716 .23877 L p
1 g
F P
s
P
p
.002 w
.53716 .23877 m .59238 .25701 L .58932 .25509 L p
1 g
F P
s
P
p
.002 w
.66865 .52965 m .69209 .47593 L .69262 .46284 L p
1 g
F P
s
P
p
.002 w
.69553 .40419 m .69262 .46284 L .69209 .47593 L p
1 g
F P
s
P
p
.002 w
.62148 .58386 m .6623 .54281 L .66865 .52965 L p
1 g
F P
s
P
p
.002 w
.69209 .47593 m .66865 .52965 L .6623 .54281 L p
1 g
F P
s
P
p
.002 w
.55881 .61741 m .61082 .59383 L .62148 .58386 L p
1 g
F P
s
P
p
.002 w
.6623 .54281 m .62148 .58386 L .61082 .59383 L p
1 g
F P
s
P
p
.004 w
.2942 .43638 m
.30092 .43619 L
s
P
p
.004 w
.20416 .43895 m
.2942 .43638 L
s
P
p
.002 w
.491 .62711 m .54671 .6222 L .55881 .61741 L p
1 g
F P
s
P
p
.002 w
.61082 .59383 m .55881 .61741 L .54671 .6222 L p
1 g
F P
s
P
p
.002 w
.30535 .45047 m .31624 .50207 L .31454 .49404 L p
1 g
F P
s
P
p
.002 w
.31454 .49404 m .30284 .43864 L .30535 .45047 L p
1 g
F P
s
P
p
.002 w
.69553 .40419 m .67775 .34522 L .67413 .34033 L p
1 g
F P
s
P
p
.002 w
.64003 .29232 m .67413 .34033 L .67775 .34522 L p
1 g
F P
s
P
p
.002 w
.67775 .34522 m .64088 .29329 L .64003 .29232 L p
1 g
F P
s
P
p
.002 w
.64088 .29329 m .58932 .25509 L .59238 .25701 L p
1 g
F P
s
P
p
.002 w
.59238 .25701 m .64003 .29232 L .64088 .29329 L p
1 g
F P
s
P
p
.002 w
.52095 .23739 m .45785 .23822 L .46939 .23619 L p
1 g
F P
s
P
p
.002 w
.46939 .23619 m .52964 .23538 L .52095 .23739 L p
1 g
F P
s
P
p
.002 w
.42878 .61459 m .48096 .62632 L .491 .62711 L p
1 g
F P
s
P
p
.002 w
.54671 .6222 m .491 .62711 L .48096 .62632 L p
1 g
F P
s
P
p
.002 w
.44703 .24582 m .39009 .26756 L .40184 .25966 L p
1 g
F P
s
P
p
.002 w
.40184 .25966 m .45785 .23822 L .44703 .24582 L p
1 g
F P
s
P
p
.002 w
.38103 .28044 m .33809 .31908 L .34663 .30676 L p
1 g
F P
s
P
p
.002 w
.34663 .30676 m .39009 .26756 L .38103 .28044 L p
1 g
F P
s
P
p
.002 w
.33385 .33508 m .30921 .38376 L .31243 .36991 L p
1 g
F P
s
P
p
.002 w
.31243 .36991 m .33809 .31908 L .33385 .33508 L p
1 g
F P
s
P
p
.002 w
.69209 .47593 m .69513 .41457 L .69553 .40419 L p
1 g
F P
s
P
p
.002 w
.67775 .34522 m .69553 .40419 L .69513 .41457 L p
1 g
F P
s
P
p
.002 w
.31132 .39951 m .30535 .45047 L .30284 .43864 L p
1 g
F P
s
P
p
.002 w
.30284 .43864 m .30921 .38376 L .31132 .39951 L p
1 g
F P
s
P
p
.002 w
.34673 .55085 m .38151 .5856 L .38115 .58806 L p
1 g
F P
s
P
p
.002 w
.38115 .58806 m .34242 .54938 L .34673 .55085 L p
1 g
F P
s
P
p
.002 w
.42878 .61459 m .38115 .58806 L .38151 .5856 L p
1 g
F P
s
P
p
.002 w
.32326 .50841 m .34673 .55085 L .34242 .54938 L p
1 g
F P
s
P
p
.002 w
.34242 .54938 m .31624 .50207 L .32326 .50841 L p
1 g
F P
s
P
p
.002 w
.6623 .54281 m .68609 .48826 L .69209 .47593 L p
1 g
F P
s
P
p
.002 w
.69513 .41457 m .69209 .47593 L .68609 .48826 L p
1 g
F P
s
P
p
.002 w
.38151 .5856 m .42428 .60941 L .42878 .61459 L p
1 g
F P
s
P
p
.002 w
.48096 .62632 m .42878 .61459 L .42428 .60941 L p
1 g
F P
s
P
p
.002 w
.61082 .59383 m .6511 .55332 L .6623 .54281 L p
1 g
F P
s
P
p
.002 w
.68609 .48826 m .6623 .54281 L .6511 .55332 L p
1 g
F P
s
P
p
.002 w
.54671 .6222 m .59659 .59957 L .61082 .59383 L p
1 g
F P
s
P
p
.002 w
.6511 .55332 m .61082 .59383 L .59659 .59957 L p
1 g
F P
s
P
p
.002 w
.58357 .25811 m .52095 .23739 L .52964 .23538 L p
1 g
F P
s
P
p
.002 w
.52964 .23538 m .58932 .25509 L .58357 .25811 L p
1 g
F P
s
P
p
.002 w
.48096 .62632 m .53279 .62173 L .54671 .6222 L p
1 g
F P
s
P
p
.002 w
.59659 .59957 m .54671 .6222 L .53279 .62173 L p
1 g
F P
s
P
p
.002 w
.31357 .46221 m .32326 .50841 L .31624 .50207 L p
1 g
F P
s
P
p
.002 w
.31624 .50207 m .30535 .45047 L .31357 .46221 L p
1 g
F P
s
P
p
.002 w
.69513 .41457 m .67646 .35275 L .67775 .34522 L p
1 g
F P
s
P
p
.002 w
.64088 .29329 m .67775 .34522 L .67646 .35275 L p
1 g
F P
s
P
p
.002 w
.51129 .24509 m .44703 .24582 L .45785 .23822 L p
1 g
F P
s
P
p
.002 w
.45785 .23822 m .52095 .23739 L .51129 .24509 L p
1 g
F P
s
P
p
.002 w
.63772 .29824 m .58357 .25811 L .58932 .25509 L p
1 g
F P
s
P
p
.002 w
.58932 .25509 m .64088 .29329 L .63772 .29824 L p
1 g
F P
s
P
p
.002 w
.42428 .60941 m .47105 .61989 L .48096 .62632 L p
1 g
F P
s
P
p
.002 w
.53279 .62173 m .48096 .62632 L .47105 .61989 L p
1 g
F P
s
P
p
.002 w
.67646 .35275 m .63772 .29824 L .64088 .29329 L p
1 g
F P
s
P
p
.002 w
.43733 .25912 m .38103 .28044 L .39009 .26756 L p
1 g
F P
s
P
p
.002 w
.39009 .26756 m .44703 .24582 L .43733 .25912 L p
1 g
F P
s
P
p
.002 w
.37509 .2982 m .33385 .33508 L .33809 .31908 L p
1 g
F P
s
P
p
.002 w
.33809 .31908 m .38103 .28044 L .37509 .2982 L p
1 g
F P
s
P
p
.002 w
.33429 .35446 m .31132 .39951 L .30921 .38376 L p
1 g
F P
s
P
p
.002 w
.30921 .38376 m .33385 .33508 L .33429 .35446 L p
1 g
F P
s
P
p
.002 w
.68609 .48826 m .6891 .42585 L .69513 .41457 L p
1 g
F P
s
P
p
.002 w
.67646 .35275 m .69513 .41457 L .6891 .42585 L p
1 g
F P
s
P
p
.002 w
.31902 .41676 m .31357 .46221 L .30535 .45047 L p
1 g
F P
s
P
p
.002 w
.30535 .45047 m .31132 .39951 L .31902 .41676 L p
1 g
F P
s
P
p
.004 w
.31674 .43574 m
.5 .43051 L
s
P
p
.004 w
.30811 .43599 m
.30956 .43595 L
s
P
p
.004 w
.30092 .43619 m
.30811 .43599 L
s
P
p
.002 w
.35566 .54891 m .38531 .57855 L .38151 .5856 L p
1 g
F P
s
P
p
.002 w
.38151 .5856 m .34673 .55085 L .35566 .54891 L p
1 g
F P
s
P
p
.002 w
.42428 .60941 m .38151 .5856 L .38531 .57855 L p
1 g
F P
s
P
p
.002 w
.33572 .51274 m .35566 .54891 L .34673 .55085 L p
1 g
F P
s
P
p
.002 w
.34673 .55085 m .32326 .50841 L .33572 .51274 L p
1 g
F P
s
P
p
.002 w
.6511 .55332 m .67448 .49942 L .68609 .48826 L p
1 g
F P
s
P
p
.002 w
.6891 .42585 m .68609 .48826 L .67448 .49942 L p
1 g
F P
s
P
p
.002 w
.59659 .59957 m .63509 .56068 L .6511 .55332 L p
1 g
F P
s
P
p
.002 w
.67448 .49942 m .6511 .55332 L .63509 .56068 L p
1 g
F P
s
P
p
.002 w
.53279 .62173 m .57902 .60064 L .59659 .59957 L p
1 g
F P
s
P
p
.002 w
.63509 .56068 m .59659 .59957 L .57902 .60064 L p
1 g
F P
s
P
p
.002 w
.38531 .57855 m .42178 .59882 L .42428 .60941 L p
1 g
F P
s
P
p
.002 w
.47105 .61989 m .42428 .60941 L .42178 .59882 L p
1 g
F P
s
P
p
.002 w
.57513 .2663 m .51129 .24509 L .52095 .23739 L p
1 g
F P
s
P
p
.002 w
.52095 .23739 m .58357 .25811 L .57513 .2663 L p
1 g
F P
s
P
p
.002 w
.47105 .61989 m .51736 .6157 L .53279 .62173 L p
1 g
F P
s
P
p
.002 w
.57902 .60064 m .53279 .62173 L .51736 .6157 L p
1 g
F P
s
P
p
.002 w
.32758 .47349 m .33572 .51274 L .32326 .50841 L p
1 g
F P
s
P
p
.002 w
.32326 .50841 m .31357 .46221 L .32758 .47349 L p
1 g
F P
s
P
p
.002 w
.6891 .42585 m .66997 .36287 L .67646 .35275 L p
1 g
F P
s
P
p
.002 w
.63772 .29824 m .67646 .35275 L .66997 .36287 L p
1 g
F P
s
P
p
.002 w
.5009 .25857 m .43733 .25912 L .44703 .24582 L p
1 g
F P
s
P
p
.002 w
.44703 .24582 m .51129 .24509 L .5009 .25857 L p
1 g
F P
s
P
p
.002 w
.37264 .32052 m .33429 .35446 L .33385 .33508 L p
1 g
F P
s
P
p
.002 w
.33385 .33508 m .37509 .2982 L .37264 .32052 L p
1 g
F P
s
P
p
.002 w
.63039 .30728 m .57513 .2663 L .58357 .25811 L p
1 g
F P
s
P
p
.002 w
.58357 .25811 m .63772 .29824 L .63039 .30728 L p
1 g
F P
s
P
p
.002 w
.42178 .59882 m .46158 .60767 L .47105 .61989 L p
1 g
F P
s
P
p
.002 w
.51736 .6157 m .47105 .61989 L .46158 .60767 L p
1 g
F P
s
P
p
.002 w
.42912 .278 m .37509 .2982 L .38103 .28044 L p
1 g
F P
s
P
p
.002 w
.38103 .28044 m .43733 .25912 L .42912 .278 L p
1 g
F P
s
P
p
.002 w
.33966 .37678 m .31902 .41676 L .31132 .39951 L p
1 g
F P
s
P
p
.002 w
.31132 .39951 m .33429 .35446 L .33966 .37678 L p
1 g
F P
s
P
p
.002 w
.66997 .36287 m .63039 .30728 L .63772 .29824 L p
1 g
F P
s
P
p
.002 w
.67448 .49942 m .67727 .43771 L .6891 .42585 L p
1 g
F P
s
P
p
.002 w
.66997 .36287 m .6891 .42585 L .67727 .43771 L p
1 g
F P
s
P
p
.002 w
.33237 .43503 m .32758 .47349 L .31357 .46221 L p
1 g
F P
s
P
p
.002 w
.31357 .46221 m .31902 .41676 L .33237 .43503 L p
1 g
F P
s
P
p
.002 w
.57902 .60064 m .61453 .56449 L .63509 .56068 L p
1 g
F P
s
P
p
.002 w
.65729 .50897 m .63509 .56068 L .61453 .56449 L p
1 g
F P
s
P
p
.002 w
.63509 .56068 m .65729 .50897 L .67448 .49942 L p
1 g
F P
s
P
p
.002 w
.67727 .43771 m .67448 .49942 L .65729 .50897 L p
1 g
F P
s
P
p
.002 w
.51736 .6157 m .55848 .59676 L .57902 .60064 L p
1 g
F P
s
P
p
.002 w
.61453 .56449 m .57902 .60064 L .55848 .59676 L p
1 g
F P
s
P
p
.002 w
.36923 .5434 m .39266 .56683 L .38531 .57855 L p
1 g
F P
s
P
p
.002 w
.38531 .57855 m .35566 .54891 L .36923 .5434 L p
1 g
F P
s
P
p
.002 w
.42178 .59882 m .38531 .57855 L .39266 .56683 L p
1 g
F P
s
P
p
.002 w
.35354 .51481 m .36923 .5434 L .35566 .54891 L p
1 g
F P
s
P
p
.002 w
.35566 .54891 m .33572 .51274 L .35354 .51481 L p
1 g
F P
s
P
p
.002 w
.46158 .60767 m .50084 .60399 L .51736 .6157 L p
1 g
F P
s
P
p
.002 w
.55848 .59676 m .51736 .6157 L .50084 .60399 L p
1 g
F P
s
P
p
.002 w
.56411 .27972 m .5009 .25857 L .51129 .24509 L p
1 g
F P
s
P
p
.002 w
.51129 .24509 m .57513 .2663 L .56411 .27972 L p
1 g
F P
s
P
p
.002 w
.39266 .56683 m .42149 .58282 L .42178 .59882 L p
1 g
F P
s
P
p
.002 w
.46158 .60767 m .42178 .59882 L .42149 .58282 L p
1 g
F P
s
P
p
.002 w
.34724 .48389 m .35354 .51481 L .33572 .51274 L p
1 g
F P
s
P
p
.002 w
.33572 .51274 m .32758 .47349 L .34724 .48389 L p
1 g
F P
s
P
p
.002 w
.67727 .43771 m .65818 .37541 L .66997 .36287 L p
1 g
F P
s
P
p
.002 w
.63039 .30728 m .66997 .36287 L .65818 .37541 L p
1 g
F P
s
P
p
.002 w
.4901 .27773 m .42912 .278 L .43733 .25912 L p
1 g
F P
s
P
p
.002 w
.43733 .25912 m .5009 .25857 L .4901 .27773 L p
1 g
F P
s
P
p
.002 w
.37394 .34686 m .33966 .37678 L .33429 .35446 L p
1 g
F P
s
P
p
.002 w
.33429 .35446 m .37264 .32052 L .37394 .34686 L p
1 g
F P
s
P
p
.002 w
.42277 .30211 m .37264 .32052 L .37509 .2982 L p
1 g
F P
s
P
p
.002 w
.37509 .2982 m .42912 .278 L .42277 .30211 L p
1 g
F P
s
P
p
.002 w
.35003 .40141 m .33237 .43503 L .31902 .41676 L p
1 g
F P
s
P
p
.002 w
.31902 .41676 m .33966 .37678 L .35003 .40141 L p
1 g
F P
s
P
p
.002 w
.42149 .58282 m .45289 .58971 L .46158 .60767 L p
1 g
F P
s
P
p
.002 w
.50084 .60399 m .46158 .60767 L .45289 .58971 L p
1 g
F P
s
P
p
.002 w
.61888 .32036 m .56411 .27972 L .57513 .2663 L p
1 g
F P
s
P
p
.002 w
.57513 .2663 m .63039 .30728 L .61888 .32036 L p
1 g
F P
s
P
p
.002 w
.65818 .37541 m .61888 .32036 L .63039 .30728 L p
1 g
F P
s
P
p
.002 w
.35119 .45375 m .34724 .48389 L .32758 .47349 L p
1 g
F P
s
P
p
.002 w
.32758 .47349 m .33237 .43503 L .35119 .45375 L p
1 g
F P
s
P
p
.002 w
.65729 .50897 m .65971 .44981 L .67727 .43771 L p
1 g
F P
s
P
p
.002 w
.65818 .37541 m .67727 .43771 L .65971 .44981 L p
1 g
F P
s
P
p
.002 w
.55848 .59676 m .58985 .56442 L .61453 .56449 L p
1 g
F P
s
P
p
.002 w
.6348 .51651 m .61453 .56449 L .58985 .56442 L p
1 g
F P
s
P
p
.002 w
.61453 .56449 m .6348 .51651 L .65729 .50897 L p
1 g
F P
s
P
p
.002 w
.50084 .60399 m .5355 .58778 L .55848 .59676 L p
1 g
F P
s
P
p
.002 w
.58985 .56442 m .55848 .59676 L .5355 .58778 L p
1 g
F P
s
P
p
.002 w
.65971 .44981 m .65729 .50897 L .6348 .51651 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.38725 .53427 m .40352 .55056 L .39266 .56683 L p
1 g
F P
s
P
p
.002 w
.39266 .56683 m .36923 .5434 L .38725 .53427 L p
1 g
F P
s
P
p
.002 w
.42149 .58282 m .39266 .56683 L .40352 .55056 L p
1 g
F P
s
P
p
.002 w
.45289 .58971 m .48372 .58667 L .50084 .60399 L p
1 g
F P
s
P
p
.002 w
.5355 .58778 m .50084 .60399 L .48372 .58667 L p
1 g
F P
s
P
p
.002 w
.37641 .51442 m .38725 .53427 L .36923 .5434 L p
1 g
F P
s
P
p
.002 w
.36923 .5434 m .35354 .51481 L .37641 .51442 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.55074 .29819 m .4901 .27773 L .5009 .25857 L p
1 g
F P
s
P
p
.002 w
.5009 .25857 m .56411 .27972 L .55074 .29819 L p
1 g
F P
s
P
p
.002 w
.40352 .55056 m .42355 .56163 L .42149 .58282 L p
1 g
F P
s
P
p
.002 w
.45289 .58971 m .42149 .58282 L .42355 .56163 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.37912 .37645 m .35003 .40141 L .33966 .37678 L p
1 g
F P
s
P
p
.002 w
.33966 .37678 m .37394 .34686 L .37912 .37645 L p
1 g
F P
s
P
p
.002 w
.37217 .49301 m .37641 .51442 L .35354 .51481 L p
1 g
F P
s
P
p
.002 w
.35354 .51481 m .34724 .48389 L .37217 .49301 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.41859 .33084 m .37394 .34686 L .37264 .32052 L p
1 g
F P
s
P
p
.002 w
.37264 .32052 m .42277 .30211 L .41859 .33084 L p
1 g
F P
s
P
p
.002 w
.47926 .30216 m .42277 .30211 L .42912 .278 L p
1 g
F P
s
P
p
.002 w
.42912 .278 m .4901 .27773 L .47926 .30216 L p
1 g
F P
s
P
p
.002 w
.36522 .42758 m .35119 .45375 L .33237 .43503 L p
1 g
F P
s
P
p
.002 w
.33237 .43503 m .35003 .40141 L .36522 .42758 L p
1 g
F P
s
P
p
.002 w
.65971 .44981 m .64117 .39008 L .65818 .37541 L p
1 g
F P
s
P
p
.002 w
.61888 .32036 m .65818 .37541 L .64117 .39008 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.42355 .56163 m .44532 .56633 L .45289 .58971 L p
1 g
F P
s
P
p
.002 w
.48372 .58667 m .45289 .58971 L .44532 .56633 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.60334 .33726 m .55074 .29819 L .56411 .27972 L p
1 g
F P
s
P
p
.002 w
.56411 .27972 m .61888 .32036 L .60334 .33726 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.64117 .39008 m .60334 .33726 L .61888 .32036 L p
1 g
F P
s
P
p
.002 w
.37505 .47226 m .37217 .49301 L .34724 .48389 L p
1 g
F P
s
P
p
.002 w
.34724 .48389 m .35119 .45375 L .37505 .47226 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5355 .58778 m .56174 .56031 L .58985 .56442 L p
1 g
F P
s
P
p
.002 w
.60755 .52167 m .58985 .56442 L .56174 .56031 L p
1 g
F P
s
P
p
.002 w
.58985 .56442 m .60755 .52167 L .6348 .51651 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48372 .58667 m .49578 .58092 L p
.5355 .58778 L 1 g
F P
s
P
p
.002 w
.52185 .58004 m .5355 .58778 L p
.50307 .58218 L 1 g
F P
s
P
p
.50307 .58218 m .49578 .58092 L .51092 .58041 L 1 g
F
P
p
.50307 .58218 m .51092 .58041 L .52185 .58004 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58041 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58041 L .5192 .57854 L 1 g
F
P
p
.002 w
.55753 .56472 m .5355 .58778 L .52208 .58017 L p
1 g
F P
s
P
p
.002 w
.52208 .58017 m .5192 .57854 L p
.53159 .57407 L 1 g
F P
s
P
p
.55753 .56472 m .52208 .58017 L .53159 .57407 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53159 .57407 L p
1 g
F P
s
P
p
.54854 .56129 m .53159 .57407 L .54242 .56713 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56283 L p
1 g
F P
s
P
p
.002 w
.56174 .56031 m .55753 .56472 L p
.54518 .56711 L 1 g
F P
s
P
p
.56174 .56031 m .54518 .56711 L .54614 .56606 L 1 g
F
P
p
.56174 .56031 m .54126 .56787 L .54696 .56421 L 1 g
F
P
p
.56075 .54566 m .54911 .56283 L .55346 .5581 L 1 g
F
P
p
.002 w
.57467 .52823 m .56174 .56031 L .5574 .55915 L p
1 g
F P
s
P
p
.002 w
.5574 .55915 m .55346 .5581 L p
.56141 .5469 L 1 g
F P
s
P
p
.57467 .52823 m .5574 .55915 L .56141 .5469 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56141 .5469 L p
1 g
F P
s
P
p
.56654 .52734 m .56141 .5469 L .56493 .53617 L 1 g
F
P
p
.56075 .54566 m .55346 .5581 L .55538 .55539 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.51078 .57377 m .53106 .55212 L .55346 .5581 L p
1 g
F P
s
P
p
.002 w
.55346 .5581 m .56174 .56031 L p
.54813 .5639 L 1 g
F P
s
P
p
.002 w
.54911 .56283 m .54854 .56129 L p
.54242 .56713 L 1 g
F P
s
P
p
.54813 .5639 m .51078 .57377 L .55346 .5581 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56226 .54852 L p
1 g
F P
s
P
p
.002 w
.56226 .54852 m .56075 .54566 L p
.55454 .55692 L 1 g
F P
s
P
p
.55454 .55692 m .54998 .56518 L .56226 .54852 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56741 .5286 m .56654 .52734 L p
.56493 .53617 L 1 g
F P
s
P
p
.002 w
.55346 .5581 m .53106 .55212 L p
.56596 .533 L 1 g
F P
s
P
p
.57467 .52823 m .56141 .5469 L .56596 .533 L 1 g
F
P
p
.56141 .5469 m .55346 .5581 L .56596 .533 L 1 g
F
P
p
.002 w
.57631 .52417 m .57467 .52823 L p
.56752 .53215 L 1 g
F P
s
P
p
.56744 .52965 m .56752 .53215 L .53106 .55212 L 1 g
F
P
p
.57631 .52417 m .56752 .53215 L .56744 .52965 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56741 .5286 L p
1 g
F P
s
P
p
.56515 .50826 m .56741 .5286 L .56726 .52408 L 1 g
F
P
p
.57713 .48319 m .56918 .51613 L .56469 .49764 L 1 g
F
P
p
.56918 .51613 m .56726 .52408 L .56579 .50903 L 1 g
F
P
p
.56918 .51613 m .56579 .50903 L .56469 .49764 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56579 .50903 L p
1 g
F P
s
P
p
.55661 .4905 m .56579 .50903 L .56068 .49829 L 1 g
F
P
p
.56515 .50826 m .56726 .52408 L .56669 .51827 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.57713 .48319 m .57631 .52417 L .56726 .52408 L p
1 g
F P
s
P
p
.002 w
.53106 .55212 m .54214 .52383 L .56726 .52408 L p
1 g
F P
s
P
p
.002 w
.56726 .52408 m .57631 .52417 L p
.56744 .52965 L 1 g
F P
s
P
p
.56744 .52965 m .53106 .55212 L .56726 .52408 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56681 .51024 L p
1 g
F P
s
P
p
.002 w
.56681 .51024 m .56515 .50826 L p
.56717 .52137 L 1 g
F P
s
P
p
.56717 .52137 m .56854 .53025 L .56681 .51024 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56726 .52408 m .54214 .52383 L p
.56191 .50087 L 1 g
F P
s
P
p
.56469 .49764 m .56579 .50903 L .56191 .50087 L 1 g
F
P
p
.56579 .50903 m .56726 .52408 L .56191 .50087 L 1 g
F
P
p
.002 w
.55734 .49128 m .55661 .4905 L p
.56068 .49829 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54214 .52383 m .54249 .4919 L .55478 .48881 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55734 .49128 L p
1 g
F P
s
P
p
.54174 .47608 m .55734 .49128 L .55478 .48881 L 1 g
F
P
p
.002 w
.55478 .48881 m .54249 .4919 L p
.547 .48126 L 1 g
F P
s
P
p
.54958 .48376 m .55478 .48881 L .55182 .48595 L 1 g
F
P
p
.54174 .47608 m .55478 .48881 L .54958 .48376 L 1 g
F
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56365 .44204 m .57713 .48319 L .55478 .48881 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.56434 .49804 m .54214 .52383 L .55478 .48881 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55734 .49128 L p
1 g
F P
s
P
p
.56068 .49829 m .56713 .51061 L .55734 .49128 L 1 g
F
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54249 .4919 m .5365 .47397 L p
.547 .48126 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54227 .47666 L p
1 g
F P
s
P
p
.52214 .46667 m .54227 .47666 L .5365 .47397 L 1 g
F
P
p
.002 w
.5365 .47397 m .54249 .4919 L p
.52594 .46887 L 1 g
F P
s
P
p
.53278 .47218 m .5365 .47397 L .53406 .47284 L 1 g
F
P
p
.52214 .46667 m .5365 .47397 L .53278 .47218 L 1 g
F
P
p
.002 w
.54249 .4919 m .50629 .49875 L p
.52594 .46887 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.547 .48126 m .5365 .47397 L .54227 .47666 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.52594 .46887 m .50629 .49875 L .51972 .46681 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46719 L .51878 .46668 L 1 g
F
P
p
.5 .4634 m .51878 .46668 L .51086 .46549 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.51117 .43173 m .53181 .45995 L .51878 .46668 L p
1 g
F P
s
P
p
.002 w
.51878 .46668 m .49886 .47699 L p
.50234 .4642 L 1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49886 .47699 m .49036 .46543 L p
.50234 .4642 L 1 g
F P
s
P
p
.47786 .46667 m .49086 .46535 L .49036 .46543 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.47987 .46688 m .46612 .4925 L .47424 .4688 L 1 g
F
P
p
.47987 .46688 m .47424 .4688 L .47754 .4672 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.46612 .4925 m .45897 .48284 L .47259 .4696 L p
1 g
F P
s
P
p
.47424 .4688 m .46612 .4925 L .47259 .4696 L 1 g
F
P
p
.002 w
.47259 .4696 m .45897 .48284 L p
.46017 .47557 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .47259 .4696 L 1 g
F
P
p
.46797 .47182 m .47259 .4696 L .46835 .47166 L 1 g
F
P
p
.45826 .47608 m .47259 .4696 L .46797 .47182 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45897 .48284 m .4547 .47963 L p
.46017 .47557 L 1 g
F P
s
P
p
.46017 .47557 m .4547 .47963 L .45758 .47682 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45758 .47682 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43483 .5059 m .44105 .49285 L p
.44216 .49222 L 1 g
F P
s
P
p
.002 w
.43601 .50477 m .43483 .5059 L p
.44216 .49222 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .43863 .49943 L 1 g
F
P
p
.002 w
.4547 .47963 m .45897 .48284 L p
.44216 .49222 L 1 g
F P
s
P
p
.44258 .49136 m .44216 .49222 L .44105 .49285 L 1 g
F
P
p
.4547 .47963 m .44216 .49222 L .44258 .49136 L 1 g
F
P
p
.002 w
.44258 .49136 m .44166 .49233 L p
.43863 .49943 L 1 g
F P
s
P
p
.002 w
.4177 .53006 m .43483 .5059 L .43422 .50858 L p
1 g
F P
s
P
p
.002 w
.43378 .50954 m .43485 .50826 L p
.4353 .50623 L 1 g
F P
s
P
p
.43485 .50826 m .43863 .49943 L .43601 .50477 L 1 g
F
P
p
.43485 .50826 m .43601 .50477 L .43575 .50529 L 1 g
F
P
p
.43485 .50826 m .43576 .50529 L .43562 .50557 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.45897 .48284 m .46612 .4925 L .43563 .50556 L p
1 g
F P
s
P
p
.002 w
.43563 .50556 m .43483 .5059 L .43601 .50477 L p
1 g
F P
s
P
p
.002 w
.43601 .50477 m .45897 .48284 L p
.43563 .50556 L 1 g
F P
s
P
p
.43575 .50529 m .43601 .50477 L .43576 .50529 L 1 g
F
P
p
.43562 .50557 m .43576 .50529 L .43562 .50556 L 1 g
F
P
p
.43485 .50826 m .43562 .50556 L .43554 .50574 L 1 g
F
P
p
.43485 .50826 m .43554 .50573 L .4353 .50623 L 1 g
F
P
p
.002 w
.46612 .4925 m .46994 .50347 L .43548 .50585 L p
1 g
F P
s
P
p
.002 w
.43548 .50585 m .43483 .5059 L .43563 .50556 L p
1 g
F P
s
P
p
.002 w
.43563 .50556 m .46612 .4925 L p
.43548 .50585 L 1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.46994 .50347 m .47002 .51453 L .43539 .50604 L p
1 g
F P
s
P
p
.002 w
.43539 .50604 m .43483 .5059 L .43548 .50585 L p
1 g
F P
s
P
p
.002 w
.43548 .50585 m .46994 .50347 L p
.43539 .50604 L 1 g
F P
s
P
p
.43554 .50574 m .43562 .50556 L .43554 .50573 L 1 g
F
P
p
.002 w
.43532 .50619 m .43483 .5059 L .43539 .50604 L p
1 g
F P
s
P
p
.4353 .50623 m .43554 .50573 L .43531 .5062 L 1 g
F
P
p
.002 w
.47002 .51453 m .4664 .52445 L .43532 .50619 L p
1 g
F P
s
P
p
.002 w
.43539 .50604 m .47002 .51453 L p
.43532 .50619 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4664 .52445 m .4595 .53217 L .43525 .50634 L p
1 g
F P
s
P
p
.002 w
.43525 .50634 m .43483 .5059 L .43532 .50619 L p
1 g
F P
s
P
p
.002 w
.43532 .50619 m .4664 .52445 L p
.43525 .50634 L 1 g
F P
s
P
p
.4353 .50623 m .4353 .50623 L .43528 .50628 L 1 g
F
P
p
.4353 .50623 m .43528 .50628 L .43378 .50954 L 1 g
F
P
p
.4353 .50623 m .4353 .50622 L .43521 .50643 L 1 g
F
P
p
.4353 .50623 m .43521 .50643 L .43378 .50954 L 1 g
F
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.4595 .53217 m .45009 .53688 L .43515 .50655 L p
1 g
F P
s
P
p
.002 w
.43515 .50655 m .43483 .5059 L .43525 .50634 L p
1 g
F P
s
P
p
.002 w
.43525 .50634 m .4595 .53217 L p
.43515 .50655 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45009 .53688 m .43921 .5381 L .43497 .50694 L p
1 g
F P
s
P
p
.002 w
.43497 .50694 m .43483 .5059 L .43515 .50655 L p
1 g
F P
s
P
p
.002 w
.43515 .50655 m .45009 .53688 L p
.43497 .50694 L 1 g
F P
s
P
p
.4353 .50622 m .43531 .50621 L .435 .50687 L 1 g
F
P
p
.4353 .50622 m .435 .50687 L .43378 .50954 L 1 g
F
P
p
.002 w
.43422 .50858 m .43483 .5059 L .43497 .50694 L p
1 g
F P
s
P
p
.43531 .50621 m .43531 .5062 L .43422 .50858 L 1 g
F
P
p
.43531 .50621 m .43422 .50858 L .43378 .50954 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.42802 .53574 m .43093 .52299 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43472 .53716 m .43195 .53657 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43195 .53657 m .42802 .53574 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43247 .52878 m .43346 .52734 L p
.43316 .51867 L 1 g
F P
s
P
p
.43925 .54566 m .43445 .53617 L .43472 .53716 L 1 g
F
P
p
.002 w
.42802 .53574 m .43018 .5362 L p
.44532 .56633 L 1 g
F P
s
P
p
.002 w
.43018 .5362 m .43472 .53716 L p
.43838 .54724 L 1 g
F P
s
P
p
.44532 .56633 m .43018 .5362 L .43838 .54724 L 1 g
F
P
p
.002 w
.4384 .54726 m .43925 .54566 L p
.43472 .53716 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4384 .54726 L p
1 g
F P
s
P
p
.45146 .56129 m .4384 .54726 L .44234 .55257 L 1 g
F
P
p
.002 w
.45249 .56558 m .44532 .56633 L .44349 .55785 L p
1 g
F P
s
P
p
.002 w
.44349 .55785 m .44234 .55257 L p
.45071 .5633 L 1 g
F P
s
P
p
.45249 .56558 m .44349 .55785 L .45071 .5633 L 1 g
F
P
p
.48372 .58667 m .44592 .56665 L .46432 .57302 L 1 g
F
P
p
.002 w
.46834 .57441 m .46872 .57265 L p
.45908 .5688 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .57441 L p
1 g
F P
s
P
p
.48921 .57862 m .46834 .57441 L .4766 .57727 L 1 g
F
P
p
.002 w
.49375 .58189 m .48372 .58667 L .4788 .58018 L p
1 g
F P
s
P
p
.002 w
.4788 .58018 m .4766 .57727 L p
.48906 .58063 L 1 g
F P
s
P
p
.49375 .58189 m .4788 .58018 L .48906 .58063 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51101 .58158 L p
1 g
F P
s
P
p
.002 w
.51101 .58158 m .51092 .58041 L p
.50365 .58126 L 1 g
F P
s
P
p
.50365 .58126 m .48889 .583 L .51101 .58158 L 1 g
F
P
p
.47826 .57772 m .4766 .57727 L .47777 .57768 L 1 g
F
P
p
.48921 .57862 m .4766 .57727 L .47826 .57772 L 1 g
F
P
p
.002 w
.48899 .58157 m .48921 .57862 L p
.47777 .57768 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58063 L p
1 g
F P
s
P
p
.002 w
.49578 .58092 m .49375 .58189 L p
.49202 .58076 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58063 L .49865 .58105 L 1 g
F
P
p
.002 w
.4766 .57727 m .4666 .5641 L p
.49375 .58189 L 1 g
F P
s
P
p
.002 w
.48906 .58063 m .48889 .583 L p
.49865 .58105 L 1 g
F P
s
P
p
.002 w
.51078 .57377 m .49578 .58092 L p
.4666 .5641 L 1 g
F P
s
P
p
.49578 .58092 m .49202 .58076 L .4666 .5641 L 1 g
F
P
p
.002 w
.44532 .56633 m .45358 .56546 L p
.46432 .57302 L 1 g
F P
s
P
p
.002 w
.47961 .58125 m .48372 .58667 L p
.45358 .56546 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45071 .5633 L p
1 g
F P
s
P
p
.002 w
.45358 .56546 m .45249 .56558 L p
.45178 .5641 L 1 g
F P
s
P
p
.46872 .57265 m .45071 .5633 L .45678 .56788 L 1 g
F
P
p
.45146 .56129 m .44234 .55257 L .44427 .55505 L 1 g
F
P
p
.002 w
.45058 .56366 m .45146 .56129 L p
.44402 .55482 L 1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44234 .55257 m .43921 .5381 L p
.45249 .56558 L 1 g
F P
s
P
p
.002 w
.45071 .5633 m .45002 .56518 L p
.45678 .56788 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4666 .5641 m .45358 .56546 L p
.43921 .5381 L 1 g
F P
s
P
p
.45358 .56546 m .45178 .5641 L .43921 .5381 L 1 g
F
P
p
.002 w
.45358 .56546 m .4666 .5641 L .4766 .57727 L p
1 g
F P
s
P
p
.002 w
.4766 .57727 m .47961 .58125 L p
.46834 .57441 L 1 g
F P
s
P
p
.46834 .57441 m .45358 .56546 L .4766 .57727 L 1 g
F
P
p
.002 w
.46834 .57441 m .4678 .57686 L p
.47777 .57768 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48899 .58157 L p
1 g
F P
s
P
p
.47777 .57768 m .4678 .57686 L .48899 .58157 L 1 g
F
P
p
.44592 .56665 m .44532 .56633 L .46432 .57302 L 1 g
F
P
p
.002 w
.46792 .57629 m .46834 .57441 L p
.45678 .56788 L 1 g
F P
s
P
p
.45908 .5688 m .45678 .56788 L .46834 .57441 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46792 .57629 L p
1 g
F P
s
P
p
.45678 .56788 m .45002 .56518 L .46792 .57629 L 1 g
F
P
p
.44427 .55505 m .44234 .55257 L .44402 .55482 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43472 .53716 m .43921 .5381 L .44234 .55257 L p
1 g
F P
s
P
p
.002 w
.44234 .55257 m .44528 .56614 L p
.4384 .54726 L 1 g
F P
s
P
p
.4384 .54726 m .43472 .53716 L .44234 .55257 L 1 g
F
P
p
.002 w
.44528 .56614 m .44532 .56633 L p
.43472 .53716 L 1 g
F P
s
P
p
.002 w
.4384 .54726 m .43743 .5491 L p
.44402 .55482 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45058 .56366 L p
1 g
F P
s
P
p
.44402 .55482 m .43743 .5491 L .45058 .56366 L 1 g
F
P
p
.002 w
.43775 .5485 m .4384 .54726 L p
.43472 .53716 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43378 .50954 L p
1 g
F P
s
P
p
.002 w
.43368 .51093 m .42802 .53574 L p
.43378 .50954 L 1 g
F P
s
P
p
.002 w
.43378 .50954 m .43378 .50954 L p
.43377 .50958 L 1 g
F P
s
P
p
.43346 .52734 m .43378 .50954 L .43377 .50958 L 1 g
F
P
p
.002 w
.42802 .53574 m .42301 .53299 L p
.43378 .50954 L 1 g
F P
s
P
p
.43346 .52734 m .43377 .50958 L .43316 .51867 L 1 g
F
P
p
.43377 .50958 m .43378 .50954 L .43368 .51093 L 1 g
F
P
p
.43377 .50958 m .43368 .51093 L .43316 .51867 L 1 g
F
P
p
.002 w
.42301 .53299 m .4177 .53006 L p
.43381 .50911 L 1 g
F P
s
P
p
.43378 .50954 m .43381 .50911 L .43422 .50858 L 1 g
F
P
p
.42301 .53299 m .43381 .50911 L .43378 .50954 L 1 g
F
P
p
.002 w
.43422 .50858 m .43368 .51093 L p
.43378 .50954 L 1 g
F P
s
P
p
.43472 .53716 m .43247 .52878 L .43422 .50858 L 1 g
F
P
p
.002 w
.43093 .52299 m .43368 .51093 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43368 .51093 m .43422 .50858 L p
.43247 .52878 L 1 g
F P
s
P
p
.002 w
.43378 .50954 m .43287 .51061 L p
.43316 .51867 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43247 .52878 L p
1 g
F P
s
P
p
.43316 .51867 m .43287 .51061 L .43247 .52878 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43775 .5485 L p
1 g
F P
s
P
p
.43445 .53617 m .43146 .53025 L .43775 .5485 L 1 g
F
P
p
.002 w
.43921 .5381 m .43472 .53716 L p
.43422 .50858 L 1 g
F P
s
P
p
.002 w
.43497 .50694 m .43921 .5381 L p
.43422 .50858 L 1 g
F P
s
P
p
.002 w
.43353 .50984 m .43378 .50954 L p
.43531 .5062 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43353 .50984 L p
1 g
F P
s
P
p
.43863 .49943 m .44166 .49233 L .43353 .50984 L 1 g
F
P
p
.002 w
.45897 .48284 m .43601 .50477 L p
.44216 .49222 L 1 g
F P
s
P
p
.44339 .4905 m .45758 .47682 L .45257 .4817 L 1 g
F
P
p
.002 w
.44105 .49285 m .44928 .47556 L .4547 .47963 L p
1 g
F P
s
P
p
.45257 .4817 m .4547 .47963 L .45698 .47747 L 1 g
F
P
p
.002 w
.45758 .47682 m .45743 .47698 L p
.4547 .47963 L 1 g
F P
s
P
p
.002 w
.45743 .47698 m .45698 .47747 L p
.4547 .47963 L 1 g
F P
s
P
p
.002 w
.45354 .47876 m .44928 .47556 L p
.45886 .47557 L 1 g
F P
s
P
p
.002 w
.45749 .47692 m .45758 .47682 L p
.46835 .47166 L 1 g
F P
s
P
p
.002 w
.45758 .47682 m .45826 .47608 L p
.46797 .47182 L 1 g
F P
s
P
p
.46797 .47182 m .46835 .47166 L .45758 .47682 L 1 g
F
P
p
.46017 .47557 m .45758 .47682 L .45886 .47557 L 1 g
F
P
p
.45758 .47682 m .45354 .47876 L .45886 .47557 L 1 g
F
P
p
.002 w
.4547 .47963 m .45354 .47876 L p
.45758 .47682 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44167 .49232 L p
1 g
F P
s
P
p
.002 w
.44167 .49232 m .44339 .4905 L p
.45257 .4817 L 1 g
F P
s
P
p
.45257 .4817 m .45698 .47747 L .44167 .49232 L 1 g
F
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44928 .47556 m .46552 .44339 L p
.46017 .47557 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.46552 .44339 m .48474 .45779 L .47259 .4696 L p
1 g
F P
s
P
p
.46552 .44339 m .47259 .4696 L .46017 .47557 L 1 g
F
P
p
.46835 .47166 m .47259 .4696 L .47718 .46778 L 1 g
F
P
p
.002 w
.47754 .4672 m .47753 .46723 L p
.47259 .4696 L 1 g
F P
s
P
p
.002 w
.47753 .46723 m .47718 .46778 L p
.47259 .4696 L 1 g
F P
s
P
p
.002 w
.47259 .4696 m .47465 .4676 L p
.47424 .4688 L 1 g
F P
s
P
p
.47754 .4672 m .47424 .4688 L .47465 .4676 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45749 .47692 L p
1 g
F P
s
P
p
.46835 .47166 m .47718 .46778 L .45749 .47692 L 1 g
F
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.49036 .46543 L 1 g
F P
s
P
p
.002 w
.49886 .47699 m .46612 .4925 L p
.47987 .46688 L 1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.50234 .4642 m .49036 .46543 L .5 .46385 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46385 L p
1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .46442 L p
.49086 .46535 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46385 L .49086 .46535 L 1 g
F
P
p
.52594 .46887 m .51972 .46681 L .52245 .46719 L 1 g
F
P
p
.002 w
.50629 .49875 m .49886 .47699 L .52005 .46603 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46385 L p
1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .4634 L p
.51086 .46549 L 1 g
F P
s
P
p
.51086 .46549 m .52282 .46778 L .5 .46385 L 1 g
F
P
p
.002 w
.48785 .46201 m .48474 .45779 L p
.50094 .46369 L 1 g
F P
s
P
p
.50234 .4642 m .5 .46385 L .50094 .46369 L 1 g
F
P
p
.5 .46385 m .48785 .46201 L .50094 .46369 L 1 g
F
P
p
.002 w
.48474 .45779 m .49036 .46543 L p
.47987 .46688 L 1 g
F P
s
P
p
.002 w
.49036 .46543 m .49886 .47699 L p
.47987 .46688 L 1 g
F P
s
P
p
.49036 .46543 m .5 .46442 L .47732 .46757 L 1 g
F
P
p
.49086 .46535 m .49121 .46531 L .49036 .46543 L 1 g
F
P
p
.49121 .46531 m .5 .46442 L .49036 .46543 L 1 g
F
P
p
.002 w
.47732 .46757 m .47754 .4672 L p
.49036 .46543 L 1 g
F P
s
P
p
.002 w
.47465 .4676 m .48474 .45779 L p
.47987 .46688 L 1 g
F P
s
P
p
.002 w
.49036 .46543 m .48785 .46201 L p
.5 .46385 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47732 .46757 L p
1 g
F P
s
P
p
.51117 .43173 m .51878 .46668 L .50234 .4642 L 1 g
F
P
p
.51285 .46587 m .51878 .46668 L .52282 .46778 L 1 g
F
P
p
.002 w
.52245 .46719 m .52249 .46724 L p
.51878 .46668 L 1 g
F P
s
P
p
.002 w
.52249 .46724 m .52282 .46778 L p
.51878 .46668 L 1 g
F P
s
P
p
.51086 .46549 m .51878 .46668 L .51285 .46587 L 1 g
F
P
p
.002 w
.48474 .45779 m .51117 .43173 L p
.50234 .4642 L 1 g
F P
s
P
p
.52245 .46719 m .51972 .46681 L .52005 .46603 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.53278 .47218 L 1 g
F P
s
P
p
.53278 .47218 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.52005 .46603 m .53181 .45995 L p
.52594 .46887 L 1 g
F P
s
P
p
.002 w
.53181 .45995 m .5365 .47397 L p
.52594 .46887 L 1 g
F P
s
P
p
.002 w
.5365 .47397 m .53505 .46965 L p
.54227 .47666 L 1 g
F P
s
P
p
.002 w
.54227 .47666 m .54302 .47747 L p
.53406 .47284 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54227 .47666 L p
1 g
F P
s
P
p
.002 w
.54227 .47666 m .54174 .47608 L p
.54958 .48376 L 1 g
F P
s
P
p
.54958 .48376 m .55834 .49233 L .54227 .47666 L 1 g
F
P
p
.002 w
.53181 .45995 m .56365 .44204 L p
.547 .48126 L 1 g
F P
s
P
p
.002 w
.53505 .46965 m .53181 .45995 L p
.547 .48126 L 1 g
F P
s
P
p
.56365 .44204 m .55478 .48881 L .547 .48126 L 1 g
F
P
p
.002 w
.55478 .48881 m .57713 .48319 L p
.56434 .49804 L 1 g
F P
s
P
p
.002 w
.55734 .49128 m .55834 .49233 L p
.55182 .48595 L 1 g
F P
s
P
p
.002 w
.56579 .50903 m .56713 .51061 L p
.56068 .49829 L 1 g
F P
s
P
p
.56669 .51827 m .56726 .52408 L .56717 .52137 L 1 g
F
P
p
.002 w
.56741 .5286 m .56854 .53025 L p
.56717 .52137 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56741 .5286 L p
1 g
F P
s
P
p
.56493 .53617 m .56257 .5491 L .56741 .5286 L 1 g
F
P
p
.002 w
.56141 .5469 m .56257 .5491 L p
.56493 .53617 L 1 g
F P
s
P
p
.55538 .55539 m .55346 .5581 L .55454 .55692 L 1 g
F
P
p
.002 w
.54911 .56283 m .54998 .56518 L p
.55454 .55692 L 1 g
F P
s
P
p
.54614 .56606 m .54518 .56711 L .54126 .56787 L 1 g
F
P
p
.54696 .56421 m .54126 .56787 L .51078 .57377 L 1 g
F
P
p
.53128 .57265 m .5192 .57854 L .5212 .57782 L 1 g
F
P
p
.002 w
.51092 .58041 m .51079 .57862 L p
.49999 .58078 L 1 g
F P
s
P
p
.002 w
.49578 .58092 m .51078 .57377 L .5192 .57854 L p
1 g
F P
s
P
p
.002 w
.5192 .57854 m .52185 .58004 L p
.51092 .58041 L 1 g
F P
s
P
p
.51092 .58041 m .49578 .58092 L .5192 .57854 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53194 .57567 L p
1 g
F P
s
P
p
.002 w
.53194 .57567 m .53128 .57265 L p
.52026 .5783 L 1 g
F P
s
P
p
.52026 .5783 m .51111 .583 L .53194 .57567 L 1 g
F
P
p
.002 w
.5192 .57854 m .51078 .57377 L p
.55753 .56472 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56283 L p
1 g
F P
s
P
p
.54242 .56713 m .5322 .57686 L .54911 .56283 L 1 g
F
P
p
.002 w
.53159 .57407 m .5322 .57686 L p
.54242 .56713 L 1 g
F P
s
P
p
.5212 .57782 m .5192 .57854 L .52026 .5783 L 1 g
F
P
p
.002 w
.51092 .58041 m .51111 .583 L p
.52026 .5783 L 1 g
F P
s
P
p
.49999 .58078 m .48889 .583 L .51092 .58041 L 1 g
F
P
p
.002 w
.6348 .51651 m .63673 .46171 L .65971 .44981 L p
1 g
F P
s
P
p
.002 w
.64117 .39008 m .65971 .44981 L .63673 .46171 L p
1 g
F P
s
P
p
.002 w
.63673 .46171 m .6348 .51651 L .60755 .52167 L p
1 g
F P
s
P
p
.004 w
.47969 .45401 m
.5 .43051 L
s
P
p
.002 w
.40933 .52167 m .4177 .53006 L .40352 .55056 L p
1 g
F P
s
P
p
.002 w
.40352 .55056 m .38725 .53427 L .40933 .52167 L p
1 g
F P
s
P
p
.002 w
.42355 .56163 m .40352 .55056 L .4177 .53006 L p
1 g
F P
s
P
p
.002 w
.40379 .51145 m .40933 .52167 L .38725 .53427 L p
1 g
F P
s
P
p
.002 w
.38725 .53427 m .37641 .51442 L .40379 .51145 L p
1 g
F P
s
P
p
.002 w
.5354 .3213 m .47926 .30216 L .4901 .27773 L p
1 g
F P
s
P
p
.002 w
.4901 .27773 m .55074 .29819 L .5354 .3213 L p
1 g
F P
s
P
p
.002 w
.38813 .40834 m .36522 .42758 L .35003 .40141 L p
1 g
F P
s
P
p
.002 w
.35003 .40141 m .37912 .37645 L .38813 .40834 L p
1 g
F P
s
P
p
.002 w
.4177 .53006 m .42802 .53574 L .42355 .56163 L p
1 g
F P
s
P
p
.002 w
.44532 .56633 m .42355 .56163 L .42802 .53574 L p
1 g
F P
s
P
p
.002 w
.41682 .3633 m .37912 .37645 L .37394 .34686 L p
1 g
F P
s
P
p
.002 w
.37394 .34686 m .41859 .33084 L .41682 .3633 L p
1 g
F P
s
P
p
.002 w
.38487 .45438 m .37505 .47226 L .35119 .45375 L p
1 g
F P
s
P
p
.002 w
.35119 .45375 m .36522 .42758 L .38487 .45438 L p
1 g
F P
s
P
p
.002 w
.46877 .33119 m .41859 .33084 L .42277 .30211 L p
1 g
F P
s
P
p
.002 w
.42277 .30211 m .47926 .30216 L .46877 .33119 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40168 .50046 m .40379 .51145 L .37641 .51442 L p
1 g
F P
s
P
p
.002 w
.37641 .51442 m .37217 .49301 L .40168 .50046 L p
1 g
F P
s
P
p
.002 w
.63673 .46171 m .6193 .40644 L .64117 .39008 L p
1 g
F P
s
P
p
.002 w
.60334 .33726 m .64117 .39008 L .6193 .40644 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.56174 .56031 m .57631 .52417 L .60755 .52167 L p
1 g
F P
s
P
p
.002 w
.4666 .5641 m .48514 .55506 L .51078 .57377 L p
1 g
F P
s
P
p
.002 w
.53106 .55212 m .51078 .57377 L .48514 .55506 L p
1 g
F P
s
P
p
.002 w
.40324 .48987 m .40168 .50046 L .37217 .49301 L p
1 g
F P
s
P
p
.002 w
.37217 .49301 m .37505 .47226 L .40324 .48987 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.58413 .35756 m .5354 .3213 L .55074 .29819 L p
1 g
F P
s
P
p
.002 w
.55074 .29819 m .60334 .33726 L .58413 .35756 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.60891 .47299 m .60755 .52167 L .57631 .52417 L p
1 g
F P
s
P
p
.002 w
.60755 .52167 m .60891 .47299 L .63673 .46171 L p
1 g
F P
s
P
p
.002 w
.6193 .40644 m .63673 .46171 L .60891 .47299 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.6193 .40644 m .58413 .35756 L .60334 .33726 L p
1 g
F P
s
P
p
.002 w
.43921 .5381 m .45009 .53688 L .4666 .5641 L p
1 g
F P
s
P
p
.002 w
.48514 .55506 m .4666 .5641 L .45009 .53688 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40072 .44137 m .38487 .45438 L .36522 .42758 L p
1 g
F P
s
P
p
.002 w
.36522 .42758 m .38813 .40834 L .40072 .44137 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.41761 .39838 m .38813 .40834 L .37912 .37645 L p
1 g
F P
s
P
p
.002 w
.37912 .37645 m .41682 .3633 L .41761 .39838 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.40835 .48082 m .40324 .48987 L .37505 .47226 L p
1 g
F P
s
P
p
.002 w
.37505 .47226 m .38487 .45438 L .40835 .48082 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51857 .34839 m .46877 .33119 L .47926 .30216 L p
1 g
F P
s
P
p
.002 w
.47926 .30216 m .5354 .3213 L .51857 .34839 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4177 .53006 m .40933 .52167 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.45904 .3639 m .41682 .3633 L .41859 .33084 L p
1 g
F P
s
P
p
.002 w
.41859 .33084 m .46877 .33119 L .45904 .3639 L p
1 g
F P
s
P
p
.002 w
.40933 .52167 m .40379 .51145 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.40379 .51145 m .40168 .50046 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.48514 .55506 m .49889 .54004 L .53106 .55212 L p
1 g
F P
s
P
p
.002 w
.54214 .52383 m .53106 .55212 L .49889 .54004 L p
1 g
F P
s
P
p
.002 w
.45009 .53688 m .4595 .53217 L .48514 .55506 L p
1 g
F P
s
P
p
.002 w
.49889 .54004 m .48514 .55506 L .4595 .53217 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.60891 .47299 m .59318 .42397 L .6193 .40644 L p
1 g
F P
s
P
p
.002 w
.58413 .35756 m .6193 .40644 L .59318 .42397 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57631 .52417 m .57713 .48319 L .60891 .47299 L p
1 g
F P
s
P
p
.002 w
.40168 .50046 m .40324 .48987 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.41649 .47431 m .40835 .48082 L .38487 .45438 L p
1 g
F P
s
P
p
.002 w
.38487 .45438 m .40072 .44137 L .41649 .47431 L p
1 g
F P
s
P
p
.002 w
.59318 .42397 m .60891 .47299 L .57713 .48319 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56183 .38063 m .51857 .34839 L .5354 .3213 L p
1 g
F P
s
P
p
.002 w
.5354 .3213 m .58413 .35756 L .56183 .38063 L p
1 g
F P
s
P
p
.002 w
.42097 .43477 m .40072 .44137 L .38813 .40834 L p
1 g
F P
s
P
p
.002 w
.38813 .40834 m .41761 .39838 L .42097 .43477 L p
1 g
F P
s
P
p
.002 w
.40324 .48987 m .40835 .48082 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.59318 .42397 m .56183 .38063 L .58413 .35756 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.4595 .53217 m .4664 .52445 L .49889 .54004 L p
1 g
F P
s
P
p
.002 w
.50626 .52058 m .49889 .54004 L .4664 .52445 L p
1 g
F P
s
P
p
.002 w
.49889 .54004 m .50626 .52058 L .54214 .52383 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45047 .39909 m .41761 .39838 L .41682 .3633 L p
1 g
F P
s
P
p
.002 w
.41682 .3633 m .45904 .3639 L .45047 .39909 L p
1 g
F P
s
P
p
.002 w
.40835 .48082 m .41649 .47431 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.50086 .37854 m .45904 .3639 L .46877 .33119 L p
1 g
F P
s
P
p
.002 w
.46877 .33119 m .51857 .34839 L .50086 .37854 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.54249 .4919 m .54214 .52383 L .50626 .52058 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42679 .47107 m .41649 .47431 L .40072 .44137 L p
1 g
F P
s
P
p
.002 w
.40072 .44137 m .42097 .43477 L .42679 .47107 L p
1 g
F P
s
P
p
.002 w
.4664 .52445 m .47002 .51453 L .50626 .52058 L p
1 g
F P
s
P
p
.002 w
.43814 .4715 m .44928 .47556 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.42679 .47107 m .43814 .4715 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.41649 .47431 m .42679 .47107 L .43483 .5059 L closepath p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57713 .48319 m .56365 .44204 L .59318 .42397 L p
1 g
F P
s
P
p
.002 w
.56183 .38063 m .59318 .42397 L .56365 .44204 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.50629 .49875 m .50626 .52058 L .47002 .51453 L p
1 g
F P
s
P
p
.002 w
.50626 .52058 m .50629 .49875 L .54249 .4919 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47002 .51453 m .46994 .50347 L .50629 .49875 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.004 w
.43305 .50796 m
.43362 .5073 L
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.44341 .43543 m .42097 .43477 L .41761 .39838 L p
1 g
F P
s
P
p
.002 w
.41761 .39838 m .45047 .39909 L .44341 .43543 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.5372 .40567 m .50086 .37854 L .51857 .34839 L p
1 g
F P
s
P
p
.002 w
.51857 .34839 m .56183 .38063 L .5372 .40567 L p
1 g
F P
s
P
p
.002 w
.43814 .4715 m .42679 .47107 L .42097 .43477 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56365 .44204 m .5372 .40567 L .56183 .38063 L p
1 g
F P
s
P
p
.002 w
.42097 .43477 m .44341 .43543 L .43814 .4715 L p
1 g
F P
s
P
p
.002 w
.46994 .50347 m .46612 .4925 L .49886 .47699 L p
1 g
F P
s
P
p
.002 w
.49886 .47699 m .50629 .49875 L .46994 .50347 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.48294 .41062 m .45047 .39909 L .45904 .3639 L p
1 g
F P
s
P
p
.002 w
.45904 .3639 m .50086 .37854 L .48294 .41062 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.004 w
.43112 .51019 m
.43169 .50952 L
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.44928 .47556 m .43814 .4715 L .44341 .43543 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.44341 .43543 m .46552 .44339 L .44928 .47556 L p
1 g
F P
s
P
p
.002 w
.5372 .40567 m .56365 .44204 L .53181 .45995 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.004 w
.42917 .51244 m
.42975 .51177 L
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.46552 .44339 m .44341 .43543 L .45047 .39909 L p
1 g
F P
s
P
p
.002 w
.45047 .39909 m .48294 .41062 L .46552 .44339 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51117 .43173 m .48294 .41062 L .50086 .37854 L p
1 g
F P
s
P
p
.002 w
.50086 .37854 m .5372 .40567 L .51117 .43173 L p
1 g
F P
s
P
p
.002 w
.53181 .45995 m .51117 .43173 L .5372 .40567 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.48474 .45779 m .46552 .44339 L .48294 .41062 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.004 w
.42721 .51471 m
.4278 .51403 L
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.48294 .41062 m .51117 .43173 L .48474 .45779 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.004 w
.42524 .51699 m
.42583 .5163 L
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.004 w
.42325 .51929 m
.42385 .5186 L
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.004 w
.42125 .5216 m
.42185 .52091 L
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.004 w
.41924 .52393 m
.41984 .52323 L
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.004 w
.41721 .52628 m
.41782 .52558 L
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.004 w
.41516 .52865 m
.41578 .52794 L
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.39527 .55165 m
.41372 .53032 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .20416 .43895 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39527 .55165 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.542636)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.542636)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4597 .43242 m .47603 .45409 L .49579 .43361 L p
1 g
F P
s
P
p
.002 w
.49579 .43361 m .48469 .41885 L .4597 .43242 L p
1 g
F P
s
P
p
.002 w
.51093 .4442 m .49579 .43361 L .47603 .45409 L p
1 g
F P
s
P
p
.002 w
.48469 .41885 m .49579 .43361 L .51563 .41309 L p
1 g
F P
s
P
p
.002 w
.49579 .43361 m .51093 .4442 L .52331 .41845 L p
1 g
F P
s
P
p
.002 w
.52331 .41845 m .51563 .41309 L .49579 .43361 L p
1 g
F P
s
P
p
.002 w
.47603 .45409 m .49826 .46966 L .51093 .4442 L p
1 g
F P
s
P
p
.002 w
.52853 .4495 m .51093 .4442 L .49826 .46966 L p
1 g
F P
s
P
p
.002 w
.51093 .4442 m .52853 .4495 L .53225 .42111 L p
1 g
F P
s
P
p
.002 w
.53225 .42111 m .52331 .41845 L .51093 .4442 L p
1 g
F P
s
P
p
.002 w
.45097 .40687 m .4597 .43242 L .48469 .41885 L p
1 g
F P
s
P
p
.002 w
.48469 .41885 m .4788 .40146 L .45097 .40687 L p
1 g
F P
s
P
p
.002 w
.4788 .40146 m .48469 .41885 L .51 .40559 L p
1 g
F P
s
P
p
.002 w
.51563 .41309 m .51 .40559 L .48469 .41885 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .51 .40559 L .51563 .41309 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .51563 .41309 L .52331 .41845 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .52331 .41845 L .53225 .42111 L closepath p
1 g
F P
s
P
p
.002 w
.51 .40559 m .50704 .39676 L .4788 .40146 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .50704 .39676 L .51 .40559 L closepath p
1 g
F P
s
P
p
.002 w
.54147 .42078 m .53225 .42111 L .52853 .4495 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .53225 .42111 L .54147 .42078 L closepath p
1 g
F P
s
P
p
.002 w
.43549 .44605 m .45671 .47414 L .47603 .45409 L p
1 g
F P
s
P
p
.002 w
.47603 .45409 m .4597 .43242 L .43549 .44605 L p
1 g
F P
s
P
p
.002 w
.49826 .46966 m .47603 .45409 L .45671 .47414 L p
1 g
F P
s
P
p
.002 w
.49826 .46966 m .52411 .47751 L .52853 .4495 L p
1 g
F P
s
P
p
.002 w
.54674 .44892 m .52853 .4495 L .52411 .47751 L p
1 g
F P
s
P
p
.002 w
.52853 .4495 m .54674 .44892 L .54147 .42078 L p
1 g
F P
s
P
p
.002 w
.47878 .38326 m .4788 .40146 L .50704 .39676 L p
1 g
F P
s
P
p
.002 w
.50704 .39676 m .50707 .38755 L .47878 .38326 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .50707 .38755 L .50704 .39676 L closepath p
1 g
F P
s
P
p
.002 w
.45083 .38009 m .45097 .40687 L .4788 .40146 L p
1 g
F P
s
P
p
.002 w
.4788 .40146 m .47878 .38326 L .45083 .38009 L p
1 g
F P
s
P
p
.002 w
.45671 .47414 m .48554 .49437 L .49826 .46966 L p
1 g
F P
s
P
p
.002 w
.52411 .47751 m .49826 .46966 L .48554 .49437 L p
1 g
F P
s
P
p
.002 w
.42407 .41292 m .43549 .44605 L .4597 .43242 L p
1 g
F P
s
P
p
.002 w
.4597 .43242 m .45097 .40687 L .42407 .41292 L p
1 g
F P
s
P
p
.002 w
.54999 .41748 m .54147 .42078 L .54674 .44892 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .54147 .42078 L .54999 .41748 L closepath p
1 g
F P
s
P
p
.002 w
.48467 .36618 m .47878 .38326 L .50707 .38755 L p
1 g
F P
s
P
p
.002 w
.50707 .38755 m .5101 .37893 L .48467 .36618 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .5101 .37893 L .50707 .38755 L closepath p
1 g
F P
s
P
p
.002 w
.52411 .47751 m .5509 .47677 L .54674 .44892 L p
1 g
F P
s
P
p
.002 w
.56363 .44247 m .54674 .44892 L .5509 .47677 L p
1 g
F P
s
P
p
.002 w
.54674 .44892 m .56363 .44247 L .54999 .41748 L p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .54999 .41748 L .5569 .41154 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .5569 .41154 L .56142 .40361 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .56142 .40361 L .56307 .39453 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .56307 .39453 L .56163 .3853 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .56163 .3853 L .55726 .37692 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .55726 .37692 L .55044 .37033 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .55044 .37033 L .54192 .36625 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .54192 .36625 L .53263 .36512 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .53263 .36512 L .5236 .36705 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .5236 .36705 L .51581 .37184 L closepath p
1 g
F P
s
P
p
.002 w
.53519 .39288 m .51581 .37184 L .5101 .37893 L closepath p
1 g
F P
s
P
p
.002 w
.5569 .41154 m .54999 .41748 L .56363 .44247 L p
1 g
F P
s
P
p
.002 w
.45937 .35489 m .45083 .38009 L .47878 .38326 L p
1 g
F P
s
P
p
.002 w
.47878 .38326 m .48467 .36618 L .45937 .35489 L p
1 g
F P
s
P
p
.002 w
.4959 .35207 m .48467 .36618 L .5101 .37893 L p
1 g
F P
s
P
p
.002 w
.5101 .37893 m .51581 .37184 L .4959 .35207 L p
1 g
F P
s
P
p
.002 w
.48554 .49437 m .51906 .50465 L .52411 .47751 L p
1 g
F P
s
P
p
.002 w
.5509 .47677 m .52411 .47751 L .51906 .50465 L p
1 g
F P
s
P
p
.002 w
.42374 .37813 m .42407 .41292 L .45097 .40687 L p
1 g
F P
s
P
p
.002 w
.45097 .40687 m .45083 .38009 L .42374 .37813 L p
1 g
F P
s
P
p
.002 w
.56363 .44247 m .57736 .4308 L .5569 .41154 L p
1 g
F P
s
P
p
.002 w
.56142 .40361 m .5569 .41154 L .57736 .4308 L p
1 g
F P
s
P
p
.002 w
.5113 .34251 m .4959 .35207 L .51581 .37184 L p
1 g
F P
s
P
p
.002 w
.51581 .37184 m .5236 .36705 L .5113 .34251 L p
1 g
F P
s
P
p
.002 w
.41251 .45949 m .43818 .49341 L .45671 .47414 L p
1 g
F P
s
P
p
.002 w
.45671 .47414 m .43549 .44605 L .41251 .45949 L p
1 g
F P
s
P
p
.002 w
.48554 .49437 m .45671 .47414 L .43818 .49341 L p
1 g
F P
s
P
p
.002 w
.5509 .47677 m .57583 .4674 L .56363 .44247 L p
1 g
F P
s
P
p
.002 w
.57736 .4308 m .56363 .44247 L .57583 .4674 L p
1 g
F P
s
P
p
.002 w
.43818 .49341 m .47298 .51787 L .48554 .49437 L p
1 g
F P
s
P
p
.002 w
.51906 .50465 m .48554 .49437 L .47298 .51787 L p
1 g
F P
s
P
p
.002 w
.47582 .33398 m .45937 .35489 L .48467 .36618 L p
1 g
F P
s
P
p
.002 w
.48467 .36618 m .4959 .35207 L .47582 .33398 L p
1 g
F P
s
P
p
.002 w
.39862 .41949 m .41251 .45949 L .43549 .44605 L p
1 g
F P
s
P
p
.002 w
.43549 .44605 m .42407 .41292 L .39862 .41949 L p
1 g
F P
s
P
p
.002 w
.57736 .4308 m .58643 .41512 L .56142 .40361 L p
1 g
F P
s
P
p
.002 w
.56307 .39453 m .56142 .40361 L .58643 .41512 L p
1 g
F P
s
P
p
.002 w
.52923 .33857 m .5113 .34251 L .5236 .36705 L p
1 g
F P
s
P
p
.002 w
.5236 .36705 m .53263 .36512 L .52923 .33857 L p
1 g
F P
s
P
p
.002 w
.51906 .50465 m .55387 .50382 L .5509 .47677 L p
1 g
F P
s
P
p
.002 w
.57583 .4674 m .5509 .47677 L .55387 .50382 L p
1 g
F P
s
P
p
.002 w
.43469 .34529 m .42374 .37813 L .45083 .38009 L p
1 g
F P
s
P
p
.002 w
.45083 .38009 m .45937 .35489 L .43469 .34529 L p
1 g
F P
s
P
p
.002 w
.58643 .41512 m .58977 .3971 L .56307 .39453 L p
1 g
F P
s
P
p
.002 w
.56163 .3853 m .56307 .39453 L .58977 .3971 L p
1 g
F P
s
P
p
.002 w
.54772 .34076 m .52923 .33857 L .53263 .36512 L p
1 g
F P
s
P
p
.002 w
.53263 .36512 m .54192 .36625 L .54772 .34076 L p
1 g
F P
s
P
p
.002 w
.58977 .3971 m .58698 .37871 L .56163 .3853 L p
1 g
F P
s
P
p
.002 w
.55726 .37692 m .56163 .3853 L .58698 .37871 L p
1 g
F P
s
P
p
.002 w
.47298 .51787 m .51346 .53039 L .51906 .50465 L p
1 g
F P
s
P
p
.002 w
.55387 .50382 m .51906 .50465 L .51346 .53039 L p
1 g
F P
s
P
p
.002 w
.56472 .34887 m .54772 .34076 L .54192 .36625 L p
1 g
F P
s
P
p
.002 w
.54192 .36625 m .55044 .37033 L .56472 .34887 L p
1 g
F P
s
P
p
.002 w
.57583 .4674 m .59619 .4503 L .57736 .4308 L p
1 g
F P
s
P
p
.002 w
.58643 .41512 m .57736 .4308 L .59619 .4503 L p
1 g
F P
s
P
p
.002 w
.39805 .37742 m .39862 .41949 L .42407 .41292 L p
1 g
F P
s
P
p
.002 w
.42407 .41292 m .42374 .37813 L .39805 .37742 L p
1 g
F P
s
P
p
.002 w
.58698 .37871 m .57831 .36201 L .55726 .37692 L p
1 g
F P
s
P
p
.002 w
.55044 .37033 m .55726 .37692 L .57831 .36201 L p
1 g
F P
s
P
p
.002 w
.57831 .36201 m .56472 .34887 L .55044 .37033 L p
1 g
F P
s
P
p
.002 w
.49851 .31972 m .47582 .33398 L .4959 .35207 L p
1 g
F P
s
P
p
.002 w
.4959 .35207 m .5113 .34251 L .49851 .31972 L p
1 g
F P
s
P
p
.002 w
.55387 .50382 m .58634 .4918 L .57583 .4674 L p
1 g
F P
s
P
p
.002 w
.59619 .4503 m .57583 .4674 L .58634 .4918 L p
1 g
F P
s
P
p
.002 w
.45597 .31795 m .43469 .34529 L .45937 .35489 L p
1 g
F P
s
P
p
.002 w
.45937 .35489 m .47582 .33398 L .45597 .31795 L p
1 g
F P
s
P
p
.002 w
.59619 .4503 m .60971 .42719 L .58643 .41512 L p
1 g
F P
s
P
p
.002 w
.58977 .3971 m .58643 .41512 L .60971 .42719 L p
1 g
F P
s
P
p
.002 w
.39124 .47248 m .42081 .51149 L .43818 .49341 L p
1 g
F P
s
P
p
.002 w
.43818 .49341 m .41251 .45949 L .39124 .47248 L p
1 g
F P
s
P
p
.002 w
.47298 .51787 m .43818 .49341 L .42081 .51149 L p
1 g
F P
s
P
p
.002 w
.52503 .31379 m .49851 .31972 L .5113 .34251 L p
1 g
F P
s
P
p
.002 w
.5113 .34251 m .52923 .33857 L .52503 .31379 L p
1 g
F P
s
P
p
.002 w
.51346 .53039 m .55555 .52954 L .55387 .50382 L p
1 g
F P
s
P
p
.002 w
.58634 .4918 m .55387 .50382 L .55555 .52954 L p
1 g
F P
s
P
p
.002 w
.42081 .51149 m .46085 .53967 L .47298 .51787 L p
1 g
F P
s
P
p
.002 w
.51346 .53039 m .47298 .51787 L .46085 .53967 L p
1 g
F P
s
P
p
.002 w
.37514 .42648 m .39124 .47248 L .41251 .45949 L p
1 g
F P
s
P
p
.002 w
.41251 .45949 m .39862 .41949 L .37514 .42648 L p
1 g
F P
s
P
p
.002 w
.41111 .33761 m .39805 .37742 L .42374 .37813 L p
1 g
F P
s
P
p
.002 w
.42374 .37813 m .43469 .34529 L .41111 .33761 L p
1 g
F P
s
P
p
.002 w
.60971 .42719 m .61477 .40054 L .58977 .3971 L p
1 g
F P
s
P
p
.002 w
.58698 .37871 m .58977 .3971 L .61477 .40054 L p
1 g
F P
s
P
p
.002 w
.55246 .31696 m .52503 .31379 L .52923 .33857 L p
1 g
F P
s
P
p
.002 w
.52923 .33857 m .54772 .34076 L .55246 .31696 L p
1 g
F P
s
P
p
.002 w
.58634 .4918 m .61298 .46967 L .59619 .4503 L p
1 g
F P
s
P
p
.002 w
.60971 .42719 m .59619 .4503 L .61298 .46967 L p
1 g
F P
s
P
p
.002 w
.48548 .29921 m .45597 .31795 L .47582 .33398 L p
1 g
F P
s
P
p
.002 w
.47582 .33398 m .49851 .31972 L .48548 .29921 L p
1 g
F P
s
P
p
.002 w
.46085 .53967 m .50741 .55418 L .51346 .53039 L p
1 g
F P
s
P
p
.002 w
.55555 .52954 m .51346 .53039 L .50741 .55418 L p
1 g
F P
s
P
p
.002 w
.61477 .40054 m .61071 .37327 L .58698 .37871 L p
1 g
F P
s
P
p
.002 w
.57831 .36201 m .58698 .37871 L .61071 .37327 L p
1 g
F P
s
P
p
.002 w
.57771 .32896 m .55246 .31696 L .54772 .34076 L p
1 g
F P
s
P
p
.002 w
.54772 .34076 m .56472 .34887 L .57771 .32896 L p
1 g
F P
s
P
p
.002 w
.37431 .37803 m .37514 .42648 L .39862 .41949 L p
1 g
F P
s
P
p
.002 w
.39862 .41949 m .39805 .37742 L .37431 .37803 L p
1 g
F P
s
P
p
.002 w
.61071 .37327 m .59789 .34847 L .57831 .36201 L p
1 g
F P
s
P
p
.002 w
.56472 .34887 m .57831 .36201 L .59789 .34847 L p
1 g
F P
s
P
p
.002 w
.59789 .34847 m .57771 .32896 L .56472 .34887 L p
1 g
F P
s
P
p
.002 w
.55555 .52954 m .59492 .51518 L .58634 .4918 L p
1 g
F P
s
P
p
.002 w
.61298 .46967 m .58634 .4918 L .59492 .51518 L p
1 g
F P
s
P
p
.002 w
.43674 .30436 m .41111 .33761 L .43469 .34529 L p
1 g
F P
s
P
p
.002 w
.43469 .34529 m .45597 .31795 L .43674 .30436 L p
1 g
F P
s
P
p
.002 w
.61298 .46967 m .63075 .43962 L .60971 .42719 L p
1 g
F P
s
P
p
.002 w
.61477 .40054 m .60971 .42719 L .63075 .43962 L p
1 g
F P
s
P
p
.002 w
.5201 .29132 m .48548 .29921 L .49851 .31972 L p
1 g
F P
s
P
p
.002 w
.49851 .31972 m .52503 .31379 L .5201 .29132 L p
1 g
F P
s
P
p
.002 w
.37216 .48476 m .405 .528 L .42081 .51149 L p
1 g
F P
s
P
p
.002 w
.42081 .51149 m .39124 .47248 L .37216 .48476 L p
1 g
F P
s
P
p
.002 w
.46085 .53967 m .42081 .51149 L .405 .528 L p
1 g
F P
s
P
p
.002 w
.50741 .55418 m .55588 .55338 L .55555 .52954 L p
1 g
F P
s
P
p
.002 w
.59492 .51518 m .55555 .52954 L .55588 .55338 L p
1 g
F P
s
P
p
.002 w
.38917 .33209 m .37431 .37803 L .39805 .37742 L p
1 g
F P
s
P
p
.002 w
.39805 .37742 m .41111 .33761 L .38917 .33209 L p
1 g
F P
s
P
p
.002 w
.405 .528 m .44939 .55929 L .46085 .53967 L p
1 g
F P
s
P
p
.002 w
.50741 .55418 m .46085 .53967 L .44939 .55929 L p
1 g
F P
s
P
p
.002 w
.35418 .43376 m .37216 .48476 L .39124 .47248 L p
1 g
F P
s
P
p
.002 w
.39124 .47248 m .37514 .42648 L .35418 .43376 L p
1 g
F P
s
P
p
.002 w
.63075 .43962 m .63751 .40482 L .61477 .40054 L p
1 g
F P
s
P
p
.002 w
.61071 .37327 m .61477 .40054 L .63751 .40482 L p
1 g
F P
s
P
p
.002 w
.55601 .29537 m .5201 .29132 L .52503 .31379 L p
1 g
F P
s
P
p
.002 w
.52503 .31379 m .55246 .31696 L .55601 .29537 L p
1 g
F P
s
P
p
.002 w
.59492 .51518 m .62732 .48852 L .61298 .46967 L p
1 g
F P
s
P
p
.002 w
.63075 .43962 m .61298 .46967 L .62732 .48852 L p
1 g
F P
s
P
p
.002 w
.47246 .28146 m .43674 .30436 L .45597 .31795 L p
1 g
F P
s
P
p
.002 w
.45597 .31795 m .48548 .29921 L .47246 .28146 L p
1 g
F P
s
P
p
.002 w
.44939 .55929 m .50101 .5755 L .50741 .55418 L p
1 g
F P
s
P
p
.002 w
.55588 .55338 m .50741 .55418 L .50101 .5755 L p
1 g
F P
s
P
p
.002 w
.63751 .40482 m .6323 .36913 L .61071 .37327 L p
1 g
F P
s
P
p
.002 w
.59789 .34847 m .61071 .37327 L .6323 .36913 L p
1 g
F P
s
P
p
.002 w
.35309 .38 m .35418 .43376 L .37514 .42648 L p
1 g
F P
s
P
p
.002 w
.37514 .42648 m .37431 .37803 L .35309 .38 L p
1 g
F P
s
P
p
.002 w
.5891 .31104 m .55601 .29537 L .55246 .31696 L p
1 g
F P
s
P
p
.002 w
.55246 .31696 m .57771 .32896 L .5891 .31104 L p
1 g
F P
s
P
p
.002 w
.55588 .55338 m .60132 .53702 L .59492 .51518 L p
1 g
F P
s
P
p
.002 w
.62732 .48852 m .59492 .51518 L .60132 .53702 L p
1 g
F P
s
P
p
.002 w
.6323 .36913 m .61554 .33661 L .59789 .34847 L p
1 g
F P
s
P
p
.002 w
.57771 .32896 m .59789 .34847 L .61554 .33661 L p
1 g
F P
s
P
p
.002 w
.61554 .33661 m .5891 .31104 L .57771 .32896 L p
1 g
F P
s
P
p
.002 w
.41857 .2936 m .38917 .33209 L .41111 .33761 L p
1 g
F P
s
P
p
.002 w
.41111 .33761 m .43674 .30436 L .41857 .2936 L p
1 g
F P
s
P
p
.002 w
.62732 .48852 m .64905 .45215 L .63075 .43962 L p
1 g
F P
s
P
p
.002 w
.63751 .40482 m .63075 .43962 L .64905 .45215 L p
1 g
F P
s
P
p
.002 w
.51451 .27173 m .47246 .28146 L .48548 .29921 L p
1 g
F P
s
P
p
.002 w
.48548 .29921 m .5201 .29132 L .51451 .27173 L p
1 g
F P
s
P
p
.002 w
.50101 .5755 m .5548 .57477 L .55588 .55338 L p
1 g
F P
s
P
p
.002 w
.60132 .53702 m .55588 .55338 L .5548 .57477 L p
1 g
F P
s
P
p
.002 w
.35576 .49602 m .39112 .54253 L .405 .528 L p
1 g
F P
s
P
p
.002 w
.405 .528 m .37216 .48476 L .35576 .49602 L p
1 g
F P
s
P
p
.002 w
.44939 .55929 m .405 .528 L .39112 .54253 L p
1 g
F P
s
P
p
.002 w
.3694 .32893 m .35309 .38 L .37431 .37803 L p
1 g
F P
s
P
p
.002 w
.37431 .37803 m .38917 .33209 L .3694 .32893 L p
1 g
F P
s
P
p
.002 w
.39112 .54253 m .43886 .57622 L .44939 .55929 L p
1 g
F P
s
P
p
.002 w
.50101 .5755 m .44939 .55929 L .43886 .57622 L p
1 g
F P
s
P
p
.002 w
.33631 .44119 m .35576 .49602 L .37216 .48476 L p
1 g
F P
s
P
p
.002 w
.37216 .48476 m .35418 .43376 L .33631 .44119 L p
1 g
F P
s
P
p
.002 w
.64905 .45215 m .65742 .40989 L .63751 .40482 L p
1 g
F P
s
P
p
.002 w
.6323 .36913 m .63751 .40482 L .65742 .40989 L p
1 g
F P
s
P
p
.002 w
.60132 .53702 m .63883 .50643 L .62732 .48852 L p
1 g
F P
s
P
p
.002 w
.64905 .45215 m .62732 .48852 L .63883 .50643 L p
1 g
F P
s
P
p
.002 w
.55823 .27656 m .51451 .27173 L .5201 .29132 L p
1 g
F P
s
P
p
.002 w
.5201 .29132 m .55601 .29537 L .55823 .27656 L p
1 g
F P
s
P
p
.002 w
.45973 .26699 m .41857 .2936 L .43674 .30436 L p
1 g
F P
s
P
p
.002 w
.43674 .30436 m .47246 .28146 L .45973 .26699 L p
1 g
F P
s
P
p
.002 w
.43886 .57622 m .49437 .59376 L .50101 .5755 L p
1 g
F P
s
P
p
.002 w
.5548 .57477 m .50101 .5755 L .49437 .59376 L p
1 g
F P
s
P
p
.002 w
.65742 .40989 m .65117 .36643 L .6323 .36913 L p
1 g
F P
s
P
p
.002 w
.61554 .33661 m .6323 .36913 L .65117 .36643 L p
1 g
F P
s
P
p
.002 w
.33497 .38335 m .33631 .44119 L .35418 .43376 L p
1 g
F P
s
P
p
.002 w
.35418 .43376 m .35309 .38 L .33497 .38335 L p
1 g
F P
s
P
p
.002 w
.59857 .29561 m .55823 .27656 L .55601 .29537 L p
1 g
F P
s
P
p
.002 w
.55601 .29537 m .5891 .31104 L .59857 .29561 L p
1 g
F P
s
P
p
.002 w
.5548 .57477 m .60531 .5568 L .60132 .53702 L p
1 g
F P
s
P
p
.002 w
.63883 .50643 m .60132 .53702 L .60531 .5568 L p
1 g
F P
s
P
p
.002 w
.40191 .28605 m .3694 .32893 L .38917 .33209 L p
1 g
F P
s
P
p
.002 w
.38917 .33209 m .41857 .2936 L .40191 .28605 L p
1 g
F P
s
P
p
.002 w
.65117 .36643 m .63081 .32679 L .61554 .33661 L p
1 g
F P
s
P
p
.002 w
.5891 .31104 m .61554 .33661 L .63081 .32679 L p
1 g
F P
s
P
p
.002 w
.63081 .32679 m .59857 .29561 L .5891 .31104 L p
1 g
F P
s
P
p
.002 w
.63883 .50643 m .66409 .46452 L .64905 .45215 L p
1 g
F P
s
P
p
.002 w
.65742 .40989 m .64905 .45215 L .66409 .46452 L p
1 g
F P
s
P
p
.002 w
.50834 .25559 m .45973 .26699 L .47246 .28146 L p
1 g
F P
s
P
p
.002 w
.47246 .28146 m .51451 .27173 L .50834 .25559 L p
1 g
F P
s
P
p
.002 w
.49437 .59376 m .55226 .59313 L .5548 .57477 L p
1 g
F P
s
P
p
.002 w
.60531 .5568 m .5548 .57477 L .55226 .59313 L p
1 g
F P
s
P
p
.002 w
.35235 .32833 m .33497 .38335 L .35309 .38 L p
1 g
F P
s
P
p
.002 w
.35309 .38 m .3694 .32893 L .35235 .32833 L p
1 g
F P
s
P
p
.002 w
.34253 .50598 m .37959 .55465 L .39112 .54253 L p
1 g
F P
s
P
p
.002 w
.39112 .54253 m .35576 .49602 L .34253 .50598 L p
1 g
F P
s
P
p
.002 w
.43886 .57622 m .39112 .54253 L .37959 .55465 L p
1 g
F P
s
P
p
.002 w
.37959 .55465 m .42956 .58996 L .43886 .57622 L p
1 g
F P
s
P
p
.002 w
.49437 .59376 m .43886 .57622 L .42956 .58996 L p
1 g
F P
s
P
p
.002 w
.60531 .5568 m .64711 .52297 L .63883 .50643 L p
1 g
F P
s
P
p
.002 w
.66409 .46452 m .63883 .50643 L .64711 .52297 L p
1 g
F P
s
P
p
.002 w
.32208 .44861 m .34253 .50598 L .35576 .49602 L p
1 g
F P
s
P
p
.002 w
.35576 .49602 m .33631 .44119 L .32208 .44861 L p
1 g
F P
s
P
p
.002 w
.66409 .46452 m .67391 .41568 L .65742 .40989 L p
1 g
F P
s
P
p
.002 w
.65117 .36643 m .65742 .40989 L .67391 .41568 L p
1 g
F P
s
P
p
.002 w
.44759 .25631 m .40191 .28605 L .41857 .2936 L p
1 g
F P
s
P
p
.002 w
.41857 .2936 m .45973 .26699 L .44759 .25631 L p
1 g
F P
s
P
p
.002 w
.559 .26109 m .50834 .25559 L .51451 .27173 L p
1 g
F P
s
P
p
.002 w
.51451 .27173 m .55823 .27656 L .559 .26109 L p
1 g
F P
s
P
p
.002 w
.42956 .58996 m .48765 .6084 L .49437 .59376 L p
1 g
F P
s
P
p
.002 w
.55226 .59313 m .49437 .59376 L .48765 .6084 L p
1 g
F P
s
P
p
.002 w
.32054 .38806 m .32208 .44861 L .33631 .44119 L p
1 g
F P
s
P
p
.002 w
.33631 .44119 m .33497 .38335 L .32054 .38806 L p
1 g
F P
s
P
p
.002 w
.67391 .41568 m .66678 .36532 L .65117 .36643 L p
1 g
F P
s
P
p
.002 w
.63081 .32679 m .65117 .36643 L .66678 .36532 L p
1 g
F P
s
P
p
.002 w
.55226 .59313 m .60668 .57396 L .60531 .5568 L p
1 g
F P
s
P
p
.002 w
.64711 .52297 m .60531 .5568 L .60668 .57396 L p
1 g
F P
s
P
p
.002 w
.60581 .28315 m .559 .26109 L .55823 .27656 L p
1 g
F P
s
P
p
.002 w
.55823 .27656 m .59857 .29561 L .60581 .28315 L p
1 g
F P
s
P
p
.002 w
.38723 .28205 m .35235 .32833 L .3694 .32893 L p
1 g
F P
s
P
p
.002 w
.3694 .32893 m .40191 .28605 L .38723 .28205 L p
1 g
F P
s
P
p
.002 w
.66678 .36532 m .6432 .31932 L .63081 .32679 L p
1 g
F P
s
P
p
.002 w
.59857 .29561 m .63081 .32679 L .6432 .31932 L p
1 g
F P
s
P
p
.002 w
.6432 .31932 m .60581 .28315 L .59857 .29561 L p
1 g
F P
s
P
p
.002 w
.64711 .52297 m .67534 .47645 L .66409 .46452 L p
1 g
F P
s
P
p
.002 w
.67391 .41568 m .66409 .46452 L .67534 .47645 L p
1 g
F P
s
P
p
.002 w
.50171 .24349 m .44759 .25631 L .45973 .26699 L p
1 g
F P
s
P
p
.002 w
.45973 .26699 m .50834 .25559 L .50171 .24349 L p
1 g
F P
s
P
p
.002 w
.48765 .6084 m .54824 .60788 L .55226 .59313 L p
1 g
F P
s
P
p
.002 w
.60668 .57396 m .55226 .59313 L .54824 .60788 L p
1 g
F P
s
P
p
.002 w
.3386 .33044 m .32054 .38806 L .33497 .38335 L p
1 g
F P
s
P
p
.002 w
.33497 .38335 m .35235 .32833 L .3386 .33044 L p
1 g
F P
s
P
p
.002 w
.33297 .51433 m .3708 .56396 L .37959 .55465 L p
1 g
F P
s
P
p
.002 w
.37959 .55465 m .34253 .50598 L .33297 .51433 L p
1 g
F P
s
P
p
.002 w
.42956 .58996 m .37959 .55465 L .3708 .56396 L p
1 g
F P
s
P
p
.002 w
.60668 .57396 m .65179 .53767 L .64711 .52297 L p
1 g
F P
s
P
p
.002 w
.67534 .47645 m .64711 .52297 L .65179 .53767 L p
1 g
F P
s
P
p
.002 w
.3708 .56396 m .42176 .6 L .42956 .58996 L p
1 g
F P
s
P
p
.002 w
.48765 .6084 m .42956 .58996 L .42176 .6 L p
1 g
F P
s
P
p
.002 w
.67534 .47645 m .68641 .42207 L .67391 .41568 L p
1 g
F P
s
P
p
.002 w
.66678 .36532 m .67391 .41568 L .68641 .42207 L p
1 g
F P
s
P
p
.002 w
.43639 .24989 m .38723 .28205 L .40191 .28605 L p
1 g
F P
s
P
p
.002 w
.40191 .28605 m .44759 .25631 L .43639 .24989 L p
1 g
F P
s
P
p
.002 w
.31204 .45584 m .33297 .51433 L .34253 .50598 L p
1 g
F P
s
P
p
.002 w
.34253 .50598 m .32208 .44861 L .31204 .45584 L p
1 g
F P
s
P
p
.002 w
.55822 .24955 m .50171 .24349 L .50834 .25559 L p
1 g
F P
s
P
p
.002 w
.50834 .25559 m .559 .26109 L .55822 .24955 L p
1 g
F P
s
P
p
.002 w
.42176 .6 m .48099 .61888 L .48765 .6084 L p
1 g
F P
s
P
p
.002 w
.54824 .60788 m .48765 .6084 L .48099 .61888 L p
1 g
F P
s
P
p
.002 w
.54824 .60788 m .60525 .58795 L .60668 .57396 L p
1 g
F P
s
P
p
.002 w
.65179 .53767 m .60668 .57396 L .60525 .58795 L p
1 g
F P
s
P
p
.002 w
.31038 .39412 m .31204 .45584 L .32208 .44861 L p
1 g
F P
s
P
p
.002 w
.32208 .44861 m .32054 .38806 L .31038 .39412 L p
1 g
F P
s
P
p
.002 w
.68641 .42207 m .67854 .36591 L .66678 .36532 L p
1 g
F P
s
P
p
.002 w
.6432 .31932 m .66678 .36532 L .67854 .36591 L p
1 g
F P
s
P
p
.002 w
.6105 .27414 m .55822 .24955 L .559 .26109 L p
1 g
F P
s
P
p
.002 w
.559 .26109 m .60581 .28315 L .6105 .27414 L p
1 g
F P
s
P
p
.002 w
.37501 .28192 m .3386 .33044 L .35235 .32833 L p
1 g
F P
s
P
p
.002 w
.35235 .32833 m .38723 .28205 L .37501 .28192 L p
1 g
F P
s
P
p
.002 w
.65179 .53767 m .68234 .48761 L .67534 .47645 L p
1 g
F P
s
P
p
.002 w
.68641 .42207 m .67534 .47645 L .68234 .48761 L p
1 g
F P
s
P
p
.002 w
.67854 .36591 m .65226 .31454 L .6432 .31932 L p
1 g
F P
s
P
p
.002 w
.60581 .28315 m .6432 .31932 L .65226 .31454 L p
1 g
F P
s
P
p
.002 w
.65226 .31454 m .6105 .27414 L .60581 .28315 L p
1 g
F P
s
P
p
.002 w
.49476 .23597 m .43639 .24989 L .44759 .25631 L p
1 g
F P
s
P
p
.002 w
.44759 .25631 m .50171 .24349 L .49476 .23597 L p
1 g
F P
s
P
p
.002 w
.48099 .61888 m .54277 .61844 L .54824 .60788 L p
1 g
F P
s
P
p
.002 w
.60525 .58795 m .54824 .60788 L .54277 .61844 L p
1 g
F P
s
P
p
.002 w
.3287 .33537 m .31038 .39412 L .32054 .38806 L p
1 g
F P
s
P
p
.002 w
.32054 .38806 m .3386 .33044 L .3287 .33537 L p
1 g
F P
s
P
p
.002 w
.32755 .52075 m .36514 .57004 L .3708 .56396 L p
1 g
F P
s
P
p
.002 w
.3708 .56396 m .33297 .51433 L .32755 .52075 L p
1 g
F P
s
P
p
.002 w
.42176 .6 m .3708 .56396 L .36514 .57004 L p
1 g
F P
s
P
p
.002 w
.60525 .58795 m .65255 .55005 L .65179 .53767 L p
1 g
F P
s
P
p
.002 w
.68234 .48761 m .65179 .53767 L .65255 .55005 L p
1 g
F P
s
P
p
.002 w
.42647 .24815 m .37501 .28192 L .38723 .28205 L p
1 g
F P
s
P
p
.002 w
.38723 .28205 m .43639 .24989 L .42647 .24815 L p
1 g
F P
s
P
p
.002 w
.68234 .48761 m .69437 .42896 L .68641 .42207 L p
1 g
F P
s
P
p
.002 w
.67854 .36591 m .68641 .42207 L .69437 .42896 L p
1 g
F P
s
P
p
.002 w
.36514 .57004 m .41576 .60586 L .42176 .6 L p
1 g
F P
s
P
p
.002 w
.48099 .61888 m .42176 .6 L .41576 .60586 L p
1 g
F P
s
P
p
.002 w
.30672 .46268 m .32755 .52075 L .33297 .51433 L p
1 g
F P
s
P
p
.002 w
.33297 .51433 m .31204 .45584 L .30672 .46268 L p
1 g
F P
s
P
p
.002 w
.55582 .24246 m .49476 .23597 L .50171 .24349 L p
1 g
F P
s
P
p
.002 w
.50171 .24349 m .55822 .24955 L .55582 .24246 L p
1 g
F P
s
P
p
.002 w
.41576 .60586 m .47457 .62465 L .48099 .61888 L p
1 g
F P
s
P
p
.002 w
.54277 .61844 m .48099 .61888 L .47457 .62465 L p
1 g
F P
s
P
p
.002 w
.54277 .61844 m .60089 .59821 L .60525 .58795 L p
1 g
F P
s
P
p
.002 w
.65255 .55005 m .60525 .58795 L .60089 .59821 L p
1 g
F P
s
P
p
.002 w
.30502 .40143 m .30672 .46268 L .31204 .45584 L p
1 g
F P
s
P
p
.002 w
.31204 .45584 m .31038 .39412 L .30502 .40143 L p
1 g
F P
s
P
p
.002 w
.69437 .42896 m .68592 .36828 L .67854 .36591 L p
1 g
F P
s
P
p
.002 w
.65226 .31454 m .67854 .36591 L .68592 .36828 L p
1 g
F P
s
P
p
.002 w
.36575 .28589 m .3287 .33537 L .3386 .33044 L p
1 g
F P
s
P
p
.002 w
.3386 .33044 m .37501 .28192 L .36575 .28589 L p
1 g
F P
s
P
p
.002 w
.61236 .26904 m .55582 .24246 L .55822 .24955 L p
1 g
F P
s
P
p
.002 w
.55822 .24955 m .6105 .27414 L .61236 .26904 L p
1 g
F P
s
P
p
.002 w
.65255 .55005 m .68463 .49767 L .68234 .48761 L p
1 g
F P
s
P
p
.002 w
.69437 .42896 m .68234 .48761 L .68463 .49767 L p
1 g
F P
s
P
p
.002 w
.68592 .36828 m .65753 .31273 L .65226 .31454 L p
1 g
F P
s
P
p
.002 w
.6105 .27414 m .65226 .31454 L .65753 .31273 L p
1 g
F P
s
P
p
.002 w
.65753 .31273 m .61236 .26904 L .6105 .27414 L p
1 g
F P
s
P
p
.002 w
.48766 .23351 m .42647 .24815 L .43639 .24989 L p
1 g
F P
s
P
p
.002 w
.43639 .24989 m .49476 .23597 L .48766 .23351 L p
1 g
F P
s
P
p
.002 w
.47457 .62465 m .53588 .62426 L .54277 .61844 L p
1 g
F P
s
P
p
.002 w
.60089 .59821 m .54277 .61844 L .53588 .62426 L p
1 g
F P
s
P
p
.002 w
.32315 .34316 m .30502 .40143 L .31038 .39412 L p
1 g
F P
s
P
p
.002 w
.31038 .39412 m .3287 .33537 L .32315 .34316 L p
1 g
F P
s
P
p
.002 w
.60089 .59821 m .64913 .55965 L .65255 .55005 L p
1 g
F P
s
P
p
.002 w
.68463 .49767 m .65255 .55005 L .64913 .55965 L p
1 g
F P
s
P
p
.002 w
.32667 .52494 m .36297 .57253 L .36514 .57004 L p
1 g
F P
s
P
p
.002 w
.36514 .57004 m .32755 .52075 L .32667 .52494 L p
1 g
F P
s
P
p
.002 w
.41576 .60586 m .36514 .57004 L .36297 .57253 L p
1 g
F P
s
P
p
.002 w
.41818 .25145 m .36575 .28589 L .37501 .28192 L p
1 g
F P
s
P
p
.002 w
.37501 .28192 m .42647 .24815 L .41818 .25145 L p
1 g
F P
s
P
p
.002 w
.68463 .49767 m .69729 .43619 L .69437 .42896 L p
1 g
F P
s
P
p
.002 w
.68592 .36828 m .69437 .42896 L .69729 .43619 L p
1 g
F P
s
P
p
.002 w
.36297 .57253 m .41184 .60711 L .41576 .60586 L p
1 g
F P
s
P
p
.002 w
.47457 .62465 m .41576 .60586 L .41184 .60711 L p
1 g
F P
s
P
p
.002 w
.55175 .24032 m .48766 .23351 L .49476 .23597 L p
1 g
F P
s
P
p
.002 w
.49476 .23597 m .55582 .24246 L .55175 .24032 L p
1 g
F P
s
P
p
.002 w
.30656 .46892 m .32667 .52494 L .32755 .52075 L p
1 g
F P
s
P
p
.002 w
.32755 .52075 m .30672 .46268 L .30656 .46892 L p
1 g
F P
s
P
p
.004 w
.2919 .33315 m
.30074 .33728 L
s
P
p
.004 w
.2488 .31299 m
.2919 .33315 L
s
P
p
.002 w
.53588 .62426 m .59354 .60424 L .60089 .59821 L p
1 g
F P
s
P
p
.002 w
.64913 .55965 m .60089 .59821 L .59354 .60424 L p
1 g
F P
s
P
p
.002 w
.41184 .60711 m .46857 .62525 L .47457 .62465 L p
1 g
F P
s
P
p
.002 w
.53588 .62426 m .47457 .62465 L .46857 .62525 L p
1 g
F P
s
P
p
.002 w
.30492 .40988 m .30656 .46892 L .30672 .46268 L p
1 g
F P
s
P
p
.002 w
.30672 .46268 m .30502 .40143 L .30492 .40988 L p
1 g
F P
s
P
p
.002 w
.35988 .29411 m .32315 .34316 L .3287 .33537 L p
1 g
F P
s
P
p
.002 w
.3287 .33537 m .36575 .28589 L .35988 .29411 L p
1 g
F P
s
P
p
.002 w
.69729 .43619 m .68843 .3725 L .68592 .36828 L p
1 g
F P
s
P
p
.002 w
.65753 .31273 m .68592 .36828 L .68843 .3725 L p
1 g
F P
s
P
p
.002 w
.61114 .26824 m .55175 .24032 L .55582 .24246 L p
1 g
F P
s
P
p
.002 w
.55582 .24246 m .61236 .26904 L .61114 .26824 L p
1 g
F P
s
P
p
.002 w
.64913 .55965 m .68184 .50628 L .68463 .49767 L p
1 g
F P
s
P
p
.002 w
.69729 .43619 m .68463 .49767 L .68184 .50628 L p
1 g
F P
s
P
p
.002 w
.4806 .23654 m .41818 .25145 L .42647 .24815 L p
1 g
F P
s
P
p
.002 w
.42647 .24815 m .48766 .23351 L .4806 .23654 L p
1 g
F P
s
P
p
.002 w
.68843 .3725 m .65861 .31415 L .65753 .31273 L p
1 g
F P
s
P
p
.002 w
.61236 .26904 m .65753 .31273 L .65861 .31415 L p
1 g
F P
s
P
p
.002 w
.65861 .31415 m .61114 .26824 L .61236 .26904 L p
1 g
F P
s
P
p
.002 w
.46857 .62525 m .52768 .62489 L .53588 .62426 L p
1 g
F P
s
P
p
.002 w
.59354 .60424 m .53588 .62426 L .52768 .62489 L p
1 g
F P
s
P
p
.002 w
.32241 .35377 m .30492 .40988 L .30502 .40143 L p
1 g
F P
s
P
p
.002 w
.30502 .40143 m .32315 .34316 L .32241 .35377 L p
1 g
F P
s
P
p
.004 w
.30074 .33728 m
.31418 .34357 L
s
P
p
.002 w
.59354 .60424 m .64136 .56602 L .64913 .55965 L p
1 g
F P
s
P
p
.002 w
.68184 .50628 m .64913 .55965 L .64136 .56602 L p
1 g
F P
s
P
p
.002 w
.41188 .26002 m .35988 .29411 L .36575 .28589 L p
1 g
F P
s
P
p
.002 w
.36575 .28589 m .41818 .25145 L .41188 .26002 L p
1 g
F P
s
P
p
.002 w
.33067 .52665 m .36457 .57111 L .36297 .57253 L p
1 g
F P
s
P
p
.002 w
.36297 .57253 m .32667 .52494 L .33067 .52665 L p
1 g
F P
s
P
p
.002 w
.41184 .60711 m .36297 .57253 L .36457 .57111 L p
1 g
F P
s
P
p
.002 w
.68184 .50628 m .69475 .44357 L .69729 .43619 L p
1 g
F P
s
P
p
.002 w
.68843 .3725 m .69729 .43619 L .69475 .44357 L p
1 g
F P
s
P
p
.002 w
.54603 .24351 m .4806 .23654 L .48766 .23351 L p
1 g
F P
s
P
p
.002 w
.48766 .23351 m .55175 .24032 L .54603 .24351 L p
1 g
F P
s
P
p
.002 w
.36457 .57111 m .41023 .60341 L .41184 .60711 L p
1 g
F P
s
P
p
.002 w
.46857 .62525 m .41184 .60711 L .41023 .60341 L p
1 g
F P
s
P
p
.002 w
.31191 .47434 m .33067 .52665 L .32667 .52494 L p
1 g
F P
s
P
p
.002 w
.32667 .52494 m .30656 .46892 L .31191 .47434 L p
1 g
F P
s
P
p
.002 w
.52768 .62489 m .58321 .60558 L .59354 .60424 L p
1 g
F P
s
P
p
.002 w
.64136 .56602 m .59354 .60424 L .58321 .60558 L p
1 g
F P
s
P
p
.002 w
.41023 .60341 m .46321 .62034 L .46857 .62525 L p
1 g
F P
s
P
p
.002 w
.52768 .62489 m .46857 .62525 L .46321 .62034 L p
1 g
F P
s
P
p
.002 w
.3578 .30662 m .32241 .35377 L .32315 .34316 L p
1 g
F P
s
P
p
.002 w
.32315 .34316 m .35988 .29411 L .3578 .30662 L p
1 g
F P
s
P
p
.002 w
.31042 .41928 m .31191 .47434 L .30656 .46892 L p
1 g
F P
s
P
p
.002 w
.30656 .46892 m .30492 .40988 L .31042 .41928 L p
1 g
F P
s
P
p
.002 w
.69475 .44357 m .68568 .37857 L .68843 .3725 L p
1 g
F P
s
P
p
.002 w
.65861 .31415 m .68843 .3725 L .68568 .37857 L p
1 g
F P
s
P
p
.002 w
.60669 .27205 m .54603 .24351 L .55175 .24032 L p
1 g
F P
s
P
p
.002 w
.55175 .24032 m .61114 .26824 L .60669 .27205 L p
1 g
F P
s
P
p
.002 w
.64136 .56602 m .67375 .51309 L .68184 .50628 L p
1 g
F P
s
P
p
.002 w
.69475 .44357 m .68184 .50628 L .67375 .51309 L p
1 g
F P
s
P
p
.002 w
.4738 .2453 m .41188 .26002 L .41818 .25145 L p
1 g
F P
s
P
p
.002 w
.41818 .25145 m .4806 .23654 L .4738 .2453 L p
1 g
F P
s
P
p
.002 w
.68568 .37857 m .65519 .31896 L .65861 .31415 L p
1 g
F P
s
P
p
.002 w
.61114 .26824 m .65861 .31415 L .65519 .31896 L p
1 g
F P
s
P
p
.002 w
.65519 .31896 m .60669 .27205 L .61114 .26824 L p
1 g
F P
s
P
p
.002 w
.46321 .62034 m .51834 .61996 L .52768 .62489 L p
1 g
F P
s
P
p
.002 w
.58321 .60558 m .52768 .62489 L .51834 .61996 L p
1 g
F P
s
P
p
.002 w
.32679 .36705 m .31042 .41928 L .30492 .40988 L p
1 g
F P
s
P
p
.002 w
.30492 .40988 m .32241 .35377 L .32679 .36705 L p
1 g
F P
s
P
p
.002 w
.58321 .60558 m .62918 .56875 L .64136 .56602 L p
1 g
F P
s
P
p
.002 w
.67375 .51309 m .64136 .56602 L .62918 .56875 L p
1 g
F P
s
P
p
.002 w
.40789 .27391 m .3578 .30662 L .35988 .29411 L p
1 g
F P
s
P
p
.002 w
.35988 .29411 m .41188 .26002 L .40789 .27391 L p
1 g
F P
s
P
p
.002 w
.33974 .52565 m .37017 .56556 L .36457 .57111 L p
1 g
F P
s
P
p
.002 w
.36457 .57111 m .33067 .52665 L .33974 .52565 L p
1 g
F P
s
P
p
.002 w
.41023 .60341 m .36457 .57111 L .37017 .56556 L p
1 g
F P
s
P
p
.002 w
.67375 .51309 m .68647 .45089 L .69475 .44357 L p
1 g
F P
s
P
p
.002 w
.68568 .37857 m .69475 .44357 L .68647 .45089 L p
1 g
F P
s
P
p
.002 w
.53871 .25229 m .4738 .2453 L .4806 .23654 L p
1 g
F P
s
P
p
.002 w
.4806 .23654 m .54603 .24351 L .53871 .25229 L p
1 g
F P
s
P
p
.002 w
.37017 .56556 m .41116 .59455 L .41023 .60341 L p
1 g
F P
s
P
p
.002 w
.46321 .62034 m .41023 .60341 L .41116 .59455 L p
1 g
F P
s
P
p
.002 w
.32296 .47871 m .33974 .52565 L .33067 .52665 L p
1 g
F P
s
P
p
.002 w
.33067 .52665 m .31191 .47434 L .32296 .47871 L p
1 g
F P
s
P
p
.002 w
.51834 .61996 m .57003 .6019 L .58321 .60558 L p
1 g
F P
s
P
p
.002 w
.62918 .56875 m .58321 .60558 L .57003 .6019 L p
1 g
F P
s
P
p
.002 w
.35983 .32326 m .32679 .36705 L .32241 .35377 L p
1 g
F P
s
P
p
.002 w
.32241 .35377 m .3578 .30662 L .35983 .32326 L p
1 g
F P
s
P
p
.002 w
.41116 .59455 m .45869 .60969 L .46321 .62034 L p
1 g
F P
s
P
p
.002 w
.51834 .61996 m .46321 .62034 L .45869 .60969 L p
1 g
F P
s
P
p
.002 w
.32171 .4294 m .32296 .47871 L .31191 .47434 L p
1 g
F P
s
P
p
.002 w
.31191 .47434 m .31042 .41928 L .32171 .4294 L p
1 g
F P
s
P
p
.002 w
.68647 .45089 m .6774 .3864 L .68568 .37857 L p
1 g
F P
s
P
p
.002 w
.65519 .31896 m .68568 .37857 L .6774 .3864 L p
1 g
F P
s
P
p
.002 w
.59892 .28067 m .53871 .25229 L .54603 .24351 L p
1 g
F P
s
P
p
.002 w
.54603 .24351 m .60669 .27205 L .59892 .28067 L p
1 g
F P
s
P
p
.002 w
.62918 .56875 m .66025 .51777 L .67375 .51309 L p
1 g
F P
s
P
p
.002 w
.68647 .45089 m .67375 .51309 L .66025 .51777 L p
1 g
F P
s
P
p
.002 w
.46749 .25988 m .40789 .27391 L .41188 .26002 L p
1 g
F P
s
P
p
.002 w
.41188 .26002 m .4738 .2453 L .46749 .25988 L p
1 g
F P
s
P
p
.002 w
.6774 .3864 m .64709 .32725 L .65519 .31896 L p
1 g
F P
s
P
p
.002 w
.60669 .27205 m .65519 .31896 L .64709 .32725 L p
1 g
F P
s
P
p
.002 w
.64709 .32725 m .59892 .28067 L .60669 .27205 L p
1 g
F P
s
P
p
.002 w
.45869 .60969 m .50808 .60927 L .51834 .61996 L p
1 g
F P
s
P
p
.002 w
.57003 .6019 m .51834 .61996 L .50808 .60927 L p
1 g
F P
s
P
p
.002 w
.33647 .38273 m .32171 .4294 L .31042 .41928 L p
1 g
F P
s
P
p
.002 w
.31042 .41928 m .32679 .36705 L .33647 .38273 L p
1 g
F P
s
P
p
.002 w
.57003 .6019 m .61273 .56753 L .62918 .56875 L p
1 g
F P
s
P
p
.002 w
.66025 .51777 m .62918 .56875 L .61273 .56753 L p
1 g
F P
s
P
p
.002 w
.40648 .293 m .35983 .32326 L .3578 .30662 L p
1 g
F P
s
P
p
.002 w
.3578 .30662 m .40789 .27391 L .40648 .293 L p
1 g
F P
s
P
p
.002 w
.66025 .51777 m .67236 .45792 L .68647 .45089 L p
1 g
F P
s
P
p
.002 w
.6774 .3864 m .68647 .45089 L .67236 .45792 L p
1 g
F P
s
P
p
.002 w
.35393 .52179 m .37983 .55579 L .37017 .56556 L p
1 g
F P
s
P
p
.002 w
.37017 .56556 m .33974 .52565 L .35393 .52179 L p
1 g
F P
s
P
p
.002 w
.41116 .59455 m .37017 .56556 L .37983 .55579 L p
1 g
F P
s
P
p
.002 w
.52995 .26673 m .46749 .25988 L .4738 .2453 L p
1 g
F P
s
P
p
.002 w
.4738 .2453 m .53871 .25229 L .52995 .26673 L p
1 g
F P
s
P
p
.002 w
.37983 .55579 m .41475 .58047 L .41116 .59455 L p
1 g
F P
s
P
p
.002 w
.45869 .60969 m .41116 .59455 L .41475 .58047 L p
1 g
F P
s
P
p
.002 w
.33971 .48184 m .35393 .52179 L .33974 .52565 L p
1 g
F P
s
P
p
.002 w
.33974 .52565 m .32296 .47871 L .33971 .48184 L p
1 g
F P
s
P
p
.002 w
.50808 .60927 m .55426 .59301 L .57003 .6019 L p
1 g
F P
s
P
p
.002 w
.61273 .56753 m .57003 .6019 L .55426 .59301 L p
1 g
F P
s
P
p
.002 w
.36611 .34374 m .33647 .38273 L .32679 .36705 L p
1 g
F P
s
P
p
.002 w
.32679 .36705 m .35983 .32326 L .36611 .34374 L p
1 g
F P
s
P
p
.004 w
.35258 .36154 m
.5 .43051 L
s
P
p
.004 w
.33951 .35542 m
.34075 .356 L
s
P
p
.004 w
.31418 .34357 m
.32753 .34982 L
s
P
p
.004 w
.32753 .34982 m
.33332 .35253 L
s
P
p
.004 w
.33332 .35253 m
.33951 .35542 L
s
P
p
.002 w
.41475 .58047 m .45521 .5933 L .45869 .60969 L p
1 g
F P
s
P
p
.002 w
.50808 .60927 m .45869 .60969 L .45521 .5933 L p
1 g
F P
s
P
p
.002 w
.33876 .43994 m .33971 .48184 L .32296 .47871 L p
1 g
F P
s
P
p
.002 w
.32296 .47871 m .32171 .4294 L .33876 .43994 L p
1 g
F P
s
P
p
.002 w
.67236 .45792 m .66351 .39586 L .6774 .3864 L p
1 g
F P
s
P
p
.002 w
.64709 .32725 m .6774 .3864 L .66351 .39586 L p
1 g
F P
s
P
p
.002 w
.61273 .56753 m .64146 .52005 L .66025 .51777 L p
1 g
F P
s
P
p
.002 w
.67236 .45792 m .66025 .51777 L .64146 .52005 L p
1 g
F P
s
P
p
.002 w
.58789 .29411 m .52995 .26673 L .53871 .25229 L p
1 g
F P
s
P
p
.002 w
.53871 .25229 m .59892 .28067 L .58789 .29411 L p
1 g
F P
s
P
p
.002 w
.46192 .28014 m .40648 .293 L .40789 .27391 L p
1 g
F P
s
P
p
.002 w
.40789 .27391 m .46749 .25988 L .46192 .28014 L p
1 g
F P
s
P
p
.002 w
.66351 .39586 m .63426 .33896 L .64709 .32725 L p
1 g
F P
s
P
p
.002 w
.59892 .28067 m .64709 .32725 L .63426 .33896 L p
1 g
F P
s
P
p
.002 w
.63426 .33896 m .58789 .29411 L .59892 .28067 L p
1 g
F P
s
P
p
.002 w
.45521 .5933 m .49717 .59284 L .50808 .60927 L p
1 g
F P
s
P
p
.002 w
.55426 .59301 m .50808 .60927 L .49717 .59284 L p
1 g
F P
s
P
p
.002 w
.35142 .40041 m .33876 .43994 L .32171 .4294 L p
1 g
F P
s
P
p
.002 w
.32171 .4294 m .33647 .38273 L .35142 .40041 L p
1 g
F P
s
P
p
.002 w
.55426 .59301 m .59229 .56218 L .61273 .56753 L p
1 g
F P
s
P
p
.002 w
.64146 .52005 m .61273 .56753 L .59229 .56218 L p
1 g
F P
s
P
p
.002 w
.40784 .31692 m .36611 .34374 L .35983 .32326 L p
1 g
F P
s
P
p
.002 w
.35983 .32326 m .40648 .293 L .40784 .31692 L p
1 g
F P
s
P
p
.002 w
.64146 .52005 m .65254 .46438 L .67236 .45792 L p
1 g
F P
s
P
p
.002 w
.66351 .39586 m .67236 .45792 L .65254 .46438 L p
1 g
F P
s
P
p
.002 w
.51996 .28665 m .46192 .28014 L .46749 .25988 L p
1 g
F P
s
P
p
.002 w
.46749 .25988 m .52995 .26673 L .51996 .28665 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.37306 .51504 m .39347 .54188 L .37983 .55579 L p
1 g
F P
s
P
p
.002 w
.37983 .55579 m .35393 .52179 L .37306 .51504 L p
1 g
F P
s
P
p
.002 w
.41475 .58047 m .37983 .55579 L .39347 .54188 L p
1 g
F P
s
P
p
.002 w
.39347 .54188 m .42104 .56134 L .41475 .58047 L p
1 g
F P
s
P
p
.002 w
.45521 .5933 m .41475 .58047 L .42104 .56134 L p
1 g
F P
s
P
p
.002 w
.36192 .48352 m .37306 .51504 L .35393 .52179 L p
1 g
F P
s
P
p
.002 w
.35393 .52179 m .33971 .48184 L .36192 .48352 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49717 .59284 m .5363 .5789 L .55426 .59301 L p
1 g
F P
s
P
p
.002 w
.59229 .56218 m .55426 .59301 L .5363 .5789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37667 .36752 m .35142 .40041 L .33647 .38273 L p
1 g
F P
s
P
p
.002 w
.33647 .38273 m .36611 .34374 L .37667 .36752 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.42104 .56134 m .45296 .57139 L .45521 .5933 L p
1 g
F P
s
P
p
.002 w
.49717 .59284 m .45521 .5933 L .45296 .57139 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.36128 .45055 m .36192 .48352 L .33971 .48184 L p
1 g
F P
s
P
p
.002 w
.33971 .48184 m .33876 .43994 L .36128 .45055 L p
1 g
F P
s
P
p
.002 w
.59229 .56218 m .61775 .51971 L .64146 .52005 L p
1 g
F P
s
P
p
.002 w
.65254 .46438 m .64146 .52005 L .61775 .51971 L p
1 g
F P
s
P
p
.002 w
.65254 .46438 m .64417 .40673 L .66351 .39586 L p
1 g
F P
s
P
p
.002 w
.63426 .33896 m .66351 .39586 L .64417 .40673 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.57378 .31218 m .51996 .28665 L .52995 .26673 L p
1 g
F P
s
P
p
.002 w
.52995 .26673 m .58789 .29411 L .57378 .31218 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.45732 .30565 m .40784 .31692 L .40648 .293 L p
1 g
F P
s
P
p
.002 w
.40648 .293 m .46192 .28014 L .45732 .30565 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.64417 .40673 m .6169 .35387 L .63426 .33896 L p
1 g
F P
s
P
p
.002 w
.58789 .29411 m .63426 .33896 L .6169 .35387 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45296 .57139 m .45809 .57132 L p
.49717 .59284 L 1 g
F P
s
P
p
.002 w
.49123 .58121 m .49717 .59284 L p
.47183 .57889 L 1 g
F P
s
P
p
.47183 .57889 m .45809 .57132 L .46834 .57438 L 1 g
F
P
p
.002 w
.46834 .57438 m .46872 .57265 L p
.45872 .56865 L 1 g
F P
s
P
p
.002 w
.4626 .57126 m .45296 .57139 L .45274 .56465 L p
1 g
F P
s
P
p
.45872 .56865 m .45536 .56731 L .4626 .57126 L 1 g
F
P
p
.45872 .56865 m .4626 .57126 L .46834 .57438 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48907 .58056 m .48921 .57862 L p
.48003 .57787 L 1 g
F P
s
P
p
.47767 .57945 m .46834 .57438 L .48907 .58056 L 1 g
F
P
p
.47183 .57889 m .46834 .57438 L .47767 .57945 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58056 L p
1 g
F P
s
P
p
.002 w
.491 .58075 m .49123 .58121 L p
.48907 .58056 L 1 g
F P
s
P
p
.47183 .57889 m .48907 .58056 L .49123 .58121 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58002 L p
1 g
F P
s
P
p
.002 w
.53571 .57911 m .49717 .59284 L .491 .58075 L p
1 g
F P
s
P
p
.53128 .57265 m .5109 .58002 L .52269 .57705 L 1 g
F
P
p
.51079 .57862 m .48907 .58056 L .49713 .58135 L 1 g
F
P
p
.002 w
.51109 .58271 m .51079 .57862 L p
.49713 .58135 L 1 g
F P
s
P
p
.002 w
.53174 .57478 m .53128 .57265 L p
.52269 .57705 L 1 g
F P
s
P
p
.002 w
.491 .58075 m .48598 .57092 L p
.5229 .577 L 1 g
F P
s
P
p
.53571 .57911 m .5109 .58002 L .5229 .577 L 1 g
F
P
p
.5109 .58002 m .491 .58075 L .5229 .577 L 1 g
F
P
p
.002 w
.5363 .5789 m .53571 .57911 L p
.5229 .577 L 1 g
F P
s
P
p
.5363 .5789 m .5229 .577 L .52345 .57686 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53174 .57478 L p
1 g
F P
s
P
p
.54854 .56129 m .53174 .57478 L .53194 .57468 L 1 g
F
P
p
.002 w
.56837 .55265 m .5363 .5789 L .53585 .57847 L p
1 g
F P
s
P
p
.002 w
.53585 .57847 m .53194 .57468 L p
.54619 .56606 L 1 g
F P
s
P
p
.56837 .55265 m .53585 .57847 L .54619 .56606 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54904 .56264 L p
1 g
F P
s
P
p
.56075 .54566 m .54904 .56264 L .55597 .55432 L 1 g
F
P
p
.54854 .56129 m .53194 .57468 L .54171 .5678 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.56837 .55265 m .54619 .56606 L .56197 .55354 L 1 g
F
P
p
.54619 .56606 m .53194 .57468 L .54904 .56264 L 1 g
F
P
p
.54619 .56606 m .54904 .56264 L .56197 .55354 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53194 .57468 m .51666 .55983 L p
.55593 .55438 L 1 g
F P
s
P
p
.56197 .55354 m .54904 .56264 L .55593 .55438 L 1 g
F
P
p
.002 w
.53194 .57468 m .5363 .5789 L p
.52668 .57738 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54904 .56264 L p
1 g
F P
s
P
p
.002 w
.54904 .56264 m .54854 .56129 L p
.54171 .5678 L 1 g
F P
s
P
p
.54171 .5678 m .5322 .57686 L .54904 .56264 L 1 g
F
P
p
.54904 .56264 m .53194 .57468 L .55593 .55438 L 1 g
F
P
p
.56075 .54566 m .55597 .55432 L .56064 .54873 L 1 g
F
P
p
.58971 .51663 m .56141 .54787 L .57785 .52218 L 1 g
F
P
p
.56141 .54787 m .56064 .54873 L .56159 .54725 L 1 g
F
P
p
.56141 .54787 m .56159 .54725 L .57785 .52218 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56159 .54725 L p
1 g
F P
s
P
p
.002 w
.58971 .51663 m .56837 .55265 L .56109 .54896 L p
1 g
F P
s
P
p
.002 w
.56109 .54896 m .56064 .54873 L p
.56141 .54787 L 1 g
F P
s
P
p
.58971 .51663 m .56109 .54896 L .56141 .54787 L 1 g
F
P
p
.002 w
.56717 .52826 m .56654 .52734 L p
.56506 .53545 L 1 g
F P
s
P
p
.56654 .52734 m .56159 .54725 L .56506 .53545 L 1 g
F
P
p
.002 w
.56159 .54725 m .56075 .54566 L p
.56064 .54873 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56717 .52826 L p
1 g
F P
s
P
p
.56515 .50826 m .56717 .52826 L .56668 .51815 L 1 g
F
P
p
.002 w
.56064 .54873 m .54168 .53911 L p
.56712 .5272 L 1 g
F P
s
P
p
.57785 .52218 m .56764 .53792 L .56712 .5272 L 1 g
F
P
p
.56764 .53792 m .56064 .54873 L .56712 .5272 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56515 .50826 m .56668 .51815 L .56639 .51232 L 1 g
F
P
p
.59768 .47462 m .56709 .51148 L .56551 .50412 L 1 g
F
P
p
.56709 .51148 m .56639 .51232 L .56607 .50936 L 1 g
F
P
p
.56709 .51148 m .56607 .50936 L .56551 .50412 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50936 L p
1 g
F P
s
P
p
.55661 .4905 m .56607 .50936 L .56204 .50089 L 1 g
F
P
p
.002 w
.56607 .50936 m .56515 .50826 L p
.56639 .51232 L 1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56639 .51232 m .55822 .51081 L p
.56417 .50535 L 1 g
F P
s
P
p
.56551 .50412 m .56607 .50936 L .56417 .50535 L 1 g
F
P
p
.56607 .50936 m .56639 .51232 L .56417 .50535 L 1 g
F
P
p
.55661 .4905 m .56204 .50089 L .5606 .49786 L 1 g
F
P
p
.002 w
.56426 .47793 m .56113 .49495 L p
.5539 .48428 L 1 g
F P
s
P
p
.002 w
.56113 .49495 m .5606 .49786 L p
.55736 .4913 L 1 g
F P
s
P
p
.56113 .49495 m .55736 .4913 L .5539 .48428 L 1 g
F
P
p
.002 w
.55736 .4913 m .55661 .4905 L p
.5606 .49786 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55736 .4913 L p
1 g
F P
s
P
p
.002 w
.55759 .49154 m .55736 .4913 L p
.5606 .49786 L 1 g
F P
s
P
p
.54174 .47608 m .55736 .4913 L .54961 .48378 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55822 .51081 m .52436 .50239 L p
.55158 .4857 L 1 g
F P
s
P
p
.5539 .48428 m .55461 .48863 L .55158 .4857 L 1 g
F
P
p
.55461 .48863 m .55822 .51081 L .55158 .4857 L 1 g
F
P
p
.002 w
.5606 .49786 m .55822 .51081 L p
.5539 .48428 L 1 g
F P
s
P
p
.002 w
.56426 .47793 m .59768 .47462 L p
.56417 .50535 L 1 g
F P
s
P
p
.002 w
.55822 .51081 m .5606 .49786 L p
.56417 .50535 L 1 g
F P
s
P
p
.002 w
.5606 .49786 m .56426 .47793 L p
.56417 .50535 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55759 .49154 L p
1 g
F P
s
P
p
.56204 .50089 m .56713 .51061 L .55759 .49154 L 1 g
F
P
p
.54174 .47608 m .54961 .48378 L .54463 .47896 L 1 g
F
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54463 .47896 m .52836 .47981 L p
.53428 .4729 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .47671 L p
1 g
F P
s
P
p
.52214 .46667 m .54231 .47671 L .53312 .47235 L 1 g
F
P
p
.53616 .47072 m .54231 .47671 L .53428 .4729 L 1 g
F
P
p
.54231 .47671 m .54463 .47896 L .53428 .4729 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.52462 .45666 m .55895 .44411 L p
.53428 .4729 L 1 g
F P
s
P
p
.002 w
.52836 .47981 m .52666 .4693 L p
.53428 .4729 L 1 g
F P
s
P
p
.52214 .46667 m .53312 .47235 L .52666 .4693 L 1 g
F
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52666 .4693 m .52836 .47981 L p
.51738 .46648 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .51139 .46559 L 1 g
F
P
p
.52248 .46723 m .51738 .46648 L .51493 .4635 L 1 g
F
P
p
.52666 .4693 m .51738 .46648 L .52248 .46723 L 1 g
F
P
p
.002 w
.52836 .47981 m .49136 .48016 L p
.51188 .46566 L 1 g
F P
s
P
p
.51493 .4635 m .51738 .46648 L .51188 .46566 L 1 g
F
P
p
.51738 .46648 m .52836 .47981 L .51188 .46566 L 1 g
F
P
p
.5 .4634 m .51139 .46559 L .50204 .46421 L 1 g
F
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50204 .46421 m .48941 .46843 L p
.49176 .46522 L 1 g
F P
s
P
p
.5 .46389 m .50204 .46421 L .49176 .46522 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .49109 .46532 L 1 g
F
P
p
.47786 .46667 m .49109 .46532 L .48802 .46582 L 1 g
F
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48802 .46582 m .48941 .46843 L p
.47518 .46835 L 1 g
F P
s
P
p
.48802 .46582 m .47518 .46835 L .47753 .46721 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46721 L p
1 g
F P
s
P
p
.47518 .46835 m .48941 .46843 L .45764 .47681 L 1 g
F
P
p
.002 w
.47753 .46721 m .47718 .46778 L p
.46806 .47178 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46721 L .46806 .47178 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43147 .50289 m .42423 .49333 L .44685 .48266 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44258 .49136 L p
1 g
F P
s
P
p
.43485 .50826 m .44258 .49136 L .4425 .49153 L 1 g
F
P
p
.002 w
.43553 .50575 m .43147 .50289 L .4425 .49153 L p
1 g
F P
s
P
p
.43872 .49925 m .4425 .49153 L .43879 .49908 L 1 g
F
P
p
.43485 .50826 m .4425 .49153 L .43872 .49925 L 1 g
F
P
p
.002 w
.4425 .49153 m .43147 .50289 L p
.43371 .49995 L 1 g
F P
s
P
p
.43371 .49995 m .44685 .48266 L .44258 .49136 L 1 g
F
P
p
.43371 .49995 m .44258 .49136 L .4425 .49153 L 1 g
F
P
p
.43485 .50826 m .44171 .49229 L .44136 .49304 L 1 g
F
P
p
.002 w
.43147 .50289 m .43415 .50477 L p
.4309 .51585 L 1 g
F P
s
P
p
.002 w
.43415 .50477 m .43553 .50575 L p
.43382 .50948 L 1 g
F P
s
P
p
.4309 .51585 m .43415 .50477 L .43382 .50948 L 1 g
F
P
p
.002 w
.4325 .52874 m .43346 .52734 L p
.43317 .51897 L 1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43291 .53032 m .42995 .53756 L p
.43065 .52166 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43247 .52878 L p
1 g
F P
s
P
p
.43925 .54566 m .43247 .52878 L .43418 .53478 L 1 g
F
P
p
.002 w
.43546 .53928 m .42995 .53756 L .43291 .53032 L p
1 g
F P
s
P
p
.43925 .54566 m .43182 .52972 L .43376 .53479 L 1 g
F
P
p
.002 w
.42995 .53756 m .43142 .53801 L p
.44099 .5538 L 1 g
F P
s
P
p
.002 w
.43142 .53801 m .43546 .53928 L p
.43846 .54715 L 1 g
F P
s
P
p
.44099 .5538 m .43142 .53801 L .43846 .54715 L 1 g
F
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.44513 .55579 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56311 L p
1 g
F P
s
P
p
.46872 .57265 m .45078 .56311 L .45554 .56686 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43846 .54715 L p
1 g
F P
s
P
p
.45006 .56217 m .44099 .5538 L .44257 .55247 L 1 g
F
P
p
.45146 .56129 m .43846 .54715 L .44513 .55579 L 1 g
F
P
p
.43925 .54566 m .43441 .53608 L .43475 .53741 L 1 g
F
P
p
.002 w
.43768 .54864 m .43846 .54715 L p
.43475 .53741 L 1 g
F P
s
P
p
.002 w
.43846 .54715 m .43925 .54566 L p
.43475 .53741 L 1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43546 .53928 m .45207 .54447 L p
.44099 .5538 L 1 g
F P
s
P
p
.002 w
.45296 .57139 m .42104 .56134 L .42995 .53756 L p
1 g
F P
s
P
p
.002 w
.43846 .54715 m .43743 .5491 L p
.44513 .55579 L 1 g
F P
s
P
p
.002 w
.45207 .54447 m .45274 .56465 L p
.45006 .56217 L 1 g
F P
s
P
p
.45006 .56217 m .44257 .55247 L .45207 .54447 L 1 g
F
P
p
.002 w
.45274 .56465 m .45296 .57139 L p
.44336 .55728 L 1 g
F P
s
P
p
.44336 .55728 m .44099 .5538 L .45274 .56465 L 1 g
F
P
p
.002 w
.45078 .56311 m .45025 .56453 L p
.45554 .56686 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56311 L p
1 g
F P
s
P
p
.44513 .55579 m .43743 .5491 L .45078 .56311 L 1 g
F
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45207 .54447 m .43546 .53928 L p
.44129 .50979 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43291 .53032 m .44129 .50979 L p
.43546 .53928 L 1 g
F P
s
P
p
.002 w
.43247 .52878 m .43182 .52972 L p
.43418 .53478 L 1 g
F P
s
P
p
.002 w
.43182 .52972 m .43146 .53025 L p
.43376 .53479 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43382 .50948 L p
1 g
F P
s
P
p
.43256 .52781 m .4309 .51585 L .43349 .51434 L 1 g
F
P
p
.43346 .52734 m .43382 .50948 L .43317 .51897 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43382 .50948 L p
1 g
F P
s
P
p
.002 w
.43382 .50948 m .43485 .50826 L p
.44136 .49304 L 1 g
F P
s
P
p
.44136 .49304 m .44166 .49233 L .43382 .50948 L 1 g
F
P
p
.002 w
.43553 .50575 m .44129 .50979 L p
.4309 .51585 L 1 g
F P
s
P
p
.002 w
.43382 .50948 m .43287 .51061 L p
.43317 .51897 L 1 g
F P
s
P
p
.002 w
.44129 .50979 m .43291 .53032 L p
.43256 .52781 L 1 g
F P
s
P
p
.43256 .52781 m .43349 .51434 L .44129 .50979 L 1 g
F
P
p
.43065 .52166 m .4309 .51585 L .43291 .53032 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43768 .54864 L p
1 g
F P
s
P
p
.43441 .53608 m .43146 .53025 L .43768 .54864 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4325 .52874 L p
1 g
F P
s
P
p
.43317 .51897 m .43287 .51061 L .4325 .52874 L 1 g
F
P
p
.002 w
.4425 .49153 m .44393 .49006 L p
.43553 .50575 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44339 .4905 L p
.45124 .48298 L 1 g
F P
s
P
p
.43553 .50575 m .44393 .49006 L .45314 .48114 L 1 g
F
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45264 .51331 m .44129 .50979 L .45419 .48012 L p
1 g
F P
s
P
p
.002 w
.47508 .509 m .46432 .51304 L .45485 .47949 L p
1 g
F P
s
P
p
.002 w
.4894 .49164 m .48376 .50161 L .45508 .47926 L p
1 g
F P
s
P
p
.002 w
.48941 .46843 m .49136 .48016 L .45537 .47898 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45755 .47685 L p
1 g
F P
s
P
p
.45826 .47608 m .46806 .47178 L .45764 .47681 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.48044 .45455 m .48374 .45774 L .45764 .47681 L p
1 g
F P
s
P
p
.002 w
.45764 .47681 m .45746 .47694 L p
.45755 .47685 L 1 g
F P
s
P
p
.48044 .45455 m .45764 .47681 L .45755 .47685 L 1 g
F
P
p
.002 w
.45755 .47685 m .45755 .47685 L p
.45764 .47681 L 1 g
F P
s
P
p
.002 w
.45755 .47685 m .45826 .47608 L p
.45764 .47681 L 1 g
F P
s
P
p
.002 w
.45755 .47685 m .45755 .47686 L p
.45747 .47694 L 1 g
F P
s
P
p
.44339 .4905 m .45755 .47685 L .45747 .47694 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.4547 .47896 m .47497 .44927 L .48044 .45455 L p
1 g
F P
s
P
p
.002 w
.45746 .47694 m .4547 .47896 L p
.48044 .45455 L 1 g
F P
s
P
p
.44339 .4905 m .45755 .47686 L .45738 .47702 L 1 g
F
P
p
.44339 .4905 m .45753 .47687 L .45729 .47711 L 1 g
F
P
p
.44339 .4905 m .45752 .47689 L .45721 .47719 L 1 g
F
P
p
.44339 .4905 m .45749 .47692 L .45714 .47726 L 1 g
F
P
p
.44339 .4905 m .45747 .47694 L .45711 .47729 L 1 g
F
P
p
.44339 .4905 m .45745 .47696 L .45712 .47728 L 1 g
F
P
p
.44339 .4905 m .45744 .47698 L .4572 .47721 L 1 g
F
P
p
.002 w
.4557 .47866 m .48941 .46843 L p
.45537 .47898 L 1 g
F P
s
P
p
.002 w
.49136 .48016 m .4894 .49164 L .4552 .47914 L p
1 g
F P
s
P
p
.002 w
.45537 .47898 m .49136 .48016 L p
.4552 .47914 L 1 g
F P
s
P
p
.002 w
.4552 .47914 m .4894 .49164 L p
.45508 .47926 L 1 g
F P
s
P
p
.002 w
.48376 .50161 m .47508 .509 L .45497 .47936 L p
1 g
F P
s
P
p
.002 w
.45508 .47926 m .48376 .50161 L p
.45497 .47936 L 1 g
F P
s
P
p
.002 w
.45497 .47936 m .47508 .509 L p
.45485 .47949 L 1 g
F P
s
P
p
.002 w
.48941 .46843 m .4557 .47866 L p
.45764 .47681 L 1 g
F P
s
P
p
.44339 .4905 m .45743 .47699 L .45122 .483 L 1 g
F
P
p
.002 w
.45537 .47898 m .4547 .47896 L .4557 .47866 L p
1 g
F P
s
P
p
.002 w
.45755 .47686 m .45753 .47687 L p
.45738 .47702 L 1 g
F P
s
P
p
.002 w
.45746 .47694 m .45764 .47681 L p
.4557 .47866 L 1 g
F P
s
P
p
.002 w
.45753 .47687 m .45752 .47689 L p
.45729 .47711 L 1 g
F P
s
P
p
.002 w
.4552 .47914 m .4547 .47896 L .45537 .47898 L p
1 g
F P
s
P
p
.002 w
.45508 .47926 m .4547 .47896 L .4552 .47914 L p
1 g
F P
s
P
p
.002 w
.45752 .47689 m .45749 .47692 L p
.45721 .47719 L 1 g
F P
s
P
p
.002 w
.45749 .47692 m .45747 .47694 L p
.45714 .47726 L 1 g
F P
s
P
p
.002 w
.45497 .47936 m .4547 .47896 L .45508 .47926 L p
1 g
F P
s
P
p
.002 w
.45485 .47949 m .4547 .47896 L .45497 .47936 L p
1 g
F P
s
P
p
.002 w
.45747 .47694 m .45745 .47696 L p
.45711 .47729 L 1 g
F P
s
P
p
.002 w
.45745 .47696 m .45744 .47698 L p
.45712 .47728 L 1 g
F P
s
P
p
.002 w
.46432 .51304 m .45264 .51331 L .45466 .47967 L p
1 g
F P
s
P
p
.002 w
.45466 .47967 m .4547 .47896 L .45485 .47949 L p
1 g
F P
s
P
p
.002 w
.45485 .47949 m .46432 .51304 L p
.45466 .47967 L 1 g
F P
s
P
p
.002 w
.45419 .48012 m .4547 .47896 L .45466 .47967 L p
1 g
F P
s
P
p
.002 w
.45466 .47967 m .45264 .51331 L p
.45419 .48012 L 1 g
F P
s
P
p
.002 w
.45744 .47698 m .45743 .47699 L p
.4572 .47721 L 1 g
F P
s
P
p
.002 w
.44129 .50979 m .43553 .50575 L p
.45314 .48114 L 1 g
F P
s
P
p
.002 w
.45419 .48012 m .44129 .50979 L p
.45314 .48114 L 1 g
F P
s
P
p
.002 w
.45743 .47699 m .45698 .47747 L p
.45122 .483 L 1 g
F P
s
P
p
.002 w
.4547 .47896 m .45419 .48012 L p
.45314 .48114 L 1 g
F P
s
P
p
.002 w
.44393 .49006 m .4547 .47896 L p
.45314 .48114 L 1 g
F P
s
P
p
.002 w
.44685 .48266 m .4547 .47896 L .4425 .49153 L p
1 g
F P
s
P
p
.002 w
.44258 .49136 m .44171 .49229 L p
.43879 .49908 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44258 .49136 L p
.45273 .48155 L 1 g
F P
s
P
p
.002 w
.44258 .49136 m .44258 .49136 L p
.44261 .49133 L 1 g
F P
s
P
p
.44261 .49133 m .45273 .48155 L .44258 .49136 L 1 g
F
P
p
.45124 .48298 m .45273 .48155 L .44258 .49136 L 1 g
F
P
p
.002 w
.44171 .49229 m .44166 .49233 L p
.44136 .49304 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44172 .49228 L p
.45273 .48155 L 1 g
F P
s
P
p
.002 w
.44172 .49228 m .44166 .49233 L p
.45273 .48155 L 1 g
F P
s
P
p
.002 w
.4557 .47866 m .4547 .47896 L .45746 .47694 L p
1 g
F P
s
P
p
.002 w
.45764 .47681 m .46926 .46831 L p
.47518 .46835 L 1 g
F P
s
P
p
.47753 .46721 m .47518 .46835 L .46926 .46831 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45755 .47685 L p
1 g
F P
s
P
p
.46806 .47178 m .47718 .46778 L .45755 .47685 L 1 g
F
P
p
.002 w
.47734 .46754 m .47753 .46721 L p
.48802 .46582 L 1 g
F P
s
P
p
.002 w
.47753 .46721 m .47786 .46667 L p
.48802 .46582 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.46926 .46831 m .48374 .45774 L .48802 .46582 L p
1 g
F P
s
P
p
.002 w
.48941 .46843 m .48374 .45774 L .51348 .43552 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46442 L p
.49109 .46532 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.51348 .43552 m .50231 .46352 L .49346 .46288 L 1 g
F
P
p
.002 w
.5 .46389 m .5 .4634 L p
.50204 .46421 L 1 g
F P
s
P
p
.50231 .46352 m .50204 .46421 L .5 .46389 L 1 g
F
P
p
.50231 .46352 m .5 .46389 L .49346 .46288 L 1 g
F
P
p
.49346 .46288 m .5 .46389 L .49176 .46522 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47734 .46754 L p
1 g
F P
s
P
p
.49109 .46532 m .5 .46442 L .47734 .46754 L 1 g
F
P
p
.002 w
.5 .46391 m .5 .46389 L p
.50204 .46421 L 1 g
F P
s
P
p
.002 w
.51348 .43552 m .52462 .45666 L .50204 .46421 L p
1 g
F P
s
P
p
.002 w
.49136 .48016 m .48941 .46843 L .52462 .45666 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46391 L p
1 g
F P
s
P
p
.51139 .46559 m .52282 .46778 L .5 .46391 L 1 g
F
P
p
.002 w
.52248 .46723 m .52282 .46778 L p
.51139 .46559 L 1 g
F P
s
P
p
.002 w
.52255 .46735 m .52248 .46723 L p
.52666 .4693 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.52666 .4693 L 1 g
F P
s
P
p
.002 w
.52462 .45666 m .52666 .4693 L p
.51493 .4635 L 1 g
F P
s
P
p
.002 w
.52666 .4693 m .52462 .45666 L p
.53428 .4729 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52255 .46735 L p
1 g
F P
s
P
p
.53312 .47235 m .54302 .47747 L .52255 .46735 L 1 g
F
P
p
.002 w
.54231 .47671 m .54302 .47747 L p
.53312 .47235 L 1 g
F P
s
P
p
.002 w
.54238 .47678 m .54231 .47671 L p
.54463 .47896 L 1 g
F P
s
P
p
.002 w
.54231 .47671 m .54174 .47608 L p
.54463 .47896 L 1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55895 .44411 m .56426 .47793 L .54463 .47896 L p
1 g
F P
s
P
p
.55895 .44411 m .54463 .47896 L .53616 .47072 L 1 g
F
P
p
.002 w
.52436 .50239 m .52836 .47981 L .56426 .47793 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54238 .47678 L p
1 g
F P
s
P
p
.54961 .48378 m .55834 .49233 L .54238 .47678 L 1 g
F
P
p
.002 w
.55736 .4913 m .55834 .49233 L p
.54961 .48378 L 1 g
F P
s
P
p
.002 w
.56607 .50936 m .56713 .51061 L p
.56204 .50089 L 1 g
F P
s
P
p
.002 w
.56626 .50958 m .56607 .50936 L p
.56639 .51232 L 1 g
F P
s
P
p
.002 w
.59768 .47462 m .58971 .51663 L .56639 .51232 L p
1 g
F P
s
P
p
.002 w
.54168 .53911 m .55822 .51081 L .56639 .51232 L p
1 g
F P
s
P
p
.002 w
.56639 .51232 m .58971 .51663 L p
.56712 .5272 L 1 g
F P
s
P
p
.56712 .5272 m .54168 .53911 L .56639 .51232 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56626 .50958 L p
1 g
F P
s
P
p
.56668 .51815 m .56854 .53025 L .56626 .50958 L 1 g
F
P
p
.002 w
.56717 .52826 m .56854 .53025 L p
.56668 .51815 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56717 .52826 L p
1 g
F P
s
P
p
.56506 .53545 m .56257 .5491 L .56717 .52826 L 1 g
F
P
p
.002 w
.56159 .54725 m .56257 .5491 L p
.56506 .53545 L 1 g
F P
s
P
p
.002 w
.5617 .54745 m .56159 .54725 L p
.56064 .54873 L 1 g
F P
s
P
p
.002 w
.51666 .55983 m .54168 .53911 L .56109 .54896 L p
1 g
F P
s
P
p
.002 w
.56109 .54896 m .56837 .55265 L p
.55909 .55394 L 1 g
F P
s
P
p
.55909 .55394 m .51666 .55983 L .56109 .54896 L 1 g
F
P
p
.002 w
.56257 .5491 m .5644 .55256 L p
.56846 .53066 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56821 .53129 L p
.56846 .53066 L 1 g
F P
s
P
p
.002 w
.56821 .53129 m .56257 .5491 L p
.56846 .53066 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5617 .54745 L p
1 g
F P
s
P
p
.55597 .55432 m .54998 .56518 L .5617 .54745 L 1 g
F
P
p
.002 w
.54904 .56264 m .54998 .56518 L p
.55597 .55432 L 1 g
F P
s
P
p
.54171 .5678 m .53194 .57468 L .53748 .57183 L 1 g
F
P
p
.002 w
.48598 .57092 m .51666 .55983 L .53194 .57468 L p
1 g
F P
s
P
p
.52668 .57738 m .48598 .57092 L .53194 .57468 L 1 g
F
P
p
.002 w
.53174 .57478 m .5322 .57686 L p
.53748 .57183 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53174 .57478 L p
1 g
F P
s
P
p
.52269 .57705 m .51111 .583 L .53174 .57478 L 1 g
F
P
p
.002 w
.5109 .58002 m .51111 .583 L p
.52269 .57705 L 1 g
F P
s
P
p
.52345 .57686 m .5229 .577 L .48598 .57092 L 1 g
F
P
p
.49713 .58135 m .491 .58075 L .48889 .583 L 1 g
F
P
p
.002 w
.48907 .58056 m .48905 .58082 L p
.491 .58075 L 1 g
F P
s
P
p
.002 w
.48905 .58082 m .48889 .583 L p
.491 .58075 L 1 g
F P
s
P
p
.002 w
.48598 .57092 m .491 .58075 L p
.46834 .57438 L 1 g
F P
s
P
p
.48907 .58056 m .46834 .57438 L .491 .58075 L 1 g
F
P
p
.002 w
.45809 .57132 m .4626 .57126 L p
.46834 .57438 L 1 g
F P
s
P
p
.46872 .57265 m .45025 .56453 L .45536 .56731 L 1 g
F
P
p
.002 w
.4626 .57126 m .48598 .57092 L p
.46834 .57438 L 1 g
F P
s
P
p
.002 w
.45025 .56453 m .45002 .56518 L p
.45536 .56731 L 1 g
F P
s
P
p
.002 w
.48598 .57092 m .4626 .57126 L p
.45207 .54447 L 1 g
F P
s
P
p
.002 w
.45274 .56465 m .45207 .54447 L p
.4626 .57126 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .57438 L p
1 g
F P
s
P
p
.45536 .56731 m .45002 .56518 L .46834 .57438 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51109 .58271 L p
1 g
F P
s
P
p
.49713 .58135 m .48889 .583 L .51109 .58271 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58056 L p
1 g
F P
s
P
p
.48003 .57787 m .4678 .57686 L .48907 .58056 L 1 g
F
P
p
.002 w
.6169 .35387 m .57378 .31218 L .58789 .29411 L p
1 g
F P
s
P
p
.002 w
.37137 .41956 m .36128 .45055 L .33876 .43994 L p
1 g
F P
s
P
p
.002 w
.33876 .43994 m .35142 .40041 L .37137 .41956 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.5363 .5789 m .56837 .55265 L .59229 .56218 L p
1 g
F P
s
P
p
.002 w
.61775 .51971 m .59229 .56218 L .56837 .55265 L p
1 g
F P
s
P
p
.002 w
.41207 .34503 m .37667 .36752 L .36611 .34374 L p
1 g
F P
s
P
p
.002 w
.36611 .34374 m .40784 .31692 L .41207 .34503 L p
1 g
F P
s
P
p
.004 w
.47891 .45307 m
.5 .43051 L
s
P
p
.002 w
.61775 .51971 m .62742 .47003 L .65254 .46438 L p
1 g
F P
s
P
p
.002 w
.64417 .40673 m .65254 .46438 L .62742 .47003 L p
1 g
F P
s
P
p
.002 w
.50904 .31162 m .45732 .30565 L .46192 .28014 L p
1 g
F P
s
P
p
.002 w
.46192 .28014 m .51996 .28665 L .50904 .31162 L p
1 g
F P
s
P
p
.002 w
.39672 .50548 m .41084 .52409 L .39347 .54188 L p
1 g
F P
s
P
p
.002 w
.39347 .54188 m .37306 .51504 L .39672 .50548 L p
1 g
F P
s
P
p
.002 w
.42104 .56134 m .39347 .54188 L .41084 .52409 L p
1 g
F P
s
P
p
.002 w
.41084 .52409 m .42995 .53756 L .42104 .56134 L p
1 g
F P
s
P
p
.002 w
.38906 .48364 m .39672 .50548 L .37306 .51504 L p
1 g
F P
s
P
p
.002 w
.37306 .51504 m .36192 .48352 L .38906 .48364 L p
1 g
F P
s
P
p
.002 w
.39131 .3939 m .37137 .41956 L .35142 .40041 L p
1 g
F P
s
P
p
.002 w
.35142 .40041 m .37667 .36752 L .39131 .3939 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.38871 .46086 m .38906 .48364 L .36192 .48352 L p
1 g
F P
s
P
p
.002 w
.36192 .48352 m .36128 .45055 L .38871 .46086 L p
1 g
F P
s
P
p
.002 w
.56837 .55265 m .58971 .51663 L .61775 .51971 L p
1 g
F P
s
P
p
.002 w
.62742 .47003 m .61775 .51971 L .58971 .51663 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.45392 .33572 m .41207 .34503 L .40784 .31692 L p
1 g
F P
s
P
p
.002 w
.40784 .31692 m .45732 .30565 L .45392 .33572 L p
1 g
F P
s
P
p
.002 w
.62742 .47003 m .61979 .41866 L .64417 .40673 L p
1 g
F P
s
P
p
.002 w
.6169 .35387 m .64417 .40673 L .61979 .41866 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.55697 .33445 m .50904 .31162 L .51996 .28665 L p
1 g
F P
s
P
p
.002 w
.51996 .28665 m .57378 .31218 L .55697 .33445 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.45207 .54447 m .47489 .54405 L .48598 .57092 L p
1 g
F P
s
P
p
.002 w
.51666 .55983 m .48598 .57092 L .47489 .54405 L p
1 g
F P
s
P
p
.002 w
.39579 .43953 m .38871 .46086 L .36128 .45055 L p
1 g
F P
s
P
p
.002 w
.36128 .45055 m .37137 .41956 L .39579 .43953 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.61979 .41866 m .5954 .3716 L .6169 .35387 L p
1 g
F P
s
P
p
.002 w
.57378 .31218 m .6169 .35387 L .5954 .3716 L p
1 g
F P
s
P
p
.002 w
.5954 .3716 m .55697 .33445 L .57378 .31218 L p
1 g
F P
s
P
p
.002 w
.41913 .37647 m .39131 .3939 L .37667 .36752 L p
1 g
F P
s
P
p
.002 w
.37667 .36752 m .41207 .34503 L .41913 .37647 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.58971 .51663 m .59768 .47462 L .62742 .47003 L p
1 g
F P
s
P
p
.002 w
.61979 .41866 m .62742 .47003 L .59768 .47462 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.49756 .34092 m .45392 .33572 L .45732 .30565 L p
1 g
F P
s
P
p
.002 w
.45732 .30565 m .50904 .31162 L .49756 .34092 L p
1 g
F P
s
P
p
.002 w
.47489 .54405 m .496 .53628 L .51666 .55983 L p
1 g
F P
s
P
p
.002 w
.54168 .53911 m .51666 .55983 L .496 .53628 L p
1 g
F P
s
P
p
.002 w
.42995 .53756 m .41084 .52409 L .43147 .50289 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42423 .49333 m .43147 .50289 L .41084 .52409 L p
1 g
F P
s
P
p
.002 w
.41084 .52409 m .39672 .50548 L .42423 .49333 L p
1 g
F P
s
P
p
.002 w
.40963 .42196 m .39579 .43953 L .37137 .41956 L p
1 g
F P
s
P
p
.002 w
.37137 .41956 m .39131 .3939 L .40963 .42196 L p
1 g
F P
s
P
p
.002 w
.42034 .48212 m .42423 .49333 L .39672 .50548 L p
1 g
F P
s
P
p
.002 w
.39672 .50548 m .38906 .48364 L .42034 .48212 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44129 .50979 m .45264 .51331 L .45207 .54447 L p
1 g
F P
s
P
p
.002 w
.47489 .54405 m .45207 .54447 L .45264 .51331 L p
1 g
F P
s
P
p
.002 w
.42022 .47046 m .42034 .48212 L .38906 .48364 L p
1 g
F P
s
P
p
.002 w
.38906 .48364 m .38871 .46086 L .42022 .47046 L p
1 g
F P
s
P
p
.002 w
.45187 .36936 m .41913 .37647 L .41207 .34503 L p
1 g
F P
s
P
p
.002 w
.41207 .34503 m .45392 .33572 L .45187 .36936 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59768 .47462 m .59106 .43128 L .61979 .41866 L p
1 g
F P
s
P
p
.002 w
.5954 .3716 m .61979 .41866 L .59106 .43128 L p
1 g
F P
s
P
p
.002 w
.53797 .36026 m .49756 .34092 L .50904 .31162 L p
1 g
F P
s
P
p
.002 w
.50904 .31162 m .55697 .33445 L .53797 .36026 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.496 .53628 m .51313 .52191 L .54168 .53911 L p
1 g
F P
s
P
p
.002 w
.55822 .51081 m .54168 .53911 L .51313 .52191 L p
1 g
F P
s
P
p
.002 w
.45264 .51331 m .46432 .51304 L .47489 .54405 L p
1 g
F P
s
P
p
.002 w
.496 .53628 m .47489 .54405 L .46432 .51304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4239 .45959 m .42022 .47046 L .38871 .46086 L p
1 g
F P
s
P
p
.002 w
.38871 .46086 m .39579 .43953 L .4239 .45959 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42882 .41012 m .40963 .42196 L .39131 .3939 L p
1 g
F P
s
P
p
.002 w
.39131 .3939 m .41913 .37647 L .42882 .41012 L p
1 g
F P
s
P
p
.002 w
.59106 .43128 m .5704 .3916 L .5954 .3716 L p
1 g
F P
s
P
p
.002 w
.55697 .33445 m .5954 .3716 L .5704 .3916 L p
1 g
F P
s
P
p
.002 w
.5704 .3916 m .53797 .36026 L .55697 .33445 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59106 .43128 m .59768 .47462 L .56426 .47793 L p
1 g
F P
s
P
p
.002 w
.46432 .51304 m .47508 .509 L .496 .53628 L p
1 g
F P
s
P
p
.002 w
.51313 .52191 m .496 .53628 L .47508 .509 L p
1 g
F P
s
P
p
.002 w
.48594 .37357 m .45187 .36936 L .45392 .33572 L p
1 g
F P
s
P
p
.002 w
.45392 .33572 m .49756 .34092 L .48594 .37357 L p
1 g
F P
s
P
p
.002 w
.43102 .45068 m .4239 .45959 L .39579 .43953 L p
1 g
F P
s
P
p
.002 w
.39579 .43953 m .40963 .42196 L .43102 .45068 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51313 .52191 m .52436 .50239 L .55822 .51081 L p
1 g
F P
s
P
p
.002 w
.42423 .49333 m .42034 .48212 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.45131 .40538 m .42882 .41012 L .41913 .37647 L p
1 g
F P
s
P
p
.002 w
.41913 .37647 m .45187 .36936 L .45131 .40538 L p
1 g
F P
s
P
p
.002 w
.42034 .48212 m .42022 .47046 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.47508 .509 m .48376 .50161 L .51313 .52191 L p
1 g
F P
s
P
p
.002 w
.52436 .50239 m .51313 .52191 L .48376 .50161 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.56426 .47793 m .55895 .44411 L .59106 .43128 L p
1 g
F P
s
P
p
.002 w
.5704 .3916 m .59106 .43128 L .55895 .44411 L p
1 g
F P
s
P
p
.002 w
.44082 .44473 m .43102 .45068 L .40963 .42196 L p
1 g
F P
s
P
p
.002 w
.40963 .42196 m .42882 .41012 L .44082 .44473 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.51744 .38873 m .48594 .37357 L .49756 .34092 L p
1 g
F P
s
P
p
.002 w
.49756 .34092 m .53797 .36026 L .51744 .38873 L p
1 g
F P
s
P
p
.002 w
.42022 .47046 m .4239 .45959 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.4239 .45959 m .43102 .45068 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.55895 .44411 m .54274 .41318 L .5704 .3916 L p
1 g
F P
s
P
p
.002 w
.53797 .36026 m .5704 .3916 L .54274 .41318 L p
1 g
F P
s
P
p
.002 w
.54274 .41318 m .51744 .38873 L .53797 .36026 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.47462 .40836 m .45131 .40538 L .45187 .36936 L p
1 g
F P
s
P
p
.002 w
.45187 .36936 m .48594 .37357 L .47462 .40836 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.48376 .50161 m .4894 .49164 L .52436 .50239 L p
1 g
F P
s
P
p
.002 w
.52836 .47981 m .52436 .50239 L .4894 .49164 L p
1 g
F P
s
P
p
.002 w
.45226 .4424 m .44082 .44473 L .42882 .41012 L p
1 g
F P
s
P
p
.002 w
.42882 .41012 m .45131 .40538 L .45226 .4424 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.43102 .45068 m .44082 .44473 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.46407 .44396 m .47497 .44927 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.45226 .4424 m .46407 .44396 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.44082 .44473 m .45226 .4424 L .4547 .47896 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.004 w
.45324 .48052 m
.4547 .47896 L
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.4894 .49164 m .49136 .48016 L .52836 .47981 L p
1 g
F P
s
P
p
.002 w
.54274 .41318 m .55895 .44411 L .52462 .45666 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49616 .41879 m .47462 .40836 L .48594 .37357 L p
1 g
F P
s
P
p
.002 w
.48594 .37357 m .51744 .38873 L .49616 .41879 L p
1 g
F P
s
P
p
.002 w
.46407 .44396 m .45226 .4424 L .45131 .40538 L p
1 g
F P
s
P
p
.002 w
.45131 .40538 m .47462 .40836 L .46407 .44396 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52462 .45666 m .51348 .43552 L .54274 .41318 L p
1 g
F P
s
P
p
.002 w
.51744 .38873 m .54274 .41318 L .51348 .43552 L p
1 g
F P
s
P
p
.002 w
.51348 .43552 m .49616 .41879 L .51744 .38873 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47497 .44927 m .46407 .44396 L .47462 .40836 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47462 .40836 m .49616 .41879 L .47497 .44927 L p
1 g
F P
s
P
p
.002 w
.48374 .45774 m .47497 .44927 L .49616 .41879 L p
1 g
F P
s
P
p
.002 w
.49616 .41879 m .51348 .43552 L .48374 .45774 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.42679 .50881 m
.45324 .48052 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .2488 .31299 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .42679 .50881 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.548062)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.548062)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47898 .4524 m .49608 .45951 L .50264 .43178 L p
1 g
F P
s
P
p
.002 w
.50264 .43178 m .49399 .42818 L .47898 .4524 L p
1 g
F P
s
P
p
.002 w
.51198 .43241 m .50264 .43178 L .49608 .45951 L p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .49399 .42818 L .50264 .43178 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .50264 .43178 L .51198 .43241 L closepath p
1 g
F P
s
P
p
.002 w
.46507 .44021 m .47898 .4524 L .49399 .42818 L p
1 g
F P
s
P
p
.002 w
.49399 .42818 m .48696 .422 L .46507 .44021 L p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .48696 .422 L .49399 .42818 L closepath p
1 g
F P
s
P
p
.002 w
.49608 .45951 m .51454 .46078 L .51198 .43241 L p
1 g
F P
s
P
p
.002 w
.52102 .43001 m .51198 .43241 L .51454 .46078 L p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .51198 .43241 L .52102 .43001 L closepath p
1 g
F P
s
P
p
.002 w
.45585 .42422 m .46507 .44021 L .48696 .422 L p
1 g
F P
s
P
p
.002 w
.48696 .422 m .48231 .4139 L .45585 .42422 L p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .48231 .4139 L .48696 .422 L closepath p
1 g
F P
s
P
p
.002 w
.51454 .46078 m .5324 .45607 L .52102 .43001 L p
1 g
F P
s
P
p
.002 w
.52876 .42483 m .52102 .43001 L .5324 .45607 L p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .52102 .43001 L .52876 .42483 L closepath p
1 g
F P
s
P
p
.002 w
.45231 .40613 m .45585 .42422 L .48231 .4139 L p
1 g
F P
s
P
p
.002 w
.48231 .4139 m .48055 .40476 L .45231 .40613 L p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .48055 .40476 L .48231 .4139 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .48187 .39555 L .48055 .40476 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .52876 .42483 L .53439 .41742 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .53439 .41742 L .53727 .40857 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .48614 .38728 L .48187 .39555 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .53727 .40857 L .5371 .39925 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .5371 .39925 L .53388 .39046 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .53388 .39046 L .52795 .38317 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .52795 .38317 L .51996 .37818 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .51996 .37818 L .51079 .37602 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .51079 .37602 L .50142 .37694 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .50142 .37694 L .4929 .38084 L closepath p
1 g
F P
s
P
p
.002 w
.50914 .40401 m .4929 .38084 L .48614 .38728 L closepath p
1 g
F P
s
P
p
.002 w
.46438 .47626 m .48956 .48673 L .49608 .45951 L p
1 g
F P
s
P
p
.002 w
.49608 .45951 m .47898 .4524 L .46438 .47626 L p
1 g
F P
s
P
p
.002 w
.51454 .46078 m .49608 .45951 L .48956 .48673 L p
1 g
F P
s
P
p
.002 w
.5324 .45607 m .54775 .44586 L .52876 .42483 L p
1 g
F P
s
P
p
.002 w
.53439 .41742 m .52876 .42483 L .54775 .44586 L p
1 g
F P
s
P
p
.002 w
.44387 .45831 m .46438 .47626 L .47898 .4524 L p
1 g
F P
s
P
p
.002 w
.47898 .4524 m .46507 .44021 L .44387 .45831 L p
1 g
F P
s
P
p
.002 w
.45486 .38789 m .45231 .40613 L .48055 .40476 L p
1 g
F P
s
P
p
.002 w
.48055 .40476 m .48187 .39555 L .45486 .38789 L p
1 g
F P
s
P
p
.002 w
.48956 .48673 m .51676 .48862 L .51454 .46078 L p
1 g
F P
s
P
p
.002 w
.5324 .45607 m .51454 .46078 L .51676 .48862 L p
1 g
F P
s
P
p
.002 w
.43023 .43477 m .44387 .45831 L .46507 .44021 L p
1 g
F P
s
P
p
.002 w
.46507 .44021 m .45585 .42422 L .43023 .43477 L p
1 g
F P
s
P
p
.002 w
.54775 .44586 m .55893 .43121 L .53439 .41742 L p
1 g
F P
s
P
p
.002 w
.53727 .40857 m .53439 .41742 L .55893 .43121 L p
1 g
F P
s
P
p
.002 w
.46328 .37146 m .45486 .38789 L .48187 .39555 L p
1 g
F P
s
P
p
.002 w
.48187 .39555 m .48614 .38728 L .46328 .37146 L p
1 g
F P
s
P
p
.002 w
.51676 .48862 m .54309 .48172 L .5324 .45607 L p
1 g
F P
s
P
p
.002 w
.54775 .44586 m .5324 .45607 L .54309 .48172 L p
1 g
F P
s
P
p
.002 w
.55893 .43121 m .56471 .4137 L .53727 .40857 L p
1 g
F P
s
P
p
.002 w
.5371 .39925 m .53727 .40857 L .56471 .4137 L p
1 g
F P
s
P
p
.002 w
.42494 .40811 m .43023 .43477 L .45585 .42422 L p
1 g
F P
s
P
p
.002 w
.45585 .42422 m .45231 .40613 L .42494 .40811 L p
1 g
F P
s
P
p
.002 w
.47666 .35865 m .46328 .37146 L .48614 .38728 L p
1 g
F P
s
P
p
.002 w
.48614 .38728 m .4929 .38084 L .47666 .35865 L p
1 g
F P
s
P
p
.002 w
.56471 .4137 m .56441 .39521 L .5371 .39925 L p
1 g
F P
s
P
p
.002 w
.53388 .39046 m .5371 .39925 L .56441 .39521 L p
1 g
F P
s
P
p
.002 w
.54309 .48172 m .56577 .46671 L .54775 .44586 L p
1 g
F P
s
P
p
.002 w
.55893 .43121 m .54775 .44586 L .56577 .46671 L p
1 g
F P
s
P
p
.002 w
.49358 .35088 m .47666 .35865 L .4929 .38084 L p
1 g
F P
s
P
p
.002 w
.4929 .38084 m .50142 .37694 L .49358 .35088 L p
1 g
F P
s
P
p
.002 w
.56441 .39521 m .55806 .37774 L .53388 .39046 L p
1 g
F P
s
P
p
.002 w
.52795 .38317 m .53388 .39046 L .55806 .37774 L p
1 g
F P
s
P
p
.002 w
.42863 .38117 m .42494 .40811 L .45231 .40613 L p
1 g
F P
s
P
p
.002 w
.45231 .40613 m .45486 .38789 L .42863 .38117 L p
1 g
F P
s
P
p
.002 w
.51219 .34902 m .49358 .35088 L .50142 .37694 L p
1 g
F P
s
P
p
.002 w
.50142 .37694 m .51079 .37602 L .51219 .34902 L p
1 g
F P
s
P
p
.002 w
.55806 .37774 m .5463 .36324 L .52795 .38317 L p
1 g
F P
s
P
p
.002 w
.51996 .37818 m .52795 .38317 L .5463 .36324 L p
1 g
F P
s
P
p
.002 w
.53043 .3533 m .51219 .34902 L .51079 .37602 L p
1 g
F P
s
P
p
.002 w
.51079 .37602 m .51996 .37818 L .53043 .3533 L p
1 g
F P
s
P
p
.002 w
.5463 .36324 m .53043 .3533 L .51996 .37818 L p
1 g
F P
s
P
p
.002 w
.45046 .4993 m .48322 .51291 L .48956 .48673 L p
1 g
F P
s
P
p
.002 w
.48956 .48673 m .46438 .47626 L .45046 .4993 L p
1 g
F P
s
P
p
.002 w
.51676 .48862 m .48956 .48673 L .48322 .51291 L p
1 g
F P
s
P
p
.002 w
.42376 .47599 m .45046 .4993 L .46438 .47626 L p
1 g
F P
s
P
p
.002 w
.46438 .47626 m .44387 .45831 L .42376 .47599 L p
1 g
F P
s
P
p
.002 w
.56577 .46671 m .58232 .44515 L .55893 .43121 L p
1 g
F P
s
P
p
.002 w
.56471 .4137 m .55893 .43121 L .58232 .44515 L p
1 g
F P
s
P
p
.002 w
.48322 .51291 m .51859 .5154 L .51676 .48862 L p
1 g
F P
s
P
p
.002 w
.54309 .48172 m .51676 .48862 L .51859 .5154 L p
1 g
F P
s
P
p
.002 w
.44099 .35686 m .42863 .38117 L .45486 .38789 L p
1 g
F P
s
P
p
.002 w
.45486 .38789 m .46328 .37146 L .44099 .35686 L p
1 g
F P
s
P
p
.002 w
.40594 .44538 m .42376 .47599 L .44387 .45831 L p
1 g
F P
s
P
p
.002 w
.44387 .45831 m .43023 .43477 L .40594 .44538 L p
1 g
F P
s
P
p
.002 w
.58232 .44515 m .59092 .41931 L .56471 .4137 L p
1 g
F P
s
P
p
.002 w
.56441 .39521 m .56471 .4137 L .59092 .41931 L p
1 g
F P
s
P
p
.002 w
.51859 .5154 m .55288 .50647 L .54309 .48172 L p
1 g
F P
s
P
p
.002 w
.56577 .46671 m .54309 .48172 L .55288 .50647 L p
1 g
F P
s
P
p
.002 w
.46074 .33786 m .44099 .35686 L .46328 .37146 L p
1 g
F P
s
P
p
.002 w
.46328 .37146 m .47666 .35865 L .46074 .33786 L p
1 g
F P
s
P
p
.002 w
.39897 .41068 m .40594 .44538 L .43023 .43477 L p
1 g
F P
s
P
p
.002 w
.43023 .43477 m .42494 .40811 L .39897 .41068 L p
1 g
F P
s
P
p
.002 w
.59092 .41931 m .59057 .39197 L .56441 .39521 L p
1 g
F P
s
P
p
.002 w
.55806 .37774 m .56441 .39521 L .59057 .39197 L p
1 g
F P
s
P
p
.002 w
.55288 .50647 m .58244 .487 L .56577 .46671 L p
1 g
F P
s
P
p
.002 w
.58232 .44515 m .56577 .46671 L .58244 .487 L p
1 g
F P
s
P
p
.002 w
.48576 .32631 m .46074 .33786 L .47666 .35865 L p
1 g
F P
s
P
p
.002 w
.47666 .35865 m .49358 .35088 L .48576 .32631 L p
1 g
F P
s
P
p
.002 w
.40369 .37555 m .39897 .41068 L .42494 .40811 L p
1 g
F P
s
P
p
.002 w
.42494 .40811 m .42863 .38117 L .40369 .37555 L p
1 g
F P
s
P
p
.002 w
.59057 .39197 m .58122 .36611 L .55806 .37774 L p
1 g
F P
s
P
p
.002 w
.5463 .36324 m .55806 .37774 L .58122 .36611 L p
1 g
F P
s
P
p
.002 w
.51331 .32353 m .48576 .32631 L .49358 .35088 L p
1 g
F P
s
P
p
.002 w
.49358 .35088 m .51219 .34902 L .51331 .32353 L p
1 g
F P
s
P
p
.002 w
.58122 .36611 m .56384 .3446 L .5463 .36324 L p
1 g
F P
s
P
p
.002 w
.53043 .3533 m .5463 .36324 L .56384 .3446 L p
1 g
F P
s
P
p
.002 w
.54034 .32986 m .51331 .32353 L .51219 .34902 L p
1 g
F P
s
P
p
.002 w
.51219 .34902 m .53043 .3533 L .54034 .32986 L p
1 g
F P
s
P
p
.002 w
.56384 .3446 m .54034 .32986 L .53043 .3533 L p
1 g
F P
s
P
p
.002 w
.58244 .487 m .60409 .45897 L .58232 .44515 L p
1 g
F P
s
P
p
.002 w
.59092 .41931 m .58232 .44515 L .60409 .45897 L p
1 g
F P
s
P
p
.002 w
.43751 .52108 m .47718 .53755 L .48322 .51291 L p
1 g
F P
s
P
p
.002 w
.48322 .51291 m .45046 .4993 L .43751 .52108 L p
1 g
F P
s
P
p
.002 w
.51859 .5154 m .48322 .51291 L .47718 .53755 L p
1 g
F P
s
P
p
.002 w
.40514 .49288 m .43751 .52108 L .45046 .4993 L p
1 g
F P
s
P
p
.002 w
.45046 .4993 m .42376 .47599 L .40514 .49288 L p
1 g
F P
s
P
p
.002 w
.41973 .3438 m .40369 .37555 L .42863 .38117 L p
1 g
F P
s
P
p
.002 w
.42863 .38117 m .44099 .35686 L .41973 .3438 L p
1 g
F P
s
P
p
.002 w
.47718 .53755 m .52001 .54059 L .51859 .5154 L p
1 g
F P
s
P
p
.002 w
.55288 .50647 m .51859 .5154 L .52001 .54059 L p
1 g
F P
s
P
p
.002 w
.38349 .45584 m .40514 .49288 L .42376 .47599 L p
1 g
F P
s
P
p
.002 w
.42376 .47599 m .40594 .44538 L .38349 .45584 L p
1 g
F P
s
P
p
.002 w
.60409 .45897 m .6154 .42531 L .59092 .41931 L p
1 g
F P
s
P
p
.002 w
.59057 .39197 m .59092 .41931 L .6154 .42531 L p
1 g
F P
s
P
p
.002 w
.52001 .54059 m .56155 .52985 L .55288 .50647 L p
1 g
F P
s
P
p
.002 w
.58244 .487 m .55288 .50647 L .56155 .52985 L p
1 g
F P
s
P
p
.002 w
.44545 .31894 m .41973 .3438 L .44099 .35686 L p
1 g
F P
s
P
p
.002 w
.44099 .35686 m .46074 .33786 L .44545 .31894 L p
1 g
F P
s
P
p
.002 w
.37494 .41379 m .38349 .45584 L .40594 .44538 L p
1 g
F P
s
P
p
.002 w
.40594 .44538 m .39897 .41068 L .37494 .41379 L p
1 g
F P
s
P
p
.002 w
.6154 .42531 m .61502 .38962 L .59057 .39197 L p
1 g
F P
s
P
p
.002 w
.58122 .36611 m .59057 .39197 L .61502 .38962 L p
1 g
F P
s
P
p
.002 w
.56155 .52985 m .59743 .50633 L .58244 .487 L p
1 g
F P
s
P
p
.002 w
.60409 .45897 m .58244 .487 L .59743 .50633 L p
1 g
F P
s
P
p
.002 w
.47811 .30378 m .44545 .31894 L .46074 .33786 L p
1 g
F P
s
P
p
.002 w
.46074 .33786 m .48576 .32631 L .47811 .30378 L p
1 g
F P
s
P
p
.002 w
.38056 .37117 m .37494 .41379 L .39897 .41068 L p
1 g
F P
s
P
p
.002 w
.39897 .41068 m .40369 .37555 L .38056 .37117 L p
1 g
F P
s
P
p
.002 w
.61502 .38962 m .60288 .35582 L .58122 .36611 L p
1 g
F P
s
P
p
.002 w
.56384 .3446 m .58122 .36611 L .60288 .35582 L p
1 g
F P
s
P
p
.002 w
.51413 .30011 m .47811 .30378 L .48576 .32631 L p
1 g
F P
s
P
p
.002 w
.48576 .32631 m .51331 .32353 L .51413 .30011 L p
1 g
F P
s
P
p
.002 w
.60288 .35582 m .58021 .32767 L .56384 .3446 L p
1 g
F P
s
P
p
.002 w
.54034 .32986 m .56384 .3446 L .58021 .32767 L p
1 g
F P
s
P
p
.002 w
.54948 .30838 m .51413 .30011 L .51331 .32353 L p
1 g
F P
s
P
p
.002 w
.51331 .32353 m .54034 .32986 L .54948 .30838 L p
1 g
F P
s
P
p
.002 w
.59743 .50633 m .62376 .4724 L .60409 .45897 L p
1 g
F P
s
P
p
.002 w
.6154 .42531 m .60409 .45897 L .62376 .4724 L p
1 g
F P
s
P
p
.002 w
.58021 .32767 m .54948 .30838 L .54034 .32986 L p
1 g
F P
s
P
p
.002 w
.4258 .54112 m .47155 .56011 L .47718 .53755 L p
1 g
F P
s
P
p
.002 w
.47718 .53755 m .43751 .52108 L .4258 .54112 L p
1 g
F P
s
P
p
.002 w
.52001 .54059 m .47718 .53755 L .47155 .56011 L p
1 g
F P
s
P
p
.002 w
.38843 .50863 m .4258 .54112 L .43751 .52108 L p
1 g
F P
s
P
p
.002 w
.43751 .52108 m .40514 .49288 L .38843 .50863 L p
1 g
F P
s
P
p
.002 w
.39993 .33258 m .38056 .37117 L .40369 .37555 L p
1 g
F P
s
P
p
.002 w
.40369 .37555 m .41973 .3438 L .39993 .33258 L p
1 g
F P
s
P
p
.002 w
.47155 .56011 m .52095 .56366 L .52001 .54059 L p
1 g
F P
s
P
p
.002 w
.56155 .52985 m .52001 .54059 L .52095 .56366 L p
1 g
F P
s
P
p
.002 w
.36338 .46594 m .38843 .50863 L .40514 .49288 L p
1 g
F P
s
P
p
.002 w
.40514 .49288 m .38349 .45584 L .36338 .46594 L p
1 g
F P
s
P
p
.002 w
.62376 .4724 m .63759 .43159 L .6154 .42531 L p
1 g
F P
s
P
p
.002 w
.61502 .38962 m .6154 .42531 L .63759 .43159 L p
1 g
F P
s
P
p
.002 w
.52095 .56366 m .5689 .55132 L .56155 .52985 L p
1 g
F P
s
P
p
.002 w
.59743 .50633 m .56155 .52985 L .5689 .55132 L p
1 g
F P
s
P
p
.002 w
.43112 .30231 m .39993 .33258 L .41973 .3438 L p
1 g
F P
s
P
p
.002 w
.41973 .3438 m .44545 .31894 L .43112 .30231 L p
1 g
F P
s
P
p
.002 w
.35341 .41742 m .36338 .46594 L .38349 .45584 L p
1 g
F P
s
P
p
.002 w
.38349 .45584 m .37494 .41379 L .35341 .41742 L p
1 g
F P
s
P
p
.002 w
.63759 .43159 m .63723 .38824 L .61502 .38962 L p
1 g
F P
s
P
p
.002 w
.60288 .35582 m .61502 .38962 L .63723 .38824 L p
1 g
F P
s
P
p
.002 w
.5689 .55132 m .61035 .52426 L .59743 .50633 L p
1 g
F P
s
P
p
.002 w
.62376 .4724 m .59743 .50633 L .61035 .52426 L p
1 g
F P
s
P
p
.002 w
.4708 .28382 m .43112 .30231 L .44545 .31894 L p
1 g
F P
s
P
p
.002 w
.44545 .31894 m .47811 .30378 L .4708 .28382 L p
1 g
F P
s
P
p
.002 w
.35979 .36818 m .35341 .41742 L .37494 .41379 L p
1 g
F P
s
P
p
.002 w
.37494 .41379 m .38056 .37117 L .35979 .36818 L p
1 g
F P
s
P
p
.002 w
.63723 .38824 m .62254 .34712 L .60288 .35582 L p
1 g
F P
s
P
p
.002 w
.58021 .32767 m .60288 .35582 L .62254 .34712 L p
1 g
F P
s
P
p
.002 w
.51461 .27931 m .4708 .28382 L .47811 .30378 L p
1 g
F P
s
P
p
.002 w
.47811 .30378 m .51413 .30011 L .51461 .27931 L p
1 g
F P
s
P
p
.002 w
.62254 .34712 m .59501 .31286 L .58021 .32767 L p
1 g
F P
s
P
p
.002 w
.54948 .30838 m .58021 .32767 L .59501 .31286 L p
1 g
F P
s
P
p
.002 w
.61035 .52426 m .64085 .48516 L .62376 .4724 L p
1 g
F P
s
P
p
.002 w
.63759 .43159 m .62376 .4724 L .64085 .48516 L p
1 g
F P
s
P
p
.002 w
.55764 .28936 m .51461 .27931 L .51413 .30011 L p
1 g
F P
s
P
p
.002 w
.51413 .30011 m .54948 .30838 L .55764 .28936 L p
1 g
F P
s
P
p
.002 w
.59501 .31286 m .55764 .28936 L .54948 .30838 L p
1 g
F P
s
P
p
.002 w
.41563 .55894 m .46649 .58005 L .47155 .56011 L p
1 g
F P
s
P
p
.002 w
.47155 .56011 m .4258 .54112 L .41563 .55894 L p
1 g
F P
s
P
p
.002 w
.52095 .56366 m .47155 .56011 L .46649 .58005 L p
1 g
F P
s
P
p
.002 w
.37407 .52286 m .41563 .55894 L .4258 .54112 L p
1 g
F P
s
P
p
.002 w
.4258 .54112 m .38843 .50863 L .37407 .52286 L p
1 g
F P
s
P
p
.002 w
.38209 .32352 m .35979 .36818 L .38056 .37117 L p
1 g
F P
s
P
p
.002 w
.38056 .37117 m .39993 .33258 L .38209 .32352 L p
1 g
F P
s
P
p
.002 w
.46649 .58005 m .52139 .58402 L .52095 .56366 L p
1 g
F P
s
P
p
.002 w
.5689 .55132 m .52095 .56366 L .52139 .58402 L p
1 g
F P
s
P
p
.002 w
.34615 .47544 m .37407 .52286 L .38843 .50863 L p
1 g
F P
s
P
p
.002 w
.38843 .50863 m .36338 .46594 L .34615 .47544 L p
1 g
F P
s
P
p
.002 w
.64085 .48516 m .65693 .43803 L .63759 .43159 L p
1 g
F P
s
P
p
.002 w
.63723 .38824 m .63759 .43159 L .65693 .43803 L p
1 g
F P
s
P
p
.002 w
.52139 .58402 m .57471 .57038 L .5689 .55132 L p
1 g
F P
s
P
p
.002 w
.61035 .52426 m .5689 .55132 L .57471 .57038 L p
1 g
F P
s
P
p
.002 w
.4181 .28844 m .38209 .32352 L .39993 .33258 L p
1 g
F P
s
P
p
.002 w
.39993 .33258 m .43112 .30231 L .4181 .28844 L p
1 g
F P
s
P
p
.002 w
.33496 .42151 m .34615 .47544 L .36338 .46594 L p
1 g
F P
s
P
p
.002 w
.36338 .46594 m .35341 .41742 L .33496 .42151 L p
1 g
F P
s
P
p
.002 w
.65693 .43803 m .65662 .3879 L .63723 .38824 L p
1 g
F P
s
P
p
.002 w
.62254 .34712 m .63723 .38824 L .65662 .3879 L p
1 g
F P
s
P
p
.002 w
.57471 .57038 m .62086 .54036 L .61035 .52426 L p
1 g
F P
s
P
p
.002 w
.64085 .48516 m .61035 .52426 L .62086 .54036 L p
1 g
F P
s
P
p
.002 w
.464 .26698 m .4181 .28844 L .43112 .30231 L p
1 g
F P
s
P
p
.002 w
.43112 .30231 m .4708 .28382 L .464 .26698 L p
1 g
F P
s
P
p
.002 w
.34195 .3667 m .33496 .42151 L .35341 .41742 L p
1 g
F P
s
P
p
.002 w
.35341 .41742 m .35979 .36818 L .34195 .3667 L p
1 g
F P
s
P
p
.002 w
.65662 .3879 m .6397 .3403 L .62254 .34712 L p
1 g
F P
s
P
p
.002 w
.59501 .31286 m .62254 .34712 L .6397 .3403 L p
1 g
F P
s
P
p
.002 w
.51474 .26172 m .464 .26698 L .4708 .28382 L p
1 g
F P
s
P
p
.002 w
.4708 .28382 m .51461 .27931 L .51474 .26172 L p
1 g
F P
s
P
p
.002 w
.62086 .54036 m .65487 .49692 L .64085 .48516 L p
1 g
F P
s
P
p
.002 w
.65693 .43803 m .64085 .48516 L .65487 .49692 L p
1 g
F P
s
P
p
.002 w
.6397 .3403 m .60786 .30059 L .59501 .31286 L p
1 g
F P
s
P
p
.002 w
.55764 .28936 m .59501 .31286 L .60786 .30059 L p
1 g
F P
s
P
p
.002 w
.56458 .27335 m .51474 .26172 L .51461 .27931 L p
1 g
F P
s
P
p
.002 w
.51461 .27931 m .55764 .28936 L .56458 .27335 L p
1 g
F P
s
P
p
.002 w
.60786 .30059 m .56458 .27335 L .55764 .28936 L p
1 g
F P
s
P
p
.002 w
.4073 .57406 m .46212 .5968 L .46649 .58005 L p
1 g
F P
s
P
p
.002 w
.46649 .58005 m .41563 .55894 L .4073 .57406 L p
1 g
F P
s
P
p
.002 w
.52139 .58402 m .46649 .58005 L .46212 .5968 L p
1 g
F P
s
P
p
.002 w
.36668 .31694 m .34195 .3667 L .35979 .36818 L p
1 g
F P
s
P
p
.002 w
.35979 .36818 m .38209 .32352 L .36668 .31694 L p
1 g
F P
s
P
p
.002 w
.36247 .5352 m .4073 .57406 L .41563 .55894 L p
1 g
F P
s
P
p
.002 w
.41563 .55894 m .37407 .52286 L .36247 .5352 L p
1 g
F P
s
P
p
.002 w
.46212 .5968 m .5213 .60111 L .52139 .58402 L p
1 g
F P
s
P
p
.002 w
.57471 .57038 m .52139 .58402 L .5213 .60111 L p
1 g
F P
s
P
p
.002 w
.33231 .48411 m .36247 .5352 L .37407 .52286 L p
1 g
F P
s
P
p
.002 w
.37407 .52286 m .34615 .47544 L .33231 .48411 L p
1 g
F P
s
P
p
.002 w
.65487 .49692 m .67287 .4445 L .65693 .43803 L p
1 g
F P
s
P
p
.002 w
.65662 .3879 m .65693 .43803 L .67287 .4445 L p
1 g
F P
s
P
p
.002 w
.5213 .60111 m .57878 .58646 L .57471 .57038 L p
1 g
F P
s
P
p
.002 w
.62086 .54036 m .57471 .57038 L .57878 .58646 L p
1 g
F P
s
P
p
.002 w
.40674 .2778 m .36668 .31694 L .38209 .32352 L p
1 g
F P
s
P
p
.002 w
.38209 .32352 m .4181 .28844 L .40674 .2778 L p
1 g
F P
s
P
p
.002 w
.32017 .42597 m .33231 .48411 L .34615 .47544 L p
1 g
F P
s
P
p
.002 w
.34615 .47544 m .33496 .42151 L .32017 .42597 L p
1 g
F P
s
P
p
.002 w
.67287 .4445 m .67261 .38867 L .65662 .3879 L p
1 g
F P
s
P
p
.002 w
.6397 .3403 m .65662 .3879 L .67261 .38867 L p
1 g
F P
s
P
p
.002 w
.57878 .58646 m .62858 .55417 L .62086 .54036 L p
1 g
F P
s
P
p
.002 w
.65487 .49692 m .62086 .54036 L .62858 .55417 L p
1 g
F P
s
P
p
.002 w
.45789 .25382 m .40674 .2778 L .4181 .28844 L p
1 g
F P
s
P
p
.002 w
.4181 .28844 m .464 .26698 L .45789 .25382 L p
1 g
F P
s
P
p
.002 w
.32762 .36685 m .32017 .42597 L .33496 .42151 L p
1 g
F P
s
P
p
.002 w
.33496 .42151 m .34195 .3667 L .32762 .36685 L p
1 g
F P
s
P
p
.002 w
.67261 .38867 m .65382 .33559 L .6397 .3403 L p
1 g
F P
s
P
p
.002 w
.60786 .30059 m .6397 .3403 L .65382 .33559 L p
1 g
F P
s
P
p
.002 w
.51447 .24791 m .45789 .25382 L .464 .26698 L p
1 g
F P
s
P
p
.002 w
.464 .26698 m .51474 .26172 L .51447 .24791 L p
1 g
F P
s
P
p
.002 w
.62858 .55417 m .66533 .50737 L .65487 .49692 L p
1 g
F P
s
P
p
.002 w
.67287 .4445 m .65487 .49692 L .66533 .50737 L p
1 g
F P
s
P
p
.002 w
.65382 .33559 m .61835 .29128 L .60786 .30059 L p
1 g
F P
s
P
p
.002 w
.56458 .27335 m .60786 .30059 L .61835 .29128 L p
1 g
F P
s
P
p
.002 w
.57008 .26088 m .51447 .24791 L .51474 .26172 L p
1 g
F P
s
P
p
.002 w
.51474 .26172 m .56458 .27335 L .57008 .26088 L p
1 g
F P
s
P
p
.002 w
.61835 .29128 m .57008 .26088 L .56458 .27335 L p
1 g
F P
s
P
p
.002 w
.35423 .31312 m .32762 .36685 L .34195 .3667 L p
1 g
F P
s
P
p
.002 w
.34195 .3667 m .36668 .31694 L .35423 .31312 L p
1 g
F P
s
P
p
.002 w
.4011 .58596 m .45858 .60979 L .46212 .5968 L p
1 g
F P
s
P
p
.002 w
.46212 .5968 m .4073 .57406 L .4011 .58596 L p
1 g
F P
s
P
p
.002 w
.5213 .60111 m .46212 .5968 L .45858 .60979 L p
1 g
F P
s
P
p
.002 w
.35407 .54524 m .4011 .58596 L .4073 .57406 L p
1 g
F P
s
P
p
.002 w
.4073 .57406 m .36247 .5352 L .35407 .54524 L p
1 g
F P
s
P
p
.002 w
.45858 .60979 m .52063 .61434 L .5213 .60111 L p
1 g
F P
s
P
p
.002 w
.57878 .58646 m .5213 .60111 L .52063 .61434 L p
1 g
F P
s
P
p
.002 w
.3224 .49169 m .35407 .54524 L .36247 .5352 L p
1 g
F P
s
P
p
.002 w
.36247 .5352 m .33231 .48411 L .3224 .49169 L p
1 g
F P
s
P
p
.002 w
.66533 .50737 m .68483 .45084 L .67287 .4445 L p
1 g
F P
s
P
p
.002 w
.67261 .38867 m .67287 .4445 L .68483 .45084 L p
1 g
F P
s
P
p
.002 w
.52063 .61434 m .58092 .59902 L .57878 .58646 L p
1 g
F P
s
P
p
.002 w
.62858 .55417 m .57878 .58646 L .58092 .59902 L p
1 g
F P
s
P
p
.002 w
.39743 .27081 m .35423 .31312 L .36668 .31694 L p
1 g
F P
s
P
p
.002 w
.36668 .31694 m .40674 .2778 L .39743 .27081 L p
1 g
F P
s
P
p
.002 w
.3096 .43074 m .3224 .49169 L .33231 .48411 L p
1 g
F P
s
P
p
.002 w
.33231 .48411 m .32017 .42597 L .3096 .43074 L p
1 g
F P
s
P
p
.002 w
.68483 .45084 m .68463 .39058 L .67261 .38867 L p
1 g
F P
s
P
p
.002 w
.65382 .33559 m .67261 .38867 L .68463 .39058 L p
1 g
F P
s
P
p
.002 w
.58092 .59902 m .63317 .56522 L .62858 .55417 L p
1 g
F P
s
P
p
.002 w
.66533 .50737 m .62858 .55417 L .63317 .56522 L p
1 g
F P
s
P
p
.002 w
.45266 .24486 m .39743 .27081 L .40674 .2778 L p
1 g
F P
s
P
p
.002 w
.40674 .2778 m .45789 .25382 L .45266 .24486 L p
1 g
F P
s
P
p
.002 w
.31734 .36872 m .3096 .43074 L .32017 .42597 L p
1 g
F P
s
P
p
.002 w
.32017 .42597 m .32762 .36685 L .31734 .36872 L p
1 g
F P
s
P
p
.002 w
.68463 .39058 m .66438 .33323 L .65382 .33559 L p
1 g
F P
s
P
p
.002 w
.61835 .29128 m .65382 .33559 L .66438 .33323 L p
1 g
F P
s
P
p
.002 w
.51381 .23845 m .45266 .24486 L .45789 .25382 L p
1 g
F P
s
P
p
.002 w
.45789 .25382 m .51447 .24791 L .51381 .23845 L p
1 g
F P
s
P
p
.002 w
.63317 .56522 m .67176 .51618 L .66533 .50737 L p
1 g
F P
s
P
p
.002 w
.68483 .45084 m .66533 .50737 L .67176 .51618 L p
1 g
F P
s
P
p
.002 w
.66438 .33323 m .62608 .28534 L .61835 .29128 L p
1 g
F P
s
P
p
.002 w
.57008 .26088 m .61835 .29128 L .62608 .28534 L p
1 g
F P
s
P
p
.002 w
.57392 .25246 m .51381 .23845 L .51447 .24791 L p
1 g
F P
s
P
p
.002 w
.51447 .24791 m .57008 .26088 L .57392 .25246 L p
1 g
F P
s
P
p
.002 w
.62608 .28534 m .57392 .25246 L .57008 .26088 L p
1 g
F P
s
P
p
.002 w
.34521 .31232 m .31734 .36872 L .32762 .36685 L p
1 g
F P
s
P
p
.002 w
.32762 .36685 m .35423 .31312 L .34521 .31232 L p
1 g
F P
s
P
p
.002 w
.39731 .59415 m .45601 .61849 L .45858 .60979 L p
1 g
F P
s
P
p
.002 w
.45858 .60979 m .4011 .58596 L .39731 .59415 L p
1 g
F P
s
P
p
.002 w
.52063 .61434 m .45858 .60979 L .45601 .61849 L p
1 g
F P
s
P
p
.002 w
.34927 .55259 m .39731 .59415 L .4011 .58596 L p
1 g
F P
s
P
p
.002 w
.4011 .58596 m .35407 .54524 L .34927 .55259 L p
1 g
F P
s
P
p
.002 w
.45601 .61849 m .51937 .62315 L .52063 .61434 L p
1 g
F P
s
P
p
.002 w
.58092 .59902 m .52063 .61434 L .51937 .62315 L p
1 g
F P
s
P
p
.002 w
.3169 .49793 m .34927 .55259 L .35407 .54524 L p
1 g
F P
s
P
p
.002 w
.35407 .54524 m .3224 .49169 L .3169 .49793 L p
1 g
F P
s
P
p
.002 w
.67176 .51618 m .69228 .4569 L .68483 .45084 L p
1 g
F P
s
P
p
.002 w
.68463 .39058 m .68483 .45084 L .69228 .4569 L p
1 g
F P
s
P
p
.002 w
.51937 .62315 m .58094 .60754 L .58092 .59902 L p
1 g
F P
s
P
p
.002 w
.63317 .56522 m .58092 .59902 L .58094 .60754 L p
1 g
F P
s
P
p
.002 w
.39053 .26789 m .34521 .31232 L .35423 .31312 L p
1 g
F P
s
P
p
.002 w
.35423 .31312 m .39743 .27081 L .39053 .26789 L p
1 g
F P
s
P
p
.002 w
.30379 .43571 m .3169 .49793 L .3224 .49169 L p
1 g
F P
s
P
p
.002 w
.3224 .49169 m .3096 .43074 L .30379 .43571 L p
1 g
F P
s
P
p
.002 w
.69228 .4569 m .69212 .39366 L .68463 .39058 L p
1 g
F P
s
P
p
.002 w
.66438 .33323 m .68463 .39058 L .69212 .39366 L p
1 g
F P
s
P
p
.002 w
.58094 .60754 m .63432 .57306 L .63317 .56522 L p
1 g
F P
s
P
p
.002 w
.67176 .51618 m .63317 .56522 L .63432 .57306 L p
1 g
F P
s
P
p
.002 w
.44851 .24062 m .39053 .26789 L .39743 .27081 L p
1 g
F P
s
P
p
.002 w
.39743 .27081 m .45266 .24486 L .44851 .24062 L p
1 g
F P
s
P
p
.002 w
.31166 .37238 m .30379 .43571 L .3096 .43074 L p
1 g
F P
s
P
p
.002 w
.3096 .43074 m .31734 .36872 L .31166 .37238 L p
1 g
F P
s
P
p
.002 w
.69212 .39366 m .6709 .33344 L .66438 .33323 L p
1 g
F P
s
P
p
.002 w
.62608 .28534 m .66438 .33323 L .6709 .33344 L p
1 g
F P
s
P
p
.002 w
.51274 .23387 m .44851 .24062 L .45266 .24486 L p
1 g
F P
s
P
p
.002 w
.45266 .24486 m .51381 .23845 L .51274 .23387 L p
1 g
F P
s
P
p
.002 w
.63432 .57306 m .67376 .52302 L .67176 .51618 L p
1 g
F P
s
P
p
.002 w
.69228 .4569 m .67176 .51618 L .67376 .52302 L p
1 g
F P
s
P
p
.002 w
.6709 .33344 m .63068 .28313 L .62608 .28534 L p
1 g
F P
s
P
p
.002 w
.57392 .25246 m .62608 .28534 L .63068 .28313 L p
1 g
F P
s
P
p
.002 w
.57588 .24859 m .51274 .23387 L .51381 .23845 L p
1 g
F P
s
P
p
.002 w
.51381 .23845 m .57392 .25246 L .57588 .24859 L p
1 g
F P
s
P
p
.002 w
.63068 .28313 m .57588 .24859 L .57392 .25246 L p
1 g
F P
s
P
p
.002 w
.3401 .31478 m .31166 .37238 L .31734 .36872 L p
1 g
F P
s
P
p
.002 w
.31734 .36872 m .34521 .31232 L .3401 .31478 L p
1 g
F P
s
P
p
.002 w
.39619 .59819 m .45454 .62238 L .45601 .61849 L p
1 g
F P
s
P
p
.002 w
.45601 .61849 m .39731 .59415 L .39619 .59819 L p
1 g
F P
s
P
p
.002 w
.51937 .62315 m .45601 .61849 L .45454 .62238 L p
1 g
F P
s
P
p
.002 w
.34843 .55688 m .39619 .59819 L .39731 .59415 L p
1 g
F P
s
P
p
.002 w
.39731 .59415 m .34927 .55259 L .34843 .55688 L p
1 g
F P
s
P
p
.002 w
.45454 .62238 m .51753 .62702 L .51937 .62315 L p
1 g
F P
s
P
p
.002 w
.58094 .60754 m .51937 .62315 L .51753 .62702 L p
1 g
F P
s
P
p
.002 w
.31625 .50257 m .34843 .55688 L .34927 .55259 L p
1 g
F P
s
P
p
.002 w
.34927 .55259 m .3169 .49793 L .31625 .50257 L p
1 g
F P
s
P
p
.002 w
.67376 .52302 m .69474 .46249 L .69228 .4569 L p
1 g
F P
s
P
p
.002 w
.69212 .39366 m .69228 .4569 L .69474 .46249 L p
1 g
F P
s
P
p
.002 w
.51753 .62702 m .57873 .61152 L .58094 .60754 L p
1 g
F P
s
P
p
.002 w
.63432 .57306 m .58094 .60754 L .57873 .61152 L p
1 g
F P
s
P
p
.002 w
.38638 .26938 m .3401 .31478 L .34521 .31232 L p
1 g
F P
s
P
p
.002 w
.34521 .31232 m .39053 .26789 L .38638 .26938 L p
1 g
F P
s
P
p
.002 w
.30321 .44075 m .31625 .50257 L .3169 .49793 L p
1 g
F P
s
P
p
.002 w
.3169 .49793 m .30379 .43571 L .30321 .44075 L p
1 g
F P
s
P
p
.002 w
.69474 .46249 m .69459 .3979 L .69212 .39366 L p
1 g
F P
s
P
p
.002 w
.6709 .33344 m .69212 .39366 L .69459 .3979 L p
1 g
F P
s
P
p
.004 w
.36625 .22594 m
.37298 .23624 L
s
P
p
.004 w
.36263 .22041 m
.36625 .22594 L
s
P
p
.002 w
.57873 .61152 m .63178 .57726 L .63432 .57306 L p
1 g
F P
s
P
p
.002 w
.67376 .52302 m .63432 .57306 L .63178 .57726 L p
1 g
F P
s
P
p
.002 w
.44562 .24152 m .38638 .26938 L .39053 .26789 L p
1 g
F P
s
P
p
.002 w
.39053 .26789 m .44851 .24062 L .44562 .24152 L p
1 g
F P
s
P
p
.002 w
.31104 .37784 m .30321 .44075 L .30379 .43571 L p
1 g
F P
s
P
p
.002 w
.30379 .43571 m .31166 .37238 L .31104 .37784 L p
1 g
F P
s
P
p
.002 w
.69459 .3979 m .67291 .33639 L .6709 .33344 L p
1 g
F P
s
P
p
.002 w
.63068 .28313 m .6709 .33344 L .67291 .33639 L p
1 g
F P
s
P
p
.002 w
.51126 .23462 m .44562 .24152 L .44851 .24062 L p
1 g
F P
s
P
p
.002 w
.44851 .24062 m .51274 .23387 L .51126 .23462 L p
1 g
F P
s
P
p
.002 w
.63178 .57726 m .67095 .52755 L .67376 .52302 L p
1 g
F P
s
P
p
.002 w
.69474 .46249 m .67376 .52302 L .67095 .52755 L p
1 g
F P
s
P
p
.002 w
.67291 .33639 m .63181 .28497 L .63068 .28313 L p
1 g
F P
s
P
p
.002 w
.57588 .24859 m .63068 .28313 L .63181 .28497 L p
1 g
F P
s
P
p
.002 w
.5758 .24967 m .51126 .23462 L .51274 .23387 L p
1 g
F P
s
P
p
.002 w
.51274 .23387 m .57588 .24859 L .5758 .24967 L p
1 g
F P
s
P
p
.002 w
.3393 .32062 m .31104 .37784 L .31166 .37238 L p
1 g
F P
s
P
p
.002 w
.31166 .37238 m .3401 .31478 L .3393 .32062 L p
1 g
F P
s
P
p
.002 w
.63181 .28497 m .5758 .24967 L .57588 .24859 L p
1 g
F P
s
P
p
.002 w
.39795 .59767 m .4543 .62103 L .45454 .62238 L p
1 g
F P
s
P
p
.002 w
.45454 .62238 m .39619 .59819 L .39795 .59767 L p
1 g
F P
s
P
p
.002 w
.51753 .62702 m .45454 .62238 L .4543 .62103 L p
1 g
F P
s
P
p
.002 w
.35184 .55779 m .39795 .59767 L .39619 .59819 L p
1 g
F P
s
P
p
.002 w
.39619 .59819 m .34843 .55688 L .35184 .55779 L p
1 g
F P
s
P
p
.002 w
.4543 .62103 m .51511 .62551 L .51753 .62702 L p
1 g
F P
s
P
p
.002 w
.57873 .61152 m .51753 .62702 L .51511 .62551 L p
1 g
F P
s
P
p
.002 w
.32079 .50537 m .35184 .55779 L .34843 .55688 L p
1 g
F P
s
P
p
.002 w
.34843 .55688 m .31625 .50257 L .32079 .50537 L p
1 g
F P
s
P
p
.002 w
.67095 .52755 m .69179 .46743 L .69474 .46249 L p
1 g
F P
s
P
p
.002 w
.69459 .3979 m .69474 .46249 L .69179 .46743 L p
1 g
F P
s
P
p
.002 w
.51511 .62551 m .57418 .61054 L .57873 .61152 L p
1 g
F P
s
P
p
.002 w
.63178 .57726 m .57873 .61152 L .57418 .61054 L p
1 g
F P
s
P
p
.002 w
.38529 .27554 m .3393 .32062 L .3401 .31478 L p
1 g
F P
s
P
p
.002 w
.3401 .31478 m .38638 .26938 L .38529 .27554 L p
1 g
F P
s
P
p
.002 w
.30824 .44572 m .32079 .50537 L .31625 .50257 L p
1 g
F P
s
P
p
.002 w
.31625 .50257 m .30321 .44075 L .30824 .44572 L p
1 g
F P
s
P
p
.002 w
.69179 .46743 m .69162 .40326 L .69459 .3979 L p
1 g
F P
s
P
p
.002 w
.67291 .33639 m .69459 .3979 L .69162 .40326 L p
1 g
F P
s
P
p
.002 w
.57418 .61054 m .62536 .57747 L .63178 .57726 L p
1 g
F P
s
P
p
.002 w
.67095 .52755 m .63178 .57726 L .62536 .57747 L p
1 g
F P
s
P
p
.002 w
.44416 .24788 m .38529 .27554 L .38638 .26938 L p
1 g
F P
s
P
p
.002 w
.38638 .26938 m .44562 .24152 L .44416 .24788 L p
1 g
F P
s
P
p
.002 w
.31582 .38505 m .30824 .44572 L .30321 .44075 L p
1 g
F P
s
P
p
.002 w
.30321 .44075 m .31104 .37784 L .31582 .38505 L p
1 g
F P
s
P
p
.002 w
.69162 .40326 m .67006 .34215 L .67291 .33639 L p
1 g
F P
s
P
p
.002 w
.63181 .28497 m .67291 .33639 L .67006 .34215 L p
1 g
F P
s
P
p
.002 w
.50939 .24104 m .44416 .24788 L .44562 .24152 L p
1 g
F P
s
P
p
.002 w
.44562 .24152 m .51126 .23462 L .50939 .24104 L p
1 g
F P
s
P
p
.002 w
.62536 .57747 m .66313 .5295 L .67095 .52755 L p
1 g
F P
s
P
p
.002 w
.69179 .46743 m .67095 .52755 L .66313 .5295 L p
1 g
F P
s
P
p
.002 w
.67006 .34215 m .6292 .29108 L .63181 .28497 L p
1 g
F P
s
P
p
.002 w
.5758 .24967 m .63181 .28497 L .6292 .29108 L p
1 g
F P
s
P
p
.002 w
.57353 .256 m .50939 .24104 L .51126 .23462 L p
1 g
F P
s
P
p
.002 w
.51126 .23462 m .5758 .24967 L .57353 .256 L p
1 g
F P
s
P
p
.002 w
.34311 .3299 m .31582 .38505 L .31104 .37784 L p
1 g
F P
s
P
p
.002 w
.31104 .37784 m .3393 .32062 L .34311 .3299 L p
1 g
F P
s
P
p
.002 w
.6292 .29108 m .57353 .256 L .5758 .24967 L p
1 g
F P
s
P
p
.002 w
.40273 .59232 m .45535 .61414 L .4543 .62103 L p
1 g
F P
s
P
p
.002 w
.4543 .62103 m .39795 .59767 L .40273 .59232 L p
1 g
F P
s
P
p
.002 w
.51511 .62551 m .4543 .62103 L .45535 .61414 L p
1 g
F P
s
P
p
.002 w
.35969 .55506 m .40273 .59232 L .39795 .59767 L p
1 g
F P
s
P
p
.002 w
.39795 .59767 m .35184 .55779 L .35969 .55506 L p
1 g
F P
s
P
p
.002 w
.45535 .61414 m .51215 .61831 L .51511 .62551 L p
1 g
F P
s
P
p
.002 w
.57418 .61054 m .51511 .62551 L .51215 .61831 L p
1 g
F P
s
P
p
.002 w
.33073 .50611 m .35969 .55506 L .35184 .55779 L p
1 g
F P
s
P
p
.002 w
.35184 .55779 m .32079 .50537 L .33073 .50611 L p
1 g
F P
s
P
p
.002 w
.66313 .5295 m .68317 .47151 L .69179 .46743 L p
1 g
F P
s
P
p
.002 w
.69162 .40326 m .69179 .46743 L .68317 .47151 L p
1 g
F P
s
P
p
.002 w
.51215 .61831 m .56729 .60431 L .57418 .61054 L p
1 g
F P
s
P
p
.002 w
.62536 .57747 m .57418 .61054 L .56729 .60431 L p
1 g
F P
s
P
p
.002 w
.38749 .28647 m .34311 .3299 L .3393 .32062 L p
1 g
F P
s
P
p
.002 w
.3393 .32062 m .38529 .27554 L .38749 .28647 L p
1 g
F P
s
P
p
.002 w
.31907 .45045 m .33073 .50611 L .32079 .50537 L p
1 g
F P
s
P
p
.002 w
.32079 .50537 m .30824 .44572 L .31907 .45045 L p
1 g
F P
s
P
p
.002 w
.68317 .47151 m .68295 .40965 L .69162 .40326 L p
1 g
F P
s
P
p
.002 w
.67006 .34215 m .69162 .40326 L .68295 .40965 L p
1 g
F P
s
P
p
.002 w
.56729 .60431 m .61502 .57341 L .62536 .57747 L p
1 g
F P
s
P
p
.002 w
.66313 .5295 m .62536 .57747 L .61502 .57341 L p
1 g
F P
s
P
p
.002 w
.44427 .25985 m .38749 .28647 L .38529 .27554 L p
1 g
F P
s
P
p
.002 w
.38529 .27554 m .44416 .24788 L .44427 .25985 L p
1 g
F P
s
P
p
.004 w
.37298 .23624 m
.3868 .25737 L
s
P
p
.002 w
.32621 .39389 m .31907 .45045 L .30824 .44572 L p
1 g
F P
s
P
p
.002 w
.30824 .44572 m .31582 .38505 L .32621 .39389 L p
1 g
F P
s
P
p
.002 w
.68295 .40965 m .66211 .35075 L .67006 .34215 L p
1 g
F P
s
P
p
.002 w
.6292 .29108 m .67006 .34215 L .66211 .35075 L p
1 g
F P
s
P
p
.002 w
.50717 .2533 m .44427 .25985 L .44416 .24788 L p
1 g
F P
s
P
p
.002 w
.44416 .24788 m .50939 .24104 L .50717 .2533 L p
1 g
F P
s
P
p
.002 w
.61502 .57341 m .65019 .52864 L .66313 .5295 L p
1 g
F P
s
P
p
.002 w
.68317 .47151 m .66313 .5295 L .65019 .52864 L p
1 g
F P
s
P
p
.002 w
.66211 .35075 m .62269 .30153 L .6292 .29108 L p
1 g
F P
s
P
p
.002 w
.57353 .256 m .6292 .29108 L .62269 .30153 L p
1 g
F P
s
P
p
.002 w
.35172 .34254 m .32621 .39389 L .31582 .38505 L p
1 g
F P
s
P
p
.002 w
.31582 .38505 m .34311 .3299 L .35172 .34254 L p
1 g
F P
s
P
p
.002 w
.56901 .26773 m .50717 .2533 L .50939 .24104 L p
1 g
F P
s
P
p
.002 w
.50939 .24104 m .57353 .256 L .56901 .26773 L p
1 g
F P
s
P
p
.002 w
.62269 .30153 m .56901 .26773 L .57353 .256 L p
1 g
F P
s
P
p
.002 w
.41057 .58197 m .45777 .60155 L .45535 .61414 L p
1 g
F P
s
P
p
.002 w
.45535 .61414 m .40273 .59232 L .41057 .58197 L p
1 g
F P
s
P
p
.002 w
.51215 .61831 m .45535 .61414 L .45777 .60155 L p
1 g
F P
s
P
p
.002 w
.372 .54855 m .41057 .58197 L .40273 .59232 L p
1 g
F P
s
P
p
.002 w
.40273 .59232 m .35969 .55506 L .372 .54855 L p
1 g
F P
s
P
p
.002 w
.45777 .60155 m .5087 .60527 L .51215 .61831 L p
1 g
F P
s
P
p
.002 w
.56729 .60431 m .51215 .61831 L .5087 .60527 L p
1 g
F P
s
P
p
.002 w
.65019 .52864 m .6688 .47455 L .68317 .47151 L p
1 g
F P
s
P
p
.002 w
.68295 .40965 m .68317 .47151 L .6688 .47455 L p
1 g
F P
s
P
p
.002 w
.34609 .50465 m .372 .54855 L .35969 .55506 L p
1 g
F P
s
P
p
.002 w
.35969 .55506 m .33073 .50611 L .34609 .50465 L p
1 g
F P
s
P
p
.002 w
.39313 .30214 m .35172 .34254 L .34311 .3299 L p
1 g
F P
s
P
p
.002 w
.34311 .3299 m .38749 .28647 L .39313 .30214 L p
1 g
F P
s
P
p
.002 w
.5087 .60527 m .55812 .59268 L .56729 .60431 L p
1 g
F P
s
P
p
.002 w
.61502 .57341 m .56729 .60431 L .55812 .59268 L p
1 g
F P
s
P
p
.002 w
.33572 .45479 m .34609 .50465 L .33073 .50611 L p
1 g
F P
s
P
p
.002 w
.33073 .50611 m .31907 .45045 L .33572 .45479 L p
1 g
F P
s
P
p
.002 w
.6688 .47455 m .66851 .41691 L .68295 .40965 L p
1 g
F P
s
P
p
.002 w
.66211 .35075 m .68295 .40965 L .66851 .41691 L p
1 g
F P
s
P
p
.002 w
.55812 .59268 m .60084 .56494 L .61502 .57341 L p
1 g
F P
s
P
p
.002 w
.65019 .52864 m .61502 .57341 L .60084 .56494 L p
1 g
F P
s
P
p
.002 w
.44605 .27741 m .39313 .30214 L .38749 .28647 L p
1 g
F P
s
P
p
.002 w
.38749 .28647 m .44427 .25985 L .44605 .27741 L p
1 g
F P
s
P
p
.004 w
.3868 .25737 m
.39172 .2649 L
s
P
p
.002 w
.34221 .40418 m .33572 .45479 L .31907 .45045 L p
1 g
F P
s
P
p
.002 w
.31907 .45045 m .32621 .39389 L .34221 .40418 L p
1 g
F P
s
P
p
.002 w
.66851 .41691 m .64902 .36207 L .66211 .35075 L p
1 g
F P
s
P
p
.002 w
.62269 .30153 m .66211 .35075 L .64902 .36207 L p
1 g
F P
s
P
p
.002 w
.50464 .27135 m .44605 .27741 L .44427 .25985 L p
1 g
F P
s
P
p
.002 w
.44427 .25985 m .50717 .2533 L .50464 .27135 L p
1 g
F P
s
P
p
.002 w
.60084 .56494 m .63225 .52481 L .65019 .52864 L p
1 g
F P
s
P
p
.002 w
.6688 .47455 m .65019 .52864 L .63225 .52481 L p
1 g
F P
s
P
p
.002 w
.64902 .36207 m .61225 .31626 L .62269 .30153 L p
1 g
F P
s
P
p
.002 w
.56901 .26773 m .62269 .30153 L .61225 .31626 L p
1 g
F P
s
P
p
.002 w
.36512 .3583 m .34221 .40418 L .32621 .39389 L p
1 g
F P
s
P
p
.002 w
.32621 .39389 m .35172 .34254 L .36512 .3583 L p
1 g
F P
s
P
p
.002 w
.56224 .2848 m .50464 .27135 L .50717 .2533 L p
1 g
F P
s
P
p
.002 w
.50717 .2533 m .56901 .26773 L .56224 .2848 L p
1 g
F P
s
P
p
.002 w
.61225 .31626 m .56224 .2848 L .56901 .26773 L p
1 g
F P
s
P
p
.002 w
.42141 .56668 m .46154 .58334 L .45777 .60155 L p
1 g
F P
s
P
p
.002 w
.45777 .60155 m .41057 .58197 L .42141 .56668 L p
1 g
F P
s
P
p
.002 w
.5087 .60527 m .45777 .60155 L .46154 .58334 L p
1 g
F P
s
P
p
.002 w
.38863 .53824 m .42141 .56668 L .41057 .58197 L p
1 g
F P
s
P
p
.002 w
.41057 .58197 m .372 .54855 L .38863 .53824 L p
1 g
F P
s
P
p
.002 w
.46154 .58334 m .50486 .58647 L .5087 .60527 L p
1 g
F P
s
P
p
.002 w
.55812 .59268 m .5087 .60527 L .50486 .58647 L p
1 g
F P
s
P
p
.002 w
.63225 .52481 m .64881 .47639 L .6688 .47455 L p
1 g
F P
s
P
p
.002 w
.66851 .41691 m .6688 .47455 L .64881 .47639 L p
1 g
F P
s
P
p
.002 w
.36667 .50091 m .38863 .53824 L .372 .54855 L p
1 g
F P
s
P
p
.002 w
.372 .54855 m .34609 .50465 L .36667 .50091 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.4022 .32226 m .36512 .3583 L .35172 .34254 L p
1 g
F P
s
P
p
.002 w
.35172 .34254 m .39313 .30214 L .4022 .32226 L p
1 g
F P
s
P
p
.002 w
.50486 .58647 m .54685 .57572 L .55812 .59268 L p
1 g
F P
s
P
p
.002 w
.60084 .56494 m .55812 .59268 L .54685 .57572 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.35795 .45855 m .36667 .50091 L .34609 .50465 L p
1 g
F P
s
P
p
.002 w
.34609 .50465 m .33572 .45479 L .35795 .45855 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.64881 .47639 m .64844 .42486 L .66851 .41691 L p
1 g
F P
s
P
p
.002 w
.64902 .36207 m .66851 .41691 L .64844 .42486 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.54685 .57572 m .58309 .5521 L .60084 .56494 L p
1 g
F P
s
P
p
.002 w
.63225 .52481 m .60084 .56494 L .58309 .5521 L p
1 g
F P
s
P
p
.002 w
.44953 .30024 m .4022 .32226 L .39313 .30214 L p
1 g
F P
s
P
p
.004 w
.42292 .31262 m
.5 .43051 L
s
P
p
.002 w
.39313 .30214 m .44605 .27741 L .44953 .30024 L p
1 g
F P
s
P
p
.004 w
.4132 .29776 m
.41389 .2988 L
s
P
p
.004 w
.39172 .2649 m
.40306 .28225 L
s
P
p
.004 w
.40306 .28225 m
.40979 .29253 L
s
P
p
.004 w
.40979 .29253 m
.4132 .29776 L
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.36355 .41563 m .35795 .45855 L .33572 .45479 L p
1 g
F P
s
P
p
.002 w
.33572 .45479 m .34221 .40418 L .36355 .41563 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.64844 .42486 m .63093 .37588 L .64902 .36207 L p
1 g
F P
s
P
p
.002 w
.61225 .31626 m .64902 .36207 L .63093 .37588 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.58309 .5521 m .60967 .51798 L .63225 .52481 L p
1 g
F P
s
P
p
.002 w
.64881 .47639 m .63225 .52481 L .60967 .51798 L p
1 g
F P
s
P
p
.002 w
.50188 .29488 m .44953 .30024 L .44605 .27741 L p
1 g
F P
s
P
p
.002 w
.44605 .27741 m .50464 .27135 L .50188 .29488 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.63093 .37588 m .59803 .335 L .61225 .31626 L p
1 g
F P
s
P
p
.002 w
.56224 .2848 m .61225 .31626 L .59803 .335 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.38308 .37679 m .36355 .41563 L .34221 .40418 L p
1 g
F P
s
P
p
.002 w
.34221 .40418 m .36512 .3583 L .38308 .37679 L p
1 g
F P
s
P
p
.002 w
.55333 .30692 m .50188 .29488 L .50464 .27135 L p
1 g
F P
s
P
p
.002 w
.50464 .27135 m .56224 .2848 L .55333 .30692 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.59803 .335 m .55333 .30692 L .56224 .2848 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.46154 .58334 m .44176 .55601 L .45096 .56262 L 1 g
F
P
p
.002 w
.464 .57198 m .46296 .57675 L p
.45096 .56262 L 1 g
F P
s
P
p
.002 w
.46296 .57675 m .46154 .58334 L p
.45096 .56262 L 1 g
F P
s
P
p
.002 w
.45096 .56262 m .45146 .56129 L p
.44525 .55589 L 1 g
F P
s
P
p
.46872 .57265 m .46018 .56924 L .464 .57198 L 1 g
F
P
p
.002 w
.4883 .58527 m .46154 .58334 L .46376 .57308 L p
1 g
F P
s
P
p
.002 w
.46376 .57308 m .464 .57198 L p
.46835 .57436 L 1 g
F P
s
P
p
.4883 .58527 m .46376 .57308 L .46835 .57436 L 1 g
F
P
p
.002 w
.4891 .58014 m .48921 .57862 L p
.4813 .57797 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50486 .58647 m .4883 .58527 L p
.48365 .57982 L 1 g
F P
s
P
p
.50486 .58647 m .48365 .57982 L .48719 .58003 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46835 .57436 L p
1 g
F P
s
P
p
.48921 .57862 m .46835 .57436 L .4813 .57797 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58014 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58014 L .49993 .58079 L 1 g
F
P
p
.4964 .58058 m .48232 .57825 L .46662 .55982 L 1 g
F
P
p
.50023 .58325 m .4891 .58014 L .4964 .58058 L 1 g
F
P
p
.4891 .58014 m .48232 .57825 L .4964 .58058 L 1 g
F
P
p
.50486 .58647 m .48232 .57825 L .50023 .58325 L 1 g
F
P
p
.51079 .57862 m .49993 .58079 L .50393 .58103 L 1 g
F
P
p
.002 w
.53623 .57844 m .50486 .58647 L .50418 .58253 L p
1 g
F P
s
P
p
.002 w
.50418 .58253 m .50393 .58103 L p
.51093 .58047 L 1 g
F P
s
P
p
.53623 .57844 m .50418 .58253 L .51093 .58047 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58047 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58047 L .52351 .57664 L 1 g
F
P
p
.002 w
.51093 .58047 m .51079 .57862 L p
.50393 .58103 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53161 .57417 m .53128 .57265 L p
.52351 .57664 L 1 g
F P
s
P
p
.002 w
.50393 .58103 m .50073 .56227 L p
.52875 .57504 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53161 .57417 L p
1 g
F P
s
P
p
.53623 .57844 m .52235 .57956 L .52952 .57538 L 1 g
F
P
p
.54854 .56129 m .53161 .57417 L .54038 .56906 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54685 .57572 m .53623 .57844 L p
.52952 .57538 L 1 g
F P
s
P
p
.53492 .57224 m .52952 .57538 L .50073 .56227 L 1 g
F
P
p
.54685 .57572 m .52952 .57538 L .53492 .57224 L 1 g
F
P
p
.54854 .56129 m .54038 .56906 L .54224 .56799 L 1 g
F
P
p
.58309 .5521 m .54613 .56647 L .5619 .55282 L 1 g
F
P
p
.54613 .56647 m .54224 .56799 L .54907 .56271 L 1 g
F
P
p
.54613 .56647 m .54907 .56271 L .5619 .55282 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54907 .56271 L p
1 g
F P
s
P
p
.002 w
.58309 .5521 m .54685 .57572 L .54224 .56799 L p
1 g
F P
s
P
p
.56075 .54566 m .54907 .56271 L .5568 .55283 L 1 g
F
P
p
.002 w
.54907 .56271 m .54854 .56129 L p
.54224 .56799 L 1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54224 .56799 m .53377 .55376 L p
.55667 .55299 L 1 g
F P
s
P
p
.5619 .55282 m .54907 .56271 L .55667 .55299 L 1 g
F
P
p
.54907 .56271 m .54224 .56799 L .55667 .55299 L 1 g
F
P
p
.002 w
.56142 .54692 m .56075 .54566 L p
.5568 .55283 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56142 .54692 L p
1 g
F P
s
P
p
.56654 .52734 m .56142 .54692 L .56437 .53924 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56506 .53743 m .58309 .5521 L p
.55911 .55291 L 1 g
F P
s
P
p
.002 w
.60967 .51798 m .58309 .5521 L .56506 .53743 L p
1 g
F P
s
P
p
.60967 .51798 m .56506 .53743 L .56614 .53371 L 1 g
F
P
p
.002 w
.56755 .52881 m .56654 .52734 L p
.56407 .54086 L 1 g
F P
s
P
p
.002 w
.58303 .50826 m .60967 .51798 L p
.56772 .53314 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56755 .52881 L p
1 g
F P
s
P
p
.56515 .50826 m .56755 .52881 L .56753 .52827 L 1 g
F
P
p
.56659 .51057 m .56753 .52827 L .56607 .51064 L 1 g
F
P
p
.002 w
.58303 .50826 m .57212 .52235 L p
.56659 .51057 L 1 g
F P
s
P
p
.002 w
.57212 .52235 m .56753 .52827 L p
.56659 .51057 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.55661 .4905 m .56595 .50921 L .5621 .501 L 1 g
F
P
p
.56515 .50826 m .56753 .52827 L .56671 .51837 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56128 .49925 m .56526 .5009 L p
.56268 .50223 L 1 g
F P
s
P
p
.002 w
.56526 .5009 m .58303 .50826 L p
.56607 .51064 L 1 g
F P
s
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56671 .51837 L 1 g
F P
s
P
p
.56607 .51064 m .53888 .51446 L .56526 .5009 L 1 g
F
P
p
.002 w
.59385 .47599 m .58303 .50826 L .56128 .49925 L p
1 g
F P
s
P
p
.55661 .4905 m .5621 .501 L .56128 .49925 L 1 g
F
P
p
.002 w
.5575 .49145 m .55661 .4905 L p
.56128 .49925 L 1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.56128 .49925 m .55316 .49589 L p
.55841 .49332 L 1 g
F P
s
P
p
.59385 .47599 m .56128 .49925 L .55841 .49332 L 1 g
F
P
p
.002 w
.56054 .47364 m .59385 .47599 L p
.55841 .49332 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5575 .49145 L p
1 g
F P
s
P
p
.002 w
.55316 .49589 m .55533 .48935 L p
.55841 .49332 L 1 g
F P
s
P
p
.55841 .49332 m .55533 .48935 L .5575 .49145 L 1 g
F
P
p
.002 w
.5558 .48793 m .56054 .47364 L p
.55851 .49242 L 1 g
F P
s
P
p
.55841 .49332 m .5575 .49145 L .55851 .49242 L 1 g
F
P
p
.5575 .49145 m .5558 .48793 L .55851 .49242 L 1 g
F
P
p
.56128 .49925 m .56713 .51061 L .55773 .49169 L 1 g
F
P
p
.002 w
.55773 .49169 m .5575 .49145 L p
.56128 .49925 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55773 .49169 L p
1 g
F P
s
P
p
.002 w
.55316 .49589 m .52112 .48127 L p
.54271 .47709 L 1 g
F P
s
P
p
.002 w
.54231 .4767 m .54174 .47608 L p
.55054 .4847 L 1 g
F P
s
P
p
.54174 .47608 m .5575 .49145 L .55533 .48935 L 1 g
F
P
p
.002 w
.55533 .48935 m .55316 .49589 L p
.54271 .47709 L 1 g
F P
s
P
p
.55054 .4847 m .55533 .48935 L .55265 .48676 L 1 g
F
P
p
.54174 .47608 m .55533 .48935 L .55054 .4847 L 1 g
F
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .4767 L p
1 g
F P
s
P
p
.53404 .4728 m .52112 .48127 L .52877 .47032 L 1 g
F
P
p
.52214 .46667 m .54231 .4767 L .53343 .47252 L 1 g
F
P
p
.54271 .47709 m .52112 .48127 L .53404 .4728 L 1 g
F
P
p
.54231 .4767 m .53404 .4728 L .53658 .47113 L 1 g
F
P
p
.54271 .47709 m .53404 .4728 L .54231 .4767 L 1 g
F
P
p
.002 w
.52112 .48127 m .52484 .46991 L .52877 .47032 L p
1 g
F P
s
P
p
.52214 .46667 m .53343 .47252 L .52877 .47032 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.56015 .45009 m .56054 .47364 L .52877 .47032 L p
1 g
F P
s
P
p
.002 w
.52877 .47032 m .52484 .46991 L p
.52625 .46912 L 1 g
F P
s
P
p
.52214 .46667 m .52877 .47032 L .52481 .46844 L 1 g
F
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52481 .46844 m .52484 .46991 L p
.51972 .46687 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .46729 L p
1 g
F P
s
P
p
.5 .4634 m .52252 .46729 L .51198 .4657 L 1 g
F
P
p
.52252 .46729 m .51972 .46687 L .50949 .46081 L 1 g
F
P
p
.52481 .46844 m .51972 .46687 L .52252 .46729 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.52484 .46991 m .49115 .46532 L p
.5 .46389 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.51198 .4657 L 1 g
F P
s
P
p
.51154 .46203 m .51972 .46687 L .5 .46389 L 1 g
F
P
p
.51972 .46687 m .52484 .46991 L .5 .46389 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.51198 .4657 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.49221 .50045 m .48014 .49961 L .48792 .46583 L p
1 g
F P
s
P
p
.002 w
.51387 .49077 m .50387 .4974 L .48853 .46574 L p
1 g
F P
s
P
p
.002 w
.52484 .46991 m .52112 .48127 L .48949 .46559 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46391 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46391 L .49919 .46404 L 1 g
F
P
p
.47786 .46667 m .5 .46394 L .49878 .46413 L 1 g
F
P
p
.47786 .46667 m .5 .46398 L .49846 .46422 L 1 g
F
P
p
.47786 .46667 m .5 .46403 L .49824 .46429 L 1 g
F
P
p
.47786 .46667 m .5 .46409 L .49819 .46435 L 1 g
F
P
p
.47786 .46667 m .5 .46414 L .49276 .46515 L 1 g
F
P
p
.002 w
.49115 .46532 m .52484 .46991 L p
.48949 .46559 L 1 g
F P
s
P
p
.002 w
.52112 .48127 m .51387 .49077 L .4889 .46568 L p
1 g
F P
s
P
p
.002 w
.48949 .46559 m .52112 .48127 L p
.4889 .46568 L 1 g
F P
s
P
p
.002 w
.4889 .46568 m .51387 .49077 L p
.48853 .46574 L 1 g
F P
s
P
p
.002 w
.50387 .4974 m .49221 .50045 L .48823 .46578 L p
1 g
F P
s
P
p
.002 w
.48853 .46574 m .50387 .4974 L p
.48823 .46578 L 1 g
F P
s
P
p
.002 w
.48823 .46578 m .49221 .50045 L p
.48792 .46583 L 1 g
F P
s
P
p
.002 w
.48014 .49961 m .46896 .49496 L .48751 .46589 L p
1 g
F P
s
P
p
.002 w
.48792 .46583 m .48014 .49961 L p
.48751 .46589 L 1 g
F P
s
P
p
.47786 .46667 m .49126 .46531 L .48853 .46575 L 1 g
F
P
p
.002 w
.46896 .49496 m .45986 .48701 L .48675 .46599 L p
1 g
F P
s
P
p
.002 w
.48751 .46589 m .46896 .49496 L p
.48675 .46599 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45986 .48701 m .45526 .47908 L p
.48382 .46638 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.45526 .47908 m .45756 .47685 L .48382 .46638 L 1 g
F
P
p
.002 w
.45756 .47685 m .45826 .47608 L p
.46812 .47176 L 1 g
F P
s
P
p
.002 w
.46833 .47166 m .48382 .46638 L p
.45756 .47685 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46721 L p
1 g
F P
s
P
p
.47786 .46667 m .48853 .46575 L .48593 .4661 L 1 g
F
P
p
.002 w
.47753 .46721 m .47786 .46667 L p
.48593 .4661 L 1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.48232 .4649 m .48813 .46491 L .48382 .46638 L p
1 g
F P
s
P
p
.002 w
.48382 .46638 m .46833 .47166 L p
.47753 .46721 L 1 g
F P
s
P
p
.47753 .46721 m .48232 .4649 L .48382 .46638 L 1 g
F
P
p
.002 w
.48675 .46599 m .45986 .48701 L p
.48382 .46638 L 1 g
F P
s
P
p
.002 w
.47732 .46756 m .47751 .46725 L p
.48593 .4661 L 1 g
F P
s
P
p
.48593 .4661 m .48675 .46599 L .48667 .466 L 1 g
F
P
p
.48593 .4661 m .48667 .466 L .47732 .46756 L 1 g
F
P
p
.002 w
.47751 .46725 m .47753 .46721 L p
.48593 .4661 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45151 .46484 m .48232 .4649 L p
.47628 .46738 L 1 g
F P
s
P
p
.002 w
.45382 .47659 m .45262 .47052 L p
.47628 .46738 L 1 g
F P
s
P
p
.002 w
.45262 .47052 m .45151 .46484 L p
.47628 .46738 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46721 L .47733 .46731 L 1 g
F
P
p
.45826 .47608 m .47753 .46722 L .46812 .47176 L 1 g
F
P
p
.002 w
.46833 .47166 m .45382 .47659 L p
.48232 .4649 L 1 g
F P
s
P
p
.002 w
.47753 .46721 m .47753 .46722 L p
.47733 .46731 L 1 g
F P
s
P
p
.002 w
.47753 .46722 m .47718 .46778 L p
.46812 .47176 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45744 .47698 L p
1 g
F P
s
P
p
.002 w
.45526 .47908 m .45986 .48701 L p
.44622 .48783 L 1 g
F P
s
P
p
.002 w
.45744 .47698 m .45698 .47747 L p
.4509 .48331 L 1 g
F P
s
P
p
.44339 .4905 m .45744 .47698 L .4509 .48331 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43591 .50502 m .43324 .50703 L p
.43937 .49796 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43697 .54375 m .43502 .54671 L p
.43449 .53489 L 1 g
F P
s
P
p
.44176 .55601 m .43502 .54671 L .43952 .55063 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43825 .54755 L p
1 g
F P
s
P
p
.45146 .56129 m .43825 .54755 L .43852 .54793 L 1 g
F
P
p
.002 w
.43502 .54671 m .43625 .54485 L p
.43825 .54755 L 1 g
F P
s
P
p
.002 w
.43877 .54826 m .43844 .54812 L p
.43825 .54755 L 1 g
F P
s
P
p
.002 w
.43844 .54812 m .43502 .54671 L p
.43825 .54755 L 1 g
F P
s
P
p
.43925 .54566 m .43534 .53792 L .43697 .54375 L 1 g
F
P
p
.002 w
.43825 .54755 m .43925 .54566 L p
.43697 .54375 L 1 g
F P
s
P
p
.45146 .56129 m .43852 .54793 L .44525 .55589 L 1 g
F
P
p
.43852 .54793 m .43822 .54761 L .43877 .54826 L 1 g
F
P
p
.43852 .54793 m .43877 .54826 L .44525 .55589 L 1 g
F
P
p
.002 w
.43625 .54485 m .43697 .54375 L p
.43825 .54755 L 1 g
F P
s
P
p
.002 w
.40923 .52428 m .42778 .51095 L p
.43239 .53373 L 1 g
F P
s
P
p
.002 w
.43269 .52847 m .43346 .52734 L p
.43319 .51959 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43269 .52847 L p
1 g
F P
s
P
p
.43925 .54566 m .43269 .52847 L .43534 .53792 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.42778 .51095 m .43324 .50703 L p
.43353 .51358 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43376 .50956 L p
1 g
F P
s
P
p
.43346 .52734 m .43376 .50956 L .43319 .51959 L 1 g
F
P
p
.43449 .53489 m .43269 .52847 L .43353 .51358 L 1 g
F
P
p
.43269 .52847 m .42778 .51095 L .43353 .51358 L 1 g
F
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.45104 .52255 m .43697 .54375 L p
.43339 .51038 L 1 g
F P
s
P
p
.43449 .53489 m .43339 .51038 L .43697 .54375 L 1 g
F
P
p
.002 w
.43324 .50703 m .43443 .50807 L p
.43339 .51038 L 1 g
F P
s
P
p
.43485 .50826 m .43847 .4998 L .43591 .50502 L 1 g
F
P
p
.002 w
.43358 .50977 m .43365 .50969 L p
.43591 .50502 L 1 g
F P
s
P
p
.002 w
.43365 .50969 m .43485 .50826 L p
.43591 .50502 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44263 .49131 L p
1 g
F P
s
P
p
.43324 .50703 m .44099 .4929 L .43937 .49796 L 1 g
F
P
p
.44099 .4929 m .44913 .47806 L .44263 .49131 L 1 g
F
P
p
.44099 .4929 m .44263 .49131 L .43937 .49796 L 1 g
F
P
p
.002 w
.44263 .49131 m .44166 .49233 L p
.43847 .4998 L 1 g
F P
s
P
p
.43485 .50826 m .44263 .49131 L .43847 .4998 L 1 g
F
P
p
.002 w
.44263 .49131 m .44339 .4905 L p
.4509 .48331 L 1 g
F P
s
P
p
.002 w
.44913 .47806 m .45382 .47659 L p
.43937 .49796 L 1 g
F P
s
P
p
.002 w
.45986 .48701 m .43591 .50502 L p
.44622 .48783 L 1 g
F P
s
P
p
.43937 .49796 m .44622 .48783 L .43591 .50502 L 1 g
F
P
p
.002 w
.4417 .49229 m .44263 .49131 L p
.45266 .48162 L 1 g
F P
s
P
p
.4509 .48331 m .45266 .48162 L .44263 .49131 L 1 g
F
P
p
.002 w
.43324 .50703 m .42139 .4867 L .44913 .47806 L p
1 g
F P
s
P
p
.002 w
.45104 .52255 m .43443 .50807 L p
.45986 .48701 L 1 g
F P
s
P
p
.002 w
.43443 .50807 m .43324 .50703 L .43591 .50502 L p
1 g
F P
s
P
p
.002 w
.43591 .50502 m .45986 .48701 L p
.43443 .50807 L 1 g
F P
s
P
p
.002 w
.43443 .50807 m .45104 .52255 L p
.43339 .51038 L 1 g
F P
s
P
p
.002 w
.43376 .50956 m .43287 .51061 L p
.43319 .51959 L 1 g
F P
s
P
p
.43502 .54671 m .42778 .51095 L .43449 .53489 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43269 .52847 L p
1 g
F P
s
P
p
.43319 .51959 m .43287 .51061 L .43269 .52847 L 1 g
F
P
p
.002 w
.43502 .54671 m .43181 .54392 L p
.43239 .53373 L 1 g
F P
s
P
p
.002 w
.43181 .54392 m .40923 .52428 L p
.43239 .53373 L 1 g
F P
s
P
p
.002 w
.43269 .52847 m .43146 .53025 L p
.43534 .53792 L 1 g
F P
s
P
p
.43697 .54375 m .43146 .53025 L .43811 .54781 L 1 g
F
P
p
.43534 .53792 m .4344 .53606 L .43697 .54375 L 1 g
F
P
p
.4344 .53606 m .43146 .53025 L .43697 .54375 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.43877 .54826 m .43825 .54755 L .45104 .52255 L 1 g
F
P
p
.002 w
.43697 .54375 m .45104 .52255 L p
.43825 .54755 L 1 g
F P
s
P
p
.002 w
.43811 .54781 m .43825 .54755 L p
.43697 .54375 L 1 g
F P
s
P
p
.002 w
.46662 .55982 m .43877 .54826 L p
.45104 .52255 L 1 g
F P
s
P
p
.002 w
.43825 .54755 m .43822 .54761 L p
.43852 .54793 L 1 g
F P
s
P
p
.44188 .5561 m .43952 .55063 L .44438 .55487 L 1 g
F
P
p
.44188 .5561 m .44438 .55487 L .45096 .56262 L 1 g
F
P
p
.44176 .55601 m .43952 .55063 L .44188 .5561 L 1 g
F
P
p
.002 w
.43502 .54671 m .46662 .55982 L .464 .57198 L p
1 g
F P
s
P
p
.002 w
.43822 .54761 m .43743 .5491 L p
.44525 .55589 L 1 g
F P
s
P
p
.45096 .56262 m .44438 .55487 L .464 .57198 L 1 g
F
P
p
.002 w
.43743 .5491 m .43811 .54781 L p
.43675 .54422 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .4335 .53669 L p
.43675 .54422 L 1 g
F P
s
P
p
.002 w
.4335 .53669 m .43743 .5491 L p
.43675 .54422 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43358 .50977 L p
.43717 .50203 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .4399 .49599 L p
.43717 .50203 L 1 g
F P
s
P
p
.002 w
.4399 .49599 m .43287 .51061 L p
.43717 .50203 L 1 g
F P
s
P
p
.43847 .4998 m .44166 .49233 L .43358 .50977 L 1 g
F
P
p
.002 w
.45382 .47659 m .45526 .47908 L p
.44622 .48783 L 1 g
F P
s
P
p
.002 w
.45382 .47659 m .45996 .4745 L p
.45756 .47685 L 1 g
F P
s
P
p
.002 w
.45526 .47908 m .45475 .4782 L p
.45756 .47685 L 1 g
F P
s
P
p
.002 w
.45475 .4782 m .45382 .47659 L p
.45756 .47685 L 1 g
F P
s
P
p
.002 w
.45996 .4745 m .46833 .47166 L p
.45756 .47685 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45756 .47685 L p
1 g
F P
s
P
p
.46812 .47176 m .47718 .46778 L .45756 .47685 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4417 .49229 L p
1 g
F P
s
P
p
.45266 .48162 m .45698 .47747 L .4417 .49229 L 1 g
F
P
p
.002 w
.48382 .46638 m .48813 .46491 L .48675 .46599 L p
1 g
F P
s
P
p
.48675 .46599 m .48853 .46575 L .48837 .46577 L 1 g
F
P
p
.48675 .46599 m .48837 .46577 L .47732 .46756 L 1 g
F
P
p
.002 w
.48675 .46599 m .48813 .46491 L .48751 .46589 L p
1 g
F P
s
P
p
.002 w
.48949 .46559 m .48813 .46491 L .49115 .46532 L p
1 g
F P
s
P
p
.002 w
.5 .46391 m .5 .46394 L p
.49919 .46404 L 1 g
F P
s
P
p
.002 w
.5 .46394 m .5 .46398 L p
.49878 .46413 L 1 g
F P
s
P
p
.002 w
.4889 .46568 m .48813 .46491 L .48949 .46559 L p
1 g
F P
s
P
p
.002 w
.48853 .46574 m .48813 .46491 L .4889 .46568 L p
1 g
F P
s
P
p
.002 w
.5 .46398 m .5 .46403 L p
.49846 .46422 L 1 g
F P
s
P
p
.002 w
.5 .46403 m .5 .46409 L p
.49824 .46429 L 1 g
F P
s
P
p
.002 w
.48823 .46578 m .48813 .46491 L .48853 .46574 L p
1 g
F P
s
P
p
.002 w
.48792 .46583 m .48813 .46491 L .48823 .46578 L p
1 g
F P
s
P
p
.002 w
.5 .46409 m .5 .46414 L p
.49819 .46435 L 1 g
F P
s
P
p
.002 w
.5 .46414 m .5 .46442 L p
.49276 .46515 L 1 g
F P
s
P
p
.002 w
.48751 .46589 m .48813 .46491 L .48792 .46583 L p
1 g
F P
s
P
p
.002 w
.48813 .46491 m .50949 .46081 L p
.51154 .46203 L 1 g
F P
s
P
p
.002 w
.49115 .46532 m .48813 .46491 L p
.51154 .46203 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47732 .46756 L p
1 g
F P
s
P
p
.49126 .46531 m .5 .46442 L .47732 .46756 L 1 g
F
P
p
.002 w
.52252 .46729 m .52282 .46778 L p
.51198 .4657 L 1 g
F P
s
P
p
.002 w
.52256 .46737 m .52252 .46729 L p
.52481 .46844 L 1 g
F P
s
P
p
.002 w
.52252 .46729 m .52214 .46667 L p
.52481 .46844 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.50949 .46081 m .5246 .45792 L .52481 .46844 L p
1 g
F P
s
P
p
.56015 .45009 m .52877 .47032 L .52625 .46912 L 1 g
F
P
p
.002 w
.5246 .45792 m .56015 .45009 L p
.52625 .46912 L 1 g
F P
s
P
p
.002 w
.52484 .46991 m .52481 .46844 L p
.52625 .46912 L 1 g
F P
s
P
p
.002 w
.52481 .46844 m .5246 .45792 L p
.52625 .46912 L 1 g
F P
s
P
p
.52877 .47032 m .54302 .47747 L .52258 .4674 L 1 g
F
P
p
.53343 .47252 m .53389 .47275 L .52877 .47032 L 1 g
F
P
p
.53389 .47275 m .54302 .47747 L .52877 .47032 L 1 g
F
P
p
.002 w
.52258 .4674 m .52256 .46737 L p
.52877 .47032 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52258 .4674 L p
1 g
F P
s
P
p
.002 w
.54231 .4767 m .54302 .47747 L p
.53343 .47252 L 1 g
F P
s
P
p
.002 w
.52877 .47032 m .53658 .47113 L p
.53404 .4728 L 1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53658 .47113 m .56054 .47364 L p
.54271 .47709 L 1 g
F P
s
P
p
.002 w
.56054 .47364 m .55533 .48935 L p
.54271 .47709 L 1 g
F P
s
P
p
.002 w
.54293 .47738 m .54231 .4767 L p
.55265 .48676 L 1 g
F P
s
P
p
.55054 .4847 m .55265 .48676 L .54231 .4767 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54293 .47738 L p
1 g
F P
s
P
p
.55265 .48676 m .55834 .49233 L .54293 .47738 L 1 g
F
P
p
.002 w
.5575 .49145 m .55834 .49233 L p
.55265 .48676 L 1 g
F P
s
P
p
.002 w
.55533 .48935 m .5558 .48793 L p
.5575 .49145 L 1 g
F P
s
P
p
.5621 .501 m .56245 .50167 L .56128 .49925 L 1 g
F
P
p
.56245 .50167 m .56713 .51061 L .56128 .49925 L 1 g
F
P
p
.002 w
.53888 .51446 m .55316 .49589 L .56128 .49925 L p
1 g
F P
s
P
p
.56268 .50223 m .53888 .51446 L .56128 .49925 L 1 g
F
P
p
.002 w
.56753 .52827 m .58303 .50826 L p
.56772 .53314 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56671 .51837 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.5621 .501 L 1 g
F P
s
P
p
.56671 .51837 m .56753 .52827 L .56728 .5221 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56222 .53512 m .53888 .51446 L p
.56607 .51064 L 1 g
F P
s
P
p
.002 w
.56753 .52827 m .56222 .53512 L p
.56607 .51064 L 1 g
F P
s
P
p
.002 w
.56222 .53512 m .56753 .52827 L p
.56772 .53314 L 1 g
F P
s
P
p
.002 w
.56755 .52881 m .56854 .53025 L p
.56728 .5221 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56755 .52881 L p
1 g
F P
s
P
p
.56407 .54086 m .56257 .5491 L .56755 .52881 L 1 g
F
P
p
.002 w
.56506 .53743 m .56222 .53512 L p
.56614 .53371 L 1 g
F P
s
P
p
.002 w
.53377 .55376 m .56222 .53512 L .56506 .53743 L p
1 g
F P
s
P
p
.55911 .55291 m .53377 .55376 L .56506 .53743 L 1 g
F
P
p
.002 w
.56142 .54692 m .56257 .5491 L p
.56437 .53924 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56142 .54692 L p
1 g
F P
s
P
p
.5568 .55283 m .54998 .56518 L .56142 .54692 L 1 g
F
P
p
.002 w
.54907 .56271 m .54998 .56518 L p
.5568 .55283 L 1 g
F P
s
P
p
.002 w
.54947 .56378 m .54907 .56271 L p
.54224 .56799 L 1 g
F P
s
P
p
.002 w
.50073 .56227 m .53377 .55376 L .54685 .57572 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54947 .56378 L p
1 g
F P
s
P
p
.54038 .56906 m .5322 .57686 L .54947 .56378 L 1 g
F
P
p
.002 w
.53161 .57417 m .5322 .57686 L p
.54038 .56906 L 1 g
F P
s
P
p
.52952 .57538 m .51093 .58047 L .52875 .57504 L 1 g
F
P
p
.52235 .57956 m .51093 .58047 L .52952 .57538 L 1 g
F
P
p
.51093 .58047 m .50393 .58103 L .52875 .57504 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53161 .57417 L p
1 g
F P
s
P
p
.52351 .57664 m .51111 .583 L .53161 .57417 L 1 g
F
P
p
.002 w
.51093 .58047 m .51111 .583 L p
.52351 .57664 L 1 g
F P
s
P
p
.002 w
.511 .58145 m .51093 .58047 L p
.50393 .58103 L 1 g
F P
s
P
p
.002 w
.46662 .55982 m .50073 .56227 L .50486 .58647 L p
1 g
F P
s
P
p
.002 w
.4891 .58014 m .48889 .583 L p
.49993 .58079 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58145 L p
1 g
F P
s
P
p
.49993 .58079 m .48889 .583 L .511 .58145 L 1 g
F
P
p
.48719 .58003 m .48365 .57982 L .48232 .57825 L 1 g
F
P
p
.002 w
.46835 .57436 m .46872 .57265 L p
.464 .57198 L 1 g
F P
s
P
p
.002 w
.464 .57198 m .46662 .55982 L p
.4883 .58527 L 1 g
F P
s
P
p
.002 w
.46835 .57436 m .4678 .57686 L p
.4813 .57797 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58014 L p
1 g
F P
s
P
p
.4813 .57797 m .4678 .57686 L .4891 .58014 L 1 g
F
P
p
.002 w
.46821 .575 m .46835 .57436 L p
.464 .57198 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45096 .56262 L p
1 g
F P
s
P
p
.44525 .55589 m .43743 .5491 L .45096 .56262 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46821 .575 L p
1 g
F P
s
P
p
.46018 .56924 m .45002 .56518 L .46821 .575 L 1 g
F
P
p
.002 w
.46154 .58334 m .42141 .56668 L .43502 .54671 L p
1 g
F P
s
P
p
.002 w
.40923 .52428 m .43502 .54671 L .42141 .56668 L p
1 g
F P
s
P
p
.002 w
.42141 .56668 m .38863 .53824 L .40923 .52428 L p
1 g
F P
s
P
p
.002 w
.60967 .51798 m .6236 .4769 L .64881 .47639 L p
1 g
F P
s
P
p
.002 w
.64844 .42486 m .64881 .47639 L .6236 .4769 L p
1 g
F P
s
P
p
.002 w
.39201 .49488 m .40923 .52428 L .38863 .53824 L p
1 g
F P
s
P
p
.002 w
.38863 .53824 m .36667 .50091 L .39201 .49488 L p
1 g
F P
s
P
p
.002 w
.41457 .34635 m .38308 .37679 L .36512 .3583 L p
1 g
F P
s
P
p
.002 w
.36512 .3583 m .4022 .32226 L .41457 .34635 L p
1 g
F P
s
P
p
.002 w
.38524 .46157 m .39201 .49488 L .36667 .50091 L p
1 g
F P
s
P
p
.002 w
.36667 .50091 m .35795 .45855 L .38524 .46157 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.6236 .4769 m .62317 .43324 L .64844 .42486 L p
1 g
F P
s
P
p
.002 w
.63093 .37588 m .64844 .42486 L .62317 .43324 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.45467 .32779 m .41457 .34635 L .4022 .32226 L p
1 g
F P
s
P
p
.002 w
.4022 .32226 m .44953 .30024 L .45467 .32779 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.38974 .42788 m .38524 .46157 L .35795 .45855 L p
1 g
F P
s
P
p
.002 w
.35795 .45855 m .36355 .41563 L .38974 .42788 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.62317 .43324 m .60825 .3918 L .63093 .37588 L p
1 g
F P
s
P
p
.002 w
.59803 .335 m .63093 .37588 L .60825 .3918 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.6236 .4769 m .60967 .51798 L .58303 .50826 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49898 .32331 m .45467 .32779 L .44953 .30024 L p
1 g
F P
s
P
p
.002 w
.44953 .30024 m .50188 .29488 L .49898 .32331 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40515 .39746 m .38974 .42788 L .36355 .41563 L p
1 g
F P
s
P
p
.002 w
.36355 .41563 m .38308 .37679 L .40515 .39746 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60825 .3918 m .58035 .35724 L .59803 .335 L p
1 g
F P
s
P
p
.002 w
.55333 .30692 m .59803 .335 L .58035 .35724 L p
1 g
F P
s
P
p
.002 w
.54251 .33351 m .49898 .32331 L .50188 .29488 L p
1 g
F P
s
P
p
.002 w
.50188 .29488 m .55333 .30692 L .54251 .33351 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.58035 .35724 m .54251 .33351 L .55333 .30692 L p
1 g
F P
s
P
p
.002 w
.45104 .52255 m .47288 .53162 L .46662 .55982 L p
1 g
F P
s
P
p
.002 w
.50073 .56227 m .46662 .55982 L .47288 .53162 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.58303 .50826 m .59385 .47599 L .6236 .4769 L p
1 g
F P
s
P
p
.002 w
.62317 .43324 m .6236 .4769 L .59385 .47599 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.47288 .53162 m .49646 .53329 L .50073 .56227 L p
1 g
F P
s
P
p
.002 w
.53377 .55376 m .50073 .56227 L .49646 .53329 L p
1 g
F P
s
P
p
.002 w
.42139 .4867 m .43324 .50703 L .40923 .52428 L p
1 g
F P
s
P
p
.002 w
.40923 .52428 m .39201 .49488 L .42139 .4867 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4299 .37368 m .40515 .39746 L .38308 .37679 L p
1 g
F P
s
P
p
.002 w
.38308 .37679 m .41457 .34635 L .4299 .37368 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.49646 .53329 m .51927 .52737 L .53377 .55376 L p
1 g
F P
s
P
p
.002 w
.56222 .53512 m .53377 .55376 L .51927 .52737 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41678 .46371 m .42139 .4867 L .39201 .49488 L p
1 g
F P
s
P
p
.002 w
.39201 .49488 m .38524 .46157 L .41678 .46371 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.59385 .47599 m .59341 .44176 L .62317 .43324 L p
1 g
F P
s
P
p
.002 w
.60825 .3918 m .62317 .43324 L .59341 .44176 L p
1 g
F P
s
P
p
.002 w
.51927 .52737 m .53888 .51446 L .56222 .53512 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.46135 .35921 m .4299 .37368 L .41457 .34635 L p
1 g
F P
s
P
p
.002 w
.41457 .34635 m .45467 .32779 L .46135 .35921 L p
1 g
F P
s
P
p
.002 w
.41996 .4405 m .41678 .46371 L .38524 .46157 L p
1 g
F P
s
P
p
.002 w
.38524 .46157 m .38974 .42788 L .41996 .4405 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.59341 .44176 m .58164 .40932 L .60825 .3918 L p
1 g
F P
s
P
p
.002 w
.58035 .35724 m .60825 .3918 L .58164 .40932 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49604 .35576 m .46135 .35921 L .45467 .32779 L p
1 g
F P
s
P
p
.002 w
.45467 .32779 m .49898 .32331 L .49604 .35576 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43065 .4196 m .41996 .4405 L .38974 .42788 L p
1 g
F P
s
P
p
.002 w
.38974 .42788 m .40515 .39746 L .43065 .4196 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.58164 .40932 m .55974 .38231 L .58035 .35724 L p
1 g
F P
s
P
p
.002 w
.54251 .33351 m .58035 .35724 L .55974 .38231 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53011 .36375 m .49604 .35576 L .49898 .32331 L p
1 g
F P
s
P
p
.002 w
.49898 .32331 m .54251 .33351 L .53011 .36375 L p
1 g
F P
s
P
p
.002 w
.55974 .38231 m .53011 .36375 L .54251 .33351 L p
1 g
F P
s
P
p
.002 w
.46896 .49496 m .48014 .49961 L .47288 .53162 L p
1 g
F P
s
P
p
.002 w
.47288 .53162 m .45104 .52255 L .46896 .49496 L p
1 g
F P
s
P
p
.002 w
.49646 .53329 m .47288 .53162 L .48014 .49961 L p
1 g
F P
s
P
p
.002 w
.59341 .44176 m .59385 .47599 L .56054 .47364 L p
1 g
F P
s
P
p
.002 w
.45986 .48701 m .46896 .49496 L .45104 .52255 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.48014 .49961 m .49221 .50045 L .49646 .53329 L p
1 g
F P
s
P
p
.002 w
.51927 .52737 m .49646 .53329 L .49221 .50045 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.44772 .4033 m .43065 .4196 L .40515 .39746 L p
1 g
F P
s
P
p
.002 w
.40515 .39746 m .4299 .37368 L .44772 .4033 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49221 .50045 m .50387 .4974 L .51927 .52737 L p
1 g
F P
s
P
p
.002 w
.53888 .51446 m .51927 .52737 L .50387 .4974 L p
1 g
F P
s
P
p
.002 w
.45151 .46484 m .45382 .47659 L .42139 .4867 L p
1 g
F P
s
P
p
.002 w
.42139 .4867 m .41678 .46371 L .45151 .46484 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.56054 .47364 m .56015 .45009 L .59341 .44176 L p
1 g
F P
s
P
p
.002 w
.58164 .40932 m .59341 .44176 L .56015 .45009 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.50387 .4974 m .51387 .49077 L .53888 .51446 L p
1 g
F P
s
P
p
.002 w
.55316 .49589 m .53888 .51446 L .51387 .49077 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.46935 .39342 m .44772 .4033 L .4299 .37368 L p
1 g
F P
s
P
p
.002 w
.4299 .37368 m .46135 .35921 L .46935 .39342 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.45318 .45301 m .45151 .46484 L .41678 .46371 L p
1 g
F P
s
P
p
.002 w
.41678 .46371 m .41996 .4405 L .45318 .45301 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56015 .45009 m .552 .42783 L .58164 .40932 L p
1 g
F P
s
P
p
.002 w
.55974 .38231 m .58164 .40932 L .552 .42783 L p
1 g
F P
s
P
p
.002 w
.51387 .49077 m .52112 .48127 L .55316 .49589 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.49318 .39108 m .46935 .39342 L .46135 .35921 L p
1 g
F P
s
P
p
.002 w
.46135 .35921 m .49604 .35576 L .49318 .39108 L p
1 g
F P
s
P
p
.002 w
.45866 .44238 m .45318 .45301 L .41996 .4405 L p
1 g
F P
s
P
p
.002 w
.41996 .4405 m .43065 .4196 L .45866 .44238 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.552 .42783 m .53692 .4093 L .55974 .38231 L p
1 g
F P
s
P
p
.002 w
.53011 .36375 m .55974 .38231 L .53692 .4093 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.51657 .39658 m .49318 .39108 L .49604 .35576 L p
1 g
F P
s
P
p
.002 w
.49604 .35576 m .53011 .36375 L .51657 .39658 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.53692 .4093 m .51657 .39658 L .53011 .36375 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.46738 .43411 m .45866 .44238 L .43065 .4196 L p
1 g
F P
s
P
p
.002 w
.43065 .4196 m .44772 .4033 L .46738 .43411 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.552 .42783 m .56015 .45009 L .5246 .45792 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.45151 .46484 m .45318 .45301 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4784 .42912 m .46738 .43411 L .44772 .4033 L p
1 g
F P
s
P
p
.002 w
.44772 .4033 m .46935 .39342 L .4784 .42912 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5246 .45792 m .52042 .4466 L .552 .42783 L p
1 g
F P
s
P
p
.002 w
.53692 .4093 m .552 .42783 L .52042 .4466 L p
1 g
F P
s
P
p
.002 w
.45318 .45301 m .45866 .44238 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.49051 .42795 m .4784 .42912 L .46935 .39342 L p
1 g
F P
s
P
p
.002 w
.46935 .39342 m .49318 .39108 L .49051 .42795 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.45866 .44238 m .46738 .43411 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.52042 .4466 m .51273 .4372 L .53692 .4093 L p
1 g
F P
s
P
p
.002 w
.51657 .39658 m .53692 .4093 L .51273 .4372 L p
1 g
F P
s
P
p
.002 w
.50239 .43075 m .49051 .42795 L .49318 .39108 L p
1 g
F P
s
P
p
.002 w
.49318 .39108 m .51657 .39658 L .50239 .43075 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51273 .4372 m .50239 .43075 L .51657 .39658 L p
1 g
F P
s
P
p
.002 w
.52042 .4466 m .5246 .45792 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.51273 .4372 m .52042 .4466 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.50239 .43075 m .51273 .4372 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.49051 .42795 m .50239 .43075 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.4784 .42912 m .49051 .42795 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.46738 .43411 m .4784 .42912 L .48813 .46491 L closepath p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.48076 .48627 m
.48813 .46491 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .36263 .22041 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .48076 .48627 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.553488)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.553488)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49831 .45562 m .51472 .44707 L .49764 .42419 L p
1 g
F P
s
P
p
.002 w
.49764 .42419 m .48932 .42852 L .49831 .45562 L p
1 g
F P
s
P
p
.002 w
.50413 .41745 m .49764 .42419 L .51472 .44707 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .48932 .42852 L .49764 .42419 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .49764 .42419 L .50413 .41745 L closepath p
1 g
F P
s
P
p
.002 w
.48008 .45849 m .49831 .45562 L .48932 .42852 L p
1 g
F P
s
P
p
.002 w
.48932 .42852 m .48009 .42996 L .48008 .45849 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .48009 .42996 L .48932 .42852 L closepath p
1 g
F P
s
P
p
.002 w
.51472 .44707 m .52756 .43376 L .50413 .41745 L p
1 g
F P
s
P
p
.002 w
.50811 .409 m .50413 .41745 L .52756 .43376 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .50413 .41745 L .50811 .409 L closepath p
1 g
F P
s
P
p
.002 w
.46194 .45537 m .48008 .45849 L .48009 .42996 L p
1 g
F P
s
P
p
.002 w
.48009 .42996 m .47092 .42836 L .46194 .45537 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .47092 .42836 L .48009 .42996 L closepath p
1 g
F P
s
P
p
.002 w
.50739 .48225 m .53154 .46966 L .51472 .44707 L p
1 g
F P
s
P
p
.002 w
.51472 .44707 m .49831 .45562 L .50739 .48225 L p
1 g
F P
s
P
p
.002 w
.52756 .43376 m .51472 .44707 L .53154 .46966 L p
1 g
F P
s
P
p
.002 w
.52756 .43376 m .53546 .41709 L .50811 .409 L p
1 g
F P
s
P
p
.002 w
.50915 .39977 m .50811 .409 L .53546 .41709 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .50811 .409 L .50915 .39977 L closepath p
1 g
F P
s
P
p
.002 w
.48055 .48653 m .50739 .48225 L .49831 .45562 L p
1 g
F P
s
P
p
.002 w
.49831 .45562 m .48008 .45849 L .48055 .48653 L p
1 g
F P
s
P
p
.002 w
.53154 .46966 m .55045 .45008 L .52756 .43376 L p
1 g
F P
s
P
p
.002 w
.53546 .41709 m .52756 .43376 L .55045 .45008 L p
1 g
F P
s
P
p
.002 w
.44585 .44656 m .46194 .45537 L .47092 .42836 L p
1 g
F P
s
P
p
.002 w
.47092 .42836 m .4628 .42388 L .44585 .44656 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .4628 .42388 L .47092 .42836 L closepath p
1 g
F P
s
P
p
.002 w
.53546 .41709 m .53757 .39884 L .50915 .39977 L p
1 g
F P
s
P
p
.002 w
.50712 .39073 m .50915 .39977 L .53757 .39884 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .50915 .39977 L .50712 .39073 L closepath p
1 g
F P
s
P
p
.002 w
.45382 .482 m .48055 .48653 L .48008 .45849 L p
1 g
F P
s
P
p
.002 w
.48008 .45849 m .46194 .45537 L .45382 .482 L p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .45248 .39914 L .45304 .40844 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .45304 .40844 L .45662 .41699 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .45662 .41699 L .4628 .42388 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .50712 .39073 L .50224 .38286 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .46788 .37669 L .46032 .38235 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .46032 .38235 L .45499 .39011 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .45499 .39011 L .45248 .39914 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .50224 .38286 L .49501 .37704 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .49501 .37704 L .48623 .37389 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .48623 .37389 L .47684 .37376 L closepath p
1 g
F P
s
P
p
.002 w
.48058 .40144 m .47684 .37376 L .46788 .37669 L closepath p
1 g
F P
s
P
p
.002 w
.43355 .43297 m .44585 .44656 L .4628 .42388 L p
1 g
F P
s
P
p
.002 w
.4628 .42388 m .45662 .41699 L .43355 .43297 L p
1 g
F P
s
P
p
.002 w
.55045 .45008 m .56213 .42556 L .53546 .41709 L p
1 g
F P
s
P
p
.002 w
.53757 .39884 m .53546 .41709 L .56213 .42556 L p
1 g
F P
s
P
p
.002 w
.53757 .39884 m .53362 .38093 L .50712 .39073 L p
1 g
F P
s
P
p
.002 w
.50224 .38286 m .50712 .39073 L .53362 .38093 L p
1 g
F P
s
P
p
.002 w
.4264 .41604 m .43355 .43297 L .45662 .41699 L p
1 g
F P
s
P
p
.002 w
.45662 .41699 m .45304 .40844 L .4264 .41604 L p
1 g
F P
s
P
p
.002 w
.43006 .46909 m .45382 .482 L .46194 .45537 L p
1 g
F P
s
P
p
.002 w
.46194 .45537 m .44585 .44656 L .43006 .46909 L p
1 g
F P
s
P
p
.002 w
.53362 .38093 m .524 .36532 L .50224 .38286 L p
1 g
F P
s
P
p
.002 w
.49501 .37704 m .50224 .38286 L .524 .36532 L p
1 g
F P
s
P
p
.002 w
.56213 .42556 m .56531 .39867 L .53757 .39884 L p
1 g
F P
s
P
p
.002 w
.53362 .38093 m .53757 .39884 L .56531 .39867 L p
1 g
F P
s
P
p
.002 w
.51639 .50792 m .54777 .49154 L .53154 .46966 L p
1 g
F P
s
P
p
.002 w
.53154 .46966 m .50739 .48225 L .51639 .50792 L p
1 g
F P
s
P
p
.002 w
.55045 .45008 m .53154 .46966 L .54777 .49154 L p
1 g
F P
s
P
p
.002 w
.42522 .39759 m .4264 .41604 L .45304 .40844 L p
1 g
F P
s
P
p
.002 w
.45304 .40844 m .45248 .39914 L .42522 .39759 L p
1 g
F P
s
P
p
.002 w
.4815 .51354 m .51639 .50792 L .50739 .48225 L p
1 g
F P
s
P
p
.002 w
.50739 .48225 m .48055 .48653 L .4815 .51354 L p
1 g
F P
s
P
p
.002 w
.524 .36532 m .50971 .3537 L .49501 .37704 L p
1 g
F P
s
P
p
.002 w
.48623 .37389 m .49501 .37704 L .50971 .3537 L p
1 g
F P
s
P
p
.002 w
.54777 .49154 m .57237 .46612 L .55045 .45008 L p
1 g
F P
s
P
p
.002 w
.56213 .42556 m .55045 .45008 L .57237 .46612 L p
1 g
F P
s
P
p
.002 w
.41183 .44909 m .43006 .46909 L .44585 .44656 L p
1 g
F P
s
P
p
.002 w
.44585 .44656 m .43355 .43297 L .41183 .44909 L p
1 g
F P
s
P
p
.002 w
.43017 .37964 m .42522 .39759 L .45248 .39914 L p
1 g
F P
s
P
p
.002 w
.45248 .39914 m .45499 .39011 L .43017 .37964 L p
1 g
F P
s
P
p
.002 w
.50971 .3537 m .49228 .34739 L .48623 .37389 L p
1 g
F P
s
P
p
.002 w
.47684 .37376 m .48623 .37389 L .49228 .34739 L p
1 g
F P
s
P
p
.002 w
.44672 .50774 m .4815 .51354 L .48055 .48653 L p
1 g
F P
s
P
p
.002 w
.48055 .48653 m .45382 .482 L .44672 .50774 L p
1 g
F P
s
P
p
.002 w
.56531 .39867 m .55958 .37224 L .53362 .38093 L p
1 g
F P
s
P
p
.002 w
.524 .36532 m .53362 .38093 L .55958 .37224 L p
1 g
F P
s
P
p
.002 w
.44075 .36417 m .43017 .37964 L .45499 .39011 L p
1 g
F P
s
P
p
.002 w
.45499 .39011 m .46032 .38235 L .44075 .36417 L p
1 g
F P
s
P
p
.002 w
.49228 .34739 m .47362 .34711 L .47684 .37376 L p
1 g
F P
s
P
p
.002 w
.46788 .37669 m .47684 .37376 L .47362 .34711 L p
1 g
F P
s
P
p
.002 w
.57237 .46612 m .58763 .43427 L .56213 .42556 L p
1 g
F P
s
P
p
.002 w
.56531 .39867 m .56213 .42556 L .58763 .43427 L p
1 g
F P
s
P
p
.002 w
.45579 .35292 m .44075 .36417 L .46032 .38235 L p
1 g
F P
s
P
p
.002 w
.46032 .38235 m .46788 .37669 L .45579 .35292 L p
1 g
F P
s
P
p
.002 w
.47362 .34711 m .45579 .35292 L .46788 .37669 L p
1 g
F P
s
P
p
.002 w
.40117 .42411 m .41183 .44909 L .43355 .43297 L p
1 g
F P
s
P
p
.002 w
.43355 .43297 m .4264 .41604 L .40117 .42411 L p
1 g
F P
s
P
p
.002 w
.41573 .49103 m .44672 .50774 L .45382 .482 L p
1 g
F P
s
P
p
.002 w
.45382 .482 m .43006 .46909 L .41573 .49103 L p
1 g
F P
s
P
p
.002 w
.55958 .37224 m .54546 .34913 L .524 .36532 L p
1 g
F P
s
P
p
.002 w
.50971 .3537 m .524 .36532 L .54546 .34913 L p
1 g
F P
s
P
p
.002 w
.58763 .43427 m .59186 .39928 L .56531 .39867 L p
1 g
F P
s
P
p
.002 w
.55958 .37224 m .56531 .39867 L .59186 .39928 L p
1 g
F P
s
P
p
.002 w
.39934 .39682 m .40117 .42411 L .4264 .41604 L p
1 g
F P
s
P
p
.002 w
.4264 .41604 m .42522 .39759 L .39934 .39682 L p
1 g
F P
s
P
p
.002 w
.54546 .34913 m .52439 .3319 L .50971 .3537 L p
1 g
F P
s
P
p
.002 w
.49228 .34739 m .50971 .3537 L .52439 .3319 L p
1 g
F P
s
P
p
.002 w
.52515 .53213 m .5631 .5123 L .54777 .49154 L p
1 g
F P
s
P
p
.002 w
.54777 .49154 m .51639 .50792 L .52515 .53213 L p
1 g
F P
s
P
p
.002 w
.57237 .46612 m .54777 .49154 L .5631 .5123 L p
1 g
F P
s
P
p
.002 w
.48293 .53899 m .52515 .53213 L .51639 .50792 L p
1 g
F P
s
P
p
.002 w
.51639 .50792 m .4815 .51354 L .48293 .53899 L p
1 g
F P
s
P
p
.002 w
.39188 .46505 m .41573 .49103 L .43006 .46909 L p
1 g
F P
s
P
p
.002 w
.43006 .46909 m .41183 .44909 L .39188 .46505 L p
1 g
F P
s
P
p
.002 w
.5631 .5123 m .5929 .48156 L .57237 .46612 L p
1 g
F P
s
P
p
.002 w
.58763 .43427 m .57237 .46612 L .5929 .48156 L p
1 g
F P
s
P
p
.002 w
.40662 .37022 m .39934 .39682 L .42522 .39759 L p
1 g
F P
s
P
p
.002 w
.42522 .39759 m .43017 .37964 L .40662 .37022 L p
1 g
F P
s
P
p
.002 w
.59186 .39928 m .58451 .36484 L .55958 .37224 L p
1 g
F P
s
P
p
.002 w
.54546 .34913 m .55958 .37224 L .58451 .36484 L p
1 g
F P
s
P
p
.002 w
.52439 .3319 m .49863 .32249 L .49228 .34739 L p
1 g
F P
s
P
p
.002 w
.47362 .34711 m .49228 .34739 L .49863 .32249 L p
1 g
F P
s
P
p
.002 w
.4408 .53207 m .48293 .53899 L .4815 .51354 L p
1 g
F P
s
P
p
.002 w
.4815 .51354 m .44672 .50774 L .4408 .53207 L p
1 g
F P
s
P
p
.002 w
.42226 .34728 m .40662 .37022 L .43017 .37964 L p
1 g
F P
s
P
p
.002 w
.43017 .37964 m .44075 .36417 L .42226 .34728 L p
1 g
F P
s
P
p
.002 w
.49863 .32249 m .47099 .32201 L .47362 .34711 L p
1 g
F P
s
P
p
.002 w
.45579 .35292 m .47362 .34711 L .47099 .32201 L p
1 g
F P
s
P
p
.002 w
.5929 .48156 m .61143 .44304 L .58763 .43427 L p
1 g
F P
s
P
p
.002 w
.59186 .39928 m .58763 .43427 L .61143 .44304 L p
1 g
F P
s
P
p
.002 w
.44455 .33059 m .42226 .34728 L .44075 .36417 L p
1 g
F P
s
P
p
.002 w
.44075 .36417 m .45579 .35292 L .44455 .33059 L p
1 g
F P
s
P
p
.002 w
.47099 .32201 m .44455 .33059 L .45579 .35292 L p
1 g
F P
s
P
p
.002 w
.37787 .43251 m .39188 .46505 L .41183 .44909 L p
1 g
F P
s
P
p
.002 w
.41183 .44909 m .40117 .42411 L .37787 .43251 L p
1 g
F P
s
P
p
.002 w
.58451 .36484 m .5662 .33466 L .54546 .34913 L p
1 g
F P
s
P
p
.002 w
.52439 .3319 m .54546 .34913 L .5662 .33466 L p
1 g
F P
s
P
p
.002 w
.40319 .51194 m .4408 .53207 L .44672 .50774 L p
1 g
F P
s
P
p
.002 w
.44672 .50774 m .41573 .49103 L .40319 .51194 L p
1 g
F P
s
P
p
.002 w
.61143 .44304 m .61667 .40069 L .59186 .39928 L p
1 g
F P
s
P
p
.002 w
.58451 .36484 m .59186 .39928 L .61667 .40069 L p
1 g
F P
s
P
p
.002 w
.37538 .39687 m .37787 .43251 L .40117 .42411 L p
1 g
F P
s
P
p
.002 w
.40117 .42411 m .39934 .39682 L .37538 .39687 L p
1 g
F P
s
P
p
.002 w
.5662 .33466 m .53879 .31207 L .52439 .3319 L p
1 g
F P
s
P
p
.002 w
.49863 .32249 m .52439 .3319 L .53879 .31207 L p
1 g
F P
s
P
p
.002 w
.53348 .55438 m .57722 .5315 L .5631 .5123 L p
1 g
F P
s
P
p
.002 w
.5631 .5123 m .52515 .53213 L .53348 .55438 L p
1 g
F P
s
P
p
.002 w
.5929 .48156 m .5631 .5123 L .57722 .5315 L p
1 g
F P
s
P
p
.002 w
.37417 .48053 m .40319 .51194 L .41573 .49103 L p
1 g
F P
s
P
p
.002 w
.41573 .49103 m .39188 .46505 L .37417 .48053 L p
1 g
F P
s
P
p
.002 w
.48482 .56235 m .53348 .55438 L .52515 .53213 L p
1 g
F P
s
P
p
.002 w
.52515 .53213 m .48293 .53899 L .48482 .56235 L p
1 g
F P
s
P
p
.002 w
.57722 .5315 m .61159 .49609 L .5929 .48156 L p
1 g
F P
s
P
p
.002 w
.61143 .44304 m .5929 .48156 L .61159 .49609 L p
1 g
F P
s
P
p
.002 w
.38482 .36208 m .37538 .39687 L .39934 .39682 L p
1 g
F P
s
P
p
.002 w
.39934 .39682 m .40662 .37022 L .38482 .36208 L p
1 g
F P
s
P
p
.002 w
.61667 .40069 m .60789 .35892 L .58451 .36484 L p
1 g
F P
s
P
p
.002 w
.5662 .33466 m .58451 .36484 L .60789 .35892 L p
1 g
F P
s
P
p
.002 w
.53879 .31207 m .50517 .29969 L .49863 .32249 L p
1 g
F P
s
P
p
.002 w
.47099 .32201 m .49863 .32249 L .50517 .29969 L p
1 g
F P
s
P
p
.002 w
.43622 .55448 m .48482 .56235 L .48293 .53899 L p
1 g
F P
s
P
p
.002 w
.48293 .53899 m .4408 .53207 L .43622 .55448 L p
1 g
F P
s
P
p
.002 w
.40525 .33205 m .38482 .36208 L .40662 .37022 L p
1 g
F P
s
P
p
.002 w
.40662 .37022 m .42226 .34728 L .40525 .33205 L p
1 g
F P
s
P
p
.002 w
.61159 .49609 m .63303 .45171 L .61143 .44304 L p
1 g
F P
s
P
p
.002 w
.61667 .40069 m .61143 .44304 L .63303 .45171 L p
1 g
F P
s
P
p
.002 w
.50517 .29969 m .46903 .29901 L .47099 .32201 L p
1 g
F P
s
P
p
.002 w
.44455 .33059 m .47099 .32201 L .46903 .29901 L p
1 g
F P
s
P
p
.002 w
.35704 .44108 m .37417 .48053 L .39188 .46505 L p
1 g
F P
s
P
p
.002 w
.39188 .46505 m .37787 .43251 L .35704 .44108 L p
1 g
F P
s
P
p
.002 w
.43442 .31021 m .40525 .33205 L .42226 .34728 L p
1 g
F P
s
P
p
.002 w
.42226 .34728 m .44455 .33059 L .43442 .31021 L p
1 g
F P
s
P
p
.002 w
.46903 .29901 m .43442 .31021 L .44455 .33059 L p
1 g
F P
s
P
p
.002 w
.60789 .35892 m .5858 .32223 L .5662 .33466 L p
1 g
F P
s
P
p
.002 w
.53879 .31207 m .5662 .33466 L .5858 .32223 L p
1 g
F P
s
P
p
.002 w
.39275 .53136 m .43622 .55448 L .4408 .53207 L p
1 g
F P
s
P
p
.002 w
.4408 .53207 m .40319 .51194 L .39275 .53136 L p
1 g
F P
s
P
p
.002 w
.63303 .45171 m .63919 .40288 L .61667 .40069 L p
1 g
F P
s
P
p
.002 w
.60789 .35892 m .61667 .40069 L .63919 .40288 L p
1 g
F P
s
P
p
.002 w
.3539 .39778 m .35704 .44108 L .37787 .43251 L p
1 g
F P
s
P
p
.002 w
.37787 .43251 m .37538 .39687 L .3539 .39778 L p
1 g
F P
s
P
p
.002 w
.5858 .32223 m .55259 .29471 L .53879 .31207 L p
1 g
F P
s
P
p
.002 w
.50517 .29969 m .53879 .31207 L .55259 .29471 L p
1 g
F P
s
P
p
.002 w
.35915 .49519 m .39275 .53136 L .40319 .51194 L p
1 g
F P
s
P
p
.002 w
.40319 .51194 m .37417 .48053 L .35915 .49519 L p
1 g
F P
s
P
p
.002 w
.5412 .57411 m .58978 .54869 L .57722 .5315 L p
1 g
F P
s
P
p
.002 w
.57722 .5315 m .53348 .55438 L .5412 .57411 L p
1 g
F P
s
P
p
.002 w
.61159 .49609 m .57722 .5315 L .58978 .54869 L p
1 g
F P
s
P
p
.002 w
.48715 .58304 m .5412 .57411 L .53348 .55438 L p
1 g
F P
s
P
p
.002 w
.53348 .55438 m .48482 .56235 L .48715 .58304 L p
1 g
F P
s
P
p
.002 w
.36531 .35545 m .3539 .39778 L .37538 .39687 L p
1 g
F P
s
P
p
.002 w
.37538 .39687 m .38482 .36208 L .36531 .35545 L p
1 g
F P
s
P
p
.002 w
.58978 .54869 m .62799 .50937 L .61159 .49609 L p
1 g
F P
s
P
p
.002 w
.63303 .45171 m .61159 .49609 L .62799 .50937 L p
1 g
F P
s
P
p
.002 w
.63919 .40288 m .62919 .35465 L .60789 .35892 L p
1 g
F P
s
P
p
.002 w
.5858 .32223 m .60789 .35892 L .62919 .35465 L p
1 g
F P
s
P
p
.002 w
.55259 .29471 m .51176 .27956 L .50517 .29969 L p
1 g
F P
s
P
p
.002 w
.46903 .29901 m .50517 .29969 L .51176 .27956 L p
1 g
F P
s
P
p
.002 w
.43313 .57439 m .48715 .58304 L .48482 .56235 L p
1 g
F P
s
P
p
.002 w
.48482 .56235 m .43622 .55448 L .43313 .57439 L p
1 g
F P
s
P
p
.002 w
.39014 .31887 m .36531 .35545 L .38482 .36208 L p
1 g
F P
s
P
p
.002 w
.38482 .36208 m .40525 .33205 L .39014 .31887 L p
1 g
F P
s
P
p
.002 w
.62799 .50937 m .65188 .46011 L .63303 .45171 L p
1 g
F P
s
P
p
.002 w
.63919 .40288 m .63303 .45171 L .65188 .46011 L p
1 g
F P
s
P
p
.002 w
.51176 .27956 m .46779 .27867 L .46903 .29901 L p
1 g
F P
s
P
p
.002 w
.43442 .31021 m .46903 .29901 L .46779 .27867 L p
1 g
F P
s
P
p
.002 w
.33923 .44964 m .35915 .49519 L .37417 .48053 L p
1 g
F P
s
P
p
.002 w
.37417 .48053 m .35704 .44108 L .33923 .44964 L p
1 g
F P
s
P
p
.002 w
.42565 .29226 m .39014 .31887 L .40525 .33205 L p
1 g
F P
s
P
p
.002 w
.40525 .33205 m .43442 .31021 L .42565 .29226 L p
1 g
F P
s
P
p
.002 w
.46779 .27867 m .42565 .29226 L .43442 .31021 L p
1 g
F P
s
P
p
.002 w
.62919 .35465 m .6038 .3122 L .5858 .32223 L p
1 g
F P
s
P
p
.002 w
.55259 .29471 m .5858 .32223 L .6038 .3122 L p
1 g
F P
s
P
p
.002 w
.38475 .54881 m .43313 .57439 L .43622 .55448 L p
1 g
F P
s
P
p
.002 w
.43622 .55448 m .39275 .53136 L .38475 .54881 L p
1 g
F P
s
P
p
.002 w
.65188 .46011 m .65884 .40585 L .63919 .40288 L p
1 g
F P
s
P
p
.002 w
.62919 .35465 m .63919 .40288 L .65884 .40585 L p
1 g
F P
s
P
p
.002 w
.33549 .39957 m .33923 .44964 L .35704 .44108 L p
1 g
F P
s
P
p
.002 w
.35704 .44108 m .3539 .39778 L .33549 .39957 L p
1 g
F P
s
P
p
.002 w
.6038 .3122 m .56549 .28029 L .55259 .29471 L p
1 g
F P
s
P
p
.002 w
.51176 .27956 m .55259 .29471 L .56549 .28029 L p
1 g
F P
s
P
p
.002 w
.34727 .50867 m .38475 .54881 L .39275 .53136 L p
1 g
F P
s
P
p
.002 w
.39275 .53136 m .35915 .49519 L .34727 .50867 L p
1 g
F P
s
P
p
.002 w
.54812 .59081 m .60045 .5634 L .58978 .54869 L p
1 g
F P
s
P
p
.002 w
.58978 .54869 m .5412 .57411 L .54812 .59081 L p
1 g
F P
s
P
p
.002 w
.62799 .50937 m .58978 .54869 L .60045 .5634 L p
1 g
F P
s
P
p
.002 w
.4899 .60048 m .54812 .59081 L .5412 .57411 L p
1 g
F P
s
P
p
.002 w
.5412 .57411 m .48715 .58304 L .4899 .60048 L p
1 g
F P
s
P
p
.002 w
.34862 .35053 m .33549 .39957 L .3539 .39778 L p
1 g
F P
s
P
p
.002 w
.3539 .39778 m .36531 .35545 L .34862 .35053 L p
1 g
F P
s
P
p
.002 w
.65884 .40585 m .64785 .35219 L .62919 .35465 L p
1 g
F P
s
P
p
.002 w
.6038 .3122 m .62919 .35465 L .64785 .35219 L p
1 g
F P
s
P
p
.002 w
.60045 .5634 m .64163 .52107 L .62799 .50937 L p
1 g
F P
s
P
p
.002 w
.65188 .46011 m .62799 .50937 L .64163 .52107 L p
1 g
F P
s
P
p
.002 w
.56549 .28029 m .51827 .26267 L .51176 .27956 L p
1 g
F P
s
P
p
.002 w
.46779 .27867 m .51176 .27956 L .51827 .26267 L p
1 g
F P
s
P
p
.002 w
.43167 .59126 m .4899 .60048 L .48715 .58304 L p
1 g
F P
s
P
p
.002 w
.48715 .58304 m .43313 .57439 L .43167 .59126 L p
1 g
F P
s
P
p
.002 w
.37735 .30813 m .34862 .35053 L .36531 .35545 L p
1 g
F P
s
P
p
.002 w
.36531 .35545 m .39014 .31887 L .37735 .30813 L p
1 g
F P
s
P
p
.002 w
.64163 .52107 m .66744 .46802 L .65188 .46011 L p
1 g
F P
s
P
p
.002 w
.65884 .40585 m .65188 .46011 L .66744 .46802 L p
1 g
F P
s
P
p
.002 w
.32499 .45802 m .34727 .50867 L .35915 .49519 L p
1 g
F P
s
P
p
.002 w
.35915 .49519 m .33923 .44964 L .32499 .45802 L p
1 g
F P
s
P
p
.002 w
.51827 .26267 m .46735 .26156 L .46779 .27867 L p
1 g
F P
s
P
p
.002 w
.42565 .29226 m .46779 .27867 L .46735 .26156 L p
1 g
F P
s
P
p
.002 w
.4185 .27729 m .37735 .30813 L .39014 .31887 L p
1 g
F P
s
P
p
.002 w
.39014 .31887 m .42565 .29226 L .4185 .27729 L p
1 g
F P
s
P
p
.002 w
.46735 .26156 m .4185 .27729 L .42565 .29226 L p
1 g
F P
s
P
p
.002 w
.64785 .35219 m .61971 .3049 L .6038 .3122 L p
1 g
F P
s
P
p
.002 w
.56549 .28029 m .6038 .3122 L .61971 .3049 L p
1 g
F P
s
P
p
.002 w
.37948 .56378 m .43167 .59126 L .43313 .57439 L p
1 g
F P
s
P
p
.002 w
.43313 .57439 m .38475 .54881 L .37948 .56378 L p
1 g
F P
s
P
p
.002 w
.66744 .46802 m .67504 .40956 L .65884 .40585 L p
1 g
F P
s
P
p
.002 w
.64785 .35219 m .65884 .40585 L .67504 .40956 L p
1 g
F P
s
P
p
.002 w
.32072 .40224 m .32499 .45802 L .33923 .44964 L p
1 g
F P
s
P
p
.002 w
.33923 .44964 m .33549 .39957 L .32072 .40224 L p
1 g
F P
s
P
p
.002 w
.61971 .3049 m .57713 .26928 L .56549 .28029 L p
1 g
F P
s
P
p
.002 w
.51827 .26267 m .56549 .28029 L .57713 .26928 L p
1 g
F P
s
P
p
.002 w
.33898 .52059 m .37948 .56378 L .38475 .54881 L p
1 g
F P
s
P
p
.002 w
.38475 .54881 m .34727 .50867 L .33898 .52059 L p
1 g
F P
s
P
p
.002 w
.55403 .60391 m .60887 .57517 L .60045 .5634 L p
1 g
F P
s
P
p
.002 w
.60045 .5634 m .54812 .59081 L .55403 .60391 L p
1 g
F P
s
P
p
.002 w
.64163 .52107 m .60045 .5634 L .60887 .57517 L p
1 g
F P
s
P
p
.002 w
.67504 .40956 m .6633 .35171 L .64785 .35219 L p
1 g
F P
s
P
p
.002 w
.61971 .3049 m .64785 .35219 L .6633 .35171 L p
1 g
F P
s
P
p
.002 w
.49302 .6141 m .55403 .60391 L .54812 .59081 L p
1 g
F P
s
P
p
.002 w
.54812 .59081 m .4899 .60048 L .49302 .6141 L p
1 g
F P
s
P
p
.002 w
.3353 .34754 m .32072 .40224 L .33549 .39957 L p
1 g
F P
s
P
p
.002 w
.33549 .39957 m .34862 .35053 L .3353 .34754 L p
1 g
F P
s
P
p
.002 w
.60887 .57517 m .65205 .53082 L .64163 .52107 L p
1 g
F P
s
P
p
.002 w
.66744 .46802 m .64163 .52107 L .65205 .53082 L p
1 g
F P
s
P
p
.002 w
.57713 .26928 m .52454 .24956 L .51827 .26267 L p
1 g
F P
s
P
p
.002 w
.46735 .26156 m .51827 .26267 L .52454 .24956 L p
1 g
F P
s
P
p
.002 w
.43198 .60451 m .49302 .6141 L .4899 .60048 L p
1 g
F P
s
P
p
.002 w
.4899 .60048 m .43167 .59126 L .43198 .60451 L p
1 g
F P
s
P
p
.002 w
.36732 .30021 m .3353 .34754 L .34862 .35053 L p
1 g
F P
s
P
p
.002 w
.34862 .35053 m .37735 .30813 L .36732 .30021 L p
1 g
F P
s
P
p
.002 w
.31486 .46598 m .33898 .52059 L .34727 .50867 L p
1 g
F P
s
P
p
.002 w
.34727 .50867 m .32499 .45802 L .31486 .46598 L p
1 g
F P
s
P
p
.002 w
.65205 .53082 m .67916 .47524 L .66744 .46802 L p
1 g
F P
s
P
p
.002 w
.67504 .40956 m .66744 .46802 L .67916 .47524 L p
1 g
F P
s
P
p
.002 w
.52454 .24956 m .46775 .24827 L .46735 .26156 L p
1 g
F P
s
P
p
.002 w
.4185 .27729 m .46735 .26156 L .46775 .24827 L p
1 g
F P
s
P
p
.002 w
.41324 .26579 m .36732 .30021 L .37735 .30813 L p
1 g
F P
s
P
p
.002 w
.37735 .30813 m .4185 .27729 L .41324 .26579 L p
1 g
F P
s
P
p
.002 w
.6633 .35171 m .63306 .30065 L .61971 .3049 L p
1 g
F P
s
P
p
.002 w
.57713 .26928 m .61971 .3049 L .63306 .30065 L p
1 g
F P
s
P
p
.002 w
.46775 .24827 m .41324 .26579 L .4185 .27729 L p
1 g
F P
s
P
p
.002 w
.37723 .57579 m .43198 .60451 L .43167 .59126 L p
1 g
F P
s
P
p
.002 w
.43167 .59126 m .37948 .56378 L .37723 .57579 L p
1 g
F P
s
P
p
.002 w
.67916 .47524 m .68721 .41399 L .67504 .40956 L p
1 g
F P
s
P
p
.002 w
.6633 .35171 m .67504 .40956 L .68721 .41399 L p
1 g
F P
s
P
p
.002 w
.31017 .40577 m .31486 .46598 L .32499 .45802 L p
1 g
F P
s
P
p
.002 w
.32499 .45802 m .32072 .40224 L .31017 .40577 L p
1 g
F P
s
P
p
.002 w
.63306 .30065 m .58717 .26215 L .57713 .26928 L p
1 g
F P
s
P
p
.002 w
.52454 .24956 m .57713 .26928 L .58717 .26215 L p
1 g
F P
s
P
p
.002 w
.33471 .53056 m .37723 .57579 L .37948 .56378 L p
1 g
F P
s
P
p
.002 w
.37948 .56378 m .33898 .52059 L .33471 .53056 L p
1 g
F P
s
P
p
.002 w
.55873 .61288 m .61471 .58354 L .60887 .57517 L p
1 g
F P
s
P
p
.002 w
.60887 .57517 m .55403 .60391 L .55873 .61288 L p
1 g
F P
s
P
p
.002 w
.65205 .53082 m .60887 .57517 L .61471 .58354 L p
1 g
F P
s
P
p
.002 w
.68721 .41399 m .67499 .35332 L .6633 .35171 L p
1 g
F P
s
P
p
.002 w
.63306 .30065 m .6633 .35171 L .67499 .35332 L p
1 g
F P
s
P
p
.002 w
.32587 .34667 m .31017 .40577 L .32072 .40224 L p
1 g
F P
s
P
p
.002 w
.32072 .40224 m .3353 .34754 L .32587 .34667 L p
1 g
F P
s
P
p
.002 w
.49645 .62332 m .55873 .61288 L .55403 .60391 L p
1 g
F P
s
P
p
.002 w
.55403 .60391 m .49302 .6141 L .49645 .62332 L p
1 g
F P
s
P
p
.002 w
.61471 .58354 m .65882 .53827 L .65205 .53082 L p
1 g
F P
s
P
p
.002 w
.67916 .47524 m .65205 .53082 L .65882 .53827 L p
1 g
F P
s
P
p
.002 w
.58717 .26215 m .53041 .24079 L .52454 .24956 L p
1 g
F P
s
P
p
.002 w
.46775 .24827 m .52454 .24956 L .53041 .24079 L p
1 g
F P
s
P
p
.002 w
.43414 .61358 m .49645 .62332 L .49302 .6141 L p
1 g
F P
s
P
p
.002 w
.49302 .6141 m .43198 .60451 L .43414 .61358 L p
1 g
F P
s
P
p
.002 w
.36046 .29549 m .32587 .34667 L .3353 .34754 L p
1 g
F P
s
P
p
.002 w
.3353 .34754 m .36732 .30021 L .36046 .29549 L p
1 g
F P
s
P
p
.002 w
.30935 .47332 m .33471 .53056 L .33898 .52059 L p
1 g
F P
s
P
p
.002 w
.33898 .52059 m .31486 .46598 L .30935 .47332 L p
1 g
F P
s
P
p
.002 w
.65882 .53827 m .68652 .48156 L .67916 .47524 L p
1 g
F P
s
P
p
.002 w
.68721 .41399 m .67916 .47524 L .68652 .48156 L p
1 g
F P
s
P
p
.002 w
.53041 .24079 m .46905 .23935 L .46775 .24827 L p
1 g
F P
s
P
p
.002 w
.41324 .26579 m .46775 .24827 L .46905 .23935 L p
1 g
F P
s
P
p
.002 w
.67499 .35332 m .64335 .29975 L .63306 .30065 L p
1 g
F P
s
P
p
.002 w
.58717 .26215 m .63306 .30065 L .64335 .29975 L p
1 g
F P
s
P
p
.002 w
.41011 .25827 m .36046 .29549 L .36732 .30021 L p
1 g
F P
s
P
p
.002 w
.36732 .30021 m .41324 .26579 L .41011 .25827 L p
1 g
F P
s
P
p
.002 w
.46905 .23935 m .41011 .25827 L .41324 .26579 L p
1 g
F P
s
P
p
.002 w
.37824 .58432 m .43414 .61358 L .43198 .60451 L p
1 g
F P
s
P
p
.002 w
.43198 .60451 m .37723 .57579 L .37824 .58432 L p
1 g
F P
s
P
p
.002 w
.68652 .48156 m .69479 .41904 L .68721 .41399 L p
1 g
F P
s
P
p
.002 w
.67499 .35332 m .68721 .41399 L .69479 .41904 L p
1 g
F P
s
P
p
.002 w
.30438 .41014 m .30935 .47332 L .31486 .46598 L p
1 g
F P
s
P
p
.002 w
.31486 .46598 m .31017 .40577 L .30438 .41014 L p
1 g
F P
s
P
p
.002 w
.64335 .29975 m .59525 .25931 L .58717 .26215 L p
1 g
F P
s
P
p
.002 w
.53041 .24079 m .58717 .26215 L .59525 .25931 L p
1 g
F P
s
P
p
.002 w
.33481 .53819 m .37824 .58432 L .37723 .57579 L p
1 g
F P
s
P
p
.002 w
.37723 .57579 m .33471 .53056 L .33481 .53819 L p
1 g
F P
s
P
p
.002 w
.56202 .61724 m .61766 .58807 L .61471 .58354 L p
1 g
F P
s
P
p
.002 w
.61471 .58354 m .55873 .61288 L .56202 .61724 L p
1 g
F P
s
P
p
.002 w
.65882 .53827 m .61471 .58354 L .61766 .58807 L p
1 g
F P
s
P
p
.002 w
.69479 .41904 m .68238 .35712 L .67499 .35332 L p
1 g
F P
s
P
p
.002 w
.64335 .29975 m .67499 .35332 L .68238 .35712 L p
1 g
F P
s
P
p
.002 w
.32084 .34807 m .30438 .41014 L .31017 .40577 L p
1 g
F P
s
P
p
.002 w
.31017 .40577 m .32587 .34667 L .32084 .34807 L p
1 g
F P
s
P
p
.002 w
.50013 .62763 m .56202 .61724 L .55873 .61288 L p
1 g
F P
s
P
p
.002 w
.55873 .61288 m .49645 .62332 L .50013 .62763 L p
1 g
F P
s
P
p
.002 w
.61766 .58807 m .6615 .54308 L .65882 .53827 L p
1 g
F P
s
P
p
.002 w
.68652 .48156 m .65882 .53827 L .6615 .54308 L p
1 g
F P
s
P
p
.002 w
.59525 .25931 m .53569 .23686 L .53041 .24079 L p
1 g
F P
s
P
p
.002 w
.46905 .23935 m .53041 .24079 L .53569 .23686 L p
1 g
F P
s
P
p
.002 w
.43822 .61798 m .50013 .62763 L .49645 .62332 L p
1 g
F P
s
P
p
.002 w
.49645 .62332 m .43414 .61358 L .43822 .61798 L p
1 g
F P
s
P
p
.002 w
.3089 .47978 m .33481 .53819 L .33471 .53056 L p
1 g
F P
s
P
p
.002 w
.33471 .53056 m .30935 .47332 L .3089 .47978 L p
1 g
F P
s
P
p
.002 w
.35717 .29431 m .32084 .34807 L .32587 .34667 L p
1 g
F P
s
P
p
.002 w
.32587 .34667 m .36046 .29549 L .35717 .29431 L p
1 g
F P
s
P
p
.002 w
.6615 .54308 m .68905 .48673 L .68652 .48156 L p
1 g
F P
s
P
p
.002 w
.69479 .41904 m .68652 .48156 L .68905 .48673 L p
1 g
F P
s
P
p
.002 w
.53569 .23686 m .47125 .23532 L .46905 .23935 L p
1 g
F P
s
P
p
.002 w
.41011 .25827 m .46905 .23935 L .47125 .23532 L p
1 g
F P
s
P
p
.002 w
.68238 .35712 m .65012 .30243 L .64335 .29975 L p
1 g
F P
s
P
p
.002 w
.59525 .25931 m .64335 .29975 L .65012 .30243 L p
1 g
F P
s
P
p
.002 w
.40933 .2552 m .35717 .29431 L .36046 .29549 L p
1 g
F P
s
P
p
.002 w
.36046 .29549 m .41011 .25827 L .40933 .2552 L p
1 g
F P
s
P
p
.002 w
.47125 .23532 m .40933 .2552 L .41011 .25827 L p
1 g
F P
s
P
p
.002 w
.3827 .58893 m .43822 .61798 L .43414 .61358 L p
1 g
F P
s
P
p
.002 w
.43414 .61358 m .37824 .58432 L .3827 .58893 L p
1 g
F P
s
P
p
.002 w
.68905 .48673 m .69729 .42464 L .69479 .41904 L p
1 g
F P
s
P
p
.002 w
.68238 .35712 m .69479 .41904 L .69729 .42464 L p
1 g
F P
s
P
p
.002 w
.30383 .41526 m .3089 .47978 L .30935 .47332 L p
1 g
F P
s
P
p
.002 w
.30935 .47332 m .30438 .41014 L .30383 .41526 L p
1 g
F P
s
P
p
.004 w
.51587 .21007 m
.51718 .19192 L
s
P
p
.002 w
.65012 .30243 m .60103 .26113 L .59525 .25931 L p
1 g
F P
s
P
p
.002 w
.53569 .23686 m .59525 .25931 L .60103 .26113 L p
1 g
F P
s
P
p
.002 w
.33958 .54313 m .3827 .58893 L .37824 .58432 L p
1 g
F P
s
P
p
.002 w
.37824 .58432 m .33481 .53819 L .33958 .54313 L p
1 g
F P
s
P
p
.002 w
.69729 .42464 m .68497 .36315 L .68238 .35712 L p
1 g
F P
s
P
p
.002 w
.65012 .30243 m .68238 .35712 L .68497 .36315 L p
1 g
F P
s
P
p
.002 w
.56371 .61655 m .61744 .58838 L .61766 .58807 L p
1 g
F P
s
P
p
.002 w
.61766 .58807 m .56202 .61724 L .56371 .61655 L p
1 g
F P
s
P
p
.002 w
.6615 .54308 m .61766 .58807 L .61744 .58838 L p
1 g
F P
s
P
p
.002 w
.32064 .35186 m .30383 .41526 L .30438 .41014 L p
1 g
F P
s
P
p
.002 w
.30438 .41014 m .32084 .34807 L .32064 .35186 L p
1 g
F P
s
P
p
.002 w
.50397 .62658 m .56371 .61655 L .56202 .61724 L p
1 g
F P
s
P
p
.002 w
.56202 .61724 m .50013 .62763 L .50397 .62658 L p
1 g
F P
s
P
p
.002 w
.61744 .58838 m .65977 .54494 L .6615 .54308 L p
1 g
F P
s
P
p
.002 w
.68905 .48673 m .6615 .54308 L .65977 .54494 L p
1 g
F P
s
P
p
.002 w
.60103 .26113 m .54021 .2382 L .53569 .23686 L p
1 g
F P
s
P
p
.002 w
.47125 .23532 m .53569 .23686 L .54021 .2382 L p
1 g
F P
s
P
p
.002 w
.44423 .61725 m .50397 .62658 L .50013 .62763 L p
1 g
F P
s
P
p
.002 w
.50013 .62763 m .43822 .61798 L .44423 .61725 L p
1 g
F P
s
P
p
.002 w
.31387 .48512 m .33958 .54313 L .33481 .53819 L p
1 g
F P
s
P
p
.002 w
.33481 .53819 m .3089 .47978 L .31387 .48512 L p
1 g
F P
s
P
p
.002 w
.35777 .29693 m .32064 .35186 L .32084 .34807 L p
1 g
F P
s
P
p
.002 w
.32084 .34807 m .35717 .29431 L .35777 .29693 L p
1 g
F P
s
P
p
.002 w
.65977 .54494 m .68636 .49055 L .68905 .48673 L p
1 g
F P
s
P
p
.002 w
.69729 .42464 m .68905 .48673 L .68636 .49055 L p
1 g
F P
s
P
p
.002 w
.54021 .2382 m .47437 .23664 L .47125 .23532 L p
1 g
F P
s
P
p
.002 w
.40933 .2552 m .47125 .23532 L .47437 .23664 L p
1 g
F P
s
P
p
.002 w
.68497 .36315 m .65294 .30884 L .65012 .30243 L p
1 g
F P
s
P
p
.002 w
.60103 .26113 m .65012 .30243 L .65294 .30884 L p
1 g
F P
s
P
p
.002 w
.41108 .25695 m .35777 .29693 L .35717 .29431 L p
1 g
F P
s
P
p
.002 w
.35717 .29431 m .40933 .2552 L .41108 .25695 L p
1 g
F P
s
P
p
.002 w
.47437 .23664 m .41108 .25695 L .40933 .2552 L p
1 g
F P
s
P
p
.002 w
.3907 .58922 m .44423 .61725 L .43822 .61798 L p
1 g
F P
s
P
p
.002 w
.43822 .61798 m .3827 .58893 L .3907 .58922 L p
1 g
F P
s
P
p
.002 w
.68636 .49055 m .69429 .43064 L .69729 .42464 L p
1 g
F P
s
P
p
.002 w
.68497 .36315 m .69729 .42464 L .69429 .43064 L p
1 g
F P
s
P
p
.002 w
.30887 .42105 m .31387 .48512 L .3089 .47978 L p
1 g
F P
s
P
p
.002 w
.3089 .47978 m .30383 .41526 L .30887 .42105 L p
1 g
F P
s
P
p
.002 w
.65294 .30884 m .60418 .26786 L .60103 .26113 L p
1 g
F P
s
P
p
.002 w
.54021 .2382 m .60103 .26113 L .60418 .26786 L p
1 g
F P
s
P
p
.002 w
.34917 .54503 m .3907 .58922 L .3827 .58893 L p
1 g
F P
s
P
p
.002 w
.3827 .58893 m .33958 .54313 L .34917 .54503 L p
1 g
F P
s
P
p
.002 w
.69429 .43064 m .68239 .37136 L .68497 .36315 L p
1 g
F P
s
P
p
.002 w
.65294 .30884 m .68497 .36315 L .68239 .37136 L p
1 g
F P
s
P
p
.002 w
.3256 .35809 m .30887 .42105 L .30383 .41526 L p
1 g
F P
s
P
p
.002 w
.30383 .41526 m .32064 .35186 L .3256 .35809 L p
1 g
F P
s
P
p
.002 w
.56366 .61049 m .61385 .58418 L .61744 .58838 L p
1 g
F P
s
P
p
.002 w
.61744 .58838 m .56371 .61655 L .56366 .61049 L p
1 g
F P
s
P
p
.002 w
.65977 .54494 m .61744 .58838 L .61385 .58418 L p
1 g
F P
s
P
p
.002 w
.50786 .61983 m .56366 .61049 L .56371 .61655 L p
1 g
F P
s
P
p
.002 w
.56371 .61655 m .50397 .62658 L .50786 .61983 L p
1 g
F P
s
P
p
.002 w
.61385 .58418 m .65338 .5436 L .65977 .54494 L p
1 g
F P
s
P
p
.002 w
.68636 .49055 m .65977 .54494 L .65338 .5436 L p
1 g
F P
s
P
p
.002 w
.60418 .26786 m .54376 .24512 L .54021 .2382 L p
1 g
F P
s
P
p
.002 w
.47437 .23664 m .54021 .2382 L .54376 .24512 L p
1 g
F P
s
P
p
.002 w
.45212 .61109 m .50786 .61983 L .50397 .62658 L p
1 g
F P
s
P
p
.002 w
.50397 .62658 m .44423 .61725 L .45212 .61109 L p
1 g
F P
s
P
p
.002 w
.32445 .4891 m .34917 .54503 L .33958 .54313 L p
1 g
F P
s
P
p
.002 w
.33958 .54313 m .31387 .48512 L .32445 .4891 L p
1 g
F P
s
P
p
.002 w
.36252 .30352 m .3256 .35809 L .32064 .35186 L p
1 g
F P
s
P
p
.002 w
.32064 .35186 m .35777 .29693 L .36252 .30352 L p
1 g
F P
s
P
p
.002 w
.65338 .5436 m .67818 .49281 L .68636 .49055 L p
1 g
F P
s
P
p
.002 w
.69429 .43064 m .68636 .49055 L .67818 .49281 L p
1 g
F P
s
P
p
.002 w
.54376 .24512 m .47836 .2436 L .47437 .23664 L p
1 g
F P
s
P
p
.004 w
.51351 .24285 m
.51587 .21007 L
s
P
p
.002 w
.41108 .25695 m .47437 .23664 L .47836 .2436 L p
1 g
F P
s
P
p
.002 w
.68239 .37136 m .65146 .31905 L .65294 .30884 L p
1 g
F P
s
P
p
.002 w
.60418 .26786 m .65294 .30884 L .65146 .31905 L p
1 g
F P
s
P
p
.002 w
.41549 .26381 m .36252 .30352 L .35777 .29693 L p
1 g
F P
s
P
p
.002 w
.35777 .29693 m .41108 .25695 L .41549 .26381 L p
1 g
F P
s
P
p
.002 w
.47836 .2436 m .41549 .26381 L .41108 .25695 L p
1 g
F P
s
P
p
.002 w
.40222 .58489 m .45212 .61109 L .44423 .61725 L p
1 g
F P
s
P
p
.002 w
.44423 .61725 m .3907 .58922 L .40222 .58489 L p
1 g
F P
s
P
p
.002 w
.67818 .49281 m .68553 .43691 L .69429 .43064 L p
1 g
F P
s
P
p
.002 w
.68239 .37136 m .69429 .43064 L .68553 .43691 L p
1 g
F P
s
P
p
.002 w
.31971 .42737 m .32445 .4891 L .31387 .48512 L p
1 g
F P
s
P
p
.002 w
.31387 .48512 m .30887 .42105 L .31971 .42737 L p
1 g
F P
s
P
p
.002 w
.65146 .31905 m .60443 .27961 L .60418 .26786 L p
1 g
F P
s
P
p
.002 w
.54376 .24512 m .60418 .26786 L .60443 .27961 L p
1 g
F P
s
P
p
.002 w
.36359 .54366 m .40222 .58489 L .3907 .58922 L p
1 g
F P
s
P
p
.002 w
.3907 .58922 m .34917 .54503 L .36359 .54366 L p
1 g
F P
s
P
p
.002 w
.68553 .43691 m .67436 .38165 L .68239 .37136 L p
1 g
F P
s
P
p
.002 w
.65146 .31905 m .68239 .37136 L .67436 .38165 L p
1 g
F P
s
P
p
.002 w
.3359 .36671 m .31971 .42737 L .30887 .42105 L p
1 g
F P
s
P
p
.002 w
.30887 .42105 m .3256 .35809 L .3359 .36671 L p
1 g
F P
s
P
p
.002 w
.56173 .5989 m .60677 .5753 L .61385 .58418 L p
1 g
F P
s
P
p
.002 w
.61385 .58418 m .56366 .61049 L .56173 .5989 L p
1 g
F P
s
P
p
.002 w
.65338 .5436 m .61385 .58418 L .60677 .5753 L p
1 g
F P
s
P
p
.002 w
.51169 .60724 m .56173 .5989 L .56366 .61049 L p
1 g
F P
s
P
p
.002 w
.56366 .61049 m .50786 .61983 L .51169 .60724 L p
1 g
F P
s
P
p
.002 w
.60677 .5753 m .64222 .53889 L .65338 .5436 L p
1 g
F P
s
P
p
.002 w
.67818 .49281 m .65338 .5436 L .64222 .53889 L p
1 g
F P
s
P
p
.002 w
.60443 .27961 m .54619 .25776 L .54376 .24512 L p
1 g
F P
s
P
p
.002 w
.47836 .2436 m .54376 .24512 L .54619 .25776 L p
1 g
F P
s
P
p
.002 w
.46175 .59935 m .51169 .60724 L .50786 .61983 L p
1 g
F P
s
P
p
.002 w
.50786 .61983 m .45212 .61109 L .46175 .59935 L p
1 g
F P
s
P
p
.002 w
.34067 .49152 m .36359 .54366 L .34917 .54503 L p
1 g
F P
s
P
p
.002 w
.34917 .54503 m .32445 .4891 L .34067 .49152 L p
1 g
F P
s
P
p
.002 w
.37151 .31415 m .3359 .36671 L .3256 .35809 L p
1 g
F P
s
P
p
.002 w
.3256 .35809 m .36252 .30352 L .37151 .31415 L p
1 g
F P
s
P
p
.002 w
.64222 .53889 m .66442 .49333 L .67818 .49281 L p
1 g
F P
s
P
p
.002 w
.68553 .43691 m .67818 .49281 L .66442 .49333 L p
1 g
F P
s
P
p
.002 w
.54619 .25776 m .48316 .25637 L .47836 .2436 L p
1 g
F P
s
P
p
.002 w
.41549 .26381 m .47836 .2436 L .48316 .25637 L p
1 g
F P
s
P
p
.002 w
.67436 .38165 m .64547 .33295 L .65146 .31905 L p
1 g
F P
s
P
p
.002 w
.60443 .27961 m .65146 .31905 L .64547 .33295 L p
1 g
F P
s
P
p
.002 w
.42258 .27587 m .37151 .31415 L .36252 .30352 L p
1 g
F P
s
P
p
.002 w
.36252 .30352 m .41549 .26381 L .42258 .27587 L p
1 g
F P
s
P
p
.002 w
.48316 .25637 m .42258 .27587 L .41549 .26381 L p
1 g
F P
s
P
p
.002 w
.41712 .57581 m .46175 .59935 L .45212 .61109 L p
1 g
F P
s
P
p
.002 w
.45212 .61109 m .40222 .58489 L .41712 .57581 L p
1 g
F P
s
P
p
.002 w
.66442 .49333 m .67093 .44324 L .68553 .43691 L p
1 g
F P
s
P
p
.002 w
.67436 .38165 m .68553 .43691 L .67093 .44324 L p
1 g
F P
s
P
p
.002 w
.33636 .43403 m .34067 .49152 L .32445 .4891 L p
1 g
F P
s
P
p
.002 w
.32445 .4891 m .31971 .42737 L .33636 .43403 L p
1 g
F P
s
P
p
.002 w
.64547 .33295 m .6016 .29631 L .60443 .27961 L p
1 g
F P
s
P
p
.002 w
.54619 .25776 m .60443 .27961 L .6016 .29631 L p
1 g
F P
s
P
p
.002 w
.38265 .53884 m .41712 .57581 L .40222 .58489 L p
1 g
F P
s
P
p
.002 w
.40222 .58489 m .36359 .54366 L .38265 .53884 L p
1 g
F P
s
P
p
.002 w
.67093 .44324 m .66083 .3938 L .67436 .38165 L p
1 g
F P
s
P
p
.002 w
.64547 .33295 m .67436 .38165 L .66083 .3938 L p
1 g
F P
s
P
p
.002 w
.35153 .37758 m .33636 .43403 L .31971 .42737 L p
1 g
F P
s
P
p
.002 w
.31971 .42737 m .3359 .36671 L .35153 .37758 L p
1 g
F P
s
P
p
.002 w
.55789 .58181 m .59621 .56175 L .60677 .5753 L p
1 g
F P
s
P
p
.002 w
.60677 .5753 m .56173 .5989 L .55789 .58181 L p
1 g
F P
s
P
p
.002 w
.64222 .53889 m .60677 .5753 L .59621 .56175 L p
1 g
F P
s
P
p
.002 w
.51532 .58887 m .55789 .58181 L .56173 .5989 L p
1 g
F P
s
P
p
.002 w
.56173 .5989 m .51169 .60724 L .51532 .58887 L p
1 g
F P
s
P
p
.002 w
.6016 .29631 m .54733 .27607 L .54619 .25776 L p
1 g
F P
s
P
p
.002 w
.48316 .25637 m .54619 .25776 L .54733 .27607 L p
1 g
F P
s
P
p
.002 w
.59621 .56175 m .62636 .53075 L .64222 .53889 L p
1 g
F P
s
P
p
.002 w
.66442 .49333 m .64222 .53889 L .62636 .53075 L p
1 g
F P
s
P
p
.002 w
.36228 .49219 m .38265 .53884 L .36359 .54366 L p
1 g
F P
s
P
p
.002 w
.36359 .54366 m .34067 .49152 L .36228 .49219 L p
1 g
F P
s
P
p
.002 w
.47289 .58208 m .51532 .58887 L .51169 .60724 L p
1 g
F P
s
P
p
.002 w
.51169 .60724 m .46175 .59935 L .47289 .58208 L p
1 g
F P
s
P
p
.002 w
.38473 .32868 m .35153 .37758 L .3359 .36671 L p
1 g
F P
s
P
p
.002 w
.3359 .36671 m .37151 .31415 L .38473 .32868 L p
1 g
F P
s
P
p
.002 w
.62636 .53075 m .64518 .49199 L .66442 .49333 L p
1 g
F P
s
P
p
.002 w
.67093 .44324 m .66442 .49333 L .64518 .49199 L p
1 g
F P
s
P
p
.002 w
.66083 .3938 m .63488 .35032 L .64547 .33295 L p
1 g
F P
s
P
p
.002 w
.6016 .29631 m .64547 .33295 L .63488 .35032 L p
1 g
F P
s
P
p
.002 w
.54733 .27607 m .48865 .27486 L .48316 .25637 L p
1 g
F P
s
P
p
.004 w
.51208 .26264 m
.51351 .24285 L
s
P
p
.002 w
.42258 .27587 m .48316 .25637 L .48865 .27486 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.43227 .29305 m .38473 .32868 L .37151 .31415 L p
1 g
F P
s
P
p
.002 w
.37151 .31415 m .42258 .27587 L .43227 .29305 L p
1 g
F P
s
P
p
.002 w
.43506 .56201 m .47289 .58208 L .46175 .59935 L p
1 g
F P
s
P
p
.002 w
.46175 .59935 m .41712 .57581 L .43506 .56201 L p
1 g
F P
s
P
p
.002 w
.48865 .27486 m .43227 .29305 L .42258 .27587 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.64518 .49199 m .65063 .44942 L .67093 .44324 L p
1 g
F P
s
P
p
.002 w
.66083 .3938 m .67093 .44324 L .65063 .44942 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.35857 .44082 m .36228 .49219 L .34067 .49152 L p
1 g
F P
s
P
p
.002 w
.34067 .49152 m .33636 .43403 L .35857 .44082 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.63488 .35032 m .59559 .31768 L .6016 .29631 L p
1 g
F P
s
P
p
.002 w
.54733 .27607 m .6016 .29631 L .59559 .31768 L p
1 g
F P
s
P
p
.002 w
.40593 .53057 m .43506 .56201 L .41712 .57581 L p
1 g
F P
s
P
p
.002 w
.41712 .57581 m .38265 .53884 L .40593 .53057 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.65063 .44942 m .64195 .40749 L .66083 .3938 L p
1 g
F P
s
P
p
.002 w
.63488 .35032 m .66083 .3938 L .64195 .40749 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.37222 .39044 m .35857 .44082 L .33636 .43403 L p
1 g
F P
s
P
p
.002 w
.33636 .43403 m .35153 .37758 L .37222 .39044 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54925 .5632 L p
1 g
F P
s
P
p
.56075 .54566 m .54925 .5632 L .55057 .56184 L 1 g
F
P
p
.55789 .58181 m .53901 .57375 L .54925 .5632 L 1 g
F
P
p
.002 w
.55229 .56006 m .55257 .56116 L p
.54925 .5632 L 1 g
F P
s
P
p
.002 w
.55257 .56116 m .55789 .58181 L p
.54925 .5632 L 1 g
F P
s
P
p
.002 w
.54925 .5632 m .54854 .56129 L p
.54166 .56785 L 1 g
F P
s
P
p
.56075 .54566 m .55057 .56184 L .55346 .55854 L 1 g
F
P
p
.56075 .54566 m .55346 .55854 L .55434 .55728 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.58236 .54371 m .55851 .55619 L p
.56701 .53918 L 1 g
F P
s
P
p
.002 w
.55851 .55619 m .55314 .559 L p
.56149 .54706 L 1 g
F P
s
P
p
.55851 .55619 m .56149 .54706 L .56701 .53918 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56149 .54706 L p
1 g
F P
s
P
p
.56654 .52734 m .56149 .54706 L .56477 .53703 L 1 g
F
P
p
.002 w
.58236 .54371 m .59621 .56175 L p
.5527 .55955 L 1 g
F P
s
P
p
.002 w
.55314 .559 m .58236 .54371 L p
.5527 .55955 L 1 g
F P
s
P
p
.002 w
.59621 .56175 m .55789 .58181 L .55229 .56006 L p
1 g
F P
s
P
p
.55057 .56184 m .55229 .56006 L .55396 .55797 L 1 g
F
P
p
.002 w
.55229 .56006 m .55215 .55952 L p
.5527 .55955 L 1 g
F P
s
P
p
.59621 .56175 m .55229 .56006 L .5527 .55955 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56196 .54794 L p
1 g
F P
s
P
p
.002 w
.56196 .54794 m .56149 .54706 L p
.55691 .55427 L 1 g
F P
s
P
p
.55691 .55427 m .54998 .56518 L .56196 .54794 L 1 g
F
P
p
.002 w
.56149 .54706 m .56075 .54566 L p
.55434 .55728 L 1 g
F P
s
P
p
.55434 .55728 m .54998 .56518 L .56149 .54706 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56701 .53918 m .56169 .54646 L .56433 .53838 L 1 g
F
P
p
.002 w
.55314 .559 m .55215 .55952 L p
.56701 .53918 L 1 g
F P
s
P
p
.002 w
.56749 .52872 m .56654 .52734 L p
.56477 .53703 L 1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56749 .52872 L p
1 g
F P
s
P
p
.56515 .50826 m .56749 .52872 L .56735 .52402 L 1 g
F
P
p
.60609 .51928 m .56735 .52402 L .56722 .52154 L 1 g
F
P
p
.56723 .52173 m .56735 .52402 L .5673 .52219 L 1 g
F
P
p
.56515 .50826 m .56735 .52402 L .56723 .52173 L 1 g
F
P
p
.002 w
.60609 .51928 m .58236 .54371 L .56735 .52402 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56735 .52402 m .58236 .54371 L p
.56779 .53941 L 1 g
F P
s
P
p
.002 w
.58193 .50472 m .60609 .51928 L p
.56722 .52154 L 1 g
F P
s
P
p
.002 w
.56713 .51998 m .58193 .50472 L p
.56722 .52154 L 1 g
F P
s
P
p
.56515 .50826 m .56723 .52173 L .56713 .51998 L 1 g
F
P
p
.002 w
.56606 .50934 m .56515 .50826 L p
.56713 .51998 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56606 .50934 L p
1 g
F P
s
P
p
.56519 .5007 m .5653 .50776 L .56151 .49982 L 1 g
F
P
p
.002 w
.58193 .50472 m .56982 .51721 L p
.56519 .5007 L 1 g
F P
s
P
p
.002 w
.56982 .51721 m .56713 .51998 L p
.56606 .50934 L 1 g
F P
s
P
p
.56982 .51721 m .56606 .50934 L .56519 .5007 L 1 g
F
P
p
.55661 .4905 m .56606 .50934 L .5618 .50043 L 1 g
F
P
p
.002 w
.56713 .51998 m .56553 .52163 L p
.56519 .5007 L 1 g
F P
s
P
p
.002 w
.55751 .49146 m .55661 .4905 L p
.5618 .50043 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55464 .48749 m .58193 .50472 L p
.56772 .50131 L 1 g
F P
s
P
p
.002 w
.54624 .49617 m .55404 .48811 L p
.56772 .50131 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55751 .49146 L p
1 g
F P
s
P
p
.54174 .47608 m .55751 .49146 L .55404 .48811 L 1 g
F
P
p
.002 w
.55404 .48811 m .54624 .49617 L p
.55086 .48502 L 1 g
F P
s
P
p
.55173 .48587 m .55404 .48811 L .55285 .48696 L 1 g
F
P
p
.54174 .47608 m .55404 .48811 L .55173 .48587 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54234 .47673 L .54202 .47658 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54234 .47673 m .54174 .47608 L p
.55176 .48589 L 1 g
F P
s
P
p
.002 w
.55657 .48346 m .55464 .48749 L .55086 .48502 L p
1 g
F P
s
P
p
.002 w
.55086 .48502 m .52749 .46971 L p
.54234 .47673 L 1 g
F P
s
P
p
.55657 .48346 m .55086 .48502 L .54234 .47673 L 1 g
F
P
p
.002 w
.54624 .49617 m .52566 .46884 L p
.55086 .48502 L 1 g
F P
s
P
p
.002 w
.52749 .46971 m .55086 .48502 L p
.52566 .46884 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55751 .49146 L p
1 g
F P
s
P
p
.5618 .50043 m .56713 .51061 L .55751 .49146 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54234 .47673 L p
1 g
F P
s
P
p
.55176 .48589 m .55834 .49233 L .54234 .47673 L 1 g
F
P
p
.52214 .46667 m .54235 .47674 L .53361 .47261 L 1 g
F
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52516 .46819 m .55982 .47666 L .55657 .48346 L p
1 g
F P
s
P
p
.002 w
.54624 .49617 m .53553 .50176 L .52531 .46868 L p
1 g
F P
s
P
p
.002 w
.52566 .46884 m .54624 .49617 L p
.52531 .46868 L 1 g
F P
s
P
p
.002 w
.53553 .50176 m .52365 .50367 L .52514 .4686 L p
1 g
F P
s
P
p
.52214 .46667 m .53396 .47279 L .52531 .46868 L 1 g
F
P
p
.002 w
.52514 .4686 m .52516 .46819 L .52531 .46868 L p
1 g
F P
s
P
p
.002 w
.52531 .46868 m .53553 .50176 L p
.52514 .4686 L 1 g
F P
s
P
p
.002 w
.52365 .50367 m .51187 .50168 L .52502 .46854 L p
1 g
F P
s
P
p
.002 w
.52502 .46854 m .52516 .46819 L .52514 .4686 L p
1 g
F P
s
P
p
.002 w
.52514 .4686 m .52365 .50367 L p
.52502 .46854 L 1 g
F P
s
P
p
.002 w
.51187 .50168 m .50145 .49601 L .52491 .46848 L p
1 g
F P
s
P
p
.002 w
.52491 .46848 m .52516 .46819 L .52502 .46854 L p
1 g
F P
s
P
p
.002 w
.52502 .46854 m .51187 .50168 L p
.52491 .46848 L 1 g
F P
s
P
p
.002 w
.50145 .49601 m .49353 .48723 L .52478 .46842 L p
1 g
F P
s
P
p
.002 w
.52478 .46842 m .52516 .46819 L .52491 .46848 L p
1 g
F P
s
P
p
.002 w
.52491 .46848 m .50145 .49601 L p
.52478 .46842 L 1 g
F P
s
P
p
.002 w
.49353 .48723 m .48897 .4763 L .52457 .46832 L p
1 g
F P
s
P
p
.002 w
.52457 .46832 m .52516 .46819 L .52478 .46842 L p
1 g
F P
s
P
p
.002 w
.52478 .46842 m .49353 .48723 L p
.52457 .46832 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48897 .4763 m .48837 .46577 L p
.52408 .46807 L 1 g
F P
s
P
p
.002 w
.49359 .46493 m .52408 .46807 L p
.48837 .46577 L 1 g
F P
s
P
p
.002 w
.48897 .4763 m .45329 .48295 L p
.4848 .46624 L 1 g
F P
s
P
p
.47786 .46667 m .49126 .46531 L .48837 .46577 L 1 g
F
P
p
.002 w
.47754 .46719 m .47786 .46667 L p
.48837 .46577 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48829 .46439 m .49158 .45279 L .51168 .462 L p
1 g
F P
s
P
p
.002 w
.52408 .46807 m .49359 .46493 L p
.50219 .46423 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .4673 L p
1 g
F P
s
P
p
.5 .4634 m .52252 .4673 L .51201 .46571 L 1 g
F
P
p
.50219 .46423 m .52252 .4673 L .52408 .46807 L 1 g
F
P
p
.49359 .46493 m .5 .46389 L .50219 .46423 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46389 L p
1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .4634 L p
.51201 .46571 L 1 g
F P
s
P
p
.51201 .46571 m .52282 .46778 L .5 .46389 L 1 g
F
P
p
.002 w
.51168 .462 m .51435 .46323 L p
.50219 .46423 L 1 g
F P
s
P
p
.5 .46389 m .51168 .462 L .50219 .46423 L 1 g
F
P
p
.50219 .46423 m .51435 .46323 L .52252 .4673 L 1 g
F
P
p
.002 w
.52252 .4673 m .52282 .46778 L p
.51201 .46571 L 1 g
F P
s
P
p
.002 w
.52457 .46832 m .48897 .4763 L p
.52408 .46807 L 1 g
F P
s
P
p
.002 w
.52256 .46737 m .52256 .46736 L p
.52485 .46846 L 1 g
F P
s
P
p
.52485 .46846 m .52491 .46849 L .52486 .46846 L 1 g
F
P
p
.52485 .46846 m .52486 .46846 L .52256 .46737 L 1 g
F
P
p
.52214 .46667 m .52531 .46868 L .52478 .46842 L 1 g
F
P
p
.002 w
.52256 .46736 m .52252 .4673 L p
.52478 .46842 L 1 g
F P
s
P
p
.002 w
.52252 .4673 m .52214 .46667 L p
.52478 .46842 L 1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.49849 .44279 m .52516 .46819 L .51435 .46323 L p
1 g
F P
s
P
p
.002 w
.51435 .46323 m .49158 .45279 L .49204 .45212 L p
1 g
F P
s
P
p
.002 w
.49204 .45212 m .49849 .44279 L p
.51435 .46323 L 1 g
F P
s
P
p
.002 w
.51435 .46323 m .52516 .46819 L .52408 .46807 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46389 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46389 L .49335 .46497 L 1 g
F
P
p
.002 w
.49359 .46493 m .48829 .46439 L p
.51168 .462 L 1 g
F P
s
P
p
.002 w
.5 .46389 m .5 .46424 L p
.49335 .46497 L 1 g
F P
s
P
p
.002 w
.5 .46424 m .5 .46442 L p
.49409 .46502 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46424 L .49409 .46502 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45185 .45953 m .48829 .46439 L p
.4848 .46624 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45329 .48295 m .45317 .48111 L p
.4848 .46624 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45317 .48111 m .45762 .47678 L .4848 .46624 L 1 g
F
P
p
.002 w
.45762 .47678 m .45826 .47608 L p
.46748 .47204 L 1 g
F P
s
P
p
.45762 .47678 m .47754 .46719 L .4848 .46624 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .46719 L p
1 g
F P
s
P
p
.002 w
.47754 .46719 m .47718 .46778 L p
.46748 .47204 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .46719 L .46748 .47204 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45744 .47697 L p
1 g
F P
s
P
p
.44339 .4905 m .45744 .47697 L .45484 .4795 L 1 g
F
P
p
.44339 .4905 m .45728 .47715 L .4521 .48216 L 1 g
F
P
p
.002 w
.45185 .45953 m .45317 .48111 L p
.41949 .4879 L 1 g
F P
s
P
p
.002 w
.45317 .48111 m .45329 .48295 L .45092 .4833 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.42729 .50613 m .44267 .49127 L .4417 .49328 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44267 .49127 L p
1 g
F P
s
P
p
.002 w
.43114 .51515 m .42729 .50613 L p
.43505 .49921 L 1 g
F P
s
P
p
.43395 .50933 m .43505 .49921 L .4417 .49328 L 1 g
F
P
p
.43114 .51515 m .43505 .49921 L .43395 .50933 L 1 g
F
P
p
.43346 .52734 m .4331 .51715 L .43291 .51891 L 1 g
F
P
p
.43346 .52734 m .43291 .51891 L .4329 .51905 L 1 g
F
P
p
.002 w
.43265 .52851 m .43346 .52734 L p
.4329 .51902 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43278 .51898 m .43114 .51515 L p
.43373 .51139 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43395 .50933 L p
1 g
F P
s
P
p
.43346 .52734 m .43395 .50933 L .4331 .51715 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.43294 .51871 m .43373 .51139 L .45329 .48295 L 1 g
F
P
p
.43278 .51898 m .43373 .51139 L .43294 .51871 L 1 g
F
P
p
.43485 .50826 m .44267 .49127 L .43782 .50132 L 1 g
F
P
p
.002 w
.43395 .50933 m .43485 .50826 L p
.43782 .50132 L 1 g
F P
s
P
p
.43114 .51515 m .4417 .49328 L .45329 .48295 L 1 g
F
P
p
.002 w
.43395 .50933 m .43287 .51061 L p
.4331 .51715 L 1 g
F P
s
P
p
.002 w
.45555 .54374 m .4329 .5191 L p
.46234 .50437 L 1 g
F P
s
P
p
.002 w
.4329 .5191 m .43278 .51898 L .43291 .51891 L p
1 g
F P
s
P
p
.002 w
.43291 .51891 m .46234 .50437 L p
.4329 .5191 L 1 g
F P
s
P
p
.4329 .51905 m .43291 .51891 L .4329 .51902 L 1 g
F
P
p
.002 w
.43278 .51898 m .4329 .5191 L p
.43286 .5205 L 1 g
F P
s
P
p
.002 w
.40593 .53057 m .43278 .51898 L p
.43286 .5205 L 1 g
F P
s
P
p
.002 w
.43506 .56201 m .43187 .55856 L p
.43265 .52851 L 1 g
F P
s
P
p
.43506 .56201 m .43265 .52851 L .43341 .53086 L 1 g
F
P
p
.002 w
.43187 .55856 m .40593 .53057 L p
.43036 .52143 L 1 g
F P
s
P
p
.43265 .52851 m .43036 .52143 L .43286 .5205 L 1 g
F
P
p
.43187 .55856 m .43036 .52143 L .43265 .52851 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43265 .52851 L p
1 g
F P
s
P
p
.43925 .54566 m .43265 .52851 L .43633 .53989 L 1 g
F
P
p
.002 w
.4386 .54689 m .43925 .54566 L p
.43633 .53989 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44368 .55432 m .43506 .56201 L p
.4339 .54002 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43807 .54789 L p
1 g
F P
s
P
p
.002 w
.46352 .57711 m .43506 .56201 L .44147 .55629 L p
1 g
F P
s
P
p
.002 w
.44147 .55629 m .44368 .55432 L p
.45095 .56267 L 1 g
F P
s
P
p
.46352 .57711 m .44147 .55629 L .45095 .56267 L 1 g
F
P
p
.002 w
.46834 .57439 m .46872 .57265 L p
.46145 .56975 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47289 .58208 m .46352 .57711 L p
.46233 .57211 L 1 g
F P
s
P
p
.47289 .58208 m .46233 .57211 L .46963 .57488 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .57439 L p
1 g
F P
s
P
p
.48921 .57862 m .46834 .57439 L .47311 .57619 L 1 g
F
P
p
.002 w
.47561 .57714 m .47289 .58208 L p
.46963 .57488 L 1 g
F P
s
P
p
.48921 .57862 m .46811 .57544 L .47812 .57771 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45555 .54374 m .48524 .55961 L .47561 .57714 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45095 .56267 L p
1 g
F P
s
P
p
.46872 .57265 m .45095 .56267 L .46145 .56975 L 1 g
F
P
p
.45146 .56129 m .43807 .54789 L .44441 .55516 L 1 g
F
P
p
.002 w
.4504 .56415 m .45146 .56129 L p
.44402 .55483 L 1 g
F P
s
P
p
.002 w
.44368 .55432 m .45555 .54374 L p
.46352 .57711 L 1 g
F P
s
P
p
.002 w
.45095 .56267 m .45002 .56518 L p
.46145 .56975 L 1 g
F P
s
P
p
.46963 .57488 m .46834 .57439 L .45555 .54374 L 1 g
F
P
p
.46834 .57439 m .46233 .57211 L .46182 .57 L 1 g
F
P
p
.46834 .57439 m .46182 .57 L .45555 .54374 L 1 g
F
P
p
.46963 .57488 m .45555 .54374 L .47561 .57714 L 1 g
F
P
p
.002 w
.46834 .57439 m .46811 .57544 L p
.47311 .57619 L 1 g
F P
s
P
p
.002 w
.51532 .58887 m .47289 .58208 L .47401 .58006 L p
1 g
F P
s
P
p
.002 w
.47401 .58006 m .47561 .57714 L p
.48586 .58017 L 1 g
F P
s
P
p
.51532 .58887 m .47401 .58006 L .48586 .58017 L 1 g
F
P
p
.002 w
.51092 .5804 m .51079 .57862 L p
.5023 .58032 L 1 g
F P
s
P
p
.51532 .58887 m .48586 .58017 L .51167 .58532 L 1 g
F
P
p
.48586 .58017 m .47561 .57714 L .48909 .5802 L 1 g
F
P
p
.48586 .58017 m .48909 .5802 L .51167 .58532 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .5802 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .5802 L .5023 .58032 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47561 .57714 m .48524 .55961 L p
.50657 .58036 L 1 g
F P
s
P
p
.51167 .58532 m .48909 .5802 L .50657 .58036 L 1 g
F
P
p
.002 w
.48895 .58219 m .48909 .5802 L p
.47683 .5776 L 1 g
F P
s
P
p
.002 w
.48909 .5802 m .48921 .57862 L p
.47812 .57771 L 1 g
F P
s
P
p
.47812 .57771 m .47683 .5776 L .48909 .5802 L 1 g
F
P
p
.48909 .5802 m .47561 .57714 L .50657 .58036 L 1 g
F
P
p
.002 w
.48909 .5802 m .48889 .583 L p
.5023 .58032 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .5804 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .5804 L .51666 .57921 L 1 g
F
P
p
.55789 .58181 m .52252 .57958 L .53604 .57248 L 1 g
F
P
p
.52252 .57958 m .51666 .57921 L .53158 .57403 L 1 g
F
P
p
.52252 .57958 m .53158 .57403 L .53604 .57248 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53158 .57403 L p
1 g
F P
s
P
p
.54854 .56129 m .53158 .57403 L .54166 .56785 L 1 g
F
P
p
.53128 .57265 m .51666 .57921 L .52236 .57723 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.55789 .58181 m .51532 .58887 L .51666 .57921 L p
1 g
F P
s
P
p
.002 w
.51666 .57921 m .51532 .58887 L p
.50737 .58114 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51666 .57921 m .51862 .56503 L p
.53604 .57248 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.53901 .57375 m .51862 .56503 L .55229 .56006 L 1 g
F
P
p
.002 w
.53158 .57403 m .5322 .57686 L p
.54166 .56785 L 1 g
F P
s
P
p
.52236 .57723 m .51666 .57921 L .51976 .57856 L 1 g
F
P
p
.002 w
.48524 .55961 m .51862 .56503 L .51666 .57921 L p
1 g
F P
s
P
p
.50737 .58114 m .48524 .55961 L .51666 .57921 L 1 g
F
P
p
.002 w
.51092 .5804 m .51111 .583 L p
.51976 .57856 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51092 .5804 L p
1 g
F P
s
P
p
.5023 .58032 m .48889 .583 L .51092 .5804 L 1 g
F
P
p
.002 w
.46811 .57544 m .4678 .57686 L p
.47812 .57771 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48895 .58219 L p
1 g
F P
s
P
p
.47683 .5776 m .4678 .57686 L .48895 .58219 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .57439 L p
1 g
F P
s
P
p
.46145 .56975 m .45002 .56518 L .46834 .57439 L 1 g
F
P
p
.002 w
.43807 .54789 m .43743 .5491 L p
.44441 .55516 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45555 .54374 m .44368 .55432 L p
.43286 .5205 L 1 g
F P
s
P
p
.4339 .54002 m .43286 .5205 L .44368 .55432 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4504 .56415 L p
1 g
F P
s
P
p
.44402 .55483 m .43743 .5491 L .4504 .56415 L 1 g
F
P
p
.002 w
.43265 .52851 m .43146 .53025 L p
.43633 .53989 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4386 .54689 L p
1 g
F P
s
P
p
.43633 .53989 m .43146 .53025 L .4386 .54689 L 1 g
F
P
p
.43341 .53086 m .43265 .52851 L .43286 .5205 L 1 g
F
P
p
.002 w
.41949 .4879 m .43278 .51898 L .40593 .53057 L p
1 g
F P
s
P
p
.002 w
.45329 .48295 m .46234 .50437 L .43278 .51898 L p
1 g
F P
s
P
p
.4329 .51902 m .43287 .51061 L .43172 .52987 L 1 g
F
P
p
.4331 .51715 m .43302 .51465 L .4329 .51902 L 1 g
F
P
p
.43302 .51465 m .43287 .51061 L .4329 .51902 L 1 g
F
P
p
.002 w
.43172 .52987 m .43265 .52851 L p
.4329 .51902 L 1 g
F P
s
P
p
.002 w
.4329 .5191 m .45555 .54374 L p
.43286 .5205 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43172 .52987 L p
1 g
F P
s
P
p
.002 w
.44267 .49127 m .44166 .49233 L p
.43782 .50132 L 1 g
F P
s
P
p
.002 w
.45092 .4833 m .45329 .48295 L p
.4417 .49328 L 1 g
F P
s
P
p
.44267 .49127 m .45092 .4833 L .4417 .49328 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43395 .50933 L p
1 g
F P
s
P
p
.43782 .50132 m .44166 .49233 L .43395 .50933 L 1 g
F
P
p
.002 w
.44179 .4922 m .44339 .4905 L p
.4522 .48206 L 1 g
F P
s
P
p
.002 w
.45092 .4833 m .41949 .4879 L p
.45317 .48111 L 1 g
F P
s
P
p
.002 w
.45744 .47697 m .45728 .47715 L p
.45484 .4795 L 1 g
F P
s
P
p
.002 w
.45728 .47715 m .45698 .47747 L p
.4521 .48216 L 1 g
F P
s
P
p
.002 w
.42729 .50613 m .41949 .4879 L .45092 .4833 L p
1 g
F P
s
P
p
.45762 .47678 m .45252 .47049 L .46589 .46873 L 1 g
F
P
p
.002 w
.45317 .48111 m .45304 .47898 L p
.45762 .47678 L 1 g
F P
s
P
p
.002 w
.45304 .47898 m .45252 .47049 L p
.45762 .47678 L 1 g
F P
s
P
p
.45762 .47678 m .46589 .46873 L .47754 .46719 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45762 .47678 L p
1 g
F P
s
P
p
.46748 .47204 m .47718 .46778 L .45762 .47678 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44179 .4922 L p
1 g
F P
s
P
p
.4522 .48206 m .45698 .47747 L .44179 .4922 L 1 g
F
P
p
.002 w
.45252 .47049 m .45185 .45953 L p
.4848 .46624 L 1 g
F P
s
P
p
.002 w
.48829 .46439 m .48837 .46577 L p
.4848 .46624 L 1 g
F P
s
P
p
.002 w
.48837 .46577 m .48897 .4763 L p
.4848 .46624 L 1 g
F P
s
P
p
.002 w
.47733 .46754 m .47754 .46719 L p
.48837 .46577 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47733 .46754 L p
1 g
F P
s
P
p
.49126 .46531 m .5 .46442 L .47733 .46754 L 1 g
F
P
p
.002 w
.48837 .46577 m .48829 .46439 L .49359 .46493 L p
1 g
F P
s
P
p
.002 w
.52408 .46807 m .52516 .46819 L .52457 .46832 L p
1 g
F P
s
P
p
.52491 .46849 m .52497 .46851 L .52492 .46849 L 1 g
F
P
p
.52491 .46849 m .52492 .46849 L .52256 .46737 L 1 g
F
P
p
.52497 .46851 m .52502 .46854 L .52498 .46852 L 1 g
F
P
p
.52497 .46851 m .52498 .46852 L .52256 .46737 L 1 g
F
P
p
.52502 .46854 m .52508 .46857 L .52503 .46855 L 1 g
F
P
p
.52502 .46854 m .52503 .46855 L .52256 .46737 L 1 g
F
P
p
.52508 .46857 m .52514 .4686 L .5251 .46858 L 1 g
F
P
p
.52508 .46857 m .5251 .46858 L .52256 .46737 L 1 g
F
P
p
.52514 .4686 m .52531 .46868 L .52522 .46863 L 1 g
F
P
p
.52514 .4686 m .52522 .46863 L .52256 .46737 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52256 .46737 L p
1 g
F P
s
P
p
.53396 .47279 m .54302 .47747 L .52256 .46737 L 1 g
F
P
p
.002 w
.52531 .46868 m .52516 .46819 L .52566 .46884 L p
1 g
F P
s
P
p
.002 w
.52749 .46971 m .52516 .46819 L p
.55657 .48346 L 1 g
F P
s
P
p
.002 w
.54234 .47673 m .54235 .47674 L p
.54202 .47658 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.53361 .47261 L 1 g
F P
s
P
p
.002 w
.52566 .46884 m .52516 .46819 L .52749 .46971 L p
1 g
F P
s
P
p
.002 w
.55086 .48502 m .55464 .48749 L .55404 .48811 L p
1 g
F P
s
P
p
.002 w
.55404 .48811 m .55464 .48749 L p
.56772 .50131 L 1 g
F P
s
P
p
.002 w
.55751 .49146 m .55834 .49233 L p
.55285 .48696 L 1 g
F P
s
P
p
.002 w
.56606 .50934 m .56713 .51061 L p
.5618 .50043 L 1 g
F P
s
P
p
.002 w
.56553 .52163 m .54624 .49617 L p
.56151 .49982 L 1 g
F P
s
P
p
.5653 .50776 m .56553 .52163 L .56151 .49982 L 1 g
F
P
p
.002 w
.5666 .50998 m .56606 .50934 L p
.56713 .51998 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5666 .50998 L p
1 g
F P
s
P
p
.56723 .52173 m .56854 .53025 L .5666 .50998 L 1 g
F
P
p
.002 w
.56553 .52163 m .56713 .51998 L p
.56722 .52154 L 1 g
F P
s
P
p
.002 w
.56735 .52402 m .56553 .52163 L p
.56722 .52154 L 1 g
F P
s
P
p
.002 w
.54463 .53256 m .56553 .52163 L .56735 .52402 L p
1 g
F P
s
P
p
.56779 .53941 m .54463 .53256 L .56735 .52402 L 1 g
F
P
p
.002 w
.56749 .52872 m .56854 .53025 L p
.5673 .52219 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56749 .52872 L p
1 g
F P
s
P
p
.56477 .53703 m .56257 .5491 L .56749 .52872 L 1 g
F
P
p
.002 w
.55215 .55952 m .54463 .53256 L p
.56433 .53838 L 1 g
F P
s
P
p
.56169 .54646 m .55215 .55952 L .56433 .53838 L 1 g
F
P
p
.002 w
.56149 .54706 m .56257 .5491 L p
.56477 .53703 L 1 g
F P
s
P
p
.55434 .55728 m .55346 .55854 L .55396 .55797 L 1 g
F
P
p
.55057 .56184 m .54942 .56366 L .55229 .56006 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54925 .5632 L p
1 g
F P
s
P
p
.54166 .56785 m .5322 .57686 L .54925 .5632 L 1 g
F
P
p
.002 w
.51862 .56503 m .55215 .55952 L .55229 .56006 L p
1 g
F P
s
P
p
.002 w
.54925 .5632 m .54942 .56366 L p
.55057 .56184 L 1 g
F P
s
P
p
.002 w
.54942 .56366 m .54998 .56518 L p
.55396 .55797 L 1 g
F P
s
P
p
.002 w
.55215 .55952 m .55314 .559 L p
.5527 .55955 L 1 g
F P
s
P
p
.002 w
.62636 .53075 m .59621 .56175 L .58236 .54371 L p
1 g
F P
s
P
p
.002 w
.59559 .31768 m .54708 .29972 L .54733 .27607 L p
1 g
F P
s
P
p
.002 w
.48865 .27486 m .54733 .27607 L .54708 .29972 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.58236 .54371 m .60609 .51928 L .62636 .53075 L p
1 g
F P
s
P
p
.002 w
.64518 .49199 m .62636 .53075 L .60609 .51928 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.38881 .49099 m .40593 .53057 L .38265 .53884 L p
1 g
F P
s
P
p
.002 w
.38265 .53884 m .36228 .49219 L .38881 .49099 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.60609 .51928 m .62086 .48873 L .64518 .49199 L p
1 g
F P
s
P
p
.002 w
.65063 .44942 m .64518 .49199 L .62086 .48873 L p
1 g
F P
s
P
p
.002 w
.40191 .34682 m .37222 .39044 L .35153 .37758 L p
1 g
F P
s
P
p
.002 w
.35153 .37758 m .38473 .32868 L .40191 .34682 L p
1 g
F P
s
P
p
.002 w
.64195 .40749 m .61983 .37071 L .63488 .35032 L p
1 g
F P
s
P
p
.002 w
.59559 .31768 m .63488 .35032 L .61983 .37071 L p
1 g
F P
s
P
p
.002 w
.54708 .29972 m .49468 .29873 L .48865 .27486 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50947 .29901 L
s
P
p
.004 w
.51073 .28151 m
.51081 .28031 L
s
P
p
.004 w
.51081 .28031 m
.51208 .26264 L
s
P
p
.002 w
.43227 .29305 m .48865 .27486 L .49468 .29873 L p
1 g
F P
s
P
p
.002 w
.44436 .31502 m .40191 .34682 L .38473 .32868 L p
1 g
F P
s
P
p
.002 w
.38473 .32868 m .43227 .29305 L .44436 .31502 L p
1 g
F P
s
P
p
.002 w
.49468 .29873 m .44436 .31502 L .43227 .29305 L p
1 g
F P
s
P
p
.002 w
.62086 .48873 m .62506 .45523 L .65063 .44942 L p
1 g
F P
s
P
p
.002 w
.64195 .40749 m .65063 .44942 L .62506 .45523 L p
1 g
F P
s
P
p
.002 w
.3858 .44751 m .38881 .49099 L .36228 .49219 L p
1 g
F P
s
P
p
.002 w
.36228 .49219 m .35857 .44082 L .3858 .44751 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61983 .37071 m .58647 .34318 L .59559 .31768 L p
1 g
F P
s
P
p
.002 w
.54708 .29972 m .59559 .31768 L .58647 .34318 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.62506 .45523 m .61813 .42232 L .64195 .40749 L p
1 g
F P
s
P
p
.002 w
.61983 .37071 m .64195 .40749 L .61813 .42232 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.39746 .40492 m .3858 .44751 L .35857 .44082 L p
1 g
F P
s
P
p
.002 w
.35857 .44082 m .37222 .39044 L .39746 .40492 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.52143 .53633 m .54463 .53256 L .55215 .55952 L p
1 g
F P
s
P
p
.002 w
.55215 .55952 m .51862 .56503 L .52143 .53633 L p
1 g
F P
s
P
p
.002 w
.58647 .34318 m .54537 .32811 L .54708 .29972 L p
1 g
F P
s
P
p
.002 w
.49468 .29873 m .54708 .29972 L .54537 .32811 L p
1 g
F P
s
P
p
.002 w
.62086 .48873 m .60609 .51928 L .58193 .50472 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40593 .53057 m .38881 .49099 L .41949 .4879 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49839 .53253 m .52143 .53633 L .51862 .56503 L p
1 g
F P
s
P
p
.002 w
.51862 .56503 m .48524 .55961 L .49839 .53253 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.58193 .50472 m .5921 .48358 L .62086 .48873 L p
1 g
F P
s
P
p
.002 w
.62506 .45523 m .62086 .48873 L .5921 .48358 L p
1 g
F P
s
P
p
.002 w
.61813 .42232 m .60066 .39353 L .61983 .37071 L p
1 g
F P
s
P
p
.002 w
.58647 .34318 m .61983 .37071 L .60066 .39353 L p
1 g
F P
s
P
p
.002 w
.42262 .36807 m .39746 .40492 L .37222 .39044 L p
1 g
F P
s
P
p
.002 w
.37222 .39044 m .40191 .34682 L .42262 .36807 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.54537 .32811 m .50105 .32738 L .49468 .29873 L p
1 g
F P
s
P
p
.002 w
.44436 .31502 m .49468 .29873 L .50105 .32738 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.47795 .5215 m .49839 .53253 L .48524 .55961 L p
1 g
F P
s
P
p
.002 w
.48524 .55961 m .45555 .54374 L .47795 .5215 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.45852 .3412 m .42262 .36807 L .40191 .34682 L p
1 g
F P
s
P
p
.002 w
.40191 .34682 m .44436 .31502 L .45852 .3412 L p
1 g
F P
s
P
p
.002 w
.50105 .32738 m .45852 .3412 L .44436 .31502 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5921 .48358 m .59493 .46044 L .62506 .45523 L p
1 g
F P
s
P
p
.002 w
.61813 .42232 m .62506 .45523 L .59493 .46044 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.41726 .45383 m .41949 .4879 L .38881 .49099 L p
1 g
F P
s
P
p
.002 w
.38881 .49099 m .3858 .44751 L .41726 .45383 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.60066 .39353 m .57443 .37206 L .58647 .34318 L p
1 g
F P
s
P
p
.002 w
.54537 .32811 m .58647 .34318 L .57443 .37206 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46234 .50437 m .47795 .5215 L .45555 .54374 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.59493 .46044 m .59006 .43776 L .61813 .42232 L p
1 g
F P
s
P
p
.002 w
.60066 .39353 m .61813 .42232 L .59006 .43776 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.42648 .42053 m .41726 .45383 L .3858 .44751 L p
1 g
F P
s
P
p
.002 w
.3858 .44751 m .39746 .40492 L .42648 .42053 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.53553 .50176 m .54624 .49617 L .56553 .52163 L p
1 g
F P
s
P
p
.002 w
.56553 .52163 m .54463 .53256 L .53553 .50176 L p
1 g
F P
s
P
p
.002 w
.57443 .37206 m .54221 .36037 L .54537 .32811 L p
1 g
F P
s
P
p
.002 w
.50105 .32738 m .54537 .32811 L .54221 .36037 L p
1 g
F P
s
P
p
.002 w
.52365 .50367 m .53553 .50176 L .54463 .53256 L p
1 g
F P
s
P
p
.002 w
.54463 .53256 m .52143 .53633 L .52365 .50367 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.5921 .48358 m .58193 .50472 L .55464 .48749 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51187 .50168 m .52365 .50367 L .52143 .53633 L p
1 g
F P
s
P
p
.002 w
.52143 .53633 m .49839 .53253 L .51187 .50168 L p
1 g
F P
s
P
p
.002 w
.59006 .43776 m .57795 .41799 L .60066 .39353 L p
1 g
F P
s
P
p
.002 w
.57443 .37206 m .60066 .39353 L .57795 .41799 L p
1 g
F P
s
P
p
.002 w
.55464 .48749 m .55982 .47666 L .5921 .48358 L p
1 g
F P
s
P
p
.002 w
.59493 .46044 m .5921 .48358 L .55982 .47666 L p
1 g
F P
s
P
p
.002 w
.44621 .39174 m .42648 .42053 L .39746 .40492 L p
1 g
F P
s
P
p
.002 w
.39746 .40492 m .42262 .36807 L .44621 .39174 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.54221 .36037 m .50754 .35988 L .50105 .32738 L p
1 g
F P
s
P
p
.002 w
.45852 .3412 m .50105 .32738 L .50754 .35988 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.50145 .49601 m .51187 .50168 L .49839 .53253 L p
1 g
F P
s
P
p
.002 w
.49839 .53253 m .47795 .5215 L .50145 .49601 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55982 .47666 m .56122 .46482 L .59493 .46044 L p
1 g
F P
s
P
p
.002 w
.59006 .43776 m .59493 .46044 L .56122 .46482 L p
1 g
F P
s
P
p
.002 w
.47428 .37073 m .44621 .39174 L .42262 .36807 L p
1 g
F P
s
P
p
.002 w
.42262 .36807 m .45852 .3412 L .47428 .37073 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.41949 .4879 m .41726 .45383 L .45185 .45953 L p
1 g
F P
s
P
p
.002 w
.50754 .35988 m .47428 .37073 L .45852 .3412 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57795 .41799 m .55984 .40331 L .57443 .37206 L p
1 g
F P
s
P
p
.002 w
.54221 .36037 m .57443 .37206 L .55984 .40331 L p
1 g
F P
s
P
p
.002 w
.49353 .48723 m .50145 .49601 L .47795 .5215 L p
1 g
F P
s
P
p
.002 w
.47795 .5215 m .46234 .50437 L .49353 .48723 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.56122 .46482 m .55868 .45325 L .59006 .43776 L p
1 g
F P
s
P
p
.002 w
.57795 .41799 m .59006 .43776 L .55868 .45325 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.45825 .4367 m .45185 .45953 L .41726 .45383 L p
1 g
F P
s
P
p
.002 w
.41726 .45383 m .42648 .42053 L .45825 .4367 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48897 .4763 m .49353 .48723 L .46234 .50437 L p
1 g
F P
s
P
p
.002 w
.46234 .50437 m .45329 .48295 L .48897 .4763 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55984 .40331 m .53768 .39537 L .54221 .36037 L p
1 g
F P
s
P
p
.002 w
.50754 .35988 m .54221 .36037 L .53768 .39537 L p
1 g
F P
s
P
p
.002 w
.55868 .45325 m .55246 .4432 L .57795 .41799 L p
1 g
F P
s
P
p
.002 w
.55984 .40331 m .57795 .41799 L .55246 .4432 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56122 .46482 m .55982 .47666 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.47182 .41697 m .45825 .4367 L .42648 .42053 L p
1 g
F P
s
P
p
.002 w
.42648 .42053 m .44621 .39174 L .47182 .41697 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.53768 .39537 m .51388 .39509 L .50754 .35988 L p
1 g
F P
s
P
p
.002 w
.47428 .37073 m .50754 .35988 L .51388 .39509 L p
1 g
F P
s
P
p
.002 w
.55868 .45325 m .56122 .46482 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49108 .40257 m .47182 .41697 L .44621 .39174 L p
1 g
F P
s
P
p
.002 w
.44621 .39174 m .47428 .37073 L .49108 .40257 L p
1 g
F P
s
P
p
.002 w
.55246 .4432 m .54321 .43577 L .55984 .40331 L p
1 g
F P
s
P
p
.002 w
.53768 .39537 m .55984 .40331 L .54321 .43577 L p
1 g
F P
s
P
p
.002 w
.51388 .39509 m .49108 .40257 L .47428 .37073 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.55246 .4432 m .55868 .45325 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49158 .45279 m .48829 .46439 L .45185 .45953 L p
1 g
F P
s
P
p
.002 w
.45185 .45953 m .45825 .4367 L .49158 .45279 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.54321 .43577 m .55246 .4432 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54321 .43577 m .53192 .43178 L .53768 .39537 L p
1 g
F P
s
P
p
.002 w
.51388 .39509 m .53768 .39537 L .53192 .43178 L p
1 g
F P
s
P
p
.002 w
.49849 .44279 m .50827 .43548 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50497 .43795 L
s
P
p
.002 w
.53192 .43178 m .54321 .43577 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.51983 .43168 m .53192 .43178 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.50827 .43548 m .51983 .43168 L .52516 .46819 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49849 .44279 m .49158 .45279 L .45825 .4367 L p
1 g
F P
s
P
p
.002 w
.45825 .4367 m .47182 .41697 L .49849 .44279 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53192 .43178 m .51983 .43168 L .51388 .39509 L p
1 g
F P
s
P
p
.002 w
.49108 .40257 m .51388 .39509 L .51983 .43168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50827 .43548 m .49849 .44279 L .47182 .41697 L p
1 g
F P
s
P
p
.002 w
.47182 .41697 m .49108 .40257 L .50827 .43548 L p
1 g
F P
s
P
p
.002 w
.51983 .43168 m .50827 .43548 L .49108 .40257 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.52516 .46819 m
.54076 .49154 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .51718 .19192 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .54076 .49154 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.558915)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.558915)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4999 .45935 m .52085 .44212 L .49958 .42309 L p
1 g
F P
s
P
p
.002 w
.49958 .42309 m .48529 .43481 L .4999 .45935 L p
1 g
F P
s
P
p
.002 w
.50958 .40759 m .49958 .42309 L .52085 .44212 L p
1 g
F P
s
P
p
.002 w
.48529 .43481 m .49958 .42309 L .47829 .40421 L p
1 g
F P
s
P
p
.002 w
.49958 .42309 m .50958 .40759 L .48336 .39633 L p
1 g
F P
s
P
p
.002 w
.48336 .39633 m .47829 .40421 L .49958 .42309 L p
1 g
F P
s
P
p
.002 w
.47484 .4693 m .4999 .45935 L .48529 .43481 L p
1 g
F P
s
P
p
.002 w
.48529 .43481 m .46821 .44155 L .47484 .4693 L p
1 g
F P
s
P
p
.002 w
.46821 .44155 m .48529 .43481 L .47103 .41016 L p
1 g
F P
s
P
p
.002 w
.47829 .40421 m .47103 .41016 L .48529 .43481 L p
1 g
F P
s
P
p
.002 w
.51459 .48331 m .54173 .46098 L .52085 .44212 L p
1 g
F P
s
P
p
.002 w
.52085 .44212 m .4999 .45935 L .51459 .48331 L p
1 g
F P
s
P
p
.002 w
.53557 .41941 m .52085 .44212 L .54173 .46098 L p
1 g
F P
s
P
p
.002 w
.52085 .44212 m .53557 .41941 L .50958 .40759 L p
1 g
F P
s
P
p
.002 w
.51423 .38994 m .50958 .40759 L .53557 .41941 L p
1 g
F P
s
P
p
.002 w
.50958 .40759 m .51423 .38994 L .48569 .38736 L p
1 g
F P
s
P
p
.002 w
.48569 .38736 m .48336 .39633 L .50958 .40759 L p
1 g
F P
s
P
p
.002 w
.48214 .49631 m .51459 .48331 L .4999 .45935 L p
1 g
F P
s
P
p
.002 w
.4999 .45935 m .47484 .4693 L .48214 .49631 L p
1 g
F P
s
P
p
.002 w
.44824 .47091 m .47484 .4693 L .46821 .44155 L p
1 g
F P
s
P
p
.002 w
.46821 .44155 m .4501 .44256 L .44824 .47091 L p
1 g
F P
s
P
p
.002 w
.4501 .44256 m .46821 .44155 L .46235 .41356 L p
1 g
F P
s
P
p
.002 w
.47103 .41016 m .46235 .41356 L .46821 .44155 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .47103 .41016 L .47829 .40421 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .47829 .40421 L .48336 .39633 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .46235 .41356 L .47103 .41016 L closepath p
1 g
F P
s
P
p
.002 w
.54173 .46098 m .56085 .43157 L .53557 .41941 L p
1 g
F P
s
P
p
.002 w
.5425 .39351 m .53557 .41941 L .56085 .43157 L p
1 g
F P
s
P
p
.002 w
.53557 .41941 m .5425 .39351 L .51423 .38994 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .48336 .39633 L .48569 .38736 L closepath p
1 g
F P
s
P
p
.002 w
.46235 .41356 m .45316 .41403 L .4501 .44256 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .45316 .41403 L .46235 .41356 L closepath p
1 g
F P
s
P
p
.002 w
.51302 .37197 m .51423 .38994 L .5425 .39351 L p
1 g
F P
s
P
p
.002 w
.51423 .38994 m .51302 .37197 L .48502 .37826 L p
1 g
F P
s
P
p
.002 w
.48502 .37826 m .48569 .38736 L .51423 .38994 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .48569 .38736 L .48502 .37826 L closepath p
1 g
F P
s
P
p
.002 w
.44762 .49855 m .48214 .49631 L .47484 .4693 L p
1 g
F P
s
P
p
.002 w
.47484 .4693 m .44824 .47091 L .44762 .49855 L p
1 g
F P
s
P
p
.002 w
.43287 .4377 m .4501 .44256 L .45316 .41403 L p
1 g
F P
s
P
p
.002 w
.45316 .41403 m .44446 .41151 L .43287 .4377 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .44446 .41151 L .45316 .41403 L closepath p
1 g
F P
s
P
p
.002 w
.42284 .4639 m .44824 .47091 L .4501 .44256 L p
1 g
F P
s
P
p
.002 w
.4501 .44256 m .43287 .4377 L .42284 .4639 L p
1 g
F P
s
P
p
.002 w
.52909 .50627 m .56183 .47931 L .54173 .46098 L p
1 g
F P
s
P
p
.002 w
.54173 .46098 m .51459 .48331 L .52909 .50627 L p
1 g
F P
s
P
p
.002 w
.56085 .43157 m .54173 .46098 L .56183 .47931 L p
1 g
F P
s
P
p
.002 w
.48141 .37 m .48502 .37826 L .51302 .37197 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .48502 .37826 L .48141 .37 L closepath p
1 g
F P
s
P
p
.002 w
.48996 .52206 m .52909 .50627 L .51459 .48331 L p
1 g
F P
s
P
p
.002 w
.51459 .48331 m .48214 .49631 L .48996 .52206 L p
1 g
F P
s
P
p
.002 w
.56085 .43157 m .56997 .39801 L .5425 .39351 L p
1 g
F P
s
P
p
.002 w
.54086 .36708 m .5425 .39351 L .56997 .39801 L p
1 g
F P
s
P
p
.002 w
.5425 .39351 m .54086 .36708 L .51302 .37197 L p
1 g
F P
s
P
p
.002 w
.41838 .4274 m .43287 .4377 L .44446 .41151 L p
1 g
F P
s
P
p
.002 w
.44446 .41151 m .43717 .40625 L .41838 .4274 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .43717 .40625 L .44446 .41151 L closepath p
1 g
F P
s
P
p
.002 w
.506 .3556 m .51302 .37197 L .54086 .36708 L p
1 g
F P
s
P
p
.002 w
.51302 .37197 m .506 .3556 L .48141 .37 L p
1 g
F P
s
P
p
.002 w
.56183 .47931 m .58496 .44385 L .56085 .43157 L p
1 g
F P
s
P
p
.002 w
.56997 .39801 m .56085 .43157 L .58496 .44385 L p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .45802 .35828 L .44885 .3602 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .44885 .3602 L .44065 .36497 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .44065 .36497 L .43433 .37208 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .43433 .37208 L .43058 .38074 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .43058 .38074 L .42982 .38999 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .42982 .38999 L .4321 .39882 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .4321 .39882 L .43717 .40625 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .48141 .37 L .47524 .36348 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .47524 .36348 L .46715 .35942 L closepath p
1 g
F P
s
P
p
.002 w
.45737 .38582 m .46715 .35942 L .45802 .35828 L closepath p
1 g
F P
s
P
p
.002 w
.47524 .36348 m .48141 .37 L .506 .3556 L p
1 g
F P
s
P
p
.002 w
.41458 .48964 m .44762 .49855 L .44824 .47091 L p
1 g
F P
s
P
p
.002 w
.44824 .47091 m .42284 .4639 L .41458 .48964 L p
1 g
F P
s
P
p
.002 w
.40823 .41273 m .41838 .4274 L .43717 .40625 L p
1 g
F P
s
P
p
.002 w
.43717 .40625 m .4321 .39882 L .40823 .41273 L p
1 g
F P
s
P
p
.002 w
.40138 .44887 m .42284 .4639 L .43287 .4377 L p
1 g
F P
s
P
p
.002 w
.43287 .4377 m .41838 .4274 L .40138 .44887 L p
1 g
F P
s
P
p
.002 w
.44829 .52495 m .48996 .52206 L .48214 .49631 L p
1 g
F P
s
P
p
.002 w
.48214 .49631 m .44762 .49855 L .44829 .52495 L p
1 g
F P
s
P
p
.002 w
.506 .3556 m .49386 .3426 L .47524 .36348 L p
1 g
F P
s
P
p
.002 w
.46715 .35942 m .47524 .36348 L .49386 .3426 L p
1 g
F P
s
P
p
.002 w
.40359 .39522 m .40823 .41273 L .4321 .39882 L p
1 g
F P
s
P
p
.002 w
.4321 .39882 m .42982 .38999 L .40359 .39522 L p
1 g
F P
s
P
p
.002 w
.54086 .36708 m .53067 .34289 L .506 .3556 L p
1 g
F P
s
P
p
.002 w
.49386 .3426 m .506 .3556 L .53067 .34289 L p
1 g
F P
s
P
p
.002 w
.56997 .39801 m .56801 .36368 L .54086 .36708 L p
1 g
F P
s
P
p
.002 w
.53067 .34289 m .54086 .36708 L .56801 .36368 L p
1 g
F P
s
P
p
.002 w
.58496 .44385 m .59611 .40337 L .56997 .39801 L p
1 g
F P
s
P
p
.002 w
.56801 .36368 m .56997 .39801 L .59611 .40337 L p
1 g
F P
s
P
p
.002 w
.49386 .3426 m .47786 .33444 L .46715 .35942 L p
1 g
F P
s
P
p
.002 w
.45802 .35828 m .46715 .35942 L .47786 .33444 L p
1 g
F P
s
P
p
.002 w
.54314 .52777 m .58076 .49675 L .56183 .47931 L p
1 g
F P
s
P
p
.002 w
.56183 .47931 m .52909 .50627 L .54314 .52777 L p
1 g
F P
s
P
p
.002 w
.58496 .44385 m .56183 .47931 L .58076 .49675 L p
1 g
F P
s
P
p
.002 w
.40504 .37681 m .40359 .39522 L .42982 .38999 L p
1 g
F P
s
P
p
.002 w
.42982 .38999 m .43058 .38074 L .40504 .37681 L p
1 g
F P
s
P
p
.002 w
.49819 .54603 m .54314 .52777 L .52909 .50627 L p
1 g
F P
s
P
p
.002 w
.52909 .50627 m .48996 .52206 L .49819 .54603 L p
1 g
F P
s
P
p
.002 w
.38625 .4273 m .40138 .44887 L .41838 .4274 L p
1 g
F P
s
P
p
.002 w
.41838 .4274 m .40823 .41273 L .38625 .4273 L p
1 g
F P
s
P
p
.002 w
.44885 .3602 m .45802 .35828 L .45972 .33208 L p
1 g
F P
s
P
p
.002 w
.47786 .33444 m .45972 .33208 L .45802 .35828 L p
1 g
F P
s
P
p
.002 w
.38654 .47027 m .41458 .48964 L .42284 .4639 L p
1 g
F P
s
P
p
.002 w
.42284 .4639 m .40138 .44887 L .38654 .47027 L p
1 g
F P
s
P
p
.002 w
.41247 .35953 m .40504 .37681 L .43058 .38074 L p
1 g
F P
s
P
p
.002 w
.43058 .38074 m .43433 .37208 L .41247 .35953 L p
1 g
F P
s
P
p
.002 w
.40829 .5144 m .44829 .52495 L .44762 .49855 L p
1 g
F P
s
P
p
.002 w
.44762 .49855 m .41458 .48964 L .40829 .5144 L p
1 g
F P
s
P
p
.002 w
.58076 .49675 m .60741 .45603 L .58496 .44385 L p
1 g
F P
s
P
p
.002 w
.59611 .40337 m .58496 .44385 L .60741 .45603 L p
1 g
F P
s
P
p
.002 w
.45972 .33208 m .44144 .33584 L .44885 .3602 L p
1 g
F P
s
P
p
.002 w
.44065 .36497 m .44885 .3602 L .44144 .33584 L p
1 g
F P
s
P
p
.002 w
.42508 .34534 m .41247 .35953 L .43433 .37208 L p
1 g
F P
s
P
p
.002 w
.43433 .37208 m .44065 .36497 L .42508 .34534 L p
1 g
F P
s
P
p
.002 w
.53067 .34289 m .5129 .3236 L .49386 .3426 L p
1 g
F P
s
P
p
.002 w
.47786 .33444 m .49386 .3426 L .5129 .3236 L p
1 g
F P
s
P
p
.002 w
.44144 .33584 m .42508 .34534 L .44065 .36497 L p
1 g
F P
s
P
p
.002 w
.45027 .54955 m .49819 .54603 L .48996 .52206 L p
1 g
F P
s
P
p
.002 w
.48996 .52206 m .44829 .52495 L .45027 .54955 L p
1 g
F P
s
P
p
.002 w
.56801 .36368 m .55497 .33216 L .53067 .34289 L p
1 g
F P
s
P
p
.002 w
.5129 .3236 m .53067 .34289 L .55497 .33216 L p
1 g
F P
s
P
p
.002 w
.37924 .40144 m .38625 .4273 L .40823 .41273 L p
1 g
F P
s
P
p
.002 w
.40823 .41273 m .40359 .39522 L .37924 .40144 L p
1 g
F P
s
P
p
.002 w
.59611 .40337 m .59396 .36189 L .56801 .36368 L p
1 g
F P
s
P
p
.002 w
.55497 .33216 m .56801 .36368 L .59396 .36189 L p
1 g
F P
s
P
p
.002 w
.5129 .3236 m .48932 .31139 L .47786 .33444 L p
1 g
F P
s
P
p
.002 w
.45972 .33208 m .47786 .33444 L .48932 .31139 L p
1 g
F P
s
P
p
.002 w
.60741 .45603 m .62039 .40952 L .59611 .40337 L p
1 g
F P
s
P
p
.002 w
.59396 .36189 m .59611 .40337 L .62039 .40952 L p
1 g
F P
s
P
p
.002 w
.36665 .44227 m .38654 .47027 L .40138 .44887 L p
1 g
F P
s
P
p
.002 w
.40138 .44887 m .38625 .4273 L .36665 .44227 L p
1 g
F P
s
P
p
.002 w
.38128 .37412 m .37924 .40144 L .40359 .39522 L p
1 g
F P
s
P
p
.002 w
.40359 .39522 m .40504 .37681 L .38128 .37412 L p
1 g
F P
s
P
p
.002 w
.37421 .49115 m .40829 .5144 L .41458 .48964 L p
1 g
F P
s
P
p
.002 w
.41458 .48964 m .38654 .47027 L .37421 .49115 L p
1 g
F P
s
P
p
.002 w
.55643 .54734 m .59811 .51295 L .58076 .49675 L p
1 g
F P
s
P
p
.002 w
.58076 .49675 m .54314 .52777 L .55643 .54734 L p
1 g
F P
s
P
p
.002 w
.60741 .45603 m .58076 .49675 L .59811 .51295 L p
1 g
F P
s
P
p
.002 w
.44144 .33584 m .45972 .33208 L .46247 .30776 L p
1 g
F P
s
P
p
.002 w
.48932 .31139 m .46247 .30776 L .45972 .33208 L p
1 g
F P
s
P
p
.002 w
.50667 .56769 m .55643 .54734 L .54314 .52777 L p
1 g
F P
s
P
p
.002 w
.54314 .52777 m .49819 .54603 L .50667 .56769 L p
1 g
F P
s
P
p
.002 w
.40416 .53764 m .45027 .54955 L .44829 .52495 L p
1 g
F P
s
P
p
.002 w
.44829 .52495 m .40829 .5144 L .40416 .53764 L p
1 g
F P
s
P
p
.002 w
.55497 .33216 m .53198 .30689 L .5129 .3236 L p
1 g
F P
s
P
p
.002 w
.48932 .31139 m .5129 .3236 L .53198 .30689 L p
1 g
F P
s
P
p
.002 w
.39226 .34844 m .38128 .37412 L .40504 .37681 L p
1 g
F P
s
P
p
.002 w
.40504 .37681 m .41247 .35953 L .39226 .34844 L p
1 g
F P
s
P
p
.002 w
.59811 .51295 m .62771 .46787 L .60741 .45603 L p
1 g
F P
s
P
p
.002 w
.62039 .40952 m .60741 .45603 L .62771 .46787 L p
1 g
F P
s
P
p
.002 w
.46247 .30776 m .43532 .31326 L .44144 .33584 L p
1 g
F P
s
P
p
.002 w
.42508 .34534 m .44144 .33584 L .43532 .31326 L p
1 g
F P
s
P
p
.002 w
.59396 .36189 m .57841 .32367 L .55497 .33216 L p
1 g
F P
s
P
p
.002 w
.53198 .30689 m .55497 .33216 L .57841 .32367 L p
1 g
F P
s
P
p
.002 w
.41098 .32734 m .39226 .34844 L .41247 .35953 L p
1 g
F P
s
P
p
.002 w
.41247 .35953 m .42508 .34534 L .41098 .32734 L p
1 g
F P
s
P
p
.002 w
.43532 .31326 m .41098 .32734 L .42508 .34534 L p
1 g
F P
s
P
p
.002 w
.35733 .40855 m .36665 .44227 L .38625 .4273 L p
1 g
F P
s
P
p
.002 w
.38625 .4273 m .37924 .40144 L .35733 .40855 L p
1 g
F P
s
P
p
.002 w
.45356 .57179 m .50667 .56769 L .49819 .54603 L p
1 g
F P
s
P
p
.002 w
.49819 .54603 m .45027 .54955 L .45356 .57179 L p
1 g
F P
s
P
p
.002 w
.62039 .40952 m .61813 .36177 L .59396 .36189 L p
1 g
F P
s
P
p
.002 w
.57841 .32367 m .59396 .36189 L .61813 .36177 L p
1 g
F P
s
P
p
.002 w
.53198 .30689 m .50132 .29079 L .48932 .31139 L p
1 g
F P
s
P
p
.002 w
.46247 .30776 m .48932 .31139 L .50132 .29079 L p
1 g
F P
s
P
p
.002 w
.34991 .45734 m .37421 .49115 L .38654 .47027 L p
1 g
F P
s
P
p
.002 w
.38654 .47027 m .36665 .44227 L .34991 .45734 L p
1 g
F P
s
P
p
.002 w
.62771 .46787 m .64225 .41636 L .62039 .40952 L p
1 g
F P
s
P
p
.002 w
.61813 .36177 m .62039 .40952 L .64225 .41636 L p
1 g
F P
s
P
p
.002 w
.35987 .3728 m .35733 .40855 L .37924 .40144 L p
1 g
F P
s
P
p
.002 w
.37924 .40144 m .38128 .37412 L .35987 .3728 L p
1 g
F P
s
P
p
.002 w
.36475 .51106 m .40416 .53764 L .40829 .5144 L p
1 g
F P
s
P
p
.002 w
.40829 .5144 m .37421 .49115 L .36475 .51106 L p
1 g
F P
s
P
p
.002 w
.57841 .32367 m .55074 .29289 L .53198 .30689 L p
1 g
F P
s
P
p
.002 w
.50132 .29079 m .53198 .30689 L .55074 .29289 L p
1 g
F P
s
P
p
.002 w
.56868 .56451 m .61347 .52752 L .59811 .51295 L p
1 g
F P
s
P
p
.002 w
.59811 .51295 m .55643 .54734 L .56868 .56451 L p
1 g
F P
s
P
p
.002 w
.62771 .46787 m .59811 .51295 L .61347 .52752 L p
1 g
F P
s
P
p
.002 w
.43532 .31326 m .46247 .30776 L .46623 .2859 L p
1 g
F P
s
P
p
.002 w
.50132 .29079 m .46623 .2859 L .46247 .30776 L p
1 g
F P
s
P
p
.002 w
.40237 .55881 m .45356 .57179 L .45027 .54955 L p
1 g
F P
s
P
p
.002 w
.45027 .54955 m .40416 .53764 L .40237 .55881 L p
1 g
F P
s
P
p
.002 w
.51523 .58649 m .56868 .56451 L .55643 .54734 L p
1 g
F P
s
P
p
.002 w
.55643 .54734 m .50667 .56769 L .51523 .58649 L p
1 g
F P
s
P
p
.002 w
.37419 .33911 m .35987 .3728 L .38128 .37412 L p
1 g
F P
s
P
p
.002 w
.38128 .37412 m .39226 .34844 L .37419 .33911 L p
1 g
F P
s
P
p
.002 w
.61813 .36177 m .60046 .31766 L .57841 .32367 L p
1 g
F P
s
P
p
.002 w
.55074 .29289 m .57841 .32367 L .60046 .31766 L p
1 g
F P
s
P
p
.002 w
.61347 .52752 m .64535 .4791 L .62771 .46787 L p
1 g
F P
s
P
p
.002 w
.64225 .41636 m .62771 .46787 L .64535 .4791 L p
1 g
F P
s
P
p
.002 w
.33841 .41644 m .34991 .45734 L .36665 .44227 L p
1 g
F P
s
P
p
.002 w
.36665 .44227 m .35733 .40855 L .33841 .41644 L p
1 g
F P
s
P
p
.002 w
.46623 .2859 m .43067 .29299 L .43532 .31326 L p
1 g
F P
s
P
p
.002 w
.41098 .32734 m .43532 .31326 L .43067 .29299 L p
1 g
F P
s
P
p
.002 w
.39873 .31143 m .37419 .33911 L .39226 .34844 L p
1 g
F P
s
P
p
.002 w
.39226 .34844 m .41098 .32734 L .39873 .31143 L p
1 g
F P
s
P
p
.002 w
.43067 .29299 m .39873 .31143 L .41098 .32734 L p
1 g
F P
s
P
p
.002 w
.64225 .41636 m .63997 .36341 L .61813 .36177 L p
1 g
F P
s
P
p
.002 w
.60046 .31766 m .61813 .36177 L .63997 .36341 L p
1 g
F P
s
P
p
.002 w
.45815 .59108 m .51523 .58649 L .50667 .56769 L p
1 g
F P
s
P
p
.002 w
.50667 .56769 m .45356 .57179 L .45815 .59108 L p
1 g
F P
s
P
p
.002 w
.33653 .4722 m .36475 .51106 L .37421 .49115 L p
1 g
F P
s
P
p
.002 w
.37421 .49115 m .34991 .45734 L .33653 .4722 L p
1 g
F P
s
P
p
.002 w
.55074 .29289 m .51363 .27317 L .50132 .29079 L p
1 g
F P
s
P
p
.002 w
.46623 .2859 m .50132 .29079 L .51363 .27317 L p
1 g
F P
s
P
p
.002 w
.64535 .4791 m .66113 .42377 L .64225 .41636 L p
1 g
F P
s
P
p
.002 w
.63997 .36341 m .64225 .41636 L .66113 .42377 L p
1 g
F P
s
P
p
.002 w
.3585 .52953 m .40237 .55881 L .40416 .53764 L p
1 g
F P
s
P
p
.002 w
.40416 .53764 m .36475 .51106 L .3585 .52953 L p
1 g
F P
s
P
p
.002 w
.34137 .37292 m .33841 .41644 L .35733 .40855 L p
1 g
F P
s
P
p
.002 w
.35733 .40855 m .35987 .3728 L .34137 .37292 L p
1 g
F P
s
P
p
.002 w
.60046 .31766 m .56875 .28201 L .55074 .29289 L p
1 g
F P
s
P
p
.002 w
.51363 .27317 m .55074 .29289 L .56875 .28201 L p
1 g
F P
s
P
p
.002 w
.51363 .27317 m .47099 .26706 L .46623 .2859 L p
1 g
F P
s
P
p
.002 w
.43067 .29299 m .46623 .2859 L .47099 .26706 L p
1 g
F P
s
P
p
.002 w
.40307 .57735 m .45815 .59108 L .45356 .57179 L p
1 g
F P
s
P
p
.002 w
.45356 .57179 m .40237 .55881 L .40307 .57735 L p
1 g
F P
s
P
p
.002 w
.57957 .5788 m .62642 .54008 L .61347 .52752 L p
1 g
F P
s
P
p
.002 w
.61347 .52752 m .56868 .56451 L .57957 .5788 L p
1 g
F P
s
P
p
.002 w
.64535 .4791 m .61347 .52752 L .62642 .54008 L p
1 g
F P
s
P
p
.002 w
.52368 .60189 m .57957 .5788 L .56868 .56451 L p
1 g
F P
s
P
p
.002 w
.56868 .56451 m .51523 .58649 L .52368 .60189 L p
1 g
F P
s
P
p
.002 w
.63997 .36341 m .62061 .31439 L .60046 .31766 L p
1 g
F P
s
P
p
.002 w
.56875 .28201 m .60046 .31766 L .62061 .31439 L p
1 g
F P
s
P
p
.002 w
.35875 .33183 m .34137 .37292 L .35987 .3728 L p
1 g
F P
s
P
p
.002 w
.35987 .3728 m .37419 .33911 L .35875 .33183 L p
1 g
F P
s
P
p
.002 w
.32305 .42497 m .33653 .4722 L .34991 .45734 L p
1 g
F P
s
P
p
.002 w
.34991 .45734 m .33841 .41644 L .32305 .42497 L p
1 g
F P
s
P
p
.002 w
.62642 .54008 m .65983 .48945 L .64535 .4791 L p
1 g
F P
s
P
p
.002 w
.66113 .42377 m .64535 .4791 L .65983 .48945 L p
1 g
F P
s
P
p
.002 w
.47099 .26706 m .42765 .27561 L .43067 .29299 L p
1 g
F P
s
P
p
.002 w
.39873 .31143 m .43067 .29299 L .42765 .27561 L p
1 g
F P
s
P
p
.002 w
.66113 .42377 m .65889 .36684 L .63997 .36341 L p
1 g
F P
s
P
p
.002 w
.62061 .31439 m .63997 .36341 L .65889 .36684 L p
1 g
F P
s
P
p
.002 w
.38868 .29805 m .35875 .33183 L .37419 .33911 L p
1 g
F P
s
P
p
.002 w
.37419 .33911 m .39873 .31143 L .38868 .29805 L p
1 g
F P
s
P
p
.002 w
.42765 .27561 m .38868 .29805 L .39873 .31143 L p
1 g
F P
s
P
p
.002 w
.46401 .60685 m .52368 .60189 L .51523 .58649 L p
1 g
F P
s
P
p
.002 w
.51523 .58649 m .45815 .59108 L .46401 .60685 L p
1 g
F P
s
P
p
.002 w
.32698 .48648 m .3585 .52953 L .36475 .51106 L p
1 g
F P
s
P
p
.002 w
.36475 .51106 m .33653 .4722 L .32698 .48648 L p
1 g
F P
s
P
p
.002 w
.56875 .28201 m .52599 .25906 L .51363 .27317 L p
1 g
F P
s
P
p
.002 w
.47099 .26706 m .51363 .27317 L .52599 .25906 L p
1 g
F P
s
P
p
.002 w
.35577 .54603 m .40307 .57735 L .40237 .55881 L p
1 g
F P
s
P
p
.002 w
.40237 .55881 m .3585 .52953 L .35577 .54603 L p
1 g
F P
s
P
p
.002 w
.65983 .48945 m .67646 .43161 L .66113 .42377 L p
1 g
F P
s
P
p
.002 w
.65889 .36684 m .66113 .42377 L .67646 .43161 L p
1 g
F P
s
P
p
.002 w
.32636 .37456 m .32305 .42497 L .33841 .41644 L p
1 g
F P
s
P
p
.002 w
.33841 .41644 m .34137 .37292 L .32636 .37456 L p
1 g
F P
s
P
p
.002 w
.62061 .31439 m .58557 .27466 L .56875 .28201 L p
1 g
F P
s
P
p
.002 w
.52599 .25906 m .56875 .28201 L .58557 .27466 L p
1 g
F P
s
P
p
.002 w
.40637 .59266 m .46401 .60685 L .45815 .59108 L p
1 g
F P
s
P
p
.002 w
.45815 .59108 m .40307 .57735 L .40637 .59266 L p
1 g
F P
s
P
p
.002 w
.52599 .25906 m .47669 .25184 L .47099 .26706 L p
1 g
F P
s
P
p
.002 w
.42765 .27561 m .47099 .26706 L .47669 .25184 L p
1 g
F P
s
P
p
.002 w
.58877 .58972 m .63653 .55023 L .62642 .54008 L p
1 g
F P
s
P
p
.002 w
.62642 .54008 m .57957 .5788 L .58877 .58972 L p
1 g
F P
s
P
p
.002 w
.65983 .48945 m .62642 .54008 L .63653 .55023 L p
1 g
F P
s
P
p
.002 w
.65889 .36684 m .63828 .31406 L .62061 .31439 L p
1 g
F P
s
P
p
.002 w
.58557 .27466 m .62061 .31439 L .63828 .31406 L p
1 g
F P
s
P
p
.002 w
.53184 .61333 m .58877 .58972 L .57957 .5788 L p
1 g
F P
s
P
p
.002 w
.57957 .5788 m .52368 .60189 L .53184 .61333 L p
1 g
F P
s
P
p
.002 w
.31183 .43397 m .32698 .48648 L .33653 .4722 L p
1 g
F P
s
P
p
.002 w
.33653 .4722 m .32305 .42497 L .31183 .43397 L p
1 g
F P
s
P
p
.002 w
.34646 .32688 m .32636 .37456 L .34137 .37292 L p
1 g
F P
s
P
p
.002 w
.34137 .37292 m .35875 .33183 L .34646 .32688 L p
1 g
F P
s
P
p
.002 w
.63653 .55023 m .67063 .49864 L .65983 .48945 L p
1 g
F P
s
P
p
.002 w
.67646 .43161 m .65983 .48945 L .67063 .49864 L p
1 g
F P
s
P
p
.002 w
.47669 .25184 m .42643 .26165 L .42765 .27561 L p
1 g
F P
s
P
p
.002 w
.38868 .29805 m .42765 .27561 L .42643 .26165 L p
1 g
F P
s
P
p
.002 w
.67646 .43161 m .6743 .37208 L .65889 .36684 L p
1 g
F P
s
P
p
.002 w
.63828 .31406 m .65889 .36684 L .6743 .37208 L p
1 g
F P
s
P
p
.002 w
.38119 .28766 m .34646 .32688 L .35875 .33183 L p
1 g
F P
s
P
p
.002 w
.35875 .33183 m .38868 .29805 L .38119 .28766 L p
1 g
F P
s
P
p
.002 w
.3217 .4998 m .35577 .54603 L .3585 .52953 L p
1 g
F P
s
P
p
.002 w
.3585 .52953 m .32698 .48648 L .3217 .4998 L p
1 g
F P
s
P
p
.002 w
.47105 .6185 m .53184 .61333 L .52368 .60189 L p
1 g
F P
s
P
p
.002 w
.52368 .60189 m .46401 .60685 L .47105 .6185 L p
1 g
F P
s
P
p
.002 w
.42643 .26165 m .38119 .28766 L .38868 .29805 L p
1 g
F P
s
P
p
.002 w
.58557 .27466 m .53812 .24897 L .52599 .25906 L p
1 g
F P
s
P
p
.002 w
.47669 .25184 m .52599 .25906 L .53812 .24897 L p
1 g
F P
s
P
p
.002 w
.35683 .56006 m .40637 .59266 L .40307 .57735 L p
1 g
F P
s
P
p
.002 w
.40307 .57735 m .35577 .54603 L .35683 .56006 L p
1 g
F P
s
P
p
.002 w
.67063 .49864 m .68769 .43973 L .67646 .43161 L p
1 g
F P
s
P
p
.002 w
.6743 .37208 m .67646 .43161 L .68769 .43973 L p
1 g
F P
s
P
p
.002 w
.31542 .37778 m .31183 .43397 L .32305 .42497 L p
1 g
F P
s
P
p
.002 w
.32305 .42497 m .32636 .37456 L .31542 .37778 L p
1 g
F P
s
P
p
.002 w
.63828 .31406 m .60073 .27118 L .58557 .27466 L p
1 g
F P
s
P
p
.002 w
.53812 .24897 m .58557 .27466 L .60073 .27118 L p
1 g
F P
s
P
p
.002 w
.41235 .60419 m .47105 .6185 L .46401 .60685 L p
1 g
F P
s
P
p
.002 w
.46401 .60685 m .40637 .59266 L .41235 .60419 L p
1 g
F P
s
P
p
.002 w
.42643 .26165 m .47669 .25184 L .48323 .24081 L p
1 g
F P
s
P
p
.002 w
.53812 .24897 m .48323 .24081 L .47669 .25184 L p
1 g
F P
s
P
p
.002 w
.6743 .37208 m .65291 .31683 L .63828 .31406 L p
1 g
F P
s
P
p
.002 w
.60073 .27118 m .63828 .31406 L .65291 .31683 L p
1 g
F P
s
P
p
.002 w
.59596 .5968 m .64338 .55758 L .63653 .55023 L p
1 g
F P
s
P
p
.002 w
.63653 .55023 m .58877 .58972 L .59596 .5968 L p
1 g
F P
s
P
p
.002 w
.67063 .49864 m .63653 .55023 L .64338 .55758 L p
1 g
F P
s
P
p
.002 w
.30528 .44324 m .3217 .4998 L .32698 .48648 L p
1 g
F P
s
P
p
.002 w
.32698 .48648 m .31183 .43397 L .30528 .44324 L p
1 g
F P
s
P
p
.002 w
.53946 .62029 m .59596 .5968 L .58877 .58972 L p
1 g
F P
s
P
p
.002 w
.58877 .58972 m .53184 .61333 L .53946 .62029 L p
1 g
F P
s
P
p
.002 w
.33781 .32453 m .31542 .37778 L .32636 .37456 L p
1 g
F P
s
P
p
.002 w
.32636 .37456 m .34646 .32688 L .33781 .32453 L p
1 g
F P
s
P
p
.002 w
.64338 .55758 m .67728 .50637 L .67063 .49864 L p
1 g
F P
s
P
p
.002 w
.68769 .43973 m .67063 .49864 L .67728 .50637 L p
1 g
F P
s
P
p
.002 w
.68769 .43973 m .68561 .3791 L .6743 .37208 L p
1 g
F P
s
P
p
.002 w
.65291 .31683 m .6743 .37208 L .68561 .3791 L p
1 g
F P
s
P
p
.002 w
.48323 .24081 m .42715 .25168 L .42643 .26165 L p
1 g
F P
s
P
p
.002 w
.38119 .28766 m .42643 .26165 L .42715 .25168 L p
1 g
F P
s
P
p
.002 w
.32111 .51177 m .35683 .56006 L .35577 .54603 L p
1 g
F P
s
P
p
.002 w
.35577 .54603 m .3217 .4998 L .32111 .51177 L p
1 g
F P
s
P
p
.002 w
.37661 .28071 m .33781 .32453 L .34646 .32688 L p
1 g
F P
s
P
p
.002 w
.34646 .32688 m .38119 .28766 L .37661 .28071 L p
1 g
F P
s
P
p
.002 w
.60073 .27118 m .5497 .2434 L .53812 .24897 L p
1 g
F P
s
P
p
.002 w
.48323 .24081 m .53812 .24897 L .5497 .2434 L p
1 g
F P
s
P
p
.002 w
.47918 .6255 m .53946 .62029 L .53184 .61333 L p
1 g
F P
s
P
p
.002 w
.53184 .61333 m .47105 .6185 L .47918 .6255 L p
1 g
F P
s
P
p
.002 w
.42715 .25168 m .37661 .28071 L .38119 .28766 L p
1 g
F P
s
P
p
.002 w
.36188 .57109 m .41235 .60419 L .40637 .59266 L p
1 g
F P
s
P
p
.002 w
.40637 .59266 m .35683 .56006 L .36188 .57109 L p
1 g
F P
s
P
p
.002 w
.67728 .50637 m .69427 .44793 L .68769 .43973 L p
1 g
F P
s
P
p
.002 w
.68561 .3791 m .68769 .43973 L .69427 .44793 L p
1 g
F P
s
P
p
.002 w
.30909 .38258 m .30528 .44324 L .31183 .43397 L p
1 g
F P
s
P
p
.002 w
.31183 .43397 m .31542 .37778 L .30909 .38258 L p
1 g
F P
s
P
p
.002 w
.65291 .31683 m .61376 .27191 L .60073 .27118 L p
1 g
F P
s
P
p
.002 w
.5497 .2434 m .60073 .27118 L .61376 .27191 L p
1 g
F P
s
P
p
.002 w
.421 .61138 m .47918 .6255 L .47105 .6185 L p
1 g
F P
s
P
p
.002 w
.47105 .6185 m .41235 .60419 L .421 .61138 L p
1 g
F P
s
P
p
.002 w
.5497 .2434 m .4905 .2345 L .48323 .24081 L p
1 g
F P
s
P
p
.002 w
.42715 .25168 m .48323 .24081 L .4905 .2345 L p
1 g
F P
s
P
p
.002 w
.68561 .3791 m .66395 .32283 L .65291 .31683 L p
1 g
F P
s
P
p
.002 w
.61376 .27191 m .65291 .31683 L .66395 .32283 L p
1 g
F P
s
P
p
.002 w
.30385 .45256 m .32111 .51177 L .3217 .4998 L p
1 g
F P
s
P
p
.002 w
.3217 .4998 m .30528 .44324 L .30385 .45256 L p
1 g
F P
s
P
p
.002 w
.60082 .59962 m .64659 .56175 L .64338 .55758 L p
1 g
F P
s
P
p
.002 w
.64338 .55758 m .59596 .5968 L .60082 .59962 L p
1 g
F P
s
P
p
.002 w
.67728 .50637 m .64338 .55758 L .64659 .56175 L p
1 g
F P
s
P
p
.002 w
.33327 .325 m .30909 .38258 L .31542 .37778 L p
1 g
F P
s
P
p
.002 w
.31542 .37778 m .33781 .32453 L .33327 .325 L p
1 g
F P
s
P
p
.002 w
.54633 .6223 m .60082 .59962 L .59596 .5968 L p
1 g
F P
s
P
p
.002 w
.59596 .5968 m .53946 .62029 L .54633 .6223 L p
1 g
F P
s
P
p
.002 w
.69427 .44793 m .69229 .38782 L .68561 .3791 L p
1 g
F P
s
P
p
.002 w
.66395 .32283 m .68561 .3791 L .69229 .38782 L p
1 g
F P
s
P
p
.002 w
.64659 .56175 m .67932 .51234 L .67728 .50637 L p
1 g
F P
s
P
p
.002 w
.69427 .44793 m .67728 .50637 L .67932 .51234 L p
1 g
F P
s
P
p
.002 w
.32549 .52197 m .36188 .57109 L .35683 .56006 L p
1 g
F P
s
P
p
.002 w
.35683 .56006 m .32111 .51177 L .32549 .52197 L p
1 g
F P
s
P
p
.002 w
.4905 .2345 m .42991 .24622 L .42715 .25168 L p
1 g
F P
s
P
p
.002 w
.37661 .28071 m .42715 .25168 L .42991 .24622 L p
1 g
F P
s
P
p
.002 w
.61376 .27191 m .56039 .24275 L .5497 .2434 L p
1 g
F P
s
P
p
.002 w
.4905 .2345 m .5497 .2434 L .56039 .24275 L p
1 g
F P
s
P
p
.002 w
.37524 .2776 m .33327 .325 L .33781 .32453 L p
1 g
F P
s
P
p
.002 w
.33781 .32453 m .37661 .28071 L .37524 .2776 L p
1 g
F P
s
P
p
.002 w
.48823 .62735 m .54633 .6223 L .53946 .62029 L p
1 g
F P
s
P
p
.002 w
.53946 .62029 m .47918 .6255 L .48823 .62735 L p
1 g
F P
s
P
p
.002 w
.42991 .24622 m .37524 .2776 L .37661 .28071 L p
1 g
F P
s
P
p
.002 w
.37102 .57863 m .421 .61138 L .41235 .60419 L p
1 g
F P
s
P
p
.002 w
.41235 .60419 m .36188 .57109 L .37102 .57863 L p
1 g
F P
s
P
p
.002 w
.67932 .51234 m .69573 .456 L .69427 .44793 L p
1 g
F P
s
P
p
.002 w
.69229 .38782 m .69427 .44793 L .69573 .456 L p
1 g
F P
s
P
p
.002 w
.30784 .38894 m .30385 .45256 L .30528 .44324 L p
1 g
F P
s
P
p
.002 w
.30528 .44324 m .30909 .38258 L .30784 .38894 L p
1 g
F P
s
P
p
.002 w
.66395 .32283 m .62416 .27707 L .61376 .27191 L p
1 g
F P
s
P
p
.002 w
.56039 .24275 m .61376 .27191 L .62416 .27707 L p
1 g
F P
s
P
p
.004 w
.64213 .2658 m
.66619 .23791 L
s
P
p
.002 w
.43224 .61375 m .48823 .62735 L .47918 .6255 L p
1 g
F P
s
P
p
.002 w
.47918 .6255 m .421 .61138 L .43224 .61375 L p
1 g
F P
s
P
p
.002 w
.69229 .38782 m .67088 .33208 L .66395 .32283 L p
1 g
F P
s
P
p
.002 w
.62416 .27707 m .66395 .32283 L .67088 .33208 L p
1 g
F P
s
P
p
.002 w
.56039 .24275 m .49836 .23341 L .4905 .2345 L p
1 g
F P
s
P
p
.002 w
.42991 .24622 m .4905 .2345 L .49836 .23341 L p
1 g
F P
s
P
p
.002 w
.30793 .46164 m .32549 .52197 L .32111 .51177 L p
1 g
F P
s
P
p
.002 w
.32111 .51177 m .30385 .45256 L .30793 .46164 L p
1 g
F P
s
P
p
.002 w
.60307 .59781 m .64583 .56243 L .64659 .56175 L p
1 g
F P
s
P
p
.002 w
.64659 .56175 m .60082 .59962 L .60307 .59781 L p
1 g
F P
s
P
p
.002 w
.67932 .51234 m .64659 .56175 L .64583 .56243 L p
1 g
F P
s
P
p
.002 w
.33324 .32848 m .30784 .38894 L .30909 .38258 L p
1 g
F P
s
P
p
.002 w
.30909 .38258 m .33327 .325 L .33324 .32848 L p
1 g
F P
s
P
p
.002 w
.55218 .61899 m .60307 .59781 L .60082 .59962 L p
1 g
F P
s
P
p
.002 w
.60082 .59962 m .54633 .6223 L .55218 .61899 L p
1 g
F P
s
P
p
.002 w
.69573 .456 m .69384 .39811 L .69229 .38782 L p
1 g
F P
s
P
p
.002 w
.67088 .33208 m .69229 .38782 L .69384 .39811 L p
1 g
F P
s
P
p
.002 w
.33504 .52998 m .37102 .57863 L .36188 .57109 L p
1 g
F P
s
P
p
.002 w
.36188 .57109 m .32549 .52197 L .33504 .52998 L p
1 g
F P
s
P
p
.002 w
.64583 .56243 m .67641 .51627 L .67932 .51234 L p
1 g
F P
s
P
p
.002 w
.69573 .456 m .67932 .51234 L .67641 .51627 L p
1 g
F P
s
P
p
.002 w
.49836 .23341 m .43476 .2457 L .42991 .24622 L p
1 g
F P
s
P
p
.002 w
.37524 .2776 m .42991 .24622 L .43476 .2457 L p
1 g
F P
s
P
p
.002 w
.62416 .27707 m .56983 .24738 L .56039 .24275 L p
1 g
F P
s
P
p
.002 w
.49836 .23341 m .56039 .24275 L .56983 .24738 L p
1 g
F P
s
P
p
.002 w
.37734 .27867 m .33324 .32848 L .33327 .325 L p
1 g
F P
s
P
p
.002 w
.33327 .325 m .37524 .2776 L .37734 .27867 L p
1 g
F P
s
P
p
.002 w
.49801 .62367 m .55218 .61899 L .54633 .6223 L p
1 g
F P
s
P
p
.002 w
.54633 .6223 m .48823 .62735 L .49801 .62367 L p
1 g
F P
s
P
p
.002 w
.43476 .2457 m .37734 .27867 L .37524 .2776 L p
1 g
F P
s
P
p
.002 w
.38424 .58223 m .43224 .61375 L .421 .61138 L p
1 g
F P
s
P
p
.002 w
.421 .61138 m .37102 .57863 L .38424 .58223 L p
1 g
F P
s
P
p
.002 w
.67088 .33208 m .63148 .28679 L .62416 .27707 L p
1 g
F P
s
P
p
.002 w
.56983 .24738 m .62416 .27707 L .63148 .28679 L p
1 g
F P
s
P
p
.002 w
.67641 .51627 m .69171 .46369 L .69573 .456 L p
1 g
F P
s
P
p
.002 w
.69384 .39811 m .69573 .456 L .69171 .46369 L p
1 g
F P
s
P
p
.002 w
.31205 .39677 m .30793 .46164 L .30385 .45256 L p
1 g
F P
s
P
p
.002 w
.30385 .45256 m .30784 .38894 L .31205 .39677 L p
1 g
F P
s
P
p
.002 w
.69384 .39811 m .67322 .34452 L .67088 .33208 L p
1 g
F P
s
P
p
.002 w
.63148 .28679 m .67088 .33208 L .67322 .34452 L p
1 g
F P
s
P
p
.002 w
.44591 .61094 m .49801 .62367 L .48823 .62735 L p
1 g
F P
s
P
p
.002 w
.48823 .62735 m .43224 .61375 L .44591 .61094 L p
1 g
F P
s
P
p
.002 w
.56983 .24738 m .5066 .23789 L .49836 .23341 L p
1 g
F P
s
P
p
.002 w
.43476 .2457 m .49836 .23341 L .5066 .23789 L p
1 g
F P
s
P
p
.002 w
.31774 .47021 m .33504 .52998 L .32549 .52197 L p
1 g
F P
s
P
p
.002 w
.32549 .52197 m .30793 .46164 L .31774 .47021 L p
1 g
F P
s
P
p
.002 w
.60245 .59112 m .64086 .55935 L .64583 .56243 L p
1 g
F P
s
P
p
.002 w
.64583 .56243 m .60307 .59781 L .60245 .59112 L p
1 g
F P
s
P
p
.002 w
.67641 .51627 m .64583 .56243 L .64086 .55935 L p
1 g
F P
s
P
p
.002 w
.33803 .33506 m .31205 .39677 L .30784 .38894 L p
1 g
F P
s
P
p
.002 w
.30784 .38894 m .33324 .32848 L .33803 .33506 L p
1 g
F P
s
P
p
.002 w
.69171 .46369 m .6899 .40976 L .69384 .39811 L p
1 g
F P
s
P
p
.002 w
.67322 .34452 m .69384 .39811 L .6899 .40976 L p
1 g
F P
s
P
p
.002 w
.55678 .61009 m .60245 .59112 L .60307 .59781 L p
1 g
F P
s
P
p
.002 w
.60307 .59781 m .55218 .61899 L .55678 .61009 L p
1 g
F P
s
P
p
.002 w
.34978 .53542 m .38424 .58223 L .37102 .57863 L p
1 g
F P
s
P
p
.002 w
.37102 .57863 m .33504 .52998 L .34978 .53542 L p
1 g
F P
s
P
p
.002 w
.64086 .55935 m .66829 .5179 L .67641 .51627 L p
1 g
F P
s
P
p
.002 w
.69171 .46369 m .67641 .51627 L .66829 .5179 L p
1 g
F P
s
P
p
.002 w
.63148 .28679 m .57765 .25747 L .56983 .24738 L p
1 g
F P
s
P
p
.002 w
.5066 .23789 m .56983 .24738 L .57765 .25747 L p
1 g
F P
s
P
p
.002 w
.5066 .23789 m .44171 .25049 L .43476 .2457 L p
1 g
F P
s
P
p
.002 w
.37734 .27867 m .43476 .2457 L .44171 .25049 L p
1 g
F P
s
P
p
.002 w
.50825 .61421 m .55678 .61009 L .55218 .61899 L p
1 g
F P
s
P
p
.002 w
.55218 .61899 m .49801 .62367 L .50825 .61421 L p
1 g
F P
s
P
p
.002 w
.38308 .28419 m .33803 .33506 L .33324 .32848 L p
1 g
F P
s
P
p
.002 w
.33324 .32848 m .37734 .27867 L .38308 .28419 L p
1 g
F P
s
P
p
.002 w
.40138 .58153 m .44591 .61094 L .43224 .61375 L p
1 g
F P
s
P
p
.002 w
.43224 .61375 m .38424 .58223 L .40138 .58153 L p
1 g
F P
s
P
p
.002 w
.44171 .25049 m .38308 .28419 L .37734 .27867 L p
1 g
F P
s
P
p
.002 w
.67322 .34452 m .6353 .30107 L .63148 .28679 L p
1 g
F P
s
P
p
.002 w
.57765 .25747 m .63148 .28679 L .6353 .30107 L p
1 g
F P
s
P
p
.002 w
.32193 .40591 m .31774 .47021 L .30793 .46164 L p
1 g
F P
s
P
p
.002 w
.30793 .46164 m .31205 .39677 L .32193 .40591 L p
1 g
F P
s
P
p
.002 w
.66829 .5179 m .68196 .47075 L .69171 .46369 L p
1 g
F P
s
P
p
.002 w
.6899 .40976 m .69171 .46369 L .68196 .47075 L p
1 g
F P
s
P
p
.002 w
.6899 .40976 m .67063 .35996 L .67322 .34452 L p
1 g
F P
s
P
p
.002 w
.6353 .30107 m .67322 .34452 L .67063 .35996 L p
1 g
F P
s
P
p
.002 w
.46171 .60272 m .50825 .61421 L .49801 .62367 L p
1 g
F P
s
P
p
.002 w
.49801 .62367 m .44591 .61094 L .46171 .60272 L p
1 g
F P
s
P
p
.002 w
.57765 .25747 m .51499 .24818 L .5066 .23789 L p
1 g
F P
s
P
p
.002 w
.44171 .25049 m .5066 .23789 L .51499 .24818 L p
1 g
F P
s
P
p
.002 w
.33332 .47795 m .34978 .53542 L .33504 .52998 L p
1 g
F P
s
P
p
.002 w
.33504 .52998 m .31774 .47021 L .33332 .47795 L p
1 g
F P
s
P
p
.002 w
.68196 .47075 m .68024 .4225 L .6899 .40976 L p
1 g
F P
s
P
p
.002 w
.67063 .35996 m .6899 .40976 L .68024 .4225 L p
1 g
F P
s
P
p
.002 w
.34778 .34473 m .32193 .40591 L .31205 .39677 L p
1 g
F P
s
P
p
.002 w
.31205 .39677 m .33803 .33506 L .34778 .34473 L p
1 g
F P
s
P
p
.002 w
.59881 .57943 m .63154 .55236 L .64086 .55935 L p
1 g
F P
s
P
p
.002 w
.64086 .55935 m .60245 .59112 L .59881 .57943 L p
1 g
F P
s
P
p
.002 w
.66829 .5179 m .64086 .55935 L .63154 .55236 L p
1 g
F P
s
P
p
.002 w
.36953 .53795 m .40138 .58153 L .38424 .58223 L p
1 g
F P
s
P
p
.002 w
.38424 .58223 m .34978 .53542 L .36953 .53795 L p
1 g
F P
s
P
p
.002 w
.5599 .59553 m .59881 .57943 L .60245 .59112 L p
1 g
F P
s
P
p
.002 w
.60245 .59112 m .55678 .61009 L .5599 .59553 L p
1 g
F P
s
P
p
.002 w
.6353 .30107 m .58352 .27303 L .57765 .25747 L p
1 g
F P
s
P
p
.002 w
.51499 .24818 m .57765 .25747 L .58352 .27303 L p
1 g
F P
s
P
p
.002 w
.63154 .55236 m .65488 .51704 L .66829 .5179 L p
1 g
F P
s
P
p
.002 w
.68196 .47075 m .66829 .5179 L .65488 .51704 L p
1 g
F P
s
P
p
.002 w
.51499 .24818 m .45066 .26077 L .44171 .25049 L p
1 g
F P
s
P
p
.002 w
.38308 .28419 m .44171 .25049 L .45066 .26077 L p
1 g
F P
s
P
p
.002 w
.42208 .57632 m .46171 .60272 L .44591 .61094 L p
1 g
F P
s
P
p
.002 w
.44591 .61094 m .40138 .58153 L .42208 .57632 L p
1 g
F P
s
P
p
.002 w
.51865 .59894 m .5599 .59553 L .55678 .61009 L p
1 g
F P
s
P
p
.002 w
.55678 .61009 m .50825 .61421 L .51865 .59894 L p
1 g
F P
s
P
p
.002 w
.39251 .29426 m .34778 .34473 L .33803 .33506 L p
1 g
F P
s
P
p
.002 w
.33803 .33506 m .38308 .28419 L .39251 .29426 L p
1 g
F P
s
P
p
.002 w
.45066 .26077 m .39251 .29426 L .38308 .28419 L p
1 g
F P
s
P
p
.002 w
.67063 .35996 m .63528 .31972 L .6353 .30107 L p
1 g
F P
s
P
p
.002 w
.58352 .27303 m .6353 .30107 L .63528 .31972 L p
1 g
F P
s
P
p
.002 w
.33752 .41615 m .33332 .47795 L .31774 .47021 L p
1 g
F P
s
P
p
.002 w
.31774 .47021 m .32193 .40591 L .33752 .41615 L p
1 g
F P
s
P
p
.002 w
.65488 .51704 m .66644 .47691 L .68196 .47075 L p
1 g
F P
s
P
p
.002 w
.68024 .4225 m .68196 .47075 L .66644 .47691 L p
1 g
F P
s
P
p
.002 w
.68024 .4225 m .66289 .37808 L .67063 .35996 L p
1 g
F P
s
P
p
.002 w
.63528 .31972 m .67063 .35996 L .66289 .37808 L p
1 g
F P
s
P
p
.002 w
.47922 .58904 m .51865 .59894 L .50825 .61421 L p
1 g
F P
s
P
p
.002 w
.50825 .61421 m .46171 .60272 L .47922 .58904 L p
1 g
F P
s
P
p
.002 w
.35448 .48455 m .36953 .53795 L .34978 .53542 L p
1 g
F P
s
P
p
.002 w
.34978 .53542 m .33332 .47795 L .35448 .48455 L p
1 g
F P
s
P
p
.002 w
.58352 .27303 m .52327 .26428 L .51499 .24818 L p
1 g
F P
s
P
p
.002 w
.45066 .26077 m .51499 .24818 L .52327 .26428 L p
1 g
F P
s
P
p
.002 w
.66644 .47691 m .66486 .43595 L .68024 .4225 L p
1 g
F P
s
P
p
.002 w
.66289 .37808 m .68024 .4225 L .66486 .43595 L p
1 g
F P
s
P
p
.002 w
.3939 .53734 m .42208 .57632 L .40138 .58153 L p
1 g
F P
s
P
p
.002 w
.40138 .58153 m .36953 .53795 L .3939 .53734 L p
1 g
F P
s
P
p
.002 w
.36249 .35735 m .33752 .41615 L .32193 .40591 L p
1 g
F P
s
P
p
.002 w
.32193 .40591 m .34778 .34473 L .36249 .35735 L p
1 g
F P
s
P
p
.002 w
.59207 .56282 m .61792 .54146 L .63154 .55236 L p
1 g
F P
s
P
p
.002 w
.63154 .55236 m .59881 .57943 L .59207 .56282 L p
1 g
F P
s
P
p
.002 w
.65488 .51704 m .63154 .55236 L .61792 .54146 L p
1 g
F P
s
P
p
.002 w
.56135 .57548 m .59207 .56282 L .59881 .57943 L p
1 g
F P
s
P
p
.002 w
.59881 .57943 m .5599 .59553 L .56135 .57548 L p
1 g
F P
s
P
p
.002 w
.63528 .31972 m .58711 .29388 L .58352 .27303 L p
1 g
F P
s
P
p
.004 w
.62604 .28445 m
.63109 .2786 L
s
P
p
.004 w
.63109 .2786 m
.64213 .2658 L
s
P
p
.002 w
.52327 .26428 m .58352 .27303 L .58711 .29388 L p
1 g
F P
s
P
p
.002 w
.61792 .54146 m .63632 .51355 L .65488 .51704 L p
1 g
F P
s
P
p
.002 w
.66644 .47691 m .65488 .51704 L .63632 .51355 L p
1 g
F P
s
P
p
.002 w
.52327 .26428 m .46145 .27653 L .45066 .26077 L p
1 g
F P
s
P
p
.002 w
.39251 .29426 m .45066 .26077 L .46145 .27653 L p
1 g
F P
s
P
p
.002 w
.44581 .56652 m .47922 .58904 L .46171 .60272 L p
1 g
F P
s
P
p
.002 w
.46171 .60272 m .42208 .57632 L .44581 .56652 L p
1 g
F P
s
P
p
.002 w
.52886 .57805 m .56135 .57548 L .5599 .59553 L p
1 g
F P
s
P
p
.002 w
.5599 .59553 m .51865 .59894 L .52886 .57805 L p
1 g
F P
s
P
p
.002 w
.66289 .37808 m .63121 .34234 L .63528 .31972 L p
1 g
F P
s
P
p
.002 w
.58711 .29388 m .63528 .31972 L .63121 .34234 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.60291 .31125 L
s
P
p
.002 w
.40554 .30881 m .36249 .35735 L .34778 .34473 L p
1 g
F P
s
P
p
.002 w
.34778 .34473 m .39251 .29426 L .40554 .30881 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.46145 .27653 m .40554 .30881 L .39251 .29426 L p
1 g
F P
s
P
p
.002 w
.35858 .42719 m .35448 .48455 L .33332 .47795 L p
1 g
F P
s
P
p
.002 w
.33332 .47795 m .33752 .41615 L .35858 .42719 L p
1 g
F P
s
P
p
.002 w
.63632 .51355 m .64535 .4819 L .66644 .47691 L p
1 g
F P
s
P
p
.002 w
.66486 .43595 m .66644 .47691 L .64535 .4819 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.66486 .43595 m .64998 .3984 L .66289 .37808 L p
1 g
F P
s
P
p
.002 w
.63121 .34234 m .66289 .37808 L .64998 .3984 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52797 .57988 m .51865 .59894 L p
.50595 .58127 L 1 g
F P
s
P
p
.50595 .58127 m .50525 .58029 L .51091 .58019 L 1 g
F
P
p
.50595 .58127 m .51091 .58019 L .52797 .57988 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58019 L p
1 g
F P
s
P
p
.53128 .57265 m .51091 .58019 L .52077 .57804 L 1 g
F
P
p
.002 w
.51091 .58019 m .51079 .57862 L p
.50214 .58035 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58059 L p
1 g
F P
s
P
p
.002 w
.51865 .59894 m .47922 .58904 L .48755 .58062 L p
1 g
F P
s
P
p
.51865 .59894 m .48755 .58062 L .48906 .58059 L 1 g
F
P
p
.5079 .58399 m .48906 .58059 L .50525 .58029 L 1 g
F
P
p
.51865 .59894 m .48906 .58059 L .5079 .58399 L 1 g
F
P
p
.002 w
.48906 .58059 m .48921 .57862 L p
.48019 .57788 L 1 g
F P
s
P
p
.002 w
.4878 .58036 m .47922 .58904 L p
.47677 .57676 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47922 .58904 m .4462 .56678 L p
.46842 .57404 L 1 g
F P
s
P
p
.47729 .5794 m .46842 .57404 L .47677 .57676 L 1 g
F
P
p
.47922 .58904 m .46842 .57404 L .47729 .5794 L 1 g
F
P
p
.002 w
.46842 .57404 m .46872 .57265 L p
.46107 .56959 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46842 .57404 L p
1 g
F P
s
P
p
.002 w
.46842 .57404 m .4678 .57686 L p
.48019 .57788 L 1 g
F P
s
P
p
.48921 .57862 m .46842 .57404 L .48019 .57788 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45073 .56326 L p
1 g
F P
s
P
p
.46872 .57265 m .45073 .56326 L .45102 .56349 L 1 g
F
P
p
.44581 .56652 m .44702 .5603 L .45073 .56326 L 1 g
F
P
p
.002 w
.45116 .5636 m .45103 .56367 L p
.45073 .56326 L 1 g
F P
s
P
p
.002 w
.45103 .56367 m .44581 .56652 L p
.45073 .56326 L 1 g
F P
s
P
p
.002 w
.45073 .56326 m .45146 .56129 L p
.4454 .55602 L 1 g
F P
s
P
p
.46872 .57265 m .45102 .56349 L .46107 .56959 L 1 g
F
P
p
.45102 .56349 m .4507 .56333 L .45116 .5636 L 1 g
F
P
p
.45102 .56349 m .45116 .5636 L .46107 .56959 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43863 .54683 L p
1 g
F P
s
P
p
.45146 .56129 m .43863 .54683 L .4454 .55602 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44581 .56652 m .44507 .56548 L p
.45361 .52629 L 1 g
F P
s
P
p
.002 w
.44507 .56548 m .42222 .53345 L .43314 .53096 L p
1 g
F P
s
P
p
.002 w
.43863 .54683 m .43925 .54566 L p
.436 .53924 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43258 .52862 L p
1 g
F P
s
P
p
.42222 .53345 m .43043 .51974 L .43258 .52862 L 1 g
F
P
p
.002 w
.43314 .53096 m .43237 .53114 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.43237 .53114 m .42222 .53345 L p
.43258 .52862 L 1 g
F P
s
P
p
.002 w
.43258 .52862 m .43346 .52734 L p
.43323 .52076 L 1 g
F P
s
P
p
.43925 .54566 m .43258 .52862 L .43436 .53599 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43421 .50903 L p
1 g
F P
s
P
p
.43346 .52734 m .43421 .50903 L .43323 .52076 L 1 g
F
P
p
.43258 .52862 m .44537 .49479 L .43314 .53096 L 1 g
F
P
p
.43043 .51974 m .43378 .51415 L .43258 .52862 L 1 g
F
P
p
.43378 .51415 m .44537 .49479 L .43258 .52862 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.42222 .53345 m .41138 .49319 L .44095 .49458 L p
1 g
F P
s
P
p
.002 w
.43421 .50903 m .43485 .50826 L p
.43799 .50093 L 1 g
F P
s
P
p
.42222 .53345 m .44095 .49458 L .42487 .52904 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4425 .49144 L p
1 g
F P
s
P
p
.41138 .49319 m .44634 .4837 L .4425 .49144 L 1 g
F
P
p
.002 w
.44095 .49458 m .43934 .49451 L p
.4425 .49144 L 1 g
F P
s
P
p
.002 w
.43934 .49451 m .41138 .49319 L p
.4425 .49144 L 1 g
F P
s
P
p
.002 w
.4425 .49144 m .44166 .49233 L p
.43914 .49823 L 1 g
F P
s
P
p
.43485 .50826 m .4425 .49144 L .43914 .49823 L 1 g
F
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.4425 .49144 m .44339 .4905 L p
.45019 .48399 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44596 .4881 m .45775 .47663 L .48364 .47145 L 1 g
F
P
p
.002 w
.45775 .47663 m .45826 .47608 L p
.46713 .47219 L 1 g
F P
s
P
p
.002 w
.47435 .46877 m .48364 .47145 L p
.45775 .47663 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.49324 .44977 m .48771 .46226 L p
.4483 .46124 L 1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48364 .47145 m .47435 .46877 L p
.47753 .46722 L 1 g
F P
s
P
p
.002 w
.48602 .46608 m .48364 .47145 L p
.47753 .46722 L 1 g
F P
s
P
p
.002 w
.48364 .47145 m .48602 .46608 L p
.52444 .46945 L 1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.48602 .46608 m .5 .46386 L .52444 .46945 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .46729 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56615 .50945 L p
1 g
F P
s
P
p
.577 .51027 m .56712 .51148 L .56615 .50945 L 1 g
F
P
p
.56502 .49871 m .56615 .50945 L .55753 .49148 L 1 g
F
P
p
.577 .51027 m .56615 .50945 L .56502 .49871 L 1 g
F
P
p
.002 w
.577 .51027 m .56967 .51631 L .56712 .51148 L p
1 g
F P
s
P
p
.002 w
.56615 .50945 m .56515 .50826 L p
.56711 .52099 L 1 g
F P
s
P
p
.002 w
.56696 .51741 m .56967 .51631 L p
.56743 .52847 L 1 g
F P
s
P
p
.56711 .52099 m .56694 .51703 L .56615 .50945 L 1 g
F
P
p
.55661 .4905 m .56615 .50945 L .56207 .50095 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55753 .49148 L p
1 g
F P
s
P
p
.002 w
.55753 .49148 m .55661 .4905 L p
.56207 .50095 L 1 g
F P
s
P
p
.56207 .50095 m .56713 .51061 L .55753 .49148 L 1 g
F
P
p
.002 w
.54174 .47608 m .55546 .48938 L p
.55553 .48953 L 1 g
F P
s
P
p
.002 w
.55546 .48938 m .55661 .4905 L p
.55553 .48953 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .55753 .49148 L p
.55553 .48953 L 1 g
F P
s
P
p
.54174 .47608 m .55753 .49148 L .55557 .48958 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55555 .48957 m .55459 .48774 L p
.5568 .48997 L 1 g
F P
s
P
p
.577 .51027 m .55753 .49148 L .5568 .48997 L 1 g
F
P
p
.55753 .49148 m .55555 .48957 L .5568 .48997 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56967 .51631 m .58229 .5416 L p
.56743 .52847 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56744 .52865 L p
1 g
F P
s
P
p
.002 w
.58229 .5416 m .56825 .54735 L p
.56744 .52865 L 1 g
F P
s
P
p
.56749 .52851 m .56744 .52865 L .56743 .52847 L 1 g
F
P
p
.58229 .5416 m .56744 .52865 L .56749 .52851 L 1 g
F
P
p
.002 w
.56744 .52865 m .56654 .52734 L p
.56454 .53831 L 1 g
F P
s
P
p
.56515 .50826 m .56744 .52865 L .56711 .52099 L 1 g
F
P
p
.002 w
.56825 .54735 m .56098 .55032 L p
.56183 .54743 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56175 .54756 L p
1 g
F P
s
P
p
.56785 .53826 m .56183 .54743 L .56408 .53981 L 1 g
F
P
p
.56785 .53826 m .56408 .53981 L .56744 .52865 L 1 g
F
P
p
.56825 .54735 m .56183 .54743 L .56785 .53826 L 1 g
F
P
p
.56654 .52734 m .56175 .54756 L .56454 .53831 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56281 L p
1 g
F P
s
P
p
.56135 .57548 m .54907 .56286 L .54912 .5628 L 1 g
F
P
p
.002 w
.56098 .55032 m .56104 .55453 L p
.54912 .5628 L 1 g
F P
s
P
p
.002 w
.56104 .55453 m .56135 .57548 L p
.54912 .5628 L 1 g
F P
s
P
p
.002 w
.54911 .56281 m .54854 .56129 L p
.54115 .56833 L 1 g
F P
s
P
p
.56075 .54566 m .54911 .56281 L .55516 .5558 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53176 .57485 L p
1 g
F P
s
P
p
.002 w
.56135 .57548 m .52886 .57805 L .52945 .57645 L p
1 g
F P
s
P
p
.56135 .57548 m .52945 .57645 L .53176 .57485 L 1 g
F
P
p
.55255 .56643 m .53176 .57485 L .54905 .56285 L 1 g
F
P
p
.56135 .57548 m .53176 .57485 L .55255 .56643 L 1 g
F
P
p
.53128 .57265 m .52077 .57804 L .52151 .57788 L 1 g
F
P
p
.51091 .58019 m .5217 .57784 L .52797 .57988 L 1 g
F
P
p
.002 w
.53176 .57485 m .53128 .57265 L p
.52151 .57788 L 1 g
F P
s
P
p
.002 w
.52886 .57805 m .52797 .57988 L p
.5217 .57784 L 1 g
F P
s
P
p
.002 w
.52513 .57709 m .52886 .57805 L p
.5217 .57784 L 1 g
F P
s
P
p
.002 w
.52886 .57805 m .52513 .57709 L p
.52816 .57615 L 1 g
F P
s
P
p
.52151 .57788 m .52513 .57709 L .53176 .57485 L 1 g
F
P
p
.002 w
.52974 .57566 m .52886 .57805 L p
.52816 .57615 L 1 g
F P
s
P
p
.52513 .57709 m .52747 .57658 L .52974 .57566 L 1 g
F
P
p
.52513 .57709 m .52974 .57566 L .53176 .57485 L 1 g
F
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.5172 .54641 m .5385 .55201 L .52974 .57566 L p
1 g
F P
s
P
p
.52816 .57615 m .5172 .54641 L .52974 .57566 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.49793 .57012 m .5172 .54641 L p
.52816 .57615 L 1 g
F P
s
P
p
.002 w
.52513 .57709 m .49793 .57012 L p
.52816 .57615 L 1 g
F P
s
P
p
.52513 .57709 m .51296 .58246 L .52747 .57658 L 1 g
F
P
p
.52151 .57788 m .52003 .57867 L .52513 .57709 L 1 g
F
P
p
.52003 .57867 m .51296 .58246 L .52513 .57709 L 1 g
F
P
p
.002 w
.49793 .57012 m .52513 .57709 L p
.5217 .57784 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58059 L .50214 .58035 L 1 g
F
P
p
.50525 .58029 m .49793 .57012 L .5217 .57784 L 1 g
F
P
p
.50525 .58029 m .5217 .57784 L .51091 .58019 L 1 g
F
P
p
.002 w
.51111 .583 m .51296 .58246 L p
.52151 .57788 L 1 g
F P
s
P
p
.52077 .57804 m .51111 .583 L .52151 .57788 L 1 g
F
P
p
.54854 .56129 m .53176 .57485 L .54115 .56833 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52945 .57645 m .5385 .55201 L p
.54905 .56285 L 1 g
F P
s
P
p
.002 w
.51296 .58246 m .5322 .57686 L .53176 .57485 L p
1 g
F P
s
P
p
.002 w
.53176 .57485 m .5322 .57686 L p
.54115 .56833 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55981 .55041 m .56098 .55032 L p
.54907 .56286 L 1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56743 .52847 m .56183 .54743 L .55872 .52076 L 1 g
F
P
p
.002 w
.56098 .55032 m .56087 .5489 L p
.56183 .54743 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .55123 .56358 L p
.56075 .54566 L 1 g
F P
s
P
p
.002 w
.56175 .54756 m .56075 .54566 L p
.55334 .55962 L 1 g
F P
s
P
p
.002 w
.56087 .5489 m .56098 .55032 L p
.56053 .54938 L 1 g
F P
s
P
p
.55334 .55962 m .56087 .5489 L .56175 .54756 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.5385 .55201 m .5472 .52157 L p
.56053 .54938 L 1 g
F P
s
P
p
.002 w
.56098 .55032 m .55981 .55041 L p
.56053 .54938 L 1 g
F P
s
P
p
.002 w
.55981 .55041 m .5385 .55201 L p
.56053 .54938 L 1 g
F P
s
P
p
.002 w
.56098 .55032 m .58229 .5416 L .59207 .56282 L p
1 g
F P
s
P
p
.002 w
.59207 .56282 m .56135 .57548 L .56098 .55032 L p
1 g
F P
s
P
p
.002 w
.55123 .56358 m .56257 .5491 L .56178 .54761 L p
1 g
F P
s
P
p
.002 w
.56178 .54761 m .56175 .54756 L p
.56087 .5489 L 1 g
F P
s
P
p
.56087 .5489 m .55123 .56358 L .56178 .54761 L 1 g
F
P
p
.55334 .55962 m .55123 .56358 L .56087 .5489 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5472 .52157 m .55872 .52076 L .56087 .5489 L p
1 g
F P
s
P
p
.56053 .54938 m .5472 .52157 L .56087 .5489 L 1 g
F
P
p
.002 w
.56087 .5489 m .55872 .52076 L p
.56183 .54743 L 1 g
F P
s
P
p
.002 w
.5385 .55201 m .55981 .55041 L p
.54907 .56286 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56281 L p
1 g
F P
s
P
p
.54115 .56833 m .5322 .57686 L .54911 .56281 L 1 g
F
P
p
.002 w
.54911 .56281 m .54998 .56518 L p
.55516 .5558 L 1 g
F P
s
P
p
.002 w
.56175 .54756 m .56257 .5491 L p
.56454 .53831 L 1 g
F P
s
P
p
.56744 .52865 m .56408 .53981 L .56743 .52847 L 1 g
F
P
p
.002 w
.56257 .5491 m .55123 .56358 L p
.55144 .56909 L 1 g
F P
s
P
p
.002 w
.55123 .56358 m .54998 .56518 L .55006 .56537 L p
1 g
F P
s
P
p
.002 w
.55006 .56537 m .55144 .56909 L p
.55123 .56358 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56744 .52865 L p
1 g
F P
s
P
p
.56454 .53831 m .56257 .5491 L .56744 .52865 L 1 g
F
P
p
.002 w
.56744 .52865 m .56854 .53025 L p
.56711 .52099 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55872 .52076 m .55471 .48876 L p
.56617 .50968 L 1 g
F P
s
P
p
.002 w
.55555 .48957 m .56617 .50968 L p
.55471 .48876 L 1 g
F P
s
P
p
.002 w
.56712 .51148 m .55555 .48957 L p
.55753 .49148 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55872 .52076 m .5472 .52157 L .55442 .48848 L p
1 g
F P
s
P
p
.54174 .47608 m .55563 .48964 L .55171 .48585 L 1 g
F
P
p
.002 w
.55442 .48848 m .55459 .48774 L .55471 .48876 L p
1 g
F P
s
P
p
.002 w
.55471 .48876 m .55872 .52076 L p
.55442 .48848 L 1 g
F P
s
P
p
.002 w
.5472 .52157 m .53633 .51863 L .55425 .48831 L p
1 g
F P
s
P
p
.002 w
.55425 .48831 m .55459 .48774 L .55442 .48848 L p
1 g
F P
s
P
p
.002 w
.55442 .48848 m .5472 .52157 L p
.55425 .48831 L 1 g
F P
s
P
p
.002 w
.53633 .51863 m .52729 .51222 L .5541 .48817 L p
1 g
F P
s
P
p
.002 w
.5541 .48817 m .55459 .48774 L .55425 .48831 L p
1 g
F P
s
P
p
.002 w
.55425 .48831 m .53633 .51863 L p
.5541 .48817 L 1 g
F P
s
P
p
.002 w
.52729 .51222 m .52108 .50303 L .55395 .48802 L p
1 g
F P
s
P
p
.002 w
.55395 .48802 m .55459 .48774 L .5541 .48817 L p
1 g
F P
s
P
p
.002 w
.5541 .48817 m .52729 .51222 L p
.55395 .48802 L 1 g
F P
s
P
p
.55425 .48831 m .55779 .49176 L .55396 .48803 L 1 g
F
P
p
.55433 .48839 m .55441 .48846 L .55425 .48831 L 1 g
F
P
p
.55441 .48846 m .55779 .49176 L .55425 .48831 L 1 g
F
P
p
.55442 .48848 m .55447 .48852 L .55433 .48839 L 1 g
F
P
p
.55447 .48852 m .55779 .49176 L .55433 .48839 L 1 g
F
P
p
.55563 .48964 m .55575 .48976 L .55442 .48848 L 1 g
F
P
p
.55575 .48976 m .55779 .49176 L .55442 .48848 L 1 g
F
P
p
.002 w
.51954 .4804 m .52444 .46945 L .55211 .48624 L p
1 g
F P
s
P
p
.55344 .48753 m .55211 .48624 L .55171 .48585 L 1 g
F
P
p
.002 w
.55376 .48783 m .51838 .49202 L p
.5534 .48749 L 1 g
F P
s
P
p
.002 w
.52108 .50303 m .51838 .49202 L .55376 .48783 L p
1 g
F P
s
P
p
.55563 .48964 m .55404 .48811 L .55171 .48585 L 1 g
F
P
p
.002 w
.55376 .48783 m .55459 .48774 L .55395 .48802 L p
1 g
F P
s
P
p
.002 w
.55395 .48802 m .52108 .50303 L p
.55376 .48783 L 1 g
F P
s
P
p
.55363 .48771 m .5534 .48749 L .55344 .48753 L 1 g
F
P
p
.55404 .48811 m .55362 .4877 L .55363 .48771 L 1 g
F
P
p
.55362 .4877 m .5534 .48749 L .55363 .48771 L 1 g
F
P
p
.5534 .48749 m .55211 .48624 L .55344 .48753 L 1 g
F
P
p
.002 w
.51838 .49202 m .51954 .4804 L .5534 .48749 L p
1 g
F P
s
P
p
.002 w
.5534 .48749 m .55459 .48774 L .55376 .48783 L p
1 g
F P
s
P
p
.002 w
.55211 .48624 m .55459 .48774 L .5534 .48749 L p
1 g
F P
s
P
p
.002 w
.5534 .48749 m .51954 .4804 L p
.55211 .48624 L 1 g
F P
s
P
p
.55404 .48811 m .55396 .48803 L .55211 .48624 L 1 g
F
P
p
.002 w
.55779 .49176 m .55834 .49233 L p
.55289 .487 L 1 g
F P
s
P
p
.55282 .48693 m .553 .4871 L .55289 .487 L 1 g
F
P
p
.553 .4871 m .55779 .49176 L .55289 .487 L 1 g
F
P
p
.002 w
.52444 .46945 m .52518 .46862 L p
.55178 .48591 L 1 g
F P
s
P
p
.002 w
.55459 .48774 m .55211 .48624 L p
.55178 .48591 L 1 g
F P
s
P
p
.002 w
.55211 .48624 m .52444 .46945 L p
.55178 .48591 L 1 g
F P
s
P
p
.52518 .46862 m .54233 .47673 L .55178 .48591 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54233 .47673 L p
1 g
F P
s
P
p
.002 w
.54233 .47673 m .54174 .47608 L p
.55171 .48585 L 1 g
F P
s
P
p
.55171 .48585 m .55834 .49233 L .54233 .47673 L 1 g
F
P
p
.55171 .48585 m .55404 .48811 L .55282 .48693 L 1 g
F
P
p
.55404 .48811 m .55779 .49176 L .55282 .48693 L 1 g
F
P
p
.002 w
.55471 .48876 m .55459 .48774 L .55555 .48957 L p
1 g
F P
s
P
p
.002 w
.56617 .50968 m .56967 .51631 L .56696 .51741 L p
1 g
F P
s
P
p
.002 w
.56696 .51741 m .55872 .52076 L p
.56617 .50968 L 1 g
F P
s
P
p
.56696 .51741 m .56789 .52602 L .56694 .51703 L 1 g
F
P
p
.56711 .52099 m .56774 .52505 L .56696 .51741 L 1 g
F
P
p
.56774 .52505 m .56789 .52602 L .56696 .51741 L 1 g
F
P
p
.002 w
.55872 .52076 m .56696 .51741 L p
.56743 .52847 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56615 .50945 L p
1 g
F P
s
P
p
.56789 .52602 m .56854 .53025 L .56615 .50945 L 1 g
F
P
p
.002 w
.56615 .50945 m .56713 .51061 L p
.56207 .50095 L 1 g
F P
s
P
p
.002 w
.55753 .49148 m .55779 .49176 L p
.55557 .48958 L 1 g
F P
s
P
p
.002 w
.55459 .48774 m .5789 .5087 L .577 .51027 L p
1 g
F P
s
P
p
.002 w
.5478 .47931 m .55459 .48774 L p
.55178 .48591 L 1 g
F P
s
P
p
.54233 .47673 m .5478 .47931 L .55178 .48591 L 1 g
F
P
p
.002 w
.54233 .47673 m .54302 .47747 L p
.53351 .47256 L 1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .53351 .47256 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52444 .46945 m .52057 .467 L p
.52252 .46729 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .54234 .47715 L p
.52214 .46667 L 1 g
F P
s
P
p
.002 w
.52252 .46729 m .52214 .46667 L p
.54234 .47715 L 1 g
F P
s
P
p
.002 w
.52592 .46779 m .52518 .46862 L p
.52252 .46729 L 1 g
F P
s
P
p
.002 w
.52518 .46862 m .52444 .46945 L p
.52252 .46729 L 1 g
F P
s
P
p
.002 w
.54234 .47715 m .52282 .46778 L .52252 .46729 L p
1 g
F P
s
P
p
.002 w
.52518 .46862 m .53254 .46038 L .5478 .47931 L p
1 g
F P
s
P
p
.002 w
.52252 .46729 m .52252 .4673 L p
.52209 .46723 L 1 g
F P
s
P
p
.5 .4634 m .52252 .46729 L .52209 .46723 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.53254 .46038 m .52592 .46779 L p
.49324 .44977 L 1 g
F P
s
P
p
.5 .4634 m .52252 .4673 L .51165 .46564 L 1 g
F
P
p
.002 w
.52057 .467 m .49324 .44977 L p
.52592 .46779 L 1 g
F P
s
P
p
.002 w
.52057 .467 m .52444 .46945 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51165 .46564 L 1 g
F P
s
P
p
.51165 .46564 m .52282 .46778 L .5 .46386 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4642 L p
1 g
F P
s
P
p
.002 w
.5 .4642 m .5 .46442 L p
.49337 .46509 L 1 g
F P
s
P
p
.47786 .46667 m .5 .4642 L .49337 .46509 L 1 g
F
P
p
.002 w
.47753 .46722 m .47786 .46667 L p
.47886 .46657 L 1 g
F P
s
P
p
.47886 .46657 m .49337 .46509 L .47753 .46722 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46722 L p
1 g
F P
s
P
p
.4483 .46124 m .48771 .46226 L .47753 .46722 L 1 g
F
P
p
.45826 .47608 m .47753 .46722 L .47607 .46793 L 1 g
F
P
p
.45826 .47608 m .47749 .46728 L .46713 .47219 L 1 g
F
P
p
.002 w
.47435 .46877 m .47171 .468 L p
.47753 .46722 L 1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.47171 .468 m .4483 .46124 L p
.47753 .46722 L 1 g
F P
s
P
p
.002 w
.49324 .44977 m .51244 .46188 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.48602 .46608 m .48783 .46199 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.48783 .46199 m .49324 .44977 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.51244 .46188 m .52057 .467 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52252 .4673 m .52282 .46778 L p
.51165 .46564 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47739 .46745 L p
1 g
F P
s
P
p
.002 w
.47739 .46745 m .47753 .46722 L p
.48363 .46646 L 1 g
F P
s
P
p
.48363 .46646 m .5 .46442 L .47739 .46745 L 1 g
F
P
p
.49337 .46509 m .5 .46442 L .47753 .46722 L 1 g
F
P
p
.002 w
.48771 .46226 m .48602 .46608 L p
.47753 .46722 L 1 g
F P
s
P
p
.002 w
.47753 .46722 m .47749 .46728 L p
.47607 .46793 L 1 g
F P
s
P
p
.002 w
.47749 .46728 m .47718 .46778 L p
.46713 .47219 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44537 .49479 m .44095 .49458 L p
.4425 .49144 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45735 .47707 L p
1 g
F P
s
P
p
.44339 .4905 m .45735 .47707 L .45207 .48218 L 1 g
F
P
p
.45019 .48399 m .44596 .4881 L .4425 .49144 L 1 g
F
P
p
.002 w
.44634 .4837 m .44596 .4881 L p
.4425 .49144 L 1 g
F P
s
P
p
.002 w
.44596 .4881 m .44537 .49479 L p
.4425 .49144 L 1 g
F P
s
P
p
.002 w
.45735 .47707 m .45698 .47747 L p
.45207 .48218 L 1 g
F P
s
P
p
.002 w
.4483 .46124 m .46779 .46687 L p
.45775 .47663 L 1 g
F P
s
P
p
.002 w
.44596 .4881 m .44649 .48197 L p
.45775 .47663 L 1 g
F P
s
P
p
.002 w
.44649 .48197 m .4483 .46124 L p
.45775 .47663 L 1 g
F P
s
P
p
.002 w
.46779 .46687 m .47435 .46877 L p
.45775 .47663 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45775 .47663 L p
1 g
F P
s
P
p
.46713 .47219 m .47718 .46778 L .45775 .47663 L 1 g
F
P
p
.45019 .48399 m .45207 .48218 L .44596 .4881 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44537 .49479 m .44596 .4881 L p
.48364 .47145 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4425 .49144 L p
1 g
F P
s
P
p
.45207 .48218 m .45698 .47747 L .4425 .49144 L 1 g
F
P
p
.002 w
.4483 .46124 m .44634 .4837 L p
.41138 .49319 L 1 g
F P
s
P
p
.002 w
.44095 .49458 m .44537 .49479 L p
.42487 .52904 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43421 .50903 L p
1 g
F P
s
P
p
.43799 .50093 m .44166 .49233 L .43421 .50903 L 1 g
F
P
p
.002 w
.43421 .50903 m .43287 .51061 L p
.43323 .52076 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43258 .52862 L p
1 g
F P
s
P
p
.43323 .52076 m .43287 .51061 L .43258 .52862 L 1 g
F
P
p
.002 w
.43258 .52862 m .43146 .53025 L p
.43436 .53599 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44537 .49479 m .45361 .52629 L .43314 .53096 L p
1 g
F P
s
P
p
.002 w
.43314 .53096 m .45361 .52629 L p
.44507 .56548 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43863 .54683 L p
1 g
F P
s
P
p
.436 .53924 m .43146 .53025 L .43863 .54683 L 1 g
F
P
p
.002 w
.43863 .54683 m .43743 .5491 L p
.4454 .55602 L 1 g
F P
s
P
p
.45073 .56326 m .45361 .52629 L .45116 .5636 L 1 g
F
P
p
.44702 .5603 m .44734 .55866 L .45073 .56326 L 1 g
F
P
p
.44734 .55866 m .45361 .52629 L .45073 .56326 L 1 g
F
P
p
.002 w
.44581 .56652 m .45116 .5636 L p
.46829 .57396 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45073 .56326 L p
1 g
F P
s
P
p
.4454 .55602 m .43743 .5491 L .45073 .56326 L 1 g
F
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45361 .52629 m .47187 .5523 L .45116 .5636 L p
1 g
F P
s
P
p
.002 w
.45073 .56326 m .4507 .56333 L p
.45102 .56349 L 1 g
F P
s
P
p
.002 w
.4507 .56333 m .45002 .56518 L p
.46107 .56959 L 1 g
F P
s
P
p
.47677 .57676 m .46829 .57396 L .47187 .5523 L 1 g
F
P
p
.002 w
.45116 .5636 m .47187 .5523 L p
.46829 .57396 L 1 g
F P
s
P
p
.002 w
.4462 .56678 m .44581 .56652 L p
.47677 .57676 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46842 .57404 L p
1 g
F P
s
P
p
.46107 .56959 m .45002 .56518 L .46842 .57404 L 1 g
F
P
p
.50525 .58029 m .48906 .58059 L .49793 .57012 L 1 g
F
P
p
.002 w
.48755 .58062 m .4878 .58036 L p
.48906 .58059 L 1 g
F P
s
P
p
.48019 .57788 m .4878 .58036 L .48906 .58059 L 1 g
F
P
p
.002 w
.4878 .58036 m .49793 .57012 L p
.48906 .58059 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58077 L p
1 g
F P
s
P
p
.002 w
.48905 .58077 m .48906 .58059 L p
.48784 .58038 L 1 g
F P
s
P
p
.48784 .58038 m .4678 .57686 L .48905 .58077 L 1 g
F
P
p
.48019 .57788 m .46885 .57695 L .4878 .58036 L 1 g
F
P
p
.002 w
.47187 .5523 m .49793 .57012 L .4878 .58036 L p
1 g
F P
s
P
p
.47677 .57676 m .47187 .5523 L .4878 .58036 L 1 g
F
P
p
.46885 .57695 m .4678 .57686 L .48906 .58059 L 1 g
F
P
p
.002 w
.48906 .58059 m .48889 .583 L p
.50214 .58035 L 1 g
F P
s
P
p
.002 w
.51091 .58019 m .51111 .583 L p
.52077 .57804 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58019 L p
1 g
F P
s
P
p
.50214 .58035 m .48889 .583 L .51091 .58019 L 1 g
F
P
p
.004 w
.5 .43051 m
.52708 .4589 L
s
P
p
.002 w
.38074 .48971 m .3939 .53734 L .36953 .53795 L p
1 g
F P
s
P
p
.002 w
.36953 .53795 m .35448 .48455 L .38074 .48971 L p
1 g
F P
s
P
p
.002 w
.58711 .29388 m .53115 .28598 L .52327 .26428 L p
1 g
F P
s
P
p
.002 w
.46145 .27653 m .52327 .26428 L .53115 .28598 L p
1 g
F P
s
P
p
.002 w
.42222 .53345 m .44581 .56652 L .42208 .57632 L p
1 g
F P
s
P
p
.002 w
.42208 .57632 m .3939 .53734 L .42222 .53345 L p
1 g
F P
s
P
p
.002 w
.64535 .4819 m .64397 .4497 L .66486 .43595 L p
1 g
F P
s
P
p
.002 w
.64998 .3984 m .66486 .43595 L .64397 .4497 L p
1 g
F P
s
P
p
.002 w
.38189 .37264 m .35858 .42719 L .33752 .41615 L p
1 g
F P
s
P
p
.002 w
.33752 .41615 m .36249 .35735 L .38189 .37264 L p
1 g
F P
s
P
p
.002 w
.63121 .34234 m .58818 .31956 L .58711 .29388 L p
1 g
F P
s
P
p
.004 w
.60431 .30963 m
.60513 .30867 L
s
P
p
.004 w
.60513 .30867 m
.60926 .30389 L
s
P
p
.004 w
.60926 .30389 m
.61739 .29447 L
s
P
p
.004 w
.61739 .29447 m
.62604 .28445 L
s
P
p
.002 w
.53115 .28598 m .58711 .29388 L .58818 .31956 L p
1 g
F P
s
P
p
.002 w
.58229 .5416 m .60023 .52679 L .61792 .54146 L p
1 g
F P
s
P
p
.002 w
.61792 .54146 m .59207 .56282 L .58229 .5416 L p
1 g
F P
s
P
p
.002 w
.63632 .51355 m .61792 .54146 L .60023 .52679 L p
1 g
F P
s
P
p
.002 w
.60023 .52679 m .61296 .50742 L .63632 .51355 L p
1 g
F P
s
P
p
.002 w
.64535 .4819 m .63632 .51355 L .61296 .50742 L p
1 g
F P
s
P
p
.002 w
.53115 .28598 m .47378 .29753 L .46145 .27653 L p
1 g
F P
s
P
p
.002 w
.40554 .30881 m .46145 .27653 L .47378 .29753 L p
1 g
F P
s
P
p
.002 w
.64998 .3984 m .62302 .36836 L .63121 .34234 L p
1 g
F P
s
P
p
.002 w
.58818 .31956 m .63121 .34234 L .62302 .36836 L p
1 g
F P
s
P
p
.002 w
.4219 .32758 m .38189 .37264 L .36249 .35735 L p
1 g
F P
s
P
p
.002 w
.36249 .35735 m .40554 .30881 L .4219 .32758 L p
1 g
F P
s
P
p
.002 w
.38463 .43866 m .38074 .48971 L .35448 .48455 L p
1 g
F P
s
P
p
.002 w
.35448 .48455 m .35858 .42719 L .38463 .43866 L p
1 g
F P
s
P
p
.002 w
.61296 .50742 m .61914 .48549 L .64535 .4819 L p
1 g
F P
s
P
p
.002 w
.64397 .4497 m .64535 .4819 L .61914 .48549 L p
1 g
F P
s
P
p
.002 w
.47378 .29753 m .4219 .32758 L .40554 .30881 L p
1 g
F P
s
P
p
.002 w
.64397 .4497 m .63212 .42031 L .64998 .3984 L p
1 g
F P
s
P
p
.002 w
.62302 .36836 m .64998 .3984 L .63212 .42031 L p
1 g
F P
s
P
p
.002 w
.41138 .49319 m .42222 .53345 L .3939 .53734 L p
1 g
F P
s
P
p
.002 w
.3939 .53734 m .38074 .48971 L .41138 .49319 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.58818 .31956 m .53832 .31277 L .53115 .28598 L p
1 g
F P
s
P
p
.002 w
.47378 .29753 m .53115 .28598 L .53832 .31277 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61914 .48549 m .61807 .46325 L .64397 .4497 L p
1 g
F P
s
P
p
.002 w
.63212 .42031 m .64397 .4497 L .61807 .46325 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.62302 .36836 m .58657 .34936 L .58818 .31956 L p
1 g
F P
s
P
p
.002 w
.53832 .31277 m .58818 .31956 L .58657 .34936 L p
1 g
F P
s
P
p
.002 w
.40551 .39016 m .38463 .43866 L .35858 .42719 L p
1 g
F P
s
P
p
.002 w
.35858 .42719 m .38189 .37264 L .40551 .39016 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.49937 .53401 m .5172 .54641 L .49793 .57012 L p
1 g
F P
s
P
p
.002 w
.49793 .57012 m .47187 .5523 L .49937 .53401 L p
1 g
F P
s
P
p
.002 w
.56967 .51631 m .5789 .5087 L .60023 .52679 L p
1 g
F P
s
P
p
.002 w
.60023 .52679 m .58229 .5416 L .56967 .51631 L p
1 g
F P
s
P
p
.002 w
.61296 .50742 m .60023 .52679 L .5789 .5087 L p
1 g
F P
s
P
p
.002 w
.63212 .42031 m .61085 .39695 L .62302 .36836 L p
1 g
F P
s
P
p
.002 w
.58657 .34936 m .62302 .36836 L .61085 .39695 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.5789 .5087 m .58542 .49874 L .61296 .50742 L p
1 g
F P
s
P
p
.002 w
.61914 .48549 m .61296 .50742 L .58542 .49874 L p
1 g
F P
s
P
p
.002 w
.53832 .31277 m .48728 .32325 L .47378 .29753 L p
1 g
F P
s
P
p
.002 w
.4219 .32758 m .47378 .29753 L .48728 .32325 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.41488 .45016 m .41138 .49319 L .38074 .48971 L p
1 g
F P
s
P
p
.002 w
.38074 .48971 m .38463 .43866 L .41488 .45016 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.61807 .46325 m .60977 .44307 L .63212 .42031 L p
1 g
F P
s
P
p
.002 w
.61085 .39695 m .63212 .42031 L .60977 .44307 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.44115 .35007 m .40551 .39016 L .38189 .37264 L p
1 g
F P
s
P
p
.002 w
.38189 .37264 m .4219 .32758 L .44115 .35007 L p
1 g
F P
s
P
p
.002 w
.58542 .49874 m .58855 .48748 L .61914 .48549 L p
1 g
F P
s
P
p
.002 w
.61807 .46325 m .61914 .48549 L .58855 .48748 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48728 .32325 m .44115 .35007 L .4219 .32758 L p
1 g
F P
s
P
p
.002 w
.53633 .51863 m .5472 .52157 L .5385 .55201 L p
1 g
F P
s
P
p
.002 w
.5385 .55201 m .5172 .54641 L .53633 .51863 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48698 .51604 m .49937 .53401 L .47187 .5523 L p
1 g
F P
s
P
p
.002 w
.47187 .5523 m .45361 .52629 L .48698 .51604 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48728 .32325 m .53832 .31277 L .54448 .34388 L p
1 g
F P
s
P
p
.002 w
.58657 .34936 m .54448 .34388 L .53832 .31277 L p
1 g
F P
s
P
p
.002 w
.58855 .48748 m .58793 .4761 L .61807 .46325 L p
1 g
F P
s
P
p
.002 w
.60977 .44307 m .61807 .46325 L .58793 .4761 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.61085 .39695 m .58225 .38232 L .58657 .34936 L p
1 g
F P
s
P
p
.002 w
.54448 .34388 m .58657 .34936 L .58225 .38232 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.52729 .51222 m .53633 .51863 L .5172 .54641 L p
1 g
F P
s
P
p
.002 w
.5172 .54641 m .49937 .53401 L .52729 .51222 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.60977 .44307 m .59501 .42713 L .61085 .39695 L p
1 g
F P
s
P
p
.002 w
.58225 .38232 m .61085 .39695 L .59501 .42713 L p
1 g
F P
s
P
p
.002 w
.43261 .40934 m .41488 .45016 L .38463 .43866 L p
1 g
F P
s
P
p
.002 w
.38463 .43866 m .40551 .39016 L .43261 .40934 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.58542 .49874 m .5789 .5087 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.58793 .4761 m .58361 .46583 L .60977 .44307 L p
1 g
F P
s
P
p
.002 w
.59501 .42713 m .60977 .44307 L .58361 .46583 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58855 .48748 m .58542 .49874 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.41138 .49319 m .41488 .45016 L .4483 .46124 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54448 .34388 m .5015 .35289 L .48728 .32325 L p
1 g
F P
s
P
p
.002 w
.44115 .35007 m .48728 .32325 L .5015 .35289 L p
1 g
F P
s
P
p
.002 w
.4815 .4944 m .48698 .51604 L .45361 .52629 L p
1 g
F P
s
P
p
.002 w
.45361 .52629 m .44537 .49479 L .4815 .4944 L p
1 g
F P
s
P
p
.002 w
.58793 .4761 m .58855 .48748 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.52108 .50303 m .52729 .51222 L .49937 .53401 L p
1 g
F P
s
P
p
.002 w
.49937 .53401 m .48698 .51604 L .52108 .50303 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.46266 .37557 m .43261 .40934 L .40551 .39016 L p
1 g
F P
s
P
p
.002 w
.40551 .39016 m .44115 .35007 L .46266 .37557 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5015 .35289 m .46266 .37557 L .44115 .35007 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58361 .46583 m .58793 .4761 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.5015 .35289 m .54448 .34388 L .54937 .37826 L p
1 g
F P
s
P
p
.002 w
.58225 .38232 m .54937 .37826 L .54448 .34388 L p
1 g
F P
s
P
p
.002 w
.59501 .42713 m .57531 .41726 L .58225 .38232 L p
1 g
F P
s
P
p
.002 w
.54937 .37826 m .58225 .38232 L .57531 .41726 L p
1 g
F P
s
P
p
.002 w
.58361 .46583 m .57603 .45778 L .59501 .42713 L p
1 g
F P
s
P
p
.002 w
.57531 .41726 m .59501 .42713 L .57603 .45778 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57603 .45778 m .58361 .46583 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.46223 .42946 m .4483 .46124 L .41488 .45016 L p
1 g
F P
s
P
p
.002 w
.41488 .45016 m .43261 .40934 L .46223 .42946 L p
1 g
F P
s
P
p
.002 w
.51838 .49202 m .52108 .50303 L .48698 .51604 L p
1 g
F P
s
P
p
.002 w
.48698 .51604 m .4815 .4944 L .51838 .49202 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48364 .47145 m .4815 .4944 L .44537 .49479 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56597 .45285 m .57603 .45778 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.57603 .45778 m .56597 .45285 L .57531 .41726 L p
1 g
F P
s
P
p
.002 w
.54296 .45421 m .55453 .45161 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.53254 .46038 m .54296 .45421 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.55453 .45161 m .56597 .45285 L .55459 .48774 L closepath p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.54937 .37826 m .51589 .38544 L .5015 .35289 L p
1 g
F P
s
P
p
.002 w
.46266 .37557 m .5015 .35289 L .51589 .38544 L p
1 g
F P
s
P
p
.002 w
.55277 .41464 m .57531 .41726 L .56597 .45285 L p
1 g
F P
s
P
p
.002 w
.57531 .41726 m .55277 .41464 L .54937 .37826 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51589 .38544 m .54937 .37826 L .55277 .41464 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.48566 .40317 m .46223 .42946 L .43261 .40934 L p
1 g
F P
s
P
p
.002 w
.43261 .40934 m .46266 .37557 L .48566 .40317 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.56597 .45285 m .55453 .45161 L .55277 .41464 L p
1 g
F P
s
P
p
.002 w
.51954 .4804 m .51838 .49202 L .4815 .4944 L p
1 g
F P
s
P
p
.002 w
.4815 .4944 m .48364 .47145 L .51954 .4804 L p
1 g
F P
s
P
p
.002 w
.51589 .38544 m .48566 .40317 L .46266 .37557 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.004 w
.55459 .48774 m
.55634 .48957 L
s
P
p
.002 w
.4483 .46124 m .46223 .42946 L .49324 .44977 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55453 .45161 m .54296 .45421 L .52989 .41966 L p
1 g
F P
s
P
p
.002 w
.52989 .41966 m .55277 .41464 L .55453 .45161 L p
1 g
F P
s
P
p
.002 w
.55277 .41464 m .52989 .41966 L .51589 .38544 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.52444 .46945 m .51954 .4804 L .48364 .47145 L p
1 g
F P
s
P
p
.002 w
.54296 .45421 m .53254 .46038 L .50926 .43182 L p
1 g
F P
s
P
p
.002 w
.50926 .43182 m .52989 .41966 L .54296 .45421 L p
1 g
F P
s
P
p
.002 w
.48566 .40317 m .51589 .38544 L .52989 .41966 L p
1 g
F P
s
P
p
.002 w
.49324 .44977 m .50926 .43182 L .53254 .46038 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.50926 .43182 m .49324 .44977 L .46223 .42946 L p
1 g
F P
s
P
p
.002 w
.46223 .42946 m .48566 .40317 L .50926 .43182 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52989 .41966 m .50926 .43182 L .48566 .40317 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.55634 .48957 m
.58805 .52282 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .66619 .23791 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58805 .52282 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.564341)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.564341)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48866 .46496 m .51834 .44644 L .49997 .42459 L p
1 g
F P
s
P
p
.002 w
.49997 .42459 m .47698 .4389 L .48866 .46496 L p
1 g
F P
s
P
p
.002 w
.5179 .4044 m .49997 .42459 L .51834 .44644 L p
1 g
F P
s
P
p
.002 w
.47698 .4389 m .49997 .42459 L .48158 .40287 L p
1 g
F P
s
P
p
.002 w
.49997 .42459 m .5179 .4044 L .49381 .38904 L p
1 g
F P
s
P
p
.002 w
.49381 .38904 m .48158 .40287 L .49997 .42459 L p
1 g
F P
s
P
p
.002 w
.50068 .49033 m .53636 .46801 L .51834 .44644 L p
1 g
F P
s
P
p
.002 w
.51834 .44644 m .48866 .46496 L .50068 .49033 L p
1 g
F P
s
P
p
.002 w
.54157 .42039 m .51834 .44644 L .53636 .46801 L p
1 g
F P
s
P
p
.002 w
.51834 .44644 m .54157 .42039 L .5179 .4044 L p
1 g
F P
s
P
p
.002 w
.4554 .4741 m .48866 .46496 L .47698 .4389 L p
1 g
F P
s
P
p
.002 w
.47698 .4389 m .45123 .44586 L .4554 .4741 L p
1 g
F P
s
P
p
.002 w
.45123 .44586 m .47698 .4389 L .46586 .41263 L p
1 g
F P
s
P
p
.002 w
.48158 .40287 m .46586 .41263 L .47698 .4389 L p
1 g
F P
s
P
p
.002 w
.52897 .38031 m .5179 .4044 L .54157 .42039 L p
1 g
F P
s
P
p
.002 w
.5179 .4044 m .52897 .38031 L .50128 .37256 L p
1 g
F P
s
P
p
.002 w
.50128 .37256 m .49381 .38904 L .5179 .4044 L p
1 g
F P
s
P
p
.002 w
.46586 .41263 m .48158 .40287 L .4635 .38166 L p
1 g
F P
s
P
p
.002 w
.48158 .40287 m .49381 .38904 L .46972 .3746 L p
1 g
F P
s
P
p
.002 w
.46972 .3746 m .4635 .38166 L .48158 .40287 L p
1 g
F P
s
P
p
.002 w
.4607 .50151 m .50068 .49033 L .48866 .46496 L p
1 g
F P
s
P
p
.002 w
.48866 .46496 m .4554 .4741 L .4607 .50151 L p
1 g
F P
s
P
p
.002 w
.46586 .41263 m .44825 .41731 L .45123 .44586 L p
1 g
F P
s
P
p
.002 w
.44825 .41731 m .46586 .41263 L .45549 .38662 L p
1 g
F P
s
P
p
.002 w
.4635 .38166 m .45549 .38662 L .46586 .41263 L p
1 g
F P
s
P
p
.002 w
.49381 .38904 m .50128 .37256 L .47348 .3662 L p
1 g
F P
s
P
p
.002 w
.47348 .3662 m .46972 .3746 L .49381 .38904 L p
1 g
F P
s
P
p
.002 w
.53636 .46801 m .56437 .43673 L .54157 .42039 L p
1 g
F P
s
P
p
.002 w
.55603 .38931 m .54157 .42039 L .56437 .43673 L p
1 g
F P
s
P
p
.002 w
.54157 .42039 m .55603 .38931 L .52897 .38031 L p
1 g
F P
s
P
p
.002 w
.42181 .47284 m .4554 .4741 L .45123 .44586 L p
1 g
F P
s
P
p
.002 w
.45123 .44586 m .42529 .4447 L .42181 .47284 L p
1 g
F P
s
P
p
.002 w
.42529 .4447 m .45123 .44586 L .44825 .41731 L p
1 g
F P
s
P
p
.002 w
.51283 .51455 m .55371 .48893 L .53636 .46801 L p
1 g
F P
s
P
p
.002 w
.53636 .46801 m .50068 .49033 L .51283 .51455 L p
1 g
F P
s
P
p
.002 w
.56437 .43673 m .53636 .46801 L .55371 .48893 L p
1 g
F P
s
P
p
.002 w
.44825 .41731 m .43057 .41639 L .42529 .4447 L p
1 g
F P
s
P
p
.002 w
.43057 .41639 m .44825 .41731 L .44652 .38896 L p
1 g
F P
s
P
p
.002 w
.45549 .38662 m .44652 .38896 L .44825 .41731 L p
1 g
F P
s
P
p
.002 w
.53194 .35472 m .52897 .38031 L .55603 .38931 L p
1 g
F P
s
P
p
.002 w
.52897 .38031 m .53194 .35472 L .50317 .35511 L p
1 g
F P
s
P
p
.002 w
.50317 .35511 m .50128 .37256 L .52897 .38031 L p
1 g
F P
s
P
p
.002 w
.50128 .37256 m .50317 .35511 L .47437 .35733 L p
1 g
F P
s
P
p
.002 w
.47437 .35733 m .47348 .3662 L .50128 .37256 L p
1 g
F P
s
P
p
.002 w
.46704 .52755 m .51283 .51455 L .50068 .49033 L p
1 g
F P
s
P
p
.002 w
.50068 .49033 m .4607 .50151 L .46704 .52755 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .45549 .38662 L .4635 .38166 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .4635 .38166 L .46972 .3746 L closepath p
1 g
F P
s
P
p
.002 w
.42022 .50026 m .4607 .50151 L .4554 .4741 L p
1 g
F P
s
P
p
.002 w
.4554 .4741 m .42181 .47284 L .42022 .50026 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .44652 .38896 L .45549 .38662 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .46972 .3746 L .47348 .3662 L closepath p
1 g
F P
s
P
p
.002 w
.55371 .48893 m .58589 .45312 L .56437 .43673 L p
1 g
F P
s
P
p
.002 w
.58197 .39939 m .56437 .43673 L .58589 .45312 L p
1 g
F P
s
P
p
.002 w
.56437 .43673 m .58197 .39939 L .55603 .38931 L p
1 g
F P
s
P
p
.002 w
.44652 .38896 m .43754 .38844 L .43057 .41639 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .43754 .38844 L .44652 .38896 L closepath p
1 g
F P
s
P
p
.002 w
.56013 .3562 m .55603 .38931 L .58197 .39939 L p
1 g
F P
s
P
p
.002 w
.55603 .38931 m .56013 .3562 L .53194 .35472 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .47348 .3662 L .47437 .35733 L closepath p
1 g
F P
s
P
p
.002 w
.40184 .43538 m .42529 .4447 L .43057 .41639 L p
1 g
F P
s
P
p
.002 w
.43057 .41639 m .41466 .4099 L .40184 .43538 L p
1 g
F P
s
P
p
.002 w
.41466 .4099 m .43057 .41639 L .43754 .38844 L p
1 g
F P
s
P
p
.002 w
.43754 .38844 m .42951 .38507 L .41466 .4099 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .42951 .38507 L .43754 .38844 L closepath p
1 g
F P
s
P
p
.002 w
.4992 .3385 m .50317 .35511 L .53194 .35472 L p
1 g
F P
s
P
p
.002 w
.50317 .35511 m .4992 .3385 L .47228 .34894 L p
1 g
F P
s
P
p
.002 w
.47228 .34894 m .47437 .35733 L .50317 .35511 L p
1 g
F P
s
P
p
.002 w
.39129 .46102 m .42181 .47284 L .42529 .4447 L p
1 g
F P
s
P
p
.002 w
.42529 .4447 m .40184 .43538 L .39129 .46102 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .47437 .35733 L .47228 .34894 L closepath p
1 g
F P
s
P
p
.002 w
.52489 .53714 m .57004 .50877 L .55371 .48893 L p
1 g
F P
s
P
p
.002 w
.55371 .48893 m .51283 .51455 L .52489 .53714 L p
1 g
F P
s
P
p
.002 w
.58589 .45312 m .55371 .48893 L .57004 .50877 L p
1 g
F P
s
P
p
.002 w
.42059 .52642 m .46704 .52755 L .4607 .50151 L p
1 g
F P
s
P
p
.002 w
.4607 .50151 m .42022 .50026 L .42059 .52642 L p
1 g
F P
s
P
p
.002 w
.52634 .33026 m .53194 .35472 L .56013 .3562 L p
1 g
F P
s
P
p
.002 w
.53194 .35472 m .52634 .33026 L .4992 .3385 L p
1 g
F P
s
P
p
.002 w
.40226 .39843 m .41466 .4099 L .42951 .38507 L p
1 g
F P
s
P
p
.002 w
.42951 .38507 m .4233 .3792 L .40226 .39843 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .4233 .3792 L .42951 .38507 L closepath p
1 g
F P
s
P
p
.002 w
.47433 .5517 m .52489 .53714 L .51283 .51455 L p
1 g
F P
s
P
p
.002 w
.51283 .51455 m .46704 .52755 L .47433 .5517 L p
1 g
F P
s
P
p
.002 w
.4674 .34193 m .47228 .34894 L .4992 .3385 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .47228 .34894 L .4674 .34193 L closepath p
1 g
F P
s
P
p
.002 w
.58589 .45312 m .60627 .4104 L .58197 .39939 L p
1 g
F P
s
P
p
.002 w
.58721 .35953 m .58197 .39939 L .60627 .4104 L p
1 g
F P
s
P
p
.002 w
.58197 .39939 m .58721 .35953 L .56013 .3562 L p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .46024 .33709 L .45157 .33496 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .45157 .33496 L .44233 .3358 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .44233 .3358 L .43355 .33953 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .43355 .33953 L .4262 .34574 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .4262 .34574 L .42111 .35374 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .42111 .35374 L .41883 .36264 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .41883 .36264 L .41959 .37145 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .41959 .37145 L .4233 .3792 L closepath p
1 g
F P
s
P
p
.002 w
.44608 .36135 m .4674 .34193 L .46024 .33709 L closepath p
1 g
F P
s
P
p
.002 w
.3834 .41868 m .40184 .43538 L .41466 .4099 L p
1 g
F P
s
P
p
.002 w
.41466 .4099 m .40226 .39843 L .3834 .41868 L p
1 g
F P
s
P
p
.002 w
.57004 .50877 m .60567 .46926 L .58589 .45312 L p
1 g
F P
s
P
p
.002 w
.60627 .4104 m .58589 .45312 L .60567 .46926 L p
1 g
F P
s
P
p
.002 w
.38329 .48633 m .42022 .50026 L .42181 .47284 L p
1 g
F P
s
P
p
.002 w
.42181 .47284 m .39129 .46102 L .38329 .48633 L p
1 g
F P
s
P
p
.002 w
.4897 .32455 m .4992 .3385 L .52634 .33026 L p
1 g
F P
s
P
p
.002 w
.4992 .3385 m .4897 .32455 L .4674 .34193 L p
1 g
F P
s
P
p
.002 w
.39477 .38314 m .40226 .39843 L .4233 .3792 L p
1 g
F P
s
P
p
.002 w
.4233 .3792 m .41959 .37145 L .39477 .38314 L p
1 g
F P
s
P
p
.002 w
.46024 .33709 m .4674 .34193 L .4897 .32455 L p
1 g
F P
s
P
p
.002 w
.55317 .3244 m .56013 .3562 L .58721 .35953 L p
1 g
F P
s
P
p
.002 w
.56013 .3562 m .55317 .3244 L .52634 .33026 L p
1 g
F P
s
P
p
.002 w
.36715 .43957 m .39129 .46102 L .40184 .43538 L p
1 g
F P
s
P
p
.002 w
.40184 .43538 m .3834 .41868 L .36715 .43957 L p
1 g
F P
s
P
p
.002 w
.39311 .36565 m .39477 .38314 L .41959 .37145 L p
1 g
F P
s
P
p
.002 w
.41959 .37145 m .41883 .36264 L .39311 .36565 L p
1 g
F P
s
P
p
.002 w
.45157 .33496 m .46024 .33709 L .4756 .31481 L p
1 g
F P
s
P
p
.002 w
.4897 .32455 m .4756 .31481 L .46024 .33709 L p
1 g
F P
s
P
p
.002 w
.42298 .55075 m .47433 .5517 L .46704 .52755 L p
1 g
F P
s
P
p
.002 w
.46704 .52755 m .42059 .52642 L .42298 .55075 L p
1 g
F P
s
P
p
.002 w
.37214 .39623 m .3834 .41868 L .40226 .39843 L p
1 g
F P
s
P
p
.002 w
.40226 .39843 m .39477 .38314 L .37214 .39623 L p
1 g
F P
s
P
p
.002 w
.51255 .30956 m .52634 .33026 L .55317 .3244 L p
1 g
F P
s
P
p
.002 w
.52634 .33026 m .51255 .30956 L .4897 .32455 L p
1 g
F P
s
P
p
.002 w
.53661 .55759 m .585 .52712 L .57004 .50877 L p
1 g
F P
s
P
p
.002 w
.57004 .50877 m .52489 .53714 L .53661 .55759 L p
1 g
F P
s
P
p
.002 w
.60567 .46926 m .57004 .50877 L .585 .52712 L p
1 g
F P
s
P
p
.002 w
.39756 .34789 m .39311 .36565 L .41883 .36264 L p
1 g
F P
s
P
p
.002 w
.41883 .36264 m .42111 .35374 L .39756 .34789 L p
1 g
F P
s
P
p
.002 w
.37807 .51078 m .42059 .52642 L .42022 .50026 L p
1 g
F P
s
P
p
.002 w
.42022 .50026 m .38329 .48633 L .37807 .51078 L p
1 g
F P
s
P
p
.002 w
.4756 .31481 m .4897 .32455 L .51255 .30956 L p
1 g
F P
s
P
p
.002 w
.4756 .31481 m .45838 .31044 L .45157 .33496 L p
1 g
F P
s
P
p
.002 w
.44233 .3358 m .45157 .33496 L .45838 .31044 L p
1 g
F P
s
P
p
.002 w
.60567 .46926 m .62841 .42213 L .60627 .4104 L p
1 g
F P
s
P
p
.002 w
.6126 .36471 m .60627 .4104 L .62841 .42213 L p
1 g
F P
s
P
p
.002 w
.60627 .4104 m .6126 .36471 L .58721 .35953 L p
1 g
F P
s
P
p
.002 w
.48244 .57339 m .53661 .55759 L .52489 .53714 L p
1 g
F P
s
P
p
.002 w
.52489 .53714 m .47433 .5517 L .48244 .57339 L p
1 g
F P
s
P
p
.002 w
.40769 .33187 m .39756 .34789 L .42111 .35374 L p
1 g
F P
s
P
p
.002 w
.42111 .35374 m .4262 .34574 L .40769 .33187 L p
1 g
F P
s
P
p
.002 w
.45838 .31044 m .43995 .31202 L .44233 .3358 L p
1 g
F P
s
P
p
.002 w
.43355 .33953 m .44233 .3358 L .43995 .31202 L p
1 g
F P
s
P
p
.002 w
.42238 .31944 m .40769 .33187 L .4262 .34574 L p
1 g
F P
s
P
p
.002 w
.4262 .34574 m .43355 .33953 L .42238 .31944 L p
1 g
F P
s
P
p
.002 w
.57915 .3211 m .58721 .35953 L .6126 .36471 L p
1 g
F P
s
P
p
.002 w
.58721 .35953 m .57915 .3211 L .55317 .3244 L p
1 g
F P
s
P
p
.002 w
.585 .52712 m .62329 .48481 L .60567 .46926 L p
1 g
F P
s
P
p
.002 w
.62841 .42213 m .60567 .46926 L .62329 .48481 L p
1 g
F P
s
P
p
.002 w
.43995 .31202 m .42238 .31944 L .43355 .33953 L p
1 g
F P
s
P
p
.002 w
.3539 .4607 m .38329 .48633 L .39129 .46102 L p
1 g
F P
s
P
p
.002 w
.39129 .46102 m .36715 .43957 L .3539 .4607 L p
1 g
F P
s
P
p
.002 w
.36949 .37036 m .37214 .39623 L .39477 .38314 L p
1 g
F P
s
P
p
.002 w
.39477 .38314 m .39311 .36565 L .36949 .37036 L p
1 g
F P
s
P
p
.002 w
.35223 .41048 m .36715 .43957 L .3834 .41868 L p
1 g
F P
s
P
p
.002 w
.3834 .41868 m .37214 .39623 L .35223 .41048 L p
1 g
F P
s
P
p
.002 w
.45838 .31044 m .4756 .31481 L .49187 .29499 L p
1 g
F P
s
P
p
.002 w
.51255 .30956 m .49187 .29499 L .4756 .31481 L p
1 g
F P
s
P
p
.002 w
.53552 .29734 m .55317 .3244 L .57915 .3211 L p
1 g
F P
s
P
p
.002 w
.55317 .3244 m .53552 .29734 L .51255 .30956 L p
1 g
F P
s
P
p
.002 w
.49187 .29499 m .51255 .30956 L .53552 .29734 L p
1 g
F P
s
P
p
.002 w
.4274 .57268 m .48244 .57339 L .47433 .5517 L p
1 g
F P
s
P
p
.002 w
.47433 .5517 m .42298 .55075 L .4274 .57268 L p
1 g
F P
s
P
p
.002 w
.37584 .53381 m .42298 .55075 L .42059 .52642 L p
1 g
F P
s
P
p
.002 w
.42059 .52642 m .37807 .51078 L .37584 .53381 L p
1 g
F P
s
P
p
.002 w
.37596 .34397 m .36949 .37036 L .39311 .36565 L p
1 g
F P
s
P
p
.002 w
.39311 .36565 m .39756 .34789 L .37596 .34397 L p
1 g
F P
s
P
p
.002 w
.49187 .29499 m .46642 .28835 L .45838 .31044 L p
1 g
F P
s
P
p
.002 w
.43995 .31202 m .45838 .31044 L .46642 .28835 L p
1 g
F P
s
P
p
.002 w
.54774 .57541 m .59823 .54355 L .585 .52712 L p
1 g
F P
s
P
p
.002 w
.585 .52712 m .53661 .55759 L .54774 .57541 L p
1 g
F P
s
P
p
.002 w
.62329 .48481 m .585 .52712 L .59823 .54355 L p
1 g
F P
s
P
p
.002 w
.62329 .48481 m .64787 .43438 L .62841 .42213 L p
1 g
F P
s
P
p
.002 w
.63574 .37167 m .62841 .42213 L .64787 .43438 L p
1 g
F P
s
P
p
.002 w
.62841 .42213 m .63574 .37167 L .6126 .36471 L p
1 g
F P
s
P
p
.002 w
.34406 .48161 m .37807 .51078 L .38329 .48633 L p
1 g
F P
s
P
p
.002 w
.38329 .48633 m .3539 .4607 L .34406 .48161 L p
1 g
F P
s
P
p
.002 w
.60372 .32051 m .6126 .36471 L .63574 .37167 L p
1 g
F P
s
P
p
.002 w
.6126 .36471 m .60372 .32051 L .57915 .3211 L p
1 g
F P
s
P
p
.002 w
.39097 .32009 m .37596 .34397 L .39756 .34789 L p
1 g
F P
s
P
p
.002 w
.39756 .34789 m .40769 .33187 L .39097 .32009 L p
1 g
F P
s
P
p
.002 w
.49126 .59207 m .54774 .57541 L .53661 .55759 L p
1 g
F P
s
P
p
.002 w
.53661 .55759 m .48244 .57339 L .49126 .59207 L p
1 g
F P
s
P
p
.002 w
.34854 .37675 m .35223 .41048 L .37214 .39623 L p
1 g
F P
s
P
p
.002 w
.37214 .39623 m .36949 .37036 L .34854 .37675 L p
1 g
F P
s
P
p
.002 w
.46642 .28835 m .43902 .29059 L .43995 .31202 L p
1 g
F P
s
P
p
.002 w
.42238 .31944 m .43995 .31202 L .43902 .29059 L p
1 g
F P
s
P
p
.002 w
.33557 .42565 m .3539 .4607 L .36715 .43957 L p
1 g
F P
s
P
p
.002 w
.36715 .43957 m .35223 .41048 L .33557 .42565 L p
1 g
F P
s
P
p
.002 w
.59823 .54355 m .63827 .49943 L .62329 .48481 L p
1 g
F P
s
P
p
.002 w
.64787 .43438 m .62329 .48481 L .63827 .49943 L p
1 g
F P
s
P
p
.002 w
.55812 .28822 m .57915 .3211 L .60372 .32051 L p
1 g
F P
s
P
p
.002 w
.57915 .3211 m .55812 .28822 L .53552 .29734 L p
1 g
F P
s
P
p
.002 w
.41285 .30157 m .39097 .32009 L .40769 .33187 L p
1 g
F P
s
P
p
.002 w
.40769 .33187 m .42238 .31944 L .41285 .30157 L p
1 g
F P
s
P
p
.002 w
.43902 .29059 m .41285 .30157 L .42238 .31944 L p
1 g
F P
s
P
p
.002 w
.46642 .28835 m .49187 .29499 L .50874 .27814 L p
1 g
F P
s
P
p
.002 w
.53552 .29734 m .50874 .27814 L .49187 .29499 L p
1 g
F P
s
P
p
.002 w
.50874 .27814 m .53552 .29734 L .55812 .28822 L p
1 g
F P
s
P
p
.002 w
.37678 .55484 m .4274 .57268 L .42298 .55075 L p
1 g
F P
s
P
p
.002 w
.42298 .55075 m .37584 .53381 L .37678 .55484 L p
1 g
F P
s
P
p
.002 w
.35687 .34216 m .34854 .37675 L .36949 .37036 L p
1 g
F P
s
P
p
.002 w
.36949 .37036 m .37596 .34397 L .35687 .34216 L p
1 g
F P
s
P
p
.002 w
.43385 .5916 m .49126 .59207 L .48244 .57339 L p
1 g
F P
s
P
p
.002 w
.48244 .57339 m .4274 .57268 L .43385 .5916 L p
1 g
F P
s
P
p
.002 w
.338 .50182 m .37584 .53381 L .37807 .51078 L p
1 g
F P
s
P
p
.002 w
.37807 .51078 m .34406 .48161 L .338 .50182 L p
1 g
F P
s
P
p
.002 w
.50874 .27814 m .47555 .26927 L .46642 .28835 L p
1 g
F P
s
P
p
.002 w
.43902 .29059 m .46642 .28835 L .47555 .26927 L p
1 g
F P
s
P
p
.002 w
.63827 .49943 m .66411 .4469 L .64787 .43438 L p
1 g
F P
s
P
p
.002 w
.65603 .38034 m .64787 .43438 L .66411 .4469 L p
1 g
F P
s
P
p
.002 w
.64787 .43438 m .65603 .38034 L .63574 .37167 L p
1 g
F P
s
P
p
.002 w
.62628 .32273 m .63574 .37167 L .65603 .38034 L p
1 g
F P
s
P
p
.002 w
.63574 .37167 m .62628 .32273 L .60372 .32051 L p
1 g
F P
s
P
p
.002 w
.33086 .38475 m .33557 .42565 L .35223 .41048 L p
1 g
F P
s
P
p
.002 w
.35223 .41048 m .34854 .37675 L .33086 .38475 L p
1 g
F P
s
P
p
.002 w
.32269 .44142 m .34406 .48161 L .3539 .4607 L p
1 g
F P
s
P
p
.002 w
.3539 .4607 m .33557 .42565 L .32269 .44142 L p
1 g
F P
s
P
p
.002 w
.55801 .59008 m .60938 .55761 L .59823 .54355 L p
1 g
F P
s
P
p
.002 w
.59823 .54355 m .54774 .57541 L .55801 .59008 L p
1 g
F P
s
P
p
.002 w
.63827 .49943 m .59823 .54355 L .60938 .55761 L p
1 g
F P
s
P
p
.002 w
.57985 .28252 m .60372 .32051 L .62628 .32273 L p
1 g
F P
s
P
p
.002 w
.60372 .32051 m .57985 .28252 L .55812 .28822 L p
1 g
F P
s
P
p
.002 w
.37651 .31078 m .35687 .34216 L .37596 .34397 L p
1 g
F P
s
P
p
.002 w
.37596 .34397 m .39097 .32009 L .37651 .31078 L p
1 g
F P
s
P
p
.002 w
.5006 .60717 m .55801 .59008 L .54774 .57541 L p
1 g
F P
s
P
p
.002 w
.54774 .57541 m .49126 .59207 L .5006 .60717 L p
1 g
F P
s
P
p
.002 w
.47555 .26927 m .50874 .27814 L .52587 .26474 L p
1 g
F P
s
P
p
.002 w
.55812 .28822 m .52587 .26474 L .50874 .27814 L p
1 g
F P
s
P
p
.002 w
.47555 .26927 m .43965 .27206 L .43902 .29059 L p
1 g
F P
s
P
p
.002 w
.41285 .30157 m .43902 .29059 L .43965 .27206 L p
1 g
F P
s
P
p
.002 w
.52587 .26474 m .55812 .28822 L .57985 .28252 L p
1 g
F P
s
P
p
.002 w
.60938 .55761 m .65018 .51277 L .63827 .49943 L p
1 g
F P
s
P
p
.002 w
.66411 .4469 m .63827 .49943 L .65018 .51277 L p
1 g
F P
s
P
p
.002 w
.40525 .28643 m .37651 .31078 L .39097 .32009 L p
1 g
F P
s
P
p
.002 w
.39097 .32009 m .41285 .30157 L .40525 .28643 L p
1 g
F P
s
P
p
.002 w
.43965 .27206 m .40525 .28643 L .41285 .30157 L p
1 g
F P
s
P
p
.002 w
.38102 .5733 m .43385 .5916 L .4274 .57268 L p
1 g
F P
s
P
p
.002 w
.4274 .57268 m .37678 .55484 L .38102 .5733 L p
1 g
F P
s
P
p
.002 w
.34085 .34261 m .33086 .38475 L .34854 .37675 L p
1 g
F P
s
P
p
.002 w
.34854 .37675 m .35687 .34216 L .34085 .34261 L p
1 g
F P
s
P
p
.002 w
.33604 .52082 m .37678 .55484 L .37584 .53381 L p
1 g
F P
s
P
p
.002 w
.37584 .53381 m .338 .50182 L .33604 .52082 L p
1 g
F P
s
P
p
.002 w
.44228 .60691 m .5006 .60717 L .49126 .59207 L p
1 g
F P
s
P
p
.002 w
.49126 .59207 m .43385 .5916 L .44228 .60691 L p
1 g
F P
s
P
p
.002 w
.52587 .26474 m .48563 .25375 L .47555 .26927 L p
1 g
F P
s
P
p
.002 w
.43965 .27206 m .47555 .26927 L .48563 .25375 L p
1 g
F P
s
P
p
.002 w
.66411 .4469 m .67291 .3906 L .65603 .38034 L p
1 g
F P
s
P
p
.002 w
.64624 .32785 m .65603 .38034 L .67291 .3906 L p
1 g
F P
s
P
p
.002 w
.65603 .38034 m .64624 .32785 L .62628 .32273 L p
1 g
F P
s
P
p
.002 w
.31409 .45745 m .338 .50182 L .34406 .48161 L p
1 g
F P
s
P
p
.002 w
.34406 .48161 m .32269 .44142 L .31409 .45745 L p
1 g
F P
s
P
p
.002 w
.31704 .39426 m .32269 .44142 L .33557 .42565 L p
1 g
F P
s
P
p
.002 w
.33557 .42565 m .33086 .38475 L .31704 .39426 L p
1 g
F P
s
P
p
.002 w
.65018 .51277 m .67662 .45943 L .66411 .4469 L p
1 g
F P
s
P
p
.002 w
.67291 .3906 m .66411 .4469 L .67662 .45943 L p
1 g
F P
s
P
p
.002 w
.60018 .28053 m .62628 .32273 L .64624 .32785 L p
1 g
F P
s
P
p
.002 w
.62628 .32273 m .60018 .28053 L .57985 .28252 L p
1 g
F P
s
P
p
.002 w
.56714 .60109 m .61807 .56886 L .60938 .55761 L p
1 g
F P
s
P
p
.002 w
.60938 .55761 m .55801 .59008 L .56714 .60109 L p
1 g
F P
s
P
p
.002 w
.65018 .51277 m .60938 .55761 L .61807 .56886 L p
1 g
F P
s
P
p
.002 w
.48563 .25375 m .52587 .26474 L .54289 .25525 L p
1 g
F P
s
P
p
.002 w
.57985 .28252 m .54289 .25525 L .52587 .26474 L p
1 g
F P
s
P
p
.002 w
.54289 .25525 m .57985 .28252 L .60018 .28053 L p
1 g
F P
s
P
p
.002 w
.36475 .30428 m .34085 .34261 L .35687 .34216 L p
1 g
F P
s
P
p
.002 w
.35687 .34216 m .37651 .31078 L .36475 .30428 L p
1 g
F P
s
P
p
.002 w
.48563 .25375 m .44188 .25703 L .43965 .27206 L p
1 g
F P
s
P
p
.002 w
.40525 .28643 m .43965 .27206 L .44188 .25703 L p
1 g
F P
s
P
p
.002 w
.51029 .61814 m .56714 .60109 L .55801 .59008 L p
1 g
F P
s
P
p
.002 w
.55801 .59008 m .5006 .60717 L .51029 .61814 L p
1 g
F P
s
P
p
.002 w
.61807 .56886 m .65857 .52443 L .65018 .51277 L p
1 g
F P
s
P
p
.002 w
.67662 .45943 m .65018 .51277 L .65857 .52443 L p
1 g
F P
s
P
p
.002 w
.39986 .27452 m .36475 .30428 L .37651 .31078 L p
1 g
F P
s
P
p
.002 w
.37651 .31078 m .40525 .28643 L .39986 .27452 L p
1 g
F P
s
P
p
.002 w
.44188 .25703 m .39986 .27452 L .40525 .28643 L p
1 g
F P
s
P
p
.002 w
.38863 .58856 m .44228 .60691 L .43385 .5916 L p
1 g
F P
s
P
p
.002 w
.43385 .5916 m .38102 .5733 L .38863 .58856 L p
1 g
F P
s
P
p
.002 w
.33846 .53806 m .38102 .5733 L .37678 .55484 L p
1 g
F P
s
P
p
.002 w
.37678 .55484 m .33604 .52082 L .33846 .53806 L p
1 g
F P
s
P
p
.002 w
.32848 .34544 m .31704 .39426 L .33086 .38475 L p
1 g
F P
s
P
p
.002 w
.33086 .38475 m .34085 .34261 L .32848 .34544 L p
1 g
F P
s
P
p
.002 w
.4526 .61804 m .51029 .61814 L .5006 .60717 L p
1 g
F P
s
P
p
.002 w
.5006 .60717 m .44228 .60691 L .4526 .61804 L p
1 g
F P
s
P
p
.002 w
.31021 .47335 m .33604 .52082 L .338 .50182 L p
1 g
F P
s
P
p
.002 w
.338 .50182 m .31409 .45745 L .31021 .47335 L p
1 g
F P
s
P
p
.002 w
.54289 .25525 m .49647 .24238 L .48563 .25375 L p
1 g
F P
s
P
p
.002 w
.44188 .25703 m .48563 .25375 L .49647 .24238 L p
1 g
F P
s
P
p
.002 w
.67662 .45943 m .68577 .4023 L .67291 .3906 L p
1 g
F P
s
P
p
.002 w
.66299 .33589 m .67291 .3906 L .68577 .4023 L p
1 g
F P
s
P
p
.002 w
.67291 .3906 m .66299 .33589 L .64624 .32785 L p
1 g
F P
s
P
p
.002 w
.30764 .40511 m .31409 .45745 L .32269 .44142 L p
1 g
F P
s
P
p
.002 w
.32269 .44142 m .31704 .39426 L .30764 .40511 L p
1 g
F P
s
P
p
.002 w
.61852 .28249 m .64624 .32785 L .66299 .33589 L p
1 g
F P
s
P
p
.002 w
.64624 .32785 m .61852 .28249 L .60018 .28053 L p
1 g
F P
s
P
p
.002 w
.65857 .52443 m .68488 .47166 L .67662 .45943 L p
1 g
F P
s
P
p
.002 w
.68577 .4023 m .67662 .45943 L .68488 .47166 L p
1 g
F P
s
P
p
.002 w
.55937 .25011 m .60018 .28053 L .61852 .28249 L p
1 g
F P
s
P
p
.002 w
.60018 .28053 m .55937 .25011 L .54289 .25525 L p
1 g
F P
s
P
p
.002 w
.49647 .24238 m .54289 .25525 L .55937 .25011 L p
1 g
F P
s
P
p
.002 w
.35617 .30092 m .32848 .34544 L .34085 .34261 L p
1 g
F P
s
P
p
.002 w
.34085 .34261 m .36475 .30428 L .35617 .30092 L p
1 g
F P
s
P
p
.002 w
.57483 .60795 m .62394 .57685 L .61807 .56886 L p
1 g
F P
s
P
p
.002 w
.61807 .56886 m .56714 .60109 L .57483 .60795 L p
1 g
F P
s
P
p
.002 w
.65857 .52443 m .61807 .56886 L .62394 .57685 L p
1 g
F P
s
P
p
.002 w
.49647 .24238 m .44578 .24606 L .44188 .25703 L p
1 g
F P
s
P
p
.002 w
.39986 .27452 m .44188 .25703 L .44578 .24606 L p
1 g
F P
s
P
p
.002 w
.52009 .62445 m .57483 .60795 L .56714 .60109 L p
1 g
F P
s
P
p
.002 w
.56714 .60109 m .51029 .61814 L .52009 .62445 L p
1 g
F P
s
P
p
.002 w
.62394 .57685 m .66302 .53404 L .65857 .52443 L p
1 g
F P
s
P
p
.002 w
.68488 .47166 m .65857 .52443 L .66302 .53404 L p
1 g
F P
s
P
p
.002 w
.39696 .26634 m .35617 .30092 L .36475 .30428 L p
1 g
F P
s
P
p
.002 w
.36475 .30428 m .39986 .27452 L .39696 .26634 L p
1 g
F P
s
P
p
.002 w
.44578 .24606 m .39696 .26634 L .39986 .27452 L p
1 g
F P
s
P
p
.002 w
.3996 .60006 m .4526 .61804 L .44228 .60691 L p
1 g
F P
s
P
p
.002 w
.44228 .60691 m .38863 .58856 L .3996 .60006 L p
1 g
F P
s
P
p
.002 w
.34542 .55299 m .38863 .58856 L .38102 .5733 L p
1 g
F P
s
P
p
.002 w
.38102 .5733 m .33846 .53806 L .34542 .55299 L p
1 g
F P
s
P
p
.002 w
.32029 .35072 m .30764 .40511 L .31704 .39426 L p
1 g
F P
s
P
p
.002 w
.31704 .39426 m .32848 .34544 L .32029 .35072 L p
1 g
F P
s
P
p
.002 w
.31143 .48868 m .33846 .53806 L .33604 .52082 L p
1 g
F P
s
P
p
.002 w
.33604 .52082 m .31021 .47335 L .31143 .48868 L p
1 g
F P
s
P
p
.002 w
.30317 .41711 m .31021 .47335 L .31409 .45745 L p
1 g
F P
s
P
p
.002 w
.31409 .45745 m .30764 .40511 L .30317 .41711 L p
1 g
F P
s
P
p
.002 w
.68488 .47166 m .69409 .4152 L .68577 .4023 L p
1 g
F P
s
P
p
.002 w
.67593 .34679 m .68577 .4023 L .69409 .4152 L p
1 g
F P
s
P
p
.002 w
.68577 .4023 m .67593 .34679 L .66299 .33589 L p
1 g
F P
s
P
p
.002 w
.46463 .62445 m .52009 .62445 L .51029 .61814 L p
1 g
F P
s
P
p
.002 w
.51029 .61814 m .4526 .61804 L .46463 .62445 L p
1 g
F P
s
P
p
.002 w
.55937 .25011 m .50783 .23566 L .49647 .24238 L p
1 g
F P
s
P
p
.002 w
.44578 .24606 m .49647 .24238 L .50783 .23566 L p
1 g
F P
s
P
p
.002 w
.63432 .28854 m .66299 .33589 L .67593 .34679 L p
1 g
F P
s
P
p
.002 w
.66299 .33589 m .63432 .28854 L .61852 .28249 L p
1 g
F P
s
P
p
.002 w
.66302 .53404 m .68843 .48326 L .68488 .47166 L p
1 g
F P
s
P
p
.002 w
.69409 .4152 m .68488 .47166 L .68843 .48326 L p
1 g
F P
s
P
p
.002 w
.57487 .2497 m .61852 .28249 L .63432 .28854 L p
1 g
F P
s
P
p
.002 w
.61852 .28249 m .57487 .2497 L .55937 .25011 L p
1 g
F P
s
P
p
.002 w
.50783 .23566 m .55937 .25011 L .57487 .2497 L p
1 g
F P
s
P
p
.002 w
.35119 .30099 m .32029 .35072 L .32848 .34544 L p
1 g
F P
s
P
p
.002 w
.32848 .34544 m .35617 .30092 L .35119 .30099 L p
1 g
F P
s
P
p
.002 w
.5808 .61023 m .62665 .58117 L .62394 .57685 L p
1 g
F P
s
P
p
.002 w
.62394 .57685 m .57483 .60795 L .5808 .61023 L p
1 g
F P
s
P
p
.002 w
.66302 .53404 m .62394 .57685 L .62665 .58117 L p
1 g
F P
s
P
p
.002 w
.50783 .23566 m .45133 .2397 L .44578 .24606 L p
1 g
F P
s
P
p
.002 w
.39696 .26634 m .44578 .24606 L .45133 .2397 L p
1 g
F P
s
P
p
.002 w
.52974 .62565 m .5808 .61023 L .57483 .60795 L p
1 g
F P
s
P
p
.002 w
.57483 .60795 m .52009 .62445 L .52974 .62565 L p
1 g
F P
s
P
p
.002 w
.62665 .58117 m .66317 .5412 L .66302 .53404 L p
1 g
F P
s
P
p
.002 w
.68843 .48326 m .66302 .53404 L .66317 .5412 L p
1 g
F P
s
P
p
.002 w
.357 .56504 m .3996 .60006 L .38863 .58856 L p
1 g
F P
s
P
p
.002 w
.38863 .58856 m .34542 .55299 L .357 .56504 L p
1 g
F P
s
P
p
.002 w
.41382 .60725 m .46463 .62445 L .4526 .61804 L p
1 g
F P
s
P
p
.002 w
.4526 .61804 m .3996 .60006 L .41382 .60725 L p
1 g
F P
s
P
p
.002 w
.39679 .26234 m .35119 .30099 L .35617 .30092 L p
1 g
F P
s
P
p
.002 w
.35617 .30092 m .39696 .26634 L .39679 .26234 L p
1 g
F P
s
P
p
.002 w
.45133 .2397 m .39679 .26234 L .39696 .26634 L p
1 g
F P
s
P
p
.002 w
.31679 .35847 m .30317 .41711 L .30764 .40511 L p
1 g
F P
s
P
p
.002 w
.30764 .40511 m .32029 .35072 L .31679 .35847 L p
1 g
F P
s
P
p
.002 w
.31802 .50297 m .34542 .55299 L .33846 .53806 L p
1 g
F P
s
P
p
.002 w
.33846 .53806 m .31143 .48868 L .31802 .50297 L p
1 g
F P
s
P
p
.002 w
.30407 .42997 m .31143 .48868 L .31021 .47335 L p
1 g
F P
s
P
p
.002 w
.31021 .47335 m .30317 .41711 L .30407 .42997 L p
1 g
F P
s
P
p
.002 w
.68843 .48326 m .69735 .42904 L .69409 .4152 L p
1 g
F P
s
P
p
.002 w
.6845 .36043 m .69409 .4152 L .69735 .42904 L p
1 g
F P
s
P
p
.002 w
.69409 .4152 m .6845 .36043 L .67593 .34679 L p
1 g
F P
s
P
p
.002 w
.647 .29878 m .67593 .34679 L .6845 .36043 L p
1 g
F P
s
P
p
.002 w
.67593 .34679 m .647 .29878 L .63432 .28854 L p
1 g
F P
s
P
p
.002 w
.47815 .62566 m .52974 .62565 L .52009 .62445 L p
1 g
F P
s
P
p
.002 w
.52009 .62445 m .46463 .62445 L .47815 .62566 L p
1 g
F P
s
P
p
.002 w
.57487 .2497 m .51945 .23408 L .50783 .23566 L p
1 g
F P
s
P
p
.002 w
.45133 .2397 m .50783 .23566 L .51945 .23408 L p
1 g
F P
s
P
p
.002 w
.63432 .28854 m .58889 .2543 L .57487 .2497 L p
1 g
F P
s
P
p
.002 w
.58889 .2543 m .63432 .28854 L .647 .29878 L p
1 g
F P
s
P
p
.002 w
.66317 .5412 m .68688 .49388 L .68843 .48326 L p
1 g
F P
s
P
p
.002 w
.69735 .42904 m .68843 .48326 L .68688 .49388 L p
1 g
F P
s
P
p
.004 w
.72295 .35644 m
.76606 .34212 L
s
P
p
.002 w
.51945 .23408 m .57487 .2497 L .58889 .2543 L p
1 g
F P
s
P
p
.002 w
.35019 .30473 m .31679 .35847 L .32029 .35072 L p
1 g
F P
s
P
p
.002 w
.32029 .35072 m .35119 .30099 L .35019 .30473 L p
1 g
F P
s
P
p
.002 w
.58475 .60754 m .62593 .58144 L .62665 .58117 L p
1 g
F P
s
P
p
.002 w
.62665 .58117 m .5808 .61023 L .58475 .60754 L p
1 g
F P
s
P
p
.002 w
.66317 .5412 m .62665 .58117 L .62593 .58144 L p
1 g
F P
s
P
p
.002 w
.51945 .23408 m .45849 .23843 L .45133 .2397 L p
1 g
F P
s
P
p
.002 w
.39679 .26234 m .45133 .2397 L .45849 .23843 L p
1 g
F P
s
P
p
.002 w
.53896 .62136 m .58475 .60754 L .5808 .61023 L p
1 g
F P
s
P
p
.002 w
.5808 .61023 m .52974 .62565 L .53896 .62136 L p
1 g
F P
s
P
p
.002 w
.37312 .5737 m .41382 .60725 L .3996 .60006 L p
1 g
F P
s
P
p
.002 w
.3996 .60006 m .357 .56504 L .37312 .5737 L p
1 g
F P
s
P
p
.002 w
.43105 .60966 m .47815 .62566 L .46463 .62445 L p
1 g
F P
s
P
p
.002 w
.46463 .62445 m .41382 .60725 L .43105 .60966 L p
1 g
F P
s
P
p
.002 w
.62593 .58144 m .65872 .54555 L .66317 .5412 L p
1 g
F P
s
P
p
.002 w
.68688 .49388 m .66317 .5412 L .65872 .54555 L p
1 g
F P
s
P
p
.002 w
.3301 .51573 m .357 .56504 L .34542 .55299 L p
1 g
F P
s
P
p
.002 w
.34542 .55299 m .31802 .50297 L .3301 .51573 L p
1 g
F P
s
P
p
.002 w
.31838 .36861 m .30407 .42997 L .30317 .41711 L p
1 g
F P
s
P
p
.002 w
.30317 .41711 m .31679 .35847 L .31838 .36861 L p
1 g
F P
s
P
p
.002 w
.39952 .26291 m .35019 .30473 L .35119 .30099 L p
1 g
F P
s
P
p
.002 w
.35119 .30099 m .39679 .26234 L .39952 .26291 L p
1 g
F P
s
P
p
.002 w
.45849 .23843 m .39952 .26291 L .39679 .26234 L p
1 g
F P
s
P
p
.002 w
.31065 .44338 m .31802 .50297 L .31143 .48868 L p
1 g
F P
s
P
p
.002 w
.31143 .48868 m .30407 .42997 L .31065 .44338 L p
1 g
F P
s
P
p
.002 w
.69735 .42904 m .68818 .37657 L .6845 .36043 L p
1 g
F P
s
P
p
.002 w
.6845 .36043 m .656 .31313 L .647 .29878 L p
1 g
F P
s
P
p
.002 w
.656 .31313 m .6845 .36043 L .68818 .37657 L p
1 g
F P
s
P
p
.002 w
.68688 .49388 m .69518 .44348 L .69735 .42904 L p
1 g
F P
s
P
p
.002 w
.68818 .37657 m .69735 .42904 L .69518 .44348 L p
1 g
F P
s
P
p
.002 w
.58889 .2543 m .531 .238 L .51945 .23408 L p
1 g
F P
s
P
p
.002 w
.45849 .23843 m .51945 .23408 L .531 .238 L p
1 g
F P
s
P
p
.002 w
.49283 .62132 m .53896 .62136 L .52974 .62565 L p
1 g
F P
s
P
p
.002 w
.52974 .62565 m .47815 .62566 L .49283 .62132 L p
1 g
F P
s
P
p
.002 w
.60094 .26408 m .647 .29878 L .656 .31313 L p
1 g
F P
s
P
p
.002 w
.647 .29878 m .60094 .26408 L .58889 .2543 L p
1 g
F P
s
P
p
.002 w
.531 .238 m .58889 .2543 L .60094 .26408 L p
1 g
F P
s
P
p
.002 w
.65872 .54555 m .67995 .50314 L .68688 .49388 L p
1 g
F P
s
P
p
.002 w
.69518 .44348 m .68688 .49388 L .67995 .50314 L p
1 g
F P
s
P
p
.002 w
.35347 .31226 m .31838 .36861 L .31679 .35847 L p
1 g
F P
s
P
p
.002 w
.31679 .35847 m .35019 .30473 L .35347 .31226 L p
1 g
F P
s
P
p
.002 w
.39352 .5785 m .43105 .60966 L .41382 .60725 L p
1 g
F P
s
P
p
.002 w
.41382 .60725 m .37312 .5737 L .39352 .5785 L p
1 g
F P
s
P
p
.002 w
.58644 .59965 m .62157 .5774 L .62593 .58144 L p
1 g
F P
s
P
p
.002 w
.62593 .58144 m .58475 .60754 L .58644 .59965 L p
1 g
F P
s
P
p
.002 w
.65872 .54555 m .62593 .58144 L .62157 .5774 L p
1 g
F P
s
P
p
.002 w
.531 .238 m .46715 .24261 L .45849 .23843 L p
1 g
F P
s
P
p
.002 w
.39952 .26291 m .45849 .23843 L .46715 .24261 L p
1 g
F P
s
P
p
.002 w
.45093 .60694 m .49283 .62132 L .47815 .62566 L p
1 g
F P
s
P
p
.002 w
.47815 .62566 m .43105 .60966 L .45093 .60694 L p
1 g
F P
s
P
p
.002 w
.34759 .52647 m .37312 .5737 L .357 .56504 L p
1 g
F P
s
P
p
.002 w
.357 .56504 m .3301 .51573 L .34759 .52647 L p
1 g
F P
s
P
p
.002 w
.54744 .61137 m .58644 .59965 L .58475 .60754 L p
1 g
F P
s
P
p
.002 w
.58475 .60754 m .53896 .62136 L .54744 .61137 L p
1 g
F P
s
P
p
.002 w
.62157 .5774 m .64951 .54679 L .65872 .54555 L p
1 g
F P
s
P
p
.002 w
.67995 .50314 m .65872 .54555 L .64951 .54679 L p
1 g
F P
s
P
p
.002 w
.32534 .38098 m .31065 .44338 L .30407 .42997 L p
1 g
F P
s
P
p
.002 w
.30407 .42997 m .31838 .36861 L .32534 .38098 L p
1 g
F P
s
P
p
.002 w
.32302 .45693 m .3301 .51573 L .31802 .50297 L p
1 g
F P
s
P
p
.002 w
.31802 .50297 m .31065 .44338 L .32302 .45693 L p
1 g
F P
s
P
p
.002 w
.69518 .44348 m .6866 .39488 L .68818 .37657 L p
1 g
F P
s
P
p
.002 w
.66085 .33141 m .68818 .37657 L .6866 .39488 L p
1 g
F P
s
P
p
.002 w
.68818 .37657 m .66085 .33141 L .656 .31313 L p
1 g
F P
s
P
p
.004 w
.6881 .36802 m
.72295 .35644 L
s
P
p
.002 w
.40528 .26835 m .35347 .31226 L .35019 .30473 L p
1 g
F P
s
P
p
.002 w
.35019 .30473 m .39952 .26291 L .40528 .26835 L p
1 g
F P
s
P
p
.002 w
.67995 .50314 m .6873 .45812 L .69518 .44348 L p
1 g
F P
s
P
p
.002 w
.6866 .39488 m .69518 .44348 L .6873 .45812 L p
1 g
F P
s
P
p
.002 w
.46715 .24261 m .40528 .26835 L .39952 .26291 L p
1 g
F P
s
P
p
.002 w
.61055 .27905 m .656 .31313 L .66085 .33141 L p
1 g
F P
s
P
p
.002 w
.656 .31313 m .61055 .27905 L .60094 .26408 L p
1 g
F P
s
P
p
.002 w
.60094 .26408 m .54212 .24764 L .531 .238 L p
1 g
F P
s
P
p
.002 w
.46715 .24261 m .531 .238 L .54212 .24764 L p
1 g
F P
s
P
p
.002 w
.5083 .61123 m .54744 .61137 L .53896 .62136 L p
1 g
F P
s
P
p
.002 w
.53896 .62136 m .49283 .62132 L .5083 .61123 L p
1 g
F P
s
P
p
.002 w
.54212 .24764 m .60094 .26408 L .61055 .27905 L p
1 g
F P
s
P
p
.002 w
.64951 .54679 m .66752 .51068 L .67995 .50314 L p
1 g
F P
s
P
p
.002 w
.6873 .45812 m .67995 .50314 L .66752 .51068 L p
1 g
F P
s
P
p
.002 w
.41777 .57908 m .45093 .60694 L .43105 .60966 L p
1 g
F P
s
P
p
.002 w
.43105 .60966 m .39352 .5785 L .41777 .57908 L p
1 g
F P
s
P
p
.002 w
.3612 .32359 m .32534 .38098 L .31838 .36861 L p
1 g
F P
s
P
p
.002 w
.31838 .36861 m .35347 .31226 L .3612 .32359 L p
1 g
F P
s
P
p
.002 w
.37021 .53472 m .39352 .5785 L .37312 .5737 L p
1 g
F P
s
P
p
.002 w
.37312 .5737 m .34759 .52647 L .37021 .53472 L p
1 g
F P
s
P
p
.002 w
.47294 .59891 m .5083 .61123 L .49283 .62132 L p
1 g
F P
s
P
p
.002 w
.49283 .62132 m .45093 .60694 L .47294 .59891 L p
1 g
F P
s
P
p
.002 w
.54212 .24764 m .47713 .25248 L .46715 .24261 L p
1 g
F P
s
P
p
.002 w
.40528 .26835 m .46715 .24261 L .47713 .25248 L p
1 g
F P
s
P
p
.002 w
.58566 .58646 m .61345 .56888 L .62157 .5774 L p
1 g
F P
s
P
p
.002 w
.62157 .5774 m .58644 .59965 L .58566 .58646 L p
1 g
F P
s
P
p
.002 w
.64951 .54679 m .62157 .5774 L .61345 .56888 L p
1 g
F P
s
P
p
.002 w
.34112 .47018 m .34759 .52647 L .3301 .51573 L p
1 g
F P
s
P
p
.002 w
.3301 .51573 m .32302 .45693 L .34112 .47018 L p
1 g
F P
s
P
p
.002 w
.6873 .45812 m .6795 .41489 L .6866 .39488 L p
1 g
F P
s
P
p
.002 w
.66115 .35325 m .6866 .39488 L .6795 .41489 L p
1 g
F P
s
P
p
.002 w
.6866 .39488 m .66115 .35325 L .66085 .33141 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.66758 .37484 L
s
P
p
.004 w
.66896 .37438 m
.67028 .37394 L
s
P
p
.002 w
.55486 .59565 m .58566 .58646 L .58644 .59965 L p
1 g
F P
s
P
p
.002 w
.58644 .59965 m .54744 .61137 L .55486 .59565 L p
1 g
F P
s
P
p
.002 w
.33776 .39531 m .32302 .45693 L .31065 .44338 L p
1 g
F P
s
P
p
.002 w
.31065 .44338 m .32534 .38098 L .33776 .39531 L p
1 g
F P
s
P
p
.002 w
.61345 .56888 m .63552 .54466 L .64951 .54679 L p
1 g
F P
s
P
p
.002 w
.66752 .51068 m .64951 .54679 L .63552 .54466 L p
1 g
F P
s
P
p
.002 w
.66752 .51068 m .67363 .4725 L .6873 .45812 L p
1 g
F P
s
P
p
.002 w
.6795 .41489 m .6873 .45812 L .67363 .4725 L p
1 g
F P
s
P
p
.002 w
.61726 .29903 m .66085 .33141 L .66115 .35325 L p
1 g
F P
s
P
p
.002 w
.66085 .33141 m .61726 .29903 L .61055 .27905 L p
1 g
F P
s
P
p
.002 w
.41407 .2788 m .3612 .32359 L .35347 .31226 L p
1 g
F P
s
P
p
.002 w
.35347 .31226 m .40528 .26835 L .41407 .2788 L p
1 g
F P
s
P
p
.002 w
.47713 .25248 m .41407 .2788 L .40528 .26835 L p
1 g
F P
s
P
p
.002 w
.61055 .27905 m .55244 .26303 L .54212 .24764 L p
1 g
F P
s
P
p
.002 w
.47713 .25248 m .54212 .24764 L .55244 .26303 L p
1 g
F P
s
P
p
.002 w
.55244 .26303 m .61055 .27905 L .61726 .29903 L p
1 g
F P
s
P
p
.002 w
.52408 .59542 m .55486 .59565 L .54744 .61137 L p
1 g
F P
s
P
p
.002 w
.54744 .61137 m .5083 .61123 L .52408 .59542 L p
1 g
F P
s
P
p
.002 w
.63552 .54466 m .64966 .51614 L .66752 .51068 L p
1 g
F P
s
P
p
.002 w
.67363 .4725 m .66752 .51068 L .64966 .51614 L p
1 g
F P
s
P
p
.002 w
.4452 .57521 m .47294 .59891 L .45093 .60694 L p
1 g
F P
s
P
p
.002 w
.45093 .60694 m .41777 .57908 L .4452 .57521 L p
1 g
F P
s
P
p
.002 w
.39741 .54009 m .41777 .57908 L .39352 .5785 L p
1 g
F P
s
P
p
.002 w
.39352 .5785 m .37021 .53472 L .39741 .54009 L p
1 g
F P
s
P
p
.002 w
.37339 .33857 m .33776 .39531 L .32534 .38098 L p
1 g
F P
s
P
p
.002 w
.32534 .38098 m .3612 .32359 L .37339 .33857 L p
1 g
F P
s
P
p
.002 w
.49645 .58557 m .52408 .59542 L .5083 .61123 L p
1 g
F P
s
P
p
.002 w
.5083 .61123 m .47294 .59891 L .49645 .58557 L p
1 g
F P
s
P
p
.002 w
.67363 .4725 m .66684 .43604 L .6795 .41489 L p
1 g
F P
s
P
p
.002 w
.65667 .37809 m .6795 .41489 L .66684 .43604 L p
1 g
F P
s
P
p
.002 w
.6795 .41489 m .65667 .37809 L .66115 .35325 L p
1 g
F P
s
P
p
.004 w
.67028 .37394 m
.67682 .37176 L
s
P
p
.004 w
.67682 .37176 m
.6881 .36802 L
s
P
p
.002 w
.36459 .48266 m .37021 .53472 L .34759 .52647 L p
1 g
F P
s
P
p
.002 w
.34759 .52647 m .34112 .47018 L .36459 .48266 L p
1 g
F P
s
P
p
.002 w
.55244 .26303 m .48819 .26803 L .47713 .25248 L p
1 g
F P
s
P
p
.002 w
.41407 .2788 m .47713 .25248 L .48819 .26803 L p
1 g
F P
s
P
p
.002 w
.35553 .4112 m .34112 .47018 L .32302 .45693 L p
1 g
F P
s
P
p
.002 w
.32302 .45693 m .33776 .39531 L .35553 .4112 L p
1 g
F P
s
P
p
.002 w
.5823 .56809 m .60162 .55588 L .61345 .56888 L p
1 g
F P
s
P
p
.002 w
.61345 .56888 m .58566 .58646 L .5823 .56809 L p
1 g
F P
s
P
p
.002 w
.63552 .54466 m .61345 .56888 L .60162 .55588 L p
1 g
F P
s
P
p
.002 w
.62069 .3236 m .66115 .35325 L .65667 .37809 L p
1 g
F P
s
P
p
.002 w
.66115 .35325 m .62069 .3236 L .61726 .29903 L p
1 g
F P
s
P
p
.002 w
.64966 .51614 m .65432 .48612 L .67363 .4725 L p
1 g
F P
s
P
p
.002 w
.66684 .43604 m .67363 .4725 L .65432 .48612 L p
1 g
F P
s
P
p
.002 w
.56091 .5744 m .5823 .56809 L .58566 .58646 L p
1 g
F P
s
P
p
.002 w
.58566 .58646 m .55486 .59565 L .56091 .5744 L p
1 g
F P
s
P
p
.002 w
.60162 .55588 m .61693 .53903 L .63552 .54466 L p
1 g
F P
s
P
p
.002 w
.64966 .51614 m .63552 .54466 L .61693 .53903 L p
1 g
F P
s
P
p
.002 w
.56156 .28399 m .61726 .29903 L .62069 .3236 L p
1 g
F P
s
P
p
.002 w
.61726 .29903 m .56156 .28399 L .55244 .26303 L p
1 g
F P
s
P
p
.002 w
.48819 .26803 m .55244 .26303 L .56156 .28399 L p
1 g
F P
s
P
p
.002 w
.42579 .29421 m .37339 .33857 L .3612 .32359 L p
1 g
F P
s
P
p
.002 w
.3612 .32359 m .41407 .2788 L .42579 .29421 L p
1 g
F P
s
P
p
.002 w
.48819 .26803 m .42579 .29421 L .41407 .2788 L p
1 g
F P
s
P
p
.002 w
.53963 .57413 m .56091 .5744 L .55486 .59565 L p
1 g
F P
s
P
p
.002 w
.55486 .59565 m .52408 .59542 L .53963 .57413 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.61693 .53903 m .62667 .51923 L .64966 .51614 L p
1 g
F P
s
P
p
.002 w
.65432 .48612 m .64966 .51614 L .62667 .51923 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.49645 .58557 m .47294 .59891 L p
.4742 .5791 L 1 g
F P
s
P
p
.4742 .5791 m .47439 .57614 L .48373 .58013 L 1 g
F
P
p
.4742 .5791 m .48373 .58013 L .49645 .58557 L 1 g
F
P
p
.002 w
.52408 .59542 m .49645 .58557 L .50244 .58102 L p
1 g
F P
s
P
p
.002 w
.51093 .58044 m .51079 .57862 L p
.49891 .581 L 1 g
F P
s
P
p
.002 w
.50244 .58102 m .49645 .58557 L p
.49786 .58099 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49645 .58557 m .49113 .58094 L p
.49786 .58099 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58071 L p
1 g
F P
s
P
p
.002 w
.49113 .58094 m .49188 .58159 L p
.48905 .58071 L 1 g
F P
s
P
p
.002 w
.49188 .58159 m .49645 .58557 L p
.47439 .57614 L 1 g
F P
s
P
p
.002 w
.48905 .58071 m .48889 .583 L p
.49637 .5815 L 1 g
F P
s
P
p
.51079 .57862 m .48905 .58071 L .49637 .5815 L 1 g
F
P
p
.002 w
.48905 .58071 m .48921 .57862 L p
.47989 .57785 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46837 .57427 L p
1 g
F P
s
P
p
.47294 .59891 m .45898 .57134 L .46837 .57427 L 1 g
F
P
p
.4743 .57759 m .46837 .57427 L .47439 .57614 L 1 g
F
P
p
.47294 .59891 m .46837 .57427 L .4743 .57759 L 1 g
F
P
p
.002 w
.46837 .57427 m .46872 .57265 L p
.45971 .56905 L 1 g
F P
s
P
p
.002 w
.46176 .57056 m .4452 .57521 L p
.45134 .56287 L 1 g
F P
s
P
p
.45971 .56905 m .45744 .56814 L .46176 .57056 L 1 g
F
P
p
.45971 .56905 m .46176 .57056 L .46837 .57427 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.48921 .57862 m .46837 .57427 L .47989 .57785 L 1 g
F
P
p
.47439 .57614 m .46837 .57427 L .47498 .56685 L 1 g
F
P
p
.002 w
.45898 .57134 m .46176 .57056 L p
.46837 .57427 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45097 .5626 L p
1 g
F P
s
P
p
.002 w
.4452 .57521 m .43143 .54817 L p
.45097 .5626 L 1 g
F P
s
P
p
.45128 .56298 m .45097 .5626 L .45134 .56287 L 1 g
F
P
p
.4452 .57521 m .45097 .5626 L .45128 .56298 L 1 g
F
P
p
.002 w
.45097 .5626 m .45146 .56129 L p
.44635 .55685 L 1 g
F P
s
P
p
.46872 .57265 m .45097 .5626 L .4577 .56756 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43849 .54708 L p
1 g
F P
s
P
p
.45146 .56129 m .43849 .54708 L .44635 .55685 L 1 g
F
P
p
.45134 .56287 m .4508 .56238 L .46221 .54101 L 1 g
F
P
p
.002 w
.42842 .54224 m .43443 .54202 L p
.43849 .54708 L 1 g
F P
s
P
p
.44104 .5536 m .42842 .54224 L .43849 .54708 L 1 g
F
P
p
.002 w
.43849 .54708 m .43925 .54566 L p
.43542 .53809 L 1 g
F P
s
P
p
.002 w
.43649 .54195 m .42842 .54224 L p
.4348 .53584 L 1 g
F P
s
P
p
.002 w
.42842 .54224 m .42497 .50335 L .42588 .50355 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.42842 .54224 m .42588 .50355 L .43274 .52839 L 1 g
F
P
p
.43208 .53858 m .43274 .52839 L .4348 .53584 L 1 g
F
P
p
.42842 .54224 m .43274 .52839 L .43208 .53858 L 1 g
F
P
p
.002 w
.43274 .52839 m .43346 .52734 L p
.43323 .52085 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43274 .52839 L p
1 g
F P
s
P
p
.002 w
.43274 .52839 m .43146 .53025 L p
.43542 .53809 L 1 g
F P
s
P
p
.43925 .54566 m .43274 .52839 L .43542 .53809 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43399 .50928 L p
1 g
F P
s
P
p
.002 w
.42588 .50355 m .43425 .50531 L p
.43399 .50928 L 1 g
F P
s
P
p
.43274 .52839 m .42991 .51814 L .43399 .50928 L 1 g
F
P
p
.42991 .51814 m .42588 .50355 L .43399 .50928 L 1 g
F
P
p
.002 w
.43399 .50928 m .43485 .50826 L p
.43795 .50101 L 1 g
F P
s
P
p
.002 w
.43568 .50561 m .42497 .50335 L p
.44121 .49439 L 1 g
F P
s
P
p
.43795 .50101 m .43988 .49651 L .43568 .50561 L 1 g
F
P
p
.43795 .50101 m .43568 .50561 L .43399 .50928 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43346 .52734 m .43399 .50928 L .43323 .52085 L 1 g
F
P
p
.43274 .52839 m .43399 .50928 L .45986 .51071 L 1 g
F
P
p
.002 w
.43425 .50531 m .43568 .50561 L p
.43399 .50928 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44284 .49108 L p
1 g
F P
s
P
p
.42497 .50335 m .45258 .47133 L .44284 .49108 L 1 g
F
P
p
.43707 .49668 m .44284 .49108 L .44121 .49439 L 1 g
F
P
p
.42497 .50335 m .44284 .49108 L .43707 .49668 L 1 g
F
P
p
.002 w
.44284 .49108 m .44193 .49205 L p
.43853 .49983 L 1 g
F P
s
P
p
.43485 .50826 m .44284 .49108 L .43853 .49983 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44284 .49108 m .44339 .4905 L p
.44837 .48573 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44121 .49439 m .44284 .49108 L .46852 .47933 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45768 .47671 L p
1 g
F P
s
P
p
.44339 .4905 m .45768 .47671 L .44837 .48573 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45768 .47671 m .45826 .47608 L p
.46801 .4718 L 1 g
F P
s
P
p
.002 w
.47595 .46798 m .46852 .47933 L .46061 .47536 L p
1 g
F P
s
P
p
.002 w
.46852 .47933 m .47595 .46798 L p
.51526 .47472 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47595 .46798 m .47754 .4672 L .51526 .47472 L 1 g
F
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.48809 .46563 L 1 g
F P
s
P
p
.47754 .4672 m .5 .46386 L .51526 .47472 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .5225 .46726 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47672 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.52351 .46777 m .54233 .47672 L .55166 .48953 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56614 .50944 L p
1 g
F P
s
P
p
.55661 .4905 m .56614 .50944 L .56204 .5009 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56476 .49845 m .56545 .50281 L p
.55888 .49429 L 1 g
F P
s
P
p
.55753 .49147 m .56476 .49845 L .55888 .49429 L 1 g
F
P
p
.002 w
.56545 .50281 m .5678 .51746 L p
.56674 .51518 L 1 g
F P
s
P
p
.002 w
.55753 .49147 m .55661 .4905 L p
.56204 .5009 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56749 .52873 L p
1 g
F P
s
P
p
.002 w
.57631 .54488 m .56832 .54721 L p
.56797 .52714 L 1 g
F P
s
P
p
.002 w
.5678 .51746 m .56935 .52248 L p
.56797 .52714 L 1 g
F P
s
P
p
.002 w
.56935 .52248 m .57631 .54488 L p
.56797 .52714 L 1 g
F P
s
P
p
.002 w
.56749 .52873 m .56654 .52734 L p
.56441 .53901 L 1 g
F P
s
P
p
.002 w
.5653 .54809 m .5617 .54802 L p
.56181 .54766 L 1 g
F P
s
P
p
.002 w
.56665 .53157 m .56583 .54159 L p
.56181 .54766 L 1 g
F P
s
P
p
.002 w
.56583 .54159 m .5653 .54809 L p
.56181 .54766 L 1 g
F P
s
P
p
.002 w
.5653 .54809 m .56091 .5744 L p
.55607 .55469 L 1 g
F P
s
P
p
.56075 .54566 m .55515 .5558 L .55581 .55501 L 1 g
F
P
p
.002 w
.56157 .54802 m .5617 .54802 L p
.55607 .55469 L 1 g
F P
s
P
p
.002 w
.5617 .54802 m .5653 .54809 L p
.56015 .55177 L 1 g
F P
s
P
p
.55607 .55469 m .5617 .54802 L .56015 .55177 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56183 .5477 L p
1 g
F P
s
P
p
.002 w
.56183 .5477 m .56257 .5491 L p
.56361 .54337 L 1 g
F P
s
P
p
.56654 .52734 m .56183 .5477 L .56361 .54337 L 1 g
F
P
p
.002 w
.56181 .54766 m .56075 .54566 L p
.55581 .55501 L 1 g
F P
s
P
p
.002 w
.56091 .5744 m .54006 .57413 L p
.54919 .56304 L 1 g
F P
s
P
p
.55676 .55749 m .54919 .56304 L .55607 .55469 L 1 g
F
P
p
.56091 .5744 m .54919 .56304 L .55676 .55749 L 1 g
F
P
p
.002 w
.54919 .56304 m .54854 .56129 L p
.53919 .57021 L 1 g
F P
s
P
p
.002 w
.54352 .56721 m .53963 .57413 L p
.54045 .56933 L 1 g
F P
s
P
p
.53919 .57021 m .54352 .56721 L .54919 .56304 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53963 .57413 m .53563 .57266 L p
.54045 .56933 L 1 g
F P
s
P
p
.55581 .55501 m .56157 .54802 L .56181 .54766 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.55607 .55469 m .5487 .5634 L .5544 .54788 L 1 g
F
P
p
.002 w
.53963 .57413 m .54352 .56721 L p
.5487 .5634 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .57472 L p
1 g
F P
s
P
p
.52219 .57975 m .53173 .57472 L .53963 .57413 L 1 g
F
P
p
.002 w
.53563 .57266 m .53716 .57322 L p
.53173 .57472 L 1 g
F P
s
P
p
.002 w
.53716 .57322 m .53963 .57413 L p
.53173 .57472 L 1 g
F P
s
P
p
.002 w
.53963 .57413 m .52408 .59542 L p
.52219 .57975 L 1 g
F P
s
P
p
.002 w
.53173 .57472 m .53128 .57265 L p
.52207 .57738 L 1 g
F P
s
P
p
.54854 .56129 m .53173 .57472 L .53519 .5729 L 1 g
F
P
p
.54854 .56129 m .53195 .57571 L .53832 .57103 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58044 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58044 L .52207 .57738 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52067 .56718 m .53563 .57266 L p
.53173 .57472 L 1 g
F P
s
P
p
.52219 .57975 m .52191 .57742 L .53173 .57472 L 1 g
F
P
p
.52191 .57742 m .52067 .56718 L .53173 .57472 L 1 g
F
P
p
.49891 .581 m .50244 .58102 L .51093 .58044 L 1 g
F
P
p
.002 w
.50244 .58102 m .52067 .56718 L p
.52218 .57967 L 1 g
F P
s
P
p
.52408 .59542 m .50244 .58102 L .52218 .57967 L 1 g
F
P
p
.002 w
.51093 .58044 m .51111 .583 L p
.52207 .57738 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53173 .57472 L p
1 g
F P
s
P
p
.52207 .57738 m .51111 .583 L .53173 .57472 L 1 g
F
P
p
.002 w
.53173 .57472 m .53195 .57571 L p
.53519 .5729 L 1 g
F P
s
P
p
.002 w
.54352 .56721 m .5544 .54788 L p
.5487 .5634 L 1 g
F P
s
P
p
.002 w
.53195 .57571 m .5322 .57686 L p
.53832 .57103 L 1 g
F P
s
P
p
.002 w
.52067 .56718 m .54476 .54423 L p
.54045 .56933 L 1 g
F P
s
P
p
.002 w
.53563 .57266 m .52067 .56718 L p
.54045 .56933 L 1 g
F P
s
P
p
.002 w
.54006 .57413 m .53963 .57413 L p
.55607 .55469 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54927 .56324 L p
1 g
F P
s
P
p
.002 w
.54927 .56324 m .54919 .56304 L p
.54717 .56469 L 1 g
F P
s
P
p
.54717 .56469 m .5322 .57686 L .54927 .56324 L 1 g
F
P
p
.53919 .57021 m .53832 .57103 L .54352 .56721 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54476 .54423 m .5544 .54788 L .54352 .56721 L p
1 g
F P
s
P
p
.54045 .56933 m .54476 .54423 L .54352 .56721 L 1 g
F
P
p
.53832 .57103 m .5322 .57686 L .54919 .56304 L 1 g
F
P
p
.55581 .55501 m .55137 .56341 L .56157 .54802 L 1 g
F
P
p
.002 w
.5544 .54788 m .56157 .54802 L p
.55607 .55469 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .55137 .56341 L p
.55581 .55501 L 1 g
F P
s
P
p
.55515 .5558 m .54998 .56518 L .55581 .55501 L 1 g
F
P
p
.56441 .53901 m .56665 .53157 L .56749 .52873 L 1 g
F
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5617 .54802 m .5544 .54788 L p
.56665 .53157 L 1 g
F P
s
P
p
.002 w
.55137 .56341 m .56257 .5491 L .56181 .54766 L p
1 g
F P
s
P
p
.56441 .53901 m .56437 .53922 L .56665 .53157 L 1 g
F
P
p
.002 w
.56706 .51914 m .5678 .51746 L .56728 .52386 L p
1 g
F P
s
P
p
.002 w
.56728 .52386 m .5678 .51746 L p
.56832 .54721 L 1 g
F P
s
P
p
.56722 .52264 m .56728 .52386 L .56826 .52984 L 1 g
F
P
p
.002 w
.56749 .52873 m .5675 .52874 L p
.56728 .52386 L 1 g
F P
s
P
p
.002 w
.5675 .52874 m .56826 .52984 L p
.56728 .52386 L 1 g
F P
s
P
p
.56515 .50826 m .56749 .52873 L .56722 .52264 L 1 g
F
P
p
.56717 .52137 m .56826 .52984 L .5678 .52547 L 1 g
F
P
p
.56515 .50826 m .56724 .5228 L .56717 .52137 L 1 g
F
P
p
.56724 .5228 m .56826 .52984 L .56717 .52137 L 1 g
F
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56702 .51837 m .5678 .51746 L .56706 .51914 L p
1 g
F P
s
P
p
.002 w
.5678 .51746 m .56679 .51573 L p
.56674 .51518 L 1 g
F P
s
P
p
.002 w
.567 .51799 m .5678 .51746 L .56702 .51837 L p
1 g
F P
s
P
p
.002 w
.56614 .50944 m .56515 .50826 L p
.56726 .52197 L 1 g
F P
s
P
p
.002 w
.56698 .51772 m .5678 .51746 L .567 .51799 L p
1 g
F P
s
P
p
.56726 .52197 m .56698 .51772 L .56614 .50944 L 1 g
F
P
p
.002 w
.56696 .51747 m .5678 .51746 L .56698 .51772 L p
1 g
F P
s
P
p
.56698 .51772 m .56696 .51748 L .56695 .51738 L 1 g
F
P
p
.56698 .51772 m .56695 .51738 L .56614 .50944 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53324 .52841 m .53267 .5179 L .56696 .51747 L p
1 g
F P
s
P
p
.002 w
.56698 .51772 m .53324 .52841 L p
.56696 .51747 L 1 g
F P
s
P
p
.56696 .51748 m .56691 .51693 L .56614 .50944 L 1 g
F
P
p
.56696 .51735 m .56679 .51573 L .56614 .50944 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53584 .50713 m .54241 .49731 L .5669 .51675 L p
1 g
F P
s
P
p
.002 w
.5669 .51675 m .5678 .51746 L .56694 .51719 L p
1 g
F P
s
P
p
.002 w
.56694 .51719 m .53584 .50713 L p
.5669 .51675 L 1 g
F P
s
P
p
.002 w
.56694 .51719 m .5678 .51746 L .56696 .51747 L p
1 g
F P
s
P
p
.56696 .51748 m .56696 .51735 L .56691 .51693 L 1 g
F
P
p
.56696 .51735 m .56695 .5172 L .56679 .51573 L 1 g
F
P
p
.002 w
.54241 .49731 m .55166 .48953 L .56679 .51573 L p
1 g
F P
s
P
p
.002 w
.56679 .51573 m .5678 .51746 L .5669 .51675 L p
1 g
F P
s
P
p
.002 w
.5669 .51675 m .54241 .49731 L p
.56679 .51573 L 1 g
F P
s
P
p
.002 w
.53267 .5179 m .53584 .50713 L .56694 .51719 L p
1 g
F P
s
P
p
.002 w
.56696 .51747 m .53267 .5179 L p
.56694 .51719 L 1 g
F P
s
P
p
.56697 .5176 m .5678 .52547 L .56695 .5172 L 1 g
F
P
p
.56726 .52197 m .56746 .52322 L .56697 .5176 L 1 g
F
P
p
.56746 .52322 m .5678 .52547 L .56697 .5176 L 1 g
F
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.53743 .53751 m .53324 .52841 L .56698 .51772 L p
1 g
F P
s
P
p
.002 w
.567 .51799 m .53743 .53751 L p
.56698 .51772 L 1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54476 .54423 m .53743 .53751 L .567 .51799 L p
1 g
F P
s
P
p
.002 w
.56702 .51837 m .54476 .54423 L p
.567 .51799 L 1 g
F P
s
P
p
.002 w
.56255 .48467 m .57387 .48327 L .56839 .51413 L p
1 g
F P
s
P
p
.002 w
.56839 .51413 m .5678 .51746 L .5667 .5106 L p
1 g
F P
s
P
p
.002 w
.5667 .5106 m .56255 .48467 L p
.56839 .51413 L 1 g
F P
s
P
p
.55429 .48835 m .55888 .49429 L .56674 .51518 L 1 g
F
P
p
.55888 .49429 m .56545 .50281 L .56614 .50944 L 1 g
F
P
p
.55888 .49429 m .56614 .50944 L .56674 .51518 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55758 .49153 L p
1 g
F P
s
P
p
.002 w
.55758 .49153 m .55753 .49147 L p
.55806 .49255 L 1 g
F P
s
P
p
.55806 .49255 m .56713 .51061 L .55758 .49153 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56653 .50991 L p
1 g
F P
s
P
p
.002 w
.56653 .50991 m .56614 .50944 L p
.56687 .51576 L 1 g
F P
s
P
p
.56687 .51576 m .56854 .53025 L .56653 .50991 L 1 g
F
P
p
.5678 .52547 m .56854 .53025 L .56614 .50944 L 1 g
F
P
p
.002 w
.55166 .48953 m .55429 .48835 L p
.56674 .51518 L 1 g
F P
s
P
p
.002 w
.56679 .51573 m .55166 .48953 L p
.56674 .51518 L 1 g
F P
s
P
p
.002 w
.5544 .54788 m .54476 .54423 L .56702 .51837 L p
1 g
F P
s
P
p
.002 w
.56706 .51914 m .5544 .54788 L p
.56702 .51837 L 1 g
F P
s
P
p
.002 w
.5544 .54788 m .56706 .51914 L p
.56665 .53157 L 1 g
F P
s
P
p
.002 w
.56728 .52386 m .56665 .53157 L p
.56706 .51914 L 1 g
F P
s
P
p
.002 w
.56832 .54721 m .5653 .54809 L .56728 .52386 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56749 .52873 L p
1 g
F P
s
P
p
.56437 .53922 m .56257 .5491 L .56749 .52873 L 1 g
F
P
p
.56204 .5009 m .56713 .51061 L .55753 .49147 L 1 g
F
P
p
.55429 .48835 m .55753 .49147 L .55888 .49429 L 1 g
F
P
p
.002 w
.56826 .52984 m .56854 .53025 L p
.5678 .52547 L 1 g
F P
s
P
p
.002 w
.56614 .50944 m .56713 .51061 L p
.56204 .5009 L 1 g
F P
s
P
p
.002 w
.56255 .48467 m .56476 .49845 L p
.55753 .49147 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55753 .49147 L p
1 g
F P
s
P
p
.54174 .47608 m .55753 .49147 L .55512 .48915 L 1 g
F
P
p
.002 w
.55429 .48835 m .55166 .48953 L .54637 .48065 L p
1 g
F P
s
P
p
.55156 .4857 m .55786 .49182 L .55216 .48628 L 1 g
F
P
p
.54174 .47608 m .55613 .49014 L .55156 .4857 L 1 g
F
P
p
.55613 .49014 m .55786 .49182 L .55156 .4857 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56255 .48467 m .55429 .48835 L p
.53362 .45926 L 1 g
F P
s
P
p
.002 w
.54637 .48065 m .55166 .48953 L p
.54233 .47672 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54233 .47672 L p
1 g
F P
s
P
p
.002 w
.54233 .47672 m .54174 .47608 L p
.55216 .48628 L 1 g
F P
s
P
p
.55216 .48628 m .55834 .49233 L .54233 .47672 L 1 g
F
P
p
.002 w
.53362 .45926 m .5447 .47785 L p
.54233 .47672 L 1 g
F P
s
P
p
.52214 .46667 m .54233 .47672 L .53278 .47218 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.51526 .47472 m .52351 .46777 L p
.55166 .48953 L 1 g
F P
s
P
p
.002 w
.51526 .47472 m .50337 .46441 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .54173 .47686 L p
.52214 .46667 L 1 g
F P
s
P
p
.002 w
.5225 .46726 m .52214 .46667 L p
.54173 .47686 L 1 g
F P
s
P
p
.002 w
.52387 .46747 m .52351 .46777 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.52351 .46777 m .51526 .47472 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.54173 .47686 m .52282 .46778 L .5225 .46726 L p
1 g
F P
s
P
p
.002 w
.52351 .46777 m .52866 .46343 L p
.54233 .47672 L 1 g
F P
s
P
p
.002 w
.52866 .46343 m .53362 .45926 L p
.54233 .47672 L 1 g
F P
s
P
p
.002 w
.54637 .48065 m .53362 .45926 L p
.55429 .48835 L 1 g
F P
s
P
p
.002 w
.55429 .48835 m .55572 .48771 L p
.55753 .49147 L 1 g
F P
s
P
p
.002 w
.55572 .48771 m .56255 .48467 L p
.55753 .49147 L 1 g
F P
s
P
p
.002 w
.55753 .49147 m .55786 .49182 L p
.55512 .48915 L 1 g
F P
s
P
p
.002 w
.5447 .47785 m .54637 .48065 L p
.54233 .47672 L 1 g
F P
s
P
p
.002 w
.55786 .49182 m .55834 .49233 L p
.55216 .48628 L 1 g
F P
s
P
p
.002 w
.54233 .47672 m .54302 .47747 L p
.53278 .47218 L 1 g
F P
s
P
p
.002 w
.5225 .46726 m .52266 .46752 L p
.51529 .46618 L 1 g
F P
s
P
p
.5 .4634 m .5225 .46726 L .51529 .46618 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53362 .45926 m .52387 .46747 L p
.48739 .45054 L 1 g
F P
s
P
p
.5 .4634 m .52266 .46752 L .51509 .4663 L 1 g
F
P
p
.002 w
.50337 .46441 m .51526 .47472 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51509 .4663 L 1 g
F P
s
P
p
.51509 .4663 m .52282 .46778 L .5 .46386 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .46442 L p
.48809 .46563 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46386 L .48809 .46563 L 1 g
F
P
p
.002 w
.49606 .45806 m .50234 .46351 L p
.5 .46386 L 1 g
F P
s
P
p
.47754 .4672 m .48818 .46195 L .5 .46386 L 1 g
F
P
p
.48818 .46195 m .49606 .45806 L .5 .46386 L 1 g
F
P
p
.002 w
.50337 .46441 m .48739 .45054 L p
.52387 .46747 L 1 g
F P
s
P
p
.002 w
.50234 .46351 m .50337 .46441 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52266 .46752 m .52282 .46778 L p
.51509 .4663 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47754 .4672 L p
1 g
F P
s
P
p
.48809 .46563 m .5 .46442 L .47754 .4672 L 1 g
F
P
p
.44284 .49108 m .45768 .47671 L .46852 .47933 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4772 .46775 L p
1 g
F P
s
P
p
.45826 .47608 m .4772 .46775 L .47611 .46825 L 1 g
F
P
p
.46801 .4718 m .46061 .47536 L .45768 .47671 L 1 g
F
P
p
.002 w
.4596 .47485 m .46061 .47536 L p
.45768 .47671 L 1 g
F P
s
P
p
.002 w
.46061 .47536 m .46852 .47933 L p
.45768 .47671 L 1 g
F P
s
P
p
.002 w
.4772 .46775 m .47718 .46778 L p
.47611 .46825 L 1 g
F P
s
P
p
.002 w
.47595 .46798 m .48739 .45054 L .49606 .45806 L p
1 g
F P
s
P
p
.46801 .4718 m .46981 .47102 L .46061 .47536 L 1 g
F
P
p
.46981 .47102 m .47611 .46825 L .46612 .47284 L 1 g
F
P
p
.46981 .47102 m .46612 .47284 L .46061 .47536 L 1 g
F
P
p
.002 w
.48739 .45054 m .47595 .46798 L p
.43576 .46289 L 1 g
F P
s
P
p
.002 w
.46061 .47536 m .43576 .46289 L p
.47595 .46798 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45768 .47671 L p
1 g
F P
s
P
p
.47611 .46825 m .47718 .46778 L .45768 .47671 L 1 g
F
P
p
.002 w
.45258 .47133 m .4596 .47485 L p
.45768 .47671 L 1 g
F P
s
P
p
.44284 .49108 m .44766 .48131 L .45768 .47671 L 1 g
F
P
p
.44766 .48131 m .45258 .47133 L .45768 .47671 L 1 g
F
P
p
.002 w
.45768 .47671 m .45698 .47747 L p
.44837 .48573 L 1 g
F P
s
P
p
.002 w
.44193 .49205 m .44166 .49233 L p
.43988 .49651 L 1 g
F P
s
P
p
.43485 .50826 m .44193 .49205 L .43988 .49651 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44284 .49108 L p
1 g
F P
s
P
p
.44837 .48573 m .45698 .47747 L .44284 .49108 L 1 g
F
P
p
.002 w
.42497 .50335 m .43576 .46289 L .45258 .47133 L p
1 g
F P
s
P
p
.002 w
.43568 .50561 m .45986 .51071 L p
.43399 .50928 L 1 g
F P
s
P
p
.002 w
.46852 .47933 m .45986 .51071 L .43568 .50561 L p
1 g
F P
s
P
p
.44121 .49439 m .46852 .47933 L .43568 .50561 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43399 .50928 L p
1 g
F P
s
P
p
.43988 .49651 m .44166 .49233 L .43399 .50928 L 1 g
F
P
p
.002 w
.43399 .50928 m .43287 .51061 L p
.43323 .52085 L 1 g
F P
s
P
p
.4348 .53584 m .43274 .52839 L .45986 .51071 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43274 .52839 L p
1 g
F P
s
P
p
.43323 .52085 m .43287 .51061 L .43274 .52839 L 1 g
F
P
p
.4508 .56238 m .43849 .54708 L .46221 .54101 L 1 g
F
P
p
.002 w
.43443 .54202 m .43649 .54195 L p
.43849 .54708 L 1 g
F P
s
P
p
.43542 .53809 m .43649 .54195 L .43849 .54708 L 1 g
F
P
p
.002 w
.43649 .54195 m .46221 .54101 L p
.43849 .54708 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43811 .54781 L p
1 g
F P
s
P
p
.002 w
.43811 .54781 m .43849 .54708 L p
.43676 .54293 L 1 g
F P
s
P
p
.43676 .54293 m .43146 .53025 L .43811 .54781 L 1 g
F
P
p
.43542 .53809 m .43347 .53424 L .43649 .54195 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.45986 .51071 m .46221 .54101 L .43649 .54195 L p
1 g
F P
s
P
p
.4348 .53584 m .45986 .51071 L .43649 .54195 L 1 g
F
P
p
.43347 .53424 m .43146 .53025 L .43849 .54708 L 1 g
F
P
p
.4508 .56238 m .44104 .5536 L .43849 .54708 L 1 g
F
P
p
.002 w
.43849 .54708 m .43743 .5491 L p
.44635 .55685 L 1 g
F P
s
P
p
.002 w
.43143 .54817 m .42842 .54224 L p
.45134 .56287 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45097 .5626 L p
1 g
F P
s
P
p
.44635 .55685 m .43743 .5491 L .45097 .5626 L 1 g
F
P
p
.002 w
.45097 .5626 m .45038 .56419 L p
.4577 .56756 L 1 g
F P
s
P
p
.46872 .57265 m .45038 .56419 L .45744 .56814 L 1 g
F
P
p
.002 w
.46176 .57056 m .47498 .56685 L p
.46837 .57427 L 1 g
F P
s
P
p
.002 w
.45038 .56419 m .45002 .56518 L p
.45744 .56814 L 1 g
F P
s
P
p
.002 w
.46221 .54101 m .47498 .56685 L .46176 .57056 L p
1 g
F P
s
P
p
.45134 .56287 m .46221 .54101 L .46176 .57056 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46837 .57427 L p
1 g
F P
s
P
p
.45744 .56814 m .45002 .56518 L .46837 .57427 L 1 g
F
P
p
.002 w
.46837 .57427 m .4678 .57686 L p
.47989 .57785 L 1 g
F P
s
P
p
.002 w
.47294 .59891 m .4452 .57521 L .45898 .57134 L p
1 g
F P
s
P
p
.002 w
.47498 .56685 m .49113 .58094 L p
.47439 .57614 L 1 g
F P
s
P
p
.47439 .57614 m .49113 .58094 L .48905 .58071 L 1 g
F
P
p
.002 w
.47498 .56685 m .5061 .55417 L p
.49786 .58099 L 1 g
F P
s
P
p
.002 w
.49113 .58094 m .47498 .56685 L p
.49786 .58099 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51097 .58109 L p
.49637 .5815 L 1 g
F P
s
P
p
.002 w
.51097 .58109 m .51093 .58044 L p
.5029 .58103 L 1 g
F P
s
P
p
.5029 .58103 m .49637 .5815 L .51097 .58109 L 1 g
F
P
p
.49891 .581 m .49685 .58141 L .50244 .58102 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.5061 .55417 m .52067 .56718 L .50244 .58102 L p
1 g
F P
s
P
p
.49786 .58099 m .5061 .55417 L .50244 .58102 L 1 g
F
P
p
.49685 .58141 m .49637 .5815 L .51093 .58044 L 1 g
F
P
p
.002 w
.48889 .583 m .51017 .583 L p
.49637 .5815 L 1 g
F P
s
P
p
.002 w
.51017 .583 m .51111 .583 L p
.49637 .5815 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58071 L p
1 g
F P
s
P
p
.47989 .57785 m .4678 .57686 L .48905 .58071 L 1 g
F
P
p
.002 w
.42842 .54224 m .4452 .57521 L .41777 .57908 L p
1 g
F P
s
P
p
.002 w
.41777 .57908 m .39741 .54009 L .42842 .54224 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52048 .45678 L
s
P
p
.004 w
.54339 .48616 m
.54825 .49239 L
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.65432 .48612 m .64878 .45764 L .66684 .43604 L p
1 g
F P
s
P
p
.002 w
.64734 .40523 m .66684 .43604 L .64878 .45764 L p
1 g
F P
s
P
p
.002 w
.66684 .43604 m .64734 .40523 L .65667 .37809 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.39284 .49387 m .39741 .54009 L .37021 .53472 L p
1 g
F P
s
P
p
.002 w
.37021 .53472 m .36459 .48266 L .39284 .49387 L p
1 g
F P
s
P
p
.002 w
.38987 .35687 m .35553 .4112 L .33776 .39531 L p
1 g
F P
s
P
p
.002 w
.33776 .39531 m .37339 .33857 L .38987 .35687 L p
1 g
F P
s
P
p
.002 w
.62057 .35211 m .65667 .37809 L .64734 .40523 L p
1 g
F P
s
P
p
.002 w
.65667 .37809 m .62057 .35211 L .62069 .3236 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.62667 .51923 m .62975 .49848 L .65432 .48612 L p
1 g
F P
s
P
p
.002 w
.64878 .45764 m .65432 .48612 L .62975 .49848 L p
1 g
F P
s
P
p
.002 w
.37826 .42817 m .36459 .48266 L .34112 .47018 L p
1 g
F P
s
P
p
.002 w
.34112 .47018 m .35553 .4112 L .37826 .42817 L p
1 g
F P
s
P
p
.002 w
.56156 .28399 m .49999 .28906 L .48819 .26803 L p
1 g
F P
s
P
p
.002 w
.42579 .29421 m .48819 .26803 L .49999 .28906 L p
1 g
F P
s
P
p
.002 w
.57631 .54488 m .58627 .5386 L .60162 .55588 L p
1 g
F P
s
P
p
.002 w
.60162 .55588 m .5823 .56809 L .57631 .54488 L p
1 g
F P
s
P
p
.002 w
.61693 .53903 m .60162 .55588 L .58627 .5386 L p
1 g
F P
s
P
p
.002 w
.5691 .31006 m .62069 .3236 L .62057 .35211 L p
1 g
F P
s
P
p
.002 w
.62069 .3236 m .5691 .31006 L .56156 .28399 L p
1 g
F P
s
P
p
.002 w
.5653 .54809 m .57631 .54488 L .5823 .56809 L p
1 g
F P
s
P
p
.002 w
.5823 .56809 m .56091 .5744 L .5653 .54809 L p
1 g
F P
s
P
p
.002 w
.58627 .5386 m .59415 .52991 L .61693 .53903 L p
1 g
F P
s
P
p
.002 w
.62667 .51923 m .61693 .53903 L .59415 .52991 L p
1 g
F P
s
P
p
.002 w
.49999 .28906 m .56156 .28399 L .5691 .31006 L p
1 g
F P
s
P
p
.002 w
.44017 .31432 m .38987 .35687 L .37339 .33857 L p
1 g
F P
s
P
p
.002 w
.37339 .33857 m .42579 .29421 L .44017 .31432 L p
1 g
F P
s
P
p
.002 w
.49999 .28906 m .44017 .31432 L .42579 .29421 L p
1 g
F P
s
P
p
.002 w
.59415 .52991 m .59911 .51972 L .62667 .51923 L p
1 g
F P
s
P
p
.002 w
.62975 .49848 m .62667 .51923 L .59911 .51972 L p
1 g
F P
s
P
p
.002 w
.62975 .49848 m .62575 .47893 L .64878 .45764 L p
1 g
F P
s
P
p
.002 w
.63331 .43377 m .64878 .45764 L .62575 .47893 L p
1 g
F P
s
P
p
.002 w
.64878 .45764 m .63331 .43377 L .64734 .40523 L p
1 g
F P
s
P
p
.002 w
.42497 .50335 m .42842 .54224 L .39741 .54009 L p
1 g
F P
s
P
p
.002 w
.39741 .54009 m .39284 .49387 L .42497 .50335 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61676 .3837 m .64734 .40523 L .63331 .43377 L p
1 g
F P
s
P
p
.002 w
.64734 .40523 m .61676 .3837 L .62057 .35211 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.59911 .51972 m .6006 .50908 L .62975 .49848 L p
1 g
F P
s
P
p
.002 w
.62575 .47893 m .62975 .49848 L .6006 .50908 L p
1 g
F P
s
P
p
.002 w
.41023 .37799 m .37826 .42817 L .35553 .4112 L p
1 g
F P
s
P
p
.002 w
.35553 .4112 m .38987 .35687 L .41023 .37799 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.4053 .44562 m .39284 .49387 L .36459 .48266 L p
1 g
F P
s
P
p
.002 w
.36459 .48266 m .37826 .42817 L .4053 .44562 L p
1 g
F P
s
P
p
.002 w
.57471 .34049 m .62057 .35211 L .61676 .3837 L p
1 g
F P
s
P
p
.002 w
.62057 .35211 m .57471 .34049 L .5691 .31006 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.5691 .31006 m .51215 .31505 L .49999 .28906 L p
1 g
F P
s
P
p
.002 w
.44017 .31432 m .49999 .28906 L .51215 .31505 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51215 .31505 m .5691 .31006 L .57471 .34049 L p
1 g
F P
s
P
p
.002 w
.49759 .53636 m .5061 .55417 L .47498 .56685 L p
1 g
F P
s
P
p
.002 w
.47498 .56685 m .46221 .54101 L .49759 .53636 L p
1 g
F P
s
P
p
.002 w
.58627 .5386 m .57631 .54488 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.59415 .52991 m .58627 .5386 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.53743 .53751 m .54476 .54423 L .52067 .56718 L p
1 g
F P
s
P
p
.002 w
.52067 .56718 m .5061 .55417 L .53743 .53751 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59911 .51972 m .59415 .52991 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.6006 .50908 m .59845 .49914 L .62575 .47893 L p
1 g
F P
s
P
p
.002 w
.61495 .4627 m .62575 .47893 L .59845 .49914 L p
1 g
F P
s
P
p
.002 w
.62575 .47893 m .61495 .4627 L .63331 .43377 L p
1 g
F P
s
P
p
.002 w
.60928 .41728 m .63331 .43377 L .61495 .4627 L p
1 g
F P
s
P
p
.002 w
.63331 .43377 m .60928 .41728 L .61676 .3837 L p
1 g
F P
s
P
p
.002 w
.6006 .50908 m .59911 .51972 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.45683 .3386 m .41023 .37799 L .38987 .35687 L p
1 g
F P
s
P
p
.002 w
.38987 .35687 m .44017 .31432 L .45683 .3386 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51215 .31505 m .45683 .3386 L .44017 .31432 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59845 .49914 m .6006 .50908 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.57812 .37431 m .61676 .3837 L .60928 .41728 L p
1 g
F P
s
P
p
.002 w
.61676 .3837 m .57812 .37431 L .57471 .34049 L p
1 g
F P
s
P
p
.002 w
.43576 .46289 m .42497 .50335 L .39284 .49387 L p
1 g
F P
s
P
p
.002 w
.39284 .49387 m .4053 .44562 L .43576 .46289 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53324 .52841 m .53743 .53751 L .5061 .55417 L p
1 g
F P
s
P
p
.002 w
.5061 .55417 m .49759 .53636 L .53324 .52841 L p
1 g
F P
s
P
p
.002 w
.43384 .40121 m .4053 .44562 L .37826 .42817 L p
1 g
F P
s
P
p
.002 w
.37826 .42817 m .41023 .37799 L .43384 .40121 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59284 .49096 m .59845 .49914 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.59845 .49914 m .59284 .49096 L .61495 .4627 L p
1 g
F P
s
P
p
.002 w
.59836 .45164 m .61495 .4627 L .59284 .49096 L p
1 g
F P
s
P
p
.002 w
.61495 .4627 m .59836 .45164 L .60928 .41728 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.52421 .34525 m .57471 .34049 L .57812 .37431 L p
1 g
F P
s
P
p
.002 w
.57471 .34049 m .52421 .34525 L .51215 .31505 L p
1 g
F P
s
P
p
.002 w
.49623 .51563 m .49759 .53636 L .46221 .54101 L p
1 g
F P
s
P
p
.002 w
.46221 .54101 m .45986 .51071 L .49623 .51563 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.58435 .48546 m .59284 .49096 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.57387 .48327 m .58435 .48546 L .5678 .51746 L closepath p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.45683 .3386 m .51215 .31505 L .52421 .34525 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.59284 .49096 m .58435 .48546 L .59836 .45164 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57914 .41029 m .60928 .41728 L .59836 .45164 L p
1 g
F P
s
P
p
.002 w
.60928 .41728 m .57914 .41029 L .57812 .37431 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53267 .5179 m .53324 .52841 L .49759 .53636 L p
1 g
F P
s
P
p
.002 w
.49759 .53636 m .49623 .51563 L .53267 .5179 L p
1 g
F P
s
P
p
.002 w
.4752 .36629 m .43384 .40121 L .41023 .37799 L p
1 g
F P
s
P
p
.002 w
.41023 .37799 m .45683 .3386 L .4752 .36629 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.52421 .34525 m .4752 .36629 L .45683 .3386 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.58435 .48546 m .57387 .48327 L .57771 .44709 L p
1 g
F P
s
P
p
.002 w
.57771 .44709 m .59836 .45164 L .58435 .48546 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.59836 .45164 m .57771 .44709 L .57914 .41029 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53572 .3786 m .57812 .37431 L .57914 .41029 L p
1 g
F P
s
P
p
.002 w
.57812 .37431 m .53572 .3786 L .52421 .34525 L p
1 g
F P
s
P
p
.002 w
.45989 .42571 m .43576 .46289 L .4053 .44562 L p
1 g
F P
s
P
p
.002 w
.4053 .44562 m .43384 .40121 L .45989 .42571 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.53584 .50713 m .53267 .5179 L .49623 .51563 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57387 .48327 m .56255 .48467 L .55528 .4497 L p
1 g
F P
s
P
p
.002 w
.55528 .4497 m .57771 .44709 L .57387 .48327 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.50231 .49426 m .49623 .51563 L .45986 .51071 L p
1 g
F P
s
P
p
.002 w
.45986 .51071 m .46852 .47933 L .50231 .49426 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.4752 .36629 m .52421 .34525 L .53572 .3786 L p
1 g
F P
s
P
p
.002 w
.49623 .51563 m .50231 .49426 L .53584 .50713 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.54241 .49731 m .53584 .50713 L .50231 .49426 L p
1 g
F P
s
P
p
.002 w
.53362 .45926 m .55528 .4497 L .56255 .48467 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54622 .41387 m .57914 .41029 L .57771 .44709 L p
1 g
F P
s
P
p
.002 w
.57914 .41029 m .54622 .41387 L .53572 .3786 L p
1 g
F P
s
P
p
.002 w
.57771 .44709 m .55528 .4497 L .54622 .41387 L p
1 g
F P
s
P
p
.002 w
.55166 .48953 m .54241 .49731 L .51526 .47472 L p
1 g
F P
s
P
p
.002 w
.50231 .49426 m .51526 .47472 L .54241 .49731 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.49463 .39641 m .45989 .42571 L .43384 .40121 L p
1 g
F P
s
P
p
.002 w
.43384 .40121 m .4752 .36629 L .49463 .39641 L p
1 g
F P
s
P
p
.002 w
.43576 .46289 m .45989 .42571 L .48739 .45054 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.53572 .3786 m .49463 .39641 L .4752 .36629 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.51526 .47472 m .50231 .49426 L .46852 .47933 L p
1 g
F P
s
P
p
.002 w
.49463 .39641 m .53572 .3786 L .54622 .41387 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55528 .4497 m .53362 .45926 L .51436 .42781 L p
1 g
F P
s
P
p
.002 w
.51436 .42781 m .54622 .41387 L .55528 .4497 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54622 .41387 m .51436 .42781 L .49463 .39641 L p
1 g
F P
s
P
p
.002 w
.48739 .45054 m .51436 .42781 L .53362 .45926 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51436 .42781 m .48739 .45054 L .45989 .42571 L p
1 g
F P
s
P
p
.002 w
.45989 .42571 m .49463 .39641 L .51436 .42781 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.59035 .54639 m
.60868 .5699 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .76606 .34212 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60868 .5699 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.569767)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.569767)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48218 .46925 m .5208 .45291 L .50646 .42828 L p
1 g
F P
s
P
p
.002 w
.50646 .42828 m .47426 .44186 L .48218 .46925 L p
1 g
F P
s
P
p
.002 w
.53387 .40689 m .50646 .42828 L .5208 .45291 L p
1 g
F P
s
P
p
.002 w
.47426 .44186 m .50646 .42828 L .49196 .40371 L p
1 g
F P
s
P
p
.002 w
.50646 .42828 m .53387 .40689 L .51318 .38707 L p
1 g
F P
s
P
p
.002 w
.51318 .38707 m .49196 .40371 L .50646 .42828 L p
1 g
F P
s
P
p
.002 w
.49196 .40371 m .46697 .41422 L .47426 .44186 L p
1 g
F P
s
P
p
.002 w
.46697 .41422 m .49196 .40371 L .47758 .37965 L p
1 g
F P
s
P
p
.002 w
.49196 .40371 m .51318 .38707 L .49208 .36821 L p
1 g
F P
s
P
p
.002 w
.49208 .36821 m .47758 .37965 L .49196 .40371 L p
1 g
F P
s
P
p
.002 w
.44146 .4748 m .48218 .46925 L .47426 .44186 L p
1 g
F P
s
P
p
.002 w
.47426 .44186 m .44032 .44631 L .44146 .4748 L p
1 g
F P
s
P
p
.002 w
.44032 .44631 m .47426 .44186 L .46697 .41422 L p
1 g
F P
s
P
p
.002 w
.49059 .49589 m .53473 .47715 L .5208 .45291 L p
1 g
F P
s
P
p
.002 w
.5208 .45291 m .48218 .46925 L .49059 .49589 L p
1 g
F P
s
P
p
.002 w
.55376 .42732 m .5208 .45291 L .53473 .47715 L p
1 g
F P
s
P
p
.002 w
.5208 .45291 m .55376 .42732 L .53387 .40689 L p
1 g
F P
s
P
p
.002 w
.46697 .41422 m .44065 .41754 L .44032 .44631 L p
1 g
F P
s
P
p
.002 w
.44065 .41754 m .46697 .41422 L .46044 .38683 L p
1 g
F P
s
P
p
.002 w
.47758 .37965 m .46044 .38683 L .46697 .41422 L p
1 g
F P
s
P
p
.002 w
.55382 .37967 m .53387 .40689 L .55376 .42732 L p
1 g
F P
s
P
p
.002 w
.53387 .40689 m .55382 .37967 L .52851 .36588 L p
1 g
F P
s
P
p
.002 w
.52851 .36588 m .51318 .38707 L .53387 .40689 L p
1 g
F P
s
P
p
.002 w
.44403 .50247 m .49059 .49589 L .48218 .46925 L p
1 g
F P
s
P
p
.002 w
.48218 .46925 m .44146 .4748 L .44403 .50247 L p
1 g
F P
s
P
p
.002 w
.51318 .38707 m .52851 .36588 L .50247 .35365 L p
1 g
F P
s
P
p
.002 w
.50247 .35365 m .49208 .36821 L .51318 .38707 L p
1 g
F P
s
P
p
.002 w
.53473 .47715 m .57251 .44799 L .55376 .42732 L p
1 g
F P
s
P
p
.002 w
.57795 .39478 m .55376 .42732 L .57251 .44799 L p
1 g
F P
s
P
p
.002 w
.55376 .42732 m .57795 .39478 L .55382 .37967 L p
1 g
F P
s
P
p
.002 w
.46044 .38683 m .47758 .37965 L .46356 .35653 L p
1 g
F P
s
P
p
.002 w
.47758 .37965 m .49208 .36821 L .47095 .35067 L p
1 g
F P
s
P
p
.002 w
.47095 .35067 m .46356 .35653 L .47758 .37965 L p
1 g
F P
s
P
p
.002 w
.49934 .52129 m .54799 .50057 L .53473 .47715 L p
1 g
F P
s
P
p
.002 w
.53473 .47715 m .49059 .49589 L .49934 .52129 L p
1 g
F P
s
P
p
.002 w
.57251 .44799 m .53473 .47715 L .54799 .50057 L p
1 g
F P
s
P
p
.002 w
.46044 .38683 m .44241 .38901 L .44065 .41754 L p
1 g
F P
s
P
p
.002 w
.44241 .38901 m .46044 .38683 L .45481 .36019 L p
1 g
F P
s
P
p
.002 w
.46356 .35653 m .45481 .36019 L .46044 .38683 L p
1 g
F P
s
P
p
.002 w
.4079 .44104 m .44032 .44631 L .44065 .41754 L p
1 g
F P
s
P
p
.002 w
.44065 .41754 m .41559 .41324 L .4079 .44104 L p
1 g
F P
s
P
p
.002 w
.41559 .41324 m .44065 .41754 L .44241 .38901 L p
1 g
F P
s
P
p
.002 w
.40243 .46879 m .44146 .4748 L .44032 .44631 L p
1 g
F P
s
P
p
.002 w
.44032 .44631 m .4079 .44104 L .40243 .46879 L p
1 g
F P
s
P
p
.002 w
.49208 .36821 m .50247 .35365 L .4762 .34322 L p
1 g
F P
s
P
p
.002 w
.4762 .34322 m .47095 .35067 L .49208 .36821 L p
1 g
F P
s
P
p
.002 w
.44804 .52878 m .49934 .52129 L .49059 .49589 L p
1 g
F P
s
P
p
.002 w
.49059 .49589 m .44403 .50247 L .44804 .52878 L p
1 g
F P
s
P
p
.002 w
.5363 .34219 m .52851 .36588 L .55382 .37967 L p
1 g
F P
s
P
p
.002 w
.52851 .36588 m .5363 .34219 L .50763 .33743 L p
1 g
F P
s
P
p
.002 w
.50763 .33743 m .50247 .35365 L .52851 .36588 L p
1 g
F P
s
P
p
.002 w
.44241 .38901 m .42532 .38593 L .41559 .41324 L p
1 g
F P
s
P
p
.002 w
.42532 .38593 m .44241 .38901 L .44561 .36126 L p
1 g
F P
s
P
p
.002 w
.45481 .36019 m .44561 .36126 L .44241 .38901 L p
1 g
F P
s
P
p
.002 w
.39931 .49596 m .44403 .50247 L .44146 .4748 L p
1 g
F P
s
P
p
.002 w
.44146 .4748 m .40243 .46879 L .39931 .49596 L p
1 g
F P
s
P
p
.002 w
.56421 .34915 m .55382 .37967 L .57795 .39478 L p
1 g
F P
s
P
p
.002 w
.55382 .37967 m .56421 .34915 L .5363 .34219 L p
1 g
F P
s
P
p
.002 w
.54799 .50057 m .58973 .46852 L .57251 .44799 L p
1 g
F P
s
P
p
.002 w
.60041 .41093 m .57251 .44799 L .58973 .46852 L p
1 g
F P
s
P
p
.002 w
.57251 .44799 m .60041 .41093 L .57795 .39478 L p
1 g
F P
s
P
p
.002 w
.50247 .35365 m .50763 .33743 L .47874 .33495 L p
1 g
F P
s
P
p
.002 w
.47874 .33495 m .4762 .34322 L .50247 .35365 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .45481 .36019 L .46356 .35653 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .46356 .35653 L .47095 .35067 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .44561 .36126 L .45481 .36019 L closepath p
1 g
F P
s
P
p
.002 w
.50828 .54493 m .56032 .5227 L .54799 .50057 L p
1 g
F P
s
P
p
.002 w
.54799 .50057 m .49934 .52129 L .50828 .54493 L p
1 g
F P
s
P
p
.002 w
.58973 .46852 m .54799 .50057 L .56032 .5227 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .47095 .35067 L .4762 .34322 L closepath p
1 g
F P
s
P
p
.002 w
.59079 .3582 m .57795 .39478 L .60041 .41093 L p
1 g
F P
s
P
p
.002 w
.57795 .39478 m .59079 .3582 L .56421 .34915 L p
1 g
F P
s
P
p
.002 w
.38028 .42628 m .4079 .44104 L .41559 .41324 L p
1 g
F P
s
P
p
.002 w
.41559 .41324 m .39438 .40159 L .38028 .42628 L p
1 g
F P
s
P
p
.002 w
.39438 .40159 m .41559 .41324 L .42532 .38593 L p
1 g
F P
s
P
p
.002 w
.42532 .38593 m .41096 .37781 L .39438 .40159 L p
1 g
F P
s
P
p
.002 w
.41096 .37781 m .42532 .38593 L .43692 .35962 L p
1 g
F P
s
P
p
.002 w
.44561 .36126 m .43692 .35962 L .42532 .38593 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .43692 .35962 L .44561 .36126 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .4762 .34322 L .47874 .33495 L closepath p
1 g
F P
s
P
p
.002 w
.45342 .55318 m .50828 .54493 L .49934 .52129 L p
1 g
F P
s
P
p
.002 w
.49934 .52129 m .44804 .52878 L .45342 .55318 L p
1 g
F P
s
P
p
.002 w
.39866 .522 m .44804 .52878 L .44403 .50247 L p
1 g
F P
s
P
p
.002 w
.44403 .50247 m .39931 .49596 L .39866 .522 L p
1 g
F P
s
P
p
.002 w
.36899 .45142 m .40243 .46879 L .4079 .44104 L p
1 g
F P
s
P
p
.002 w
.4079 .44104 m .38028 .42628 L .36899 .45142 L p
1 g
F P
s
P
p
.002 w
.50692 .32122 m .50763 .33743 L .5363 .34219 L p
1 g
F P
s
P
p
.002 w
.50763 .33743 m .50692 .32122 L .47827 .32674 L p
1 g
F P
s
P
p
.002 w
.47827 .32674 m .47874 .33495 L .50763 .33743 L p
1 g
F P
s
P
p
.002 w
.43692 .35962 m .42969 .35541 L .41096 .37781 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .42969 .35541 L .43692 .35962 L closepath p
1 g
F P
s
P
p
.002 w
.53557 .31839 m .5363 .34219 L .56421 .34915 L p
1 g
F P
s
P
p
.002 w
.5363 .34219 m .53557 .31839 L .50692 .32122 L p
1 g
F P
s
P
p
.002 w
.56032 .5227 m .60507 .4885 L .58973 .46852 L p
1 g
F P
s
P
p
.002 w
.62075 .42783 m .58973 .46852 L .60507 .4885 L p
1 g
F P
s
P
p
.002 w
.58973 .46852 m .62075 .42783 L .60041 .41093 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .47874 .33495 L .47827 .32674 L closepath p
1 g
F P
s
P
p
.002 w
.61551 .36919 m .60041 .41093 L .62075 .42783 L p
1 g
F P
s
P
p
.002 w
.60041 .41093 m .61551 .36919 L .59079 .3582 L p
1 g
F P
s
P
p
.002 w
.40091 .36543 m .41096 .37781 L .42969 .35541 L p
1 g
F P
s
P
p
.002 w
.42969 .35541 m .42469 .34908 L .40091 .36543 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .42469 .34908 L .42969 .35541 L closepath p
1 g
F P
s
P
p
.002 w
.37936 .38359 m .39438 .40159 L .41096 .37781 L p
1 g
F P
s
P
p
.002 w
.41096 .37781 m .40091 .36543 L .37936 .38359 L p
1 g
F P
s
P
p
.002 w
.56364 .31832 m .56421 .34915 L .59079 .3582 L p
1 g
F P
s
P
p
.002 w
.56421 .34915 m .56364 .31832 L .53557 .31839 L p
1 g
F P
s
P
p
.002 w
.36081 .47648 m .39931 .49596 L .40243 .46879 L p
1 g
F P
s
P
p
.002 w
.40243 .46879 m .36899 .45142 L .36081 .47648 L p
1 g
F P
s
P
p
.002 w
.47483 .31947 m .47827 .32674 L .50692 .32122 L p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .47827 .32674 L .47483 .31947 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .47483 .31947 L .46873 .31395 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .46873 .31395 L .46064 .3108 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .46064 .3108 L .45142 .31039 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .45142 .31039 L .4421 .31279 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .4421 .31279 L .43374 .31774 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .43374 .31774 L .42725 .32468 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .42725 .32468 L .42336 .33282 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .42336 .33282 L .42249 .34127 L closepath p
1 g
F P
s
P
p
.002 w
.45019 .33482 m .42249 .34127 L .42469 .34908 L closepath p
1 g
F P
s
P
p
.002 w
.5003 .30676 m .50692 .32122 L .53557 .31839 L p
1 g
F P
s
P
p
.002 w
.50692 .32122 m .5003 .30676 L .47483 .31947 L p
1 g
F P
s
P
p
.002 w
.36052 .40322 m .38028 .42628 L .39438 .40159 L p
1 g
F P
s
P
p
.002 w
.39438 .40159 m .37936 .38359 L .36052 .40322 L p
1 g
F P
s
P
p
.002 w
.51724 .56628 m .57144 .54306 L .56032 .5227 L p
1 g
F P
s
P
p
.002 w
.56032 .5227 m .50828 .54493 L .51724 .56628 L p
1 g
F P
s
P
p
.002 w
.60507 .4885 m .56032 .5227 L .57144 .54306 L p
1 g
F P
s
P
p
.002 w
.39636 .35003 m .40091 .36543 L .42469 .34908 L p
1 g
F P
s
P
p
.002 w
.42469 .34908 m .42249 .34127 L .39636 .35003 L p
1 g
F P
s
P
p
.002 w
.40057 .54631 m .45342 .55318 L .44804 .52878 L p
1 g
F P
s
P
p
.002 w
.44804 .52878 m .39866 .522 L .40057 .54631 L p
1 g
F P
s
P
p
.002 w
.46873 .31395 m .47483 .31947 L .5003 .30676 L p
1 g
F P
s
P
p
.002 w
.46013 .5751 m .51724 .56628 L .50828 .54493 L p
1 g
F P
s
P
p
.002 w
.50828 .54493 m .45342 .55318 L .46013 .5751 L p
1 g
F P
s
P
p
.002 w
.59056 .32108 m .59079 .3582 L .61551 .36919 L p
1 g
F P
s
P
p
.002 w
.59079 .3582 m .59056 .32108 L .56364 .31832 L p
1 g
F P
s
P
p
.002 w
.52612 .29699 m .53557 .31839 L .56364 .31832 L p
1 g
F P
s
P
p
.002 w
.53557 .31839 m .52612 .29699 L .5003 .30676 L p
1 g
F P
s
P
p
.002 w
.39793 .33325 m .39636 .35003 L .42249 .34127 L p
1 g
F P
s
P
p
.002 w
.42249 .34127 m .42336 .33282 L .39793 .33325 L p
1 g
F P
s
P
p
.002 w
.37237 .36099 m .37936 .38359 L .40091 .36543 L p
1 g
F P
s
P
p
.002 w
.40091 .36543 m .39636 .35003 L .37237 .36099 L p
1 g
F P
s
P
p
.002 w
.34486 .42393 m .36899 .45142 L .38028 .42628 L p
1 g
F P
s
P
p
.002 w
.38028 .42628 m .36052 .40322 L .34486 .42393 L p
1 g
F P
s
P
p
.002 w
.57144 .54306 m .61814 .50753 L .60507 .4885 L p
1 g
F P
s
P
p
.002 w
.63849 .44516 m .60507 .4885 L .61814 .50753 L p
1 g
F P
s
P
p
.002 w
.60507 .4885 m .63849 .44516 L .62075 .42783 L p
1 g
F P
s
P
p
.002 w
.35602 .50095 m .39866 .522 L .39931 .49596 L p
1 g
F P
s
P
p
.002 w
.39931 .49596 m .36081 .47648 L .35602 .50095 L p
1 g
F P
s
P
p
.002 w
.5003 .30676 m .48836 .29567 L .46873 .31395 L p
1 g
F P
s
P
p
.002 w
.46064 .3108 m .46873 .31395 L .48836 .29567 L p
1 g
F P
s
P
p
.002 w
.6378 .38196 m .62075 .42783 L .63849 .44516 L p
1 g
F P
s
P
p
.002 w
.62075 .42783 m .6378 .38196 L .61551 .36919 L p
1 g
F P
s
P
p
.002 w
.48836 .29567 m .5003 .30676 L .52612 .29699 L p
1 g
F P
s
P
p
.002 w
.40557 .31696 m .39793 .33325 L .42336 .33282 L p
1 g
F P
s
P
p
.002 w
.42336 .33282 m .42725 .32468 L .40557 .31696 L p
1 g
F P
s
P
p
.002 w
.48836 .29567 m .47231 .28926 L .46064 .3108 L p
1 g
F P
s
P
p
.002 w
.45142 .31039 m .46064 .3108 L .47231 .28926 L p
1 g
F P
s
P
p
.002 w
.41849 .30303 m .40557 .31696 L .42725 .32468 L p
1 g
F P
s
P
p
.002 w
.42725 .32468 m .43374 .31774 L .41849 .30303 L p
1 g
F P
s
P
p
.002 w
.55175 .29042 m .56364 .31832 L .59056 .32108 L p
1 g
F P
s
P
p
.002 w
.56364 .31832 m .55175 .29042 L .52612 .29699 L p
1 g
F P
s
P
p
.002 w
.3511 .37398 m .36052 .40322 L .37936 .38359 L p
1 g
F P
s
P
p
.002 w
.37936 .38359 m .37237 .36099 L .3511 .37398 L p
1 g
F P
s
P
p
.002 w
.47231 .28926 m .45392 .28835 L .45142 .31039 L p
1 g
F P
s
P
p
.002 w
.4421 .31279 m .45142 .31039 L .45392 .28835 L p
1 g
F P
s
P
p
.002 w
.61573 .32669 m .61551 .36919 L .6378 .38196 L p
1 g
F P
s
P
p
.002 w
.61551 .36919 m .61573 .32669 L .59056 .32108 L p
1 g
F P
s
P
p
.002 w
.43525 .29311 m .41849 .30303 L .43374 .31774 L p
1 g
F P
s
P
p
.002 w
.43374 .31774 m .4421 .31279 L .43525 .29311 L p
1 g
F P
s
P
p
.002 w
.45392 .28835 m .43525 .29311 L .4421 .31279 L p
1 g
F P
s
P
p
.002 w
.40511 .56831 m .46013 .5751 L .45342 .55318 L p
1 g
F P
s
P
p
.002 w
.45342 .55318 m .40057 .54631 L .40511 .56831 L p
1 g
F P
s
P
p
.002 w
.37446 .33617 m .37237 .36099 L .39636 .35003 L p
1 g
F P
s
P
p
.002 w
.39636 .35003 m .39793 .33325 L .37446 .33617 L p
1 g
F P
s
P
p
.002 w
.33282 .44532 m .36081 .47648 L .36899 .45142 L p
1 g
F P
s
P
p
.002 w
.36899 .45142 m .34486 .42393 L .33282 .44532 L p
1 g
F P
s
P
p
.002 w
.52602 .5848 m .58107 .56117 L .57144 .54306 L p
1 g
F P
s
P
p
.002 w
.57144 .54306 m .51724 .56628 L .52602 .5848 L p
1 g
F P
s
P
p
.002 w
.61814 .50753 m .57144 .54306 L .58107 .56117 L p
1 g
F P
s
P
p
.002 w
.52612 .29699 m .5087 .28043 L .48836 .29567 L p
1 g
F P
s
P
p
.002 w
.47231 .28926 m .48836 .29567 L .5087 .28043 L p
1 g
F P
s
P
p
.002 w
.5087 .28043 m .52612 .29699 L .55175 .29042 L p
1 g
F P
s
P
p
.002 w
.35483 .52423 m .40057 .54631 L .39866 .522 L p
1 g
F P
s
P
p
.002 w
.39866 .522 m .35602 .50095 L .35483 .52423 L p
1 g
F P
s
P
p
.002 w
.46807 .59396 m .52602 .5848 L .51724 .56628 L p
1 g
F P
s
P
p
.002 w
.51724 .56628 m .46013 .5751 L .46807 .59396 L p
1 g
F P
s
P
p
.002 w
.61814 .50753 m .65316 .46258 L .63849 .44516 L p
1 g
F P
s
P
p
.002 w
.65711 .39628 m .63849 .44516 L .65316 .46258 L p
1 g
F P
s
P
p
.002 w
.63849 .44516 m .65711 .39628 L .6378 .38196 L p
1 g
F P
s
P
p
.002 w
.38565 .31192 m .37446 .33617 L .39793 .33325 L p
1 g
F P
s
P
p
.002 w
.39793 .33325 m .40557 .31696 L .38565 .31192 L p
1 g
F P
s
P
p
.002 w
.58107 .56117 m .62858 .52517 L .61814 .50753 L p
1 g
F P
s
P
p
.002 w
.65316 .46258 m .61814 .50753 L .62858 .52517 L p
1 g
F P
s
P
p
.002 w
.57663 .2873 m .59056 .32108 L .61573 .32669 L p
1 g
F P
s
P
p
.002 w
.59056 .32108 m .57663 .2873 L .55175 .29042 L p
1 g
F P
s
P
p
.002 w
.33313 .38879 m .34486 .42393 L .36052 .40322 L p
1 g
F P
s
P
p
.002 w
.36052 .40322 m .3511 .37398 L .33313 .38879 L p
1 g
F P
s
P
p
.002 w
.5087 .28043 m .48502 .27075 L .47231 .28926 L p
1 g
F P
s
P
p
.002 w
.45392 .28835 m .47231 .28926 L .48502 .27075 L p
1 g
F P
s
P
p
.002 w
.35355 .34162 m .3511 .37398 L .37237 .36099 L p
1 g
F P
s
P
p
.002 w
.37237 .36099 m .37446 .33617 L .35355 .34162 L p
1 g
F P
s
P
p
.002 w
.63852 .33512 m .6378 .38196 L .65711 .39628 L p
1 g
F P
s
P
p
.002 w
.6378 .38196 m .63852 .33512 L .61573 .32669 L p
1 g
F P
s
P
p
.002 w
.32483 .46691 m .35602 .50095 L .36081 .47648 L p
1 g
F P
s
P
p
.002 w
.36081 .47648 m .33282 .44532 L .32483 .46691 L p
1 g
F P
s
P
p
.002 w
.40485 .29113 m .38565 .31192 L .40557 .31696 L p
1 g
F P
s
P
p
.002 w
.40557 .31696 m .41849 .30303 L .40485 .29113 L p
1 g
F P
s
P
p
.002 w
.52933 .26866 m .55175 .29042 L .57663 .2873 L p
1 g
F P
s
P
p
.002 w
.55175 .29042 m .52933 .26866 L .5087 .28043 L p
1 g
F P
s
P
p
.002 w
.48502 .27075 m .45768 .26927 L .45392 .28835 L p
1 g
F P
s
P
p
.002 w
.43525 .29311 m .45392 .28835 L .45768 .26927 L p
1 g
F P
s
P
p
.002 w
.41228 .58739 m .46807 .59396 L .46013 .5751 L p
1 g
F P
s
P
p
.002 w
.46013 .5751 m .40511 .56831 L .41228 .58739 L p
1 g
F P
s
P
p
.002 w
.48502 .27075 m .5087 .28043 L .52933 .26866 L p
1 g
F P
s
P
p
.002 w
.42985 .27632 m .40485 .29113 L .41849 .30303 L p
1 g
F P
s
P
p
.002 w
.41849 .30303 m .43525 .29311 L .42985 .27632 L p
1 g
F P
s
P
p
.002 w
.45768 .26927 m .42985 .27632 L .43525 .29311 L p
1 g
F P
s
P
p
.002 w
.35744 .54575 m .40511 .56831 L .40057 .54631 L p
1 g
F P
s
P
p
.002 w
.40057 .54631 m .35483 .52423 L .35744 .54575 L p
1 g
F P
s
P
p
.002 w
.53443 .59996 m .58893 .57651 L .58107 .56117 L p
1 g
F P
s
P
p
.002 w
.58107 .56117 m .52602 .5848 L .53443 .59996 L p
1 g
F P
s
P
p
.002 w
.62858 .52517 m .58107 .56117 L .58893 .57651 L p
1 g
F P
s
P
p
.002 w
.31902 .40514 m .33282 .44532 L .34486 .42393 L p
1 g
F P
s
P
p
.002 w
.34486 .42393 m .33313 .38879 L .31902 .40514 L p
1 g
F P
s
P
p
.002 w
.60018 .28782 m .61573 .32669 L .63852 .33512 L p
1 g
F P
s
P
p
.002 w
.61573 .32669 m .60018 .28782 L .57663 .2873 L p
1 g
F P
s
P
p
.002 w
.47713 .60918 m .53443 .59996 L .52602 .5848 L p
1 g
F P
s
P
p
.002 w
.52602 .5848 m .46807 .59396 L .47713 .60918 L p
1 g
F P
s
P
p
.002 w
.62858 .52517 m .66431 .47971 L .65316 .46258 L p
1 g
F P
s
P
p
.002 w
.67289 .41191 m .65316 .46258 L .66431 .47971 L p
1 g
F P
s
P
p
.002 w
.65316 .46258 m .67289 .41191 L .65711 .39628 L p
1 g
F P
s
P
p
.002 w
.36805 .30982 m .35355 .34162 L .37446 .33617 L p
1 g
F P
s
P
p
.002 w
.37446 .33617 m .38565 .31192 L .36805 .30982 L p
1 g
F P
s
P
p
.002 w
.33583 .3496 m .33313 .38879 L .3511 .37398 L p
1 g
F P
s
P
p
.002 w
.3511 .37398 m .35355 .34162 L .33583 .3496 L p
1 g
F P
s
P
p
.002 w
.58893 .57651 m .63603 .54094 L .62858 .52517 L p
1 g
F P
s
P
p
.002 w
.66431 .47971 m .62858 .52517 L .63603 .54094 L p
1 g
F P
s
P
p
.002 w
.32127 .48821 m .35483 .52423 L .35602 .50095 L p
1 g
F P
s
P
p
.002 w
.35602 .50095 m .32483 .46691 L .32127 .48821 L p
1 g
F P
s
P
p
.002 w
.52933 .26866 m .49852 .25582 L .48502 .27075 L p
1 g
F P
s
P
p
.002 w
.45768 .26927 m .48502 .27075 L .49852 .25582 L p
1 g
F P
s
P
p
.002 w
.65833 .34629 m .65711 .39628 L .67289 .41191 L p
1 g
F P
s
P
p
.002 w
.65711 .39628 m .65833 .34629 L .63852 .33512 L p
1 g
F P
s
P
p
.002 w
.5498 .26078 m .57663 .2873 L .60018 .28782 L p
1 g
F P
s
P
p
.002 w
.57663 .2873 m .5498 .26078 L .52933 .26866 L p
1 g
F P
s
P
p
.002 w
.49852 .25582 m .52933 .26866 L .5498 .26078 L p
1 g
F P
s
P
p
.002 w
.39319 .28245 m .36805 .30982 L .38565 .31192 L p
1 g
F P
s
P
p
.002 w
.38565 .31192 m .40485 .29113 L .39319 .28245 L p
1 g
F P
s
P
p
.002 w
.42204 .60294 m .47713 .60918 L .46807 .59396 L p
1 g
F P
s
P
p
.002 w
.46807 .59396 m .41228 .58739 L .42204 .60294 L p
1 g
F P
s
P
p
.002 w
.49852 .25582 m .4627 .25374 L .45768 .26927 L p
1 g
F P
s
P
p
.002 w
.42985 .27632 m .45768 .26927 L .4627 .25374 L p
1 g
F P
s
P
p
.002 w
.36397 .56489 m .41228 .58739 L .40511 .56831 L p
1 g
F P
s
P
p
.002 w
.40511 .56831 m .35744 .54575 L .36397 .56489 L p
1 g
F P
s
P
p
.002 w
.30929 .42272 m .32483 .46691 L .33282 .44532 L p
1 g
F P
s
P
p
.002 w
.33282 .44532 m .31902 .40514 L .30929 .42272 L p
1 g
F P
s
P
p
.002 w
.62178 .29214 m .63852 .33512 L .65833 .34629 L p
1 g
F P
s
P
p
.002 w
.63852 .33512 m .62178 .29214 L .60018 .28782 L p
1 g
F P
s
P
p
.002 w
.42609 .26295 m .39319 .28245 L .40485 .29113 L p
1 g
F P
s
P
p
.002 w
.40485 .29113 m .42985 .27632 L .42609 .26295 L p
1 g
F P
s
P
p
.002 w
.4627 .25374 m .42609 .26295 L .42985 .27632 L p
1 g
F P
s
P
p
.002 w
.54225 .61121 m .59475 .58859 L .58893 .57651 L p
1 g
F P
s
P
p
.002 w
.58893 .57651 m .53443 .59996 L .54225 .61121 L p
1 g
F P
s
P
p
.002 w
.63603 .54094 m .58893 .57651 L .59475 .58859 L p
1 g
F P
s
P
p
.002 w
.3533 .31087 m .33583 .3496 L .35355 .34162 L p
1 g
F P
s
P
p
.002 w
.35355 .34162 m .36805 .30982 L .3533 .31087 L p
1 g
F P
s
P
p
.002 w
.63603 .54094 m .67152 .49614 L .66431 .47971 L p
1 g
F P
s
P
p
.002 w
.68459 .42853 m .66431 .47971 L .67152 .49614 L p
1 g
F P
s
P
p
.002 w
.66431 .47971 m .68459 .42853 L .67289 .41191 L p
1 g
F P
s
P
p
.002 w
.32187 .36004 m .31902 .40514 L .33313 .38879 L p
1 g
F P
s
P
p
.002 w
.33313 .38879 m .33583 .3496 L .32187 .36004 L p
1 g
F P
s
P
p
.002 w
.32242 .50865 m .35744 .54575 L .35483 .52423 L p
1 g
F P
s
P
p
.002 w
.35483 .52423 m .32127 .48821 L .32242 .50865 L p
1 g
F P
s
P
p
.002 w
.48714 .6202 m .54225 .61121 L .53443 .59996 L p
1 g
F P
s
P
p
.002 w
.53443 .59996 m .47713 .60918 L .48714 .6202 L p
1 g
F P
s
P
p
.002 w
.67453 .36006 m .67289 .41191 L .68459 .42853 L p
1 g
F P
s
P
p
.002 w
.67289 .41191 m .67453 .36006 L .65833 .34629 L p
1 g
F P
s
P
p
.002 w
.56961 .25715 m .60018 .28782 L .62178 .29214 L p
1 g
F P
s
P
p
.002 w
.60018 .28782 m .56961 .25715 L .5498 .26078 L p
1 g
F P
s
P
p
.002 w
.5498 .26078 m .51254 .245 L .49852 .25582 L p
1 g
F P
s
P
p
.002 w
.4627 .25374 m .49852 .25582 L .51254 .245 L p
1 g
F P
s
P
p
.002 w
.59475 .58859 m .64015 .55439 L .63603 .54094 L p
1 g
F P
s
P
p
.002 w
.67152 .49614 m .63603 .54094 L .64015 .55439 L p
1 g
F P
s
P
p
.002 w
.51254 .245 m .5498 .26078 L .56961 .25715 L p
1 g
F P
s
P
p
.002 w
.38394 .27741 m .3533 .31087 L .36805 .30982 L p
1 g
F P
s
P
p
.002 w
.36805 .30982 m .39319 .28245 L .38394 .27741 L p
1 g
F P
s
P
p
.002 w
.30443 .44113 m .32127 .48821 L .32483 .46691 L p
1 g
F P
s
P
p
.002 w
.32483 .46691 m .30929 .42272 L .30443 .44113 L p
1 g
F P
s
P
p
.002 w
.64081 .30032 m .65833 .34629 L .67453 .36006 L p
1 g
F P
s
P
p
.002 w
.65833 .34629 m .64081 .30032 L .62178 .29214 L p
1 g
F P
s
P
p
.002 w
.37444 .58102 m .42204 .60294 L .41228 .58739 L p
1 g
F P
s
P
p
.002 w
.41228 .58739 m .36397 .56489 L .37444 .58102 L p
1 g
F P
s
P
p
.002 w
.43429 .61438 m .48714 .6202 L .47713 .60918 L p
1 g
F P
s
P
p
.002 w
.47713 .60918 m .42204 .60294 L .43429 .61438 L p
1 g
F P
s
P
p
.002 w
.51254 .245 m .46891 .24234 L .4627 .25374 L p
1 g
F P
s
P
p
.002 w
.42609 .26295 m .4627 .25374 L .46891 .24234 L p
1 g
F P
s
P
p
.002 w
.42416 .25355 m .38394 .27741 L .39319 .28245 L p
1 g
F P
s
P
p
.002 w
.39319 .28245 m .42609 .26295 L .42416 .25355 L p
1 g
F P
s
P
p
.002 w
.31227 .37281 m .30929 .42272 L .31902 .40514 L p
1 g
F P
s
P
p
.002 w
.31902 .40514 m .32187 .36004 L .31227 .37281 L p
1 g
F P
s
P
p
.002 w
.34196 .31522 m .32187 .36004 L .33583 .3496 L p
1 g
F P
s
P
p
.002 w
.33583 .3496 m .3533 .31087 L .34196 .31522 L p
1 g
F P
s
P
p
.002 w
.46891 .24234 m .42416 .25355 L .42609 .26295 L p
1 g
F P
s
P
p
.002 w
.32851 .52764 m .36397 .56489 L .35744 .54575 L p
1 g
F P
s
P
p
.002 w
.35744 .54575 m .32242 .50865 L .32851 .52764 L p
1 g
F P
s
P
p
.002 w
.64015 .55439 m .67437 .51141 L .67152 .49614 L p
1 g
F P
s
P
p
.002 w
.69173 .44578 m .67152 .49614 L .67437 .51141 L p
1 g
F P
s
P
p
.002 w
.67152 .49614 m .69173 .44578 L .68459 .42853 L p
1 g
F P
s
P
p
.002 w
.54925 .61803 m .59825 .59689 L .59475 .58859 L p
1 g
F P
s
P
p
.002 w
.59475 .58859 m .54225 .61121 L .54925 .61803 L p
1 g
F P
s
P
p
.002 w
.64015 .55439 m .59475 .58859 L .59825 .59689 L p
1 g
F P
s
P
p
.002 w
.58824 .25809 m .62178 .29214 L .64081 .30032 L p
1 g
F P
s
P
p
.002 w
.62178 .29214 m .58824 .25809 L .56961 .25715 L p
1 g
F P
s
P
p
.002 w
.68656 .3762 m .68459 .42853 L .69173 .44578 L p
1 g
F P
s
P
p
.002 w
.68459 .42853 m .68656 .3762 L .67453 .36006 L p
1 g
F P
s
P
p
.002 w
.49791 .62648 m .54925 .61803 L .54225 .61121 L p
1 g
F P
s
P
p
.002 w
.54225 .61121 m .48714 .6202 L .49791 .62648 L p
1 g
F P
s
P
p
.002 w
.56961 .25715 m .52674 .23878 L .51254 .245 L p
1 g
F P
s
P
p
.002 w
.46891 .24234 m .51254 .245 L .52674 .23878 L p
1 g
F P
s
P
p
.002 w
.52674 .23878 m .56961 .25715 L .58824 .25809 L p
1 g
F P
s
P
p
.002 w
.59825 .59689 m .64063 .56502 L .64015 .55439 L p
1 g
F P
s
P
p
.002 w
.67437 .51141 m .64015 .55439 L .64063 .56502 L p
1 g
F P
s
P
p
.002 w
.30483 .45991 m .32242 .50865 L .32127 .48821 L p
1 g
F P
s
P
p
.002 w
.32127 .48821 m .30443 .44113 L .30483 .45991 L p
1 g
F P
s
P
p
.002 w
.65664 .31234 m .67453 .36006 L .68656 .3762 L p
1 g
F P
s
P
p
.002 w
.67453 .36006 m .65664 .31234 L .64081 .30032 L p
1 g
F P
s
P
p
.002 w
.38878 .59355 m .43429 .61438 L .42204 .60294 L p
1 g
F P
s
P
p
.002 w
.42204 .60294 m .37444 .58102 L .38878 .59355 L p
1 g
F P
s
P
p
.002 w
.37748 .27636 m .34196 .31522 L .3533 .31087 L p
1 g
F P
s
P
p
.002 w
.3533 .31087 m .38394 .27741 L .37748 .27636 L p
1 g
F P
s
P
p
.002 w
.44883 .62115 m .49791 .62648 L .48714 .6202 L p
1 g
F P
s
P
p
.002 w
.48714 .6202 m .43429 .61438 L .44883 .62115 L p
1 g
F P
s
P
p
.002 w
.52674 .23878 m .47623 .23562 L .46891 .24234 L p
1 g
F P
s
P
p
.002 w
.42416 .25355 m .46891 .24234 L .47623 .23562 L p
1 g
F P
s
P
p
.002 w
.30753 .38769 m .30443 .44113 L .30929 .42272 L p
1 g
F P
s
P
p
.002 w
.30929 .42272 m .31227 .37281 L .30753 .38769 L p
1 g
F P
s
P
p
.002 w
.33961 .54457 m .37444 .58102 L .36397 .56489 L p
1 g
F P
s
P
p
.002 w
.36397 .56489 m .32851 .52764 L .33961 .54457 L p
1 g
F P
s
P
p
.002 w
.33454 .32296 m .31227 .37281 L .32187 .36004 L p
1 g
F P
s
P
p
.002 w
.32187 .36004 m .34196 .31522 L .33454 .32296 L p
1 g
F P
s
P
p
.002 w
.60512 .26381 m .64081 .30032 L .65664 .31234 L p
1 g
F P
s
P
p
.002 w
.64081 .30032 m .60512 .26381 L .58824 .25809 L p
1 g
F P
s
P
p
.002 w
.42424 .24861 m .37748 .27636 L .38394 .27741 L p
1 g
F P
s
P
p
.002 w
.38394 .27741 m .42416 .25355 L .42424 .24861 L p
1 g
F P
s
P
p
.002 w
.64063 .56502 m .67255 .52507 L .67437 .51141 L p
1 g
F P
s
P
p
.002 w
.69388 .46325 m .67437 .51141 L .67255 .52507 L p
1 g
F P
s
P
p
.002 w
.67437 .51141 m .69388 .46325 L .69173 .44578 L p
1 g
F P
s
P
p
.002 w
.69385 .39441 m .69173 .44578 L .69388 .46325 L p
1 g
F P
s
P
p
.002 w
.69173 .44578 m .69385 .39441 L .68656 .3762 L p
1 g
F P
s
P
p
.002 w
.47623 .23562 m .42424 .24861 L .42416 .25355 L p
1 g
F P
s
P
p
.002 w
.55519 .61995 m .59918 .60097 L .59825 .59689 L p
1 g
F P
s
P
p
.002 w
.59825 .59689 m .54925 .61803 L .55519 .61995 L p
1 g
F P
s
P
p
.002 w
.64063 .56502 m .59825 .59689 L .59918 .60097 L p
1 g
F P
s
P
p
.002 w
.58824 .25809 m .54077 .23761 L .52674 .23878 L p
1 g
F P
s
P
p
.002 w
.47623 .23562 m .52674 .23878 L .54077 .23761 L p
1 g
F P
s
P
p
.002 w
.54077 .23761 m .58824 .25809 L .60512 .26381 L p
1 g
F P
s
P
p
.002 w
.50918 .62756 m .55519 .61995 L .54925 .61803 L p
1 g
F P
s
P
p
.002 w
.54925 .61803 m .49791 .62648 L .50918 .62756 L p
1 g
F P
s
P
p
.002 w
.31076 .47854 m .32851 .52764 L .32242 .50865 L p
1 g
F P
s
P
p
.002 w
.32242 .50865 m .30483 .45991 L .31076 .47854 L p
1 g
F P
s
P
p
.002 w
.66867 .32808 m .68656 .3762 L .69385 .39441 L p
1 g
F P
s
P
p
.002 w
.68656 .3762 m .66867 .32808 L .65664 .31234 L p
1 g
F P
s
P
p
.002 w
.59918 .60097 m .63724 .57238 L .64063 .56502 L p
1 g
F P
s
P
p
.002 w
.67255 .52507 m .64063 .56502 L .63724 .57238 L p
1 g
F P
s
P
p
.002 w
.40678 .60191 m .44883 .62115 L .43429 .61438 L p
1 g
F P
s
P
p
.002 w
.43429 .61438 m .38878 .59355 L .40678 .60191 L p
1 g
F P
s
P
p
.002 w
.37419 .27959 m .33454 .32296 L .34196 .31522 L p
1 g
F P
s
P
p
.002 w
.34196 .31522 m .37748 .27636 L .37419 .27959 L p
1 g
F P
s
P
p
.004 w
.69811 .45804 m
.7015 .45851 L
s
P
p
.004 w
.7015 .45851 m
.79401 .47137 L
s
P
p
.002 w
.30808 .40436 m .30483 .45991 L .30443 .44113 L p
1 g
F P
s
P
p
.002 w
.30443 .44113 m .30753 .38769 L .30808 .40436 L p
1 g
F P
s
P
p
.002 w
.46538 .6228 m .50918 .62756 L .49791 .62648 L p
1 g
F P
s
P
p
.002 w
.49791 .62648 m .44883 .62115 L .46538 .6228 L p
1 g
F P
s
P
p
.002 w
.35568 .55885 m .38878 .59355 L .37444 .58102 L p
1 g
F P
s
P
p
.002 w
.37444 .58102 m .33961 .54457 L .35568 .55885 L p
1 g
F P
s
P
p
.002 w
.65664 .31234 m .61968 .27442 L .60512 .26381 L p
1 g
F P
s
P
p
.002 w
.61968 .27442 m .65664 .31234 L .66867 .32808 L p
1 g
F P
s
P
p
.002 w
.54077 .23761 m .48453 .23406 L .47623 .23562 L p
1 g
F P
s
P
p
.002 w
.42424 .24861 m .47623 .23562 L .48453 .23406 L p
1 g
F P
s
P
p
.002 w
.33152 .33409 m .30753 .38769 L .31227 .37281 L p
1 g
F P
s
P
p
.002 w
.31227 .37281 m .33454 .32296 L .33152 .33409 L p
1 g
F P
s
P
p
.002 w
.67255 .52507 m .69068 .48046 L .69388 .46325 L p
1 g
F P
s
P
p
.002 w
.69388 .46325 m .69596 .41428 L .69385 .39441 L p
1 g
F P
s
P
p
.002 w
.69596 .41428 m .69388 .46325 L .69068 .48046 L p
1 g
F P
s
P
p
.002 w
.63724 .57238 m .66581 .53664 L .67255 .52507 L p
1 g
F P
s
P
p
.002 w
.69068 .48046 m .67255 .52507 L .66581 .53664 L p
1 g
F P
s
P
p
.002 w
.42646 .24858 m .37419 .27959 L .37748 .27636 L p
1 g
F P
s
P
p
.002 w
.37748 .27636 m .42424 .24861 L .42646 .24858 L p
1 g
F P
s
P
p
.002 w
.48453 .23406 m .42646 .24858 L .42424 .24861 L p
1 g
F P
s
P
p
.002 w
.60512 .26381 m .55422 .24182 L .54077 .23761 L p
1 g
F P
s
P
p
.002 w
.55422 .24182 m .60512 .26381 L .61968 .27442 L p
1 g
F P
s
P
p
.002 w
.32235 .49645 m .33961 .54457 L .32851 .52764 L p
1 g
F P
s
P
p
.002 w
.32851 .52764 m .31076 .47854 L .32235 .49645 L p
1 g
F P
s
P
p
.002 w
.48453 .23406 m .54077 .23761 L .55422 .24182 L p
1 g
F P
s
P
p
.002 w
.69385 .39441 m .67634 .34727 L .66867 .32808 L p
1 g
F P
s
P
p
.002 w
.67634 .34727 m .69385 .39441 L .69596 .41428 L p
1 g
F P
s
P
p
.002 w
.55983 .61661 m .59736 .60042 L .59918 .60097 L p
1 g
F P
s
P
p
.002 w
.59918 .60097 m .55519 .61995 L .55983 .61661 L p
1 g
F P
s
P
p
.002 w
.63724 .57238 m .59918 .60097 L .59736 .60042 L p
1 g
F P
s
P
p
.002 w
.52067 .62307 m .55983 .61661 L .55519 .61995 L p
1 g
F P
s
P
p
.002 w
.55519 .61995 m .50918 .62756 L .52067 .62307 L p
1 g
F P
s
P
p
.002 w
.59736 .60042 m .62981 .57603 L .63724 .57238 L p
1 g
F P
s
P
p
.002 w
.66581 .53664 m .63724 .57238 L .62981 .57603 L p
1 g
F P
s
P
p
.002 w
.4281 .60563 m .46538 .6228 L .44883 .62115 L p
1 g
F P
s
P
p
.002 w
.44883 .62115 m .40678 .60191 L .4281 .60563 L p
1 g
F P
s
P
p
.002 w
.31422 .42243 m .31076 .47854 L .30483 .45991 L p
1 g
F P
s
P
p
.002 w
.30483 .45991 m .30808 .40436 L .31422 .42243 L p
1 g
F P
s
P
p
.002 w
.37646 .56987 m .40678 .60191 L .38878 .59355 L p
1 g
F P
s
P
p
.002 w
.38878 .59355 m .35568 .55885 L .37646 .56987 L p
1 g
F P
s
P
p
.002 w
.37435 .2873 m .33152 .33409 L .33454 .32296 L p
1 g
F P
s
P
p
.002 w
.33454 .32296 m .37419 .27959 L .37435 .2873 L p
1 g
F P
s
P
p
.002 w
.63136 .28988 m .66867 .32808 L .67634 .34727 L p
1 g
F P
s
P
p
.002 w
.66867 .32808 m .63136 .28988 L .61968 .27442 L p
1 g
F P
s
P
p
.002 w
.48356 .61897 m .52067 .62307 L .50918 .62756 L p
1 g
F P
s
P
p
.002 w
.50918 .62756 m .46538 .6228 L .48356 .61897 L p
1 g
F P
s
P
p
.002 w
.33325 .34847 m .30808 .40436 L .30753 .38769 L p
1 g
F P
s
P
p
.002 w
.30753 .38769 m .33152 .33409 L .33325 .34847 L p
1 g
F P
s
P
p
.002 w
.66581 .53664 m .68194 .4969 L .69068 .48046 L p
1 g
F P
s
P
p
.002 w
.69255 .4353 m .69068 .48046 L .68194 .4969 L p
1 g
F P
s
P
p
.002 w
.69068 .48046 m .69255 .4353 L .69596 .41428 L p
1 g
F P
s
P
p
.002 w
.55422 .24182 m .49363 .23804 L .48453 .23406 L p
1 g
F P
s
P
p
.002 w
.42646 .24858 m .48453 .23406 L .49363 .23804 L p
1 g
F P
s
P
p
.002 w
.62981 .57603 m .65407 .54564 L .66581 .53664 L p
1 g
F P
s
P
p
.002 w
.68194 .4969 m .66581 .53664 L .65407 .54564 L p
1 g
F P
s
P
p
.002 w
.33952 .51302 m .35568 .55885 L .33961 .54457 L p
1 g
F P
s
P
p
.002 w
.33961 .54457 m .32235 .49645 L .33952 .51302 L p
1 g
F P
s
P
p
.002 w
.56666 .25161 m .61968 .27442 L .63136 .28988 L p
1 g
F P
s
P
p
.002 w
.61968 .27442 m .56666 .25161 L .55422 .24182 L p
1 g
F P
s
P
p
.002 w
.6792 .36951 m .69596 .41428 L .69255 .4353 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.68885 .45675 L
s
P
p
.002 w
.69596 .41428 m .6792 .36951 L .67634 .34727 L p
1 g
F P
s
P
p
.002 w
.43089 .25377 m .37435 .2873 L .37419 .27959 L p
1 g
F P
s
P
p
.002 w
.37419 .27959 m .42646 .24858 L .43089 .25377 L p
1 g
F P
s
P
p
.002 w
.49363 .23804 m .55422 .24182 L .56666 .25161 L p
1 g
F P
s
P
p
.002 w
.49363 .23804 m .43089 .25377 L .42646 .24858 L p
1 g
F P
s
P
p
.002 w
.56295 .60775 m .59266 .59495 L .59736 .60042 L p
1 g
F P
s
P
p
.002 w
.59736 .60042 m .55983 .61661 L .56295 .60775 L p
1 g
F P
s
P
p
.002 w
.62981 .57603 m .59736 .60042 L .59266 .59495 L p
1 g
F P
s
P
p
.002 w
.53202 .6128 m .56295 .60775 L .55983 .61661 L p
1 g
F P
s
P
p
.002 w
.55983 .61661 m .52067 .62307 L .53202 .6128 L p
1 g
F P
s
P
p
.002 w
.45223 .60435 m .48356 .61897 L .46538 .6228 L p
1 g
F P
s
P
p
.002 w
.46538 .6228 m .4281 .60563 L .45223 .60435 L p
1 g
F P
s
P
p
.002 w
.32606 .44137 m .32235 .49645 L .31076 .47854 L p
1 g
F P
s
P
p
.002 w
.31076 .47854 m .31422 .42243 L .32606 .44137 L p
1 g
F P
s
P
p
.002 w
.40151 .57714 m .4281 .60563 L .40678 .60191 L p
1 g
F P
s
P
p
.002 w
.40678 .60191 m .37646 .56987 L .40151 .57714 L p
1 g
F P
s
P
p
.002 w
.59266 .59495 m .61831 .57564 L .62981 .57603 L p
1 g
F P
s
P
p
.002 w
.65407 .54564 m .62981 .57603 L .61831 .57564 L p
1 g
F P
s
P
p
.002 w
.63963 .30998 m .67634 .34727 L .6792 .36951 L p
1 g
F P
s
P
p
.002 w
.67634 .34727 m .63963 .30998 L .63136 .28988 L p
1 g
F P
s
P
p
.002 w
.37821 .29954 m .33325 .34847 L .33152 .33409 L p
1 g
F P
s
P
p
.002 w
.33152 .33409 m .37435 .2873 L .37821 .29954 L p
1 g
F P
s
P
p
.002 w
.33998 .36583 m .31422 .42243 L .30808 .40436 L p
1 g
F P
s
P
p
.002 w
.30808 .40436 m .33325 .34847 L .33998 .36583 L p
1 g
F P
s
P
p
.002 w
.65407 .54564 m .66761 .512 L .68194 .4969 L p
1 g
F P
s
P
p
.002 w
.68344 .45689 m .68194 .4969 L .66761 .512 L p
1 g
F P
s
P
p
.002 w
.68194 .4969 m .68344 .45689 L .69255 .4353 L p
1 g
F P
s
P
p
.004 w
.68953 .45685 m
.69096 .45705 L
s
P
p
.004 w
.69096 .45705 m
.69811 .45804 L
s
P
p
.002 w
.50287 .60948 m .53202 .6128 L .52067 .62307 L p
1 g
F P
s
P
p
.002 w
.52067 .62307 m .48356 .61897 L .50287 .60948 L p
1 g
F P
s
P
p
.002 w
.36197 .52765 m .37646 .56987 L .35568 .55885 L p
1 g
F P
s
P
p
.002 w
.35568 .55885 m .33952 .51302 L .36197 .52765 L p
1 g
F P
s
P
p
.002 w
.67691 .39425 m .69255 .4353 L .68344 .45689 L p
1 g
F P
s
P
p
.002 w
.69255 .4353 m .67691 .39425 L .6792 .36951 L p
1 g
F P
s
P
p
.002 w
.56666 .25161 m .50329 .2478 L .49363 .23804 L p
1 g
F P
s
P
p
.002 w
.43089 .25377 m .49363 .23804 L .50329 .2478 L p
1 g
F P
s
P
p
.002 w
.57762 .267 m .63136 .28988 L .63963 .30998 L p
1 g
F P
s
P
p
.002 w
.63136 .28988 m .57762 .267 L .56666 .25161 L p
1 g
F P
s
P
p
.002 w
.61831 .57564 m .63738 .55164 L .65407 .54564 L p
1 g
F P
s
P
p
.002 w
.66761 .512 m .65407 .54564 L .63738 .55164 L p
1 g
F P
s
P
p
.002 w
.50329 .2478 m .56666 .25161 L .57762 .267 L p
1 g
F P
s
P
p
.002 w
.43754 .26438 m .37821 .29954 L .37435 .2873 L p
1 g
F P
s
P
p
.002 w
.37435 .2873 m .43089 .25377 L .43754 .26438 L p
1 g
F P
s
P
p
.002 w
.50329 .2478 m .43754 .26438 L .43089 .25377 L p
1 g
F P
s
P
p
.002 w
.34347 .4606 m .33952 .51302 L .32235 .49645 L p
1 g
F P
s
P
p
.002 w
.32235 .49645 m .32606 .44137 L .34347 .4606 L p
1 g
F P
s
P
p
.002 w
.43017 .58025 m .45223 .60435 L .4281 .60563 L p
1 g
F P
s
P
p
.002 w
.4281 .60563 m .40151 .57714 L .43017 .58025 L p
1 g
F P
s
P
p
.002 w
.64405 .33429 m .6792 .36951 L .67691 .39425 L p
1 g
F P
s
P
p
.002 w
.6792 .36951 m .64405 .33429 L .63963 .30998 L p
1 g
F P
s
P
p
.002 w
.47849 .59788 m .50287 .60948 L .48356 .61897 L p
1 g
F P
s
P
p
.002 w
.48356 .61897 m .45223 .60435 L .47849 .59788 L p
1 g
F P
s
P
p
.002 w
.56434 .59331 m .58502 .58441 L .59266 .59495 L p
1 g
F P
s
P
p
.002 w
.59266 .59495 m .56295 .60775 L .56434 .59331 L p
1 g
F P
s
P
p
.004 w
.58678 .59722 m
.59783 .61844 L
s
P
p
.002 w
.61831 .57564 m .59266 .59495 L .58502 .58441 L p
1 g
F P
s
P
p
.002 w
.54286 .59676 m .56434 .59331 L .56295 .60775 L p
1 g
F P
s
P
p
.002 w
.56295 .60775 m .53202 .6128 L .54286 .59676 L p
1 g
F P
s
P
p
.002 w
.58502 .58441 m .60285 .57095 L .61831 .57564 L p
1 g
F P
s
P
p
.002 w
.63738 .55164 m .61831 .57564 L .60285 .57095 L p
1 g
F P
s
P
p
.002 w
.63738 .55164 m .64787 .52522 L .66761 .512 L p
1 g
F P
s
P
p
.002 w
.66865 .47836 m .66761 .512 L .64787 .52522 L p
1 g
F P
s
P
p
.002 w
.66761 .512 m .66865 .47836 L .68344 .45689 L p
1 g
F P
s
P
p
.002 w
.38915 .53975 m .40151 .57714 L .37646 .56987 L p
1 g
F P
s
P
p
.002 w
.37646 .56987 m .36197 .52765 L .38915 .53975 L p
1 g
F P
s
P
p
.002 w
.35174 .38576 m .32606 .44137 L .31422 .42243 L p
1 g
F P
s
P
p
.002 w
.31422 .42243 m .33998 .36583 L .35174 .38576 L p
1 g
F P
s
P
p
.002 w
.38586 .31617 m .33998 .36583 L .33325 .34847 L p
1 g
F P
s
P
p
.002 w
.33325 .34847 m .37821 .29954 L .38586 .31617 L p
1 g
F P
s
P
p
.002 w
.66932 .42078 m .68344 .45689 L .66865 .47836 L p
1 g
F P
s
P
p
.002 w
.68344 .45689 m .66932 .42078 L .67691 .39425 L p
1 g
F P
s
P
p
.002 w
.52274 .59435 m .54286 .59676 L .53202 .6128 L p
1 g
F P
s
P
p
.002 w
.53202 .6128 m .50287 .60948 L .52274 .59435 L p
1 g
F P
s
P
p
.002 w
.58666 .28779 m .63963 .30998 L .64405 .33429 L p
1 g
F P
s
P
p
.002 w
.63963 .30998 m .58666 .28779 L .57762 .267 L p
1 g
F P
s
P
p
.002 w
.60285 .57095 m .61601 .55427 L .63738 .55164 L p
1 g
F P
s
P
p
.002 w
.64787 .52522 m .63738 .55164 L .61601 .55427 L p
1 g
F P
s
P
p
.002 w
.57762 .267 m .51324 .26337 L .50329 .2478 L p
1 g
F P
s
P
p
.002 w
.43754 .26438 m .50329 .2478 L .51324 .26337 L p
1 g
F P
s
P
p
.002 w
.51324 .26337 m .57762 .267 L .58666 .28779 L p
1 g
F P
s
P
p
.002 w
.6443 .36219 m .67691 .39425 L .66932 .42078 L p
1 g
F P
s
P
p
.002 w
.67691 .39425 m .6443 .36219 L .64405 .33429 L p
1 g
F P
s
P
p
.002 w
.3661 .47945 m .36197 .52765 L .33952 .51302 L p
1 g
F P
s
P
p
.002 w
.33952 .51302 m .34347 .4606 L .3661 .47945 L p
1 g
F P
s
P
p
.002 w
.46159 .57893 m .47849 .59788 L .45223 .60435 L p
1 g
F P
s
P
p
.002 w
.45223 .60435 m .43017 .58025 L .46159 .57893 L p
1 g
F P
s
P
p
.002 w
.50608 .58622 m .52274 .59435 L .50287 .60948 L p
1 g
F P
s
P
p
.002 w
.50287 .60948 m .47849 .59788 L .50608 .58622 L p
1 g
F P
s
P
p
.002 w
.44632 .28038 m .38586 .31617 L .37821 .29954 L p
1 g
F P
s
P
p
.002 w
.37821 .29954 m .43754 .26438 L .44632 .28038 L p
1 g
F P
s
P
p
.002 w
.51324 .26337 m .44632 .28038 L .43754 .26438 L p
1 g
F P
s
P
p
.002 w
.42027 .5488 m .43017 .58025 L .40151 .57714 L p
1 g
F P
s
P
p
.002 w
.40151 .57714 m .38915 .53975 L .42027 .5488 L p
1 g
F P
s
P
p
.002 w
.56386 .57342 m .57454 .56883 L .58502 .58441 L p
1 g
F P
s
P
p
.002 w
.58502 .58441 m .56434 .59331 L .56386 .57342 L p
1 g
F P
s
P
p
.002 w
.60285 .57095 m .58502 .58441 L .57454 .56883 L p
1 g
F P
s
P
p
.002 w
.61601 .55427 m .62311 .53601 L .64787 .52522 L p
1 g
F P
s
P
p
.002 w
.64842 .499 m .64787 .52522 L .62311 .53601 L p
1 g
F P
s
P
p
.002 w
.64787 .52522 m .64842 .499 L .66865 .47836 L p
1 g
F P
s
P
p
.002 w
.65646 .44826 m .66865 .47836 L .64842 .499 L p
1 g
F P
s
P
p
.002 w
.66865 .47836 m .65646 .44826 L .66932 .42078 L p
1 g
F P
s
P
p
.002 w
.55279 .57516 m .56386 .57342 L .56434 .59331 L p
1 g
F P
s
P
p
.002 w
.56434 .59331 m .54286 .59676 L .55279 .57516 L p
1 g
F P
s
P
p
.002 w
.36839 .40766 m .34347 .4606 L .32606 .44137 L p
1 g
F P
s
P
p
.002 w
.32606 .44137 m .35174 .38576 L .36839 .40766 L p
1 g
F P
s
P
p
.002 w
.57454 .56883 m .58373 .56188 L .60285 .57095 L p
1 g
F P
s
P
p
.002 w
.61601 .55427 m .60285 .57095 L .58373 .56188 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.59338 .31355 m .64405 .33429 L .6443 .36219 L p
1 g
F P
s
P
p
.002 w
.64405 .33429 m .59338 .31355 L .58666 .28779 L p
1 g
F P
s
P
p
.002 w
.39724 .33687 m .35174 .38576 L .33998 .36583 L p
1 g
F P
s
P
p
.002 w
.33998 .36583 m .38586 .31617 L .39724 .33687 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54249 .57385 m .55279 .57516 L .54286 .59676 L p
1 g
F P
s
P
p
.002 w
.54286 .59676 m .52274 .59435 L .54249 .57385 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.58373 .56188 m .59045 .55327 L .61601 .55427 L p
1 g
F P
s
P
p
.002 w
.62311 .53601 m .61601 .55427 L .59045 .55327 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.64019 .39284 m .66932 .42078 L .65646 .44826 L p
1 g
F P
s
P
p
.002 w
.66932 .42078 m .64019 .39284 L .6443 .36219 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.39333 .49721 m .38915 .53975 L .36197 .52765 L p
1 g
F P
s
P
p
.002 w
.36197 .52765 m .3661 .47945 L .39333 .49721 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50608 .58622 m .47849 .59788 L p
.48977 .58065 L 1 g
F P
s
P
p
.002 w
.48907 .58046 m .48921 .57862 L p
.47875 .57776 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.47849 .59788 m .46159 .57893 L .4745 .57665 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57459 L p
1 g
F P
s
P
p
.46159 .57893 m .46739 .57429 L .4683 .57459 L 1 g
F
P
p
.002 w
.4745 .57665 m .47224 .57705 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.47224 .57705 m .46159 .57893 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.4683 .57459 m .46872 .57265 L p
.45881 .56869 L 1 g
F P
s
P
p
.48921 .57862 m .4683 .57459 L .47097 .57548 L 1 g
F
P
p
.48921 .57862 m .46821 .575 L .47875 .57776 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.46739 .57429 m .49004 .55623 L .4745 .57665 L 1 g
F
P
p
.002 w
.46159 .57893 m .43017 .58025 L p
.44823 .56089 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.44823 .56089 m .45088 .56285 L .46159 .57893 L 1 g
F
P
p
.002 w
.45848 .56849 m .46009 .5739 L p
.45088 .56285 L 1 g
F P
s
P
p
.002 w
.46009 .5739 m .46159 .57893 L p
.45088 .56285 L 1 g
F P
s
P
p
.002 w
.45088 .56285 m .45146 .56129 L p
.44463 .55536 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45088 .56285 L p
1 g
F P
s
P
p
.002 w
.46159 .57893 m .45848 .56849 L p
.46758 .57415 L 1 g
F P
s
P
p
.46872 .57265 m .45088 .56285 L .4587 .56865 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45429 .55438 m .49004 .55623 L p
.46758 .57415 L 1 g
F P
s
P
p
.002 w
.45848 .56849 m .45429 .55438 L p
.46758 .57415 L 1 g
F P
s
P
p
.4587 .56865 m .45848 .56849 L .45002 .56518 L 1 g
F
P
p
.002 w
.45088 .56285 m .45061 .56359 L p
.45848 .56849 L 1 g
F P
s
P
p
.002 w
.45061 .56359 m .45002 .56518 L p
.45848 .56849 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43854 .547 L p
1 g
F P
s
P
p
.45146 .56129 m .43854 .547 L .44069 .5502 L 1 g
F
P
p
.42027 .5488 m .43424 .54061 L .43854 .547 L 1 g
F
P
p
.002 w
.44216 .55239 m .44009 .55205 L p
.43854 .547 L 1 g
F P
s
P
p
.002 w
.44009 .55205 m .42027 .5488 L p
.43854 .547 L 1 g
F P
s
P
p
.002 w
.43854 .547 m .43925 .54566 L p
.43636 .53994 L 1 g
F P
s
P
p
.45146 .56129 m .44069 .5502 L .44463 .55536 L 1 g
F
P
p
.44069 .5502 m .4382 .54764 L .44216 .55239 L 1 g
F
P
p
.44069 .5502 m .44216 .55239 L .44463 .55536 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43278 .52833 L p
1 g
F P
s
P
p
.43424 .54061 m .43621 .53946 L .43854 .547 L 1 g
F
P
p
.43925 .54566 m .43278 .52833 L .43636 .53994 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42027 .5488 m .42427 .51321 L .43325 .51684 L p
1 g
F P
s
P
p
.002 w
.43278 .52833 m .43346 .52734 L p
.43317 .51888 L 1 g
F P
s
P
p
.42027 .5488 m .43325 .51684 L .43223 .54179 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43405 .50922 L p
1 g
F P
s
P
p
.002 w
.43325 .51684 m .42427 .51321 L p
.43392 .5104 L 1 g
F P
s
P
p
.43346 .52734 m .43405 .50922 L .43313 .51795 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.44236 .47754 m .44751 .4813 L p
.44274 .49119 L 1 g
F P
s
P
p
.43443 .50842 m .43757 .49619 L .44274 .49119 L 1 g
F
P
p
.43757 .49619 m .44236 .47754 L .44274 .49119 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44274 .49119 m .44339 .4905 L p
.45073 .48347 L 1 g
F P
s
P
p
.45752 .47686 m .49587 .47514 L .45063 .48357 L 1 g
F
P
p
.45073 .48347 m .45082 .48338 L .45063 .48357 L 1 g
F
P
p
.45073 .48347 m .45063 .48357 L .44274 .49119 L 1 g
F
P
p
.002 w
.49587 .47514 m .47216 .49928 L .45063 .48357 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.43405 .50922 m .43485 .50826 L p
.43753 .50199 L 1 g
F P
s
P
p
.43443 .50842 m .44274 .49119 L .47216 .49928 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45779 .47659 L p
1 g
F P
s
P
p
.002 w
.45779 .47659 m .45738 .47704 L p
.45318 .48108 L 1 g
F P
s
P
p
.44339 .4905 m .45779 .47659 L .45318 .48108 L 1 g
F
P
p
.002 w
.44236 .47754 m .47279 .44618 L .47988 .45508 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45752 .47686 m .45779 .47659 L .49587 .47514 L 1 g
F
P
p
.45779 .47659 m .47762 .46707 L .49587 .47514 L 1 g
F
P
p
.002 w
.47762 .46707 m .47786 .46667 L p
.48941 .46549 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49587 .47514 m .48832 .46567 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.51199 .46571 m .52244 .46717 L .53952 .49048 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54228 .47666 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53952 .49048 m .53203 .47183 L p
.54228 .47666 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56611 .5094 L p
1 g
F P
s
P
p
.002 w
.56243 .50169 m .56211 .48413 L p
.56454 .4943 L 1 g
F P
s
P
p
.56454 .4943 m .57018 .51794 L .56611 .5094 L 1 g
F
P
p
.56454 .4943 m .56611 .5094 L .56243 .50169 L 1 g
F
P
p
.002 w
.56611 .5094 m .56515 .50826 L p
.56714 .5212 L 1 g
F P
s
P
p
.002 w
.57377 .51792 m .56769 .53298 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.567 .51796 m .57072 .51794 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.57072 .51794 m .57377 .51792 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.56749 .52873 m .56654 .52734 L p
.56441 .53903 L 1 g
F P
s
P
p
.56714 .5212 m .567 .51796 L .56611 .5094 L 1 g
F
P
p
.002 w
.55279 .57516 m .54249 .57385 L .55201 .5611 L p
1 g
F P
s
P
p
.002 w
.55201 .5611 m .56142 .5485 L .559 .55596 L p
1 g
F P
s
P
p
.002 w
.559 .55596 m .55279 .57516 L p
.55201 .5611 L 1 g
F P
s
P
p
.002 w
.54249 .57385 m .52274 .59435 L p
.53169 .57477 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.53169 .57477 m .5317 .57475 L .53174 .57474 L 1 g
F
P
p
.002 w
.53772 .57145 m .54249 .57385 L p
.53169 .57477 L 1 g
F P
s
P
p
.002 w
.53174 .57474 m .53128 .57265 L p
.52091 .57797 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52274 .59435 m .50608 .58622 L .51901 .57854 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58075 L p
1 g
F P
s
P
p
.002 w
.51901 .57854 m .5157 .5805 L p
.51142 .58062 L 1 g
F P
s
P
p
.002 w
.5157 .5805 m .50608 .58622 L p
.51132 .58073 L 1 g
F P
s
P
p
.51132 .58073 m .51142 .58062 L .5157 .5805 L 1 g
F
P
p
.48977 .58065 m .48986 .58051 L .50462 .58453 L 1 g
F
P
p
.002 w
.50176 .58123 m .50462 .58453 L p
.48986 .58051 L 1 g
F P
s
P
p
.002 w
.51095 .58075 m .51079 .57862 L p
.49632 .58151 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58046 L p
1 g
F P
s
P
p
.48977 .58065 m .48907 .58046 L .48986 .58051 L 1 g
F
P
p
.47849 .59788 m .4745 .57665 L .48977 .58065 L 1 g
F
P
p
.002 w
.50462 .58453 m .50608 .58622 L p
.48977 .58065 L 1 g
F P
s
P
p
.002 w
.48907 .58046 m .48889 .583 L p
.49867 .58104 L 1 g
F P
s
P
p
.51079 .57862 m .48907 .58046 L .49867 .58104 L 1 g
F
P
p
.002 w
.4745 .57665 m .49472 .57308 L p
.48986 .58051 L 1 g
F P
s
P
p
.48907 .58046 m .4745 .57665 L .48986 .58051 L 1 g
F
P
p
.002 w
.49472 .57308 m .50176 .58123 L p
.48986 .58051 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58075 L .51239 .58035 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.49472 .57308 m .5284 .56284 L p
.51142 .58062 L 1 g
F P
s
P
p
.002 w
.50608 .58622 m .50319 .58288 L p
.51142 .58062 L 1 g
F P
s
P
p
.002 w
.50319 .58288 m .49472 .57308 L p
.51142 .58062 L 1 g
F P
s
P
p
.52274 .59435 m .51901 .57854 L .5317 .57475 L 1 g
F
P
p
.002 w
.51096 .58094 m .51111 .583 L p
.52072 .57807 L 1 g
F P
s
P
p
.52091 .57797 m .51901 .57854 L .52072 .57807 L 1 g
F
P
p
.51901 .57854 m .51096 .58094 L .52072 .57807 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51102 .58179 L p
1 g
F P
s
P
p
.002 w
.51102 .58179 m .51095 .58075 L p
.50458 .5814 L 1 g
F P
s
P
p
.50458 .5814 m .48889 .583 L .51102 .58179 L 1 g
F
P
p
.49632 .58151 m .48889 .583 L .51095 .58075 L 1 g
F
P
p
.002 w
.51095 .58075 m .51096 .58094 L p
.51239 .58035 L 1 g
F P
s
P
p
.53128 .57265 m .51096 .58094 L .52091 .57797 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.5284 .56284 m .53405 .5696 L .51901 .57854 L p
1 g
F P
s
P
p
.51142 .58062 m .5284 .56284 L .51901 .57854 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53193 .57564 L p
1 g
F P
s
P
p
.002 w
.55201 .5611 m .54249 .57385 L .541 .5731 L p
1 g
F P
s
P
p
.002 w
.541 .5731 m .53772 .57145 L p
.54922 .56312 L 1 g
F P
s
P
p
.541 .5731 m .54922 .56312 L .55201 .5611 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54922 .56312 L p
1 g
F P
s
P
p
.56075 .54566 m .54922 .56312 L .55497 .55615 L 1 g
F
P
p
.54854 .56129 m .53193 .57564 L .53839 .57096 L 1 g
F
P
p
.002 w
.54923 .56315 m .54854 .56129 L p
.53771 .57161 L 1 g
F P
s
P
p
.002 w
.5833 .52099 m .56166 .5482 L p
.56179 .54775 L 1 g
F P
s
P
p
.56075 .54566 m .55586 .55506 L .56181 .54768 L 1 g
F
P
p
.002 w
.56182 .54767 m .56075 .54566 L p
.56181 .54768 L 1 g
F P
s
P
p
.002 w
.57997 .51991 m .5833 .52099 L p
.56179 .54775 L 1 g
F P
s
P
p
.56182 .54767 m .56179 .54775 L .56165 .54792 L 1 g
F
P
p
.57997 .51991 m .56179 .54775 L .56182 .54767 L 1 g
F
P
p
.56169 .54783 m .56165 .54792 L .56182 .54767 L 1 g
F
P
p
.55586 .55506 m .56165 .54792 L .56169 .54783 L 1 g
F
P
p
.55586 .55506 m .561 .54882 L .56165 .54792 L 1 g
F
P
p
.002 w
.56142 .5485 m .55201 .5611 L p
.55016 .56198 L 1 g
F P
s
P
p
.002 w
.561 .54882 m .56142 .5485 L p
.55016 .56198 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .55182 .56283 L p
.56075 .54566 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53405 .5696 m .5284 .56284 L .56118 .5486 L p
1 g
F P
s
P
p
.002 w
.56118 .5486 m .56142 .5485 L .561 .54882 L p
1 g
F P
s
P
p
.002 w
.561 .54882 m .53405 .5696 L p
.56118 .5486 L 1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5284 .56284 m .52619 .55425 L .56124 .54853 L p
1 g
F P
s
P
p
.002 w
.56124 .54853 m .56142 .5485 L .56118 .5486 L p
1 g
F P
s
P
p
.002 w
.56118 .5486 m .5284 .56284 L p
.56124 .54853 L 1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.52619 .55425 m .52771 .54475 L .56127 .54848 L p
1 g
F P
s
P
p
.002 w
.56127 .54848 m .56142 .5485 L .56124 .54853 L p
1 g
F P
s
P
p
.002 w
.56124 .54853 m .52619 .55425 L p
.56127 .54848 L 1 g
F P
s
P
p
.56121 .54856 m .56129 .54847 L .5613 .54845 L 1 g
F
P
p
.56118 .5486 m .5612 .54857 L .56121 .54856 L 1 g
F
P
p
.5612 .54857 m .56129 .54847 L .56121 .54856 L 1 g
F
P
p
.561 .54882 m .56112 .54867 L .56118 .5486 L 1 g
F
P
p
.56112 .54867 m .56129 .54847 L .56118 .5486 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.57377 .51792 m .57997 .51991 L p
.56182 .54767 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56182 .54767 L p
1 g
F P
s
P
p
.002 w
.56165 .54792 m .562 .54706 L p
.56182 .54767 L 1 g
F P
s
P
p
.002 w
.562 .54706 m .57377 .51792 L p
.56182 .54767 L 1 g
F P
s
P
p
.002 w
.56182 .54767 m .56182 .54767 L p
.56182 .54766 L 1 g
F P
s
P
p
.56654 .52734 m .56182 .54767 L .56182 .54766 L 1 g
F
P
p
.002 w
.56769 .53298 m .562 .54706 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.59045 .55327 m .58373 .56188 L .56142 .5485 L closepath p
1 g
F P
s
P
p
.002 w
.594 .5439 m .59045 .55327 L .56142 .5485 L closepath p
1 g
F P
s
P
p
.002 w
.59395 .53476 m .594 .5439 L .56142 .5485 L closepath p
1 g
F P
s
P
p
.002 w
.59027 .52683 m .59395 .53476 L .56159 .54843 L p
1 g
F P
s
P
p
.002 w
.56159 .54843 m .56142 .5485 L .56161 .54836 L p
1 g
F P
s
P
p
.002 w
.56161 .54836 m .59027 .52683 L p
.56159 .54843 L 1 g
F P
s
P
p
.002 w
.56182 .54767 m .56182 .54768 L p
.56441 .53903 L 1 g
F P
s
P
p
.002 w
.5833 .52099 m .59027 .52683 L .56161 .54836 L p
1 g
F P
s
P
p
.002 w
.56161 .54836 m .56142 .5485 L .56166 .5482 L p
1 g
F P
s
P
p
.002 w
.56166 .5482 m .5833 .52099 L p
.56161 .54836 L 1 g
F P
s
P
p
.56439 .53913 m .5643 .53962 L .56738 .5292 L 1 g
F
P
p
.5643 .53962 m .56257 .5491 L .56691 .53113 L 1 g
F
P
p
.5643 .53962 m .56691 .53113 L .56738 .5292 L 1 g
F
P
p
.002 w
.56182 .54768 m .56257 .5491 L p
.56417 .54035 L 1 g
F P
s
P
p
.56441 .53903 m .56182 .54768 L .56417 .54035 L 1 g
F
P
p
.56654 .52734 m .56182 .54767 L .56441 .53903 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56822 .52979 L p
1 g
F P
s
P
p
.56515 .50826 m .56822 .52979 L .56772 .52493 L 1 g
F
P
p
.55661 .4905 m .56611 .5094 L .56243 .50169 L 1 g
F
P
p
.55661 .4905 m .56243 .50169 L .56205 .50091 L 1 g
F
P
p
.002 w
.56233 .49611 m .56243 .50169 L p
.55746 .4914 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55478 .48881 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.53952 .49048 m .55268 .48678 L p
.56273 .51799 L 1 g
F P
s
P
p
.55268 .48678 m .55582 .48982 L .56273 .51799 L 1 g
F
P
p
.54174 .47608 m .55478 .48881 L .55112 .48527 L 1 g
F
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56243 .50169 m .56273 .51799 L p
.55582 .48982 L 1 g
F P
s
P
p
.55746 .4914 m .56243 .50169 L .55582 .48982 L 1 g
F
P
p
.55478 .48881 m .55777 .49173 L .55268 .48678 L 1 g
F
P
p
.55478 .48881 m .55268 .48678 L .55112 .48527 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55492 .48615 m .55746 .4914 L .55582 .48982 L 1 g
F
P
p
.002 w
.55268 .48678 m .55492 .48615 L p
.55582 .48982 L 1 g
F P
s
P
p
.002 w
.55268 .48678 m .53952 .49048 L p
.54228 .47666 L 1 g
F P
s
P
p
.002 w
.55777 .49173 m .55834 .49233 L p
.55183 .48596 L 1 g
F P
s
P
p
.55112 .48527 m .55268 .48678 L .55183 .48596 L 1 g
F
P
p
.55268 .48678 m .55777 .49173 L .55183 .48596 L 1 g
F
P
p
.002 w
.55746 .4914 m .55777 .49173 L p
.55478 .48881 L 1 g
F P
s
P
p
.002 w
.55492 .48615 m .56211 .48413 L .56233 .49611 L p
1 g
F P
s
P
p
.55492 .48615 m .56233 .49611 L .55746 .4914 L 1 g
F
P
p
.56205 .50091 m .56243 .50169 L .5621 .501 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56273 .51799 m .56243 .50169 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.57018 .51794 m .567 .51796 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.567 .51796 m .56273 .51799 L p
.56611 .5094 L 1 g
F P
s
P
p
.002 w
.56822 .52979 m .56854 .53025 L p
.56772 .52493 L 1 g
F P
s
P
p
.567 .51796 m .56749 .52873 L .56165 .54792 L 1 g
F
P
p
.002 w
.562 .54706 m .56165 .54792 L p
.56749 .52873 L 1 g
F P
s
P
p
.002 w
.55139 .52122 m .56273 .51799 L .56143 .54826 L p
1 g
F P
s
P
p
.002 w
.56143 .54826 m .56142 .5485 L .56137 .54835 L p
1 g
F P
s
P
p
.002 w
.56137 .54835 m .55139 .52122 L p
.56143 .54826 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54104 .52725 m .55139 .52122 L .56137 .54835 L p
1 g
F P
s
P
p
.002 w
.56137 .54835 m .56142 .5485 L .56133 .54841 L p
1 g
F P
s
P
p
.002 w
.56133 .54841 m .54104 .52725 L p
.56137 .54835 L 1 g
F P
s
P
p
.002 w
.53284 .5354 m .54104 .52725 L .56133 .54841 L p
1 g
F P
s
P
p
.002 w
.56133 .54841 m .56142 .5485 L .5613 .54844 L p
1 g
F P
s
P
p
.561 .54882 m .56124 .54853 L .56165 .54792 L 1 g
F
P
p
.56124 .54853 m .56126 .5485 L .56127 .54848 L 1 g
F
P
p
.56124 .54853 m .56127 .54848 L .56165 .54792 L 1 g
F
P
p
.002 w
.52771 .54475 m .53284 .5354 L .5613 .54844 L p
1 g
F P
s
P
p
.002 w
.5613 .54844 m .56142 .5485 L .56127 .54848 L p
1 g
F P
s
P
p
.002 w
.56127 .54848 m .52771 .54475 L p
.5613 .54844 L 1 g
F P
s
P
p
.002 w
.5613 .54844 m .53284 .5354 L p
.56133 .54841 L 1 g
F P
s
P
p
.56126 .5485 m .56128 .54848 L .5613 .54844 L 1 g
F
P
p
.56126 .5485 m .5613 .54844 L .56165 .54792 L 1 g
F
P
p
.56128 .54848 m .56129 .54847 L .56134 .54839 L 1 g
F
P
p
.56128 .54848 m .56134 .54839 L .56165 .54792 L 1 g
F
P
p
.56129 .54847 m .5613 .54845 L .56143 .54826 L 1 g
F
P
p
.56129 .54847 m .56143 .54826 L .56165 .54792 L 1 g
F
P
p
.56441 .53903 m .56439 .53913 L .56749 .52873 L 1 g
F
P
p
.56439 .53913 m .56738 .5292 L .56749 .52873 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56751 .52875 L p
1 g
F P
s
P
p
.002 w
.56751 .52875 m .56749 .52873 L p
.56738 .5292 L 1 g
F P
s
P
p
.56738 .5292 m .56257 .5491 L .56751 .52875 L 1 g
F
P
p
.002 w
.56142 .5485 m .56165 .54792 L p
.56179 .54775 L 1 g
F P
s
P
p
.002 w
.56166 .5482 m .56142 .5485 L p
.56179 .54775 L 1 g
F P
s
P
p
.002 w
.56182 .54767 m .56182 .54767 L p
.56181 .54768 L 1 g
F P
s
P
p
.55586 .55506 m .55182 .56283 L .56129 .54847 L 1 g
F
P
p
.002 w
.53405 .5696 m .561 .54882 L p
.55016 .56198 L 1 g
F P
s
P
p
.002 w
.53772 .57145 m .53405 .5696 L p
.55201 .5611 L 1 g
F P
s
P
p
.002 w
.54922 .56312 m .54998 .56518 L p
.55497 .55615 L 1 g
F P
s
P
p
.002 w
.53193 .57564 m .5322 .57686 L p
.53839 .57096 L 1 g
F P
s
P
p
.002 w
.51901 .57854 m .53405 .5696 L p
.5317 .57475 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53174 .57474 L p
1 g
F P
s
P
p
.52091 .57797 m .51111 .583 L .53174 .57474 L 1 g
F
P
p
.002 w
.53405 .5696 m .53772 .57145 L p
.53174 .57474 L 1 g
F P
s
P
p
.5317 .57475 m .53405 .5696 L .53174 .57474 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54984 .56478 L p
1 g
F P
s
P
p
.002 w
.54984 .56478 m .54923 .56315 L p
.54152 .56936 L 1 g
F P
s
P
p
.54152 .56936 m .5322 .57686 L .54984 .56478 L 1 g
F
P
p
.53771 .57161 m .5322 .57686 L .54923 .56315 L 1 g
F
P
p
.002 w
.56165 .54792 m .56142 .5485 L p
.56148 .54819 L 1 g
F P
s
P
p
.567 .51796 m .56165 .54792 L .56148 .54819 L 1 g
F
P
p
.002 w
.56142 .5485 m .56273 .51799 L .567 .51796 L p
1 g
F P
s
P
p
.002 w
.57454 .56883 m .56386 .57342 L .56142 .5485 L closepath p
1 g
F P
s
P
p
.002 w
.58373 .56188 m .57454 .56883 L .56142 .5485 L closepath p
1 g
F P
s
P
p
.002 w
.56386 .57342 m .55279 .57516 L .56142 .5485 L closepath p
1 g
F P
s
P
p
.002 w
.55182 .56283 m .56257 .5491 L .56182 .54767 L p
1 g
F P
s
P
p
.56714 .5212 m .56772 .52493 L .567 .51796 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .5094 L p
1 g
F P
s
P
p
.56772 .52493 m .56854 .53025 L .56611 .5094 L 1 g
F
P
p
.002 w
.56611 .5094 m .56713 .51061 L p
.5621 .501 L 1 g
F P
s
P
p
.002 w
.57377 .51792 m .57018 .51794 L p
.56211 .48413 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54228 .47666 L p
1 g
F P
s
P
p
.002 w
.54228 .47666 m .54174 .47608 L p
.55112 .48527 L 1 g
F P
s
P
p
.55112 .48527 m .55834 .49233 L .54228 .47666 L 1 g
F
P
p
.52623 .45738 m .55959 .48484 L .54228 .47666 L 1 g
F
P
p
.52214 .46667 m .54228 .47666 L .53792 .47461 L 1 g
F
P
p
.52214 .46667 m .5425 .47691 L .5332 .47239 L 1 g
F
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53203 .47183 m .53952 .49048 L p
.52244 .46717 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46717 L p
1 g
F P
s
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.5332 .47239 L 1 g
F P
s
P
p
.5332 .47239 m .54302 .47747 L .52244 .46717 L 1 g
F
P
p
.002 w
.52623 .45738 m .53062 .46831 L p
.52244 .46717 L 1 g
F P
s
P
p
.5 .4634 m .52244 .46717 L .51726 .46645 L 1 g
F
P
p
.5 .4634 m .52257 .46738 L .51218 .46574 L 1 g
F
P
p
.002 w
.49587 .47514 m .51199 .46571 L p
.53952 .49048 L 1 g
F P
s
P
p
.002 w
.51199 .46571 m .49587 .47514 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .4634 L p
.51218 .46574 L 1 g
F P
s
P
p
.51218 .46574 m .52282 .46778 L .5 .46382 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46414 L p
1 g
F P
s
P
p
.002 w
.5 .46414 m .5 .46442 L p
.49045 .46539 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46414 L .49045 .46539 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47762 .46707 L p
1 g
F P
s
P
p
.002 w
.47762 .46707 m .47718 .46778 L p
.46512 .47307 L 1 g
F P
s
P
p
.45826 .47608 m .47762 .46707 L .46512 .47307 L 1 g
F
P
p
.002 w
.45779 .47659 m .45826 .47608 L p
.46512 .47307 L 1 g
F P
s
P
p
.44236 .47754 m .47988 .45508 L .45779 .47659 L 1 g
F
P
p
.45721 .47687 m .45779 .47659 L .45752 .47686 L 1 g
F
P
p
.44236 .47754 m .45779 .47659 L .45721 .47687 L 1 g
F
P
p
.002 w
.47988 .45508 m .48617 .46296 L p
.47762 .46707 L 1 g
F P
s
P
p
.45779 .47659 m .46601 .46859 L .47762 .46707 L 1 g
F
P
p
.46601 .46859 m .47988 .45508 L .47762 .46707 L 1 g
F
P
p
.47279 .44618 m .52089 .4605 L .5 .46382 L 1 g
F
P
p
.48941 .46549 m .48832 .46567 L .47762 .46707 L 1 g
F
P
p
.002 w
.48832 .46567 m .48495 .46144 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.48495 .46144 m .47279 .44618 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.51199 .46571 m .51537 .46374 L p
.52244 .46717 L 1 g
F P
s
P
p
.002 w
.51537 .46374 m .52623 .45738 L p
.52244 .46717 L 1 g
F P
s
P
p
.002 w
.53203 .47183 m .52866 .46342 L p
.54228 .47666 L 1 g
F P
s
P
p
.002 w
.52866 .46342 m .52623 .45738 L p
.54228 .47666 L 1 g
F P
s
P
p
.002 w
.55959 .48484 m .55268 .48678 L p
.54228 .47666 L 1 g
F P
s
P
p
.002 w
.54228 .47666 m .5425 .47691 L p
.53792 .47461 L 1 g
F P
s
P
p
.002 w
.56211 .48413 m .55959 .48484 L p
.52623 .45738 L 1 g
F P
s
P
p
.002 w
.53062 .46831 m .53203 .47183 L p
.52244 .46717 L 1 g
F P
s
P
p
.002 w
.5425 .47691 m .54302 .47747 L p
.5332 .47239 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52257 .46738 L p
.51726 .46645 L 1 g
F P
s
P
p
.002 w
.52089 .4605 m .51199 .46571 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52257 .46738 m .52282 .46778 L p
.51218 .46574 L 1 g
F P
s
P
p
.48941 .46549 m .49045 .46539 L .48832 .46567 L 1 g
F
P
p
.002 w
.52623 .45738 m .52089 .4605 L p
.47279 .44618 L 1 g
F P
s
P
p
.002 w
.48617 .46296 m .48832 .46567 L p
.47762 .46707 L 1 g
F P
s
P
p
.002 w
.48832 .46567 m .49587 .47514 L p
.47762 .46707 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47762 .46707 L p
1 g
F P
s
P
p
.49045 .46539 m .5 .46442 L .47762 .46707 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45779 .47659 L p
1 g
F P
s
P
p
.46512 .47307 m .47718 .46778 L .45779 .47659 L 1 g
F
P
p
.44339 .4905 m .45738 .47704 L .45082 .48338 L 1 g
F
P
p
.002 w
.44751 .4813 m .45063 .48357 L p
.44274 .49119 L 1 g
F P
s
P
p
.002 w
.45063 .48357 m .47216 .49928 L p
.44274 .49119 L 1 g
F P
s
P
p
.002 w
.45738 .47704 m .45698 .47747 L p
.45082 .48338 L 1 g
F P
s
P
p
.002 w
.45063 .48357 m .44236 .47754 L p
.45752 .47686 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44274 .49119 L p
1 g
F P
s
P
p
.45082 .48338 m .45698 .47747 L .44274 .49119 L 1 g
F
P
p
.002 w
.42427 .51321 m .43606 .48995 L p
.43392 .5104 L 1 g
F P
s
P
p
.002 w
.43606 .48995 m .44236 .47754 L p
.43392 .5104 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43405 .50922 L p
1 g
F P
s
P
p
.43753 .50199 m .44166 .49233 L .43405 .50922 L 1 g
F
P
p
.43392 .5104 m .43443 .50842 L .47216 .49928 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43191 .52959 L p
1 g
F P
s
P
p
.002 w
.43191 .52959 m .43278 .52833 L p
.43282 .52093 L 1 g
F P
s
P
p
.43282 .52093 m .43287 .51061 L .43191 .52959 L 1 g
F
P
p
.002 w
.43405 .50922 m .43287 .51061 L p
.43313 .51795 L 1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.47216 .49928 m .45783 .52679 L .43325 .51684 L p
1 g
F P
s
P
p
.43392 .5104 m .47216 .49928 L .43325 .51684 L 1 g
F
P
p
.002 w
.43325 .51684 m .45783 .52679 L p
.43223 .54179 L 1 g
F P
s
P
p
.43317 .51888 m .43287 .51061 L .43278 .52833 L 1 g
F
P
p
.002 w
.43278 .52833 m .43146 .53025 L p
.43636 .53994 L 1 g
F P
s
P
p
.43854 .547 m .45783 .52679 L .44216 .55239 L 1 g
F
P
p
.43621 .53946 m .45783 .52679 L .43854 .547 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43854 .547 L p
1 g
F P
s
P
p
.43636 .53994 m .43146 .53025 L .43854 .547 L 1 g
F
P
p
.002 w
.45783 .52679 m .45429 .55438 L .44216 .55239 L p
1 g
F P
s
P
p
.002 w
.43854 .547 m .4382 .54764 L p
.44069 .5502 L 1 g
F P
s
P
p
.002 w
.43017 .58025 m .42027 .5488 L .45429 .55438 L p
1 g
F P
s
P
p
.002 w
.4382 .54764 m .43743 .5491 L p
.44463 .55536 L 1 g
F P
s
P
p
.002 w
.45429 .55438 m .45848 .56849 L p
.45088 .56285 L 1 g
F P
s
P
p
.44823 .56089 m .44876 .56031 L .45088 .56285 L 1 g
F
P
p
.44876 .56031 m .45429 .55438 L .45088 .56285 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45088 .56285 L p
1 g
F P
s
P
p
.44463 .55536 m .43743 .5491 L .45088 .56285 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46807 .5756 L p
1 g
F P
s
P
p
.002 w
.46807 .5756 m .4683 .57459 L p
.46312 .57193 L 1 g
F P
s
P
p
.46312 .57193 m .45002 .56518 L .46807 .5756 L 1 g
F
P
p
.45881 .56869 m .45002 .56518 L .4683 .57459 L 1 g
F
P
p
.002 w
.4683 .57459 m .46821 .575 L p
.47097 .57548 L 1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.49004 .55623 m .49472 .57308 L .4745 .57665 L p
1 g
F P
s
P
p
.002 w
.46821 .575 m .4678 .57686 L p
.47875 .57776 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58046 L p
1 g
F P
s
P
p
.47875 .57776 m .4678 .57686 L .48907 .58046 L 1 g
F
P
p
.002 w
.58666 .28779 m .52315 .28453 L .51324 .26337 L p
1 g
F P
s
P
p
.002 w
.44632 .28038 m .51324 .26337 L .52315 .28453 L p
1 g
F P
s
P
p
.002 w
.52315 .28453 m .58666 .28779 L .59338 .31355 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51249 .4545 L
s
P
p
.004 w
.52936 .48691 m
.54796 .52264 L
s
P
p
.002 w
.62311 .53601 m .62328 .51804 L .64842 .499 L p
1 g
F P
s
P
p
.002 w
.63862 .47576 m .64842 .499 L .62328 .51804 L p
1 g
F P
s
P
p
.002 w
.64842 .499 m .63862 .47576 L .65646 .44826 L p
1 g
F P
s
P
p
.002 w
.59045 .55327 m .594 .5439 L .62311 .53601 L p
1 g
F P
s
P
p
.002 w
.62328 .51804 m .62311 .53601 L .594 .5439 L p
1 g
F P
s
P
p
.002 w
.45705 .30151 m .39724 .33687 L .38586 .31617 L p
1 g
F P
s
P
p
.002 w
.38586 .31617 m .44632 .28038 L .45705 .30151 L p
1 g
F P
s
P
p
.002 w
.59743 .34355 m .6443 .36219 L .64019 .39284 L p
1 g
F P
s
P
p
.002 w
.6443 .36219 m .59743 .34355 L .59338 .31355 L p
1 g
F P
s
P
p
.002 w
.52315 .28453 m .45705 .30151 L .44632 .28038 L p
1 g
F P
s
P
p
.002 w
.38951 .43083 m .3661 .47945 L .34347 .4606 L p
1 g
F P
s
P
p
.002 w
.34347 .4606 m .36839 .40766 L .38951 .43083 L p
1 g
F P
s
P
p
.002 w
.63172 .42522 m .65646 .44826 L .63862 .47576 L p
1 g
F P
s
P
p
.002 w
.65646 .44826 m .63172 .42522 L .64019 .39284 L p
1 g
F P
s
P
p
.002 w
.42427 .51321 m .42027 .5488 L .38915 .53975 L p
1 g
F P
s
P
p
.002 w
.38915 .53975 m .39333 .49721 L .42427 .51321 L p
1 g
F P
s
P
p
.002 w
.41213 .36108 m .36839 .40766 L .35174 .38576 L p
1 g
F P
s
P
p
.002 w
.35174 .38576 m .39724 .33687 L .41213 .36108 L p
1 g
F P
s
P
p
.002 w
.594 .5439 m .59395 .53476 L .62328 .51804 L p
1 g
F P
s
P
p
.002 w
.61631 .50227 m .62328 .51804 L .59395 .53476 L p
1 g
F P
s
P
p
.002 w
.62328 .51804 m .61631 .50227 L .63862 .47576 L p
1 g
F P
s
P
p
.002 w
.53265 .31082 m .59338 .31355 L .59743 .34355 L p
1 g
F P
s
P
p
.002 w
.59338 .31355 m .53265 .31082 L .52315 .28453 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.45705 .30151 m .52315 .28453 L .53265 .31082 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.61912 .45818 m .63862 .47576 L .61631 .50227 L p
1 g
F P
s
P
p
.002 w
.63862 .47576 m .61912 .45818 L .63172 .42522 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.59857 .37685 m .64019 .39284 L .63172 .42522 L p
1 g
F P
s
P
p
.002 w
.64019 .39284 m .59857 .37685 L .59743 .34355 L p
1 g
F P
s
P
p
.002 w
.52619 .55425 m .5284 .56284 L .49472 .57308 L p
1 g
F P
s
P
p
.002 w
.49472 .57308 m .49004 .55623 L .52619 .55425 L p
1 g
F P
s
P
p
.002 w
.41446 .45442 m .39333 .49721 L .3661 .47945 L p
1 g
F P
s
P
p
.002 w
.3661 .47945 m .38951 .43083 L .41446 .45442 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59395 .53476 m .59027 .52683 L .61631 .50227 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46942 .32726 m .41213 .36108 L .39724 .33687 L p
1 g
F P
s
P
p
.002 w
.39724 .33687 m .45705 .30151 L .46942 .32726 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60278 .49051 m .61631 .50227 L .59027 .52683 L p
1 g
F P
s
P
p
.002 w
.61631 .50227 m .60278 .49051 L .61912 .45818 L p
1 g
F P
s
P
p
.002 w
.53265 .31082 m .46942 .32726 L .45705 .30151 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.43012 .38802 m .38951 .43083 L .36839 .40766 L p
1 g
F P
s
P
p
.002 w
.36839 .40766 m .41213 .36108 L .43012 .38802 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.49275 .53744 m .49004 .55623 L .45429 .55438 L p
1 g
F P
s
P
p
.002 w
.45429 .55438 m .45783 .52679 L .49275 .53744 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59027 .52683 m .5833 .52099 L .60278 .49051 L p
1 g
F P
s
P
p
.002 w
.59667 .41228 m .63172 .42522 L .61912 .45818 L p
1 g
F P
s
P
p
.002 w
.63172 .42522 m .59667 .41228 L .59857 .37685 L p
1 g
F P
s
P
p
.002 w
.54137 .34145 m .59743 .34355 L .59857 .37685 L p
1 g
F P
s
P
p
.002 w
.59743 .34355 m .54137 .34145 L .53265 .31082 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.52771 .54475 m .52619 .55425 L .49004 .55623 L p
1 g
F P
s
P
p
.002 w
.49004 .55623 m .49275 .53744 L .52771 .54475 L p
1 g
F P
s
P
p
.002 w
.44236 .47754 m .42427 .51321 L .39333 .49721 L p
1 g
F P
s
P
p
.002 w
.39333 .49721 m .41446 .45442 L .44236 .47754 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.46942 .32726 m .53265 .31082 L .54137 .34145 L p
1 g
F P
s
P
p
.002 w
.5833 .52099 m .57377 .51792 L .58403 .48418 L p
1 g
F P
s
P
p
.002 w
.58403 .48418 m .60278 .49051 L .5833 .52099 L p
1 g
F P
s
P
p
.002 w
.59177 .44852 m .61912 .45818 L .60278 .49051 L p
1 g
F P
s
P
p
.002 w
.61912 .45818 m .59177 .44852 L .59667 .41228 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.60278 .49051 m .58403 .48418 L .59177 .44852 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.53284 .5354 m .52771 .54475 L .49275 .53744 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56211 .48413 m .58403 .48418 L .57377 .51792 L p
1 g
F P
s
P
p
.002 w
.54897 .37541 m .59857 .37685 L .59667 .41228 L p
1 g
F P
s
P
p
.002 w
.59857 .37685 m .54897 .37541 L .54137 .34145 L p
1 g
F P
s
P
p
.002 w
.48305 .35684 m .43012 .38802 L .41213 .36108 L p
1 g
F P
s
P
p
.002 w
.41213 .36108 m .46942 .32726 L .48305 .35684 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.45059 .41676 m .41446 .45442 L .38951 .43083 L p
1 g
F P
s
P
p
.002 w
.38951 .43083 m .43012 .38802 L .45059 .41676 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.54104 .52725 m .53284 .5354 L .50271 .51881 L p
1 g
F P
s
P
p
.002 w
.49275 .53744 m .50271 .51881 L .53284 .5354 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54137 .34145 m .48305 .35684 L .46942 .32726 L p
1 g
F P
s
P
p
.002 w
.56273 .51799 m .55139 .52122 L .53952 .49048 L p
1 g
F P
s
P
p
.002 w
.50271 .51881 m .49275 .53744 L .45783 .52679 L p
1 g
F P
s
P
p
.002 w
.45783 .52679 m .47216 .49928 L .50271 .51881 L p
1 g
F P
s
P
p
.002 w
.55139 .52122 m .54104 .52725 L .51892 .50251 L p
1 g
F P
s
P
p
.002 w
.50271 .51881 m .51892 .50251 L .54104 .52725 L p
1 g
F P
s
P
p
.002 w
.51892 .50251 m .53952 .49048 L .55139 .52122 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58403 .48418 m .56211 .48413 L .55955 .44816 L p
1 g
F P
s
P
p
.002 w
.55955 .44816 m .59177 .44852 L .58403 .48418 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55511 .41144 m .59667 .41228 L .59177 .44852 L p
1 g
F P
s
P
p
.002 w
.59667 .41228 m .55511 .41144 L .54897 .37541 L p
1 g
F P
s
P
p
.002 w
.48305 .35684 m .54137 .34145 L .54897 .37541 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.59177 .44852 m .55955 .44816 L .55511 .41144 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47279 .44618 m .44236 .47754 L .41446 .45442 L p
1 g
F P
s
P
p
.002 w
.41446 .45442 m .45059 .41676 L .47279 .44618 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.51892 .50251 m .50271 .51881 L .47216 .49928 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52623 .45738 m .55955 .44816 L .56211 .48413 L p
1 g
F P
s
P
p
.002 w
.49743 .38922 m .45059 .41676 L .43012 .38802 L p
1 g
F P
s
P
p
.002 w
.43012 .38802 m .48305 .35684 L .49743 .38922 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.54897 .37541 m .49743 .38922 L .48305 .35684 L p
1 g
F P
s
P
p
.002 w
.53952 .49048 m .51892 .50251 L .49587 .47514 L p
1 g
F P
s
P
p
.002 w
.47216 .49928 m .49587 .47514 L .51892 .50251 L p
1 g
F P
s
P
p
.002 w
.49743 .38922 m .54897 .37541 L .55511 .41144 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.55955 .44816 m .52623 .45738 L .51202 .42318 L p
1 g
F P
s
P
p
.002 w
.51202 .42318 m .55511 .41144 L .55955 .44816 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.55511 .41144 m .51202 .42318 L .49743 .38922 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51202 .42318 m .47279 .44618 L .45059 .41676 L p
1 g
F P
s
P
p
.002 w
.45059 .41676 m .49743 .38922 L .51202 .42318 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.58264 .58926 m
.58678 .59722 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47279 .44618 m .51202 .42318 L .52623 .45738 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .79401 .47137 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .59783 .61844 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.575194)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.575194)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47488 .44967 m .51584 .44082 L .50647 .41382 L p
1 g
F P
s
P
p
.002 w
.50647 .41382 m .47227 .42118 L .47488 .44967 L p
1 g
F P
s
P
p
.002 w
.53751 .39846 m .50647 .41382 L .51584 .44082 L p
1 g
F P
s
P
p
.002 w
.47227 .42118 m .50647 .41382 L .49691 .38715 L p
1 g
F P
s
P
p
.002 w
.50647 .41382 m .53751 .39846 L .52098 .37513 L p
1 g
F P
s
P
p
.002 w
.52098 .37513 m .49691 .38715 L .50647 .41382 L p
1 g
F P
s
P
p
.002 w
.4781 .47781 m .52486 .46766 L .51584 .44082 L p
1 g
F P
s
P
p
.002 w
.51584 .44082 m .47488 .44967 L .4781 .47781 L p
1 g
F P
s
P
p
.002 w
.5531 .42254 m .51584 .44082 L .52486 .46766 L p
1 g
F P
s
P
p
.002 w
.51584 .44082 m .5531 .42254 L .53751 .39846 L p
1 g
F P
s
P
p
.002 w
.43391 .44826 m .47488 .44967 L .47227 .42118 L p
1 g
F P
s
P
p
.002 w
.47227 .42118 m .43811 .41983 L .43391 .44826 L p
1 g
F P
s
P
p
.002 w
.43811 .41983 m .47227 .42118 L .47033 .39284 L p
1 g
F P
s
P
p
.002 w
.49691 .38715 m .47033 .39284 L .47227 .42118 L p
1 g
F P
s
P
p
.002 w
.43131 .47642 m .4781 .47781 L .47488 .44967 L p
1 g
F P
s
P
p
.002 w
.47488 .44967 m .43391 .44826 L .43131 .47642 L p
1 g
F P
s
P
p
.002 w
.47033 .39284 m .49691 .38715 L .48734 .36128 L p
1 g
F P
s
P
p
.002 w
.49691 .38715 m .52098 .37513 L .50383 .35298 L p
1 g
F P
s
P
p
.002 w
.50383 .35298 m .48734 .36128 L .49691 .38715 L p
1 g
F P
s
P
p
.002 w
.4819 .50506 m .53336 .49385 L .52486 .46766 L p
1 g
F P
s
P
p
.002 w
.52486 .46766 m .4781 .47781 L .4819 .50506 L p
1 g
F P
s
P
p
.002 w
.56747 .44693 m .52486 .46766 L .53336 .49385 L p
1 g
F P
s
P
p
.002 w
.52486 .46766 m .56747 .44693 L .5531 .42254 L p
1 g
F P
s
P
p
.002 w
.47033 .39284 m .44381 .39165 L .43811 .41983 L p
1 g
F P
s
P
p
.002 w
.44381 .39165 m .47033 .39284 L .46909 .36517 L p
1 g
F P
s
P
p
.002 w
.48734 .36128 m .46909 .36517 L .47033 .39284 L p
1 g
F P
s
P
p
.002 w
.56242 .37645 m .53751 .39846 L .5531 .42254 L p
1 g
F P
s
P
p
.002 w
.53751 .39846 m .56242 .37645 L .54018 .35791 L p
1 g
F P
s
P
p
.002 w
.54018 .35791 m .52098 .37513 L .53751 .39846 L p
1 g
F P
s
P
p
.002 w
.43037 .5038 m .4819 .50506 L .4781 .47781 L p
1 g
F P
s
P
p
.002 w
.4781 .47781 m .43131 .47642 L .43037 .5038 L p
1 g
F P
s
P
p
.002 w
.58319 .39636 m .5531 .42254 L .56747 .44693 L p
1 g
F P
s
P
p
.002 w
.5531 .42254 m .58319 .39636 L .56242 .37645 L p
1 g
F P
s
P
p
.002 w
.52098 .37513 m .54018 .35791 L .51688 .34109 L p
1 g
F P
s
P
p
.002 w
.51688 .34109 m .50383 .35298 L .52098 .37513 L p
1 g
F P
s
P
p
.002 w
.39674 .43648 m .43391 .44826 L .43811 .41983 L p
1 g
F P
s
P
p
.002 w
.43811 .41983 m .40723 .40972 L .39674 .43648 L p
1 g
F P
s
P
p
.002 w
.40723 .40972 m .43811 .41983 L .44381 .39165 L p
1 g
F P
s
P
p
.002 w
.44381 .39165 m .41995 .3836 L .40723 .40972 L p
1 g
F P
s
P
p
.002 w
.41995 .3836 m .44381 .39165 L .45091 .36427 L p
1 g
F P
s
P
p
.002 w
.46909 .36517 m .45091 .36427 L .44381 .39165 L p
1 g
F P
s
P
p
.002 w
.38871 .46335 m .43131 .47642 L .43391 .44826 L p
1 g
F P
s
P
p
.002 w
.43391 .44826 m .39674 .43648 L .38871 .46335 L p
1 g
F P
s
P
p
.002 w
.53336 .49385 m .58035 .47118 L .56747 .44693 L p
1 g
F P
s
P
p
.002 w
.60208 .41728 m .56747 .44693 L .58035 .47118 L p
1 g
F P
s
P
p
.002 w
.56747 .44693 m .60208 .41728 L .58319 .39636 L p
1 g
F P
s
P
p
.002 w
.46909 .36517 m .48734 .36128 L .47793 .33671 L p
1 g
F P
s
P
p
.002 w
.48734 .36128 m .50383 .35298 L .48635 .33244 L p
1 g
F P
s
P
p
.002 w
.48635 .33244 m .47793 .33671 L .48734 .36128 L p
1 g
F P
s
P
p
.002 w
.48619 .53092 m .54117 .5189 L .53336 .49385 L p
1 g
F P
s
P
p
.002 w
.53336 .49385 m .4819 .50506 L .48619 .53092 L p
1 g
F P
s
P
p
.002 w
.58035 .47118 m .53336 .49385 L .54117 .5189 L p
1 g
F P
s
P
p
.002 w
.45091 .36427 m .46909 .36517 L .4686 .33869 L p
1 g
F P
s
P
p
.002 w
.47793 .33671 m .4686 .33869 L .46909 .36517 L p
1 g
F P
s
P
p
.002 w
.43114 .52982 m .48619 .53092 L .4819 .50506 L p
1 g
F P
s
P
p
.002 w
.4819 .50506 m .43037 .5038 L .43114 .52982 L p
1 g
F P
s
P
p
.002 w
.50383 .35298 m .51688 .34109 L .49296 .32633 L p
1 g
F P
s
P
p
.002 w
.49296 .32633 m .48635 .33244 L .50383 .35298 L p
1 g
F P
s
P
p
.002 w
.45091 .36427 m .43465 .35861 L .41995 .3836 L p
1 g
F P
s
P
p
.002 w
.43465 .35861 m .45091 .36427 L .45931 .33819 L p
1 g
F P
s
P
p
.002 w
.4686 .33869 m .45931 .33819 L .45091 .36427 L p
1 g
F P
s
P
p
.002 w
.57863 .34975 m .56242 .37645 L .58319 .39636 L p
1 g
F P
s
P
p
.002 w
.56242 .37645 m .57863 .34975 L .55247 .33709 L p
1 g
F P
s
P
p
.002 w
.55247 .33709 m .54018 .35791 L .56242 .37645 L p
1 g
F P
s
P
p
.002 w
.38334 .48982 m .43037 .5038 L .43131 .47642 L p
1 g
F P
s
P
p
.002 w
.43131 .47642 m .38871 .46335 L .38334 .48982 L p
1 g
F P
s
P
p
.002 w
.54018 .35791 m .55247 .33709 L .52511 .32677 L p
1 g
F P
s
P
p
.002 w
.52511 .32677 m .51688 .34109 L .54018 .35791 L p
1 g
F P
s
P
p
.002 w
.60304 .36452 m .58319 .39636 L .60208 .41728 L p
1 g
F P
s
P
p
.002 w
.58319 .39636 m .60304 .36452 L .57863 .34975 L p
1 g
F P
s
P
p
.002 w
.54117 .5189 m .59146 .49484 L .58035 .47118 L p
1 g
F P
s
P
p
.002 w
.6187 .43882 m .58035 .47118 L .59146 .49484 L p
1 g
F P
s
P
p
.002 w
.58035 .47118 m .6187 .43882 L .60208 .41728 L p
1 g
F P
s
P
p
.002 w
.51688 .34109 m .52511 .32677 L .49705 .319 L p
1 g
F P
s
P
p
.002 w
.49705 .319 m .49296 .32633 L .51688 .34109 L p
1 g
F P
s
P
p
.002 w
.3828 .39159 m .40723 .40972 L .41995 .3836 L p
1 g
F P
s
P
p
.002 w
.41995 .3836 m .40124 .36932 L .3828 .39159 L p
1 g
F P
s
P
p
.002 w
.40124 .36932 m .41995 .3836 L .43465 .35861 L p
1 g
F P
s
P
p
.002 w
.3671 .41508 m .39674 .43648 L .40723 .40972 L p
1 g
F P
s
P
p
.002 w
.40723 .40972 m .3828 .39159 L .3671 .41508 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .4686 .33869 L .47793 .33671 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .47793 .33671 L .48635 .33244 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .45931 .33819 L .4686 .33869 L closepath p
1 g
F P
s
P
p
.002 w
.43465 .35861 m .42201 .34869 L .40124 .36932 L p
1 g
F P
s
P
p
.002 w
.42201 .34869 m .43465 .35861 L .45106 .33523 L p
1 g
F P
s
P
p
.002 w
.45931 .33819 m .45106 .33523 L .43465 .35861 L p
1 g
F P
s
P
p
.002 w
.49093 .55484 m .54813 .54229 L .54117 .5189 L p
1 g
F P
s
P
p
.002 w
.54117 .5189 m .48619 .53092 L .49093 .55484 L p
1 g
F P
s
P
p
.002 w
.59146 .49484 m .54117 .5189 L .54813 .54229 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .48635 .33244 L .49296 .32633 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .45106 .33523 L .45931 .33819 L closepath p
1 g
F P
s
P
p
.002 w
.38081 .51532 m .43114 .52982 L .43037 .5038 L p
1 g
F P
s
P
p
.002 w
.43037 .5038 m .38334 .48982 L .38081 .51532 L p
1 g
F P
s
P
p
.002 w
.43367 .55395 m .49093 .55484 L .48619 .53092 L p
1 g
F P
s
P
p
.002 w
.48619 .53092 m .43114 .52982 L .43367 .55395 L p
1 g
F P
s
P
p
.002 w
.62518 .38114 m .60208 .41728 L .6187 .43882 L p
1 g
F P
s
P
p
.002 w
.60208 .41728 m .62518 .38114 L .60304 .36452 L p
1 g
F P
s
P
p
.002 w
.35452 .43933 m .38871 .46335 L .39674 .43648 L p
1 g
F P
s
P
p
.002 w
.39674 .43648 m .3671 .41508 L .35452 .43933 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .49296 .32633 L .49705 .319 L closepath p
1 g
F P
s
P
p
.002 w
.52756 .31148 m .52511 .32677 L .55247 .33709 L p
1 g
F P
s
P
p
.002 w
.52511 .32677 m .52756 .31148 L .49818 .31123 L p
1 g
F P
s
P
p
.002 w
.49818 .31123 m .49705 .319 L .52511 .32677 L p
1 g
F P
s
P
p
.002 w
.45106 .33523 m .44471 .33011 L .42201 .34869 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .44471 .33011 L .45106 .33523 L closepath p
1 g
F P
s
P
p
.002 w
.55641 .3147 m .55247 .33709 L .57863 .34975 L p
1 g
F P
s
P
p
.002 w
.55247 .33709 m .55641 .3147 L .52756 .31148 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .49705 .319 L .49818 .31123 L closepath p
1 g
F P
s
P
p
.002 w
.54813 .54229 m .60053 .51741 L .59146 .49484 L p
1 g
F P
s
P
p
.002 w
.63265 .46055 m .59146 .49484 L .60053 .51741 L p
1 g
F P
s
P
p
.002 w
.59146 .49484 m .63265 .46055 L .6187 .43882 L p
1 g
F P
s
P
p
.002 w
.58416 .32087 m .57863 .34975 L .60304 .36452 L p
1 g
F P
s
P
p
.002 w
.57863 .34975 m .58416 .32087 L .55641 .3147 L p
1 g
F P
s
P
p
.002 w
.38977 .35011 m .40124 .36932 L .42201 .34869 L p
1 g
F P
s
P
p
.002 w
.42201 .34869 m .41442 .33548 L .38977 .35011 L p
1 g
F P
s
P
p
.002 w
.41442 .33548 m .42201 .34869 L .44471 .33011 L p
1 g
F P
s
P
p
.002 w
.44471 .33011 m .44097 .32336 L .41442 .33548 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .44097 .32336 L .44471 .33011 L closepath p
1 g
F P
s
P
p
.002 w
.34541 .46383 m .38334 .48982 L .38871 .46335 L p
1 g
F P
s
P
p
.002 w
.38871 .46335 m .35452 .43933 L .34541 .46383 L p
1 g
F P
s
P
p
.002 w
.36758 .36697 m .3828 .39159 L .40124 .36932 L p
1 g
F P
s
P
p
.002 w
.40124 .36932 m .38977 .35011 L .36758 .36697 L p
1 g
F P
s
P
p
.002 w
.64455 .39932 m .6187 .43882 L .63265 .46055 L p
1 g
F P
s
P
p
.002 w
.6187 .43882 m .64455 .39932 L .62518 .38114 L p
1 g
F P
s
P
p
.002 w
.49617 .30384 m .49818 .31123 L .52756 .31148 L p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .49818 .31123 L .49617 .30384 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .44813 .3009 L .44274 .3079 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .44274 .3079 L .44027 .31568 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .44027 .31568 L .44097 .32336 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .49617 .30384 L .49121 .29765 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .49121 .29765 L .48381 .29336 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .48381 .29336 L .47476 .29146 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .47476 .29146 L .46509 .29218 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .46509 .29218 L .45586 .29545 L closepath p
1 g
F P
s
P
p
.002 w
.46887 .31395 m .45586 .29545 L .44813 .3009 L closepath p
1 g
F P
s
P
p
.002 w
.38127 .53928 m .43367 .55395 L .43114 .52982 L p
1 g
F P
s
P
p
.002 w
.43114 .52982 m .38081 .51532 L .38127 .53928 L p
1 g
F P
s
P
p
.002 w
.49603 .57627 m .55407 .5635 L .54813 .54229 L p
1 g
F P
s
P
p
.002 w
.54813 .54229 m .49093 .55484 L .49603 .57627 L p
1 g
F P
s
P
p
.002 w
.60053 .51741 m .54813 .54229 L .55407 .5635 L p
1 g
F P
s
P
p
.002 w
.52383 .29682 m .52756 .31148 L .55641 .3147 L p
1 g
F P
s
P
p
.002 w
.52756 .31148 m .52383 .29682 L .49617 .30384 L p
1 g
F P
s
P
p
.002 w
.4128 .32033 m .41442 .33548 L .44097 .32336 L p
1 g
F P
s
P
p
.002 w
.44097 .32336 m .44027 .31568 L .4128 .32033 L p
1 g
F P
s
P
p
.002 w
.61018 .32992 m .60304 .36452 L .62518 .38114 L p
1 g
F P
s
P
p
.002 w
.60304 .36452 m .61018 .32992 L .58416 .32087 L p
1 g
F P
s
P
p
.002 w
.34838 .38576 m .3671 .41508 L .3828 .39159 L p
1 g
F P
s
P
p
.002 w
.3828 .39159 m .36758 .36697 L .34838 .38576 L p
1 g
F P
s
P
p
.002 w
.43796 .57559 m .49603 .57627 L .49093 .55484 L p
1 g
F P
s
P
p
.002 w
.49093 .55484 m .43367 .55395 L .43796 .57559 L p
1 g
F P
s
P
p
.002 w
.49121 .29765 m .49617 .30384 L .52383 .29682 L p
1 g
F P
s
P
p
.002 w
.38707 .32786 m .38977 .35011 L .41442 .33548 L p
1 g
F P
s
P
p
.002 w
.41442 .33548 m .4128 .32033 L .38707 .32786 L p
1 g
F P
s
P
p
.002 w
.55128 .29308 m .55641 .3147 L .58416 .32087 L p
1 g
F P
s
P
p
.002 w
.55641 .3147 m .55128 .29308 L .52383 .29682 L p
1 g
F P
s
P
p
.002 w
.41751 .30485 m .4128 .32033 L .44027 .31568 L p
1 g
F P
s
P
p
.002 w
.44027 .31568 m .44274 .3079 L .41751 .30485 L p
1 g
F P
s
P
p
.002 w
.34008 .48805 m .38081 .51532 L .38334 .48982 L p
1 g
F P
s
P
p
.002 w
.38334 .48982 m .34541 .46383 L .34008 .48805 L p
1 g
F P
s
P
p
.002 w
.55407 .5635 m .60728 .53839 L .60053 .51741 L p
1 g
F P
s
P
p
.002 w
.64356 .48205 m .60053 .51741 L .60728 .53839 L p
1 g
F P
s
P
p
.002 w
.60053 .51741 m .64356 .48205 L .63265 .46055 L p
1 g
F P
s
P
p
.002 w
.52383 .29682 m .51417 .28443 L .49121 .29765 L p
1 g
F P
s
P
p
.002 w
.48381 .29336 m .49121 .29765 L .51417 .28443 L p
1 g
F P
s
P
p
.002 w
.33268 .40612 m .35452 .43933 L .3671 .41508 L p
1 g
F P
s
P
p
.002 w
.3671 .41508 m .34838 .38576 L .33268 .40612 L p
1 g
F P
s
P
p
.002 w
.63388 .34172 m .62518 .38114 L .64455 .39932 L p
1 g
F P
s
P
p
.002 w
.62518 .38114 m .63388 .34172 L .61018 .32992 L p
1 g
F P
s
P
p
.002 w
.42814 .2908 m .41751 .30485 L .44274 .3079 L p
1 g
F P
s
P
p
.002 w
.44274 .3079 m .44813 .3009 L .42814 .2908 L p
1 g
F P
s
P
p
.002 w
.51417 .28443 m .52383 .29682 L .55128 .29308 L p
1 g
F P
s
P
p
.002 w
.66065 .41869 m .63265 .46055 L .64356 .48205 L p
1 g
F P
s
P
p
.002 w
.63265 .46055 m .66065 .41869 L .64455 .39932 L p
1 g
F P
s
P
p
.002 w
.36368 .3382 m .36758 .36697 L .38977 .35011 L p
1 g
F P
s
P
p
.002 w
.38977 .35011 m .38707 .32786 L .36368 .3382 L p
1 g
F P
s
P
p
.002 w
.51417 .28443 m .49953 .27575 L .48381 .29336 L p
1 g
F P
s
P
p
.002 w
.47476 .29146 m .48381 .29336 L .49953 .27575 L p
1 g
F P
s
P
p
.002 w
.57793 .29279 m .58416 .32087 L .61018 .32992 L p
1 g
F P
s
P
p
.002 w
.58416 .32087 m .57793 .29279 L .55128 .29308 L p
1 g
F P
s
P
p
.002 w
.44358 .27984 m .42814 .2908 L .44813 .3009 L p
1 g
F P
s
P
p
.002 w
.44813 .3009 m .45586 .29545 L .44358 .27984 L p
1 g
F P
s
P
p
.002 w
.38484 .5611 m .43796 .57559 L .43367 .55395 L p
1 g
F P
s
P
p
.002 w
.43367 .55395 m .38127 .53928 L .38484 .5611 L p
1 g
F P
s
P
p
.002 w
.39376 .30495 m .38707 .32786 L .4128 .32033 L p
1 g
F P
s
P
p
.002 w
.4128 .32033 m .41751 .30485 L .39376 .30495 L p
1 g
F P
s
P
p
.002 w
.49953 .27575 m .48148 .27185 L .47476 .29146 L p
1 g
F P
s
P
p
.002 w
.46509 .29218 m .47476 .29146 L .48148 .27185 L p
1 g
F P
s
P
p
.002 w
.46208 .27326 m .44358 .27984 L .45586 .29545 L p
1 g
F P
s
P
p
.002 w
.45586 .29545 m .46509 .29218 L .46208 .27326 L p
1 g
F P
s
P
p
.002 w
.48148 .27185 m .46208 .27326 L .46509 .29218 L p
1 g
F P
s
P
p
.002 w
.50139 .59464 m .5588 .58197 L .55407 .5635 L p
1 g
F P
s
P
p
.002 w
.55407 .5635 m .49603 .57627 L .50139 .59464 L p
1 g
F P
s
P
p
.002 w
.60728 .53839 m .55407 .5635 L .5588 .58197 L p
1 g
F P
s
P
p
.002 w
.32097 .42764 m .34541 .46383 L .35452 .43933 L p
1 g
F P
s
P
p
.002 w
.35452 .43933 m .33268 .40612 L .32097 .42764 L p
1 g
F P
s
P
p
.002 w
.444 .59416 m .50139 .59464 L .49603 .57627 L p
1 g
F P
s
P
p
.002 w
.49603 .57627 m .43796 .57559 L .444 .59416 L p
1 g
F P
s
P
p
.002 w
.33881 .51143 m .38127 .53928 L .38081 .51532 L p
1 g
F P
s
P
p
.002 w
.38081 .51532 m .34008 .48805 L .33881 .51143 L p
1 g
F P
s
P
p
.002 w
.53729 .27465 m .55128 .29308 L .57793 .29279 L p
1 g
F P
s
P
p
.002 w
.55128 .29308 m .53729 .27465 L .51417 .28443 L p
1 g
F P
s
P
p
.002 w
.49953 .27575 m .51417 .28443 L .53729 .27465 L p
1 g
F P
s
P
p
.002 w
.34325 .35121 m .34838 .38576 L .36758 .36697 L p
1 g
F P
s
P
p
.002 w
.36758 .36697 m .36368 .3382 L .34325 .35121 L p
1 g
F P
s
P
p
.002 w
.65466 .3561 m .64455 .39932 L .66065 .41869 L p
1 g
F P
s
P
p
.002 w
.64455 .39932 m .65466 .3561 L .63388 .34172 L p
1 g
F P
s
P
p
.002 w
.60316 .29606 m .61018 .32992 L .63388 .34172 L p
1 g
F P
s
P
p
.002 w
.61018 .32992 m .60316 .29606 L .57793 .29279 L p
1 g
F P
s
P
p
.002 w
.40939 .28402 m .39376 .30495 L .41751 .30485 L p
1 g
F P
s
P
p
.002 w
.41751 .30485 m .42814 .2908 L .40939 .28402 L p
1 g
F P
s
P
p
.002 w
.5588 .58197 m .61148 .55726 L .60728 .53839 L p
1 g
F P
s
P
p
.002 w
.65108 .50282 m .60728 .53839 L .61148 .55726 L p
1 g
F P
s
P
p
.002 w
.60728 .53839 m .65108 .50282 L .64356 .48205 L p
1 g
F P
s
P
p
.002 w
.67299 .43889 m .64356 .48205 L .65108 .50282 L p
1 g
F P
s
P
p
.002 w
.64356 .48205 m .67299 .43889 L .66065 .41869 L p
1 g
F P
s
P
p
.002 w
.37209 .30834 m .36368 .3382 L .38707 .32786 L p
1 g
F P
s
P
p
.002 w
.38707 .32786 m .39376 .30495 L .37209 .30834 L p
1 g
F P
s
P
p
.002 w
.53729 .27465 m .51573 .26163 L .49953 .27575 L p
1 g
F P
s
P
p
.002 w
.48148 .27185 m .49953 .27575 L .51573 .26163 L p
1 g
F P
s
P
p
.002 w
.43234 .26761 m .40939 .28402 L .42814 .2908 L p
1 g
F P
s
P
p
.002 w
.42814 .2908 m .44358 .27984 L .43234 .26761 L p
1 g
F P
s
P
p
.002 w
.39158 .58016 m .444 .59416 L .43796 .57559 L p
1 g
F P
s
P
p
.002 w
.43796 .57559 m .38484 .5611 L .39158 .58016 L p
1 g
F P
s
P
p
.002 w
.32639 .3667 m .33268 .40612 L .34838 .38576 L p
1 g
F P
s
P
p
.002 w
.34838 .38576 m .34325 .35121 L .32639 .3667 L p
1 g
F P
s
P
p
.002 w
.31369 .44984 m .34008 .48805 L .34541 .46383 L p
1 g
F P
s
P
p
.002 w
.34541 .46383 m .32097 .42764 L .31369 .44984 L p
1 g
F P
s
P
p
.002 w
.56004 .26866 m .57793 .29279 L .60316 .29606 L p
1 g
F P
s
P
p
.002 w
.57793 .29279 m .56004 .26866 L .53729 .27465 L p
1 g
F P
s
P
p
.002 w
.51573 .26163 m .48891 .25572 L .48148 .27185 L p
1 g
F P
s
P
p
.002 w
.46208 .27326 m .48148 .27185 L .48891 .25572 L p
1 g
F P
s
P
p
.002 w
.51573 .26163 m .53729 .27465 L .56004 .26866 L p
1 g
F P
s
P
p
.002 w
.62634 .30294 m .63388 .34172 L .65466 .3561 L p
1 g
F P
s
P
p
.002 w
.63388 .34172 m .62634 .30294 L .60316 .29606 L p
1 g
F P
s
P
p
.002 w
.45995 .25777 m .43234 .26761 L .44358 .27984 L p
1 g
F P
s
P
p
.002 w
.44358 .27984 m .46208 .27326 L .45995 .25777 L p
1 g
F P
s
P
p
.002 w
.34181 .53335 m .38484 .5611 L .38127 .53928 L p
1 g
F P
s
P
p
.002 w
.38127 .53928 m .33881 .51143 L .34181 .53335 L p
1 g
F P
s
P
p
.002 w
.67191 .37281 m .66065 .41869 L .67299 .43889 L p
1 g
F P
s
P
p
.002 w
.66065 .41869 m .67191 .37281 L .65466 .3561 L p
1 g
F P
s
P
p
.002 w
.48891 .25572 m .45995 .25777 L .46208 .27326 L p
1 g
F P
s
P
p
.002 w
.50691 .60937 m .56217 .59715 L .5588 .58197 L p
1 g
F P
s
P
p
.002 w
.5588 .58197 m .50139 .59464 L .50691 .60937 L p
1 g
F P
s
P
p
.002 w
.61148 .55726 m .5588 .58197 L .56217 .59715 L p
1 g
F P
s
P
p
.002 w
.45174 .60906 m .50691 .60937 L .50139 .59464 L p
1 g
F P
s
P
p
.002 w
.50139 .59464 m .444 .59416 L .45174 .60906 L p
1 g
F P
s
P
p
.002 w
.39237 .28087 m .37209 .30834 L .39376 .30495 L p
1 g
F P
s
P
p
.002 w
.39376 .30495 m .40939 .28402 L .39237 .28087 L p
1 g
F P
s
P
p
.002 w
.35312 .31508 m .34325 .35121 L .36368 .3382 L p
1 g
F P
s
P
p
.002 w
.36368 .3382 m .37209 .30834 L .35312 .31508 L p
1 g
F P
s
P
p
.002 w
.61148 .55726 m .65487 .52237 L .65108 .50282 L p
1 g
F P
s
P
p
.002 w
.68113 .45946 m .65108 .50282 L .65487 .52237 L p
1 g
F P
s
P
p
.002 w
.65108 .50282 m .68113 .45946 L .67299 .43889 L p
1 g
F P
s
P
p
.002 w
.56217 .59715 m .6129 .57348 L .61148 .55726 L p
1 g
F P
s
P
p
.002 w
.65487 .52237 m .61148 .55726 L .6129 .57348 L p
1 g
F P
s
P
p
.002 w
.31367 .38438 m .32097 .42764 L .33268 .40612 L p
1 g
F P
s
P
p
.002 w
.33268 .40612 m .32639 .3667 L .31367 .38438 L p
1 g
F P
s
P
p
.002 w
.5819 .26677 m .60316 .29606 L .62634 .30294 L p
1 g
F P
s
P
p
.002 w
.60316 .29606 m .5819 .26677 L .56004 .26866 L p
1 g
F P
s
P
p
.002 w
.56004 .26866 m .53205 .25149 L .51573 .26163 L p
1 g
F P
s
P
p
.002 w
.48891 .25572 m .51573 .26163 L .53205 .25149 L p
1 g
F P
s
P
p
.002 w
.31122 .47219 m .33881 .51143 L .34008 .48805 L p
1 g
F P
s
P
p
.002 w
.34008 .48805 m .31369 .44984 L .31122 .47219 L p
1 g
F P
s
P
p
.002 w
.64683 .31341 m .65466 .3561 L .67191 .37281 L p
1 g
F P
s
P
p
.002 w
.65466 .3561 m .64683 .31341 L .62634 .30294 L p
1 g
F P
s
P
p
.002 w
.42246 .25924 m .39237 .28087 L .40939 .28402 L p
1 g
F P
s
P
p
.002 w
.40939 .28402 m .43234 .26761 L .42246 .25924 L p
1 g
F P
s
P
p
.002 w
.53205 .25149 m .56004 .26866 L .5819 .26677 L p
1 g
F P
s
P
p
.002 w
.40147 .59586 m .45174 .60906 L .444 .59416 L p
1 g
F P
s
P
p
.002 w
.444 .59416 m .39158 .58016 L .40147 .59586 L p
1 g
F P
s
P
p
.002 w
.68508 .39156 m .67299 .43889 L .68113 .45946 L p
1 g
F P
s
P
p
.002 w
.67299 .43889 m .68508 .39156 L .67191 .37281 L p
1 g
F P
s
P
p
.002 w
.34919 .5532 m .39158 .58016 L .38484 .5611 L p
1 g
F P
s
P
p
.002 w
.38484 .5611 m .34181 .53335 L .34919 .5532 L p
1 g
F P
s
P
p
.002 w
.53205 .25149 m .49692 .24361 L .48891 .25572 L p
1 g
F P
s
P
p
.002 w
.45995 .25777 m .48891 .25572 L .49692 .24361 L p
1 g
F P
s
P
p
.002 w
.33745 .32518 m .32639 .3667 L .34325 .35121 L p
1 g
F P
s
P
p
.002 w
.34325 .35121 m .35312 .31508 L .33745 .32518 L p
1 g
F P
s
P
p
.002 w
.45881 .24627 m .42246 .25924 L .43234 .26761 L p
1 g
F P
s
P
p
.002 w
.43234 .26761 m .45995 .25777 L .45881 .24627 L p
1 g
F P
s
P
p
.002 w
.37761 .28164 m .35312 .31508 L .37209 .30834 L p
1 g
F P
s
P
p
.002 w
.37209 .30834 m .39237 .28087 L .37761 .28164 L p
1 g
F P
s
P
p
.002 w
.49692 .24361 m .45881 .24627 L .45995 .25777 L p
1 g
F P
s
P
p
.002 w
.51247 .61991 m .56402 .60849 L .56217 .59715 L p
1 g
F P
s
P
p
.002 w
.56217 .59715 m .50691 .60937 L .51247 .61991 L p
1 g
F P
s
P
p
.002 w
.6129 .57348 m .56217 .59715 L .56402 .60849 L p
1 g
F P
s
P
p
.002 w
.46109 .61972 m .51247 .61991 L .50691 .60937 L p
1 g
F P
s
P
p
.002 w
.50691 .60937 m .45174 .60906 L .46109 .61972 L p
1 g
F P
s
P
p
.002 w
.30563 .40392 m .31369 .44984 L .32097 .42764 L p
1 g
F P
s
P
p
.002 w
.32097 .42764 m .31367 .38438 L .30563 .40392 L p
1 g
F P
s
P
p
.002 w
.60227 .26921 m .62634 .30294 L .64683 .31341 L p
1 g
F P
s
P
p
.002 w
.62634 .30294 m .60227 .26921 L .5819 .26677 L p
1 g
F P
s
P
p
.002 w
.6129 .57348 m .65465 .54015 L .65487 .52237 L p
1 g
F P
s
P
p
.002 w
.68467 .47993 m .65487 .52237 L .65465 .54015 L p
1 g
F P
s
P
p
.002 w
.65487 .52237 m .68467 .47993 L .68113 .45946 L p
1 g
F P
s
P
p
.002 w
.31385 .49412 m .34181 .53335 L .33881 .51143 L p
1 g
F P
s
P
p
.002 w
.33881 .51143 m .31122 .47219 L .31385 .49412 L p
1 g
F P
s
P
p
.002 w
.66398 .32738 m .67191 .37281 L .68508 .39156 L p
1 g
F P
s
P
p
.002 w
.67191 .37281 m .66398 .32738 L .64683 .31341 L p
1 g
F P
s
P
p
.002 w
.5819 .26677 m .5481 .24578 L .53205 .25149 L p
1 g
F P
s
P
p
.002 w
.49692 .24361 m .53205 .25149 L .5481 .24578 L p
1 g
F P
s
P
p
.002 w
.56402 .60849 m .61133 .58648 L .6129 .57348 L p
1 g
F P
s
P
p
.002 w
.65465 .54015 m .6129 .57348 L .61133 .58648 L p
1 g
F P
s
P
p
.002 w
.5481 .24578 m .5819 .26677 L .60227 .26921 L p
1 g
F P
s
P
p
.002 w
.69364 .41195 m .68113 .45946 L .68467 .47993 L p
1 g
F P
s
P
p
.002 w
.68113 .45946 m .69364 .41195 L .68508 .39156 L p
1 g
F P
s
P
p
.002 w
.41428 .25519 m .37761 .28164 L .39237 .28087 L p
1 g
F P
s
P
p
.002 w
.39237 .28087 m .42246 .25924 L .41428 .25519 L p
1 g
F P
s
P
p
.002 w
.36098 .57033 m .40147 .59586 L .39158 .58016 L p
1 g
F P
s
P
p
.002 w
.39158 .58016 m .34919 .5532 L .36098 .57033 L p
1 g
F P
s
P
p
.002 w
.41443 .6076 m .46109 .61972 L .45174 .60906 L p
1 g
F P
s
P
p
.002 w
.45174 .60906 m .40147 .59586 L .41443 .6076 L p
1 g
F P
s
P
p
.002 w
.32569 .33856 m .31367 .38438 L .32639 .3667 L p
1 g
F P
s
P
p
.002 w
.32639 .3667 m .33745 .32518 L .32569 .33856 L p
1 g
F P
s
P
p
.002 w
.36561 .28653 m .33745 .32518 L .35312 .31508 L p
1 g
F P
s
P
p
.002 w
.35312 .31508 m .37761 .28164 L .36561 .28653 L p
1 g
F P
s
P
p
.002 w
.5481 .24578 m .50533 .23609 L .49692 .24361 L p
1 g
F P
s
P
p
.002 w
.45881 .24627 m .49692 .24361 L .50533 .23609 L p
1 g
F P
s
P
p
.002 w
.30272 .42485 m .31122 .47219 L .31369 .44984 L p
1 g
F P
s
P
p
.002 w
.31369 .44984 m .30563 .40392 L .30272 .42485 L p
1 g
F P
s
P
p
.002 w
.62056 .27613 m .64683 .31341 L .66398 .32738 L p
1 g
F P
s
P
p
.002 w
.64683 .31341 m .62056 .27613 L .60227 .26921 L p
1 g
F P
s
P
p
.002 w
.45874 .2393 m .41428 .25519 L .42246 .25924 L p
1 g
F P
s
P
p
.002 w
.42246 .25924 m .45881 .24627 L .45874 .2393 L p
1 g
F P
s
P
p
.002 w
.32177 .51499 m .34919 .5532 L .34181 .53335 L p
1 g
F P
s
P
p
.002 w
.34181 .53335 m .31385 .49412 L .32177 .51499 L p
1 g
F P
s
P
p
.002 w
.50533 .23609 m .45874 .2393 L .45881 .24627 L p
1 g
F P
s
P
p
.002 w
.67718 .34464 m .68508 .39156 L .69364 .41195 L p
1 g
F P
s
P
p
.002 w
.68508 .39156 m .67718 .34464 L .66398 .32738 L p
1 g
F P
s
P
p
.002 w
.51792 .62572 m .56419 .61546 L .56402 .60849 L p
1 g
F P
s
P
p
.002 w
.56402 .60849 m .51247 .61991 L .51792 .62572 L p
1 g
F P
s
P
p
.002 w
.61133 .58648 m .56402 .60849 L .56419 .61546 L p
1 g
F P
s
P
p
.002 w
.61133 .58648 m .65021 .55561 L .65465 .54015 L p
1 g
F P
s
P
p
.002 w
.68329 .49974 m .65465 .54015 L .65021 .55561 L p
1 g
F P
s
P
p
.002 w
.65465 .54015 m .68329 .49974 L .68467 .47993 L p
1 g
F P
s
P
p
.002 w
.47188 .62559 m .51792 .62572 L .51247 .61991 L p
1 g
F P
s
P
p
.002 w
.51247 .61991 m .46109 .61972 L .47188 .62559 L p
1 g
F P
s
P
p
.002 w
.60227 .26921 m .56346 .24491 L .5481 .24578 L p
1 g
F P
s
P
p
.002 w
.50533 .23609 m .5481 .24578 L .56346 .24491 L p
1 g
F P
s
P
p
.002 w
.56346 .24491 m .60227 .26921 L .62056 .27613 L p
1 g
F P
s
P
p
.002 w
.69714 .43351 m .68467 .47993 L .68329 .49974 L p
1 g
F P
s
P
p
.002 w
.68467 .47993 m .69714 .43351 L .69364 .41195 L p
1 g
F P
s
P
p
.002 w
.56419 .61546 m .60665 .59575 L .61133 .58648 L p
1 g
F P
s
P
p
.002 w
.65021 .55561 m .61133 .58648 L .60665 .59575 L p
1 g
F P
s
P
p
.002 w
.31837 .35501 m .30563 .40392 L .31367 .38438 L p
1 g
F P
s
P
p
.002 w
.31367 .38438 m .32569 .33856 L .31837 .35501 L p
1 g
F P
s
P
p
.002 w
.37708 .58413 m .41443 .6076 L .40147 .59586 L p
1 g
F P
s
P
p
.002 w
.40147 .59586 m .36098 .57033 L .37708 .58413 L p
1 g
F P
s
P
p
.002 w
.40812 .25583 m .36561 .28653 L .37761 .28164 L p
1 g
F P
s
P
p
.002 w
.37761 .28164 m .41428 .25519 L .40812 .25583 L p
1 g
F P
s
P
p
.002 w
.43027 .61483 m .47188 .62559 L .46109 .61972 L p
1 g
F P
s
P
p
.002 w
.46109 .61972 m .41443 .6076 L .43027 .61483 L p
1 g
F P
s
P
p
.002 w
.30529 .44664 m .31385 .49412 L .31122 .47219 L p
1 g
F P
s
P
p
.002 w
.31122 .47219 m .30272 .42485 L .30529 .44664 L p
1 g
F P
s
P
p
.002 w
.3569 .29567 m .32569 .33856 L .33745 .32518 L p
1 g
F P
s
P
p
.002 w
.33745 .32518 m .36561 .28653 L .3569 .29567 L p
1 g
F P
s
P
p
.002 w
.63614 .2876 m .66398 .32738 L .67718 .34464 L p
1 g
F P
s
P
p
.002 w
.66398 .32738 m .63614 .2876 L .62056 .27613 L p
1 g
F P
s
P
p
.002 w
.33499 .53413 m .36098 .57033 L .34919 .5532 L p
1 g
F P
s
P
p
.002 w
.34919 .5532 m .32177 .51499 L .33499 .53413 L p
1 g
F P
s
P
p
.002 w
.56346 .24491 m .51396 .23363 L .50533 .23609 L p
1 g
F P
s
P
p
.002 w
.45874 .2393 m .50533 .23609 L .51396 .23363 L p
1 g
F P
s
P
p
.002 w
.69364 .41195 m .68586 .36487 L .67718 .34464 L p
1 g
F P
s
P
p
.002 w
.68586 .36487 m .69364 .41195 L .69714 .43351 L p
1 g
F P
s
P
p
.002 w
.45982 .23735 m .40812 .25583 L .41428 .25519 L p
1 g
F P
s
P
p
.002 w
.41428 .25519 m .45874 .2393 L .45982 .23735 L p
1 g
F P
s
P
p
.002 w
.60665 .59575 m .64142 .5682 L .65021 .55561 L p
1 g
F P
s
P
p
.002 w
.67676 .51833 m .65021 .55561 L .64142 .5682 L p
1 g
F P
s
P
p
.002 w
.65021 .55561 m .67676 .51833 L .68329 .49974 L p
1 g
F P
s
P
p
.002 w
.51396 .23363 m .45982 .23735 L .45874 .2393 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.66435 .53583 L
s
P
p
.004 w
.66436 .53584 m
.66556 .53661 L
s
P
p
.004 w
.69484 .55537 m
.75138 .59161 L
s
P
p
.002 w
.52311 .62633 m .56259 .61757 L .56419 .61546 L p
1 g
F P
s
P
p
.004 w
.55324 .62987 m
.55993 .65491 L
s
P
p
.002 w
.56419 .61546 m .51792 .62572 L .52311 .62633 L p
1 g
F P
s
P
p
.002 w
.60665 .59575 m .56419 .61546 L .56259 .61757 L p
1 g
F P
s
P
p
.002 w
.62056 .27613 m .57765 .24918 L .56346 .24491 L p
1 g
F P
s
P
p
.002 w
.57765 .24918 m .62056 .27613 L .63614 .2876 L p
1 g
F P
s
P
p
.002 w
.68329 .49974 m .69522 .4557 L .69714 .43351 L p
1 g
F P
s
P
p
.002 w
.69522 .4557 m .68329 .49974 L .67676 .51833 L p
1 g
F P
s
P
p
.002 w
.48392 .62623 m .52311 .62633 L .51792 .62572 L p
1 g
F P
s
P
p
.002 w
.51792 .62572 m .47188 .62559 L .48392 .62623 L p
1 g
F P
s
P
p
.002 w
.51396 .23363 m .56346 .24491 L .57765 .24918 L p
1 g
F P
s
P
p
.002 w
.31598 .37423 m .30272 .42485 L .30563 .40392 L p
1 g
F P
s
P
p
.002 w
.30563 .40392 m .31837 .35501 L .31598 .37423 L p
1 g
F P
s
P
p
.002 w
.56259 .61757 m .59877 .60078 L .60665 .59575 L p
1 g
F P
s
P
p
.002 w
.64142 .5682 m .60665 .59575 L .59877 .60078 L p
1 g
F P
s
P
p
.002 w
.39722 .594 m .43027 .61483 L .41443 .6076 L p
1 g
F P
s
P
p
.002 w
.41443 .6076 m .37708 .58413 L .39722 .594 L p
1 g
F P
s
P
p
.002 w
.31354 .46869 m .32177 .51499 L .31385 .49412 L p
1 g
F P
s
P
p
.002 w
.31385 .49412 m .30529 .44664 L .31354 .46869 L p
1 g
F P
s
P
p
.002 w
.67718 .34464 m .64843 .30351 L .63614 .2876 L p
1 g
F P
s
P
p
.002 w
.64843 .30351 m .67718 .34464 L .68586 .36487 L p
1 g
F P
s
P
p
.002 w
.4043 .26146 m .3569 .29567 L .36561 .28653 L p
1 g
F P
s
P
p
.002 w
.36561 .28653 m .40812 .25583 L .4043 .26146 L p
1 g
F P
s
P
p
.002 w
.35193 .30904 m .31837 .35501 L .32569 .33856 L p
1 g
F P
s
P
p
.002 w
.32569 .33856 m .3569 .29567 L .35193 .30904 L p
1 g
F P
s
P
p
.002 w
.44869 .61709 m .48392 .62623 L .47188 .62559 L p
1 g
F P
s
P
p
.002 w
.47188 .62559 m .43027 .61483 L .44869 .61709 L p
1 g
F P
s
P
p
.002 w
.68955 .38763 m .69714 .43351 L .69522 .4557 L p
1 g
F P
s
P
p
.002 w
.69714 .43351 m .68955 .38763 L .68586 .36487 L p
1 g
F P
s
P
p
.002 w
.35337 .55089 m .37708 .58413 L .36098 .57033 L p
1 g
F P
s
P
p
.002 w
.36098 .57033 m .33499 .53413 L .35337 .55089 L p
1 g
F P
s
P
p
.002 w
.57765 .24918 m .52256 .23664 L .51396 .23363 L p
1 g
F P
s
P
p
.002 w
.45982 .23735 m .51396 .23363 L .52256 .23664 L p
1 g
F P
s
P
p
.002 w
.59877 .60078 m .62829 .57739 L .64142 .5682 L p
1 g
F P
s
P
p
.002 w
.64142 .5682 m .66501 .5351 L .67676 .51833 L p
1 g
F P
s
P
p
.002 w
.66501 .5351 m .64142 .5682 L .62829 .57739 L p
1 g
F P
s
P
p
.004 w
.66556 .53661 m
.69484 .55537 L
s
P
p
.002 w
.59019 .25877 m .63614 .2876 L .64843 .30351 L p
1 g
F P
s
P
p
.002 w
.63614 .2876 m .59019 .25877 L .57765 .24918 L p
1 g
F P
s
P
p
.002 w
.68768 .47789 m .67676 .51833 L .66501 .5351 L p
1 g
F P
s
P
p
.002 w
.67676 .51833 m .68768 .47789 L .69522 .4557 L p
1 g
F P
s
P
p
.002 w
.46209 .24082 m .4043 .26146 L .40812 .25583 L p
1 g
F P
s
P
p
.002 w
.40812 .25583 m .45982 .23735 L .46209 .24082 L p
1 g
F P
s
P
p
.002 w
.31885 .39577 m .30529 .44664 L .30272 .42485 L p
1 g
F P
s
P
p
.002 w
.30272 .42485 m .31598 .37423 L .31885 .39577 L p
1 g
F P
s
P
p
.002 w
.52256 .23664 m .46209 .24082 L .45982 .23735 L p
1 g
F P
s
P
p
.002 w
.52256 .23664 m .57765 .24918 L .59019 .25877 L p
1 g
F P
s
P
p
.002 w
.52786 .62138 m .55912 .61445 L .56259 .61757 L p
1 g
F P
s
P
p
.002 w
.56259 .61757 m .52311 .62633 L .52786 .62138 L p
1 g
F P
s
P
p
.002 w
.59877 .60078 m .56259 .61757 L .55912 .61445 L p
1 g
F P
s
P
p
.002 w
.32748 .4903 m .33499 .53413 L .32177 .51499 L p
1 g
F P
s
P
p
.002 w
.32177 .51499 m .31354 .46869 L .32748 .4903 L p
1 g
F P
s
P
p
.002 w
.49691 .62127 m .52786 .62138 L .52311 .62633 L p
1 g
F P
s
P
p
.002 w
.52311 .62633 m .48392 .62623 L .49691 .62127 L p
1 g
F P
s
P
p
.002 w
.65688 .32363 m .68586 .36487 L .68955 .38763 L p
1 g
F P
s
P
p
.002 w
.68586 .36487 m .65688 .32363 L .64843 .30351 L p
1 g
F P
s
P
p
.002 w
.42098 .59947 m .44869 .61709 L .43027 .61483 L p
1 g
F P
s
P
p
.002 w
.43027 .61483 m .39722 .594 L .42098 .59947 L p
1 g
F P
s
P
p
.002 w
.55912 .61445 m .58774 .60115 L .59877 .60078 L p
1 g
F P
s
P
p
.002 w
.62829 .57739 m .59877 .60078 L .58774 .60115 L p
1 g
F P
s
P
p
.002 w
.68789 .41233 m .69522 .4557 L .68768 .47789 L p
1 g
F P
s
P
p
.002 w
.69522 .4557 m .68789 .41233 L .68955 .38763 L p
1 g
F P
s
P
p
.002 w
.37655 .56462 m .39722 .594 L .37708 .58413 L p
1 g
F P
s
P
p
.002 w
.37708 .58413 m .35337 .55089 L .37655 .56462 L p
1 g
F P
s
P
p
.002 w
.35108 .32648 m .31598 .37423 L .31837 .35501 L p
1 g
F P
s
P
p
.002 w
.31837 .35501 m .35193 .30904 L .35108 .32648 L p
1 g
F P
s
P
p
.002 w
.4031 .27224 m .35193 .30904 L .3569 .29567 L p
1 g
F P
s
P
p
.002 w
.3569 .29567 m .4043 .26146 L .4031 .27224 L p
1 g
F P
s
P
p
.002 w
.46927 .61401 m .49691 .62127 L .48392 .62623 L p
1 g
F P
s
P
p
.002 w
.48392 .62623 m .44869 .61709 L .46927 .61401 L p
1 g
F P
s
P
p
.002 w
.32716 .41904 m .31354 .46869 L .30529 .44664 L p
1 g
F P
s
P
p
.002 w
.30529 .44664 m .31885 .39577 L .32716 .41904 L p
1 g
F P
s
P
p
.002 w
.62829 .57739 m .6481 .54943 L .66501 .5351 L p
1 g
F P
s
P
p
.002 w
.67449 .49939 m .66501 .5351 L .6481 .54943 L p
1 g
F P
s
P
p
.002 w
.66501 .5351 m .67449 .49939 L .68768 .47789 L p
1 g
F P
s
P
p
.002 w
.60061 .27371 m .64843 .30351 L .65688 .32363 L p
1 g
F P
s
P
p
.002 w
.64843 .30351 m .60061 .27371 L .59019 .25877 L p
1 g
F P
s
P
p
.002 w
.59019 .25877 m .53088 .24538 L .52256 .23664 L p
1 g
F P
s
P
p
.002 w
.46209 .24082 m .52256 .23664 L .53088 .24538 L p
1 g
F P
s
P
p
.002 w
.58774 .60115 m .61094 .58269 L .62829 .57739 L p
1 g
F P
s
P
p
.002 w
.6481 .54943 m .62829 .57739 L .61094 .58269 L p
1 g
F P
s
P
p
.002 w
.3469 .51074 m .35337 .55089 L .33499 .53413 L p
1 g
F P
s
P
p
.002 w
.33499 .53413 m .32748 .4903 L .3469 .51074 L p
1 g
F P
s
P
p
.002 w
.66103 .34754 m .68955 .38763 L .68789 .41233 L p
1 g
F P
s
P
p
.002 w
.68955 .38763 m .66103 .34754 L .65688 .32363 L p
1 g
F P
s
P
p
.002 w
.46557 .24996 m .4031 .27224 L .4043 .26146 L p
1 g
F P
s
P
p
.002 w
.4043 .26146 m .46209 .24082 L .46557 .24996 L p
1 g
F P
s
P
p
.002 w
.53088 .24538 m .59019 .25877 L .60061 .27371 L p
1 g
F P
s
P
p
.002 w
.6807 .43828 m .68768 .47789 L .67449 .49939 L p
1 g
F P
s
P
p
.002 w
.68768 .47789 m .6807 .43828 L .68789 .41233 L p
1 g
F P
s
P
p
.002 w
.44776 .60013 m .46927 .61401 L .44869 .61709 L p
1 g
F P
s
P
p
.002 w
.44869 .61709 m .42098 .59947 L .44776 .60013 L p
1 g
F P
s
P
p
.002 w
.53088 .24538 m .46557 .24996 L .46209 .24082 L p
1 g
F P
s
P
p
.002 w
.53202 .61065 m .55379 .60583 L .55912 .61445 L p
1 g
F P
s
P
p
.002 w
.55912 .61445 m .52786 .62138 L .53202 .61065 L p
1 g
F P
s
P
p
.002 w
.58774 .60115 m .55912 .61445 L .55379 .60583 L p
1 g
F P
s
P
p
.002 w
.40398 .57475 m .42098 .59947 L .39722 .594 L p
1 g
F P
s
P
p
.002 w
.39722 .594 m .37655 .56462 L .40398 .57475 L p
1 g
F P
s
P
p
.002 w
.51051 .61054 m .53202 .61065 L .52786 .62138 L p
1 g
F P
s
P
p
.002 w
.52786 .62138 m .49691 .62127 L .51051 .61054 L p
1 g
F P
s
P
p
.002 w
.35463 .34766 m .31885 .39577 L .31598 .37423 L p
1 g
F P
s
P
p
.002 w
.31598 .37423 m .35108 .32648 L .35463 .34766 L p
1 g
F P
s
P
p
.002 w
.55379 .60583 m .57369 .59656 L .58774 .60115 L p
1 g
F P
s
P
p
.002 w
.61094 .58269 m .58774 .60115 L .57369 .59656 L p
1 g
F P
s
P
p
.002 w
.40471 .28814 m .35108 .32648 L .35193 .30904 L p
1 g
F P
s
P
p
.002 w
.35193 .30904 m .4031 .27224 L .40471 .28814 L p
1 g
F P
s
P
p
.002 w
.49144 .60543 m .51051 .61054 L .49691 .62127 L p
1 g
F P
s
P
p
.002 w
.49691 .62127 m .46927 .61401 L .49144 .60543 L p
1 g
F P
s
P
p
.002 w
.34089 .44333 m .32748 .4903 L .31354 .46869 L p
1 g
F P
s
P
p
.002 w
.31354 .46869 m .32716 .41904 L .34089 .44333 L p
1 g
F P
s
P
p
.002 w
.61094 .58269 m .62633 .56075 L .6481 .54943 L p
1 g
F P
s
P
p
.002 w
.65582 .51948 m .6481 .54943 L .62633 .56075 L p
1 g
F P
s
P
p
.002 w
.6481 .54943 m .65582 .51948 L .67449 .49939 L p
1 g
F P
s
P
p
.002 w
.60844 .29381 m .65688 .32363 L .66103 .34754 L p
1 g
F P
s
P
p
.002 w
.65688 .32363 m .60844 .29381 L .60061 .27371 L p
1 g
F P
s
P
p
.002 w
.37135 .52928 m .37655 .56462 L .35337 .55089 L p
1 g
F P
s
P
p
.002 w
.35337 .55089 m .3469 .51074 L .37135 .52928 L p
1 g
F P
s
P
p
.002 w
.66053 .37461 m .68789 .41233 L .6807 .43828 L p
1 g
F P
s
P
p
.002 w
.68789 .41233 m .66053 .37461 L .66103 .34754 L p
1 g
F P
s
P
p
.002 w
.57369 .59656 m .58971 .58372 L .61094 .58269 L p
1 g
F P
s
P
p
.002 w
.62633 .56075 m .61094 .58269 L .58971 .58372 L p
1 g
F P
s
P
p
.002 w
.60061 .27371 m .53862 .25993 L .53088 .24538 L p
1 g
F P
s
P
p
.002 w
.46557 .24996 m .53088 .24538 L .53862 .25993 L p
1 g
F P
s
P
p
.002 w
.66797 .46467 m .67449 .49939 L .65582 .51948 L p
1 g
F P
s
P
p
.002 w
.67449 .49939 m .66797 .46467 L .6807 .43828 L p
1 g
F P
s
P
p
.002 w
.43486 .5808 m .44776 .60013 L .42098 .59947 L p
1 g
F P
s
P
p
.002 w
.42098 .59947 m .40398 .57475 L .43486 .5808 L p
1 g
F P
s
P
p
.002 w
.53862 .25993 m .60061 .27371 L .60844 .29381 L p
1 g
F P
s
P
p
.002 w
.47679 .59577 m .49144 .60543 L .46927 .61401 L p
1 g
F P
s
P
p
.002 w
.46927 .61401 m .44776 .60013 L .47679 .59577 L p
1 g
F P
s
P
p
.002 w
.47021 .26483 m .40471 .28814 L .4031 .27224 L p
1 g
F P
s
P
p
.002 w
.4031 .27224 m .46557 .24996 L .47021 .26483 L p
1 g
F P
s
P
p
.002 w
.36267 .37203 m .32716 .41904 L .31885 .39577 L p
1 g
F P
s
P
p
.002 w
.31885 .39577 m .35463 .34766 L .36267 .37203 L p
1 g
F P
s
P
p
.002 w
.53862 .25993 m .47021 .26483 L .46557 .24996 L p
1 g
F P
s
P
p
.002 w
.53538 .59415 m .54664 .59166 L .55379 .60583 L p
1 g
F P
s
P
p
.002 w
.55379 .60583 m .53202 .61065 L .53538 .59415 L p
1 g
F P
s
P
p
.002 w
.57369 .59656 m .55379 .60583 L .54664 .59166 L p
1 g
F P
s
P
p
.002 w
.5243 .59405 m .53538 .59415 L .53202 .61065 L p
1 g
F P
s
P
p
.002 w
.53202 .61065 m .51051 .61054 L .5243 .59405 L p
1 g
F P
s
P
p
.002 w
.35975 .46783 m .3469 .51074 L .32748 .4903 L p
1 g
F P
s
P
p
.002 w
.32748 .4903 m .34089 .44333 L .35975 .46783 L p
1 g
F P
s
P
p
.002 w
.40013 .5452 m .40398 .57475 L .37655 .56462 L p
1 g
F P
s
P
p
.002 w
.37655 .56462 m .37135 .52928 L .40013 .5452 L p
1 g
F P
s
P
p
.002 w
.54664 .59166 m .5569 .58685 L .57369 .59656 L p
1 g
F P
s
P
p
.002 w
.58971 .58372 m .57369 .59656 L .5569 .58685 L p
1 g
F P
s
P
p
.002 w
.40925 .30892 m .35463 .34766 L .35108 .32648 L p
1 g
F P
s
P
p
.002 w
.35108 .32648 m .40471 .28814 L .40925 .30892 L p
1 g
F P
s
P
p
.002 w
.58971 .58372 m .60018 .56856 L .62633 .56075 L p
1 g
F P
s
P
p
.002 w
.63206 .53745 m .62633 .56075 L .60018 .56856 L p
1 g
F P
s
P
p
.002 w
.62633 .56075 m .63206 .53745 L .65582 .51948 L p
1 g
F P
s
P
p
.002 w
.61329 .31866 m .66103 .34754 L .66053 .37461 L p
1 g
F P
s
P
p
.002 w
.66103 .34754 m .61329 .31866 L .60844 .29381 L p
1 g
F P
s
P
p
.002 w
.6552 .40405 m .6807 .43828 L .66797 .46467 L p
1 g
F P
s
P
p
.002 w
.6807 .43828 m .6552 .40405 L .66053 .37461 L p
1 g
F P
s
P
p
.002 w
.51455 .59137 m .5243 .59405 L .51051 .61054 L p
1 g
F P
s
P
p
.002 w
.51051 .61054 m .49144 .60543 L .51455 .59137 L p
1 g
F P
s
P
p
.002 w
.64995 .49061 m .65582 .51948 L .63206 .53745 L p
1 g
F P
s
P
p
.002 w
.65582 .51948 m .64995 .49061 L .66797 .46467 L p
1 g
F P
s
P
p
.002 w
.5569 .58685 m .5651 .58022 L .58971 .58372 L p
1 g
F P
s
P
p
.002 w
.60018 .56856 m .58971 .58372 L .5651 .58022 L p
1 g
F P
s
P
p
.002 w
.46823 .58244 m .47679 .59577 L .44776 .60013 L p
1 g
F P
s
P
p
.002 w
.44776 .60013 m .43486 .5808 L .46823 .58244 L p
1 g
F P
s
P
p
.002 w
.50716 .58636 m .51455 .59137 L .49144 .60543 L p
1 g
F P
s
P
p
.002 w
.49144 .60543 m .47679 .59577 L .50716 .58636 L p
1 g
F P
s
P
p
.002 w
.60844 .29381 m .54549 .28013 L .53862 .25993 L p
1 g
F P
s
P
p
.002 w
.47021 .26483 m .53862 .25993 L .54549 .28013 L p
1 g
F P
s
P
p
.002 w
.54549 .28013 m .60844 .29381 L .61329 .31866 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.43233 .55787 m .43486 .5808 L .40398 .57475 L p
1 g
F P
s
P
p
.002 w
.40398 .57475 m .40013 .5452 L .43233 .55787 L p
1 g
F P
s
P
p
.002 w
.37513 .39887 m .34089 .44333 L .32716 .41904 L p
1 g
F P
s
P
p
.002 w
.32716 .41904 m .36267 .37203 L .37513 .39887 L p
1 g
F P
s
P
p
.002 w
.38326 .49165 m .37135 .52928 L .3469 .51074 L p
1 g
F P
s
P
p
.002 w
.3469 .51074 m .35975 .46783 L .38326 .49165 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52946 .54083 L
s
P
p
.002 w
.64508 .4349 m .66797 .46467 L .64995 .49061 L p
1 g
F P
s
P
p
.002 w
.66797 .46467 m .64508 .4349 L .6552 .40405 L p
1 g
F P
s
P
p
.002 w
.47592 .28527 m .40925 .30892 L .40471 .28814 L p
1 g
F P
s
P
p
.002 w
.40471 .28814 m .47021 .26483 L .47592 .28527 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.5651 .58022 m .57036 .57243 L .60018 .56856 L p
1 g
F P
s
P
p
.002 w
.60386 .55259 m .60018 .56856 L .57036 .57243 L p
1 g
F P
s
P
p
.002 w
.60018 .56856 m .60386 .55259 L .63206 .53745 L p
1 g
F P
s
P
p
.002 w
.61483 .3476 m .66053 .37461 L .6552 .40405 L p
1 g
F P
s
P
p
.002 w
.66053 .37461 m .61483 .3476 L .61329 .31866 L p
1 g
F P
s
P
p
.002 w
.62712 .51519 m .63206 .53745 L .60386 .55259 L p
1 g
F P
s
P
p
.002 w
.63206 .53745 m .62712 .51519 L .64995 .49061 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.54549 .28013 m .47592 .28527 L .47021 .26483 L p
1 g
F P
s
P
p
.002 w
.54664 .59166 m .53538 .59415 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.5569 .58685 m .54664 .59166 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.53538 .59415 m .5243 .59405 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.41671 .3341 m .36267 .37203 L .35463 .34766 L p
1 g
F P
s
P
p
.002 w
.35463 .34766 m .40925 .30892 L .41671 .3341 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.50716 .58636 m .47679 .59577 L p
.50024 .58121 L 1 g
F P
s
P
p
.002 w
.50409 .58138 m .50716 .58636 L p
.50024 .58121 L 1 g
F P
s
P
p
.51079 .57862 m .49829 .58112 L .50409 .58138 L 1 g
F
P
p
.002 w
.52051 .58014 m .50716 .58636 L .50486 .58263 L p
1 g
F P
s
P
p
.002 w
.50486 .58263 m .50409 .58138 L p
.51096 .58086 L 1 g
F P
s
P
p
.50486 .58263 m .51096 .58086 L .52051 .58014 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58086 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58086 L .52088 .57798 L 1 g
F
P
p
.002 w
.51096 .58086 m .51079 .57862 L p
.50409 .58138 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.47679 .59577 m .46823 .58244 L .48899 .5807 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .5807 L p
1 g
F P
s
P
p
.51079 .57862 m .48906 .5807 L .49829 .58112 L 1 g
F
P
p
.002 w
.48899 .5807 m .48903 .58069 L p
.48906 .5807 L 1 g
F P
s
P
p
.47679 .59577 m .48899 .5807 L .50024 .58121 L 1 g
F
P
p
.002 w
.48903 .58069 m .46823 .58244 L p
.48087 .57842 L 1 g
F P
s
P
p
.002 w
.48906 .5807 m .48921 .57862 L p
.47837 .57773 L 1 g
F P
s
P
p
.002 w
.46823 .58244 m .46755 .57472 L p
.46823 .57491 L 1 g
F P
s
P
p
.47694 .57967 m .46823 .57491 L .48087 .57842 L 1 g
F
P
p
.46823 .58244 m .46823 .57491 L .47694 .57967 L 1 g
F
P
p
.002 w
.46823 .57491 m .46872 .57265 L p
.45924 .56886 L 1 g
F P
s
P
p
.002 w
.46823 .58244 m .43486 .5808 L p
.45783 .57073 L 1 g
F P
s
P
p
.45783 .57073 m .46035 .56962 L .46211 .57249 L 1 g
F
P
p
.45783 .57073 m .46211 .57249 L .46823 .58244 L 1 g
F
P
p
.002 w
.46753 .57453 m .46755 .57472 L p
.46035 .56962 L 1 g
F P
s
P
p
.002 w
.46755 .57472 m .46823 .58244 L p
.46211 .57249 L 1 g
F P
s
P
p
.46035 .56962 m .46755 .57472 L .46211 .57249 L 1 g
F
P
p
.002 w
.4678 .57686 m .46687 .58109 L p
.4874 .58287 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .48485 .58182 L p
.4874 .58287 L 1 g
F P
s
P
p
.002 w
.48485 .58182 m .4678 .57686 L p
.4874 .58287 L 1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48885 .58347 L p
1 g
F P
s
P
p
.002 w
.48885 .58347 m .48889 .583 L p
.4874 .58287 L 1 g
F P
s
P
p
.4874 .58287 m .46687 .58109 L .48885 .58347 L 1 g
F
P
p
.45924 .56886 m .46753 .57453 L .46823 .57491 L 1 g
F
P
p
.002 w
.43486 .5808 m .43233 .55787 L .44971 .56235 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.43486 .5808 m .44971 .56235 L .45079 .56309 L 1 g
F
P
p
.45769 .57079 m .45079 .56309 L .46035 .56962 L 1 g
F
P
p
.43486 .5808 m .45079 .56309 L .45769 .57079 L 1 g
F
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44491 .5556 L 1 g
F P
s
P
p
.002 w
.45026 .56249 m .43233 .55787 L p
.44489 .55558 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43233 .55787 m .43685 .54522 L p
.43842 .54723 L 1 g
F P
s
P
p
.4417 .55616 m .43842 .54723 L .44489 .55558 L 1 g
F
P
p
.43233 .55787 m .43842 .54723 L .4417 .55616 L 1 g
F
P
p
.002 w
.43842 .54723 m .43925 .54566 L p
.43534 .53793 L 1 g
F P
s
P
p
.002 w
.43233 .55787 m .40013 .5452 L p
.4346 .53554 L 1 g
F P
s
P
p
.002 w
.43726 .54408 m .43233 .55787 L p
.4346 .53554 L 1 g
F P
s
P
p
.002 w
.40013 .5452 m .41064 .51392 L .43228 .5281 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.40013 .5452 m .43228 .5281 L .43249 .52876 L 1 g
F
P
p
.43229 .53619 m .43249 .52876 L .4346 .53554 L 1 g
F
P
p
.40013 .5452 m .43249 .52876 L .43229 .53619 L 1 g
F
P
p
.002 w
.43249 .52876 m .43346 .52734 L p
.43322 .5203 L 1 g
F P
s
P
p
.002 w
.4325 .52824 m .41064 .51392 L p
.4339 .51268 L 1 g
F P
s
P
p
.002 w
.41064 .51392 m .43499 .48457 L .4363 .48597 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.41064 .51392 m .4363 .48597 L .43423 .50899 L 1 g
F
P
p
.43246 .51276 m .43423 .50899 L .4339 .51268 L 1 g
F
P
p
.41064 .51392 m .43423 .50899 L .43246 .51276 L 1 g
F
P
p
.002 w
.43423 .50899 m .43485 .50826 L p
.4375 .50206 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43423 .50899 L p
1 g
F P
s
P
p
.002 w
.43423 .50899 m .43287 .51061 L p
.43322 .5203 L 1 g
F P
s
P
p
.43346 .52734 m .43423 .50899 L .43322 .5203 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44256 .49138 L p
1 g
F P
s
P
p
.43485 .50826 m .44256 .49138 L .44229 .49193 L 1 g
F
P
p
.43485 .50826 m .44251 .49143 L .4375 .50206 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.48787 .49318 m .46011 .51128 L .44216 .49219 L p
1 g
F P
s
P
p
.002 w
.44216 .49219 m .44195 .49197 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44256 .49138 m .44339 .4905 L p
.44914 .48499 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44256 .49138 m .48787 .49318 L .44216 .49219 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45782 .47657 L p
1 g
F P
s
P
p
.44339 .4905 m .45782 .47657 L .44914 .48499 L 1 g
F
P
p
.44515 .48623 m .44748 .48661 L .44256 .49138 L 1 g
F
P
p
.44748 .48661 m .48787 .49318 L .44256 .49138 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47479 .46856 m .48787 .49318 L p
.43933 .48528 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47755 .46718 L p
1 g
F P
s
P
p
.002 w
.52097 .48178 m .48787 .49318 L .47479 .46856 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.47755 .46718 m .52097 .48178 L .47479 .46856 L 1 g
F
P
p
.002 w
.47755 .46718 m .47786 .46667 L p
.4868 .46576 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46373 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46373 L .4868 .46576 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47073 .4609 m .47429 .45967 L p
.52097 .48178 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46713 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54231 .4767 L p
1 g
F P
s
P
p
.52214 .46667 m .54231 .4767 L .53109 .4713 L 1 g
F
P
p
.52242 .46713 m .52784 .46974 L .51781 .46654 L 1 g
F
P
p
.002 w
.52097 .48178 m .51781 .46654 L p
.52784 .46974 L 1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50935 L p
1 g
F P
s
P
p
.002 w
.57227 .5165 m .56929 .51604 L p
.56607 .50935 L 1 g
F P
s
P
p
.56115 .49916 m .56573 .5063 L .56607 .50935 L 1 g
F
P
p
.56573 .5063 m .57227 .5165 L .56607 .50935 L 1 g
F
P
p
.002 w
.56607 .50935 m .56515 .50826 L p
.56705 .52059 L 1 g
F P
s
P
p
.56705 .52059 m .56698 .5193 L .56607 .50935 L 1 g
F
P
p
.002 w
.56677 .51565 m .57227 .5165 L .56733 .52541 L p
1 g
F P
s
P
p
.56716 .52129 m .56702 .51794 L .56607 .50935 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.57227 .5165 m .56776 .53597 L .56746 .52869 L 1 g
F
P
p
.002 w
.56733 .52541 m .56978 .52099 L p
.56746 .52869 L 1 g
F P
s
P
p
.002 w
.56978 .52099 m .57227 .5165 L p
.56746 .52869 L 1 g
F P
s
P
p
.002 w
.56746 .52869 m .56654 .52734 L p
.56449 .53858 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56746 .52869 L p
1 g
F P
s
P
p
.002 w
.56746 .52869 m .56854 .53025 L p
.56716 .52129 L 1 g
F P
s
P
p
.56515 .50826 m .56746 .52869 L .56716 .52129 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54922 .56312 L p
1 g
F P
s
P
p
.002 w
.57005 .5567 m .5444 .56894 L p
.55618 .55807 L 1 g
F P
s
P
p
.002 w
.56441 .55046 m .56529 .55144 L p
.55618 .55807 L 1 g
F P
s
P
p
.002 w
.56529 .55144 m .57005 .5567 L p
.55618 .55807 L 1 g
F P
s
P
p
.002 w
.54922 .56312 m .54854 .56129 L p
.53831 .57104 L 1 g
F P
s
P
p
.53831 .57104 m .53873 .57074 L .54922 .56312 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53876 .57072 m .53781 .57209 L .53803 .57124 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53176 .57483 L p
1 g
F P
s
P
p
.54854 .56129 m .53176 .57483 L .53603 .57247 L 1 g
F
P
p
.54854 .56129 m .53603 .57247 L .53673 .57207 L 1 g
F
P
p
.54854 .56129 m .53673 .57207 L .53692 .57196 L 1 g
F
P
p
.54854 .56129 m .53691 .57197 L .53708 .57187 L 1 g
F
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.50244 .57157 m .50573 .56336 L .53705 .57188 L p
1 g
F P
s
P
p
.002 w
.53705 .57188 m .53781 .57209 L .53673 .57207 L p
1 g
F P
s
P
p
.002 w
.53673 .57207 m .50244 .57157 L p
.53705 .57188 L 1 g
F P
s
P
p
.53692 .57196 m .53673 .57207 L .53691 .57197 L 1 g
F
P
p
.53708 .57187 m .53691 .57197 L .53705 .57189 L 1 g
F
P
p
.54854 .56129 m .53705 .57189 L .5372 .57179 L 1 g
F
P
p
.54854 .56129 m .53717 .57182 L .53824 .57111 L 1 g
F
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50573 .56336 m .51251 .5558 L .53728 .57174 L p
1 g
F P
s
P
p
.002 w
.53728 .57174 m .53781 .57209 L .53705 .57188 L p
1 g
F P
s
P
p
.002 w
.53705 .57188 m .50573 .56336 L p
.53728 .57174 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.51251 .5558 m .52205 .54976 L .53748 .57162 L p
1 g
F P
s
P
p
.002 w
.53748 .57162 m .53781 .57209 L .53728 .57174 L p
1 g
F P
s
P
p
.002 w
.53728 .57174 m .51251 .5558 L p
.53748 .57162 L 1 g
F P
s
P
p
.5372 .57179 m .53705 .57189 L .53717 .57182 L 1 g
F
P
p
.002 w
.53803 .57124 m .53781 .57209 L .5377 .57147 L p
1 g
F P
s
P
p
.53824 .57111 m .53717 .57182 L .53796 .57138 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52205 .54976 m .53329 .54592 L .5377 .57147 L p
1 g
F P
s
P
p
.002 w
.5377 .57147 m .53781 .57209 L .53748 .57162 L p
1 g
F P
s
P
p
.002 w
.53748 .57162 m .52205 .54976 L p
.5377 .57147 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.53329 .54592 m .54496 .54473 L .53803 .57124 L p
1 g
F P
s
P
p
.002 w
.5377 .57147 m .53329 .54592 L p
.53803 .57124 L 1 g
F P
s
P
p
.53796 .57138 m .53728 .57176 L .5379 .57143 L 1 g
F
P
p
.53728 .57176 m .53603 .57247 L .53718 .57183 L 1 g
F
P
p
.53728 .57176 m .53718 .57183 L .5379 .57143 L 1 g
F
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.52051 .58014 m .51421 .57992 L .53053 .57519 L 1 g
F
P
p
.002 w
.53603 .57247 m .53781 .57209 L .5309 .57531 L p
1 g
F P
s
P
p
.002 w
.53176 .57483 m .53128 .57265 L p
.52088 .57798 L 1 g
F P
s
P
p
.002 w
.5309 .57531 m .52051 .58014 L p
.53603 .57247 L 1 g
F P
s
P
p
.002 w
.50409 .58138 m .50295 .57952 L p
.52051 .58014 L 1 g
F P
s
P
p
.002 w
.5243 .59405 m .51455 .59137 L .53601 .57358 L p
1 g
F P
s
P
p
.002 w
.53601 .57358 m .53781 .57209 L .5371 .57324 L p
1 g
F P
s
P
p
.002 w
.5371 .57324 m .5243 .59405 L p
.53601 .57358 L 1 g
F P
s
P
p
.002 w
.53781 .57209 m .51455 .59137 L .5088 .58747 L p
1 g
F P
s
P
p
.002 w
.5088 .58747 m .50716 .58636 L .5309 .57531 L p
1 g
F P
s
P
p
.002 w
.5309 .57531 m .53781 .57209 L p
.5088 .58747 L 1 g
F P
s
P
p
.002 w
.53176 .57483 m .53176 .57483 L p
.5379 .57143 L 1 g
F P
s
P
p
.002 w
.53673 .57207 m .53781 .57209 L .53603 .57247 L p
1 g
F P
s
P
p
.002 w
.53176 .57483 m .5322 .57686 L p
.53785 .57147 L 1 g
F P
s
P
p
.5379 .57143 m .53176 .57483 L .53785 .57147 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53177 .57488 L p
1 g
F P
s
P
p
.002 w
.53177 .57488 m .53176 .57483 L p
.53115 .57507 L 1 g
F P
s
P
p
.53115 .57507 m .51111 .583 L .53177 .57488 L 1 g
F
P
p
.52088 .57798 m .51111 .583 L .53176 .57483 L 1 g
F
P
p
.002 w
.50295 .57952 m .53603 .57247 L p
.53053 .57519 L 1 g
F P
s
P
p
.51421 .57992 m .50295 .57952 L .53053 .57519 L 1 g
F
P
p
.002 w
.50295 .57952 m .50244 .57157 L .53673 .57207 L p
1 g
F P
s
P
p
.002 w
.53603 .57247 m .50295 .57952 L p
.53673 .57207 L 1 g
F P
s
P
p
.002 w
.54496 .54473 m .55573 .54631 L .53876 .57072 L p
1 g
F P
s
P
p
.002 w
.53803 .57124 m .54496 .54473 L p
.53876 .57072 L 1 g
F P
s
P
p
.53831 .57104 m .53829 .57106 L .53873 .57074 L 1 g
F
P
p
.002 w
.54554 .5658 m .53781 .57209 L .53876 .57072 L p
1 g
F P
s
P
p
.53829 .57106 m .53822 .57113 L .54554 .5658 L 1 g
F
P
p
.53829 .57106 m .54554 .5658 L .54922 .56312 L 1 g
F
P
p
.002 w
.56098 .54882 m .56441 .55046 L .55002 .56216 L p
1 g
F P
s
P
p
.002 w
.55002 .56216 m .56441 .55046 L p
.5444 .56894 L 1 g
F P
s
P
p
.55488 .55629 m .55002 .56216 L .54998 .56518 L 1 g
F
P
p
.002 w
.54922 .56312 m .54922 .56313 L p
.55002 .56216 L 1 g
F P
s
P
p
.002 w
.54922 .56313 m .54998 .56518 L p
.55002 .56216 L 1 g
F P
s
P
p
.56075 .54566 m .54922 .56312 L .55488 .55629 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .55194 .56268 L p
.56075 .54566 L 1 g
F P
s
P
p
.002 w
.56441 .55046 m .56135 .549 L p
.56539 .54205 L 1 g
F P
s
P
p
.002 w
.56135 .549 m .56098 .54882 L p
.56178 .5476 L 1 g
F P
s
P
p
.56539 .54205 m .56135 .549 L .56178 .5476 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56178 .5476 L p
1 g
F P
s
P
p
.56654 .52734 m .56178 .5476 L .56449 .53858 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55573 .54631 m .56733 .52541 L p
.56539 .54205 L 1 g
F P
s
P
p
.002 w
.56178 .5476 m .56075 .54566 L p
.55194 .56268 L 1 g
F P
s
P
p
.002 w
.56098 .54882 m .55573 .54631 L p
.56539 .54205 L 1 g
F P
s
P
p
.002 w
.56178 .5476 m .56257 .5491 L p
.56449 .53858 L 1 g
F P
s
P
p
.002 w
.55194 .56268 m .56257 .5491 L .56178 .5476 L p
1 g
F P
s
P
p
.002 w
.55573 .54631 m .56098 .54882 L p
.54554 .5658 L 1 g
F P
s
P
p
.002 w
.55002 .56216 m .54554 .5658 L p
.56098 .54882 L 1 g
F P
s
P
p
.002 w
.53876 .57072 m .55573 .54631 L p
.54554 .5658 L 1 g
F P
s
P
p
.002 w
.5444 .56894 m .53781 .57209 L .55002 .56216 L p
1 g
F P
s
P
p
.002 w
.5651 .58022 m .5569 .58685 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.57036 .57243 m .5651 .58022 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.57209 .5643 m .57036 .57243 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.57005 .5567 m .57209 .5643 L .53781 .57209 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54922 .56312 L p
1 g
F P
s
P
p
.53822 .57113 m .5322 .57686 L .54922 .56312 L 1 g
F
P
p
.56776 .53597 m .56441 .55046 L .56733 .52541 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56746 .52869 L p
1 g
F P
s
P
p
.56449 .53858 m .56257 .5491 L .56746 .52869 L 1 g
F
P
p
.002 w
.55089 .51318 m .56677 .51565 L p
.55573 .54631 L 1 g
F P
s
P
p
.002 w
.56733 .52541 m .55573 .54631 L p
.56677 .51565 L 1 g
F P
s
P
p
.56705 .52059 m .56716 .52129 L .56698 .5193 L 1 g
F
P
p
.56716 .52129 m .568 .52675 L .56702 .51794 L 1 g
F
P
p
.55661 .4905 m .56607 .50935 L .56136 .4996 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55737 .49131 m .55661 .4905 L p
.56136 .4996 L 1 g
F P
s
P
p
.56381 .49753 m .57227 .5165 L .5541 .48815 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55737 .49131 L p
1 g
F P
s
P
p
.56136 .4996 m .56713 .51061 L .55737 .49131 L 1 g
F
P
p
.55534 .47851 m .56381 .49753 L .55737 .49131 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55737 .49131 L p
1 g
F P
s
P
p
.54174 .47608 m .55737 .49131 L .5541 .48815 L 1 g
F
P
p
.002 w
.5541 .48815 m .55089 .51318 L p
.54516 .47948 L 1 g
F P
s
P
p
.55056 .48471 m .5541 .48815 L .55166 .4858 L 1 g
F
P
p
.54174 .47608 m .5541 .48815 L .55056 .48471 L 1 g
F
P
p
.002 w
.52097 .48178 m .54516 .47948 L p
.55089 .51318 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55089 .51318 m .5541 .48815 L p
.56115 .49916 L 1 g
F P
s
P
p
.52784 .46974 m .54231 .4767 L .52097 .48178 L 1 g
F
P
p
.002 w
.54231 .4767 m .54174 .47608 L p
.55613 .49017 L 1 g
F P
s
P
p
.002 w
.5476 .47925 m .54516 .47948 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.54516 .47948 m .52097 .48178 L p
.54231 .4767 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54231 .4767 L p
1 g
F P
s
P
p
.55613 .49017 m .55834 .49233 L .54231 .4767 L 1 g
F
P
p
.002 w
.54516 .47948 m .55534 .47851 L .5541 .48815 L p
1 g
F P
s
P
p
.002 w
.5541 .48815 m .55447 .48529 L p
.55737 .49131 L 1 g
F P
s
P
p
.002 w
.55447 .48529 m .55534 .47851 L p
.55737 .49131 L 1 g
F P
s
P
p
.002 w
.56929 .51604 m .55089 .51318 L p
.56115 .49916 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56607 .50935 L p
1 g
F P
s
P
p
.568 .52675 m .56854 .53025 L .56607 .50935 L 1 g
F
P
p
.002 w
.56607 .50935 m .56713 .51061 L p
.56136 .4996 L 1 g
F P
s
P
p
.002 w
.55737 .49131 m .55834 .49233 L p
.55166 .4858 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52242 .46713 L p
1 g
F P
s
P
p
.002 w
.52242 .46713 m .52214 .46667 L p
.53109 .4713 L 1 g
F P
s
P
p
.53109 .4713 m .54302 .47747 L .52242 .46713 L 1 g
F
P
p
.002 w
.55534 .47851 m .5476 .47925 L p
.52784 .46974 L 1 g
F P
s
P
p
.5443 .46994 m .55534 .47851 L .52784 .46974 L 1 g
F
P
p
.5443 .46994 m .52784 .46974 L .52242 .46713 L 1 g
F
P
p
.002 w
.54231 .4767 m .54302 .47747 L p
.53109 .4713 L 1 g
F P
s
P
p
.002 w
.52242 .46713 m .52251 .46729 L p
.51935 .46674 L 1 g
F P
s
P
p
.5 .4634 m .52242 .46713 L .51935 .46674 L 1 g
F
P
p
.5 .4634 m .52251 .46729 L .50959 .46525 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51781 .46654 m .51358 .44606 L p
.5443 .46994 L 1 g
F P
s
P
p
.002 w
.51781 .46654 m .52097 .48178 L p
.47429 .45967 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47429 .45967 m .51358 .44606 L .51781 .46654 L p
1 g
F P
s
P
p
.002 w
.52251 .46729 m .52282 .46778 L p
.50959 .46525 L 1 g
F P
s
P
p
.002 w
.5 .46373 m .5 .46442 L p
.4868 .46576 L 1 g
F P
s
P
p
.47073 .4609 m .48132 .4653 L .47755 .46718 L 1 g
F
P
p
.45826 .47608 m .47755 .46718 L .47031 .47079 L 1 g
F
P
p
.002 w
.47479 .46856 m .47433 .46768 L p
.47755 .46718 L 1 g
F P
s
P
p
.002 w
.47433 .46768 m .47073 .4609 L p
.47755 .46718 L 1 g
F P
s
P
p
.48132 .4653 m .4836 .46625 L .47755 .46718 L 1 g
F
P
p
.4836 .46625 m .52097 .48178 L .47755 .46718 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47755 .46718 L p
1 g
F P
s
P
p
.4868 .46576 m .5 .46442 L .47755 .46718 L 1 g
F
P
p
.002 w
.47755 .46718 m .47718 .46778 L p
.47031 .47079 L 1 g
F P
s
P
p
.002 w
.43499 .48457 m .47073 .4609 L .47479 .46856 L p
1 g
F P
s
P
p
.002 w
.45782 .47657 m .45826 .47608 L p
.46661 .47242 L 1 g
F P
s
P
p
.43499 .48457 m .47479 .46856 L .43933 .48528 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45782 .47657 L p
1 g
F P
s
P
p
.46661 .47242 m .47718 .46778 L .45782 .47657 L 1 g
F
P
p
.002 w
.45782 .47657 m .45698 .47747 L p
.44914 .48499 L 1 g
F P
s
P
p
.43423 .50899 m .43517 .4985 L .44216 .49219 L 1 g
F
P
p
.002 w
.4363 .48597 m .44195 .49197 L p
.43517 .4985 L 1 g
F P
s
P
p
.002 w
.44195 .49197 m .44216 .49219 L p
.43517 .4985 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .45465 .47974 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44245 .49157 m .44166 .49233 L p
.4375 .50206 L 1 g
F P
s
P
p
.002 w
.45465 .47974 m .44166 .49233 L .44251 .49143 L p
1 g
F P
s
P
p
.002 w
.44251 .49143 m .44256 .49138 L p
.45465 .47974 L 1 g
F P
s
P
p
.44914 .48499 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.43499 .48457 m .44515 .48623 L .44256 .49138 L 1 g
F
P
p
.002 w
.44195 .49197 m .43499 .48457 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.44256 .49138 m .44251 .49143 L p
.44229 .49193 L 1 g
F P
s
P
p
.4339 .51268 m .43423 .50899 L .46011 .51128 L 1 g
F
P
p
.002 w
.44216 .49219 m .46011 .51128 L p
.43423 .50899 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43423 .50899 L p
1 g
F P
s
P
p
.4375 .50206 m .44166 .49233 L .43423 .50899 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43249 .52876 L p
1 g
F P
s
P
p
.002 w
.43249 .52876 m .43146 .53025 L p
.43534 .53793 L 1 g
F P
s
P
p
.43925 .54566 m .43249 .52876 L .43534 .53793 L 1 g
F
P
p
.4346 .53554 m .43249 .52876 L .44094 .53377 L 1 g
F
P
p
.002 w
.43228 .5281 m .4325 .52824 L p
.43249 .52876 L 1 g
F P
s
P
p
.43322 .5203 m .4325 .52824 L .43249 .52876 L 1 g
F
P
p
.002 w
.4325 .52824 m .44094 .53377 L p
.43249 .52876 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43245 .52881 L p
1 g
F P
s
P
p
.002 w
.43245 .52881 m .43249 .52876 L p
.4325 .52828 L 1 g
F P
s
P
p
.4325 .52828 m .43287 .51061 L .43245 .52881 L 1 g
F
P
p
.43322 .5203 m .43293 .51222 L .4325 .52824 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.46011 .51128 m .44094 .53377 L .4325 .52824 L p
1 g
F P
s
P
p
.4339 .51268 m .46011 .51128 L .4325 .52824 L 1 g
F
P
p
.43293 .51222 m .43287 .51061 L .43249 .52876 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43842 .54723 L p
1 g
F P
s
P
p
.002 w
.43842 .54723 m .43743 .5491 L p
.44491 .5556 L 1 g
F P
s
P
p
.45146 .56129 m .43842 .54723 L .44491 .5556 L 1 g
F
P
p
.43842 .54723 m .44094 .53377 L .44489 .55558 L 1 g
F
P
p
.002 w
.43685 .54522 m .43726 .54408 L p
.43842 .54723 L 1 g
F P
s
P
p
.43534 .53793 m .43726 .54408 L .43842 .54723 L 1 g
F
P
p
.002 w
.43726 .54408 m .44094 .53377 L p
.43842 .54723 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.002 w
.4383 .54745 m .43842 .54723 L p
.43767 .5454 L 1 g
F P
s
P
p
.43767 .5454 m .43146 .53025 L .4383 .54745 L 1 g
F
P
p
.43534 .53793 m .43404 .53536 L .43726 .54408 L 1 g
F
P
p
.002 w
.44094 .53377 m .43726 .54408 L p
.4346 .53554 L 1 g
F P
s
P
p
.43404 .53536 m .43146 .53025 L .43842 .54723 L 1 g
F
P
p
.002 w
.44094 .53377 m .47303 .55045 L p
.44489 .55558 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56309 L p
1 g
F P
s
P
p
.002 w
.45079 .56309 m .45002 .56518 L p
.45924 .56886 L 1 g
F P
s
P
p
.46872 .57265 m .45079 .56309 L .45924 .56886 L 1 g
F
P
p
.46035 .56962 m .45079 .56309 L .46685 .56677 L 1 g
F
P
p
.002 w
.44971 .56235 m .45026 .56249 L p
.45079 .56309 L 1 g
F P
s
P
p
.44491 .5556 m .45026 .56249 L .45079 .56309 L 1 g
F
P
p
.002 w
.45026 .56249 m .46685 .56677 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45077 .56315 L p
1 g
F P
s
P
p
.002 w
.45077 .56315 m .45079 .56309 L p
.45041 .56269 L 1 g
F P
s
P
p
.45041 .56269 m .43743 .5491 L .45077 .56315 L 1 g
F
P
p
.44491 .5556 m .4412 .55237 L .45026 .56249 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47303 .55045 m .46685 .56677 L .45026 .56249 L p
1 g
F P
s
P
p
.44489 .55558 m .47303 .55045 L .45026 .56249 L 1 g
F
P
p
.4412 .55237 m .43743 .5491 L .45079 .56309 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.46823 .57491 m .46685 .56677 L .48087 .57842 L 1 g
F
P
p
.002 w
.46755 .57472 m .46753 .57453 L p
.46823 .57491 L 1 g
F P
s
P
p
.002 w
.46753 .57453 m .46685 .56677 L p
.46823 .57491 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46821 .57499 L p
1 g
F P
s
P
p
.002 w
.46821 .57499 m .46823 .57491 L p
.46759 .57457 L 1 g
F P
s
P
p
.46759 .57457 m .45002 .56518 L .46821 .57499 L 1 g
F
P
p
.45924 .56886 m .45159 .5658 L .46753 .57453 L 1 g
F
P
p
.002 w
.46685 .56677 m .46753 .57453 L p
.46035 .56962 L 1 g
F P
s
P
p
.45159 .5658 m .45002 .56518 L .46823 .57491 L 1 g
F
P
p
.47837 .57773 m .47615 .57755 L .48903 .58069 L 1 g
F
P
p
.47837 .57773 m .48903 .58069 L .48906 .5807 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46685 .56677 m .50244 .57157 L p
.48087 .57842 L 1 g
F P
s
P
p
.002 w
.50244 .57157 m .50295 .57952 L .48903 .58069 L p
1 g
F P
s
P
p
.48087 .57842 m .50244 .57157 L .48903 .58069 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .5807 L p
1 g
F P
s
P
p
.002 w
.48906 .5807 m .48906 .5807 L p
.48905 .5807 L 1 g
F P
s
P
p
.48905 .5807 m .4678 .57686 L .48906 .5807 L 1 g
F
P
p
.47615 .57755 m .4678 .57686 L .48906 .5807 L 1 g
F
P
p
.50024 .58121 m .48906 .5807 L .50295 .57952 L 1 g
F
P
p
.002 w
.48903 .58069 m .50295 .57952 L p
.48906 .5807 L 1 g
F P
s
P
p
.002 w
.48906 .5807 m .48889 .583 L p
.49829 .58112 L 1 g
F P
s
P
p
.002 w
.51096 .58086 m .51111 .583 L p
.52088 .57798 L 1 g
F P
s
P
p
.002 w
.51102 .5817 m .51096 .58086 L p
.50409 .58138 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51102 .5817 L p
1 g
F P
s
P
p
.49829 .58112 m .48889 .583 L .51102 .5817 L 1 g
F
P
p
.002 w
.50295 .57952 m .50409 .58138 L p
.50024 .58121 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.41064 .51392 m .40013 .5452 L .37135 .52928 L p
1 g
F P
s
P
p
.002 w
.37135 .52928 m .38326 .49165 L .41064 .51392 L p
1 g
F P
s
P
p
.002 w
.63038 .4661 m .64995 .49061 L .62712 .51519 L p
1 g
F P
s
P
p
.002 w
.64995 .49061 m .63038 .4661 L .64508 .4349 L p
1 g
F P
s
P
p
.002 w
.57036 .57243 m .57209 .5643 L .60386 .55259 L p
1 g
F P
s
P
p
.002 w
.60018 .53749 m .60386 .55259 L .57209 .5643 L p
1 g
F P
s
P
p
.002 w
.60386 .55259 m .60018 .53749 L .62712 .51519 L p
1 g
F P
s
P
p
.002 w
.39171 .42727 m .35975 .46783 L .34089 .44333 L p
1 g
F P
s
P
p
.002 w
.34089 .44333 m .37513 .39887 L .39171 .42727 L p
1 g
F P
s
P
p
.002 w
.55121 .30557 m .61329 .31866 L .61483 .3476 L p
1 g
F P
s
P
p
.002 w
.61329 .31866 m .55121 .30557 L .54549 .28013 L p
1 g
F P
s
P
p
.002 w
.6129 .37975 m .6552 .40405 L .64508 .4349 L p
1 g
F P
s
P
p
.002 w
.6552 .40405 m .6129 .37975 L .61483 .3476 L p
1 g
F P
s
P
p
.002 w
.47592 .28527 m .54549 .28013 L .55121 .30557 L p
1 g
F P
s
P
p
.002 w
.61157 .4965 m .62712 .51519 L .60018 .53749 L p
1 g
F P
s
P
p
.002 w
.62712 .51519 m .61157 .4965 L .63038 .4661 L p
1 g
F P
s
P
p
.002 w
.57209 .5643 m .57005 .5567 L .60018 .53749 L p
1 g
F P
s
P
p
.002 w
.48256 .31083 m .41671 .3341 L .40925 .30892 L p
1 g
F P
s
P
p
.002 w
.40925 .30892 m .47592 .28527 L .48256 .31083 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.42695 .36295 m .37513 .39887 L .36267 .37203 L p
1 g
F P
s
P
p
.002 w
.36267 .37203 m .41671 .3341 L .42695 .36295 L p
1 g
F P
s
P
p
.002 w
.55121 .30557 m .48256 .31083 L .47592 .28527 L p
1 g
F P
s
P
p
.002 w
.58931 .52497 m .60018 .53749 L .57005 .5567 L p
1 g
F P
s
P
p
.002 w
.60018 .53749 m .58931 .52497 L .61157 .4965 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60747 .41399 m .64508 .4349 L .63038 .4661 L p
1 g
F P
s
P
p
.002 w
.64508 .4349 m .60747 .41399 L .6129 .37975 L p
1 g
F P
s
P
p
.002 w
.4119 .4562 m .38326 .49165 L .35975 .46783 L p
1 g
F P
s
P
p
.002 w
.35975 .46783 m .39171 .42727 L .4119 .4562 L p
1 g
F P
s
P
p
.002 w
.57005 .5567 m .56441 .55046 L .58931 .52497 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.55551 .33556 m .61483 .3476 L .6129 .37975 L p
1 g
F P
s
P
p
.002 w
.61483 .3476 m .55551 .33556 L .55121 .30557 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.50573 .56336 m .50244 .57157 L .46685 .56677 L p
1 g
F P
s
P
p
.002 w
.46685 .56677 m .47303 .55045 L .50573 .56336 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.57227 .5165 m .58931 .52497 L .56441 .55046 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.59865 .44908 m .63038 .4661 L .61157 .4965 L p
1 g
F P
s
P
p
.002 w
.63038 .4661 m .59865 .44908 L .60747 .41399 L p
1 g
F P
s
P
p
.002 w
.48256 .31083 m .55121 .30557 L .55551 .33556 L p
1 g
F P
s
P
p
.002 w
.51251 .5558 m .50573 .56336 L .47303 .55045 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.43499 .48457 m .41064 .51392 L .38326 .49165 L p
1 g
F P
s
P
p
.002 w
.38326 .49165 m .4119 .4562 L .43499 .48457 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58931 .52497 m .57227 .5165 L .58677 .48369 L p
1 g
F P
s
P
p
.002 w
.58677 .48369 m .61157 .4965 L .58931 .52497 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61157 .4965 m .58677 .48369 L .59865 .44908 L p
1 g
F P
s
P
p
.002 w
.43967 .39449 m .39171 .42727 L .37513 .39887 L p
1 g
F P
s
P
p
.002 w
.37513 .39887 m .42695 .36295 L .43967 .39449 L p
1 g
F P
s
P
p
.002 w
.55573 .54631 m .54496 .54473 L .55089 .51318 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48992 .3408 m .42695 .36295 L .41671 .3341 L p
1 g
F P
s
P
p
.002 w
.41671 .3341 m .48256 .31083 L .48992 .3408 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.52205 .54976 m .51251 .5558 L .48628 .53532 L p
1 g
F P
s
P
p
.002 w
.47303 .55045 m .48628 .53532 L .51251 .5558 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.55817 .36912 m .6129 .37975 L .60747 .41399 L p
1 g
F P
s
P
p
.002 w
.6129 .37975 m .55817 .36912 L .55551 .33556 L p
1 g
F P
s
P
p
.002 w
.48628 .53532 m .47303 .55045 L .44094 .53377 L p
1 g
F P
s
P
p
.002 w
.54496 .54473 m .53329 .54592 L .52762 .51548 L p
1 g
F P
s
P
p
.002 w
.52762 .51548 m .55089 .51318 L .54496 .54473 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.53329 .54592 m .52205 .54976 L .5052 .52317 L p
1 g
F P
s
P
p
.002 w
.48628 .53532 m .5052 .52317 L .52205 .54976 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55551 .33556 m .48992 .3408 L .48256 .31083 L p
1 g
F P
s
P
p
.002 w
.5052 .52317 m .52762 .51548 L .53329 .54592 L p
1 g
F P
s
P
p
.002 w
.44094 .53377 m .46011 .51128 L .48628 .53532 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.55534 .47851 m .58677 .48369 L .57227 .5165 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.48992 .3408 m .55551 .33556 L .55817 .36912 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.55906 .40505 m .60747 .41399 L .59865 .44908 L p
1 g
F P
s
P
p
.002 w
.60747 .41399 m .55906 .40505 L .55817 .36912 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45445 .42757 m .4119 .4562 L .39171 .42727 L p
1 g
F P
s
P
p
.002 w
.39171 .42727 m .43967 .39449 L .45445 .42757 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5052 .52317 m .48628 .53532 L .46011 .51128 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.58677 .48369 m .55534 .47851 L .5581 .442 L p
1 g
F P
s
P
p
.002 w
.5581 .442 m .59865 .44908 L .58677 .48369 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.59865 .44908 m .5581 .442 L .55906 .40505 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49774 .37416 m .43967 .39449 L .42695 .36295 L p
1 g
F P
s
P
p
.002 w
.42695 .36295 m .48992 .3408 L .49774 .37416 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55089 .51318 m .52762 .51548 L .52097 .48178 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.52762 .51548 m .5052 .52317 L .48787 .49318 L p
1 g
F P
s
P
p
.002 w
.46011 .51128 m .48787 .49318 L .5052 .52317 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47073 .4609 m .43499 .48457 L .4119 .4562 L p
1 g
F P
s
P
p
.002 w
.4119 .4562 m .45445 .42757 L .47073 .4609 L p
1 g
F P
s
P
p
.002 w
.55817 .36912 m .49774 .37416 L .48992 .3408 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.48787 .49318 m .52097 .48178 L .52762 .51548 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49774 .37416 m .55817 .36912 L .55906 .40505 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51358 .44606 m .5581 .442 L .55534 .47851 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.55053 .61973 m
.55324 .62987 L
s
P
p
.002 w
.50573 .40971 m .45445 .42757 L .43967 .39449 L p
1 g
F P
s
P
p
.002 w
.43967 .39449 m .49774 .37416 L .50573 .40971 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50573 .40971 m .55906 .40505 L .5581 .442 L p
1 g
F P
s
P
p
.002 w
.55906 .40505 m .50573 .40971 L .49774 .37416 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.5581 .442 m .51358 .44606 L .50573 .40971 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51358 .44606 m .47073 .4609 L .45445 .42757 L p
1 g
F P
s
P
p
.002 w
.45445 .42757 m .50573 .40971 L .51358 .44606 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .75138 .59161 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .55993 .65491 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.58062)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.58062)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47311 .46626 m .52093 .46595 L .51775 .43772 L p
1 g
F P
s
P
p
.002 w
.51775 .43772 m .47583 .43798 L .47311 .46626 L p
1 g
F P
s
P
p
.002 w
.55784 .42776 m .51775 .43772 L .52093 .46595 L p
1 g
F P
s
P
p
.002 w
.47583 .43798 m .51775 .43772 L .51414 .40937 L p
1 g
F P
s
P
p
.002 w
.51775 .43772 m .55784 .42776 L .54758 .40092 L p
1 g
F P
s
P
p
.002 w
.54758 .40092 m .51414 .40937 L .51775 .43772 L p
1 g
F P
s
P
p
.002 w
.42743 .45566 m .47311 .46626 L .47583 .43798 L p
1 g
F P
s
P
p
.002 w
.47583 .43798 m .43585 .42849 L .42743 .45566 L p
1 g
F P
s
P
p
.002 w
.43585 .42849 m .47583 .43798 L .47912 .40957 L p
1 g
F P
s
P
p
.002 w
.51414 .40937 m .47912 .40957 L .47583 .43798 L p
1 g
F P
s
P
p
.002 w
.47912 .40957 m .51414 .40937 L .51017 .38141 L p
1 g
F P
s
P
p
.002 w
.51414 .40937 m .54758 .40092 L .53613 .37474 L p
1 g
F P
s
P
p
.002 w
.53613 .37474 m .51017 .38141 L .51414 .40937 L p
1 g
F P
s
P
p
.002 w
.47912 .40957 m .44579 .40149 L .43585 .42849 L p
1 g
F P
s
P
p
.002 w
.44579 .40149 m .47912 .40957 L .48294 .38156 L p
1 g
F P
s
P
p
.002 w
.51017 .38141 m .48294 .38156 L .47912 .40957 L p
1 g
F P
s
P
p
.002 w
.47103 .49392 m .52364 .49356 L .52093 .46595 L p
1 g
F P
s
P
p
.002 w
.52093 .46595 m .47311 .46626 L .47103 .49392 L p
1 g
F P
s
P
p
.002 w
.56674 .45478 m .52093 .46595 L .52364 .49356 L p
1 g
F P
s
P
p
.002 w
.52093 .46595 m .56674 .45478 L .55784 .42776 L p
1 g
F P
s
P
p
.002 w
.42071 .48249 m .47103 .49392 L .47311 .46626 L p
1 g
F P
s
P
p
.002 w
.47311 .46626 m .42743 .45566 L .42071 .48249 L p
1 g
F P
s
P
p
.002 w
.48294 .38156 m .51017 .38141 L .50591 .35435 L p
1 g
F P
s
P
p
.002 w
.51017 .38141 m .53613 .37474 L .52371 .3497 L p
1 g
F P
s
P
p
.002 w
.52371 .3497 m .50591 .35435 L .51017 .38141 L p
1 g
F P
s
P
p
.002 w
.48294 .38156 m .45707 .37516 L .44579 .40149 L p
1 g
F P
s
P
p
.002 w
.45707 .37516 m .48294 .38156 L .48721 .35445 L p
1 g
F P
s
P
p
.002 w
.50591 .35435 m .48721 .35445 L .48294 .38156 L p
1 g
F P
s
P
p
.002 w
.57628 .3849 m .54758 .40092 L .55784 .42776 L p
1 g
F P
s
P
p
.002 w
.54758 .40092 m .57628 .3849 L .5583 .36211 L p
1 g
F P
s
P
p
.002 w
.5583 .36211 m .53613 .37474 L .54758 .40092 L p
1 g
F P
s
P
p
.002 w
.59243 .40884 m .55784 .42776 L .56674 .45478 L p
1 g
F P
s
P
p
.002 w
.55784 .42776 m .59243 .40884 L .57628 .3849 L p
1 g
F P
s
P
p
.002 w
.40152 .40995 m .43585 .42849 L .44579 .40149 L p
1 g
F P
s
P
p
.002 w
.44579 .40149 m .41732 .38577 L .40152 .40995 L p
1 g
F P
s
P
p
.002 w
.41732 .38577 m .44579 .40149 L .45707 .37516 L p
1 g
F P
s
P
p
.002 w
.38803 .43484 m .42743 .45566 L .43585 .42849 L p
1 g
F P
s
P
p
.002 w
.43585 .42849 m .40152 .40995 L .38803 .43484 L p
1 g
F P
s
P
p
.002 w
.53613 .37474 m .5583 .36211 L .53881 .34093 L p
1 g
F P
s
P
p
.002 w
.53881 .34093 m .52371 .3497 L .53613 .37474 L p
1 g
F P
s
P
p
.002 w
.46962 .52043 m .5258 .52003 L .52364 .49356 L p
1 g
F P
s
P
p
.002 w
.52364 .49356 m .47103 .49392 L .46962 .52043 L p
1 g
F P
s
P
p
.002 w
.57409 .48146 m .52364 .49356 L .5258 .52003 L p
1 g
F P
s
P
p
.002 w
.52364 .49356 m .57409 .48146 L .56674 .45478 L p
1 g
F P
s
P
p
.002 w
.41585 .50846 m .46962 .52043 L .47103 .49392 L p
1 g
F P
s
P
p
.002 w
.47103 .49392 m .42071 .48249 L .41585 .50846 L p
1 g
F P
s
P
p
.002 w
.45707 .37516 m .4351 .36275 L .41732 .38577 L p
1 g
F P
s
P
p
.002 w
.4351 .36275 m .45707 .37516 L .46948 .34998 L p
1 g
F P
s
P
p
.002 w
.48721 .35445 m .46948 .34998 L .45707 .37516 L p
1 g
F P
s
P
p
.002 w
.60642 .43351 m .56674 .45478 L .57409 .48146 L p
1 g
F P
s
P
p
.002 w
.56674 .45478 m .60642 .43351 L .59243 .40884 L p
1 g
F P
s
P
p
.002 w
.48721 .35445 m .50591 .35435 L .50144 .32872 L p
1 g
F P
s
P
p
.002 w
.50591 .35435 m .52371 .3497 L .51053 .32631 L p
1 g
F P
s
P
p
.002 w
.51053 .32631 m .50144 .32872 L .50591 .35435 L p
1 g
F P
s
P
p
.002 w
.37715 .45996 m .42071 .48249 L .42743 .45566 L p
1 g
F P
s
P
p
.002 w
.42743 .45566 m .38803 .43484 L .37715 .45996 L p
1 g
F P
s
P
p
.002 w
.46948 .34998 m .48721 .35445 L .49186 .32877 L p
1 g
F P
s
P
p
.002 w
.50144 .32872 m .49186 .32877 L .48721 .35445 L p
1 g
F P
s
P
p
.002 w
.52371 .3497 m .53881 .34093 L .5182 .32178 L p
1 g
F P
s
P
p
.002 w
.5182 .32178 m .51053 .32631 L .52371 .3497 L p
1 g
F P
s
P
p
.002 w
.46948 .34998 m .45452 .34135 L .4351 .36275 L p
1 g
F P
s
P
p
.002 w
.45452 .34135 m .46948 .34998 L .48281 .32644 L p
1 g
F P
s
P
p
.002 w
.49186 .32877 m .48281 .32644 L .46948 .34998 L p
1 g
F P
s
P
p
.002 w
.59732 .36264 m .57628 .3849 L .59243 .40884 L p
1 g
F P
s
P
p
.002 w
.57628 .3849 m .59732 .36264 L .57436 .34467 L p
1 g
F P
s
P
p
.002 w
.57436 .34467 m .5583 .36211 L .57628 .3849 L p
1 g
F P
s
P
p
.002 w
.5583 .36211 m .57436 .34467 L .54963 .32888 L p
1 g
F P
s
P
p
.002 w
.54963 .32888 m .53881 .34093 L .5583 .36211 L p
1 g
F P
s
P
p
.002 w
.5258 .52003 m .57972 .50731 L .57409 .48146 L p
1 g
F P
s
P
p
.002 w
.61794 .45842 m .57409 .48146 L .57972 .50731 L p
1 g
F P
s
P
p
.002 w
.57409 .48146 m .61794 .45842 L .60642 .43351 L p
1 g
F P
s
P
p
.002 w
.46894 .54525 m .52737 .54481 L .5258 .52003 L p
1 g
F P
s
P
p
.002 w
.5258 .52003 m .46962 .52043 L .46894 .54525 L p
1 g
F P
s
P
p
.002 w
.57972 .50731 m .5258 .52003 L .52737 .54481 L p
1 g
F P
s
P
p
.002 w
.39664 .36368 m .41732 .38577 L .4351 .36275 L p
1 g
F P
s
P
p
.002 w
.4351 .36275 m .41933 .34544 L .39664 .36368 L p
1 g
F P
s
P
p
.002 w
.41933 .34544 m .4351 .36275 L .45452 .34135 L p
1 g
F P
s
P
p
.002 w
.37633 .38376 m .40152 .40995 L .41732 .38577 L p
1 g
F P
s
P
p
.002 w
.41732 .38577 m .39664 .36368 L .37633 .38376 L p
1 g
F P
s
P
p
.002 w
.36917 .48481 m .41585 .50846 L .42071 .48249 L p
1 g
F P
s
P
p
.002 w
.42071 .48249 m .37715 .45996 L .36917 .48481 L p
1 g
F P
s
P
p
.002 w
.41299 .53304 m .46894 .54525 L .46962 .52043 L p
1 g
F P
s
P
p
.002 w
.46962 .52043 m .41585 .50846 L .41299 .53304 L p
1 g
F P
s
P
p
.002 w
.61803 .38245 m .59243 .40884 L .60642 .43351 L p
1 g
F P
s
P
p
.002 w
.59243 .40884 m .61803 .38245 L .59732 .36264 L p
1 g
F P
s
P
p
.002 w
.53881 .34093 m .54963 .32888 L .52361 .31558 L p
1 g
F P
s
P
p
.002 w
.52361 .31558 m .5182 .32178 L .53881 .34093 L p
1 g
F P
s
P
p
.002 w
.45452 .34135 m .44392 .32938 L .41933 .34544 L p
1 g
F P
s
P
p
.002 w
.44392 .32938 m .45452 .34135 L .47523 .32198 L p
1 g
F P
s
P
p
.002 w
.48281 .32644 m .47523 .32198 L .45452 .34135 L p
1 g
F P
s
P
p
.002 w
.35887 .4053 m .38803 .43484 L .40152 .40995 L p
1 g
F P
s
P
p
.002 w
.40152 .40995 m .37633 .38376 L .35887 .4053 L p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .49186 .32877 L .50144 .32872 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .50144 .32872 L .51053 .32631 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .48281 .32644 L .49186 .32877 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .51053 .32631 L .5182 .32178 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .47523 .32198 L .48281 .32644 L closepath p
1 g
F P
s
P
p
.002 w
.63604 .40372 m .60642 .43351 L .61794 .45842 L p
1 g
F P
s
P
p
.002 w
.60642 .43351 m .63604 .40372 L .61803 .38245 L p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .5182 .32178 L .52361 .31558 L closepath p
1 g
F P
s
P
p
.002 w
.52737 .54481 m .58348 .53179 L .57972 .50731 L p
1 g
F P
s
P
p
.002 w
.62671 .48308 m .57972 .50731 L .58348 .53179 L p
1 g
F P
s
P
p
.002 w
.57972 .50731 m .62671 .48308 L .61794 .45842 L p
1 g
F P
s
P
p
.002 w
.47523 .32198 m .46992 .31583 L .44392 .32938 L p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .46992 .31583 L .47523 .32198 L closepath p
1 g
F P
s
P
p
.002 w
.34469 .42788 m .37715 .45996 L .38803 .43484 L p
1 g
F P
s
P
p
.002 w
.38803 .43484 m .35887 .4053 L .34469 .42788 L p
1 g
F P
s
P
p
.002 w
.55492 .31473 m .54963 .32888 L .57436 .34467 L p
1 g
F P
s
P
p
.002 w
.54963 .32888 m .55492 .31473 L .52618 .30836 L p
1 g
F P
s
P
p
.002 w
.52618 .30836 m .52361 .31558 L .54963 .32888 L p
1 g
F P
s
P
p
.002 w
.58248 .32404 m .57436 .34467 L .59732 .36264 L p
1 g
F P
s
P
p
.002 w
.57436 .34467 m .58248 .32404 L .55492 .31473 L p
1 g
F P
s
P
p
.002 w
.36434 .50886 m .41299 .53304 L .41585 .50846 L p
1 g
F P
s
P
p
.002 w
.41585 .50846 m .36917 .48481 L .36434 .50886 L p
1 g
F P
s
P
p
.002 w
.41159 .32484 m .41933 .34544 L .44392 .32938 L p
1 g
F P
s
P
p
.002 w
.44392 .32938 m .43888 .31526 L .41159 .32484 L p
1 g
F P
s
P
p
.002 w
.43888 .31526 m .44392 .32938 L .46992 .31583 L p
1 g
F P
s
P
p
.002 w
.3862 .33722 m .39664 .36368 L .41933 .34544 L p
1 g
F P
s
P
p
.002 w
.41933 .34544 m .41159 .32484 L .3862 .33722 L p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .52361 .31558 L .52618 .30836 L closepath p
1 g
F P
s
P
p
.002 w
.46903 .56782 m .52829 .56736 L .52737 .54481 L p
1 g
F P
s
P
p
.002 w
.52737 .54481 m .46894 .54525 L .46903 .56782 L p
1 g
F P
s
P
p
.002 w
.58348 .53179 m .52737 .54481 L .52829 .56736 L p
1 g
F P
s
P
p
.002 w
.46992 .31583 m .46749 .30863 L .43888 .31526 L p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .46749 .30863 L .46992 .31583 L closepath p
1 g
F P
s
P
p
.002 w
.60824 .33614 m .59732 .36264 L .61803 .38245 L p
1 g
F P
s
P
p
.002 w
.59732 .36264 m .60824 .33614 L .58248 .32404 L p
1 g
F P
s
P
p
.002 w
.41226 .55566 m .46903 .56782 L .46894 .54525 L p
1 g
F P
s
P
p
.002 w
.46894 .54525 m .41299 .53304 L .41226 .55566 L p
1 g
F P
s
P
p
.002 w
.65091 .42604 m .61794 .45842 L .62671 .48308 L p
1 g
F P
s
P
p
.002 w
.61794 .45842 m .65091 .42604 L .63604 .40372 L p
1 g
F P
s
P
p
.002 w
.3633 .35219 m .37633 .38376 L .39664 .36368 L p
1 g
F P
s
P
p
.002 w
.39664 .36368 m .3862 .33722 L .3633 .35219 L p
1 g
F P
s
P
p
.002 w
.52558 .30089 m .52618 .30836 L .55492 .31473 L p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .52618 .30836 L .52558 .30089 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .52558 .30089 L .52184 .29398 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .52184 .29398 L .51534 .2884 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .51534 .2884 L .50677 .28479 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .50677 .28479 L .49709 .28356 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .49709 .28356 L .48738 .28487 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .48738 .28487 L .47873 .28856 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .47873 .28856 L .47211 .2942 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .47211 .2942 L .46824 .30115 L closepath p
1 g
F P
s
P
p
.002 w
.49683 .30505 m .46824 .30115 L .46749 .30863 L closepath p
1 g
F P
s
P
p
.002 w
.4401 .30045 m .43888 .31526 L .46749 .30863 L p
1 g
F P
s
P
p
.002 w
.46749 .30863 m .46824 .30115 L .4401 .30045 L p
1 g
F P
s
P
p
.002 w
.33419 .45103 m .36917 .48481 L .37715 .45996 L p
1 g
F P
s
P
p
.002 w
.37715 .45996 m .34469 .42788 L .33419 .45103 L p
1 g
F P
s
P
p
.002 w
.63165 .35083 m .61803 .38245 L .63604 .40372 L p
1 g
F P
s
P
p
.002 w
.61803 .38245 m .63165 .35083 L .60824 .33614 L p
1 g
F P
s
P
p
.002 w
.554 .29995 m .55492 .31473 L .58248 .32404 L p
1 g
F P
s
P
p
.002 w
.55492 .31473 m .554 .29995 L .52558 .30089 L p
1 g
F P
s
P
p
.002 w
.41302 .30307 m .41159 .32484 L .43888 .31526 L p
1 g
F P
s
P
p
.002 w
.43888 .31526 m .4401 .30045 L .41302 .30307 L p
1 g
F P
s
P
p
.002 w
.52829 .56736 m .58521 .55434 L .58348 .53179 L p
1 g
F P
s
P
p
.002 w
.63246 .50697 m .58348 .53179 L .58521 .55434 L p
1 g
F P
s
P
p
.002 w
.58348 .53179 m .63246 .50697 L .62671 .48308 L p
1 g
F P
s
P
p
.002 w
.52184 .29398 m .52558 .30089 L .554 .29995 L p
1 g
F P
s
P
p
.002 w
.34346 .36948 m .35887 .4053 L .37633 .38376 L p
1 g
F P
s
P
p
.002 w
.37633 .38376 m .3633 .35219 L .34346 .36948 L p
1 g
F P
s
P
p
.002 w
.4476 .28658 m .4401 .30045 L .46824 .30115 L p
1 g
F P
s
P
p
.002 w
.46824 .30115 m .47211 .2942 L .4476 .28658 L p
1 g
F P
s
P
p
.002 w
.36288 .53154 m .41226 .55566 L .41299 .53304 L p
1 g
F P
s
P
p
.002 w
.41299 .53304 m .36434 .50886 L .36288 .53154 L p
1 g
F P
s
P
p
.002 w
.58148 .30232 m .58248 .32404 L .60824 .33614 L p
1 g
F P
s
P
p
.002 w
.58248 .32404 m .58148 .30232 L .554 .29995 L p
1 g
F P
s
P
p
.002 w
.66222 .44897 m .62671 .48308 L .63246 .50697 L p
1 g
F P
s
P
p
.002 w
.62671 .48308 m .66222 .44897 L .65091 .42604 L p
1 g
F P
s
P
p
.002 w
.38762 .30902 m .3862 .33722 L .41159 .32484 L p
1 g
F P
s
P
p
.002 w
.41159 .32484 m .41302 .30307 L .38762 .30902 L p
1 g
F P
s
P
p
.002 w
.554 .29995 m .54679 .28616 L .52184 .29398 L p
1 g
F P
s
P
p
.002 w
.51534 .2884 m .52184 .29398 L .54679 .28616 L p
1 g
F P
s
P
p
.002 w
.65211 .36786 m .63604 .40372 L .65091 .42604 L p
1 g
F P
s
P
p
.002 w
.63604 .40372 m .65211 .36786 L .63165 .35083 L p
1 g
F P
s
P
p
.002 w
.46069 .27524 m .4476 .28658 L .47211 .2942 L p
1 g
F P
s
P
p
.002 w
.47211 .2942 m .47873 .28856 L .46069 .27524 L p
1 g
F P
s
P
p
.002 w
.46991 .58759 m .52852 .58712 L .52829 .56736 L p
1 g
F P
s
P
p
.002 w
.52829 .56736 m .46903 .56782 L .46991 .58759 L p
1 g
F P
s
P
p
.002 w
.58521 .55434 m .52829 .56736 L .52852 .58712 L p
1 g
F P
s
P
p
.002 w
.41379 .57575 m .46991 .58759 L .46903 .56782 L p
1 g
F P
s
P
p
.002 w
.46903 .56782 m .41226 .55566 L .41379 .57575 L p
1 g
F P
s
P
p
.002 w
.54679 .28616 m .554 .29995 L .58148 .30232 L p
1 g
F P
s
P
p
.002 w
.32777 .47425 m .36434 .50886 L .36917 .48481 L p
1 g
F P
s
P
p
.002 w
.36917 .48481 m .33419 .45103 L .32777 .47425 L p
1 g
F P
s
P
p
.002 w
.54679 .28616 m .53396 .27494 L .51534 .2884 L p
1 g
F P
s
P
p
.002 w
.50677 .28479 m .51534 .2884 L .53396 .27494 L p
1 g
F P
s
P
p
.002 w
.42383 .28249 m .41302 .30307 L .4401 .30045 L p
1 g
F P
s
P
p
.002 w
.4401 .30045 m .4476 .28658 L .42383 .28249 L p
1 g
F P
s
P
p
.002 w
.32725 .38879 m .34469 .42788 L .35887 .4053 L p
1 g
F P
s
P
p
.002 w
.35887 .4053 m .34346 .36948 L .32725 .38879 L p
1 g
F P
s
P
p
.002 w
.47795 .26779 m .46069 .27524 L .47873 .28856 L p
1 g
F P
s
P
p
.002 w
.47873 .28856 m .48738 .28487 L .47795 .26779 L p
1 g
F P
s
P
p
.002 w
.6074 .30803 m .60824 .33614 L .63165 .35083 L p
1 g
F P
s
P
p
.002 w
.60824 .33614 m .6074 .30803 L .58148 .30232 L p
1 g
F P
s
P
p
.002 w
.53396 .27494 m .51686 .26763 L .50677 .28479 L p
1 g
F P
s
P
p
.002 w
.49709 .28356 m .50677 .28479 L .51686 .26763 L p
1 g
F P
s
P
p
.002 w
.49744 .26514 m .47795 .26779 L .48738 .28487 L p
1 g
F P
s
P
p
.002 w
.48738 .28487 m .49709 .28356 L .49744 .26514 L p
1 g
F P
s
P
p
.002 w
.51686 .26763 m .49744 .26514 L .49709 .28356 L p
1 g
F P
s
P
p
.002 w
.36454 .31828 m .3633 .35219 L .3862 .33722 L p
1 g
F P
s
P
p
.002 w
.3862 .33722 m .38762 .30902 L .36454 .31828 L p
1 g
F P
s
P
p
.002 w
.52852 .58712 m .5848 .57441 L .58521 .55434 L p
1 g
F P
s
P
p
.002 w
.63494 .52955 m .58521 .55434 L .5848 .57441 L p
1 g
F P
s
P
p
.002 w
.58521 .55434 m .63494 .52955 L .63246 .50697 L p
1 g
F P
s
P
p
.002 w
.66909 .38691 m .65091 .42604 L .66222 .44897 L p
1 g
F P
s
P
p
.002 w
.65091 .42604 m .66909 .38691 L .65211 .36786 L p
1 g
F P
s
P
p
.002 w
.58148 .30232 m .57113 .28188 L .54679 .28616 L p
1 g
F P
s
P
p
.002 w
.53396 .27494 m .54679 .28616 L .57113 .28188 L p
1 g
F P
s
P
p
.002 w
.57113 .28188 m .58148 .30232 L .6074 .30803 L p
1 g
F P
s
P
p
.002 w
.365 .55227 m .41379 .57575 L .41226 .55566 L p
1 g
F P
s
P
p
.002 w
.41226 .55566 m .36288 .53154 L .365 .55227 L p
1 g
F P
s
P
p
.002 w
.66959 .47199 m .63246 .50697 L .63494 .52955 L p
1 g
F P
s
P
p
.002 w
.63246 .50697 m .66959 .47199 L .66222 .44897 L p
1 g
F P
s
P
p
.002 w
.44309 .26555 m .42383 .28249 L .4476 .28658 L p
1 g
F P
s
P
p
.002 w
.4476 .28658 m .46069 .27524 L .44309 .26555 L p
1 g
F P
s
P
p
.002 w
.63112 .31705 m .63165 .35083 L .65211 .36786 L p
1 g
F P
s
P
p
.002 w
.63165 .35083 m .63112 .31705 L .6074 .30803 L p
1 g
F P
s
P
p
.002 w
.40137 .28216 m .38762 .30902 L .41302 .30307 L p
1 g
F P
s
P
p
.002 w
.41302 .30307 m .42383 .28249 L .40137 .28216 L p
1 g
F P
s
P
p
.002 w
.31518 .40972 m .33419 .45103 L .34469 .42788 L p
1 g
F P
s
P
p
.002 w
.34469 .42788 m .32725 .38879 L .31518 .40972 L p
1 g
F P
s
P
p
.002 w
.32573 .49698 m .36288 .53154 L .36434 .50886 L p
1 g
F P
s
P
p
.002 w
.36434 .50886 m .32777 .47425 L .32573 .49698 L p
1 g
F P
s
P
p
.002 w
.34441 .33077 m .34346 .36948 L .3633 .35219 L p
1 g
F P
s
P
p
.002 w
.3633 .35219 m .36454 .31828 L .34441 .33077 L p
1 g
F P
s
P
p
.002 w
.47161 .60396 m .52801 .60349 L .52852 .58712 L p
1 g
F P
s
P
p
.002 w
.52852 .58712 m .46991 .58759 L .47161 .60396 L p
1 g
F P
s
P
p
.002 w
.5848 .57441 m .52852 .58712 L .52801 .60349 L p
1 g
F P
s
P
p
.002 w
.57113 .28188 m .55226 .26512 L .53396 .27494 L p
1 g
F P
s
P
p
.002 w
.51686 .26763 m .53396 .27494 L .55226 .26512 L p
1 g
F P
s
P
p
.002 w
.41764 .59273 m .47161 .60396 L .46991 .58759 L p
1 g
F P
s
P
p
.002 w
.46991 .58759 m .41379 .57575 L .41764 .59273 L p
1 g
F P
s
P
p
.002 w
.46877 .25436 m .44309 .26555 L .46069 .27524 L p
1 g
F P
s
P
p
.002 w
.46069 .27524 m .47795 .26779 L .46877 .25436 L p
1 g
F P
s
P
p
.002 w
.59427 .28136 m .6074 .30803 L .63112 .31705 L p
1 g
F P
s
P
p
.002 w
.6074 .30803 m .59427 .28136 L .57113 .28188 L p
1 g
F P
s
P
p
.002 w
.68204 .4076 m .66222 .44897 L .66959 .47199 L p
1 g
F P
s
P
p
.002 w
.66222 .44897 m .68204 .4076 L .66909 .38691 L p
1 g
F P
s
P
p
.002 w
.55226 .26512 m .52686 .25414 L .51686 .26763 L p
1 g
F P
s
P
p
.002 w
.49744 .26514 m .51686 .26763 L .52686 .25414 L p
1 g
F P
s
P
p
.002 w
.49786 .25038 m .46877 .25436 L .47795 .26779 L p
1 g
F P
s
P
p
.002 w
.47795 .26779 m .49744 .26514 L .49786 .25038 L p
1 g
F P
s
P
p
.002 w
.65201 .32931 m .65211 .36786 L .66909 .38691 L p
1 g
F P
s
P
p
.002 w
.65211 .36786 m .65201 .32931 L .63112 .31705 L p
1 g
F P
s
P
p
.002 w
.55226 .26512 m .57113 .28188 L .59427 .28136 L p
1 g
F P
s
P
p
.002 w
.52686 .25414 m .49786 .25038 L .49744 .26514 L p
1 g
F P
s
P
p
.002 w
.38082 .28577 m .36454 .31828 L .38762 .30902 L p
1 g
F P
s
P
p
.002 w
.38762 .30902 m .40137 .28216 L .38082 .28577 L p
1 g
F P
s
P
p
.002 w
.42639 .2599 m .40137 .28216 L .42383 .28249 L p
1 g
F P
s
P
p
.002 w
.42383 .28249 m .44309 .26555 L .42639 .2599 L p
1 g
F P
s
P
p
.002 w
.52801 .60349 m .58215 .59139 L .5848 .57441 L p
1 g
F P
s
P
p
.002 w
.63396 .55023 m .5848 .57441 L .58215 .59139 L p
1 g
F P
s
P
p
.002 w
.5848 .57441 m .63396 .55023 L .63494 .52955 L p
1 g
F P
s
P
p
.002 w
.30774 .43182 m .32777 .47425 L .33419 .45103 L p
1 g
F P
s
P
p
.002 w
.33419 .45103 m .31518 .40972 L .30774 .43182 L p
1 g
F P
s
P
p
.002 w
.6727 .49459 m .63494 .52955 L .63396 .55023 L p
1 g
F P
s
P
p
.002 w
.63494 .52955 m .6727 .49459 L .66959 .47199 L p
1 g
F P
s
P
p
.002 w
.32786 .34632 m .32725 .38879 L .34346 .36948 L p
1 g
F P
s
P
p
.002 w
.34346 .36948 m .34441 .33077 L .32786 .34632 L p
1 g
F P
s
P
p
.002 w
.3708 .57044 m .41764 .59273 L .41379 .57575 L p
1 g
F P
s
P
p
.002 w
.41379 .57575 m .365 .55227 L .3708 .57044 L p
1 g
F P
s
P
p
.002 w
.32833 .51862 m .365 .55227 L .36288 .53154 L p
1 g
F P
s
P
p
.002 w
.36288 .53154 m .32573 .49698 L .32833 .51862 L p
1 g
F P
s
P
p
.002 w
.61562 .28478 m .63112 .31705 L .65201 .32931 L p
1 g
F P
s
P
p
.002 w
.63112 .31705 m .61562 .28478 L .59427 .28136 L p
1 g
F P
s
P
p
.002 w
.59427 .28136 m .56981 .25934 L .55226 .26512 L p
1 g
F P
s
P
p
.002 w
.52686 .25414 m .55226 .26512 L .56981 .25934 L p
1 g
F P
s
P
p
.002 w
.46006 .24512 m .42639 .2599 L .44309 .26555 L p
1 g
F P
s
P
p
.002 w
.44309 .26555 m .46877 .25436 L .46006 .24512 L p
1 g
F P
s
P
p
.002 w
.69048 .4295 m .66959 .47199 L .6727 .49459 L p
1 g
F P
s
P
p
.002 w
.66959 .47199 m .69048 .4295 L .68204 .4076 L p
1 g
F P
s
P
p
.002 w
.66943 .34463 m .66909 .38691 L .68204 .4076 L p
1 g
F P
s
P
p
.002 w
.66909 .38691 m .66943 .34463 L .65201 .32931 L p
1 g
F P
s
P
p
.002 w
.47413 .61635 m .52673 .61591 L .52801 .60349 L p
1 g
F P
s
P
p
.002 w
.52801 .60349 m .47161 .60396 L .47413 .61635 L p
1 g
F P
s
P
p
.002 w
.58215 .59139 m .52801 .60349 L .52673 .61591 L p
1 g
F P
s
P
p
.002 w
.42385 .60599 m .47413 .61635 L .47161 .60396 L p
1 g
F P
s
P
p
.002 w
.47161 .60396 m .41764 .59273 L .42385 .60599 L p
1 g
F P
s
P
p
.002 w
.3628 .29342 m .34441 .33077 L .36454 .31828 L p
1 g
F P
s
P
p
.002 w
.36454 .31828 m .38082 .28577 L .3628 .29342 L p
1 g
F P
s
P
p
.002 w
.56981 .25934 m .59427 .28136 L .61562 .28478 L p
1 g
F P
s
P
p
.002 w
.30533 .45456 m .32573 .49698 L .32777 .47425 L p
1 g
F P
s
P
p
.002 w
.32777 .47425 m .30774 .43182 L .30533 .45456 L p
1 g
F P
s
P
p
.002 w
.31548 .36466 m .31518 .40972 L .32725 .38879 L p
1 g
F P
s
P
p
.002 w
.32725 .38879 m .32786 .34632 L .31548 .36466 L p
1 g
F P
s
P
p
.002 w
.41105 .25864 m .38082 .28577 L .40137 .28216 L p
1 g
F P
s
P
p
.002 w
.40137 .28216 m .42639 .2599 L .41105 .25864 L p
1 g
F P
s
P
p
.002 w
.56981 .25934 m .53653 .24483 L .52686 .25414 L p
1 g
F P
s
P
p
.002 w
.49786 .25038 m .52686 .25414 L .53653 .24483 L p
1 g
F P
s
P
p
.002 w
.49837 .23985 m .46006 .24512 L .46877 .25436 L p
1 g
F P
s
P
p
.002 w
.46877 .25436 m .49786 .25038 L .49837 .23985 L p
1 g
F P
s
P
p
.002 w
.58215 .59139 m .62937 .56842 L .63396 .55023 L p
1 g
F P
s
P
p
.002 w
.67125 .51617 m .63396 .55023 L .62937 .56842 L p
1 g
F P
s
P
p
.002 w
.63396 .55023 m .67125 .51617 L .6727 .49459 L p
1 g
F P
s
P
p
.002 w
.53653 .24483 m .49837 .23985 L .49786 .25038 L p
1 g
F P
s
P
p
.002 w
.52673 .61591 m .5772 .60472 L .58215 .59139 L p
1 g
F P
s
P
p
.002 w
.62937 .56842 m .58215 .59139 L .5772 .60472 L p
1 g
F P
s
P
p
.002 w
.33573 .53857 m .3708 .57044 L .365 .55227 L p
1 g
F P
s
P
p
.002 w
.365 .55227 m .32833 .51862 L .33573 .53857 L p
1 g
F P
s
P
p
.002 w
.38035 .58546 m .42385 .60599 L .41764 .59273 L p
1 g
F P
s
P
p
.002 w
.41764 .59273 m .3708 .57044 L .38035 .58546 L p
1 g
F P
s
P
p
.002 w
.63456 .29225 m .65201 .32931 L .66943 .34463 L p
1 g
F P
s
P
p
.002 w
.65201 .32931 m .63456 .29225 L .61562 .28478 L p
1 g
F P
s
P
p
.002 w
.68279 .36275 m .68204 .4076 L .69048 .4295 L p
1 g
F P
s
P
p
.002 w
.68204 .4076 m .68279 .36275 L .66943 .34463 L p
1 g
F P
s
P
p
.002 w
.69399 .4521 m .6727 .49459 L .67125 .51617 L p
1 g
F P
s
P
p
.002 w
.6727 .49459 m .69399 .4521 L .69048 .4295 L p
1 g
F P
s
P
p
.002 w
.34791 .30512 m .32786 .34632 L .34441 .33077 L p
1 g
F P
s
P
p
.002 w
.34441 .33077 m .3628 .29342 L .34791 .30512 L p
1 g
F P
s
P
p
.002 w
.61562 .28478 m .58612 .25796 L .56981 .25934 L p
1 g
F P
s
P
p
.002 w
.53653 .24483 m .56981 .25934 L .58612 .25796 L p
1 g
F P
s
P
p
.002 w
.45207 .24055 m .41105 .25864 L .42639 .2599 L p
1 g
F P
s
P
p
.002 w
.42639 .2599 m .46006 .24512 L .45207 .24055 L p
1 g
F P
s
P
p
.002 w
.30783 .38542 m .30774 .43182 L .31518 .40972 L p
1 g
F P
s
P
p
.002 w
.31518 .40972 m .31548 .36466 L .30783 .38542 L p
1 g
F P
s
P
p
.002 w
.58612 .25796 m .61562 .28478 L .63456 .29225 L p
1 g
F P
s
P
p
.002 w
.30825 .47735 m .32833 .51862 L .32573 .49698 L p
1 g
F P
s
P
p
.002 w
.32573 .49698 m .30533 .45456 L .30825 .47735 L p
1 g
F P
s
P
p
.002 w
.47746 .62421 m .52468 .62381 L .52673 .61591 L p
1 g
F P
s
P
p
.002 w
.52673 .61591 m .47413 .61635 L .47746 .62421 L p
1 g
F P
s
P
p
.002 w
.5772 .60472 m .52673 .61591 L .52468 .62381 L p
1 g
F P
s
P
p
.002 w
.39754 .26207 m .3628 .29342 L .38082 .28577 L p
1 g
F P
s
P
p
.002 w
.38082 .28577 m .41105 .25864 L .39754 .26207 L p
1 g
F P
s
P
p
.002 w
.43239 .61498 m .47746 .62421 L .47413 .61635 L p
1 g
F P
s
P
p
.002 w
.47413 .61635 m .42385 .60599 L .43239 .61498 L p
1 g
F P
s
P
p
.002 w
.5772 .60472 m .62109 .58353 L .62937 .56842 L p
1 g
F P
s
P
p
.002 w
.66509 .53613 m .62937 .56842 L .62109 .58353 L p
1 g
F P
s
P
p
.002 w
.62937 .56842 m .66509 .53613 L .67125 .51617 L p
1 g
F P
s
P
p
.002 w
.58612 .25796 m .54561 .24021 L .53653 .24483 L p
1 g
F P
s
P
p
.002 w
.49837 .23985 m .53653 .24483 L .54561 .24021 L p
1 g
F P
s
P
p
.002 w
.49894 .23409 m .45207 .24055 L .46006 .24512 L p
1 g
F P
s
P
p
.002 w
.46006 .24512 m .49837 .23985 L .49894 .23409 L p
1 g
F P
s
P
p
.002 w
.65047 .30378 m .66943 .34463 L .68279 .36275 L p
1 g
F P
s
P
p
.002 w
.66943 .34463 m .65047 .30378 L .63456 .29225 L p
1 g
F P
s
P
p
.002 w
.34795 .55616 m .38035 .58546 L .3708 .57044 L p
1 g
F P
s
P
p
.002 w
.3708 .57044 m .33573 .53857 L .34795 .55616 L p
1 g
F P
s
P
p
.002 w
.69152 .38332 m .69048 .4295 L .69399 .4521 L p
1 g
F P
s
P
p
.002 w
.69048 .4295 m .69152 .38332 L .68279 .36275 L p
1 g
F P
s
P
p
.002 w
.52468 .62381 m .56993 .61383 L .5772 .60472 L p
1 g
F P
s
P
p
.002 w
.62109 .58353 m .5772 .60472 L .56993 .61383 L p
1 g
F P
s
P
p
.002 w
.54561 .24021 m .49894 .23409 L .49837 .23985 L p
1 g
F P
s
P
p
.002 w
.39357 .59673 m .43239 .61498 L .42385 .60599 L p
1 g
F P
s
P
p
.002 w
.42385 .60599 m .38035 .58546 L .39357 .59673 L p
1 g
F P
s
P
p
.002 w
.69225 .47481 m .67125 .51617 L .66509 .53613 L p
1 g
F P
s
P
p
.002 w
.67125 .51617 m .69225 .47481 L .69399 .4521 L p
1 g
F P
s
P
p
.002 w
.33675 .32076 m .31548 .36466 L .32786 .34632 L p
1 g
F P
s
P
p
.002 w
.32786 .34632 m .34791 .30512 L .33675 .32076 L p
1 g
F P
s
P
p
.002 w
.30535 .40813 m .30533 .45456 L .30774 .43182 L p
1 g
F P
s
P
p
.002 w
.30774 .43182 m .30783 .38542 L .30535 .40813 L p
1 g
F P
s
P
p
.002 w
.63456 .29225 m .6007 .26128 L .58612 .25796 L p
1 g
F P
s
P
p
.002 w
.54561 .24021 m .58612 .25796 L .6007 .26128 L p
1 g
F P
s
P
p
.002 w
.6007 .26128 m .63456 .29225 L .65047 .30378 L p
1 g
F P
s
P
p
.002 w
.31668 .49953 m .33573 .53857 L .32833 .51862 L p
1 g
F P
s
P
p
.002 w
.32833 .51862 m .30825 .47735 L .31668 .49953 L p
1 g
F P
s
P
p
.002 w
.44508 .24108 m .39754 .26207 L .41105 .25864 L p
1 g
F P
s
P
p
.002 w
.41105 .25864 m .45207 .24055 L .44508 .24108 L p
1 g
F P
s
P
p
.002 w
.38638 .27038 m .34791 .30512 L .3628 .29342 L p
1 g
F P
s
P
p
.002 w
.3628 .29342 m .39754 .26207 L .38638 .27038 L p
1 g
F P
s
P
p
.004 w
.6028 .59436 m
.60328 .59514 L
s
P
p
.004 w
.60328 .59514 m
.62114 .6236 L
s
P
p
.004 w
.62114 .6236 m
.65528 .67802 L
s
P
p
.002 w
.48156 .62703 m .52184 .62669 L .52468 .62381 L p
1 g
F P
s
P
p
.002 w
.52468 .62381 m .47746 .62421 L .48156 .62703 L p
1 g
F P
s
P
p
.002 w
.56993 .61383 m .52468 .62381 L .52184 .62669 L p
1 g
F P
s
P
p
.002 w
.68279 .36275 m .66273 .31925 L .65047 .30378 L p
1 g
F P
s
P
p
.002 w
.66273 .31925 m .68279 .36275 L .69152 .38332 L p
1 g
F P
s
P
p
.002 w
.44319 .61919 m .48156 .62703 L .47746 .62421 L p
1 g
F P
s
P
p
.002 w
.47746 .62421 m .43239 .61498 L .44319 .61919 L p
1 g
F P
s
P
p
.002 w
.56993 .61383 m .60914 .59497 L .62109 .58353 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.60254 .59396 L
s
P
p
.002 w
.65412 .55383 m .62109 .58353 L .60914 .59497 L p
1 g
F P
s
P
p
.002 w
.62109 .58353 m .65412 .55383 L .66509 .53613 L p
1 g
F P
s
P
p
.002 w
.69399 .4521 m .69516 .40589 L .69152 .38332 L p
1 g
F P
s
P
p
.002 w
.69516 .40589 m .69399 .4521 L .69225 .47481 L p
1 g
F P
s
P
p
.004 w
.50539 .64342 m
.50606 .67002 L
s
P
p
.002 w
.6007 .26128 m .5538 .24069 L .54561 .24021 L p
1 g
F P
s
P
p
.002 w
.49894 .23409 m .54561 .24021 L .5538 .24069 L p
1 g
F P
s
P
p
.002 w
.3649 .57079 m .39357 .59673 L .38035 .58546 L p
1 g
F P
s
P
p
.002 w
.38035 .58546 m .34795 .55616 L .3649 .57079 L p
1 g
F P
s
P
p
.002 w
.32986 .3401 m .30783 .38542 L .31548 .36466 L p
1 g
F P
s
P
p
.002 w
.31548 .36466 m .33675 .32076 L .32986 .3401 L p
1 g
F P
s
P
p
.002 w
.49956 .23357 m .44508 .24108 L .45207 .24055 L p
1 g
F P
s
P
p
.002 w
.45207 .24055 m .49894 .23409 L .49956 .23357 L p
1 g
F P
s
P
p
.002 w
.66509 .53613 m .68506 .49699 L .69225 .47481 L p
1 g
F P
s
P
p
.002 w
.68506 .49699 m .66509 .53613 L .65412 .55383 L p
1 g
F P
s
P
p
.002 w
.30836 .43219 m .30825 .47735 L .30533 .45456 L p
1 g
F P
s
P
p
.002 w
.30533 .45456 m .30535 .40813 L .30836 .43219 L p
1 g
F P
s
P
p
.002 w
.52184 .62669 m .5604 .6182 L .56993 .61383 L p
1 g
F P
s
P
p
.002 w
.60914 .59497 m .56993 .61383 L .5604 .6182 L p
1 g
F P
s
P
p
.002 w
.5538 .24069 m .49956 .23357 L .49894 .23409 L p
1 g
F P
s
P
p
.002 w
.41031 .60372 m .44319 .61919 L .43239 .61498 L p
1 g
F P
s
P
p
.002 w
.43239 .61498 m .39357 .59673 L .41031 .60372 L p
1 g
F P
s
P
p
.002 w
.3306 .52042 m .34795 .55616 L .33573 .53857 L p
1 g
F P
s
P
p
.002 w
.33573 .53857 m .31668 .49953 L .3306 .52042 L p
1 g
F P
s
P
p
.002 w
.65047 .30378 m .61303 .26947 L .6007 .26128 L p
1 g
F P
s
P
p
.002 w
.61303 .26947 m .65047 .30378 L .66273 .31925 L p
1 g
F P
s
P
p
.002 w
.5538 .24069 m .6007 .26128 L .61303 .26947 L p
1 g
F P
s
P
p
.002 w
.37803 .28362 m .33675 .32076 L .34791 .30512 L p
1 g
F P
s
P
p
.002 w
.34791 .30512 m .38638 .27038 L .37803 .28362 L p
1 g
F P
s
P
p
.002 w
.43935 .24704 m .38638 .27038 L .39754 .26207 L p
1 g
F P
s
P
p
.002 w
.39754 .26207 m .44508 .24108 L .43935 .24704 L p
1 g
F P
s
P
p
.002 w
.6708 .33843 m .69152 .38332 L .69516 .40589 L p
1 g
F P
s
P
p
.002 w
.69152 .38332 m .6708 .33843 L .66273 .31925 L p
1 g
F P
s
P
p
.002 w
.69336 .42986 m .69225 .47481 L .68506 .49699 L p
1 g
F P
s
P
p
.002 w
.69225 .47481 m .69336 .42986 L .69516 .40589 L p
1 g
F P
s
P
p
.002 w
.5604 .6182 m .59364 .60221 L .60914 .59497 L p
1 g
F P
s
P
p
.002 w
.60914 .59497 m .63843 .56865 L .65412 .55383 L p
1 g
F P
s
P
p
.002 w
.63843 .56865 m .60914 .59497 L .59364 .60221 L p
1 g
F P
s
P
p
.002 w
.32767 .36272 m .30535 .40813 L .30783 .38542 L p
1 g
F P
s
P
p
.002 w
.30783 .38542 m .32986 .3401 L .32767 .36272 L p
1 g
F P
s
P
p
.002 w
.48637 .6244 m .51827 .62412 L .52184 .62669 L p
1 g
F P
s
P
p
.002 w
.52184 .62669 m .48156 .62703 L .48637 .6244 L p
1 g
F P
s
P
p
.002 w
.5604 .6182 m .52184 .62669 L .51827 .62412 L p
1 g
F P
s
P
p
.002 w
.31703 .45692 m .31668 .49953 L .30825 .47735 L p
1 g
F P
s
P
p
.002 w
.30825 .47735 m .30836 .43219 L .31703 .45692 L p
1 g
F P
s
P
p
.002 w
.67238 .51796 m .65412 .55383 L .63843 .56865 L p
1 g
F P
s
P
p
.002 w
.65412 .55383 m .67238 .51796 L .68506 .49699 L p
1 g
F P
s
P
p
.002 w
.45605 .61818 m .48637 .6244 L .48156 .62703 L p
1 g
F P
s
P
p
.002 w
.48156 .62703 m .44319 .61919 L .45605 .61818 L p
1 g
F P
s
P
p
.002 w
.38628 .58184 m .41031 .60372 L .39357 .59673 L p
1 g
F P
s
P
p
.002 w
.39357 .59673 m .3649 .57079 L .38628 .58184 L p
1 g
F P
s
P
p
.002 w
.61303 .26947 m .56082 .24659 L .5538 .24069 L p
1 g
F P
s
P
p
.002 w
.49956 .23357 m .5538 .24069 L .56082 .24659 L p
1 g
F P
s
P
p
.002 w
.34984 .53928 m .3649 .57079 L .34795 .55616 L p
1 g
F P
s
P
p
.002 w
.34795 .55616 m .3306 .52042 L .34984 .53928 L p
1 g
F P
s
P
p
.002 w
.50022 .23867 m .43935 .24704 L .44508 .24108 L p
1 g
F P
s
P
p
.002 w
.44508 .24108 m .49956 .23357 L .50022 .23867 L p
1 g
F P
s
P
p
.002 w
.51827 .62412 m .54874 .6174 L .5604 .6182 L p
1 g
F P
s
P
p
.002 w
.59364 .60221 m .5604 .6182 L .54874 .6174 L p
1 g
F P
s
P
p
.002 w
.62262 .2826 m .66273 .31925 L .6708 .33843 L p
1 g
F P
s
P
p
.002 w
.66273 .31925 m .62262 .2826 L .61303 .26947 L p
1 g
F P
s
P
p
.002 w
.43025 .60597 m .45605 .61818 L .44319 .61919 L p
1 g
F P
s
P
p
.002 w
.44319 .61919 m .41031 .60372 L .43025 .60597 L p
1 g
F P
s
P
p
.002 w
.56082 .24659 m .50022 .23867 L .49956 .23357 L p
1 g
F P
s
P
p
.002 w
.56082 .24659 m .61303 .26947 L .62262 .2826 L p
1 g
F P
s
P
p
.002 w
.67421 .36093 m .69516 .40589 L .69336 .42986 L p
1 g
F P
s
P
p
.002 w
.69516 .40589 m .67421 .36093 L .6708 .33843 L p
1 g
F P
s
P
p
.002 w
.37291 .30166 m .32986 .3401 L .33675 .32076 L p
1 g
F P
s
P
p
.002 w
.33675 .32076 m .37803 .28362 L .37291 .30166 L p
1 g
F P
s
P
p
.002 w
.68591 .45457 m .68506 .49699 L .67238 .51796 L p
1 g
F P
s
P
p
.002 w
.68506 .49699 m .68591 .45457 L .69336 .42986 L p
1 g
F P
s
P
p
.002 w
.43514 .25858 m .37803 .28362 L .38638 .27038 L p
1 g
F P
s
P
p
.002 w
.38638 .27038 m .43935 .24704 L .43514 .25858 L p
1 g
F P
s
P
p
.002 w
.33048 .38806 m .30836 .43219 L .30535 .40813 L p
1 g
F P
s
P
p
.002 w
.30535 .40813 m .32767 .36272 L .33048 .38806 L p
1 g
F P
s
P
p
.002 w
.3313 .48154 m .3306 .52042 L .31668 .49953 L p
1 g
F P
s
P
p
.002 w
.31668 .49953 m .31703 .45692 L .3313 .48154 L p
1 g
F P
s
P
p
.002 w
.54874 .6174 m .57487 .60478 L .59364 .60221 L p
1 g
F P
s
P
p
.002 w
.61824 .57999 m .59364 .60221 L .57487 .60478 L p
1 g
F P
s
P
p
.002 w
.59364 .60221 m .61824 .57999 L .63843 .56865 L p
1 g
F P
s
P
p
.002 w
.65434 .53702 m .63843 .56865 L .61824 .57999 L p
1 g
F P
s
P
p
.002 w
.63843 .56865 m .65434 .53702 L .67238 .51796 L p
1 g
F P
s
P
p
.002 w
.41163 .58881 m .43025 .60597 L .41031 .60372 L p
1 g
F P
s
P
p
.002 w
.41031 .60372 m .38628 .58184 L .41163 .58881 L p
1 g
F P
s
P
p
.002 w
.37397 .55544 m .38628 .58184 L .3649 .57079 L p
1 g
F P
s
P
p
.002 w
.3649 .57079 m .34984 .53928 L .37397 .55544 L p
1 g
F P
s
P
p
.002 w
.49178 .61603 m .514 .61584 L .51827 .62412 L p
1 g
F P
s
P
p
.002 w
.51827 .62412 m .48637 .6244 L .49178 .61603 L p
1 g
F P
s
P
p
.002 w
.54874 .6174 m .51827 .62412 L .514 .61584 L p
1 g
F P
s
P
p
.002 w
.47071 .61167 m .49178 .61603 L .48637 .6244 L p
1 g
F P
s
P
p
.002 w
.48637 .6244 m .45605 .61818 L .47071 .61167 L p
1 g
F P
s
P
p
.002 w
.62901 .30053 m .6708 .33843 L .67421 .36093 L p
1 g
F P
s
P
p
.002 w
.6708 .33843 m .62901 .30053 L .62262 .2826 L p
1 g
F P
s
P
p
.002 w
.62262 .2826 m .56637 .25808 L .56082 .24659 L p
1 g
F P
s
P
p
.002 w
.50022 .23867 m .56082 .24659 L .56637 .25808 L p
1 g
F P
s
P
p
.002 w
.67262 .38618 m .69336 .42986 L .68591 .45457 L p
1 g
F P
s
P
p
.002 w
.69336 .42986 m .67262 .38618 L .67421 .36093 L p
1 g
F P
s
P
p
.002 w
.67281 .47926 m .67238 .51796 L .65434 .53702 L p
1 g
F P
s
P
p
.002 w
.67238 .51796 m .67281 .47926 L .68591 .45457 L p
1 g
F P
s
P
p
.002 w
.50091 .24959 m .43514 .25858 L .43935 .24704 L p
1 g
F P
s
P
p
.002 w
.43935 .24704 m .50022 .23867 L .50091 .24959 L p
1 g
F P
s
P
p
.002 w
.514 .61584 m .5352 .61113 L .54874 .6174 L p
1 g
F P
s
P
p
.002 w
.57487 .60478 m .54874 .6174 L .5352 .61113 L p
1 g
F P
s
P
p
.002 w
.45292 .60316 m .47071 .61167 L .45605 .61818 L p
1 g
F P
s
P
p
.002 w
.45605 .61818 m .43025 .60597 L .45292 .60316 L p
1 g
F P
s
P
p
.002 w
.3714 .32417 m .32767 .36272 L .32986 .3401 L p
1 g
F P
s
P
p
.002 w
.32986 .3401 m .37291 .30166 L .3714 .32417 L p
1 g
F P
s
P
p
.002 w
.56637 .25808 m .62262 .2826 L .62901 .30053 L p
1 g
F P
s
P
p
.002 w
.56637 .25808 m .50091 .24959 L .50022 .23867 L p
1 g
F P
s
P
p
.002 w
.35093 .50522 m .34984 .53928 L .3306 .52042 L p
1 g
F P
s
P
p
.002 w
.3306 .52042 m .3313 .48154 L .35093 .50522 L p
1 g
F P
s
P
p
.002 w
.33843 .41537 m .31703 .45692 L .30836 .43219 L p
1 g
F P
s
P
p
.002 w
.30836 .43219 m .33048 .38806 L .33843 .41537 L p
1 g
F P
s
P
p
.002 w
.43268 .27569 m .37291 .30166 L .37803 .28362 L p
1 g
F P
s
P
p
.002 w
.37803 .28362 m .43514 .25858 L .43268 .27569 L p
1 g
F P
s
P
p
.002 w
.57487 .60478 m .59398 .58734 L .61824 .57999 L p
1 g
F P
s
P
p
.002 w
.6313 .55348 m .61824 .57999 L .59398 .58734 L p
1 g
F P
s
P
p
.002 w
.61824 .57999 m .6313 .55348 L .65434 .53702 L p
1 g
F P
s
P
p
.002 w
.5352 .61113 m .55324 .60233 L .57487 .60478 L p
1 g
F P
s
P
p
.002 w
.59398 .58734 m .57487 .60478 L .55324 .60233 L p
1 g
F P
s
P
p
.002 w
.40238 .56825 m .41163 .58881 L .38628 .58184 L p
1 g
F P
s
P
p
.002 w
.38628 .58184 m .37397 .55544 L .40238 .56825 L p
1 g
F P
s
P
p
.002 w
.44026 .59128 m .45292 .60316 L .43025 .60597 L p
1 g
F P
s
P
p
.002 w
.43025 .60597 m .41163 .58881 L .44026 .59128 L p
1 g
F P
s
P
p
.002 w
.6318 .32295 m .67421 .36093 L .67262 .38618 L p
1 g
F P
s
P
p
.002 w
.67421 .36093 m .6318 .32295 L .62901 .30053 L p
1 g
F P
s
P
p
.002 w
.65429 .5031 m .65434 .53702 L .6313 .55348 L p
1 g
F P
s
P
p
.002 w
.65434 .53702 m .65429 .5031 L .67281 .47926 L p
1 g
F P
s
P
p
.002 w
.66585 .41346 m .68591 .45457 L .67281 .47926 L p
1 g
F P
s
P
p
.002 w
.68591 .45457 m .66585 .41346 L .67262 .38618 L p
1 g
F P
s
P
p
.002 w
.49766 .60182 m .50915 .60173 L .514 .61584 L p
1 g
F P
s
P
p
.002 w
.514 .61584 m .49178 .61603 L .49766 .60182 L p
1 g
F P
s
P
p
.002 w
.5352 .61113 m .514 .61584 L .50915 .60173 L p
1 g
F P
s
P
p
.002 w
.4868 .59955 m .49766 .60182 L .49178 .61603 L p
1 g
F P
s
P
p
.002 w
.49178 .61603 m .47071 .61167 L .4868 .59955 L p
1 g
F P
s
P
p
.002 w
.37538 .5271 m .37397 .55544 L .34984 .53928 L p
1 g
F P
s
P
p
.002 w
.34984 .53928 m .35093 .50522 L .37538 .5271 L p
1 g
F P
s
P
p
.002 w
.37371 .35059 m .33048 .38806 L .32767 .36272 L p
1 g
F P
s
P
p
.002 w
.32767 .36272 m .3714 .32417 L .37371 .35059 L p
1 g
F P
s
P
p
.002 w
.35144 .44379 m .3313 .48154 L .31703 .45692 L p
1 g
F P
s
P
p
.002 w
.31703 .45692 m .33843 .41537 L .35144 .44379 L p
1 g
F P
s
P
p
.002 w
.62901 .30053 m .57017 .27513 L .56637 .25808 L p
1 g
F P
s
P
p
.002 w
.50091 .24959 m .56637 .25808 L .57017 .27513 L p
1 g
F P
s
P
p
.002 w
.50915 .60173 m .52008 .59928 L .5352 .61113 L p
1 g
F P
s
P
p
.002 w
.55324 .60233 m .5352 .61113 L .52008 .59928 L p
1 g
F P
s
P
p
.002 w
.5016 .26635 m .43268 .27569 L .43514 .25858 L p
1 g
F P
s
P
p
.002 w
.43514 .25858 m .50091 .24959 L .5016 .26635 L p
1 g
F P
s
P
p
.002 w
.4777 .59513 m .4868 .59955 L .47071 .61167 L p
1 g
F P
s
P
p
.002 w
.47071 .61167 m .45292 .60316 L .4777 .59513 L p
1 g
F P
s
P
p
.002 w
.57017 .27513 m .62901 .30053 L .6318 .32295 L p
1 g
F P
s
P
p
.002 w
.55324 .60233 m .56625 .59026 L .59398 .58734 L p
1 g
F P
s
P
p
.002 w
.60384 .56668 m .59398 .58734 L .56625 .59026 L p
1 g
F P
s
P
p
.002 w
.59398 .58734 m .60384 .56668 L .6313 .55348 L p
1 g
F P
s
P
p
.002 w
.43421 .57718 m .44026 .59128 L .41163 .58881 L p
1 g
F P
s
P
p
.002 w
.41163 .58881 m .40238 .56825 L .43421 .57718 L p
1 g
F P
s
P
p
.002 w
.43216 .2981 m .3714 .32417 L .37291 .30166 L p
1 g
F P
s
P
p
.002 w
.37291 .30166 m .43268 .27569 L .43216 .2981 L p
1 g
F P
s
P
p
.002 w
.57017 .27513 m .5016 .26635 L .50091 .24959 L p
1 g
F P
s
P
p
.002 w
.63079 .52524 m .6313 .55348 L .60384 .56668 L p
1 g
F P
s
P
p
.002 w
.6313 .55348 m .63079 .52524 L .65429 .5031 L p
1 g
F P
s
P
p
.002 w
.52008 .59928 m .52932 .59471 L .55324 .60233 L p
1 g
F P
s
P
p
.002 w
.56625 .59026 m .55324 .60233 L .52932 .59471 L p
1 g
F P
s
P
p
.002 w
.65394 .44191 m .67281 .47926 L .65429 .5031 L p
1 g
F P
s
P
p
.002 w
.67281 .47926 m .65394 .44191 L .66585 .41346 L p
1 g
F P
s
P
p
.002 w
.47133 .58901 m .4777 .59513 L .45292 .60316 L p
1 g
F P
s
P
p
.002 w
.45292 .60316 m .44026 .59128 L .47133 .58901 L p
1 g
F P
s
P
p
.002 w
.63072 .3493 m .67262 .38618 L .66585 .41346 L p
1 g
F P
s
P
p
.002 w
.67262 .38618 m .63072 .3493 L .6318 .32295 L p
1 g
F P
s
P
p
.002 w
.40393 .54637 m .40238 .56825 L .37397 .55544 L p
1 g
F P
s
P
p
.002 w
.37397 .55544 m .37538 .5271 L .40393 .54637 L p
1 g
F P
s
P
p
.002 w
.3692 .47231 m .35093 .50522 L .3313 .48154 L p
1 g
F P
s
P
p
.002 w
.3313 .48154 m .35144 .44379 L .3692 .47231 L p
1 g
F P
s
P
p
.002 w
.37993 .38017 m .33843 .41537 L .33048 .38806 L p
1 g
F P
s
P
p
.002 w
.33048 .38806 m .37371 .35059 L .37993 .38017 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50299 .54865 L
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.52932 .59471 m .53588 .58849 L .56625 .59026 L p
1 g
F P
s
P
p
.002 w
.57275 .57608 m .56625 .59026 L .53588 .58849 L p
1 g
F P
s
P
p
.002 w
.56625 .59026 m .57275 .57608 L .60384 .56668 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.46842 .58181 m .47133 .58901 L .44026 .59128 L p
1 g
F P
s
P
p
.002 w
.44026 .59128 m .43421 .57718 L .46842 .58181 L p
1 g
F P
s
P
p
.002 w
.50915 .60173 m .49766 .60182 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.52008 .59928 m .50915 .60173 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.49766 .60182 m .4868 .59955 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.603 .54488 m .60384 .56668 L .57275 .57608 L p
1 g
F P
s
P
p
.002 w
.60384 .56668 m .603 .54488 L .63079 .52524 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.63714 .47055 m .65429 .5031 L .63079 .52524 L p
1 g
F P
s
P
p
.002 w
.65429 .5031 m .63714 .47055 L .65394 .44191 L p
1 g
F P
s
P
p
.002 w
.6318 .32295 m .57201 .29749 L .57017 .27513 L p
1 g
F P
s
P
p
.002 w
.5016 .26635 m .57017 .27513 L .57201 .29749 L p
1 g
F P
s
P
p
.002 w
.57201 .29749 m .6318 .32295 L .63072 .3493 L p
1 g
F P
s
P
p
.002 w
.52932 .59471 m .52008 .59928 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.4868 .59955 m .4777 .59513 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.43561 .56231 m .43421 .57718 L .40238 .56825 L p
1 g
F P
s
P
p
.002 w
.40238 .56825 m .40393 .54637 L .43561 .56231 L p
1 g
F P
s
P
p
.002 w
.50226 .28869 m .43216 .2981 L .43268 .27569 L p
1 g
F P
s
P
p
.002 w
.43268 .27569 m .5016 .26635 L .50226 .28869 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.4337 .32527 m .37371 .35059 L .3714 .32417 L p
1 g
F P
s
P
p
.002 w
.3714 .32417 m .43216 .2981 L .4337 .32527 L p
1 g
F P
s
P
p
.002 w
.53588 .58849 m .52932 .59471 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.39117 .49992 m .37538 .5271 L .35093 .50522 L p
1 g
F P
s
P
p
.002 w
.35093 .50522 m .3692 .47231 L .39117 .49992 L p
1 g
F P
s
P
p
.002 w
.62563 .37884 m .66585 .41346 L .65394 .44191 L p
1 g
F P
s
P
p
.002 w
.66585 .41346 m .62563 .37884 L .63072 .3493 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.4777 .59513 m .47133 .58901 L .50383 .58192 L closepath p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.57201 .29749 m .50226 .28869 L .5016 .26635 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.53588 .58849 m .53904 .58125 L .57275 .57608 L p
1 g
F P
s
P
p
.002 w
.57184 .56125 m .57275 .57608 L .53904 .58125 L p
1 g
F P
s
P
p
.002 w
.57275 .57608 m .57184 .56125 L .603 .54488 L p
1 g
F P
s
P
p
.002 w
.38998 .41191 m .35144 .44379 L .33843 .41537 L p
1 g
F P
s
P
p
.002 w
.33843 .41537 m .37993 .38017 L .38998 .41191 L p
1 g
F P
s
P
p
.002 w
.53904 .58125 m .50757 .58185 L p
.51145 .58083 L 1 g
F P
s
P
p
.002 w
.47133 .58901 m .46842 .58181 L .49368 .58189 L p
1 g
F P
s
P
p
.002 w
.49368 .58189 m .50383 .58192 L .49845 .5831 L p
1 g
F P
s
P
p
.002 w
.49845 .5831 m .47133 .58901 L p
.49368 .58189 L 1 g
F P
s
P
p
.002 w
.46842 .58181 m .43421 .57718 L p
.46676 .57451 L 1 g
F P
s
P
p
.46676 .57451 m .46819 .57508 L .46842 .58181 L 1 g
F
P
p
.002 w
.46918 .57547 m .46915 .57572 L p
.46819 .57508 L 1 g
F P
s
P
p
.002 w
.46915 .57572 m .46842 .58181 L p
.46819 .57508 L 1 g
F P
s
P
p
.002 w
.46819 .57508 m .46872 .57265 L p
.45903 .56878 L 1 g
F P
s
P
p
.002 w
.46441 .57255 m .4565 .56974 L p
.45302 .56457 L 1 g
F P
s
P
p
.002 w
.4565 .56974 m .43561 .56231 L p
.45202 .56444 L 1 g
F P
s
P
p
.45202 .56444 m .45302 .56457 L .4565 .56974 L 1 g
F
P
p
.002 w
.43561 .56231 m .40393 .54637 L p
.43858 .54801 L 1 g
F P
s
P
p
.002 w
.43835 .54735 m .43925 .54566 L p
.43539 .53802 L 1 g
F P
s
P
p
.002 w
.43644 .5417 m .43211 .53818 L p
.43303 .52978 L 1 g
F P
s
P
p
.002 w
.43211 .53818 m .4166 .52556 L p
.43259 .52967 L 1 g
F P
s
P
p
.43259 .52967 m .43303 .52978 L .43211 .53818 L 1 g
F
P
p
.002 w
.4166 .52556 m .39117 .49992 L p
.43407 .50739 L 1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43407 .50739 m .43387 .50942 L .4166 .52556 L 1 g
F
P
p
.002 w
.43356 .51272 m .43165 .51417 L p
.43387 .50942 L 1 g
F P
s
P
p
.002 w
.43165 .51417 m .4166 .52556 L p
.43387 .50942 L 1 g
F P
s
P
p
.002 w
.43387 .50942 m .43485 .50826 L p
.43832 .50015 L 1 g
F P
s
P
p
.42025 .47722 m .44487 .48695 L .4428 .49113 L 1 g
F
P
p
.002 w
.43655 .50371 m .43403 .49963 L p
.4428 .49113 L 1 g
F P
s
P
p
.002 w
.43403 .49963 m .42025 .47722 L p
.4428 .49113 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43387 .50942 L p
1 g
F P
s
P
p
.002 w
.4166 .52556 m .4291 .5161 L p
.43259 .52967 L 1 g
F P
s
P
p
.002 w
.4291 .5161 m .43356 .51272 L p
.43266 .52851 L 1 g
F P
s
P
p
.4291 .5161 m .43266 .52851 L .43259 .52967 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43266 .52851 L p
1 g
F P
s
P
p
.43925 .54566 m .43266 .52851 L .43539 .53802 L 1 g
F
P
p
.43346 .52734 m .43387 .50942 L .43356 .51272 L 1 g
F
P
p
.43318 .51932 m .43356 .51272 L .43311 .51736 L 1 g
F
P
p
.43346 .52734 m .43356 .51272 L .43318 .51932 L 1 g
F
P
p
.002 w
.43266 .52851 m .43346 .52734 L p
.43318 .51932 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43938 .50831 m .46023 .53677 L p
.43259 .52967 L 1 g
F P
s
P
p
.002 w
.43356 .51272 m .43938 .50831 L p
.43259 .52967 L 1 g
F P
s
P
p
.002 w
.43266 .52851 m .43146 .53025 L p
.43539 .53802 L 1 g
F P
s
P
p
.43311 .51736 m .43356 .51272 L .43287 .51061 L 1 g
F
P
p
.002 w
.43387 .50942 m .43373 .50959 L p
.43356 .51272 L 1 g
F P
s
P
p
.002 w
.43373 .50959 m .43287 .51061 L p
.43356 .51272 L 1 g
F P
s
P
p
.002 w
.43938 .50831 m .43356 .51272 L p
.43387 .50942 L 1 g
F P
s
P
p
.43407 .50739 m .43477 .50751 L .43387 .50942 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4421 .49187 L p
1 g
F P
s
P
p
.43485 .50826 m .4421 .49187 L .43936 .49772 L 1 g
F
P
p
.43832 .50015 m .43655 .50371 L .43387 .50942 L 1 g
F
P
p
.43477 .50751 m .43938 .50831 L .43387 .50942 L 1 g
F
P
p
.002 w
.4421 .49187 m .44166 .49233 L p
.43936 .49772 L 1 g
F P
s
P
p
.002 w
.4428 .49113 m .44339 .4905 L p
.44829 .4858 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.4428 .49113 m .46986 .49683 L .43655 .50371 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45776 .47663 L p
1 g
F P
s
P
p
.44339 .4905 m .45776 .47663 L .44829 .4858 L 1 g
F
P
p
.44487 .48695 m .44646 .48758 L .4428 .49113 L 1 g
F
P
p
.44646 .48758 m .46986 .49683 L .4428 .49113 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45776 .47663 m .45826 .47608 L p
.4672 .47216 L 1 g
F P
s
P
p
.4714 .47011 m .50445 .49265 L .46315 .47414 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.4714 .47011 m .47941 .4668 L .50445 .49265 L 1 g
F
P
p
.47941 .4668 m .5 .46386 L .50445 .49265 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52236 .46704 L p
1 g
F P
s
P
p
.51232 .46568 m .53888 .49635 L .50441 .4646 L 1 g
F
P
p
.5 .4634 m .52236 .46704 L .51161 .46558 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.50439 .45652 m .549 .46146 L .54643 .47032 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56623 .50954 L p
1 g
F P
s
P
p
.55661 .4905 m .56623 .50954 L .56594 .50894 L 1 g
F
P
p
.002 w
.56892 .5074 m .56668 .5105 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56442 .50575 m .56595 .50631 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56595 .50631 m .56892 .5074 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56623 .50954 m .56515 .50826 L p
.56678 .51885 L 1 g
F P
s
P
p
.002 w
.56635 .51096 m .56668 .5105 L p
.56646 .51297 L 1 g
F P
s
P
p
.56678 .51885 m .56635 .51096 L .56623 .50954 L 1 g
F
P
p
.56807 .51357 m .56694 .52172 L .56668 .5105 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5618 .54763 L p
1 g
F P
s
P
p
.56654 .52734 m .5618 .54763 L .56204 .54699 L 1 g
F
P
p
.002 w
.56339 .5474 m .56139 .54872 L p
.5618 .54763 L 1 g
F P
s
P
p
.002 w
.56221 .54653 m .5625 .54674 L p
.5618 .54763 L 1 g
F P
s
P
p
.002 w
.5625 .54674 m .56339 .5474 L p
.5618 .54763 L 1 g
F P
s
P
p
.002 w
.5618 .54763 m .56075 .54566 L p
.55521 .5557 L 1 g
F P
s
P
p
.56339 .5474 m .55062 .56197 L .55321 .55813 L 1 g
F
P
p
.55062 .56197 m .54121 .5727 L .54918 .56302 L 1 g
F
P
p
.55062 .56197 m .54918 .56302 L .55321 .55813 L 1 g
F
P
p
.002 w
.56339 .5474 m .57184 .56125 L .54121 .5727 L p
1 g
F P
s
P
p
.002 w
.54918 .56302 m .54854 .56129 L p
.5386 .57076 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56302 L p
1 g
F P
s
P
p
.002 w
.54918 .56302 m .54934 .56343 L p
.55107 .56073 L 1 g
F P
s
P
p
.56075 .54566 m .54918 .56302 L .55107 .56073 L 1 g
F
P
p
.002 w
.56045 .54934 m .56339 .5474 L p
.55321 .55813 L 1 g
F P
s
P
p
.56075 .54566 m .54934 .56343 L .5547 .55663 L 1 g
F
P
p
.55521 .5557 m .56045 .54934 L .5618 .54763 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53839 .57375 m .53881 .57869 L p
.52241 .57997 L 1 g
F P
s
P
p
.52949 .57609 m .52241 .57997 L .51145 .58083 L 1 g
F
P
p
.53839 .57375 m .52241 .57997 L .52949 .57609 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53176 .57484 L p
1 g
F P
s
P
p
.54854 .56129 m .53176 .57484 L .53183 .5748 L 1 g
F
P
p
.002 w
.53839 .57375 m .53025 .57568 L p
.53176 .57484 L 1 g
F P
s
P
p
.002 w
.53715 .57182 m .53793 .57304 L p
.53176 .57484 L 1 g
F P
s
P
p
.002 w
.53793 .57304 m .53839 .57375 L p
.53176 .57484 L 1 g
F P
s
P
p
.002 w
.52288 .57742 m .53839 .57375 L p
.50757 .58185 L 1 g
F P
s
P
p
.002 w
.53176 .57484 m .53128 .57265 L p
.5208 .57803 L 1 g
F P
s
P
p
.53489 .57309 m .53176 .57485 L .53473 .57322 L 1 g
F
P
p
.54854 .56129 m .53183 .5748 L .53489 .57309 L 1 g
F
P
p
.53183 .5748 m .53176 .57485 L .53489 .57309 L 1 g
F
P
p
.54854 .56129 m .53193 .57564 L .5386 .57076 L 1 g
F
P
p
.002 w
.50383 .58192 m .46842 .58181 L .46868 .57965 L p
1 g
F P
s
P
p
.002 w
.51096 .58087 m .51079 .57862 L p
.49817 .58114 L 1 g
F P
s
P
p
.49817 .58114 m .50093 .58128 L .51096 .58087 L 1 g
F
P
p
.002 w
.50269 .58136 m .50383 .58192 L .50093 .58128 L p
1 g
F P
s
P
p
.50093 .58128 m .50214 .58134 L .5022 .58134 L 1 g
F
P
p
.50093 .58128 m .5022 .58134 L .51096 .58087 L 1 g
F
P
p
.50214 .58134 m .50279 .58137 L .51096 .58087 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46819 .57508 L p
1 g
F P
s
P
p
.002 w
.46819 .57508 m .46816 .57521 L p
.46875 .5753 L 1 g
F P
s
P
p
.48921 .57862 m .46819 .57508 L .46875 .5753 L 1 g
F
P
p
.002 w
.43421 .57718 m .43561 .56231 L .44118 .56429 L p
1 g
F P
s
P
p
.45903 .56878 m .46441 .57255 L .46819 .57508 L 1 g
F
P
p
.002 w
.44118 .56429 m .46932 .5743 L p
.46676 .57451 L 1 g
F P
s
P
p
.43421 .57718 m .44118 .56429 L .46676 .57451 L 1 g
F
P
p
.48921 .57862 m .46816 .57521 L .46852 .5753 L 1 g
F
P
p
.002 w
.46868 .57965 m .46918 .57547 L p
.48906 .58068 L 1 g
F P
s
P
p
.48921 .57862 m .46815 .57524 L .47725 .57764 L 1 g
F
P
p
.46868 .57965 m .48906 .58068 L .49051 .58106 L 1 g
F
P
p
.002 w
.48905 .58072 m .48906 .58068 L p
.47671 .57759 L 1 g
F P
s
P
p
.002 w
.48906 .58068 m .48921 .57862 L p
.47752 .57766 L 1 g
F P
s
P
p
.47752 .57766 m .47671 .57759 L .48906 .58068 L 1 g
F
P
p
.002 w
.50093 .58128 m .50383 .58192 L p
.49051 .58106 L 1 g
F P
s
P
p
.48906 .58068 m .50093 .58128 L .49051 .58106 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48892 .58251 L p
1 g
F P
s
P
p
.002 w
.48892 .58251 m .48889 .583 L p
.49273 .58223 L 1 g
F P
s
P
p
.51079 .57862 m .48892 .58251 L .49273 .58223 L 1 g
F
P
p
.50269 .58137 m .50316 .58138 L .51096 .58087 L 1 g
F
P
p
.50302 .58139 m .50344 .58139 L .51096 .58087 L 1 g
F
P
p
.50325 .5814 m .50372 .58139 L .51096 .58087 L 1 g
F
P
p
.50343 .58141 m .50408 .58138 L .51096 .58087 L 1 g
F
P
p
.50358 .58142 m .50393 .58139 L .51096 .58087 L 1 g
F
P
p
.002 w
.50325 .58138 m .50383 .58192 L .50269 .58136 L p
1 g
F P
s
P
p
.002 w
.50358 .58139 m .50383 .58192 L .50325 .58138 L p
1 g
F P
s
P
p
.002 w
.50384 .58139 m .50383 .58192 L .50358 .58139 L p
1 g
F P
s
P
p
.002 w
.5041 .58138 m .50383 .58192 L .50384 .58139 L p
1 g
F P
s
P
p
.002 w
.50443 .58136 m .50383 .58192 L .5041 .58138 L p
1 g
F P
s
P
p
.49273 .58223 m .50695 .58119 L .51096 .58087 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58087 L p
1 g
F P
s
P
p
.53128 .57265 m .51096 .58087 L .51122 .5808 L 1 g
F
P
p
.5208 .57803 m .51096 .5809 L .5203 .57828 L 1 g
F
P
p
.53128 .57265 m .51105 .58087 L .5208 .57803 L 1 g
F
P
p
.51105 .58087 m .51096 .5809 L .5208 .57803 L 1 g
F
P
p
.53715 .57182 m .53176 .57484 L .50695 .58119 L 1 g
F
P
p
.002 w
.53025 .57568 m .52288 .57742 L p
.53176 .57484 L 1 g
F P
s
P
p
.002 w
.52288 .57742 m .50695 .58119 L p
.53176 .57484 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53395 .56683 m .53715 .57182 L p
.50604 .58125 L 1 g
F P
s
P
p
.002 w
.50383 .58192 m .50502 .58133 L p
.50604 .58125 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.50502 .58133 m .53395 .56683 L p
.50604 .58125 L 1 g
F P
s
P
p
.002 w
.46932 .5743 m .50093 .58128 L p
.48906 .58068 L 1 g
F P
s
P
p
.002 w
.46918 .57547 m .46932 .5743 L p
.48906 .58068 L 1 g
F P
s
P
p
.002 w
.46816 .57521 m .46815 .57524 L p
.46852 .5753 L 1 g
F P
s
P
p
.002 w
.46815 .57524 m .4678 .57686 L p
.47725 .57764 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46932 .5743 m .474 .56729 L .50269 .58136 L p
1 g
F P
s
P
p
.002 w
.50093 .58128 m .46932 .5743 L p
.50269 .58136 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.474 .56729 m .48199 .56158 L .50325 .58138 L p
1 g
F P
s
P
p
.002 w
.50269 .58136 m .474 .56729 L p
.50325 .58138 L 1 g
F P
s
P
p
.50214 .58134 m .50269 .58137 L .50279 .58137 L 1 g
F
P
p
.50269 .58137 m .50302 .58139 L .50316 .58138 L 1 g
F
P
p
.002 w
.48199 .56158 m .49243 .55782 L .50358 .58139 L p
1 g
F P
s
P
p
.002 w
.50325 .58138 m .48199 .56158 L p
.50358 .58139 L 1 g
F P
s
P
p
.002 w
.49243 .55782 m .50416 .55646 L .50384 .58139 L p
1 g
F P
s
P
p
.002 w
.50358 .58139 m .49243 .55782 L p
.50384 .58139 L 1 g
F P
s
P
p
.50302 .58139 m .50325 .5814 L .50344 .58139 L 1 g
F
P
p
.50325 .5814 m .50343 .58141 L .50372 .58139 L 1 g
F
P
p
.002 w
.50416 .55646 m .51584 .55764 L .5041 .58138 L p
1 g
F P
s
P
p
.002 w
.50384 .58139 m .50416 .55646 L p
.5041 .58138 L 1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51584 .55764 m .52616 .56124 L .50443 .58136 L p
1 g
F P
s
P
p
.002 w
.5041 .58138 m .51584 .55764 L p
.50443 .58136 L 1 g
F P
s
P
p
.50343 .58141 m .50358 .58142 L .50408 .58138 L 1 g
F
P
p
.50358 .58142 m .50361 .58142 L .50393 .58139 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52616 .56124 m .53395 .56683 L .50502 .58133 L p
1 g
F P
s
P
p
.002 w
.50502 .58133 m .50383 .58192 L .50443 .58136 L p
1 g
F P
s
P
p
.002 w
.50443 .58136 m .52616 .56124 L p
.50502 .58133 L 1 g
F P
s
P
p
.49817 .58114 m .49273 .58223 L .50361 .58142 L 1 g
F
P
p
.49273 .58223 m .49214 .58235 L .50695 .58119 L 1 g
F
P
p
.002 w
.50695 .58119 m .50383 .58192 L p
.50604 .58125 L 1 g
F P
s
P
p
.53715 .57182 m .50695 .58119 L .50604 .58125 L 1 g
F
P
p
.002 w
.53881 .57869 m .53904 .58125 L p
.51145 .58083 L 1 g
F P
s
P
p
.002 w
.53904 .58125 m .53588 .58849 L .50585 .58234 L p
1 g
F P
s
P
p
.002 w
.50757 .58185 m .53904 .58125 L p
.50585 .58234 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53176 .57484 L p
1 g
F P
s
P
p
.5208 .57803 m .51111 .583 L .53176 .57484 L 1 g
F
P
p
.002 w
.53176 .57484 m .53176 .57485 L p
.53183 .5748 L 1 g
F P
s
P
p
.002 w
.53176 .57485 m .53193 .57564 L p
.53473 .57322 L 1 g
F P
s
P
p
.002 w
.53839 .57375 m .53715 .57182 L p
.54595 .56538 L 1 g
F P
s
P
p
.002 w
.53193 .57564 m .5322 .57686 L p
.5386 .57076 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53395 .56683 m .56045 .54934 L p
.54595 .56538 L 1 g
F P
s
P
p
.002 w
.53715 .57182 m .53395 .56683 L p
.54595 .56538 L 1 g
F P
s
P
p
.55321 .55813 m .53839 .57375 L .56045 .54934 L 1 g
F
P
p
.56654 .52734 m .56204 .54699 L .56455 .53824 L 1 g
F
P
p
.56204 .54699 m .56186 .54775 L .56221 .54653 L 1 g
F
P
p
.56204 .54699 m .56221 .54653 L .56455 .53824 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.56221 .54653 m .5618 .54763 L .53395 .56683 L 1 g
F
P
p
.002 w
.56139 .54872 m .56045 .54934 L p
.5618 .54763 L 1 g
F P
s
P
p
.002 w
.56045 .54934 m .53395 .56683 L p
.5618 .54763 L 1 g
F P
s
P
p
.002 w
.54934 .56343 m .54998 .56518 L p
.5547 .55663 L 1 g
F P
s
P
p
.002 w
.54121 .5727 m .53839 .57375 L p
.55321 .55813 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56302 L p
1 g
F P
s
P
p
.5386 .57076 m .5322 .57686 L .54918 .56302 L 1 g
F
P
p
.55521 .5557 m .5547 .55663 L .56045 .54934 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5618 .54763 L p
1 g
F P
s
P
p
.5547 .55663 m .54998 .56518 L .5618 .54763 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.54813 .53612 m .56221 .54653 L p
.53395 .56683 L 1 g
F P
s
P
p
.002 w
.5618 .54763 m .56186 .54775 L p
.56204 .54699 L 1 g
F P
s
P
p
.56476 .53749 m .56339 .5474 L .56405 .54001 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.56694 .52172 m .56646 .51297 L .56668 .5105 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56731 .52846 L p
1 g
F P
s
P
p
.56892 .5074 m .56814 .54344 L .56694 .52172 L 1 g
F
P
p
.002 w
.56731 .52846 m .56794 .52938 L p
.56695 .52189 L 1 g
F P
s
P
p
.56515 .50826 m .56731 .52846 L .56695 .52189 L 1 g
F
P
p
.002 w
.56892 .5074 m .59106 .5243 L .56814 .54344 L p
1 g
F P
s
P
p
.56515 .50826 m .56794 .52938 L .56735 .5225 L 1 g
F
P
p
.002 w
.56731 .52846 m .56654 .52734 L p
.56455 .53824 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56814 .54344 m .56339 .5474 L p
.56694 .52172 L 1 g
F P
s
P
p
.002 w
.56892 .5074 m .56442 .50575 L p
.549 .46146 L 1 g
F P
s
P
p
.002 w
.54662 .46969 m .549 .46146 L p
.56042 .49425 L 1 g
F P
s
P
p
.56042 .49425 m .56442 .50575 L .55721 .49114 L 1 g
F
P
p
.56042 .49425 m .55721 .49114 L .54662 .46969 L 1 g
F
P
p
.55661 .4905 m .56594 .50894 L .56289 .50251 L 1 g
F
P
p
.002 w
.56668 .5105 m .56892 .5074 L p
.56807 .51357 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55721 .49114 L p
1 g
F P
s
P
p
.54174 .47608 m .55721 .49114 L .54964 .48381 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56442 .50575 m .53888 .49635 L .54408 .47843 L p
1 g
F P
s
P
p
.54174 .47608 m .54964 .48381 L .54901 .4832 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55721 .49114 m .56442 .50575 L .54408 .47843 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54408 .47843 m .53888 .49635 L p
.5348 .47306 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .5423 .47669 L p
1 g
F P
s
P
p
.52214 .46667 m .5423 .47669 L .52996 .47072 L 1 g
F
P
p
.53403 .46863 m .5423 .47669 L .5348 .47306 L 1 g
F
P
p
.5423 .47669 m .54408 .47843 L .5348 .47306 L 1 g
F
P
p
.51232 .46568 m .52236 .46704 L .53888 .49635 L 1 g
F
P
p
.002 w
.52236 .46704 m .52214 .46667 L p
.52996 .47072 L 1 g
F P
s
P
p
.52236 .46704 m .53403 .46863 L .5348 .47306 L 1 g
F
P
p
.52236 .46704 m .5348 .47306 L .53888 .49635 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52236 .46704 L p
1 g
F P
s
P
p
.52996 .47072 m .54302 .47747 L .52236 .46704 L 1 g
F
P
p
.002 w
.5423 .47669 m .54302 .47747 L p
.52996 .47072 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54408 .47843 m .54662 .46969 L p
.55721 .49114 L 1 g
F P
s
P
p
.54901 .4832 m .55815 .49214 L .55518 .48924 L 1 g
F
P
p
.54964 .48381 m .55815 .49214 L .54901 .4832 L 1 g
F
P
p
.002 w
.55721 .49114 m .55815 .49214 L p
.54964 .48381 L 1 g
F P
s
P
p
.56289 .50251 m .56471 .50633 L .56423 .50509 L 1 g
F
P
p
.56471 .50633 m .56627 .5096 L .56571 .50834 L 1 g
F
P
p
.56471 .50633 m .56571 .50834 L .56423 .50509 L 1 g
F
P
p
.56594 .50894 m .56627 .5096 L .56289 .50251 L 1 g
F
P
p
.56442 .50575 m .56623 .50954 L .54813 .53612 L 1 g
F
P
p
.002 w
.56668 .5105 m .56635 .51096 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56635 .51096 m .54813 .53612 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56794 .52938 m .56854 .53025 L p
.56735 .5225 L 1 g
F P
s
P
p
.002 w
.54813 .53612 m .56635 .51096 L p
.56397 .5403 L 1 g
F P
s
P
p
.002 w
.56339 .5474 m .56221 .54653 L p
.56397 .5403 L 1 g
F P
s
P
p
.002 w
.56221 .54653 m .54813 .53612 L p
.56397 .5403 L 1 g
F P
s
P
p
.56646 .51297 m .56339 .5474 L .56635 .51096 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56731 .52846 L p
1 g
F P
s
P
p
.56455 .53824 m .56257 .5491 L .56731 .52846 L 1 g
F
P
p
.002 w
.56186 .54775 m .56257 .5491 L p
.56455 .53824 L 1 g
F P
s
P
p
.56694 .52172 m .56476 .53749 L .56646 .51297 L 1 g
F
P
p
.56476 .53749 m .56405 .54001 L .56646 .51297 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56627 .5096 L p
1 g
F P
s
P
p
.002 w
.56627 .5096 m .56623 .50954 L p
.56631 .51032 L 1 g
F P
s
P
p
.56631 .51032 m .56854 .53025 L .56627 .5096 L 1 g
F
P
p
.56678 .51885 m .56735 .5225 L .56635 .51096 L 1 g
F
P
p
.56735 .5225 m .56854 .53025 L .56623 .50954 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.53888 .49635 m .56442 .50575 L p
.54813 .53612 L 1 g
F P
s
P
p
.002 w
.56623 .50954 m .56627 .5096 L p
.56594 .50894 L 1 g
F P
s
P
p
.002 w
.56627 .5096 m .56713 .51061 L p
.56423 .50509 L 1 g
F P
s
P
p
.002 w
.55815 .49214 m .55834 .49233 L p
.55518 .48924 L 1 g
F P
s
P
p
.002 w
.54643 .47032 m .54408 .47843 L p
.53403 .46863 L 1 g
F P
s
P
p
.50439 .45652 m .54643 .47032 L .51232 .46568 L 1 g
F
P
p
.51069 .46546 m .52275 .46767 L .51867 .46699 L 1 g
F
P
p
.5 .4634 m .51161 .46558 L .51069 .46546 L 1 g
F
P
p
.51161 .46558 m .52275 .46767 L .51069 .46546 L 1 g
F
P
p
.002 w
.52236 .46704 m .52275 .46767 L p
.51161 .46558 L 1 g
F P
s
P
p
.002 w
.53888 .49635 m .50445 .49265 L .50441 .4646 L p
1 g
F P
s
P
p
.002 w
.50441 .4646 m .50445 .49265 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51867 .46699 L 1 g
F P
s
P
p
.51867 .46699 m .52282 .46778 L .5 .46386 L 1 g
F
P
p
.002 w
.50439 .45652 m .5044 .46323 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.47763 .46706 m .47786 .46667 L p
.48652 .46579 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .46442 L p
.48652 .46579 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46386 L .48652 .46579 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.49743 .45737 m .50439 .45652 L p
.4714 .47011 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.45957 .46203 m .49743 .45737 L p
.47763 .46706 L 1 g
F P
s
P
p
.46879 .46832 m .47763 .46706 L .4714 .47011 L 1 g
F
P
p
.45957 .46203 m .47763 .46706 L .46879 .46832 L 1 g
F
P
p
.47941 .4668 m .49044 .46226 L .5 .46386 L 1 g
F
P
p
.49044 .46226 m .50439 .45652 L .5 .46386 L 1 g
F
P
p
.002 w
.50441 .4646 m .50439 .45652 L p
.51232 .46568 L 1 g
F P
s
P
p
.002 w
.5044 .46323 m .50441 .4646 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52275 .46767 m .52282 .46778 L p
.51867 .46699 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47763 .46706 L p
1 g
F P
s
P
p
.48652 .46579 m .5 .46442 L .47763 .46706 L 1 g
F
P
p
.002 w
.50445 .49265 m .46986 .49683 L .46315 .47414 L p
1 g
F P
s
P
p
.002 w
.46315 .47414 m .46986 .49683 L p
.43977 .48493 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45751 .4769 L p
1 g
F P
s
P
p
.002 w
.45751 .4769 m .45776 .47663 L p
.46216 .47462 L 1 g
F P
s
P
p
.46216 .47462 m .47718 .46778 L .45751 .4769 L 1 g
F
P
p
.4672 .47216 m .47201 .47005 L .46315 .47414 L 1 g
F
P
p
.4672 .47216 m .46315 .47414 L .45776 .47663 L 1 g
F
P
p
.002 w
.46315 .47414 m .45957 .46203 L p
.4714 .47011 L 1 g
F P
s
P
p
.002 w
.42025 .47722 m .45957 .46203 L .46315 .47414 L p
1 g
F P
s
P
p
.42025 .47722 m .46315 .47414 L .43977 .48493 L 1 g
F
P
p
.47201 .47005 m .47718 .46778 L .45776 .47663 L 1 g
F
P
p
.002 w
.45776 .47663 m .45698 .47747 L p
.44829 .4858 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4428 .49113 L p
1 g
F P
s
P
p
.44829 .4858 m .45698 .47747 L .4428 .49113 L 1 g
F
P
p
.43832 .50015 m .43936 .49772 L .43655 .50371 L 1 g
F
P
p
.002 w
.46986 .49683 m .43938 .50831 L .43655 .50371 L p
1 g
F P
s
P
p
.002 w
.39117 .49992 m .42025 .47722 L .43938 .50831 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43387 .50942 L p
1 g
F P
s
P
p
.43936 .49772 m .44166 .49233 L .43387 .50942 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43194 .52955 L p
1 g
F P
s
P
p
.002 w
.43194 .52955 m .43266 .52851 L p
.43275 .52116 L 1 g
F P
s
P
p
.43275 .52116 m .43287 .51061 L .43194 .52955 L 1 g
F
P
p
.43318 .51932 m .43287 .51061 L .43266 .52851 L 1 g
F
P
p
.43539 .53802 m .43482 .5369 L .43644 .5417 L 1 g
F
P
p
.43539 .53802 m .43644 .5417 L .43835 .54735 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46023 .53677 m .44456 .5483 L .43644 .5417 L p
1 g
F P
s
P
p
.43303 .52978 m .46023 .53677 L .43644 .5417 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.40393 .54637 m .4166 .52556 L .43188 .53799 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43835 .54735 L p
1 g
F P
s
P
p
.45146 .56129 m .43835 .54735 L .44189 .55247 L 1 g
F
P
p
.002 w
.43561 .56231 m .44 .55543 L p
.45202 .56444 L 1 g
F P
s
P
p
.002 w
.44 .55543 m .44189 .55247 L p
.45082 .56302 L 1 g
F P
s
P
p
.44 .55543 m .45082 .56302 L .45202 .56444 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45082 .56302 L p
1 g
F P
s
P
p
.46872 .57265 m .45082 .56302 L .45903 .56878 L 1 g
F
P
p
.45146 .56129 m .44189 .55247 L .44351 .55438 L 1 g
F
P
p
.002 w
.45082 .56302 m .45146 .56129 L p
.44351 .55438 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44456 .5483 m .474 .56729 L p
.45202 .56444 L 1 g
F P
s
P
p
.002 w
.44189 .55247 m .44456 .5483 L p
.45202 .56444 L 1 g
F P
s
P
p
.002 w
.45082 .56302 m .45002 .56518 L p
.45903 .56878 L 1 g
F P
s
P
p
.44351 .55438 m .44189 .55247 L .44277 .55374 L 1 g
F
P
p
.002 w
.43188 .53799 m .44456 .5483 L p
.43882 .54802 L 1 g
F P
s
P
p
.40393 .54637 m .43188 .53799 L .43882 .54802 L 1 g
F
P
p
.43858 .54801 m .43882 .54802 L .43872 .54845 L 1 g
F
P
p
.43858 .54801 m .43872 .54845 L .43561 .56231 L 1 g
F
P
p
.002 w
.44189 .55247 m .43561 .56231 L p
.43882 .54802 L 1 g
F P
s
P
p
.002 w
.43835 .54735 m .43743 .5491 L p
.44277 .55374 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43835 .54735 L p
1 g
F P
s
P
p
.43482 .5369 m .43146 .53025 L .43835 .54735 L 1 g
F
P
p
.002 w
.44456 .5483 m .44189 .55247 L p
.43882 .54802 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45025 .56455 L p
1 g
F P
s
P
p
.002 w
.45025 .56455 m .45082 .56302 L p
.44502 .55699 L 1 g
F P
s
P
p
.44502 .55699 m .43743 .5491 L .45025 .56455 L 1 g
F
P
p
.44351 .55438 m .43743 .5491 L .45082 .56302 L 1 g
F
P
p
.45903 .56878 m .45838 .56852 L .46441 .57255 L 1 g
F
P
p
.002 w
.474 .56729 m .46932 .5743 L .46441 .57255 L p
1 g
F P
s
P
p
.45302 .56457 m .474 .56729 L .46441 .57255 L 1 g
F
P
p
.002 w
.46932 .5743 m .46918 .57547 L p
.46676 .57451 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46819 .57508 L p
1 g
F P
s
P
p
.45838 .56852 m .45002 .56518 L .46819 .57508 L 1 g
F
P
p
.002 w
.48889 .583 m .48905 .58072 L p
.47668 .57847 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48562 .58205 L p
.47668 .57847 L 1 g
F P
s
P
p
.002 w
.48562 .58205 m .48889 .583 L p
.47668 .57847 L 1 g
F P
s
P
p
.47671 .57759 m .4678 .57686 L .48905 .58072 L 1 g
F
P
p
.002 w
.50757 .58185 m .50383 .58192 L .52288 .57742 L p
1 g
F P
s
P
p
.002 w
.50585 .58234 m .50383 .58192 L .50757 .58185 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51096 .58087 L p
1 g
F P
s
P
p
.49214 .58235 m .48889 .583 L .51096 .58087 L 1 g
F
P
p
.002 w
.51096 .58087 m .51096 .5809 L p
.51122 .5808 L 1 g
F P
s
P
p
.002 w
.51096 .5809 m .51111 .583 L p
.5203 .57828 L 1 g
F P
s
P
p
.002 w
.61595 .49836 m .63079 .52524 L .603 .54488 L p
1 g
F P
s
P
p
.002 w
.63079 .52524 m .61595 .49836 L .63714 .47055 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.4166 .52556 m .40393 .54637 L .37538 .5271 L p
1 g
F P
s
P
p
.002 w
.37538 .5271 m .39117 .49992 L .4166 .52556 L p
1 g
F P
s
P
p
.002 w
.53904 .58125 m .53839 .57375 L .57184 .56125 L p
1 g
F P
s
P
p
.002 w
.61659 .41059 m .65394 .44191 L .63714 .47055 L p
1 g
F P
s
P
p
.002 w
.65394 .44191 m .61659 .41059 L .62563 .37884 L p
1 g
F P
s
P
p
.002 w
.59106 .5243 m .603 .54488 L .57184 .56125 L p
1 g
F P
s
P
p
.002 w
.603 .54488 m .59106 .5243 L .61595 .49836 L p
1 g
F P
s
P
p
.002 w
.5717 .32462 m .63072 .3493 L .62563 .37884 L p
1 g
F P
s
P
p
.002 w
.63072 .3493 m .5717 .32462 L .57201 .29749 L p
1 g
F P
s
P
p
.002 w
.50226 .28869 m .57201 .29749 L .5717 .32462 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.43733 .3564 m .37993 .38017 L .37371 .35059 L p
1 g
F P
s
P
p
.002 w
.37371 .35059 m .4337 .32527 L .43733 .3564 L p
1 g
F P
s
P
p
.002 w
.57184 .56125 m .56339 .5474 L .59106 .5243 L p
1 g
F P
s
P
p
.002 w
.40357 .44467 m .3692 .47231 L .35144 .44379 L p
1 g
F P
s
P
p
.002 w
.35144 .44379 m .38998 .41191 L .40357 .44467 L p
1 g
F P
s
P
p
.002 w
.50288 .31611 m .4337 .32527 L .43216 .2981 L p
1 g
F P
s
P
p
.002 w
.43216 .2981 m .50226 .28869 L .50288 .31611 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60381 .44342 m .63714 .47055 L .61595 .49836 L p
1 g
F P
s
P
p
.002 w
.63714 .47055 m .60381 .44342 L .61659 .41059 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.5717 .32462 m .50288 .31611 L .50226 .28869 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53395 .56683 m .52616 .56124 L .54813 .53612 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48199 .56158 m .474 .56729 L .44456 .5483 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42025 .47722 m .39117 .49992 L .3692 .47231 L p
1 g
F P
s
P
p
.002 w
.3692 .47231 m .40357 .44467 L .42025 .47722 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.56917 .35572 m .62563 .37884 L .61659 .41059 L p
1 g
F P
s
P
p
.002 w
.62563 .37884 m .56917 .35572 L .5717 .32462 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.58772 .47611 m .61595 .49836 L .59106 .5243 L p
1 g
F P
s
P
p
.002 w
.61595 .49836 m .58772 .47611 L .60381 .44342 L p
1 g
F P
s
P
p
.002 w
.52616 .56124 m .51584 .55764 L .52768 .5288 L p
1 g
F P
s
P
p
.002 w
.52768 .5288 m .54813 .53612 L .52616 .56124 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.49243 .55782 m .48199 .56158 L .46023 .53677 L p
1 g
F P
s
P
p
.002 w
.44456 .5483 m .46023 .53677 L .48199 .56158 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59106 .5243 m .56892 .5074 L .58772 .47611 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44298 .39042 m .38998 .41191 L .37993 .38017 L p
1 g
F P
s
P
p
.002 w
.37993 .38017 m .43733 .3564 L .44298 .39042 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51584 .55764 m .50416 .55646 L .50437 .52637 L p
1 g
F P
s
P
p
.002 w
.50437 .52637 m .52768 .5288 L .51584 .55764 L p
1 g
F P
s
P
p
.002 w
.50288 .31611 m .5717 .32462 L .56917 .35572 L p
1 g
F P
s
P
p
.002 w
.50416 .55646 m .49243 .55782 L .48097 .52915 L p
1 g
F P
s
P
p
.002 w
.46023 .53677 m .48097 .52915 L .49243 .55782 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48097 .52915 m .50437 .52637 L .50416 .55646 L p
1 g
F P
s
P
p
.002 w
.50342 .34779 m .43733 .3564 L .4337 .32527 L p
1 g
F P
s
P
p
.002 w
.4337 .32527 m .50288 .31611 L .50342 .34779 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.004 w
.50465 .61431 m
.50465 .61438 L
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.56443 .38975 m .61659 .41059 L .60381 .44342 L p
1 g
F P
s
P
p
.002 w
.61659 .41059 m .56443 .38975 L .56917 .35572 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.54813 .53612 m .52768 .5288 L .53888 .49635 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56917 .35572 m .50342 .34779 L .50288 .31611 L p
1 g
F P
s
P
p
.002 w
.48097 .52915 m .46023 .53677 L .43938 .50831 L p
1 g
F P
s
P
p
.002 w
.45049 .4261 m .40357 .44467 L .38998 .41191 L p
1 g
F P
s
P
p
.002 w
.38998 .41191 m .44298 .39042 L .45049 .4261 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.55763 .42546 m .60381 .44342 L .58772 .47611 L p
1 g
F P
s
P
p
.002 w
.60381 .44342 m .55763 .42546 L .56443 .38975 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.549 .46146 m .58772 .47611 L .56892 .5074 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.52768 .5288 m .50437 .52637 L .50445 .49265 L p
1 g
F P
s
P
p
.002 w
.50445 .49265 m .53888 .49635 L .52768 .5288 L p
1 g
F P
s
P
p
.002 w
.50342 .34779 m .56917 .35572 L .56443 .38975 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.50437 .52637 m .48097 .52915 L .46986 .49683 L p
1 g
F P
s
P
p
.002 w
.43938 .50831 m .46986 .49683 L .48097 .52915 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58772 .47611 m .549 .46146 L .55763 .42546 L p
1 g
F P
s
P
p
.002 w
.45957 .46203 m .42025 .47722 L .40357 .44467 L p
1 g
F P
s
P
p
.002 w
.40357 .44467 m .45049 .4261 L .45957 .46203 L p
1 g
F P
s
P
p
.002 w
.50387 .38263 m .44298 .39042 L .43733 .3564 L p
1 g
F P
s
P
p
.002 w
.43733 .3564 m .50342 .34779 L .50387 .38263 L p
1 g
F P
s
P
p
.002 w
.46986 .49683 m .50445 .49265 L .50437 .52637 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.004 w
.50512 .63276 m
.50539 .64342 L
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.56443 .38975 m .50387 .38263 L .50342 .34779 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.50387 .38263 m .56443 .38975 L .55763 .42546 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50419 .41935 m .45049 .4261 L .44298 .39042 L p
1 g
F P
s
P
p
.002 w
.44298 .39042 m .50387 .38263 L .50419 .41935 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.549 .46146 m .50439 .45652 L .50419 .41935 L p
1 g
F P
s
P
p
.002 w
.50419 .41935 m .55763 .42546 L .549 .46146 L p
1 g
F P
s
P
p
.002 w
.55763 .42546 m .50419 .41935 L .50387 .38263 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50439 .45652 m .45957 .46203 L .45049 .4261 L p
1 g
F P
s
P
p
.002 w
.45049 .4261 m .50419 .41935 L .50439 .45652 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .65528 .67802 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .50606 .67002 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.586047)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.586047)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.42734 .44439 m .46997 .46453 L .4786 .43752 L p
1 g
F P
s
P
p
.002 w
.4786 .43752 m .44133 .41972 L .42734 .44439 L p
1 g
F P
s
P
p
.002 w
.51966 .44598 m .4786 .43752 L .46997 .46453 L p
1 g
F P
s
P
p
.002 w
.44133 .41972 m .4786 .43752 L .48771 .41042 L p
1 g
F P
s
P
p
.002 w
.4786 .43752 m .51966 .44598 L .522 .41748 L p
1 g
F P
s
P
p
.002 w
.522 .41748 m .48771 .41042 L .4786 .43752 L p
1 g
F P
s
P
p
.002 w
.48771 .41042 m .45668 .39544 L .44133 .41972 L p
1 g
F P
s
P
p
.002 w
.45668 .39544 m .48771 .41042 L .49715 .38372 L p
1 g
F P
s
P
p
.002 w
.48771 .41042 m .522 .41748 L .52381 .3892 L p
1 g
F P
s
P
p
.002 w
.52381 .3892 m .49715 .38372 L .48771 .41042 L p
1 g
F P
s
P
p
.002 w
.46997 .46453 m .51684 .47419 L .51966 .44598 L p
1 g
F P
s
P
p
.002 w
.56083 .44434 m .51966 .44598 L .51684 .47419 L p
1 g
F P
s
P
p
.002 w
.51966 .44598 m .56083 .44434 L .55634 .41596 L p
1 g
F P
s
P
p
.002 w
.55634 .41596 m .522 .41748 L .51966 .44598 L p
1 g
F P
s
P
p
.002 w
.522 .41748 m .55634 .41596 L .55048 .3879 L p
1 g
F P
s
P
p
.002 w
.55048 .3879 m .52381 .3892 L .522 .41748 L p
1 g
F P
s
P
p
.002 w
.41499 .46898 m .462 .49096 L .46997 .46453 L p
1 g
F P
s
P
p
.002 w
.46997 .46453 m .42734 .44439 L .41499 .46898 L p
1 g
F P
s
P
p
.002 w
.51684 .47419 m .46997 .46453 L .462 .49096 L p
1 g
F P
s
P
p
.002 w
.462 .49096 m .51359 .5016 L .51684 .47419 L p
1 g
F P
s
P
p
.002 w
.56385 .47253 m .51684 .47419 L .51359 .5016 L p
1 g
F P
s
P
p
.002 w
.51684 .47419 m .56385 .47253 L .56083 .44434 L p
1 g
F P
s
P
p
.002 w
.49715 .38372 m .47309 .37198 L .45668 .39544 L p
1 g
F P
s
P
p
.002 w
.47309 .37198 m .49715 .38372 L .50676 .3579 L p
1 g
F P
s
P
p
.002 w
.49715 .38372 m .52381 .3892 L .52506 .36166 L p
1 g
F P
s
P
p
.002 w
.52506 .36166 m .50676 .3579 L .49715 .38372 L p
1 g
F P
s
P
p
.002 w
.52381 .3892 m .55048 .3879 L .54335 .36069 L p
1 g
F P
s
P
p
.002 w
.54335 .36069 m .52506 .36166 L .52381 .3892 L p
1 g
F P
s
P
p
.002 w
.41136 .39407 m .44133 .41972 L .45668 .39544 L p
1 g
F P
s
P
p
.002 w
.45668 .39544 m .43188 .37384 L .41136 .39407 L p
1 g
F P
s
P
p
.002 w
.43188 .37384 m .45668 .39544 L .47309 .37198 L p
1 g
F P
s
P
p
.002 w
.58749 .40587 m .55634 .41596 L .56083 .44434 L p
1 g
F P
s
P
p
.002 w
.55634 .41596 m .58749 .40587 L .57456 .37986 L p
1 g
F P
s
P
p
.002 w
.57456 .37986 m .55048 .3879 L .55634 .41596 L p
1 g
F P
s
P
p
.002 w
.39285 .41537 m .42734 .44439 L .44133 .41972 L p
1 g
F P
s
P
p
.002 w
.44133 .41972 m .41136 .39407 L .39285 .41537 L p
1 g
F P
s
P
p
.002 w
.59831 .43256 m .56083 .44434 L .56385 .47253 L p
1 g
F P
s
P
p
.002 w
.56083 .44434 m .59831 .43256 L .58749 .40587 L p
1 g
F P
s
P
p
.002 w
.47309 .37198 m .454 .35507 L .43188 .37384 L p
1 g
F P
s
P
p
.002 w
.454 .35507 m .47309 .37198 L .49028 .34978 L p
1 g
F P
s
P
p
.002 w
.50676 .3579 m .49028 .34978 L .47309 .37198 L p
1 g
F P
s
P
p
.002 w
.55048 .3879 m .57456 .37986 L .55978 .35504 L p
1 g
F P
s
P
p
.002 w
.55978 .35504 m .54335 .36069 L .55048 .3879 L p
1 g
F P
s
P
p
.002 w
.40453 .49303 m .45484 .51631 L .462 .49096 L p
1 g
F P
s
P
p
.002 w
.462 .49096 m .41499 .46898 L .40453 .49303 L p
1 g
F P
s
P
p
.002 w
.51359 .5016 m .462 .49096 L .45484 .51631 L p
1 g
F P
s
P
p
.002 w
.45484 .51631 m .50995 .52769 L .51359 .5016 L p
1 g
F P
s
P
p
.002 w
.56534 .5 m .51359 .5016 L .50995 .52769 L p
1 g
F P
s
P
p
.002 w
.51359 .5016 m .56534 .5 L .56385 .47253 L p
1 g
F P
s
P
p
.002 w
.49028 .34978 m .50676 .3579 L .51635 .33346 L p
1 g
F P
s
P
p
.002 w
.50676 .3579 m .52506 .36166 L .52571 .33538 L p
1 g
F P
s
P
p
.002 w
.52571 .33538 m .51635 .33346 L .50676 .3579 L p
1 g
F P
s
P
p
.002 w
.52506 .36166 m .54335 .36069 L .53505 .33485 L p
1 g
F P
s
P
p
.002 w
.53505 .33485 m .52571 .33538 L .52506 .36166 L p
1 g
F P
s
P
p
.002 w
.37676 .43734 m .41499 .46898 L .42734 .44439 L p
1 g
F P
s
P
p
.002 w
.42734 .44439 m .39285 .41537 L .37676 .43734 L p
1 g
F P
s
P
p
.002 w
.60679 .45945 m .56385 .47253 L .56534 .5 L p
1 g
F P
s
P
p
.002 w
.56385 .47253 m .60679 .45945 L .59831 .43256 L p
1 g
F P
s
P
p
.002 w
.49028 .34978 m .47731 .33809 L .454 .35507 L p
1 g
F P
s
P
p
.002 w
.47731 .33809 m .49028 .34978 L .50794 .32928 L p
1 g
F P
s
P
p
.002 w
.51635 .33346 m .50794 .32928 L .49028 .34978 L p
1 g
F P
s
P
p
.002 w
.54335 .36069 m .55978 .35504 L .5434 .3319 L p
1 g
F P
s
P
p
.002 w
.5434 .3319 m .53505 .33485 L .54335 .36069 L p
1 g
F P
s
P
p
.002 w
.41591 .34754 m .43188 .37384 L .454 .35507 L p
1 g
F P
s
P
p
.002 w
.454 .35507 m .4419 .33455 L .41591 .34754 L p
1 g
F P
s
P
p
.002 w
.4419 .33455 m .454 .35507 L .47731 .33809 L p
1 g
F P
s
P
p
.002 w
.39178 .36272 m .41136 .39407 L .43188 .37384 L p
1 g
F P
s
P
p
.002 w
.43188 .37384 m .41591 .34754 L .39178 .36272 L p
1 g
F P
s
P
p
.002 w
.59358 .36573 m .57456 .37986 L .58749 .40587 L p
1 g
F P
s
P
p
.002 w
.57456 .37986 m .59358 .36573 L .57263 .34523 L p
1 g
F P
s
P
p
.002 w
.57263 .34523 m .55978 .35504 L .57456 .37986 L p
1 g
F P
s
P
p
.002 w
.6123 .38793 m .58749 .40587 L .59831 .43256 L p
1 g
F P
s
P
p
.002 w
.58749 .40587 m .6123 .38793 L .59358 .36573 L p
1 g
F P
s
P
p
.002 w
.36346 .45956 m .40453 .49303 L .41499 .46898 L p
1 g
F P
s
P
p
.002 w
.41499 .46898 m .37676 .43734 L .36346 .45956 L p
1 g
F P
s
P
p
.002 w
.47731 .33809 m .46924 .32398 L .4419 .33455 L p
1 g
F P
s
P
p
.002 w
.46924 .32398 m .47731 .33809 L .50138 .32327 L p
1 g
F P
s
P
p
.002 w
.50794 .32928 m .50138 .32327 L .47731 .33809 L p
1 g
F P
s
P
p
.002 w
.50995 .52769 m .56523 .52621 L .56534 .5 L p
1 g
F P
s
P
p
.002 w
.61272 .48599 m .56534 .5 L .56523 .52621 L p
1 g
F P
s
P
p
.002 w
.56534 .5 m .61272 .48599 L .60679 .45945 L p
1 g
F P
s
P
p
.002 w
.37005 .37981 m .39285 .41537 L .41136 .39407 L p
1 g
F P
s
P
p
.002 w
.41136 .39407 m .39178 .36272 L .37005 .37981 L p
1 g
F P
s
P
p
.002 w
.55978 .35504 m .57263 .34523 L .54987 .32683 L p
1 g
F P
s
P
p
.002 w
.54987 .32683 m .5434 .3319 L .55978 .35504 L p
1 g
F P
s
P
p
.002 w
.39624 .51604 m .44865 .54007 L .45484 .51631 L p
1 g
F P
s
P
p
.002 w
.45484 .51631 m .40453 .49303 L .39624 .51604 L p
1 g
F P
s
P
p
.002 w
.50995 .52769 m .45484 .51631 L .44865 .54007 L p
1 g
F P
s
P
p
.002 w
.44865 .54007 m .50598 .55192 L .50995 .52769 L p
1 g
F P
s
P
p
.002 w
.56523 .52621 m .50995 .52769 L .50598 .55192 L p
1 g
F P
s
P
p
.002 w
.62838 .4114 m .59831 .43256 L .60679 .45945 L p
1 g
F P
s
P
p
.002 w
.59831 .43256 m .62838 .4114 L .6123 .38793 L p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .50794 .32928 L .51635 .33346 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .51635 .33346 L .52571 .33538 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .52571 .33538 L .53505 .33485 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .50138 .32327 L .50794 .32928 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .53505 .33485 L .5434 .3319 L closepath p
1 g
F P
s
P
p
.002 w
.50138 .32327 m .49736 .31604 L .46924 .32398 L p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .49736 .31604 L .50138 .32327 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .5434 .3319 L .54987 .32683 L closepath p
1 g
F P
s
P
p
.002 w
.35122 .39851 m .37676 .43734 L .39285 .41537 L p
1 g
F P
s
P
p
.002 w
.39285 .41537 m .37005 .37981 L .35122 .39851 L p
1 g
F P
s
P
p
.002 w
.64146 .43569 m .60679 .45945 L .61272 .48599 L p
1 g
F P
s
P
p
.002 w
.60679 .45945 m .64146 .43569 L .62838 .4114 L p
1 g
F P
s
P
p
.002 w
.43827 .31244 m .4419 .33455 L .46924 .32398 L p
1 g
F P
s
P
p
.002 w
.46924 .32398 m .467 .30888 L .43827 .31244 L p
1 g
F P
s
P
p
.002 w
.467 .30888 m .46924 .32398 L .49736 .31604 L p
1 g
F P
s
P
p
.002 w
.58048 .33219 m .57263 .34523 L .59358 .36573 L p
1 g
F P
s
P
p
.002 w
.57263 .34523 m .58048 .33219 L .55374 .32015 L p
1 g
F P
s
P
p
.002 w
.55374 .32015 m .54987 .32683 L .57263 .34523 L p
1 g
F P
s
P
p
.002 w
.41076 .31902 m .41591 .34754 L .4419 .33455 L p
1 g
F P
s
P
p
.002 w
.4419 .33455 m .43827 .31244 L .41076 .31902 L p
1 g
F P
s
P
p
.002 w
.60541 .34677 m .59358 .36573 L .6123 .38793 L p
1 g
F P
s
P
p
.002 w
.59358 .36573 m .60541 .34677 L .58048 .33219 L p
1 g
F P
s
P
p
.002 w
.35333 .48157 m .39624 .51604 L .40453 .49303 L p
1 g
F P
s
P
p
.002 w
.40453 .49303 m .36346 .45956 L .35333 .48157 L p
1 g
F P
s
P
p
.002 w
.49736 .31604 m .49635 .30837 L .467 .30888 L p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .49635 .30837 L .49736 .31604 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .54987 .32683 L .55374 .32015 L closepath p
1 g
F P
s
P
p
.002 w
.50598 .55192 m .56348 .55059 L .56523 .52621 L p
1 g
F P
s
P
p
.002 w
.61593 .51165 m .56523 .52621 L .56348 .55059 L p
1 g
F P
s
P
p
.002 w
.56523 .52621 m .61593 .51165 L .61272 .48599 L p
1 g
F P
s
P
p
.002 w
.38508 .32855 m .39178 .36272 L .41591 .34754 L p
1 g
F P
s
P
p
.002 w
.41591 .34754 m .41076 .31902 L .38508 .32855 L p
1 g
F P
s
P
p
.002 w
.62798 .36366 m .6123 .38793 L .62838 .4114 L p
1 g
F P
s
P
p
.002 w
.6123 .38793 m .62798 .36366 L .60541 .34677 L p
1 g
F P
s
P
p
.002 w
.39036 .5375 m .44359 .5617 L .44865 .54007 L p
1 g
F P
s
P
p
.002 w
.44865 .54007 m .39624 .51604 L .39036 .5375 L p
1 g
F P
s
P
p
.002 w
.50598 .55192 m .44865 .54007 L .44359 .5617 L p
1 g
F P
s
P
p
.002 w
.44359 .5617 m .50176 .57373 L .50598 .55192 L p
1 g
F P
s
P
p
.002 w
.56348 .55059 m .50598 .55192 L .50176 .57373 L p
1 g
F P
s
P
p
.002 w
.47099 .29438 m .467 .30888 L .49635 .30837 L p
1 g
F P
s
P
p
.002 w
.49635 .30837 m .49849 .30107 L .47099 .29438 L p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .49849 .30107 L .49635 .30837 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .55374 .32015 L .55456 .31258 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .55456 .31258 L .55221 .30492 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .55221 .30492 L .54691 .29802 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .54691 .29802 L .53921 .29266 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .53921 .29266 L .52998 .28946 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .52998 .28946 L .52025 .28877 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .52025 .28877 L .51111 .29067 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .51111 .29067 L .50359 .29494 L closepath p
1 g
F P
s
P
p
.002 w
.52573 .31091 m .50359 .29494 L .49849 .30107 L closepath p
1 g
F P
s
P
p
.002 w
.55456 .31258 m .55374 .32015 L .58048 .33219 L p
1 g
F P
s
P
p
.002 w
.3358 .41845 m .36346 .45956 L .37676 .43734 L p
1 g
F P
s
P
p
.002 w
.37676 .43734 m .35122 .39851 L .3358 .41845 L p
1 g
F P
s
P
p
.002 w
.65117 .4603 m .61272 .48599 L .61593 .51165 L p
1 g
F P
s
P
p
.002 w
.61272 .48599 m .65117 .4603 L .64146 .43569 L p
1 g
F P
s
P
p
.002 w
.44379 .29104 m .43827 .31244 L .467 .30888 L p
1 g
F P
s
P
p
.002 w
.467 .30888 m .47099 .29438 L .44379 .29104 L p
1 g
F P
s
P
p
.002 w
.58236 .31724 m .58048 .33219 L .60541 .34677 L p
1 g
F P
s
P
p
.002 w
.58048 .33219 m .58236 .31724 L .55456 .31258 L p
1 g
F P
s
P
p
.002 w
.36185 .34089 m .37005 .37981 L .39178 .36272 L p
1 g
F P
s
P
p
.002 w
.39178 .36272 m .38508 .32855 L .36185 .34089 L p
1 g
F P
s
P
p
.002 w
.48092 .2821 m .47099 .29438 L .49849 .30107 L p
1 g
F P
s
P
p
.002 w
.49849 .30107 m .50359 .29494 L .48092 .2821 L p
1 g
F P
s
P
p
.002 w
.64766 .38252 m .62838 .4114 L .64146 .43569 L p
1 g
F P
s
P
p
.002 w
.62838 .4114 m .64766 .38252 L .62798 .36366 L p
1 g
F P
s
P
p
.002 w
.55221 .30492 m .55456 .31258 L .58236 .31724 L p
1 g
F P
s
P
p
.002 w
.41749 .29122 m .41076 .31902 L .43827 .31244 L p
1 g
F P
s
P
p
.002 w
.43827 .31244 m .44379 .29104 L .41749 .29122 L p
1 g
F P
s
P
p
.002 w
.34671 .50288 m .39036 .5375 L .39624 .51604 L p
1 g
F P
s
P
p
.002 w
.39624 .51604 m .35333 .48157 L .34671 .50288 L p
1 g
F P
s
P
p
.002 w
.60851 .32486 m .60541 .34677 L .62798 .36366 L p
1 g
F P
s
P
p
.002 w
.60541 .34677 m .60851 .32486 L .58236 .31724 L p
1 g
F P
s
P
p
.002 w
.49583 .27348 m .48092 .2821 L .50359 .29494 L p
1 g
F P
s
P
p
.002 w
.50359 .29494 m .51111 .29067 L .49583 .27348 L p
1 g
F P
s
P
p
.002 w
.50176 .57373 m .56007 .57259 L .56348 .55059 L p
1 g
F P
s
P
p
.002 w
.61626 .53586 m .56348 .55059 L .56007 .57259 L p
1 g
F P
s
P
p
.002 w
.56348 .55059 m .61626 .53586 L .61593 .51165 L p
1 g
F P
s
P
p
.002 w
.58236 .31724 m .57789 .302 L .55221 .30492 L p
1 g
F P
s
P
p
.002 w
.54691 .29802 m .55221 .30492 L .57789 .302 L p
1 g
F P
s
P
p
.002 w
.45821 .27277 m .44379 .29104 L .47099 .29438 L p
1 g
F P
s
P
p
.002 w
.47099 .29438 m .48092 .2821 L .45821 .27277 L p
1 g
F P
s
P
p
.002 w
.34166 .35586 m .35122 .39851 L .37005 .37981 L p
1 g
F P
s
P
p
.002 w
.37005 .37981 m .36185 .34089 L .34166 .35586 L p
1 g
F P
s
P
p
.002 w
.32425 .43924 m .35333 .48157 L .36346 .45956 L p
1 g
F P
s
P
p
.002 w
.36346 .45956 m .3358 .41845 L .32425 .43924 L p
1 g
F P
s
P
p
.002 w
.57789 .302 m .58236 .31724 L .60851 .32486 L p
1 g
F P
s
P
p
.002 w
.51408 .26959 m .49583 .27348 L .51111 .29067 L p
1 g
F P
s
P
p
.002 w
.51111 .29067 m .52025 .28877 L .51408 .26959 L p
1 g
F P
s
P
p
.002 w
.57789 .302 m .56744 .28817 L .54691 .29802 L p
1 g
F P
s
P
p
.002 w
.53921 .29266 m .54691 .29802 L .56744 .28817 L p
1 g
F P
s
P
p
.002 w
.65721 .48471 m .61593 .51165 L .61626 .53586 L p
1 g
F P
s
P
p
.002 w
.61593 .51165 m .65721 .48471 L .65117 .4603 L p
1 g
F P
s
P
p
.002 w
.66393 .40302 m .64146 .43569 L .65117 .4603 L p
1 g
F P
s
P
p
.002 w
.64146 .43569 m .66393 .40302 L .64766 .38252 L p
1 g
F P
s
P
p
.002 w
.38713 .55688 m .43981 .58065 L .44359 .5617 L p
1 g
F P
s
P
p
.002 w
.44359 .5617 m .39036 .5375 L .38713 .55688 L p
1 g
F P
s
P
p
.002 w
.50176 .57373 m .44359 .5617 L .43981 .58065 L p
1 g
F P
s
P
p
.002 w
.39272 .29502 m .38508 .32855 L .41076 .31902 L p
1 g
F P
s
P
p
.002 w
.41076 .31902 m .41749 .29122 L .39272 .29502 L p
1 g
F P
s
P
p
.002 w
.5336 .27094 m .51408 .26959 L .52025 .28877 L p
1 g
F P
s
P
p
.002 w
.52025 .28877 m .52998 .28946 L .5336 .27094 L p
1 g
F P
s
P
p
.002 w
.43981 .58065 m .49735 .59256 L .50176 .57373 L p
1 g
F P
s
P
p
.002 w
.56007 .57259 m .50176 .57373 L .49735 .59256 L p
1 g
F P
s
P
p
.002 w
.56744 .28817 m .5521 .27739 L .53921 .29266 L p
1 g
F P
s
P
p
.002 w
.52998 .28946 m .53921 .29266 L .5521 .27739 L p
1 g
F P
s
P
p
.002 w
.5521 .27739 m .5336 .27094 L .52998 .28946 L p
1 g
F P
s
P
p
.002 w
.63241 .33535 m .62798 .36366 L .64766 .38252 L p
1 g
F P
s
P
p
.002 w
.62798 .36366 m .63241 .33535 L .60851 .32486 L p
1 g
F P
s
P
p
.002 w
.48018 .25984 m .45821 .27277 L .48092 .2821 L p
1 g
F P
s
P
p
.002 w
.48092 .2821 m .49583 .27348 L .48018 .25984 L p
1 g
F P
s
P
p
.002 w
.60851 .32486 m .6022 .30231 L .57789 .302 L p
1 g
F P
s
P
p
.002 w
.56744 .28817 m .57789 .302 L .6022 .30231 L p
1 g
F P
s
P
p
.002 w
.43595 .2673 m .41749 .29122 L .44379 .29104 L p
1 g
F P
s
P
p
.002 w
.44379 .29104 m .45821 .27277 L .43595 .2673 L p
1 g
F P
s
P
p
.002 w
.6022 .30231 m .60851 .32486 L .63241 .33535 L p
1 g
F P
s
P
p
.002 w
.32512 .37321 m .3358 .41845 L .35122 .39851 L p
1 g
F P
s
P
p
.002 w
.35122 .39851 m .34166 .35586 L .32512 .37321 L p
1 g
F P
s
P
p
.002 w
.34391 .52296 m .38713 .55688 L .39036 .5375 L p
1 g
F P
s
P
p
.002 w
.39036 .5375 m .34671 .50288 L .34391 .52296 L p
1 g
F P
s
P
p
.002 w
.3701 .3025 m .36185 .34089 L .38508 .32855 L p
1 g
F P
s
P
p
.002 w
.38508 .32855 m .39272 .29502 L .3701 .3025 L p
1 g
F P
s
P
p
.002 w
.67632 .42473 m .65117 .4603 L .65721 .48471 L p
1 g
F P
s
P
p
.002 w
.65117 .4603 m .67632 .42473 L .66393 .40302 L p
1 g
F P
s
P
p
.002 w
.49735 .59256 m .555 .5916 L .56007 .57259 L p
1 g
F P
s
P
p
.002 w
.61358 .55801 m .56007 .57259 L .555 .5916 L p
1 g
F P
s
P
p
.002 w
.56007 .57259 m .61358 .55801 L .61626 .53586 L p
1 g
F P
s
P
p
.002 w
.65344 .34857 m .64766 .38252 L .66393 .40302 L p
1 g
F P
s
P
p
.002 w
.64766 .38252 m .65344 .34857 L .63241 .33535 L p
1 g
F P
s
P
p
.002 w
.31702 .46041 m .34671 .50288 L .35333 .48157 L p
1 g
F P
s
P
p
.002 w
.35333 .48157 m .32425 .43924 L .31702 .46041 L p
1 g
F P
s
P
p
.002 w
.6593 .50835 m .61626 .53586 L .61358 .55801 L p
1 g
F P
s
P
p
.002 w
.61626 .53586 m .6593 .50835 L .65721 .48471 L p
1 g
F P
s
P
p
.002 w
.50732 .25394 m .48018 .25984 L .49583 .27348 L p
1 g
F P
s
P
p
.002 w
.49583 .27348 m .51408 .26959 L .50732 .25394 L p
1 g
F P
s
P
p
.002 w
.6022 .30231 m .58687 .28172 L .56744 .28817 L p
1 g
F P
s
P
p
.002 w
.5521 .27739 m .56744 .28817 L .58687 .28172 L p
1 g
F P
s
P
p
.002 w
.53647 .25592 m .50732 .25394 L .51408 .26959 L p
1 g
F P
s
P
p
.002 w
.51408 .26959 m .5336 .27094 L .53647 .25592 L p
1 g
F P
s
P
p
.002 w
.58687 .28172 m .56409 .26558 L .5521 .27739 L p
1 g
F P
s
P
p
.002 w
.5336 .27094 m .5521 .27739 L .56409 .26558 L p
1 g
F P
s
P
p
.002 w
.38676 .57362 m .43748 .59637 L .43981 .58065 L p
1 g
F P
s
P
p
.002 w
.43981 .58065 m .38713 .55688 L .38676 .57362 L p
1 g
F P
s
P
p
.002 w
.49735 .59256 m .43981 .58065 L .43748 .59637 L p
1 g
F P
s
P
p
.002 w
.4147 .26598 m .39272 .29502 L .41749 .29122 L p
1 g
F P
s
P
p
.002 w
.41749 .29122 m .43595 .2673 L .4147 .26598 L p
1 g
F P
s
P
p
.002 w
.43748 .59637 m .49286 .60783 L .49735 .59256 L p
1 g
F P
s
P
p
.002 w
.555 .5916 m .49735 .59256 L .49286 .60783 L p
1 g
F P
s
P
p
.002 w
.62452 .30599 m .63241 .33535 L .65344 .34857 L p
1 g
F P
s
P
p
.002 w
.63241 .33535 m .62452 .30599 L .6022 .30231 L p
1 g
F P
s
P
p
.002 w
.56409 .26558 m .53647 .25592 L .5336 .27094 L p
1 g
F P
s
P
p
.002 w
.46452 .25024 m .43595 .2673 L .45821 .27277 L p
1 g
F P
s
P
p
.002 w
.45821 .27277 m .48018 .25984 L .46452 .25024 L p
1 g
F P
s
P
p
.002 w
.58687 .28172 m .6022 .30231 L .62452 .30599 L p
1 g
F P
s
P
p
.002 w
.31279 .3926 m .32425 .43924 L .3358 .41845 L p
1 g
F P
s
P
p
.002 w
.3358 .41845 m .32512 .37321 L .31279 .3926 L p
1 g
F P
s
P
p
.002 w
.35029 .31362 m .34166 .35586 L .36185 .34089 L p
1 g
F P
s
P
p
.002 w
.36185 .34089 m .3701 .3025 L .35029 .31362 L p
1 g
F P
s
P
p
.002 w
.671 .36432 m .66393 .40302 L .67632 .42473 L p
1 g
F P
s
P
p
.002 w
.66393 .40302 m .671 .36432 L .65344 .34857 L p
1 g
F P
s
P
p
.002 w
.68438 .44718 m .65721 .48471 L .6593 .50835 L p
1 g
F P
s
P
p
.002 w
.65721 .48471 m .68438 .44718 L .67632 .42473 L p
1 g
F P
s
P
p
.002 w
.34519 .54127 m .38676 .57362 L .38713 .55688 L p
1 g
F P
s
P
p
.002 w
.38713 .55688 m .34391 .52296 L .34519 .54127 L p
1 g
F P
s
P
p
.002 w
.31449 .48145 m .34391 .52296 L .34671 .50288 L p
1 g
F P
s
P
p
.002 w
.34671 .50288 m .31702 .46041 L .31449 .48145 L p
1 g
F P
s
P
p
.002 w
.49286 .60783 m .54829 .60705 L .555 .5916 L p
1 g
F P
s
P
p
.002 w
.60783 .57752 m .555 .5916 L .54829 .60705 L p
1 g
F P
s
P
p
.002 w
.555 .5916 m .60783 .57752 L .61358 .55801 L p
1 g
F P
s
P
p
.002 w
.65722 .53062 m .61358 .55801 L .60783 .57752 L p
1 g
F P
s
P
p
.002 w
.61358 .55801 m .65722 .53062 L .6593 .50835 L p
1 g
F P
s
P
p
.002 w
.50011 .24239 m .46452 .25024 L .48018 .25984 L p
1 g
F P
s
P
p
.002 w
.48018 .25984 m .50732 .25394 L .50011 .24239 L p
1 g
F P
s
P
p
.002 w
.62452 .30599 m .60467 .27898 L .58687 .28172 L p
1 g
F P
s
P
p
.002 w
.56409 .26558 m .58687 .28172 L .60467 .27898 L p
1 g
F P
s
P
p
.002 w
.39504 .26905 m .3701 .3025 L .39272 .29502 L p
1 g
F P
s
P
p
.002 w
.39272 .29502 m .4147 .26598 L .39504 .26905 L p
1 g
F P
s
P
p
.002 w
.64424 .31308 m .65344 .34857 L .671 .36432 L p
1 g
F P
s
P
p
.002 w
.65344 .34857 m .64424 .31308 L .62452 .30599 L p
1 g
F P
s
P
p
.002 w
.33393 .32828 m .32512 .37321 L .34166 .35586 L p
1 g
F P
s
P
p
.002 w
.34166 .35586 m .35029 .31362 L .33393 .32828 L p
1 g
F P
s
P
p
.002 w
.44923 .24514 m .4147 .26598 L .43595 .2673 L p
1 g
F P
s
P
p
.002 w
.43595 .2673 m .46452 .25024 L .44923 .24514 L p
1 g
F P
s
P
p
.002 w
.30517 .41364 m .31702 .46041 L .32425 .43924 L p
1 g
F P
s
P
p
.002 w
.32425 .43924 m .31279 .3926 L .30517 .41364 L p
1 g
F P
s
P
p
.002 w
.60467 .27898 m .62452 .30599 L .64424 .31308 L p
1 g
F P
s
P
p
.002 w
.68449 .38231 m .67632 .42473 L .68438 .44718 L p
1 g
F P
s
P
p
.002 w
.67632 .42473 m .68449 .38231 L .671 .36432 L p
1 g
F P
s
P
p
.002 w
.53848 .24496 m .50011 .24239 L .50732 .25394 L p
1 g
F P
s
P
p
.002 w
.50732 .25394 m .53647 .25592 L .53848 .24496 L p
1 g
F P
s
P
p
.002 w
.60467 .27898 m .57483 .25771 L .56409 .26558 L p
1 g
F P
s
P
p
.002 w
.53647 .25592 m .56409 .26558 L .57483 .25771 L p
1 g
F P
s
P
p
.002 w
.38943 .58716 m .43672 .60828 L .43748 .59637 L p
1 g
F P
s
P
p
.002 w
.43748 .59637 m .38676 .57362 L .38943 .58716 L p
1 g
F P
s
P
p
.002 w
.49286 .60783 m .43748 .59637 L .43672 .60828 L p
1 g
F P
s
P
p
.002 w
.68771 .46985 m .6593 .50835 L .65722 .53062 L p
1 g
F P
s
P
p
.002 w
.6593 .50835 m .68771 .46985 L .68438 .44718 L p
1 g
F P
s
P
p
.002 w
.43672 .60828 m .48838 .61898 L .49286 .60783 L p
1 g
F P
s
P
p
.002 w
.54829 .60705 m .49286 .60783 L .48838 .61898 L p
1 g
F P
s
P
p
.002 w
.57483 .25771 m .53848 .24496 L .53647 .25592 L p
1 g
F P
s
P
p
.002 w
.31696 .5018 m .34519 .54127 L .34391 .52296 L p
1 g
F P
s
P
p
.002 w
.34391 .52296 m .31449 .48145 L .31696 .5018 L p
1 g
F P
s
P
p
.002 w
.65083 .55091 m .60783 .57752 L .59897 .59376 L p
1 g
F P
s
P
p
.002 w
.54829 .60705 m .59897 .59376 L .60783 .57752 L p
1 g
F P
s
P
p
.002 w
.60783 .57752 m .65083 .55091 L .65722 .53062 L p
1 g
F P
s
P
p
.002 w
.37756 .27666 m .35029 .31362 L .3701 .3025 L p
1 g
F P
s
P
p
.002 w
.3701 .3025 m .39504 .26905 L .37756 .27666 L p
1 g
F P
s
P
p
.002 w
.35075 .55724 m .38943 .58716 L .38676 .57362 L p
1 g
F P
s
P
p
.002 w
.38676 .57362 m .34519 .54127 L .35075 .55724 L p
1 g
F P
s
P
p
.002 w
.48838 .61898 m .54002 .61834 L .54829 .60705 L p
1 g
F P
s
P
p
.002 w
.59897 .59376 m .54829 .60705 L .54002 .61834 L p
1 g
F P
s
P
p
.002 w
.66074 .32358 m .671 .36432 L .68449 .38231 L p
1 g
F P
s
P
p
.002 w
.671 .36432 m .66074 .32358 L .64424 .31308 L p
1 g
F P
s
P
p
.002 w
.4926 .23549 m .44923 .24514 L .46452 .25024 L p
1 g
F P
s
P
p
.002 w
.46452 .25024 m .50011 .24239 L .4926 .23549 L p
1 g
F P
s
P
p
.002 w
.32162 .34623 m .31279 .3926 L .32512 .37321 L p
1 g
F P
s
P
p
.002 w
.32512 .37321 m .33393 .32828 L .32162 .34623 L p
1 g
F P
s
P
p
.002 w
.64424 .31308 m .62032 .28022 L .60467 .27898 L p
1 g
F P
s
P
p
.002 w
.57483 .25771 m .60467 .27898 L .62032 .28022 L p
1 g
F P
s
P
p
.002 w
.6934 .40219 m .68438 .44718 L .68771 .46985 L p
1 g
F P
s
P
p
.002 w
.68438 .44718 m .6934 .40219 L .68449 .38231 L p
1 g
F P
s
P
p
.002 w
.43474 .24493 m .39504 .26905 L .4147 .26598 L p
1 g
F P
s
P
p
.002 w
.4147 .26598 m .44923 .24514 L .43474 .24493 L p
1 g
F P
s
P
p
.002 w
.30271 .43582 m .31449 .48145 L .31702 .46041 L p
1 g
F P
s
P
p
.002 w
.31702 .46041 m .30517 .41364 L .30271 .43582 L p
1 g
F P
s
P
p
.002 w
.62032 .28022 m .64424 .31308 L .66074 .32358 L p
1 g
F P
s
P
p
.002 w
.68602 .49215 m .65722 .53062 L .65083 .55091 L p
1 g
F P
s
P
p
.002 w
.65722 .53062 m .68602 .49215 L .68771 .46985 L p
1 g
F P
s
P
p
.002 w
.53952 .2386 m .4926 .23549 L .50011 .24239 L p
1 g
F P
s
P
p
.002 w
.50011 .24239 m .53848 .24496 L .53952 .2386 L p
1 g
F P
s
P
p
.002 w
.62032 .28022 m .58398 .25422 L .57483 .25771 L p
1 g
F P
s
P
p
.002 w
.53848 .24496 m .57483 .25771 L .58398 .25422 L p
1 g
F P
s
P
p
.002 w
.39523 .59696 m .43765 .61585 L .43672 .60828 L p
1 g
F P
s
P
p
.002 w
.43672 .60828 m .38943 .58716 L .39523 .59696 L p
1 g
F P
s
P
p
.002 w
.48838 .61898 m .43672 .60828 L .43765 .61585 L p
1 g
F P
s
P
p
.002 w
.43765 .61585 m .48403 .62546 L .48838 .61898 L p
1 g
F P
s
P
p
.002 w
.54002 .61834 m .48838 .61898 L .48403 .62546 L p
1 g
F P
s
P
p
.002 w
.58398 .25422 m .53952 .2386 L .53848 .24496 L p
1 g
F P
s
P
p
.002 w
.36287 .28885 m .33393 .32828 L .35029 .31362 L p
1 g
F P
s
P
p
.002 w
.35029 .31362 m .37756 .27666 L .36287 .28885 L p
1 g
F P
s
P
p
.002 w
.32461 .52087 m .35075 .55724 L .34519 .54127 L p
1 g
F P
s
P
p
.002 w
.34519 .54127 m .31696 .5018 L .32461 .52087 L p
1 g
F P
s
P
p
.002 w
.67341 .3374 m .68449 .38231 L .6934 .40219 L p
1 g
F P
s
P
p
.002 w
.68449 .38231 m .67341 .3374 L .66074 .32358 L p
1 g
F P
s
P
p
.002 w
.54002 .61834 m .58709 .60614 L .59897 .59376 L p
1 g
F P
s
P
p
.002 w
.64008 .56857 m .59897 .59376 L .58709 .60614 L p
1 g
F P
s
P
p
.002 w
.59897 .59376 m .64008 .56857 L .65083 .55091 L p
1 g
F P
s
P
p
.002 w
.31392 .36715 m .30517 .41364 L .31279 .3926 L p
1 g
F P
s
P
p
.002 w
.31279 .3926 m .32162 .34623 L .31392 .36715 L p
1 g
F P
s
P
p
.002 w
.36067 .57029 m .39523 .59696 L .38943 .58716 L p
1 g
F P
s
P
p
.002 w
.38943 .58716 m .35075 .55724 L .36067 .57029 L p
1 g
F P
s
P
p
.002 w
.69724 .42352 m .68771 .46985 L .68602 .49215 L p
1 g
F P
s
P
p
.002 w
.68771 .46985 m .69724 .42352 L .6934 .40219 L p
1 g
F P
s
P
p
.002 w
.48403 .62546 m .53031 .62493 L .54002 .61834 L p
1 g
F P
s
P
p
.004 w
.51988 .62505 m
.52925 .71668 L
s
P
p
.004 w
.5 .43051 m
.51939 .62027 L
s
P
p
.002 w
.58709 .60614 m .54002 .61834 L .53031 .62493 L p
1 g
F P
s
P
p
.002 w
.48497 .23371 m .43474 .24493 L .44923 .24514 L p
1 g
F P
s
P
p
.002 w
.44923 .24514 m .4926 .23549 L .48497 .23371 L p
1 g
F P
s
P
p
.002 w
.30572 .45856 m .31696 .5018 L .31449 .48145 L p
1 g
F P
s
P
p
.002 w
.31449 .48145 m .30271 .43582 L .30572 .45856 L p
1 g
F P
s
P
p
.002 w
.66074 .32358 m .63328 .28564 L .62032 .28022 L p
1 g
F P
s
P
p
.002 w
.58398 .25422 m .62032 .28022 L .63328 .28564 L p
1 g
F P
s
P
p
.002 w
.42149 .24991 m .37756 .27666 L .39504 .26905 L p
1 g
F P
s
P
p
.002 w
.39504 .26905 m .43474 .24493 L .42149 .24991 L p
1 g
F P
s
P
p
.002 w
.67911 .51346 m .65083 .55091 L .64008 .56857 L p
1 g
F P
s
P
p
.002 w
.65083 .55091 m .67911 .51346 L .68602 .49215 L p
1 g
F P
s
P
p
.002 w
.63328 .28564 m .66074 .32358 L .67341 .3374 L p
1 g
F P
s
P
p
.002 w
.35154 .30549 m .32162 .34623 L .33393 .32828 L p
1 g
F P
s
P
p
.002 w
.33393 .32828 m .36287 .28885 L .35154 .30549 L p
1 g
F P
s
P
p
.002 w
.53951 .23732 m .48497 .23371 L .4926 .23549 L p
1 g
F P
s
P
p
.002 w
.4926 .23549 m .53952 .2386 L .53951 .23732 L p
1 g
F P
s
P
p
.002 w
.63328 .28564 m .59119 .25547 L .58398 .25422 L p
1 g
F P
s
P
p
.002 w
.53952 .2386 m .58398 .25422 L .59119 .25547 L p
1 g
F P
s
P
p
.002 w
.6934 .40219 m .68169 .35433 L .67341 .3374 L p
1 g
F P
s
P
p
.002 w
.68169 .35433 m .6934 .40219 L .69724 .42352 L p
1 g
F P
s
P
p
.002 w
.40422 .60251 m .44036 .61859 L .43765 .61585 L p
1 g
F P
s
P
p
.002 w
.43765 .61585 m .39523 .59696 L .40422 .60251 L p
1 g
F P
s
P
p
.002 w
.48403 .62546 m .43765 .61585 L .44036 .61859 L p
1 g
F P
s
P
p
.002 w
.31128 .39055 m .30271 .43582 L .30517 .41364 L p
1 g
F P
s
P
p
.002 w
.30517 .41364 m .31392 .36715 L .31128 .39055 L p
1 g
F P
s
P
p
.002 w
.44036 .61859 m .47993 .62679 L .48403 .62546 L p
1 g
F P
s
P
p
.002 w
.53031 .62493 m .48403 .62546 L .47993 .62679 L p
1 g
F P
s
P
p
.004 w
.4506 .66011 m
.4561 .63452 L
s
P
p
.002 w
.3375 .53804 m .36067 .57029 L .35075 .55724 L p
1 g
F P
s
P
p
.002 w
.35075 .55724 m .32461 .52087 L .3375 .53804 L p
1 g
F P
s
P
p
.002 w
.59119 .25547 m .53951 .23732 L .53952 .2386 L p
1 g
F P
s
P
p
.002 w
.68602 .49215 m .69565 .44574 L .69724 .42352 L p
1 g
F P
s
P
p
.002 w
.69565 .44574 m .68602 .49215 L .67911 .51346 L p
1 g
F P
s
P
p
.002 w
.53031 .62493 m .57233 .6141 L .58709 .60614 L p
1 g
F P
s
P
p
.002 w
.58709 .60614 m .62506 .58298 L .64008 .56857 L p
1 g
F P
s
P
p
.002 w
.62506 .58298 m .58709 .60614 L .57233 .6141 L p
1 g
F P
s
P
p
.002 w
.31437 .48122 m .32461 .52087 L .31696 .5018 L p
1 g
F P
s
P
p
.002 w
.31696 .5018 m .30572 .45856 L .31437 .48122 L p
1 g
F P
s
P
p
.002 w
.40996 .26024 m .36287 .28885 L .37756 .27666 L p
1 g
F P
s
P
p
.002 w
.37756 .27666 m .42149 .24991 L .40996 .26024 L p
1 g
F P
s
P
p
.002 w
.37492 .57989 m .40422 .60251 L .39523 .59696 L p
1 g
F P
s
P
p
.002 w
.39523 .59696 m .36067 .57029 L .37492 .57989 L p
1 g
F P
s
P
p
.002 w
.64008 .56857 m .66693 .53312 L .67911 .51346 L p
1 g
F P
s
P
p
.002 w
.66693 .53312 m .64008 .56857 L .62506 .58298 L p
1 g
F P
s
P
p
.002 w
.47743 .23744 m .42149 .24991 L .43474 .24493 L p
1 g
F P
s
P
p
.002 w
.43474 .24493 m .48497 .23371 L .47743 .23744 L p
1 g
F P
s
P
p
.002 w
.47993 .62679 m .51934 .62635 L .53031 .62493 L p
1 g
F P
s
P
p
.002 w
.57233 .6141 m .53031 .62493 L .51934 .62635 L p
1 g
F P
s
P
p
.002 w
.67341 .3374 m .64302 .29534 L .63328 .28564 L p
1 g
F P
s
P
p
.002 w
.64302 .29534 m .67341 .3374 L .68169 .35433 L p
1 g
F P
s
P
p
.002 w
.59119 .25547 m .63328 .28564 L .64302 .29534 L p
1 g
F P
s
P
p
.002 w
.34412 .32633 m .31392 .36715 L .32162 .34623 L p
1 g
F P
s
P
p
.002 w
.32162 .34623 m .35154 .30549 L .34412 .32633 L p
1 g
F P
s
P
p
.002 w
.6851 .37403 m .69724 .42352 L .69565 .44574 L p
1 g
F P
s
P
p
.002 w
.69724 .42352 m .6851 .37403 L .68169 .35433 L p
1 g
F P
s
P
p
.002 w
.31402 .41583 m .30572 .45856 L .30271 .43582 L p
1 g
F P
s
P
p
.002 w
.30271 .43582 m .31128 .39055 L .31402 .41583 L p
1 g
F P
s
P
p
.002 w
.68842 .46825 m .67911 .51346 L .66693 .53312 L p
1 g
F P
s
P
p
.002 w
.67911 .51346 m .68842 .46825 L .69565 .44574 L p
1 g
F P
s
P
p
.002 w
.53837 .24149 m .47743 .23744 L .48497 .23371 L p
1 g
F P
s
P
p
.002 w
.48497 .23371 m .53951 .23732 L .53837 .24149 L p
1 g
F P
s
P
p
.002 w
.64302 .29534 m .59612 .26176 L .59119 .25547 L p
1 g
F P
s
P
p
.002 w
.53951 .23732 m .59119 .25547 L .59612 .26176 L p
1 g
F P
s
P
p
.002 w
.3555 .55268 m .37492 .57989 L .36067 .57029 L p
1 g
F P
s
P
p
.002 w
.36067 .57029 m .3375 .53804 L .3555 .55268 L p
1 g
F P
s
P
p
.002 w
.51934 .62635 m .55495 .61715 L .57233 .6141 L p
1 g
F P
s
P
p
.002 w
.60597 .59356 m .57233 .6141 L .55495 .61715 L p
1 g
F P
s
P
p
.002 w
.57233 .6141 m .60597 .59356 L .62506 .58298 L p
1 g
F P
s
P
p
.002 w
.41633 .60337 m .44488 .6161 L .44036 .61859 L p
1 g
F P
s
P
p
.002 w
.44036 .61859 m .40422 .60251 L .41633 .60337 L p
1 g
F P
s
P
p
.002 w
.47993 .62679 m .44036 .61859 L .44488 .6161 L p
1 g
F P
s
P
p
.002 w
.44488 .6161 m .47622 .62259 L .47993 .62679 L p
1 g
F P
s
P
p
.002 w
.51934 .62635 m .47993 .62679 L .47622 .62259 L p
1 g
F P
s
P
p
.002 w
.32866 .50308 m .3375 .53804 L .32461 .52087 L p
1 g
F P
s
P
p
.002 w
.32461 .52087 m .31437 .48122 L .32866 .50308 L p
1 g
F P
s
P
p
.002 w
.64959 .55045 m .62506 .58298 L .60597 .59356 L p
1 g
F P
s
P
p
.002 w
.62506 .58298 m .64959 .55045 L .66693 .53312 L p
1 g
F P
s
P
p
.002 w
.59612 .26176 m .53837 .24149 L .53951 .23732 L p
1 g
F P
s
P
p
.002 w
.4006 .27593 m .35154 .30549 L .36287 .28885 L p
1 g
F P
s
P
p
.002 w
.36287 .28885 m .40996 .26024 L .4006 .27593 L p
1 g
F P
s
P
p
.002 w
.64907 .3093 m .68169 .35433 L .6851 .37403 L p
1 g
F P
s
P
p
.002 w
.68169 .35433 m .64907 .3093 L .64302 .29534 L p
1 g
F P
s
P
p
.002 w
.47023 .24692 m .40996 .26024 L .42149 .24991 L p
1 g
F P
s
P
p
.002 w
.42149 .24991 m .47743 .23744 L .47023 .24692 L p
1 g
F P
s
P
p
.002 w
.39332 .58553 m .41633 .60337 L .40422 .60251 L p
1 g
F P
s
P
p
.002 w
.40422 .60251 m .37492 .57989 L .39332 .58553 L p
1 g
F P
s
P
p
.002 w
.59612 .26176 m .64302 .29534 L .64907 .3093 L p
1 g
F P
s
P
p
.002 w
.47622 .62259 m .50737 .62222 L .51934 .62635 L p
1 g
F P
s
P
p
.002 w
.55495 .61715 m .51934 .62635 L .50737 .62222 L p
1 g
F P
s
P
p
.002 w
.34103 .3509 m .31128 .39055 L .31392 .36715 L p
1 g
F P
s
P
p
.002 w
.31392 .36715 m .34412 .32633 L .34103 .3509 L p
1 g
F P
s
P
p
.002 w
.32229 .44224 m .31437 .48122 L .30572 .45856 L p
1 g
F P
s
P
p
.002 w
.30572 .45856 m .31402 .41583 L .32229 .44224 L p
1 g
F P
s
P
p
.002 w
.68326 .39606 m .69565 .44574 L .68842 .46825 L p
1 g
F P
s
P
p
.002 w
.69565 .44574 m .68326 .39606 L .6851 .37403 L p
1 g
F P
s
P
p
.002 w
.6755 .49035 m .66693 .53312 L .64959 .55045 L p
1 g
F P
s
P
p
.002 w
.66693 .53312 m .6755 .49035 L .68842 .46825 L p
1 g
F P
s
P
p
.002 w
.34836 .5234 m .3555 .55268 L .3375 .53804 L p
1 g
F P
s
P
p
.002 w
.3375 .53804 m .32866 .50308 L .34836 .5234 L p
1 g
F P
s
P
p
.002 w
.37828 .5642 m .39332 .58553 L .37492 .57989 L p
1 g
F P
s
P
p
.002 w
.37492 .57989 m .3555 .55268 L .37828 .5642 L p
1 g
F P
s
P
p
.002 w
.50737 .62222 m .53535 .61493 L .55495 .61715 L p
1 g
F P
s
P
p
.002 w
.5832 .59978 m .55495 .61715 L .53535 .61493 L p
1 g
F P
s
P
p
.002 w
.55495 .61715 m .5832 .59978 L .60597 .59356 L p
1 g
F P
s
P
p
.002 w
.6274 .56481 m .60597 .59356 L .5832 .59978 L p
1 g
F P
s
P
p
.002 w
.60597 .59356 m .6274 .56481 L .64959 .55045 L p
1 g
F P
s
P
p
.002 w
.53606 .25135 m .47023 .24692 L .47743 .23744 L p
1 g
F P
s
P
p
.002 w
.47743 .23744 m .53837 .24149 L .53606 .25135 L p
1 g
F P
s
P
p
.002 w
.64907 .3093 m .59848 .27321 L .59612 .26176 L p
1 g
F P
s
P
p
.002 w
.53837 .24149 m .59612 .26176 L .59848 .27321 L p
1 g
F P
s
P
p
.002 w
.39384 .29675 m .34412 .32633 L .35154 .30549 L p
1 g
F P
s
P
p
.002 w
.35154 .30549 m .4006 .27593 L .39384 .29675 L p
1 g
F P
s
P
p
.002 w
.43137 .59922 m .45121 .6081 L .44488 .6161 L p
1 g
F P
s
P
p
.002 w
.44488 .6161 m .41633 .60337 L .43137 .59922 L p
1 g
F P
s
P
p
.002 w
.47622 .62259 m .44488 .6161 L .45121 .6081 L p
1 g
F P
s
P
p
.002 w
.45121 .6081 m .47304 .61262 L .47622 .62259 L p
1 g
F P
s
P
p
.002 w
.50737 .62222 m .47622 .62259 L .47304 .61262 L p
1 g
F P
s
P
p
.002 w
.65101 .32733 m .6851 .37403 L .68326 .39606 L p
1 g
F P
s
P
p
.002 w
.6851 .37403 m .65101 .32733 L .64907 .3093 L p
1 g
F P
s
P
p
.002 w
.34258 .37855 m .31402 .41583 L .31128 .39055 L p
1 g
F P
s
P
p
.002 w
.31128 .39055 m .34103 .3509 L .34258 .37855 L p
1 g
F P
s
P
p
.002 w
.59848 .27321 m .53606 .25135 L .53837 .24149 L p
1 g
F P
s
P
p
.002 w
.46362 .26221 m .4006 .27593 L .40996 .26024 L p
1 g
F P
s
P
p
.002 w
.40996 .26024 m .47023 .24692 L .46362 .26221 L p
1 g
F P
s
P
p
.002 w
.33604 .46896 m .32866 .50308 L .31437 .48122 L p
1 g
F P
s
P
p
.002 w
.31437 .48122 m .32229 .44224 L .33604 .46896 L p
1 g
F P
s
P
p
.002 w
.67598 .41982 m .68842 .46825 L .6755 .49035 L p
1 g
F P
s
P
p
.002 w
.68842 .46825 m .67598 .41982 L .68326 .39606 L p
1 g
F P
s
P
p
.002 w
.59848 .27321 m .64907 .3093 L .65101 .32733 L p
1 g
F P
s
P
p
.002 w
.4155 .58682 m .43137 .59922 L .41633 .60337 L p
1 g
F P
s
P
p
.002 w
.41633 .60337 m .39332 .58553 L .4155 .58682 L p
1 g
F P
s
P
p
.002 w
.47304 .61262 m .4947 .61233 L .50737 .62222 L p
1 g
F P
s
P
p
.002 w
.53535 .61493 m .50737 .62222 L .4947 .61233 L p
1 g
F P
s
P
p
.002 w
.65707 .5113 m .64959 .55045 L .6274 .56481 L p
1 g
F P
s
P
p
.002 w
.64959 .55045 m .65707 .5113 L .6755 .49035 L p
1 g
F P
s
P
p
.002 w
.37303 .54145 m .37828 .5642 L .3555 .55268 L p
1 g
F P
s
P
p
.002 w
.3555 .55268 m .34836 .5234 L .37303 .54145 L p
1 g
F P
s
P
p
.002 w
.53535 .61493 m .5573 .60125 L .5832 .59978 L p
1 g
F P
s
P
p
.002 w
.60088 .5756 m .5832 .59978 L .5573 .60125 L p
1 g
F P
s
P
p
.002 w
.5832 .59978 m .60088 .5756 L .6274 .56481 L p
1 g
F P
s
P
p
.002 w
.40529 .57209 m .4155 .58682 L .39332 .58553 L p
1 g
F P
s
P
p
.002 w
.39332 .58553 m .37828 .5642 L .40529 .57209 L p
1 g
F P
s
P
p
.002 w
.4947 .61233 m .51402 .60721 L .53535 .61493 L p
1 g
F P
s
P
p
.002 w
.5573 .60125 m .53535 .61493 L .51402 .60721 L p
1 g
F P
s
P
p
.002 w
.39005 .32228 m .34103 .3509 L .34412 .32633 L p
1 g
F P
s
P
p
.002 w
.34412 .32633 m .39384 .29675 L .39005 .32228 L p
1 g
F P
s
P
p
.002 w
.3489 .40845 m .32229 .44224 L .31402 .41583 L p
1 g
F P
s
P
p
.002 w
.31402 .41583 m .34258 .37855 L .3489 .40845 L p
1 g
F P
s
P
p
.002 w
.64855 .34907 m .68326 .39606 L .67598 .41982 L p
1 g
F P
s
P
p
.002 w
.68326 .39606 m .64855 .34907 L .65101 .32733 L p
1 g
F P
s
P
p
.002 w
.35497 .49507 m .34836 .5234 L .32866 .50308 L p
1 g
F P
s
P
p
.002 w
.32866 .50308 m .33604 .46896 L .35497 .49507 L p
1 g
F P
s
P
p
.002 w
.53258 .26695 m .46362 .26221 L .47023 .24692 L p
1 g
F P
s
P
p
.002 w
.47023 .24692 m .53606 .25135 L .53258 .26695 L p
1 g
F P
s
P
p
.002 w
.65101 .32733 m .59802 .28978 L .59848 .27321 L p
1 g
F P
s
P
p
.002 w
.53606 .25135 m .59848 .27321 L .59802 .28978 L p
1 g
F P
s
P
p
.002 w
.66325 .44458 m .6755 .49035 L .65707 .5113 L p
1 g
F P
s
P
p
.002 w
.6755 .49035 m .66325 .44458 L .67598 .41982 L p
1 g
F P
s
P
p
.002 w
.63352 .53037 m .6274 .56481 L .60088 .5756 L p
1 g
F P
s
P
p
.002 w
.6274 .56481 m .63352 .53037 L .65707 .5113 L p
1 g
F P
s
P
p
.002 w
.44902 .58991 m .45925 .59451 L .45121 .6081 L p
1 g
F P
s
P
p
.002 w
.45121 .6081 m .43137 .59922 L .44902 .58991 L p
1 g
F P
s
P
p
.002 w
.47304 .61262 m .45121 .6081 L .45925 .59451 L p
1 g
F P
s
P
p
.002 w
.45925 .59451 m .47053 .59685 L .47304 .61262 L p
1 g
F P
s
P
p
.002 w
.4947 .61233 m .47304 .61262 L .47053 .59685 L p
1 g
F P
s
P
p
.002 w
.45785 .28313 m .39384 .29675 L .4006 .27593 L p
1 g
F P
s
P
p
.002 w
.4006 .27593 m .46362 .26221 L .45785 .28313 L p
1 g
F P
s
P
p
.002 w
.59802 .28978 m .65101 .32733 L .64855 .34907 L p
1 g
F P
s
P
p
.002 w
.59802 .28978 m .53258 .26695 L .53606 .25135 L p
1 g
F P
s
P
p
.002 w
.44091 .5835 m .44902 .58991 L .43137 .59922 L p
1 g
F P
s
P
p
.002 w
.43137 .59922 m .4155 .58682 L .44091 .5835 L p
1 g
F P
s
P
p
.002 w
.47053 .59685 m .4817 .59667 L .4947 .61233 L p
1 g
F P
s
P
p
.002 w
.51402 .60721 m .4947 .61233 L .4817 .59667 L p
1 g
F P
s
P
p
.002 w
.40196 .55652 m .40529 .57209 L .37828 .5642 L p
1 g
F P
s
P
p
.002 w
.37828 .5642 m .37303 .54145 L .40196 .55652 L p
1 g
F P
s
P
p
.002 w
.51402 .60721 m .529 .59769 L .5573 .60125 L p
1 g
F P
s
P
p
.002 w
.57076 .58234 m .5573 .60125 L .529 .59769 L p
1 g
F P
s
P
p
.002 w
.5573 .60125 m .57076 .58234 L .60088 .5756 L p
1 g
F P
s
P
p
.002 w
.35993 .43961 m .33604 .46896 L .32229 .44224 L p
1 g
F P
s
P
p
.002 w
.32229 .44224 m .3489 .40845 L .35993 .43961 L p
1 g
F P
s
P
p
.002 w
.37856 .51963 m .37303 .54145 L .34836 .5234 L p
1 g
F P
s
P
p
.002 w
.34836 .5234 m .35497 .49507 L .37856 .51963 L p
1 g
F P
s
P
p
.002 w
.3895 .3518 m .34258 .37855 L .34103 .3509 L p
1 g
F P
s
P
p
.002 w
.34103 .3509 m .39005 .32228 L .3895 .3518 L p
1 g
F P
s
P
p
.002 w
.43579 .57594 m .44091 .5835 L .4155 .58682 L p
1 g
F P
s
P
p
.002 w
.4155 .58682 m .40529 .57209 L .43579 .57594 L p
1 g
F P
s
P
p
.002 w
.529 .59769 m .51402 .60721 L .4916 .59399 L p
1 g
F P
s
P
p
.002 w
.4817 .59667 m .4916 .59399 L .51402 .60721 L p
1 g
F P
s
P
p
.002 w
.60551 .54681 m .60088 .5756 L .57076 .58234 L p
1 g
F P
s
P
p
.002 w
.60088 .5756 m .60551 .54681 L .63352 .53037 L p
1 g
F P
s
P
p
.002 w
.64528 .46953 m .65707 .5113 L .63352 .53037 L p
1 g
F P
s
P
p
.002 w
.65707 .5113 m .64528 .46953 L .66325 .44458 L p
1 g
F P
s
P
p
.002 w
.64154 .37396 m .67598 .41982 L .66325 .44458 L p
1 g
F P
s
P
p
.002 w
.67598 .41982 m .64154 .37396 L .64855 .34907 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.47558 .54399 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.52799 .28807 m .45785 .28313 L .46362 .26221 L p
1 g
F P
s
P
p
.002 w
.46362 .26221 m .53258 .26695 L .52799 .28807 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.64855 .34907 m .59459 .31119 L .59802 .28978 L p
1 g
F P
s
P
p
.002 w
.53258 .26695 m .59802 .28978 L .59459 .31119 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45318 .30922 m .39005 .32228 L .39384 .29675 L p
1 g
F P
s
P
p
.002 w
.39384 .29675 m .45785 .28313 L .45318 .30922 L p
1 g
F P
s
P
p
.002 w
.43425 .56802 m .43579 .57594 L .40529 .57209 L p
1 g
F P
s
P
p
.002 w
.40529 .57209 m .40196 .55652 L .43425 .56802 L p
1 g
F P
s
P
p
.002 w
.4916 .59399 m .49917 .58905 L .529 .59769 L p
1 g
F P
s
P
p
.002 w
.53796 .58465 m .529 .59769 L .49917 .58905 L p
1 g
F P
s
P
p
.002 w
.529 .59769 m .53796 .58465 L .57076 .58234 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.59459 .31119 m .64855 .34907 L .64154 .37396 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.45925 .59451 m .44902 .58991 L .46875 .57551 L p
1 g
F P
s
P
p
.002 w
.44902 .58991 m .44091 .5835 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.44091 .5835 m .43579 .57594 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.43579 .57594 m .43425 .56802 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46818 .57513 L p
1 g
F P
s
P
p
.48921 .57862 m .46818 .57513 L .46818 .57513 L 1 g
F
P
p
.48921 .57862 m .46818 .57513 L .46842 .57523 L 1 g
F
P
p
.002 w
.46861 .5753 m .46881 .57546 L .46746 .57484 L p
1 g
F P
s
P
p
.46861 .5753 m .46842 .57523 L .46861 .5753 L 1 g
F
P
p
.48921 .57862 m .46842 .57523 L .46861 .5753 L 1 g
F
P
p
.48921 .57862 m .46861 .5753 L .46869 .57534 L 1 g
F
P
p
.48921 .57862 m .46868 .57533 L .46874 .57536 L 1 g
F
P
p
.002 w
.4365 .56058 m .4407 .5562 L p
.45077 .56314 L 1 g
F P
s
P
p
.45652 .56976 m .45077 .56314 L .46807 .57506 L 1 g
F
P
p
.4365 .56058 m .45077 .56314 L .45652 .56976 L 1 g
F
P
p
.41736 .52943 m .43255 .53881 L .43882 .54882 L 1 g
F
P
p
.002 w
.43979 .55189 m .41736 .52943 L p
.43882 .54882 L 1 g
F P
s
P
p
.002 w
.43836 .54734 m .43925 .54566 L p
.43547 .53818 L 1 g
F P
s
P
p
.002 w
.45077 .56314 m .45146 .56129 L p
.44263 .55362 L 1 g
F P
s
P
p
.44263 .55362 m .44299 .55414 L .45077 .56314 L 1 g
F
P
p
.002 w
.443 .55417 m .44236 .55446 L p
.43255 .53881 L 1 g
F P
s
P
p
.44225 .55329 m .44519 .55671 L .45077 .56314 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44236 .55446 m .43979 .55189 L p
.43882 .54882 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45123 .55035 m .443 .55417 L p
.43836 .54734 L 1 g
F P
s
P
p
.43255 .53881 m .43642 .5412 L .43836 .54734 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43249 .52875 L p
1 g
F P
s
P
p
.43925 .54566 m .43249 .52875 L .43547 .53818 L 1 g
F
P
p
.43642 .5412 m .45123 .55035 L .43836 .54734 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4348 .52105 m .45123 .55035 L p
.43215 .53856 L 1 g
F P
s
P
p
.002 w
.41736 .52943 m .43273 .52204 L p
.43215 .53856 L 1 g
F P
s
P
p
.002 w
.43249 .52875 m .43346 .52734 L p
.43311 .51743 L 1 g
F P
s
P
p
.002 w
.41736 .52943 m .39475 .50124 L p
.43289 .5201 L 1 g
F P
s
P
p
.002 w
.43273 .52204 m .41736 .52943 L p
.43289 .5201 L 1 g
F P
s
P
p
.43311 .51743 m .43273 .52204 L .43249 .52875 L 1 g
F
P
p
.002 w
.39475 .50124 m .42017 .48856 L .43312 .51732 L p
1 g
F P
s
P
p
.39475 .50124 m .43312 .51732 L .43289 .5201 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43398 .5093 L p
1 g
F P
s
P
p
.42017 .48856 m .43492 .50039 L .43398 .5093 L 1 g
F
P
p
.002 w
.43312 .51732 m .43167 .51409 L p
.43398 .5093 L 1 g
F P
s
P
p
.002 w
.43167 .51409 m .42017 .48856 L p
.43398 .5093 L 1 g
F P
s
P
p
.002 w
.43398 .5093 m .43485 .50826 L p
.43781 .50134 L 1 g
F P
s
P
p
.43346 .52734 m .43398 .5093 L .43311 .51741 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43398 .5093 m .45648 .51767 L .43312 .51732 L 1 g
F
P
p
.43492 .50039 m .43734 .50232 L .43398 .5093 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44265 .49129 L p
1 g
F P
s
P
p
.43485 .50826 m .44265 .49129 L .43781 .50134 L 1 g
F
P
p
.43734 .50232 m .45648 .51767 L .43398 .5093 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45207 .48332 m .45648 .51767 L p
.434 .49965 L 1 g
F P
s
P
p
.002 w
.44265 .49129 m .44339 .4905 L p
.45194 .48231 L 1 g
F P
s
P
p
.45194 .48231 m .45066 .48355 L .44265 .49129 L 1 g
F
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45769 .4767 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45769 .4767 m .48668 .48633 L .45198 .48227 L 1 g
F
P
p
.002 w
.45769 .4767 m .45826 .47608 L p
.4658 .47277 L 1 g
F P
s
P
p
.47124 .47014 m .48668 .48633 L .45769 .4767 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47764 .46704 L p
1 g
F P
s
P
p
.45826 .47608 m .47764 .46704 L .4658 .47277 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49098 .46526 m .48668 .48633 L p
.46934 .46815 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46379 L p
1 g
F P
s
P
p
.002 w
.51974 .49728 m .48668 .48633 L .49098 .46526 L p
1 g
F P
s
P
p
.5 .46379 m .51974 .49728 L .49098 .46526 L 1 g
F
P
p
.50131 .46398 m .51974 .49728 L .5 .46379 L 1 g
F
P
p
.002 w
.5 .46379 m .5 .4634 L p
.50869 .46507 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52239 .46709 L p
1 g
F P
s
P
p
.5 .4634 m .52239 .46709 L .50869 .46507 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47662 L p
1 g
F P
s
P
p
.53887 .47505 m .54721 .51479 L .53292 .47228 L 1 g
F
P
p
.52214 .46667 m .54223 .47662 L .53623 .47383 L 1 g
F
P
p
.002 w
.53676 .46501 m .57209 .48794 L .57042 .48973 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56583 .50906 L p
1 g
F P
s
P
p
.55661 .4905 m .56583 .50906 L .56301 .50301 L 1 g
F
P
p
.57209 .48794 m .56863 .51509 L .56583 .50906 L 1 g
F
P
p
.002 w
.56138 .4995 m .56475 .49586 L p
.56583 .50906 L 1 g
F P
s
P
p
.002 w
.56475 .49586 m .57209 .48794 L p
.56583 .50906 L 1 g
F P
s
P
p
.002 w
.56583 .50906 m .56515 .50826 L p
.56645 .51667 L 1 g
F P
s
P
p
.56188 .50059 m .56655 .50993 L .56254 .50184 L 1 g
F
P
p
.55661 .4905 m .56301 .50301 L .56188 .50059 L 1 g
F
P
p
.56301 .50301 m .56655 .50993 L .56188 .50059 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.57389 .56 m .55468 .56528 L p
.56203 .54647 L 1 g
F P
s
P
p
.002 w
.56152 .54712 m .56075 .54566 L p
.55607 .55414 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56152 .54712 L p
1 g
F P
s
P
p
.56654 .52734 m .56152 .54712 L .56415 .54014 L 1 g
F
P
p
.002 w
.56589 .53658 m .56706 .53999 L p
.56203 .54647 L 1 g
F P
s
P
p
.002 w
.56706 .53999 m .57389 .56 L p
.56203 .54647 L 1 g
F P
s
P
p
.56589 .53658 m .55468 .56528 L .56514 .53752 L 1 g
F
P
p
.56425 .5399 m .56251 .54898 L .56284 .5476 L 1 g
F
P
p
.56654 .52734 m .56415 .54014 L .56425 .5399 L 1 g
F
P
p
.56415 .54014 m .56251 .54898 L .56425 .5399 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57465 L p
1 g
F P
s
P
p
.002 w
.53796 .58465 m .51641 .58321 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53966 .57021 m .53941 .57237 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53941 .57237 m .53796 .58465 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53172 .57465 m .53128 .57265 L p
.52143 .5777 L 1 g
F P
s
P
p
.54854 .56129 m .53172 .57465 L .53711 .57163 L 1 g
F
P
p
.53789 .57144 m .53206 .57621 L .53638 .57288 L 1 g
F
P
p
.54854 .56129 m .53547 .57312 L .53789 .57144 L 1 g
F
P
p
.53547 .57312 m .53206 .57621 L .53789 .57144 L 1 g
F
P
p
.002 w
.53796 .58465 m .53966 .57021 L p
.57389 .56 L 1 g
F P
s
P
p
.002 w
.54155 .56889 m .57389 .56 L p
.53966 .57021 L 1 g
F P
s
P
p
.002 w
.55468 .56528 m .54545 .56782 L p
.55813 .55612 L 1 g
F P
s
P
p
.002 w
.54545 .56782 m .54155 .56889 L p
.54918 .56302 L 1 g
F P
s
P
p
.55813 .55612 m .54545 .56782 L .54918 .56302 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54918 .56302 L p
1 g
F P
s
P
p
.56075 .54566 m .54918 .56302 L .55607 .55414 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54918 .56302 L p
1 g
F P
s
P
p
.002 w
.54918 .56302 m .54854 .56129 L p
.53638 .57288 L 1 g
F P
s
P
p
.53638 .57288 m .5322 .57686 L .54918 .56302 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.5654 .53685 m .56589 .53658 L p
.56514 .53752 L 1 g
F P
s
P
p
.56632 .5332 m .56589 .53658 L .56576 .53552 L 1 g
F
P
p
.002 w
.56589 .53658 m .56559 .53623 L p
.56576 .53552 L 1 g
F P
s
P
p
.002 w
.57389 .56 m .56589 .53658 L .59578 .51641 L p
1 g
F P
s
P
p
.002 w
.56742 .52863 m .56654 .52734 L p
.56397 .54144 L 1 g
F P
s
P
p
.002 w
.56559 .53623 m .56589 .53658 L .5654 .53685 L p
1 g
F P
s
P
p
.56397 .54144 m .56284 .5476 L .56559 .53623 L 1 g
F
P
p
.56397 .54144 m .56559 .53623 L .56742 .52863 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54721 .51479 m .56559 .53623 L p
.53397 .55353 L 1 g
F P
s
P
p
.002 w
.5654 .53685 m .53397 .55353 L p
.56559 .53623 L 1 g
F P
s
P
p
.002 w
.57209 .48794 m .59578 .51641 L .56796 .53519 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56742 .52863 L p
1 g
F P
s
P
p
.56515 .50826 m .56742 .52863 L .56645 .51667 L 1 g
F
P
p
.002 w
.56796 .53519 m .56589 .53658 L p
.56722 .52614 L 1 g
F P
s
P
p
.57209 .48794 m .56796 .53519 L .56722 .52614 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.57042 .48973 m .56348 .49722 L p
.55236 .48133 L 1 g
F P
s
P
p
.002 w
.56348 .49722 m .56138 .4995 L p
.55725 .49118 L 1 g
F P
s
P
p
.55236 .48133 m .56348 .49722 L .55725 .49118 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55725 .49118 L p
1 g
F P
s
P
p
.54174 .47608 m .55725 .49118 L .54806 .48227 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.53887 .47505 m .54223 .47662 L .54721 .51479 L 1 g
F
P
p
.002 w
.54223 .47662 m .54174 .47608 L p
.54806 .48227 L 1 g
F P
s
P
p
.54223 .47662 m .55236 .48133 L .55168 .48578 L 1 g
F
P
p
.54223 .47662 m .55168 .48578 L .54721 .51479 L 1 g
F
P
p
.002 w
.56138 .4995 m .54721 .51479 L p
.55236 .48133 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54223 .47662 L p
1 g
F P
s
P
p
.54806 .48227 m .55834 .49233 L .54223 .47662 L 1 g
F
P
p
.002 w
.55725 .49118 m .55834 .49233 L p
.54806 .48227 L 1 g
F P
s
P
p
.56863 .51509 m .56632 .5332 L .56138 .4995 L 1 g
F
P
p
.002 w
.56742 .52863 m .56854 .53025 L p
.56645 .51667 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56742 .52863 L p
1 g
F P
s
P
p
.56284 .5476 m .56257 .5491 L .56742 .52863 L 1 g
F
P
p
.002 w
.54721 .51479 m .56138 .4995 L p
.56576 .53552 L 1 g
F P
s
P
p
.002 w
.56559 .53623 m .54721 .51479 L p
.56576 .53552 L 1 g
F P
s
P
p
.56514 .53752 m .55813 .55612 L .53976 .56939 L 1 g
F
P
p
.002 w
.54155 .56889 m .53976 .56939 L p
.55813 .55612 L 1 g
F P
s
P
p
.002 w
.54918 .56302 m .54998 .56518 L p
.55607 .55414 L 1 g
F P
s
P
p
.002 w
.53966 .57021 m .53976 .56939 L .54155 .56889 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58081 L p
1 g
F P
s
P
p
.002 w
.51641 .58321 m .50534 .58247 L p
.50877 .58146 L 1 g
F P
s
P
p
.53128 .57265 m .51095 .58081 L .52143 .5777 L 1 g
F
P
p
.002 w
.51095 .58081 m .51079 .57862 L p
.49814 .58115 L 1 g
F P
s
P
p
.002 w
.50367 .58141 m .50358 .58236 L .49728 .58111 L p
1 g
F P
s
P
p
.002 w
.50358 .58236 m .50239 .58417 L p
.48906 .58068 L 1 g
F P
s
P
p
.48921 .57862 m .46884 .5754 L .47748 .57766 L 1 g
F
P
p
.002 w
.49917 .58905 m .46881 .57546 L .46999 .5757 L p
1 g
F P
s
P
p
.002 w
.50239 .58417 m .49917 .58905 L p
.47984 .5802 L 1 g
F P
s
P
p
.48906 .58068 m .47984 .5802 L .46999 .5757 L 1 g
F
P
p
.50239 .58417 m .47984 .5802 L .48906 .58068 L 1 g
F
P
p
.002 w
.49728 .58111 m .50358 .58236 L p
.48906 .58068 L 1 g
F P
s
P
p
.50728 .58111 m .50877 .58146 L .50358 .58236 L 1 g
F
P
p
.002 w
.50534 .58247 m .50358 .58236 L p
.50877 .58146 L 1 g
F P
s
P
p
.52239 .57987 m .51641 .58321 L .50728 .58111 L 1 g
F
P
p
.49814 .58115 m .50367 .58141 L .51095 .58081 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53976 .56939 m .53966 .57021 L p
.50358 .58236 L 1 g
F P
s
P
p
.002 w
.49917 .58905 m .50358 .58236 L .53796 .58465 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48891 .58262 L p
1 g
F P
s
P
p
.51079 .57862 m .48891 .58262 L .49205 .58236 L 1 g
F
P
p
.002 w
.5043 .57461 m .53976 .56939 L p
.50698 .58114 L 1 g
F P
s
P
p
.002 w
.50358 .58236 m .50367 .58141 L p
.50698 .58114 L 1 g
F P
s
P
p
.002 w
.50367 .58141 m .5043 .57461 L p
.50698 .58114 L 1 g
F P
s
P
p
.002 w
.48891 .58262 m .48889 .583 L p
.49205 .58236 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51103 .58182 L p
1 g
F P
s
P
p
.002 w
.51103 .58182 m .51095 .58081 L p
.50428 .58147 L 1 g
F P
s
P
p
.50428 .58147 m .48889 .583 L .51103 .58182 L 1 g
F
P
p
.002 w
.46878 .57553 m .45925 .59451 L p
.46875 .57551 L 1 g
F P
s
P
p
.002 w
.47053 .59685 m .45925 .59451 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.4817 .59667 m .47053 .59685 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.4916 .59399 m .4817 .59667 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.49917 .58905 m .4916 .59399 L .46881 .57546 L closepath p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46999 .5757 m .49728 .58111 L p
.48906 .58068 L 1 g
F P
s
P
p
.49814 .58115 m .49812 .58115 L .50367 .58141 L 1 g
F
P
p
.49812 .58115 m .49205 .58236 L .50344 .58143 L 1 g
F
P
p
.49812 .58115 m .50344 .58143 L .50367 .58141 L 1 g
F
P
p
.48921 .57862 m .46873 .57535 L .46878 .57537 L 1 g
F
P
p
.48921 .57862 m .46876 .57537 L .4688 .57538 L 1 g
F
P
p
.48921 .57862 m .46879 .57538 L .46883 .57539 L 1 g
F
P
p
.48921 .57862 m .46881 .57538 L .46885 .5754 L 1 g
F
P
p
.48921 .57862 m .46883 .57539 L .46887 .5754 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.5043 .57461 m .50367 .58141 L p
.46999 .5757 L 1 g
F P
s
P
p
.002 w
.49728 .58111 m .46999 .5757 L p
.50367 .58141 L 1 g
F P
s
P
p
.53966 .57021 m .52239 .57987 L .50728 .58111 L 1 g
F
P
p
.002 w
.51095 .58081 m .51111 .583 L p
.52143 .5777 L 1 g
F P
s
P
p
.49205 .58236 m .48889 .583 L .51095 .58081 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57465 L p
1 g
F P
s
P
p
.52143 .5777 m .51111 .583 L .53172 .57465 L 1 g
F
P
p
.002 w
.53172 .57465 m .53206 .57621 L p
.53711 .57163 L 1 g
F P
s
P
p
.002 w
.53206 .57621 m .5322 .57686 L p
.53638 .57288 L 1 g
F P
s
P
p
.002 w
.53976 .56939 m .53397 .55353 L .5654 .53685 L p
1 g
F P
s
P
p
.56514 .53752 m .53976 .56939 L .5654 .53685 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56152 .54712 L p
1 g
F P
s
P
p
.55607 .55414 m .54998 .56518 L .56152 .54712 L 1 g
F
P
p
.002 w
.56152 .54712 m .56251 .54898 L p
.56415 .54014 L 1 g
F P
s
P
p
.002 w
.56251 .54898 m .56257 .5491 L p
.56284 .5476 L 1 g
F P
s
P
p
.56632 .5332 m .56576 .53552 L .56138 .4995 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56583 .50906 L p
1 g
F P
s
P
p
.56645 .51667 m .56854 .53025 L .56583 .50906 L 1 g
F
P
p
.002 w
.56583 .50906 m .56655 .50993 L p
.56301 .50301 L 1 g
F P
s
P
p
.002 w
.56655 .50993 m .56713 .51061 L p
.56254 .50184 L 1 g
F P
s
P
p
.53676 .46501 m .57042 .48973 L .53887 .47505 L 1 g
F
P
p
.53355 .47258 m .54266 .47709 L .53428 .47295 L 1 g
F
P
p
.52214 .46667 m .53623 .47383 L .53355 .47258 L 1 g
F
P
p
.53623 .47383 m .54266 .47709 L .53355 .47258 L 1 g
F
P
p
.002 w
.54223 .47662 m .54266 .47709 L p
.53623 .47383 L 1 g
F P
s
P
p
.002 w
.54721 .51479 m .51974 .49728 L .53292 .47228 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53292 .47228 m .51974 .49728 L p
.49576 .45396 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53292 .47228 m .53676 .46501 L p
.53887 .47505 L 1 g
F P
s
P
p
.002 w
.49396 .4507 m .53676 .46501 L .53292 .47228 L p
1 g
F P
s
P
p
.49396 .4507 m .53292 .47228 L .49576 .45396 L 1 g
F
P
p
.002 w
.54266 .47709 m .54302 .47747 L p
.53428 .47295 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46379 L p
1 g
F P
s
P
p
.50869 .46507 m .52282 .46778 L .5 .46379 L 1 g
F
P
p
.49396 .4507 m .5011 .46361 L .5 .46379 L 1 g
F
P
p
.47786 .46667 m .5 .46379 L .48979 .46546 L 1 g
F
P
p
.002 w
.49098 .46526 m .49154 .46254 L p
.5 .46379 L 1 g
F P
s
P
p
.002 w
.49154 .46254 m .49396 .4507 L p
.5 .46379 L 1 g
F P
s
P
p
.5011 .46361 m .50131 .46398 L .5 .46379 L 1 g
F
P
p
.002 w
.52239 .46709 m .52282 .46778 L p
.50869 .46507 L 1 g
F P
s
P
p
.002 w
.5 .46379 m .5 .46442 L p
.48979 .46546 L 1 g
F P
s
P
p
.002 w
.4491 .44694 m .49396 .4507 L .49098 .46526 L p
1 g
F P
s
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48868 .46557 L 1 g
F P
s
P
p
.4491 .44694 m .49098 .46526 L .46934 .46815 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48868 .46557 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47764 .46704 m .47718 .46778 L p
.4658 .47277 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.4491 .44694 m .46795 .4667 L .45769 .4767 L 1 g
F
P
p
.44339 .4905 m .45769 .4767 L .45195 .4823 L 1 g
F
P
p
.002 w
.45198 .48227 m .45176 .47957 L p
.45769 .4767 L 1 g
F P
s
P
p
.002 w
.45176 .47957 m .4491 .44694 L p
.45769 .4767 L 1 g
F P
s
P
p
.46795 .4667 m .47124 .47014 L .45769 .4767 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45769 .4767 L p
1 g
F P
s
P
p
.4658 .47277 m .47718 .46778 L .45769 .4767 L 1 g
F
P
p
.002 w
.45769 .4767 m .45698 .47747 L p
.45195 .4823 L 1 g
F P
s
P
p
.002 w
.48668 .48633 m .45207 .48332 L .45198 .48227 L p
1 g
F P
s
P
p
.002 w
.40792 .45407 m .4491 .44694 L .45198 .48227 L p
1 g
F P
s
P
p
.002 w
.45198 .48227 m .45207 .48332 L p
.45137 .48286 L 1 g
F P
s
P
p
.40792 .45407 m .45198 .48227 L .45137 .48286 L 1 g
F
P
p
.002 w
.45207 .48332 m .45066 .48355 L p
.45137 .48286 L 1 g
F P
s
P
p
.002 w
.45066 .48355 m .45207 .48332 L p
.434 .49965 L 1 g
F P
s
P
p
.002 w
.44265 .49129 m .44166 .49233 L p
.43781 .50134 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44232 .49163 L p
1 g
F P
s
P
p
.002 w
.44232 .49163 m .44265 .49129 L p
.44754 .48657 L 1 g
F P
s
P
p
.44754 .48657 m .45698 .47747 L .44232 .49163 L 1 g
F
P
p
.45194 .48231 m .45255 .48172 L .45066 .48355 L 1 g
F
P
p
.002 w
.42017 .48856 m .40792 .45407 L p
.45137 .48286 L 1 g
F P
s
P
p
.002 w
.45066 .48355 m .42017 .48856 L p
.45137 .48286 L 1 g
F P
s
P
p
.002 w
.42017 .48856 m .45066 .48355 L p
.434 .49965 L 1 g
F P
s
P
p
.45255 .48172 m .45698 .47747 L .44265 .49129 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43398 .5093 L p
1 g
F P
s
P
p
.43781 .50134 m .44166 .49233 L .43398 .5093 L 1 g
F
P
p
.002 w
.43398 .5093 m .43287 .51061 L p
.43311 .51741 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.45648 .51767 m .4348 .52105 L .43312 .51732 L p
1 g
F P
s
P
p
.002 w
.43312 .51732 m .4348 .52105 L p
.43289 .5201 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43213 .52928 L p
1 g
F P
s
P
p
.002 w
.43213 .52928 m .43249 .52875 L p
.4326 .52358 L 1 g
F P
s
P
p
.4326 .52358 m .43287 .51061 L .43213 .52928 L 1 g
F
P
p
.43311 .51743 m .433 .51428 L .43273 .52204 L 1 g
F
P
p
.002 w
.4348 .52105 m .43273 .52204 L p
.43289 .5201 L 1 g
F P
s
P
p
.002 w
.43273 .52204 m .4348 .52105 L p
.43215 .53856 L 1 g
F P
s
P
p
.433 .51428 m .43287 .51061 L .43249 .52875 L 1 g
F
P
p
.002 w
.43249 .52875 m .43146 .53025 L p
.43547 .53818 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43836 .54734 L p
1 g
F P
s
P
p
.43547 .53818 m .43146 .53025 L .43836 .54734 L 1 g
F
P
p
.44263 .55362 m .44225 .55329 L .44299 .55414 L 1 g
F
P
p
.002 w
.44236 .55446 m .443 .55417 L p
.44518 .55669 L 1 g
F P
s
P
p
.002 w
.46818 .57513 m .46872 .57265 L p
.45886 .56871 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.46861 .5753 m .44519 .55671 L p
.46873 .57535 L 1 g
F P
s
P
p
.002 w
.44519 .55671 m .44236 .55446 L p
.44518 .55669 L 1 g
F P
s
P
p
.44518 .55669 m .46873 .57535 L .44519 .55671 L 1 g
F
P
p
.46807 .57506 m .44525 .55677 L .46861 .5753 L 1 g
F
P
p
.002 w
.44236 .55446 m .44519 .55671 L p
.44525 .55677 L 1 g
F P
s
P
p
.002 w
.44519 .55671 m .46861 .5753 L p
.44525 .55677 L 1 g
F P
s
P
p
.002 w
.4407 .5562 m .44236 .55446 L p
.46807 .57506 L 1 g
F P
s
P
p
.002 w
.44236 .55446 m .4365 .56058 L .40606 .54174 L p
1 g
F P
s
P
p
.002 w
.40606 .54174 m .41736 .52943 L .44236 .55446 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45076 .56318 L p
1 g
F P
s
P
p
.002 w
.45076 .56318 m .45077 .56314 L p
.45025 .56259 L 1 g
F P
s
P
p
.45025 .56259 m .43743 .5491 L .45076 .56318 L 1 g
F
P
p
.44225 .55329 m .44214 .55319 L .44519 .55671 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.45123 .55035 m .46873 .57535 L p
.44518 .55669 L 1 g
F P
s
P
p
.002 w
.443 .55417 m .45123 .55035 L p
.44518 .55669 L 1 g
F P
s
P
p
.44214 .55319 m .43743 .5491 L .45077 .56314 L 1 g
F
P
p
.002 w
.46746 .57484 m .4365 .56058 L p
.46861 .5753 L 1 g
F P
s
P
p
.002 w
.46818 .57513 m .46818 .57513 L p
.45863 .56862 L 1 g
F P
s
P
p
.45886 .56871 m .45863 .56862 L .46818 .57513 L 1 g
F
P
p
.002 w
.46873 .57535 m .46881 .57546 L .46861 .5753 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45123 .55035 m .46215 .54874 L .46879 .57537 L p
1 g
F P
s
P
p
.002 w
.46879 .57537 m .46881 .57546 L .46873 .57535 L p
1 g
F P
s
P
p
.002 w
.46873 .57535 m .45123 .55035 L p
.46879 .57537 L 1 g
F P
s
P
p
.46869 .57534 m .46861 .5753 L .46868 .57533 L 1 g
F
P
p
.46874 .57536 m .46868 .57533 L .46873 .57535 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.46215 .54874 m .47389 .54982 L .46883 .57539 L p
1 g
F P
s
P
p
.002 w
.46883 .57539 m .46881 .57546 L .46879 .57537 L p
1 g
F P
s
P
p
.002 w
.46879 .57537 m .46215 .54874 L p
.46883 .57539 L 1 g
F P
s
P
p
.002 w
.47389 .54982 m .48512 .55349 L .46886 .5754 L p
1 g
F P
s
P
p
.002 w
.46886 .5754 m .46881 .57546 L .46883 .57539 L p
1 g
F P
s
P
p
.002 w
.46883 .57539 m .47389 .54982 L p
.46886 .5754 L 1 g
F P
s
P
p
.46878 .57537 m .46873 .57535 L .46876 .57537 L 1 g
F
P
p
.4688 .57538 m .46876 .57537 L .46879 .57538 L 1 g
F
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.48512 .55349 m .49458 .55931 L .4689 .57541 L p
1 g
F P
s
P
p
.002 w
.4689 .57541 m .46881 .57546 L .46886 .5754 L p
1 g
F P
s
P
p
.002 w
.46886 .5754 m .48512 .55349 L p
.4689 .57541 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.49458 .55931 m .50121 .56663 L .46896 .57543 L p
1 g
F P
s
P
p
.002 w
.46896 .57543 m .46881 .57546 L .4689 .57541 L p
1 g
F P
s
P
p
.002 w
.4689 .57541 m .49458 .55931 L p
.46896 .57543 L 1 g
F P
s
P
p
.46883 .57539 m .46879 .57538 L .46881 .57538 L 1 g
F
P
p
.46885 .5754 m .46881 .57538 L .46883 .57539 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.50121 .56663 m .5043 .57461 L .46908 .57546 L p
1 g
F P
s
P
p
.002 w
.46908 .57546 m .46881 .57546 L .46896 .57543 L p
1 g
F P
s
P
p
.002 w
.46896 .57543 m .50121 .56663 L p
.46908 .57546 L 1 g
F P
s
P
p
.002 w
.46999 .5757 m .46881 .57546 L .46908 .57546 L p
1 g
F P
s
P
p
.002 w
.46908 .57546 m .5043 .57461 L p
.46999 .5757 L 1 g
F P
s
P
p
.46887 .5754 m .46883 .57539 L .46884 .5754 L 1 g
F
P
p
.47748 .57766 m .46884 .5754 L .47368 .57734 L 1 g
F
P
p
.002 w
.46818 .57513 m .46818 .57513 L p
.46818 .57513 L 1 g
F P
s
P
p
.002 w
.43425 .56802 m .43602 .56219 L p
.46837 .57526 L 1 g
F P
s
P
p
.002 w
.46746 .57484 m .46837 .57526 L p
.43602 .56219 L 1 g
F P
s
P
p
.002 w
.46837 .57526 m .46881 .57546 L .4686 .57542 L p
1 g
F P
s
P
p
.002 w
.4686 .57542 m .43425 .56802 L p
.46837 .57526 L 1 g
F P
s
P
p
.002 w
.46875 .57551 m .46881 .57546 L .46878 .57553 L p
1 g
F P
s
P
p
.002 w
.46818 .57513 m .4678 .57686 L p
.47368 .57734 L 1 g
F P
s
P
p
.002 w
.43602 .56219 m .4365 .56058 L .46746 .57484 L p
1 g
F P
s
P
p
.002 w
.46817 .57517 m .46818 .57513 L p
.4535 .56657 L 1 g
F P
s
P
p
.45863 .56862 m .4535 .56657 L .46818 .57513 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46817 .57517 L p
1 g
F P
s
P
p
.4535 .56657 m .45002 .56518 L .46817 .57517 L 1 g
F
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.40606 .54174 m .40196 .55652 L .37303 .54145 L p
1 g
F P
s
P
p
.002 w
.37303 .54145 m .37856 .51963 L .40606 .54174 L p
1 g
F P
s
P
p
.002 w
.37538 .47092 m .35497 .49507 L .33604 .46896 L p
1 g
F P
s
P
p
.002 w
.33604 .46896 m .35993 .43961 L .37538 .47092 L p
1 g
F P
s
P
p
.002 w
.57389 .56 m .57076 .58234 L .53796 .58465 L p
1 g
F P
s
P
p
.002 w
.57076 .58234 m .57389 .56 L .60551 .54681 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.59459 .31119 m .52799 .28807 L .53258 .26695 L p
1 g
F P
s
P
p
.002 w
.62255 .49377 m .63352 .53037 L .60551 .54681 L p
1 g
F P
s
P
p
.002 w
.63352 .53037 m .62255 .49377 L .64528 .46953 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.39233 .38438 m .3489 .40845 L .34258 .37855 L p
1 g
F P
s
P
p
.002 w
.34258 .37855 m .3895 .3518 L .39233 .38438 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.63002 .40127 m .66325 .44458 L .64528 .46953 L p
1 g
F P
s
P
p
.002 w
.66325 .44458 m .63002 .40127 L .64154 .37396 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.4365 .56058 m .43425 .56802 L .40196 .55652 L p
1 g
F P
s
P
p
.002 w
.40196 .55652 m .40606 .54174 L .4365 .56058 L p
1 g
F P
s
P
p
.002 w
.39475 .50124 m .37856 .51963 L .35497 .49507 L p
1 g
F P
s
P
p
.002 w
.35497 .49507 m .37538 .47092 L .39475 .50124 L p
1 g
F P
s
P
p
.002 w
.59578 .51641 m .60551 .54681 L .57389 .56 L p
1 g
F P
s
P
p
.002 w
.60551 .54681 m .59578 .51641 L .62255 .49377 L p
1 g
F P
s
P
p
.002 w
.44983 .33976 m .3895 .3518 L .39005 .32228 L p
1 g
F P
s
P
p
.002 w
.39005 .32228 m .45318 .30922 L .44983 .33976 L p
1 g
F P
s
P
p
.002 w
.52239 .31425 m .45318 .30922 L .45785 .28313 L p
1 g
F P
s
P
p
.002 w
.45785 .28313 m .52799 .28807 L .52239 .31425 L p
1 g
F P
s
P
p
.002 w
.39853 .4189 m .35993 .43961 L .3489 .40845 L p
1 g
F P
s
P
p
.002 w
.3489 .40845 m .39233 .38438 L .39853 .4189 L p
1 g
F P
s
P
p
.002 w
.58817 .33695 m .64154 .37396 L .63002 .40127 L p
1 g
F P
s
P
p
.002 w
.64154 .37396 m .58817 .33695 L .59459 .31119 L p
1 g
F P
s
P
p
.002 w
.52799 .28807 m .59459 .31119 L .58817 .33695 L p
1 g
F P
s
P
p
.002 w
.41736 .52943 m .40606 .54174 L .37856 .51963 L p
1 g
F P
s
P
p
.002 w
.37856 .51963 m .39475 .50124 L .41736 .52943 L p
1 g
F P
s
P
p
.002 w
.61426 .43008 m .64528 .46953 L .62255 .49377 L p
1 g
F P
s
P
p
.002 w
.64528 .46953 m .61426 .43008 L .63002 .40127 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.58817 .33695 m .52239 .31425 L .52799 .28807 L p
1 g
F P
s
P
p
.002 w
.53397 .55353 m .53976 .56939 L .5043 .57461 L p
1 g
F P
s
P
p
.002 w
.5043 .57461 m .50121 .56663 L .53397 .55353 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40792 .45407 m .37538 .47092 L .35993 .43961 L p
1 g
F P
s
P
p
.002 w
.35993 .43961 m .39853 .4189 L .40792 .45407 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.59472 .45933 m .62255 .49377 L .59578 .51641 L p
1 g
F P
s
P
p
.002 w
.62255 .49377 m .59472 .45933 L .61426 .43008 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.50121 .56663 m .49458 .55931 L .52104 .53887 L p
1 g
F P
s
P
p
.002 w
.52104 .53887 m .53397 .55353 L .50121 .56663 L p
1 g
F P
s
P
p
.002 w
.44798 .37374 m .39233 .38438 L .3895 .3518 L p
1 g
F P
s
P
p
.002 w
.3895 .3518 m .44983 .33976 L .44798 .37374 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.57885 .36628 m .63002 .40127 L .61426 .43008 L p
1 g
F P
s
P
p
.002 w
.63002 .40127 m .57885 .36628 L .58817 .33695 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42017 .48856 m .39475 .50124 L .37538 .47092 L p
1 g
F P
s
P
p
.002 w
.37538 .47092 m .40792 .45407 L .42017 .48856 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51595 .34473 m .44983 .33976 L .45318 .30922 L p
1 g
F P
s
P
p
.002 w
.45318 .30922 m .52239 .31425 L .51595 .34473 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.46215 .54874 m .45123 .55035 L .4348 .52105 L p
1 g
F P
s
P
p
.002 w
.49458 .55931 m .48512 .55349 L .50231 .52714 L p
1 g
F P
s
P
p
.002 w
.50231 .52714 m .52104 .53887 L .49458 .55931 L p
1 g
F P
s
P
p
.002 w
.59578 .51641 m .57209 .48794 L .59472 .45933 L p
1 g
F P
s
P
p
.002 w
.52239 .31425 m .58817 .33695 L .57885 .36628 L p
1 g
F P
s
P
p
.002 w
.53397 .55353 m .52104 .53887 L .54721 .51479 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.47389 .54982 m .46215 .54874 L .45648 .51767 L p
1 g
F P
s
P
p
.002 w
.4348 .52105 m .45648 .51767 L .46215 .54874 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48512 .55349 m .47389 .54982 L .47991 .51978 L p
1 g
F P
s
P
p
.002 w
.47991 .51978 m .50231 .52714 L .48512 .55349 L p
1 g
F P
s
P
p
.002 w
.45648 .51767 m .47991 .51978 L .47389 .54982 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57885 .36628 m .51595 .34473 L .52239 .31425 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.44772 .40993 m .39853 .4189 L .39233 .38438 L p
1 g
F P
s
P
p
.002 w
.39233 .38438 m .44798 .37374 L .44772 .40993 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56688 .39821 m .61426 .43008 L .59472 .45933 L p
1 g
F P
s
P
p
.002 w
.61426 .43008 m .56688 .39821 L .57885 .36628 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.52104 .53887 m .50231 .52714 L .51974 .49728 L p
1 g
F P
s
P
p
.002 w
.51974 .49728 m .54721 .51479 L .52104 .53887 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.50888 .37849 m .44798 .37374 L .44983 .33976 L p
1 g
F P
s
P
p
.002 w
.44983 .33976 m .51595 .34473 L .50888 .37849 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.4491 .44694 m .40792 .45407 L .39853 .4189 L p
1 g
F P
s
P
p
.002 w
.39853 .4189 m .44772 .40993 L .4491 .44694 L p
1 g
F P
s
P
p
.002 w
.51595 .34473 m .57885 .36628 L .56688 .39821 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55268 .43154 m .59472 .45933 L .57209 .48794 L p
1 g
F P
s
P
p
.002 w
.59472 .45933 m .55268 .43154 L .56688 .39821 L p
1 g
F P
s
P
p
.002 w
.47991 .51978 m .45648 .51767 L .45207 .48332 L p
1 g
F P
s
P
p
.002 w
.50231 .52714 m .47991 .51978 L .48668 .48633 L p
1 g
F P
s
P
p
.002 w
.48668 .48633 m .51974 .49728 L .50231 .52714 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.004 w
.4561 .63452 m
.45815 .62501 L
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57209 .48794 m .53676 .46501 L .55268 .43154 L p
1 g
F P
s
P
p
.002 w
.45207 .48332 m .48668 .48633 L .47991 .51978 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56688 .39821 m .50888 .37849 L .51595 .34473 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.50146 .41428 m .44772 .40993 L .44798 .37374 L p
1 g
F P
s
P
p
.002 w
.44798 .37374 m .50888 .37849 L .50146 .41428 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.50888 .37849 m .56688 .39821 L .55268 .43154 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49396 .4507 m .4491 .44694 L .44772 .40993 L p
1 g
F P
s
P
p
.002 w
.44772 .40993 m .50146 .41428 L .49396 .4507 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.55268 .43154 m .50146 .41428 L .50888 .37849 L p
1 g
F P
s
P
p
.002 w
.50146 .41428 m .55268 .43154 L .53676 .46501 L p
1 g
F P
s
P
p
.002 w
.53676 .46501 m .49396 .4507 L .50146 .41428 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .52925 .71668 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .4506 .66011 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.591473)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.591473)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44302 .42174 m .47599 .44703 L .49022 .4223 L p
1 g
F P
s
P
p
.002 w
.49022 .4223 m .46281 .40113 L .44302 .42174 L p
1 g
F P
s
P
p
.002 w
.52247 .43584 m .49022 .4223 L .47599 .44703 L p
1 g
F P
s
P
p
.002 w
.46281 .40113 m .49022 .4223 L .5047 .39775 L p
1 g
F P
s
P
p
.002 w
.49022 .4223 m .52247 .43584 L .52974 .40825 L p
1 g
F P
s
P
p
.002 w
.52974 .40825 m .5047 .39775 L .49022 .4223 L p
1 g
F P
s
P
p
.002 w
.47599 .44703 m .51467 .4633 L .52247 .43584 L p
1 g
F P
s
P
p
.002 w
.55652 .44045 m .52247 .43584 L .51467 .4633 L p
1 g
F P
s
P
p
.002 w
.52247 .43584 m .55652 .44045 L .55616 .41171 L p
1 g
F P
s
P
p
.002 w
.55616 .41171 m .52974 .40825 L .52247 .43584 L p
1 g
F P
s
P
p
.002 w
.42447 .44272 m .46226 .47151 L .47599 .44703 L p
1 g
F P
s
P
p
.002 w
.47599 .44703 m .44302 .42174 L .42447 .44272 L p
1 g
F P
s
P
p
.002 w
.51467 .4633 m .47599 .44703 L .46226 .47151 L p
1 g
F P
s
P
p
.002 w
.5047 .39775 m .48348 .38125 L .46281 .40113 L p
1 g
F P
s
P
p
.002 w
.48348 .38125 m .5047 .39775 L .51916 .37383 L p
1 g
F P
s
P
p
.002 w
.5047 .39775 m .52974 .40825 L .53632 .38102 L p
1 g
F P
s
P
p
.002 w
.53632 .38102 m .51916 .37383 L .5047 .39775 L p
1 g
F P
s
P
p
.002 w
.46226 .47151 m .50646 .49013 L .51467 .4633 L p
1 g
F P
s
P
p
.002 w
.5555 .46902 m .51467 .4633 L .50646 .49013 L p
1 g
F P
s
P
p
.002 w
.51467 .4633 m .5555 .46902 L .55652 .44045 L p
1 g
F P
s
P
p
.002 w
.52974 .40825 m .55616 .41171 L .55443 .38331 L p
1 g
F P
s
P
p
.002 w
.55443 .38331 m .53632 .38102 L .52974 .40825 L p
1 g
F P
s
P
p
.002 w
.41889 .38964 m .44302 .42174 L .46281 .40113 L p
1 g
F P
s
P
p
.002 w
.46281 .40113 m .44292 .37426 L .41889 .38964 L p
1 g
F P
s
P
p
.002 w
.44292 .37426 m .46281 .40113 L .48348 .38125 L p
1 g
F P
s
P
p
.002 w
.48348 .38125 m .46822 .36032 L .44292 .37426 L p
1 g
F P
s
P
p
.002 w
.46822 .36032 m .48348 .38125 L .50466 .36248 L p
1 g
F P
s
P
p
.002 w
.51916 .37383 m .50466 .36248 L .48348 .38125 L p
1 g
F P
s
P
p
.002 w
.40752 .46368 m .44929 .49528 L .46226 .47151 L p
1 g
F P
s
P
p
.002 w
.46226 .47151 m .42447 .44272 L .40752 .46368 L p
1 g
F P
s
P
p
.002 w
.50646 .49013 m .46226 .47151 L .44929 .49528 L p
1 g
F P
s
P
p
.002 w
.58911 .43555 m .55652 .44045 L .5555 .46902 L p
1 g
F P
s
P
p
.002 w
.55652 .44045 m .58911 .43555 L .58137 .4077 L p
1 g
F P
s
P
p
.002 w
.58137 .4077 m .55616 .41171 L .55652 .44045 L p
1 g
F P
s
P
p
.002 w
.39661 .4062 m .42447 .44272 L .44302 .42174 L p
1 g
F P
s
P
p
.002 w
.44302 .42174 m .41889 .38964 L .39661 .4062 L p
1 g
F P
s
P
p
.002 w
.55616 .41171 m .58137 .4077 L .57164 .38042 L p
1 g
F P
s
P
p
.002 w
.57164 .38042 m .55443 .38331 L .55616 .41171 L p
1 g
F P
s
P
p
.002 w
.50466 .36248 m .51916 .37383 L .53333 .35099 L p
1 g
F P
s
P
p
.002 w
.51916 .37383 m .53632 .38102 L .54211 .35466 L p
1 g
F P
s
P
p
.002 w
.54211 .35466 m .53333 .35099 L .51916 .37383 L p
1 g
F P
s
P
p
.002 w
.44929 .49528 m .49799 .51583 L .50646 .49013 L p
1 g
F P
s
P
p
.002 w
.55312 .49687 m .50646 .49013 L .49799 .51583 L p
1 g
F P
s
P
p
.002 w
.50646 .49013 m .55312 .49687 L .5555 .46902 L p
1 g
F P
s
P
p
.002 w
.53632 .38102 m .55443 .38331 L .55135 .35578 L p
1 g
F P
s
P
p
.002 w
.55135 .35578 m .54211 .35466 L .53632 .38102 L p
1 g
F P
s
P
p
.002 w
.59471 .46346 m .5555 .46902 L .55312 .49687 L p
1 g
F P
s
P
p
.002 w
.5555 .46902 m .59471 .46346 L .58911 .43555 L p
1 g
F P
s
P
p
.002 w
.50466 .36248 m .49432 .34809 L .46822 .36032 L p
1 g
F P
s
P
p
.002 w
.49432 .34809 m .50466 .36248 L .52595 .34517 L p
1 g
F P
s
P
p
.002 w
.53333 .35099 m .52595 .34517 L .50466 .36248 L p
1 g
F P
s
P
p
.002 w
.55443 .38331 m .57164 .38042 L .5601 .35424 L p
1 g
F P
s
P
p
.002 w
.5601 .35424 m .55135 .35578 L .55443 .38331 L p
1 g
F P
s
P
p
.002 w
.37654 .42363 m .40752 .46368 L .42447 .44272 L p
1 g
F P
s
P
p
.002 w
.42447 .44272 m .39661 .4062 L .37654 .42363 L p
1 g
F P
s
P
p
.002 w
.43267 .34418 m .44292 .37426 L .46822 .36032 L p
1 g
F P
s
P
p
.002 w
.46822 .36032 m .46055 .33697 L .43267 .34418 L p
1 g
F P
s
P
p
.002 w
.46055 .33697 m .46822 .36032 L .49432 .34809 L p
1 g
F P
s
P
p
.002 w
.40619 .35361 m .41889 .38964 L .44292 .37426 L p
1 g
F P
s
P
p
.002 w
.44292 .37426 m .43267 .34418 L .40619 .35361 L p
1 g
F P
s
P
p
.002 w
.39256 .48421 m .43733 .51788 L .44929 .49528 L p
1 g
F P
s
P
p
.002 w
.44929 .49528 m .40752 .46368 L .39256 .48421 L p
1 g
F P
s
P
p
.002 w
.49799 .51583 m .44929 .49528 L .43733 .51788 L p
1 g
F P
s
P
p
.002 w
.49432 .34809 m .48926 .3321 L .46055 .33697 L p
1 g
F P
s
P
p
.002 w
.48926 .3321 m .49432 .34809 L .52073 .3378 L p
1 g
F P
s
P
p
.002 w
.52595 .34517 m .52073 .3378 L .49432 .34809 L p
1 g
F P
s
P
p
.002 w
.60279 .39646 m .58137 .4077 L .58911 .43555 L p
1 g
F P
s
P
p
.002 w
.58137 .4077 m .60279 .39646 L .58616 .37259 L p
1 g
F P
s
P
p
.002 w
.58616 .37259 m .57164 .38042 L .58137 .4077 L p
1 g
F P
s
P
p
.002 w
.59803 .49087 m .55312 .49687 L .54939 .52349 L p
1 g
F P
s
P
p
.002 w
.49799 .51583 m .54939 .52349 L .55312 .49687 L p
1 g
F P
s
P
p
.002 w
.55312 .49687 m .59803 .49087 L .59471 .46346 L p
1 g
F P
s
P
p
.002 w
.43733 .51788 m .48941 .53989 L .49799 .51583 L p
1 g
F P
s
P
p
.002 w
.54939 .52349 m .49799 .51583 L .48941 .53989 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .52595 .34517 L .53333 .35099 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .53333 .35099 L .54211 .35466 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .54211 .35466 L .55135 .35578 L closepath p
1 g
F P
s
P
p
.002 w
.57164 .38042 m .58616 .37259 L .56743 .35018 L p
1 g
F P
s
P
p
.002 w
.56743 .35018 m .5601 .35424 L .57164 .38042 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .52073 .3378 L .52595 .34517 L closepath p
1 g
F P
s
P
p
.002 w
.61699 .42135 m .58911 .43555 L .59471 .46346 L p
1 g
F P
s
P
p
.002 w
.58911 .43555 m .61699 .42135 L .60279 .39646 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .55135 .35578 L .5601 .35424 L closepath p
1 g
F P
s
P
p
.002 w
.38165 .36512 m .39661 .4062 L .41889 .38964 L p
1 g
F P
s
P
p
.002 w
.41889 .38964 m .40619 .35361 L .38165 .36512 L p
1 g
F P
s
P
p
.002 w
.52073 .3378 m .51825 .32965 L .48926 .3321 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .51825 .32965 L .52073 .3378 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .5601 .35424 L .56743 .35018 L closepath p
1 g
F P
s
P
p
.002 w
.35916 .4416 m .39256 .48421 L .40752 .46368 L p
1 g
F P
s
P
p
.002 w
.40752 .46368 m .37654 .42363 L .35916 .4416 L p
1 g
F P
s
P
p
.002 w
.46148 .31355 m .46055 .33697 L .48926 .3321 L p
1 g
F P
s
P
p
.002 w
.48926 .3321 m .49012 .31616 L .46148 .31355 L p
1 g
F P
s
P
p
.002 w
.49012 .31616 m .48926 .3321 L .51825 .32965 L p
1 g
F P
s
P
p
.002 w
.62843 .44676 m .59471 .46346 L .59803 .49087 L p
1 g
F P
s
P
p
.002 w
.59471 .46346 m .62843 .44676 L .61699 .42135 L p
1 g
F P
s
P
p
.002 w
.43348 .31385 m .43267 .34418 L .46055 .33697 L p
1 g
F P
s
P
p
.002 w
.46055 .33697 m .46148 .31355 L .43348 .31385 L p
1 g
F P
s
P
p
.002 w
.51825 .32965 m .5188 .32158 L .49012 .31616 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .5188 .32158 L .51825 .32965 L closepath p
1 g
F P
s
P
p
.002 w
.59639 .36053 m .58616 .37259 L .60279 .39646 L p
1 g
F P
s
P
p
.002 w
.58616 .37259 m .59639 .36053 L .57252 .344 L p
1 g
F P
s
P
p
.002 w
.57252 .344 m .56743 .35018 L .58616 .37259 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .56743 .35018 L .57252 .344 L closepath p
1 g
F P
s
P
p
.002 w
.59895 .51725 m .54939 .52349 L .54436 .5483 L p
1 g
F P
s
P
p
.002 w
.48941 .53989 m .54436 .5483 L .54939 .52349 L p
1 g
F P
s
P
p
.002 w
.54939 .52349 m .59895 .51725 L .59803 .49087 L p
1 g
F P
s
P
p
.002 w
.35962 .37851 m .37654 .42363 L .39661 .4062 L p
1 g
F P
s
P
p
.002 w
.39661 .4062 m .38165 .36512 L .35962 .37851 L p
1 g
F P
s
P
p
.002 w
.37993 .50391 m .42665 .53884 L .43733 .51788 L p
1 g
F P
s
P
p
.002 w
.43733 .51788 m .39256 .48421 L .37993 .50391 L p
1 g
F P
s
P
p
.002 w
.48941 .53989 m .43733 .51788 L .42665 .53884 L p
1 g
F P
s
P
p
.002 w
.61808 .37896 m .60279 .39646 L .61699 .42135 L p
1 g
F P
s
P
p
.002 w
.60279 .39646 m .61808 .37896 L .59639 .36053 L p
1 g
F P
s
P
p
.002 w
.40669 .3171 m .40619 .35361 L .43267 .34418 L p
1 g
F P
s
P
p
.002 w
.43267 .34418 m .43348 .31385 L .40669 .3171 L p
1 g
F P
s
P
p
.002 w
.42665 .53884 m .4809 .56179 L .48941 .53989 L p
1 g
F P
s
P
p
.002 w
.54436 .5483 m .48941 .53989 L .4809 .56179 L p
1 g
F P
s
P
p
.002 w
.49692 .30198 m .49012 .31616 L .5188 .32158 L p
1 g
F P
s
P
p
.002 w
.5188 .32158 m .52234 .31446 L .49692 .30198 L p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .52234 .31446 L .5188 .32158 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .57252 .344 L .57482 .33635 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .57482 .33635 L .57402 .32804 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .57402 .32804 L .5702 .32 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .5702 .32 L .56374 .31312 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .56374 .31312 L .55537 .30818 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .55537 .30818 L .54601 .30573 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .54601 .30573 L .53672 .30605 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .53672 .30605 L .52853 .30908 L closepath p
1 g
F P
s
P
p
.002 w
.54696 .32968 m .52853 .30908 L .52234 .31446 L closepath p
1 g
F P
s
P
p
.002 w
.57482 .33635 m .57252 .344 L .59639 .36053 L p
1 g
F P
s
P
p
.002 w
.4712 .29256 m .46148 .31355 L .49012 .31616 L p
1 g
F P
s
P
p
.002 w
.49012 .31616 m .49692 .30198 L .4712 .29256 L p
1 g
F P
s
P
p
.002 w
.63683 .47219 m .59803 .49087 L .59895 .51725 L p
1 g
F P
s
P
p
.002 w
.59803 .49087 m .63683 .47219 L .62843 .44676 L p
1 g
F P
s
P
p
.002 w
.63709 .39895 m .61699 .42135 L .62843 .44676 L p
1 g
F P
s
P
p
.002 w
.61699 .42135 m .63709 .39895 L .61808 .37896 L p
1 g
F P
s
P
p
.002 w
.50907 .29117 m .49692 .30198 L .52234 .31446 L p
1 g
F P
s
P
p
.002 w
.52234 .31446 m .52853 .30908 L .50907 .29117 L p
1 g
F P
s
P
p
.002 w
.60114 .34546 m .59639 .36053 L .61808 .37896 L p
1 g
F P
s
P
p
.002 w
.59639 .36053 m .60114 .34546 L .57482 .33635 L p
1 g
F P
s
P
p
.002 w
.34492 .45976 m .37993 .50391 L .39256 .48421 L p
1 g
F P
s
P
p
.002 w
.39256 .48421 m .35916 .4416 L .34492 .45976 L p
1 g
F P
s
P
p
.002 w
.57402 .32804 m .57482 .33635 L .60114 .34546 L p
1 g
F P
s
P
p
.002 w
.38173 .32333 m .38165 .36512 L .40619 .35361 L p
1 g
F P
s
P
p
.002 w
.40619 .35361 m .40669 .3171 L .38173 .32333 L p
1 g
F P
s
P
p
.002 w
.44572 .28647 m .43348 .31385 L .46148 .31355 L p
1 g
F P
s
P
p
.002 w
.46148 .31355 m .4712 .29256 L .44572 .28647 L p
1 g
F P
s
P
p
.002 w
.34067 .39357 m .35916 .4416 L .37654 .42363 L p
1 g
F P
s
P
p
.002 w
.37654 .42363 m .35962 .37851 L .34067 .39357 L p
1 g
F P
s
P
p
.002 w
.52531 .285 m .50907 .29117 L .52853 .30908 L p
1 g
F P
s
P
p
.002 w
.52853 .30908 m .53672 .30605 L .52531 .285 L p
1 g
F P
s
P
p
.002 w
.59738 .54202 m .54436 .5483 L .53808 .57076 L p
1 g
F P
s
P
p
.002 w
.4809 .56179 m .53808 .57076 L .54436 .5483 L p
1 g
F P
s
P
p
.002 w
.54436 .5483 m .59738 .54202 L .59895 .51725 L p
1 g
F P
s
P
p
.002 w
.60114 .34546 m .59975 .32896 L .57402 .32804 L p
1 g
F P
s
P
p
.002 w
.5702 .32 m .57402 .32804 L .59975 .32896 L p
1 g
F P
s
P
p
.002 w
.48893 .27641 m .4712 .29256 L .49692 .30198 L p
1 g
F P
s
P
p
.002 w
.49692 .30198 m .50907 .29117 L .48893 .27641 L p
1 g
F P
s
P
p
.002 w
.62536 .35687 m .61808 .37896 L .63709 .39895 L p
1 g
F P
s
P
p
.002 w
.61808 .37896 m .62536 .35687 L .60114 .34546 L p
1 g
F P
s
P
p
.002 w
.65297 .42012 m .62843 .44676 L .63683 .47219 L p
1 g
F P
s
P
p
.002 w
.62843 .44676 m .65297 .42012 L .63709 .39895 L p
1 g
F P
s
P
p
.002 w
.54387 .28428 m .52531 .285 L .53672 .30605 L p
1 g
F P
s
P
p
.002 w
.53672 .30605 m .54601 .30573 L .54387 .28428 L p
1 g
F P
s
P
p
.002 w
.36999 .5223 m .41753 .55766 L .42665 .53884 L p
1 g
F P
s
P
p
.002 w
.42665 .53884 m .37993 .50391 L .36999 .5223 L p
1 g
F P
s
P
p
.002 w
.4809 .56179 m .42665 .53884 L .41753 .55766 L p
1 g
F P
s
P
p
.002 w
.59975 .32896 m .59225 .31288 L .5702 .32 L p
1 g
F P
s
P
p
.002 w
.56374 .31312 m .5702 .32 L .59225 .31288 L p
1 g
F P
s
P
p
.002 w
.64191 .49711 m .59895 .51725 L .59738 .54202 L p
1 g
F P
s
P
p
.002 w
.59895 .51725 m .64191 .49711 L .63683 .47219 L p
1 g
F P
s
P
p
.002 w
.59975 .32896 m .60114 .34546 L .62536 .35687 L p
1 g
F P
s
P
p
.002 w
.41753 .55766 m .47262 .581 L .4809 .56179 L p
1 g
F P
s
P
p
.002 w
.53808 .57076 m .4809 .56179 L .47262 .581 L p
1 g
F P
s
P
p
.002 w
.56262 .28915 m .54387 .28428 L .54601 .30573 L p
1 g
F P
s
P
p
.002 w
.54601 .30573 m .55537 .30818 L .56262 .28915 L p
1 g
F P
s
P
p
.002 w
.59225 .31288 m .5794 .29907 L .56374 .31312 L p
1 g
F P
s
P
p
.002 w
.55537 .30818 m .56374 .31312 L .5794 .29907 L p
1 g
F P
s
P
p
.002 w
.5794 .29907 m .56262 .28915 L .55537 .30818 L p
1 g
F P
s
P
p
.002 w
.42103 .28396 m .40669 .3171 L .43348 .31385 L p
1 g
F P
s
P
p
.002 w
.43348 .31385 m .44572 .28647 L .42103 .28396 L p
1 g
F P
s
P
p
.002 w
.35921 .33249 m .35962 .37851 L .38165 .36512 L p
1 g
F P
s
P
p
.002 w
.38165 .36512 m .38173 .32333 L .35921 .33249 L p
1 g
F P
s
P
p
.002 w
.51292 .2671 m .48893 .27641 L .50907 .29117 L p
1 g
F P
s
P
p
.002 w
.50907 .29117 m .52531 .285 L .51292 .2671 L p
1 g
F P
s
P
p
.002 w
.6469 .37042 m .63709 .39895 L .65297 .42012 L p
1 g
F P
s
P
p
.002 w
.63709 .39895 m .6469 .37042 L .62536 .35687 L p
1 g
F P
s
P
p
.002 w
.33428 .47772 m .36999 .5223 L .37993 .50391 L p
1 g
F P
s
P
p
.002 w
.37993 .50391 m .34492 .45976 L .33428 .47772 L p
1 g
F P
s
P
p
.002 w
.46855 .26524 m .44572 .28647 L .4712 .29256 L p
1 g
F P
s
P
p
.002 w
.4712 .29256 m .48893 .27641 L .46855 .26524 L p
1 g
F P
s
P
p
.002 w
.32533 .41003 m .34492 .45976 L .35916 .4416 L p
1 g
F P
s
P
p
.002 w
.35916 .4416 m .34067 .39357 L .32533 .41003 L p
1 g
F P
s
P
p
.002 w
.62536 .35687 m .62356 .3325 L .59975 .32896 L p
1 g
F P
s
P
p
.002 w
.59225 .31288 m .59975 .32896 L .62356 .3325 L p
1 g
F P
s
P
p
.002 w
.66527 .44204 m .63683 .47219 L .64191 .49711 L p
1 g
F P
s
P
p
.002 w
.63683 .47219 m .66527 .44204 L .65297 .42012 L p
1 g
F P
s
P
p
.002 w
.47262 .581 m .53063 .59029 L .53808 .57076 L p
1 g
F P
s
P
p
.002 w
.59327 .56459 m .53808 .57076 L .53063 .59029 L p
1 g
F P
s
P
p
.002 w
.53808 .57076 m .59327 .56459 L .59738 .54202 L p
1 g
F P
s
P
p
.002 w
.62356 .3325 m .62536 .35687 L .6469 .37042 L p
1 g
F P
s
P
p
.002 w
.39774 .28521 m .38173 .32333 L .40669 .3171 L p
1 g
F P
s
P
p
.002 w
.40669 .3171 m .42103 .28396 L .39774 .28521 L p
1 g
F P
s
P
p
.002 w
.54051 .26591 m .51292 .2671 L .52531 .285 L p
1 g
F P
s
P
p
.002 w
.52531 .285 m .54387 .28428 L .54051 .26591 L p
1 g
F P
s
P
p
.002 w
.64345 .52094 m .59738 .54202 L .59327 .56459 L p
1 g
F P
s
P
p
.002 w
.59738 .54202 m .64345 .52094 L .64191 .49711 L p
1 g
F P
s
P
p
.002 w
.62356 .3325 m .61259 .30858 L .59225 .31288 L p
1 g
F P
s
P
p
.002 w
.5794 .29907 m .59225 .31288 L .61259 .30858 L p
1 g
F P
s
P
p
.002 w
.33976 .3445 m .34067 .39357 L .35962 .37851 L p
1 g
F P
s
P
p
.002 w
.35962 .37851 m .35921 .33249 L .33976 .3445 L p
1 g
F P
s
P
p
.002 w
.36311 .53893 m .41022 .57383 L .41753 .55766 L p
1 g
F P
s
P
p
.002 w
.41753 .55766 m .36999 .5223 L .36311 .53893 L p
1 g
F P
s
P
p
.002 w
.47262 .581 m .41753 .55766 L .41022 .57383 L p
1 g
F P
s
P
p
.002 w
.5685 .27313 m .54051 .26591 L .54387 .28428 L p
1 g
F P
s
P
p
.002 w
.54387 .28428 m .56262 .28915 L .5685 .27313 L p
1 g
F P
s
P
p
.002 w
.41022 .57383 m .46477 .59696 L .47262 .581 L p
1 g
F P
s
P
p
.002 w
.53063 .59029 m .47262 .581 L .46477 .59696 L p
1 g
F P
s
P
p
.002 w
.66518 .38587 m .65297 .42012 L .66527 .44204 L p
1 g
F P
s
P
p
.002 w
.65297 .42012 m .66518 .38587 L .6469 .37042 L p
1 g
F P
s
P
p
.002 w
.61259 .30858 m .59352 .28795 L .5794 .29907 L p
1 g
F P
s
P
p
.002 w
.56262 .28915 m .5794 .29907 L .59352 .28795 L p
1 g
F P
s
P
p
.002 w
.44837 .25808 m .42103 .28396 L .44572 .28647 L p
1 g
F P
s
P
p
.002 w
.44572 .28647 m .46855 .26524 L .44837 .25808 L p
1 g
F P
s
P
p
.002 w
.49978 .25288 m .46855 .26524 L .48893 .27641 L p
1 g
F P
s
P
p
.002 w
.48893 .27641 m .51292 .2671 L .49978 .25288 L p
1 g
F P
s
P
p
.002 w
.59352 .28795 m .5685 .27313 L .56262 .28915 L p
1 g
F P
s
P
p
.002 w
.67358 .46424 m .64191 .49711 L .64345 .52094 L p
1 g
F P
s
P
p
.002 w
.64191 .49711 m .67358 .46424 L .66527 .44204 L p
1 g
F P
s
P
p
.002 w
.6469 .37042 m .64485 .33868 L .62356 .3325 L p
1 g
F P
s
P
p
.002 w
.61259 .30858 m .62356 .3325 L .64485 .33868 L p
1 g
F P
s
P
p
.002 w
.31413 .42755 m .33428 .47772 L .34492 .45976 L p
1 g
F P
s
P
p
.002 w
.34492 .45976 m .32533 .41003 L .31413 .42755 L p
1 g
F P
s
P
p
.002 w
.64485 .33868 m .6469 .37042 L .66518 .38587 L p
1 g
F P
s
P
p
.002 w
.32766 .49504 m .36311 .53893 L .36999 .5223 L p
1 g
F P
s
P
p
.002 w
.36999 .5223 m .33428 .47772 L .32766 .49504 L p
1 g
F P
s
P
p
.002 w
.37645 .29036 m .35921 .33249 L .38173 .32333 L p
1 g
F P
s
P
p
.002 w
.38173 .32333 m .39774 .28521 L .37645 .29036 L p
1 g
F P
s
P
p
.002 w
.46477 .59696 m .52213 .60631 L .53063 .59029 L p
1 g
F P
s
P
p
.002 w
.58659 .58434 m .53063 .59029 L .52213 .60631 L p
1 g
F P
s
P
p
.002 w
.53063 .59029 m .58659 .58434 L .59327 .56459 L p
1 g
F P
s
P
p
.002 w
.64126 .54309 m .59327 .56459 L .58659 .58434 L p
1 g
F P
s
P
p
.002 w
.59327 .56459 m .64126 .54309 L .64345 .52094 L p
1 g
F P
s
P
p
.002 w
.32399 .35919 m .32533 .41003 L .34067 .39357 L p
1 g
F P
s
P
p
.002 w
.34067 .39357 m .33976 .3445 L .32399 .35919 L p
1 g
F P
s
P
p
.002 w
.53597 .2512 m .49978 .25288 L .51292 .2671 L p
1 g
F P
s
P
p
.002 w
.51292 .2671 m .54051 .26591 L .53597 .2512 L p
1 g
F P
s
P
p
.002 w
.67964 .40295 m .66527 .44204 L .67358 .46424 L p
1 g
F P
s
P
p
.002 w
.66527 .44204 m .67964 .40295 L .66518 .38587 L p
1 g
F P
s
P
p
.002 w
.64485 .33868 m .63067 .30733 L .61259 .30858 L p
1 g
F P
s
P
p
.002 w
.59352 .28795 m .61259 .30858 L .63067 .30733 L p
1 g
F P
s
P
p
.002 w
.4289 .25528 m .39774 .28521 L .42103 .28396 L p
1 g
F P
s
P
p
.002 w
.42103 .28396 m .44837 .25808 L .4289 .25528 L p
1 g
F P
s
P
p
.002 w
.48618 .24289 m .44837 .25808 L .46855 .26524 L p
1 g
F P
s
P
p
.002 w
.46855 .26524 m .49978 .25288 L .48618 .24289 L p
1 g
F P
s
P
p
.002 w
.35961 .55331 m .40502 .58683 L .41022 .57383 L p
1 g
F P
s
P
p
.002 w
.41022 .57383 m .36311 .53893 L .35961 .55331 L p
1 g
F P
s
P
p
.002 w
.46477 .59696 m .41022 .57383 L .40502 .58683 L p
1 g
F P
s
P
p
.002 w
.5728 .26065 m .53597 .2512 L .54051 .26591 L p
1 g
F P
s
P
p
.002 w
.54051 .26591 m .5685 .27313 L .5728 .26065 L p
1 g
F P
s
P
p
.002 w
.67752 .48621 m .64345 .52094 L .64126 .54309 L p
1 g
F P
s
P
p
.002 w
.64345 .52094 m .67752 .48621 L .67358 .46424 L p
1 g
F P
s
P
p
.002 w
.40502 .58683 m .45755 .60912 L .46477 .59696 L p
1 g
F P
s
P
p
.002 w
.52213 .60631 m .46477 .59696 L .45755 .60912 L p
1 g
F P
s
P
p
.002 w
.63067 .30733 m .60571 .28018 L .59352 .28795 L p
1 g
F P
s
P
p
.002 w
.5685 .27313 m .59352 .28795 L .60571 .28018 L p
1 g
F P
s
P
p
.002 w
.66299 .34748 m .66518 .38587 L .67964 .40295 L p
1 g
F P
s
P
p
.002 w
.66518 .38587 m .66299 .34748 L .64485 .33868 L p
1 g
F P
s
P
p
.002 w
.63067 .30733 m .64485 .33868 L .66299 .34748 L p
1 g
F P
s
P
p
.002 w
.35781 .29946 m .33976 .3445 L .35921 .33249 L p
1 g
F P
s
P
p
.002 w
.35921 .33249 m .37645 .29036 L .35781 .29946 L p
1 g
F P
s
P
p
.002 w
.60571 .28018 m .5728 .26065 L .5685 .27313 L p
1 g
F P
s
P
p
.002 w
.30758 .44575 m .32766 .49504 L .33428 .47772 L p
1 g
F P
s
P
p
.002 w
.33428 .47772 m .31413 .42755 L .30758 .44575 L p
1 g
F P
s
P
p
.002 w
.32543 .51126 m .35961 .55331 L .36311 .53893 L p
1 g
F P
s
P
p
.002 w
.36311 .53893 m .32766 .49504 L .32543 .51126 L p
1 g
F P
s
P
p
.002 w
.31249 .3763 m .31413 .42755 L .32533 .41003 L p
1 g
F P
s
P
p
.002 w
.32533 .41003 m .32399 .35919 L .31249 .3763 L p
1 g
F P
s
P
p
.002 w
.52213 .60631 m .57738 .60069 L .58659 .58434 L p
1 g
F P
s
P
p
.002 w
.63523 .56294 m .58659 .58434 L .57738 .60069 L p
1 g
F P
s
P
p
.002 w
.58659 .58434 m .63523 .56294 L .64126 .54309 L p
1 g
F P
s
P
p
.002 w
.68976 .42131 m .67358 .46424 L .67752 .48621 L p
1 g
F P
s
P
p
.002 w
.67358 .46424 m .68976 .42131 L .67964 .40295 L p
1 g
F P
s
P
p
.002 w
.57738 .60069 m .52213 .60631 L .51272 .61824 L p
1 g
F P
s
P
p
.002 w
.45755 .60912 m .51272 .61824 L .52213 .60631 L p
1 g
F P
s
P
p
.002 w
.53028 .24073 m .48618 .24289 L .49978 .25288 L p
1 g
F P
s
P
p
.002 w
.49978 .25288 m .53597 .2512 L .53028 .24073 L p
1 g
F P
s
P
p
.002 w
.41067 .25714 m .37645 .29036 L .39774 .28521 L p
1 g
F P
s
P
p
.002 w
.39774 .28521 m .4289 .25528 L .41067 .25714 L p
1 g
F P
s
P
p
.002 w
.66299 .34748 m .64594 .30933 L .63067 .30733 L p
1 g
F P
s
P
p
.002 w
.60571 .28018 m .63067 .30733 L .64594 .30933 L p
1 g
F P
s
P
p
.002 w
.47243 .23761 m .4289 .25528 L .44837 .25808 L p
1 g
F P
s
P
p
.002 w
.44837 .25808 m .48618 .24289 L .47243 .23761 L p
1 g
F P
s
P
p
.002 w
.67681 .50738 m .64126 .54309 L .63523 .56294 L p
1 g
F P
s
P
p
.002 w
.64126 .54309 m .67681 .50738 L .67752 .48621 L p
1 g
F P
s
P
p
.002 w
.6774 .35883 m .67964 .40295 L .68976 .42131 L p
1 g
F P
s
P
p
.002 w
.67964 .40295 m .6774 .35883 L .66299 .34748 L p
1 g
F P
s
P
p
.002 w
.34244 .31249 m .32399 .35919 L .33976 .3445 L p
1 g
F P
s
P
p
.002 w
.33976 .3445 m .35781 .29946 L .34244 .31249 L p
1 g
F P
s
P
p
.002 w
.5753 .25224 m .53028 .24073 L .53597 .2512 L p
1 g
F P
s
P
p
.002 w
.53597 .2512 m .5728 .26065 L .5753 .25224 L p
1 g
F P
s
P
p
.002 w
.35977 .56494 m .40215 .59616 L .40502 .58683 L p
1 g
F P
s
P
p
.002 w
.40502 .58683 m .35961 .55331 L .35977 .56494 L p
1 g
F P
s
P
p
.002 w
.45755 .60912 m .40502 .58683 L .40215 .59616 L p
1 g
F P
s
P
p
.002 w
.64594 .30933 m .66299 .34748 L .6774 .35883 L p
1 g
F P
s
P
p
.002 w
.40215 .59616 m .45118 .61697 L .45755 .60912 L p
1 g
F P
s
P
p
.002 w
.51272 .61824 m .45755 .60912 L .45118 .61697 L p
1 g
F P
s
P
p
.002 w
.64594 .30933 m .61554 .27615 L .60571 .28018 L p
1 g
F P
s
P
p
.002 w
.5728 .26065 m .60571 .28018 L .61554 .27615 L p
1 g
F P
s
P
p
.002 w
.30607 .46419 m .32543 .51126 L .32766 .49504 L p
1 g
F P
s
P
p
.002 w
.32766 .49504 m .30758 .44575 L .30607 .46419 L p
1 g
F P
s
P
p
.002 w
.61554 .27615 m .5753 .25224 L .5728 .26065 L p
1 g
F P
s
P
p
.002 w
.30578 .3955 m .30758 .44575 L .31413 .42755 L p
1 g
F P
s
P
p
.002 w
.31413 .42755 m .31249 .3763 L .30578 .3955 L p
1 g
F P
s
P
p
.002 w
.69505 .44055 m .67752 .48621 L .67681 .50738 L p
1 g
F P
s
P
p
.002 w
.67752 .48621 m .69505 .44055 L .68976 .42131 L p
1 g
F P
s
P
p
.002 w
.32791 .5259 m .35977 .56494 L .35961 .55331 L p
1 g
F P
s
P
p
.002 w
.35961 .55331 m .32543 .51126 L .32791 .5259 L p
1 g
F P
s
P
p
.002 w
.39424 .26388 m .35781 .29946 L .37645 .29036 L p
1 g
F P
s
P
p
.002 w
.37645 .29036 m .41067 .25714 L .39424 .26388 L p
1 g
F P
s
P
p
.002 w
.51272 .61824 m .56574 .61302 L .57738 .60069 L p
1 g
F P
s
P
p
.002 w
.62531 .57987 m .57738 .60069 L .56574 .61302 L p
1 g
F P
s
P
p
.002 w
.57738 .60069 m .62531 .57987 L .63523 .56294 L p
1 g
F P
s
P
p
.002 w
.52351 .23503 m .47243 .23761 L .48618 .24289 L p
1 g
F P
s
P
p
.002 w
.48618 .24289 m .53028 .24073 L .52351 .23503 L p
1 g
F P
s
P
p
.002 w
.45118 .61697 m .50259 .62554 L .51272 .61824 L p
1 g
F P
s
P
p
.002 w
.56574 .61302 m .51272 .61824 L .50259 .62554 L p
1 g
F P
s
P
p
.002 w
.45889 .23746 m .41067 .25714 L .4289 .25528 L p
1 g
F P
s
P
p
.002 w
.4289 .25528 m .47243 .23761 L .45889 .23746 L p
1 g
F P
s
P
p
.002 w
.67122 .52715 m .63523 .56294 L .62531 .57987 L p
1 g
F P
s
P
p
.002 w
.63523 .56294 m .67122 .52715 L .67681 .50738 L p
1 g
F P
s
P
p
.002 w
.6774 .35883 m .65783 .31472 L .64594 .30933 L p
1 g
F P
s
P
p
.002 w
.61554 .27615 m .64594 .30933 L .65783 .31472 L p
1 g
F P
s
P
p
.002 w
.33094 .32926 m .31249 .3763 L .32399 .35919 L p
1 g
F P
s
P
p
.002 w
.32399 .35919 m .34244 .31249 L .33094 .32926 L p
1 g
F P
s
P
p
.002 w
.68748 .37255 m .68976 .42131 L .69505 .44055 L p
1 g
F P
s
P
p
.002 w
.68976 .42131 m .68748 .37255 L .6774 .35883 L p
1 g
F P
s
P
p
.002 w
.65783 .31472 m .6774 .35883 L .68748 .37255 L p
1 g
F P
s
P
p
.002 w
.57584 .2484 m .52351 .23503 L .53028 .24073 L p
1 g
F P
s
P
p
.002 w
.53028 .24073 m .5753 .25224 L .57584 .2484 L p
1 g
F P
s
P
p
.002 w
.30994 .48235 m .32791 .5259 L .32543 .51126 L p
1 g
F P
s
P
p
.002 w
.32543 .51126 m .30607 .46419 L .30994 .48235 L p
1 g
F P
s
P
p
.002 w
.36381 .57334 m .40185 .60133 L .40215 .59616 L p
1 g
F P
s
P
p
.002 w
.40215 .59616 m .35977 .56494 L .36381 .57334 L p
1 g
F P
s
P
p
.002 w
.45118 .61697 m .40215 .59616 L .40185 .60133 L p
1 g
F P
s
P
p
.002 w
.40185 .60133 m .44588 .62003 L .45118 .61697 L p
1 g
F P
s
P
p
.002 w
.50259 .62554 m .45118 .61697 L .44588 .62003 L p
1 g
F P
s
P
p
.002 w
.69513 .46019 m .67681 .50738 L .67122 .52715 L p
1 g
F P
s
P
p
.002 w
.67681 .50738 m .69513 .46019 L .69505 .44055 L p
1 g
F P
s
P
p
.002 w
.65783 .31472 m .62261 .27619 L .61554 .27615 L p
1 g
F P
s
P
p
.002 w
.5753 .25224 m .61554 .27615 L .62261 .27619 L p
1 g
F P
s
P
p
.002 w
.30431 .41636 m .30607 .46419 L .30758 .44575 L p
1 g
F P
s
P
p
.002 w
.30758 .44575 m .30578 .3955 L .30431 .41636 L p
1 g
F P
s
P
p
.002 w
.38017 .27557 m .34244 .31249 L .35781 .29946 L p
1 g
F P
s
P
p
.002 w
.35781 .29946 m .39424 .26388 L .38017 .27557 L p
1 g
F P
s
P
p
.004 w
.43269 .6105 m
.5 .43051 L
s
P
p
.004 w
.43026 .61698 m
.43142 .61388 L
s
P
p
.004 w
.42865 .6213 m
.43026 .61698 L
s
P
p
.004 w
.39823 .70262 m
.42865 .6213 L
s
P
p
.002 w
.62261 .27619 m .57584 .2484 L .5753 .25224 L p
1 g
F P
s
P
p
.002 w
.50259 .62554 m .55184 .62079 L .56574 .61302 L p
1 g
F P
s
P
p
.002 w
.61157 .59328 m .56574 .61302 L .55184 .62079 L p
1 g
F P
s
P
p
.002 w
.56574 .61302 m .61157 .59328 L .62531 .57987 L p
1 g
F P
s
P
p
.002 w
.33531 .53845 m .36381 .57334 L .35977 .56494 L p
1 g
F P
s
P
p
.002 w
.35977 .56494 m .32791 .5259 L .33531 .53845 L p
1 g
F P
s
P
p
.002 w
.51579 .23458 m .45889 .23746 L .47243 .23761 L p
1 g
F P
s
P
p
.002 w
.47243 .23761 m .52351 .23503 L .51579 .23458 L p
1 g
F P
s
P
p
.002 w
.62531 .57987 m .66066 .54491 L .67122 .52715 L p
1 g
F P
s
P
p
.002 w
.66066 .54491 m .62531 .57987 L .61157 .59328 L p
1 g
F P
s
P
p
.002 w
.44596 .24277 m .39424 .26388 L .41067 .25714 L p
1 g
F P
s
P
p
.002 w
.41067 .25714 m .45889 .23746 L .44596 .24277 L p
1 g
F P
s
P
p
.002 w
.55184 .62079 m .50259 .62554 L .49197 .62774 L p
1 g
F P
s
P
p
.002 w
.44588 .62003 m .49197 .62774 L .50259 .62554 L p
1 g
F P
s
P
p
.002 w
.32385 .3495 m .30578 .3955 L .31249 .3763 L p
1 g
F P
s
P
p
.002 w
.31249 .3763 m .33094 .32926 L .32385 .3495 L p
1 g
F P
s
P
p
.002 w
.69505 .44055 m .69273 .38842 L .68748 .37255 L p
1 g
F P
s
P
p
.002 w
.69273 .38842 m .69505 .44055 L .69513 .46019 L p
1 g
F P
s
P
p
.002 w
.68748 .37255 m .66582 .32355 L .65783 .31472 L p
1 g
F P
s
P
p
.002 w
.62261 .27619 m .65783 .31472 L .66582 .32355 L p
1 g
F P
s
P
p
.002 w
.66582 .32355 m .68748 .37255 L .69273 .38842 L p
1 g
F P
s
P
p
.002 w
.67122 .52715 m .6897 .47969 L .69513 .46019 L p
1 g
F P
s
P
p
.002 w
.6897 .47969 m .67122 .52715 L .66066 .54491 L p
1 g
F P
s
P
p
.002 w
.31936 .49971 m .33531 .53845 L .32791 .5259 L p
1 g
F P
s
P
p
.002 w
.32791 .5259 m .30994 .48235 L .31936 .49971 L p
1 g
F P
s
P
p
.002 w
.30839 .43832 m .30994 .48235 L .30607 .46419 L p
1 g
F P
s
P
p
.002 w
.30607 .46419 m .30431 .41636 L .30839 .43832 L p
1 g
F P
s
P
p
.002 w
.36904 .29213 m .33094 .32926 L .34244 .31249 L p
1 g
F P
s
P
p
.002 w
.34244 .31249 m .38017 .27557 L .36904 .29213 L p
1 g
F P
s
P
p
.002 w
.57425 .24952 m .51579 .23458 L .52351 .23503 L p
1 g
F P
s
P
p
.002 w
.52351 .23503 m .57584 .2484 L .57425 .24952 L p
1 g
F P
s
P
p
.002 w
.37189 .57806 m .40431 .60192 L .40185 .60133 L p
1 g
F P
s
P
p
.002 w
.40185 .60133 m .36381 .57334 L .37189 .57806 L p
1 g
F P
s
P
p
.002 w
.44588 .62003 m .40185 .60133 L .40431 .60192 L p
1 g
F P
s
P
p
.002 w
.40431 .60192 m .44187 .61787 L .44588 .62003 L p
1 g
F P
s
P
p
.002 w
.49197 .62774 m .44588 .62003 L .44187 .61787 L p
1 g
F P
s
P
p
.002 w
.66582 .32355 m .62654 .28059 L .62261 .27619 L p
1 g
F P
s
P
p
.002 w
.57584 .2484 m .62261 .27619 L .62654 .28059 L p
1 g
F P
s
P
p
.002 w
.49197 .62774 m .53594 .62351 L .55184 .62079 L p
1 g
F P
s
P
p
.002 w
.55184 .62079 m .5942 .60258 L .61157 .59328 L p
1 g
F P
s
P
p
.002 w
.5942 .60258 m .55184 .62079 L .53594 .62351 L p
1 g
F P
s
P
p
.002 w
.62654 .28059 m .57425 .24952 L .57584 .2484 L p
1 g
F P
s
P
p
.002 w
.64518 .56003 m .61157 .59328 L .5942 .60258 L p
1 g
F P
s
P
p
.002 w
.61157 .59328 m .64518 .56003 L .66066 .54491 L p
1 g
F P
s
P
p
.002 w
.32161 .37275 m .30431 .41636 L .30578 .3955 L p
1 g
F P
s
P
p
.002 w
.30578 .3955 m .32385 .3495 L .32161 .37275 L p
1 g
F P
s
P
p
.002 w
.34771 .54842 m .37189 .57806 L .36381 .57334 L p
1 g
F P
s
P
p
.002 w
.36381 .57334 m .33531 .53845 L .34771 .54842 L p
1 g
F P
s
P
p
.002 w
.43407 .2537 m .38017 .27557 L .39424 .26388 L p
1 g
F P
s
P
p
.002 w
.39424 .26388 m .44596 .24277 L .43407 .2537 L p
1 g
F P
s
P
p
.002 w
.69269 .40608 m .69513 .46019 L .6897 .47969 L p
1 g
F P
s
P
p
.002 w
.69513 .46019 m .69269 .40608 L .69273 .38842 L p
1 g
F P
s
P
p
.002 w
.50728 .23973 m .44596 .24277 L .45889 .23746 L p
1 g
F P
s
P
p
.002 w
.45889 .23746 m .51579 .23458 L .50728 .23973 L p
1 g
F P
s
P
p
.002 w
.53594 .62351 m .49197 .62774 L .48112 .62443 L p
1 g
F P
s
P
p
.002 w
.44187 .61787 m .48112 .62443 L .49197 .62774 L p
1 g
F P
s
P
p
.002 w
.69273 .38842 m .66942 .33579 L .66582 .32355 L p
1 g
F P
s
P
p
.002 w
.62654 .28059 m .66582 .32355 L .66942 .33579 L p
1 g
F P
s
P
p
.002 w
.66942 .33579 m .69273 .38842 L .69269 .40608 L p
1 g
F P
s
P
p
.002 w
.67865 .49845 m .66066 .54491 L .64518 .56003 L p
1 g
F P
s
P
p
.002 w
.66066 .54491 m .67865 .49845 L .6897 .47969 L p
1 g
F P
s
P
p
.002 w
.36134 .31332 m .32385 .3495 L .33094 .32926 L p
1 g
F P
s
P
p
.002 w
.33094 .32926 m .36904 .29213 L .36134 .31332 L p
1 g
F P
s
P
p
.002 w
.31817 .46077 m .31936 .49971 L .30994 .48235 L p
1 g
F P
s
P
p
.002 w
.30994 .48235 m .30839 .43832 L .31817 .46077 L p
1 g
F P
s
P
p
.002 w
.33434 .51567 m .34771 .54842 L .33531 .53845 L p
1 g
F P
s
P
p
.002 w
.33531 .53845 m .31936 .49971 L .33434 .51567 L p
1 g
F P
s
P
p
.002 w
.57046 .25592 m .50728 .23973 L .51579 .23458 L p
1 g
F P
s
P
p
.002 w
.51579 .23458 m .57425 .24952 L .57046 .25592 L p
1 g
F P
s
P
p
.002 w
.48112 .62443 m .5184 .6208 L .53594 .62351 L p
1 g
F P
s
P
p
.002 w
.57352 .60728 m .53594 .62351 L .5184 .6208 L p
1 g
F P
s
P
p
.002 w
.53594 .62351 m .57352 .60728 L .5942 .60258 L p
1 g
F P
s
P
p
.002 w
.384 .57873 m .40962 .59761 L .40431 .60192 L p
1 g
F P
s
P
p
.002 w
.40431 .60192 m .37189 .57806 L .384 .57873 L p
1 g
F P
s
P
p
.002 w
.44187 .61787 m .40431 .60192 L .40962 .59761 L p
1 g
F P
s
P
p
.002 w
.32454 .39841 m .30839 .43832 L .30431 .41636 L p
1 g
F P
s
P
p
.002 w
.30431 .41636 m .32161 .37275 L .32454 .39841 L p
1 g
F P
s
P
p
.002 w
.66942 .33579 m .627 .28949 L .62654 .28059 L p
1 g
F P
s
P
p
.002 w
.57425 .24952 m .62654 .28059 L .627 .28949 L p
1 g
F P
s
P
p
.002 w
.40962 .59761 m .43935 .61024 L .44187 .61787 L p
1 g
F P
s
P
p
.002 w
.48112 .62443 m .44187 .61787 L .43935 .61024 L p
1 g
F P
s
P
p
.002 w
.625 .57192 m .5942 .60258 L .57352 .60728 L p
1 g
F P
s
P
p
.002 w
.5942 .60258 m .625 .57192 L .64518 .56003 L p
1 g
F P
s
P
p
.002 w
.68709 .42511 m .6897 .47969 L .67865 .49845 L p
1 g
F P
s
P
p
.002 w
.6897 .47969 m .68709 .42511 L .69269 .40608 L p
1 g
F P
s
P
p
.002 w
.42367 .27024 m .36904 .29213 L .38017 .27557 L p
1 g
F P
s
P
p
.002 w
.38017 .27557 m .43407 .2537 L .42367 .27024 L p
1 g
F P
s
P
p
.002 w
.627 .28949 m .57046 .25592 L .57425 .24952 L p
1 g
F P
s
P
p
.002 w
.36501 .55533 m .384 .57873 L .37189 .57806 L p
1 g
F P
s
P
p
.002 w
.37189 .57806 m .34771 .54842 L .36501 .55533 L p
1 g
F P
s
P
p
.002 w
.49821 .25068 m .43407 .2537 L .44596 .24277 L p
1 g
F P
s
P
p
.002 w
.44596 .24277 m .50728 .23973 L .49821 .25068 L p
1 g
F P
s
P
p
.002 w
.5184 .6208 m .48112 .62443 L .47037 .61538 L p
1 g
F P
s
P
p
.002 w
.43935 .61024 m .47037 .61538 L .48112 .62443 L p
1 g
F P
s
P
p
.002 w
.66204 .51585 m .64518 .56003 L .625 .57192 L p
1 g
F P
s
P
p
.002 w
.64518 .56003 m .66204 .51585 L .67865 .49845 L p
1 g
F P
s
P
p
.002 w
.66827 .35127 m .69269 .40608 L .68709 .42511 L p
1 g
F P
s
P
p
.002 w
.69269 .40608 m .66827 .35127 L .66942 .33579 L p
1 g
F P
s
P
p
.002 w
.627 .28949 m .66942 .33579 L .66827 .35127 L p
1 g
F P
s
P
p
.002 w
.3575 .33864 m .32161 .37275 L .32385 .3495 L p
1 g
F P
s
P
p
.002 w
.32385 .3495 m .36134 .31332 L .3575 .33864 L p
1 g
F P
s
P
p
.002 w
.33359 .48299 m .33434 .51567 L .31936 .49971 L p
1 g
F P
s
P
p
.002 w
.31936 .49971 m .31817 .46077 L .33359 .48299 L p
1 g
F P
s
P
p
.002 w
.35469 .52964 m .36501 .55533 L .34771 .54842 L p
1 g
F P
s
P
p
.002 w
.34771 .54842 m .33434 .51567 L .35469 .52964 L p
1 g
F P
s
P
p
.002 w
.33275 .42574 m .31817 .46077 L .30839 .43832 L p
1 g
F P
s
P
p
.002 w
.30839 .43832 m .32454 .39841 L .33275 .42574 L p
1 g
F P
s
P
p
.002 w
.5184 .6208 m .55 .60699 L .57352 .60728 L p
1 g
F P
s
P
p
.002 w
.60055 .58004 m .57352 .60728 L .55 .60699 L p
1 g
F P
s
P
p
.002 w
.57352 .60728 m .60055 .58004 L .625 .57192 L p
1 g
F P
s
P
p
.002 w
.47037 .61538 m .49967 .61244 L .5184 .6208 L p
1 g
F P
s
P
p
.002 w
.55 .60699 m .5184 .6208 L .49967 .61244 L p
1 g
F P
s
P
p
.002 w
.67578 .44495 m .67865 .49845 L .66204 .51585 L p
1 g
F P
s
P
p
.002 w
.67865 .49845 m .67578 .44495 L .68709 .42511 L p
1 g
F P
s
P
p
.002 w
.56442 .26773 m .49821 .25068 L .50728 .23973 L p
1 g
F P
s
P
p
.002 w
.50728 .23973 m .57046 .25592 L .56442 .26773 L p
1 g
F P
s
P
p
.002 w
.41518 .29213 m .36134 .31332 L .36904 .29213 L p
1 g
F P
s
P
p
.002 w
.36904 .29213 m .42367 .27024 L .41518 .29213 L p
1 g
F P
s
P
p
.002 w
.40001 .57506 m .41781 .58822 L .40962 .59761 L p
1 g
F P
s
P
p
.002 w
.40962 .59761 m .384 .57873 L .40001 .57506 L p
1 g
F P
s
P
p
.002 w
.43935 .61024 m .40962 .59761 L .41781 .58822 L p
1 g
F P
s
P
p
.002 w
.66827 .35127 m .62375 .3029 L .627 .28949 L p
1 g
F P
s
P
p
.002 w
.57046 .25592 m .627 .28949 L .62375 .3029 L p
1 g
F P
s
P
p
.002 w
.41781 .58822 m .43851 .597 L .43935 .61024 L p
1 g
F P
s
P
p
.002 w
.47037 .61538 m .43935 .61024 L .43851 .597 L p
1 g
F P
s
P
p
.002 w
.64014 .53125 m .625 .57192 L .60055 .58004 L p
1 g
F P
s
P
p
.002 w
.625 .57192 m .64014 .53125 L .66204 .51585 L p
1 g
F P
s
P
p
.002 w
.48883 .26741 m .42367 .27024 L .43407 .2537 L p
1 g
F P
s
P
p
.002 w
.43407 .2537 m .49821 .25068 L .48883 .26741 L p
1 g
F P
s
P
p
.002 w
.62375 .3029 m .56442 .26773 L .57046 .25592 L p
1 g
F P
s
P
p
.002 w
.38693 .55881 m .40001 .57506 L .384 .57873 L p
1 g
F P
s
P
p
.002 w
.384 .57873 m .36501 .55533 L .38693 .55881 L p
1 g
F P
s
P
p
.002 w
.35784 .36743 m .32454 .39841 L .32161 .37275 L p
1 g
F P
s
P
p
.002 w
.32161 .37275 m .3575 .33864 L .35784 .36743 L p
1 g
F P
s
P
p
.002 w
.49967 .61244 m .47037 .61538 L .46007 .60053 L p
1 g
F P
s
P
p
.002 w
.43851 .597 m .46007 .60053 L .47037 .61538 L p
1 g
F P
s
P
p
.002 w
.6621 .36968 m .68709 .42511 L .67578 .44495 L p
1 g
F P
s
P
p
.002 w
.68709 .42511 m .6621 .36968 L .66827 .35127 L p
1 g
F P
s
P
p
.002 w
.35438 .50421 m .35469 .52964 L .33434 .51567 L p
1 g
F P
s
P
p
.002 w
.33434 .51567 m .33359 .48299 L .35438 .50421 L p
1 g
F P
s
P
p
.002 w
.62375 .3029 m .66827 .35127 L .6621 .36968 L p
1 g
F P
s
P
p
.002 w
.34618 .45384 m .33359 .48299 L .31817 .46077 L p
1 g
F P
s
P
p
.002 w
.31817 .46077 m .33275 .42574 L .34618 .45384 L p
1 g
F P
s
P
p
.002 w
.37996 .54107 m .38693 .55881 L .36501 .55533 L p
1 g
F P
s
P
p
.002 w
.36501 .55533 m .35469 .52964 L .37996 .54107 L p
1 g
F P
s
P
p
.002 w
.49967 .61244 m .52429 .60148 L .55 .60699 L p
1 g
F P
s
P
p
.002 w
.57244 .58395 m .55 .60699 L .52429 .60148 L p
1 g
F P
s
P
p
.002 w
.55 .60699 m .57244 .58395 L .60055 .58004 L p
1 g
F P
s
P
p
.002 w
.65888 .465 m .66204 .51585 L .64014 .53125 L p
1 g
F P
s
P
p
.002 w
.66204 .51585 m .65888 .465 L .67578 .44495 L p
1 g
F P
s
P
p
.002 w
.46007 .60053 m .48032 .5984 L .49967 .61244 L p
1 g
F P
s
P
p
.002 w
.52429 .60148 m .49967 .61244 L .48032 .5984 L p
1 g
F P
s
P
p
.002 w
.409 .31889 m .3575 .33864 L .36134 .31332 L p
1 g
F P
s
P
p
.002 w
.36134 .31332 m .41518 .29213 L .409 .31889 L p
1 g
F P
s
P
p
.002 w
.61348 .54405 m .60055 .58004 L .57244 .58395 L p
1 g
F P
s
P
p
.002 w
.60055 .58004 m .61348 .54405 L .64014 .53125 L p
1 g
F P
s
P
p
.002 w
.55622 .28489 m .48883 .26741 L .49821 .25068 L p
1 g
F P
s
P
p
.002 w
.49821 .25068 m .56442 .26773 L .55622 .28489 L p
1 g
F P
s
P
p
.002 w
.36248 .3988 m .33275 .42574 L .32454 .39841 L p
1 g
F P
s
P
p
.002 w
.32454 .39841 m .35784 .36743 L .36248 .3988 L p
1 g
F P
s
P
p
.002 w
.41962 .56692 m .42878 .57373 L .41781 .58822 L p
1 g
F P
s
P
p
.002 w
.41781 .58822 m .40001 .57506 L .41962 .56692 L p
1 g
F P
s
P
p
.002 w
.43851 .597 m .41781 .58822 L .42878 .57373 L p
1 g
F P
s
P
p
.002 w
.6621 .36968 m .61668 .32065 L .62375 .3029 L p
1 g
F P
s
P
p
.002 w
.56442 .26773 m .62375 .3029 L .61668 .32065 L p
1 g
F P
s
P
p
.002 w
.47947 .28967 m .41518 .29213 L .42367 .27024 L p
1 g
F P
s
P
p
.002 w
.42367 .27024 m .48883 .26741 L .47947 .28967 L p
1 g
F P
s
P
p
.002 w
.42878 .57373 m .43948 .57827 L .43851 .597 L p
1 g
F P
s
P
p
.002 w
.46007 .60053 m .43851 .597 L .43948 .57827 L p
1 g
F P
s
P
p
.002 w
.65085 .39056 m .67578 .44495 L .65888 .465 L p
1 g
F P
s
P
p
.002 w
.67578 .44495 m .65085 .39056 L .6621 .36968 L p
1 g
F P
s
P
p
.002 w
.37998 .52366 m .37996 .54107 L .35469 .52964 L p
1 g
F P
s
P
p
.002 w
.35469 .52964 m .35438 .50421 L .37998 .52366 L p
1 g
F P
s
P
p
.002 w
.41294 .55854 m .41962 .56692 L .40001 .57506 L p
1 g
F P
s
P
p
.002 w
.40001 .57506 m .38693 .55881 L .41294 .55854 L p
1 g
F P
s
P
p
.002 w
.61668 .32065 m .55622 .28489 L .56442 .26773 L p
1 g
F P
s
P
p
.002 w
.48032 .5984 m .46007 .60053 L .45059 .58005 L p
1 g
F P
s
P
p
.002 w
.43948 .57827 m .45059 .58005 L .46007 .60053 L p
1 g
F P
s
P
p
.002 w
.3645 .48175 m .35438 .50421 L .33359 .48299 L p
1 g
F P
s
P
p
.002 w
.33359 .48299 m .34618 .45384 L .3645 .48175 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.61668 .32065 m .6621 .36968 L .65085 .39056 L p
1 g
F P
s
P
p
.002 w
.48032 .5984 m .49715 .59071 L .52429 .60148 L p
1 g
F P
s
P
p
.002 w
.5415 .58336 m .52429 .60148 L .49715 .59071 L p
1 g
F P
s
P
p
.002 w
.52429 .60148 m .5415 .58336 L .57244 .58395 L p
1 g
F P
s
P
p
.002 w
.63673 .48454 m .64014 .53125 L .61348 .54405 L p
1 g
F P
s
P
p
.002 w
.64014 .53125 m .63673 .48454 L .65888 .465 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.40948 .54945 m .41294 .55854 L .38693 .55881 L p
1 g
F P
s
P
p
.002 w
.38693 .55881 m .37996 .54107 L .40948 .54945 L p
1 g
F P
s
P
p
.002 w
.58282 .55369 m .57244 .58395 L .5415 .58336 L p
1 g
F P
s
P
p
.002 w
.57244 .58395 m .58282 .55369 L .61348 .54405 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.40544 .34974 m .35784 .36743 L .3575 .33864 L p
1 g
F P
s
P
p
.002 w
.3575 .33864 m .409 .31889 L .40544 .34974 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.004 w
.45519 .52673 m
.5 .43051 L
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.45059 .58005 m .46097 .57889 L .48032 .5984 L p
1 g
F P
s
P
p
.002 w
.49715 .59071 m .48032 .5984 L .46097 .57889 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37141 .43168 m .34618 .45384 L .33275 .42574 L p
1 g
F P
s
P
p
.002 w
.33275 .42574 m .36248 .3988 L .37141 .43168 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54602 .30709 m .47947 .28967 L .48883 .26741 L p
1 g
F P
s
P
p
.002 w
.48883 .26741 m .55622 .28489 L .54602 .30709 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.38717 .50846 m .37998 .52366 L .35438 .50421 L p
1 g
F P
s
P
p
.002 w
.35438 .50421 m .3645 .48175 L .38717 .50846 L p
1 g
F P
s
P
p
.002 w
.40963 .54061 m .40948 .54945 L .37996 .54107 L p
1 g
F P
s
P
p
.002 w
.37996 .54107 m .37998 .52366 L .40963 .54061 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.63468 .41329 m .65888 .465 L .63673 .48454 L p
1 g
F P
s
P
p
.002 w
.65888 .465 m .63468 .41329 L .65085 .39056 L p
1 g
F P
s
P
p
.002 w
.47045 .31692 m .409 .31889 L .41518 .29213 L p
1 g
F P
s
P
p
.002 w
.41518 .29213 m .47947 .28967 L .47045 .31692 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.60992 .50286 m .61348 .54405 L .58282 .55369 L p
1 g
F P
s
P
p
.002 w
.61348 .54405 m .60992 .50286 L .63673 .48454 L p
1 g
F P
s
P
p
.002 w
.65085 .39056 m .60581 .34236 L .61668 .32065 L p
1 g
F P
s
P
p
.002 w
.55622 .28489 m .61668 .32065 L .60581 .34236 L p
1 g
F P
s
P
p
.002 w
.46097 .57889 m .4685 .57534 L p
.49715 .59071 L 1 g
F P
s
P
p
.002 w
.4685 .57534 m .4686 .57529 L p
.47341 .57789 L 1 g
F P
s
P
p
.49715 .59071 m .4685 .57534 L .47341 .57789 L 1 g
F
P
p
.002 w
.46097 .57889 m .45059 .58005 L .44352 .5581 L p
1 g
F P
s
P
p
.002 w
.44352 .5581 m .44232 .55438 L .44701 .56055 L p
1 g
F P
s
P
p
.002 w
.44701 .56055 m .46097 .57889 L p
.44352 .5581 L 1 g
F P
s
P
p
.46872 .57265 m .45888 .56872 L .46092 .57012 L 1 g
F
P
p
.002 w
.4685 .57534 m .46097 .57889 L .4537 .56934 L p
1 g
F P
s
P
p
.002 w
.4537 .56934 m .44701 .56055 L p
.45077 .56314 L 1 g
F P
s
P
p
.002 w
.45077 .56314 m .45146 .56129 L p
.44264 .55362 L 1 g
F P
s
P
p
.44264 .55362 m .44267 .55366 L .45077 .56314 L 1 g
F
P
p
.002 w
.44282 .55388 m .44232 .55438 L .44262 .5536 L p
1 g
F P
s
P
p
.44262 .55361 m .4427 .55372 L .44271 .55373 L 1 g
F
P
p
.44266 .55365 m .44271 .55373 L .45077 .56314 L 1 g
F
P
p
.44262 .55361 m .44271 .55373 L .44266 .55365 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44262 .5536 m .44232 .55438 L .44227 .55311 L p
1 g
F P
s
P
p
.44257 .55357 m .44277 .55382 L .45077 .56314 L 1 g
F
P
p
.4425 .5535 m .44292 .55403 L .45077 .56314 L 1 g
F
P
p
.002 w
.44298 .55409 m .44232 .55438 L .44282 .55388 L p
1 g
F P
s
P
p
.4424 .55342 m .44335 .55455 L .45077 .56314 L 1 g
F
P
p
.002 w
.44314 .55429 m .44232 .55438 L .44298 .55409 L p
1 g
F P
s
P
p
.002 w
.44335 .55454 m .44232 .55438 L .44314 .55429 L p
1 g
F P
s
P
p
.44229 .55332 m .4448 .55625 L .45077 .56314 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46818 .57513 L p
1 g
F P
s
P
p
.002 w
.47179 .57618 m .49715 .59071 L p
.4686 .57529 L 1 g
F P
s
P
p
.48921 .57862 m .46818 .57513 L .46914 .57551 L 1 g
F
P
p
.002 w
.50322 .58414 m .49715 .59071 L .4787 .58014 L p
1 g
F P
s
P
p
.002 w
.4787 .58014 m .47179 .57618 L p
.48907 .58055 L 1 g
F P
s
P
p
.50322 .58414 m .4787 .58014 L .48907 .58055 L 1 g
F
P
p
.51079 .57862 m .49912 .58095 L .5059 .58122 L 1 g
F
P
p
.002 w
.52113 .58012 m .5415 .58336 L p
.5089 .5814 L 1 g
F P
s
P
p
.5089 .5814 m .5059 .58122 L .51096 .58086 L 1 g
F
P
p
.5089 .5814 m .51096 .58086 L .52113 .58012 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51096 .58086 L p
1 g
F P
s
P
p
.002 w
.49715 .59071 m .5059 .58122 L p
.5415 .58336 L 1 g
F P
s
P
p
.53128 .57265 m .51096 .58086 L .51651 .57939 L 1 g
F
P
p
.002 w
.546 .56951 m .5415 .58336 L .52196 .58026 L p
1 g
F P
s
P
p
.002 w
.52196 .58026 m .51651 .57939 L p
.53164 .57432 L 1 g
F P
s
P
p
.546 .56951 m .52196 .58026 L .53164 .57432 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53164 .57432 L p
1 g
F P
s
P
p
.54854 .56129 m .53164 .57432 L .5407 .56876 L 1 g
F
P
p
.53128 .57265 m .51651 .57939 L .52122 .57781 L 1 g
F
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51096 .58086 m .51079 .57862 L p
.5059 .58122 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58055 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58055 L .49912 .58095 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.50873 .57815 m .5059 .58122 L p
.46951 .57487 L 1 g
F P
s
P
p
.002 w
.5059 .58122 m .50322 .58414 L p
.49037 .5806 L 1 g
F P
s
P
p
.48921 .57862 m .46914 .57551 L .47769 .57767 L 1 g
F
P
p
.002 w
.48904 .58097 m .48921 .57862 L p
.47695 .57761 L 1 g
F P
s
P
p
.5059 .58122 m .49037 .5806 L .46951 .57487 L 1 g
F
P
p
.002 w
.47179 .57618 m .46951 .57487 L p
.50322 .58414 L 1 g
F P
s
P
p
.002 w
.48907 .58055 m .48889 .583 L p
.49912 .58095 L 1 g
F P
s
P
p
.002 w
.5059 .58122 m .50873 .57815 L .51651 .57939 L p
1 g
F P
s
P
p
.002 w
.51651 .57939 m .52113 .58012 L p
.51096 .58086 L 1 g
F P
s
P
p
.51096 .58086 m .5059 .58122 L .51651 .57939 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53187 .57533 L p
1 g
F P
s
P
p
.002 w
.53187 .57533 m .53128 .57265 L p
.51989 .5785 L 1 g
F P
s
P
p
.51989 .5785 m .51111 .583 L .53187 .57533 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.54854 .56129 m .5407 .56876 L .54761 .56452 L 1 g
F
P
p
.002 w
.55575 .55857 m .58282 .55369 L p
.54846 .56426 L 1 g
F P
s
P
p
.54846 .56426 m .54761 .56452 L .54929 .5633 L 1 g
F
P
p
.54846 .56426 m .54929 .5633 L .55575 .55857 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54929 .5633 L p
1 g
F P
s
P
p
.002 w
.5415 .58336 m .54761 .56452 L p
.58282 .55369 L 1 g
F P
s
P
p
.56075 .54566 m .54929 .5633 L .55291 .55908 L 1 g
F
P
p
.002 w
.57946 .52066 m .58282 .55369 L .55766 .55822 L p
1 g
F P
s
P
p
.002 w
.55766 .55822 m .55291 .55908 L p
.56137 .54683 L 1 g
F P
s
P
p
.57946 .52066 m .55766 .55822 L .56137 .54683 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56137 .54683 L p
1 g
F P
s
P
p
.56654 .52734 m .56137 .54683 L .56502 .53564 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.57932 .51926 m .57946 .52066 L p
.56297 .54194 L 1 g
F P
s
P
p
.56339 .54065 m .56297 .54194 L .54916 .55975 L 1 g
F
P
p
.57932 .51926 m .56297 .54194 L .56339 .54065 L 1 g
F
P
p
.56075 .54566 m .55291 .55908 L .55509 .55592 L 1 g
F
P
p
.002 w
.54929 .5633 m .54854 .56129 L p
.54761 .56452 L 1 g
F P
s
P
p
.002 w
.54761 .56452 m .54916 .55975 L .55291 .55908 L p
1 g
F P
s
P
p
.002 w
.55291 .55908 m .55575 .55857 L p
.54929 .5633 L 1 g
F P
s
P
p
.54929 .5633 m .54761 .56452 L .55291 .55908 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56215 .54831 L p
1 g
F P
s
P
p
.002 w
.56215 .54831 m .56075 .54566 L p
.55414 .55764 L 1 g
F P
s
P
p
.55414 .55764 m .54998 .56518 L .56215 .54831 L 1 g
F
P
p
.002 w
.55291 .55908 m .54916 .55975 L p
.57946 .52066 L 1 g
F P
s
P
p
.002 w
.56735 .52852 m .56654 .52734 L p
.56502 .53564 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56735 .52852 L p
1 g
F P
s
P
p
.56515 .50826 m .56735 .52852 L .56724 .52427 L 1 g
F
P
p
.002 w
.56398 .4891 m .57932 .51926 L .5721 .52225 L p
1 g
F P
s
P
p
.002 w
.5721 .52225 m .56724 .52427 L p
.56583 .50907 L 1 g
F P
s
P
p
.56398 .4891 m .5721 .52225 L .56583 .50907 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56583 .50907 L p
1 g
F P
s
P
p
.55661 .4905 m .56583 .50907 L .56099 .49888 L 1 g
F
P
p
.56515 .50826 m .56724 .52427 L .56667 .51809 L 1 g
F
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56724 .52427 m .57932 .51926 L p
.56752 .5351 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55741 .49136 m .55661 .4905 L p
.56099 .49888 L 1 g
F P
s
P
p
.002 w
.56724 .52427 m .546 .53307 L p
.56045 .49774 L 1 g
F P
s
P
p
.56398 .4891 m .56583 .50907 L .56045 .49774 L 1 g
F
P
p
.56583 .50907 m .56724 .52427 L .56045 .49774 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56167 .48454 m .56398 .4891 L p
.546 .53307 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.546 .53307 m .53198 .50631 L .55524 .48925 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49136 L p
1 g
F P
s
P
p
.54174 .47608 m .55741 .49136 L .55524 .48925 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55524 .48925 m .53198 .50631 L p
.53165 .47155 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54217 .47655 L p
1 g
F P
s
P
p
.52214 .46667 m .54217 .47655 L .53058 .47104 L 1 g
F
P
p
.5316 .46627 m .54217 .47655 L .53165 .47155 L 1 g
F
P
p
.54217 .47655 m .55524 .48925 L .53165 .47155 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46717 L p
1 g
F P
s
P
p
.002 w
.53198 .50631 m .50844 .48268 L .52097 .46699 L p
1 g
F P
s
P
p
.52138 .46704 m .53198 .50631 L .52097 .46699 L 1 g
F
P
p
.5 .4634 m .52244 .46717 L .52097 .46699 L 1 g
F
P
p
.5 .4634 m .52097 .46699 L .50923 .46518 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.49228 .43102 m .53149 .4538 L .52097 .46699 L p
1 g
F P
s
P
p
.002 w
.52097 .46699 m .50844 .48268 L p
.50265 .46416 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.50265 .46416 m .50844 .48268 L .48671 .46588 L 1 g
F
P
p
.47786 .46667 m .48865 .46557 L .481 .4668 L 1 g
F
P
p
.47843 .46716 m .48532 .50971 L .47721 .46743 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .4673 L p
1 g
F P
s
P
p
.47748 .4673 m .47721 .46743 L .47719 .46734 L 1 g
F
P
p
.47843 .46716 m .47721 .46743 L .47748 .4673 L 1 g
F
P
p
.45826 .47608 m .47748 .4673 L .47714 .46746 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47714 .46746 m .46472 .49784 L p
.45559 .47874 L 1 g
F P
s
P
p
.45777 .47662 m .47714 .46746 L .45559 .47874 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45777 .47662 L p
1 g
F P
s
P
p
.44339 .4905 m .45777 .47662 L .45005 .48412 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44204 .49145 m .44462 .45581 L p
.45233 .47193 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44236 .49159 L p
1 g
F P
s
P
p
.43485 .50826 m .44236 .49159 L .44234 .49164 L 1 g
F
P
p
.43485 .50826 m .44234 .49164 L .44202 .49231 L 1 g
F
P
p
.41993 .49126 m .43561 .49201 L .4329 .51158 L 1 g
F
P
p
.43561 .49201 m .44202 .49231 L .43398 .5093 L 1 g
F
P
p
.43561 .49201 m .43398 .5093 L .4329 .51158 L 1 g
F
P
p
.002 w
.42051 .52739 m .42392 .52638 L p
.43892 .54921 L 1 g
F P
s
P
p
.002 w
.43944 .55081 m .42051 .52739 L p
.43892 .54921 L 1 g
F P
s
P
p
.002 w
.43834 .54739 m .43925 .54566 L p
.43521 .53768 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43834 .54739 L p
1 g
F P
s
P
p
.45146 .56129 m .43834 .54739 L .43841 .5475 L 1 g
F
P
p
.002 w
.44113 .55145 m .44232 .55438 L p
.42392 .52638 L 1 g
F P
s
P
p
.45146 .56129 m .43832 .54741 L .44097 .55123 L 1 g
F
P
p
.002 w
.42392 .52638 m .43015 .52452 L .43236 .52995 L p
1 g
F P
s
P
p
.002 w
.44232 .55438 m .43944 .55081 L p
.43892 .54921 L 1 g
F P
s
P
p
.002 w
.44227 .55311 m .44232 .55438 L .44113 .55145 L p
1 g
F P
s
P
p
.45146 .56129 m .43787 .54826 L .44218 .55323 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4324 .52889 L p
1 g
F P
s
P
p
.43925 .54566 m .4324 .52889 L .43242 .52898 L 1 g
F
P
p
.43925 .54566 m .43242 .52898 L .43521 .53768 L 1 g
F
P
p
.43236 .52995 m .43267 .52976 L .43385 .53342 L 1 g
F
P
p
.43242 .52898 m .43411 .53423 L .43521 .53768 L 1 g
F
P
p
.43346 .52734 m .43314 .5182 L .43254 .52456 L 1 g
F
P
p
.002 w
.4324 .52889 m .43346 .52734 L p
.43254 .52456 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43398 .5093 L p
1 g
F P
s
P
p
.4329 .51158 m .43398 .5093 L .43365 .51276 L 1 g
F
P
p
.43346 .52734 m .43398 .5093 L .43314 .5182 L 1 g
F
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44128 .5247 m .43015 .52452 L .41993 .49126 L p
1 g
F P
s
P
p
.002 w
.43398 .5093 m .43287 .51061 L p
.43314 .5182 L 1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44202 .49231 m .44128 .5247 L p
.43365 .51276 L 1 g
F P
s
P
p
.43485 .50826 m .44202 .49231 L .43842 .49991 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.43398 .5093 m .44202 .49231 L .43365 .51276 L 1 g
F
P
p
.002 w
.43254 .52456 m .44128 .5247 L p
.43267 .52976 L 1 g
F P
s
P
p
.4324 .52889 m .43267 .52976 L .43236 .52995 L 1 g
F
P
p
.43254 .52456 m .43267 .52976 L .4324 .52889 L 1 g
F
P
p
.002 w
.43411 .53423 m .43236 .52995 L p
.43385 .53342 L 1 g
F P
s
P
p
.002 w
.43236 .52995 m .43411 .53423 L p
.43211 .53832 L 1 g
F P
s
P
p
.43211 .53832 m .43411 .53423 L .43834 .54739 L 1 g
F
P
p
.42392 .52638 m .43236 .52995 L .43211 .53832 L 1 g
F
P
p
.002 w
.43236 .52995 m .43015 .52452 L .43254 .52456 L p
1 g
F P
s
P
p
.002 w
.43239 .5289 m .43146 .53025 L p
.4352 .53765 L 1 g
F P
s
P
p
.43521 .53768 m .43411 .53423 L .4352 .53765 L 1 g
F
P
p
.43411 .53423 m .43239 .5289 L .4352 .53765 L 1 g
F
P
p
.43242 .52898 m .43239 .5289 L .43411 .53423 L 1 g
F
P
p
.002 w
.44113 .55145 m .43411 .53423 L p
.44227 .55311 L 1 g
F P
s
P
p
.43385 .53342 m .44227 .55311 L .43411 .53423 L 1 g
F
P
p
.002 w
.44128 .5247 m .44227 .55311 L p
.43385 .53342 L 1 g
F P
s
P
p
.43267 .52976 m .44128 .5247 L .43385 .53342 L 1 g
F
P
p
.002 w
.4324 .52889 m .43239 .5289 L p
.43242 .52898 L 1 g
F P
s
P
p
.002 w
.43411 .53423 m .44113 .55145 L p
.43834 .54739 L 1 g
F P
s
P
p
.4324 .52889 m .43254 .52456 L .43251 .52492 L 1 g
F
P
p
.002 w
.43209 .52933 m .43239 .5289 L p
.43251 .52492 L 1 g
F P
s
P
p
.002 w
.43239 .5289 m .4324 .52889 L p
.43251 .52492 L 1 g
F P
s
P
p
.002 w
.41343 .53297 m .42051 .52739 L .43944 .55081 L p
1 g
F P
s
P
p
.002 w
.43944 .55081 m .44232 .55438 L .44006 .5527 L p
1 g
F P
s
P
p
.002 w
.44006 .5527 m .41343 .53297 L p
.43944 .55081 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43832 .54741 L p
1 g
F P
s
P
p
.002 w
.43832 .54741 m .43834 .54739 L p
.43821 .54707 L 1 g
F P
s
P
p
.43821 .54707 m .43146 .53025 L .43832 .54741 L 1 g
F
P
p
.43521 .53768 m .43146 .53025 L .43834 .54739 L 1 g
F
P
p
.002 w
.43834 .54739 m .43832 .54741 L p
.43841 .5475 L 1 g
F P
s
P
p
.002 w
.43832 .54741 m .43787 .54826 L p
.44097 .55123 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43209 .52933 L p
1 g
F P
s
P
p
.43314 .5182 m .43287 .51061 L .43209 .52933 L 1 g
F
P
p
.43842 .49991 m .44202 .49231 L .43878 .49907 L 1 g
F
P
p
.002 w
.41993 .49126 m .44204 .49145 L .44202 .49231 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46472 .49784 m .45266 .52794 L p
.44219 .49196 L 1 g
F P
s
P
p
.002 w
.44204 .49145 m .44238 .49155 L p
.44219 .49196 L 1 g
F P
s
P
p
.44339 .4905 m .45005 .48412 L .4424 .49155 L 1 g
F
P
p
.002 w
.4424 .49155 m .46472 .49784 L p
.44236 .49159 L 1 g
F P
s
P
p
.002 w
.44236 .49159 m .44236 .49159 L p
.4424 .49155 L 1 g
F P
s
P
p
.002 w
.44236 .49159 m .44339 .4905 L p
.4424 .49155 L 1 g
F P
s
P
p
.44236 .49159 m .46472 .49784 L .44219 .49196 L 1 g
F
P
p
.002 w
.44238 .49155 m .4424 .49155 L p
.44236 .49159 L 1 g
F P
s
P
p
.43878 .49907 m .44236 .49159 L .43992 .49641 L 1 g
F
P
p
.44234 .49164 m .44236 .49159 L .43878 .49907 L 1 g
F
P
p
.002 w
.44236 .49159 m .44236 .49159 L p
.44234 .49164 L 1 g
F P
s
P
p
.002 w
.45266 .52794 m .44128 .5247 L .44202 .49231 L p
1 g
F P
s
P
p
.002 w
.44202 .49231 m .44204 .49145 L p
.44219 .49196 L 1 g
F P
s
P
p
.44219 .49196 m .45266 .52794 L .44202 .49231 L 1 g
F
P
p
.002 w
.46472 .49784 m .44238 .49155 L p
.45233 .47193 L 1 g
F P
s
P
p
.002 w
.44238 .49155 m .44204 .49145 L p
.45233 .47193 L 1 g
F P
s
P
p
.002 w
.44236 .49159 m .44166 .49233 L p
.43992 .49641 L 1 g
F P
s
P
p
.002 w
.45777 .47662 m .45698 .47747 L p
.45005 .48412 L 1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.44462 .45581 m .46987 .46486 L .45516 .47785 L 1 g
F
P
p
.45826 .47608 m .47714 .46746 L .46722 .47215 L 1 g
F
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48532 .50971 m .46472 .49784 L .47714 .46746 L p
1 g
F P
s
P
p
.002 w
.47714 .46746 m .47719 .46734 L p
.47721 .46743 L 1 g
F P
s
P
p
.47721 .46743 m .48532 .50971 L .47714 .46746 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45734 .47708 L p
1 g
F P
s
P
p
.002 w
.45734 .47708 m .45826 .47608 L p
.47001 .47093 L 1 g
F P
s
P
p
.47001 .47093 m .47718 .46778 L .45734 .47708 L 1 g
F
P
p
.46987 .46486 m .47714 .46746 L .45777 .47662 L 1 g
F
P
p
.46987 .46486 m .45777 .47662 L .45516 .47785 L 1 g
F
P
p
.45516 .47785 m .45777 .47662 L .45559 .47874 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44236 .49159 L p
1 g
F P
s
P
p
.45005 .48412 m .45698 .47747 L .44236 .49159 L 1 g
F
P
p
.46722 .47215 m .47714 .46746 L .47001 .47093 L 1 g
F
P
p
.002 w
.44462 .45581 m .4781 .46512 L .47714 .46746 L p
1 g
F P
s
P
p
.002 w
.47748 .4673 m .47718 .46778 L p
.47001 .47093 L 1 g
F P
s
P
p
.002 w
.47748 .4673 m .47786 .46667 L p
.481 .4668 L 1 g
F P
s
P
p
.002 w
.50844 .48268 m .48532 .50971 L p
.47843 .46716 L 1 g
F P
s
P
p
.50265 .46416 m .48671 .46588 L .5 .46375 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .46442 L p
.48865 .46557 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46375 L .48865 .46557 L 1 g
F
P
p
.002 w
.4781 .46512 m .47995 .46066 L p
.48671 .46588 L 1 g
F P
s
P
p
.002 w
.50844 .48268 m .481 .4668 L p
.48671 .46588 L 1 g
F P
s
P
p
.002 w
.481 .4668 m .4781 .46512 L p
.48671 .46588 L 1 g
F P
s
P
p
.002 w
.4781 .46512 m .481 .4668 L p
.47843 .46716 L 1 g
F P
s
P
p
.002 w
.481 .4668 m .50844 .48268 L p
.47843 .46716 L 1 g
F P
s
P
p
.481 .4668 m .5 .46442 L .47744 .46737 L 1 g
F
P
p
.48865 .46557 m .49216 .46522 L .481 .4668 L 1 g
F
P
p
.49216 .46522 m .5 .46442 L .481 .4668 L 1 g
F
P
p
.002 w
.47744 .46737 m .47748 .4673 L p
.481 .4668 L 1 g
F P
s
P
p
.002 w
.47719 .46734 m .4781 .46512 L p
.47843 .46716 L 1 g
F P
s
P
p
.5 .46375 m .48671 .46588 L .47995 .46066 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47744 .46737 L p
1 g
F P
s
P
p
.53165 .47155 m .53198 .50631 L .52138 .46704 L 1 g
F
P
p
.52244 .46717 m .52138 .46704 L .52127 .46661 L 1 g
F
P
p
.53165 .47155 m .52138 .46704 L .52244 .46717 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46434 L p
1 g
F P
s
P
p
.002 w
.5 .46434 m .5 .4634 L p
.51422 .46613 L 1 g
F P
s
P
p
.51422 .46613 m .52282 .46778 L .5 .46434 L 1 g
F
P
p
.49228 .43102 m .52097 .46699 L .50265 .46416 L 1 g
F
P
p
.51422 .46613 m .52097 .46699 L .52282 .46778 L 1 g
F
P
p
.002 w
.52244 .46717 m .52247 .46722 L p
.52097 .46699 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .52282 .46778 L p
.52097 .46699 L 1 g
F P
s
P
p
.50923 .46518 m .52097 .46699 L .51422 .46613 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.47995 .46066 m .49228 .43102 L p
.50265 .46416 L 1 g
F P
s
P
p
.002 w
.52097 .46699 m .52127 .46661 L p
.52138 .46704 L 1 g
F P
s
P
p
.002 w
.52244 .46717 m .52214 .46667 L p
.53058 .47104 L 1 g
F P
s
P
p
.002 w
.52127 .46661 m .53149 .4538 L p
.53165 .47155 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46717 L p
1 g
F P
s
P
p
.53058 .47104 m .54302 .47747 L .52244 .46717 L 1 g
F
P
p
.002 w
.54217 .47655 m .54302 .47747 L p
.53058 .47104 L 1 g
F P
s
P
p
.54908 .48327 m .55524 .48925 L .55225 .48637 L 1 g
F
P
p
.54174 .47608 m .55524 .48925 L .54908 .48327 L 1 g
F
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53149 .4538 m .56167 .48454 L .55524 .48925 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.55898 .49286 m .546 .53307 L .55524 .48925 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55741 .49136 L p
1 g
F P
s
P
p
.56099 .49888 m .56713 .51061 L .55741 .49136 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.53149 .4538 m .55524 .48925 L .5316 .46627 L 1 g
F
P
p
.002 w
.55524 .48925 m .56167 .48454 L p
.55898 .49286 L 1 g
F P
s
P
p
.002 w
.55741 .49136 m .55834 .49233 L p
.55225 .48637 L 1 g
F P
s
P
p
.002 w
.56583 .50907 m .56713 .51061 L p
.56099 .49888 L 1 g
F P
s
P
p
.56667 .51809 m .56724 .52427 L .56716 .5213 L 1 g
F
P
p
.002 w
.54916 .55975 m .546 .53307 L .56724 .52427 L p
1 g
F P
s
P
p
.56752 .5351 m .54916 .55975 L .56724 .52427 L 1 g
F
P
p
.002 w
.56735 .52852 m .56854 .53025 L p
.56716 .5213 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56735 .52852 L p
1 g
F P
s
P
p
.56502 .53564 m .56257 .5491 L .56735 .52852 L 1 g
F
P
p
.002 w
.56137 .54683 m .56257 .5491 L p
.56502 .53564 L 1 g
F P
s
P
p
.55509 .55592 m .55291 .55908 L .55414 .55764 L 1 g
F
P
p
.002 w
.54929 .5633 m .54998 .56518 L p
.55414 .55764 L 1 g
F P
s
P
p
.002 w
.54935 .56346 m .54929 .5633 L p
.54761 .56452 L 1 g
F P
s
P
p
.002 w
.54916 .55975 m .54761 .56452 L p
.50873 .57815 L 1 g
F P
s
P
p
.002 w
.54761 .56452 m .546 .56951 L p
.53552 .57194 L 1 g
F P
s
P
p
.54761 .56452 m .53552 .57194 L .50873 .57815 L 1 g
F
P
p
.002 w
.51651 .57939 m .50873 .57815 L p
.546 .56951 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54935 .56346 L p
1 g
F P
s
P
p
.5407 .56876 m .5322 .57686 L .54935 .56346 L 1 g
F
P
p
.002 w
.53164 .57432 m .5322 .57686 L p
.5407 .56876 L 1 g
F P
s
P
p
.52122 .57781 m .51651 .57939 L .51989 .5785 L 1 g
F
P
p
.002 w
.51096 .58086 m .51111 .583 L p
.51989 .5785 L 1 g
F P
s
P
p
.002 w
.511 .58142 m .51096 .58086 L p
.5059 .58122 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .511 .58142 L p
1 g
F P
s
P
p
.49912 .58095 m .48889 .583 L .511 .58142 L 1 g
F
P
p
.47769 .57767 m .46914 .57551 L .47374 .57735 L 1 g
F
P
p
.46818 .57513 m .45745 .57084 L .45077 .56314 L 1 g
F
P
p
.45745 .57084 m .4537 .56934 L .45077 .56314 L 1 g
F
P
p
.4685 .57534 m .4537 .56934 L .46818 .57513 L 1 g
F
P
p
.002 w
.46817 .57517 m .46818 .57513 L p
.45426 .56797 L 1 g
F P
s
P
p
.002 w
.46818 .57513 m .46872 .57265 L p
.46092 .57012 L 1 g
F P
s
P
p
.46092 .57012 m .45426 .56797 L .46818 .57513 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.46951 .57487 m .4685 .57534 L p
.44513 .55663 L 1 g
F P
s
P
p
.002 w
.44232 .55438 m .4448 .55625 L p
.44513 .55663 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.4448 .55625 m .46951 .57487 L p
.44513 .55663 L 1 g
F P
s
P
p
.002 w
.43787 .54826 m .43743 .5491 L p
.44218 .55323 L 1 g
F P
s
P
p
.002 w
.44128 .5247 m .45266 .52794 L .44262 .5536 L p
1 g
F P
s
P
p
.002 w
.44227 .55311 m .44128 .5247 L p
.44262 .5536 L 1 g
F P
s
P
p
.002 w
.45266 .52794 m .46301 .53389 L .44282 .55388 L p
1 g
F P
s
P
p
.002 w
.44262 .5536 m .45266 .52794 L p
.44282 .55388 L 1 g
F P
s
P
p
.44264 .55362 m .44262 .55361 L .44267 .55366 L 1 g
F
P
p
.44262 .55361 m .44257 .55357 L .4427 .55372 L 1 g
F
P
p
.002 w
.46301 .53389 m .47115 .54185 L .44298 .55409 L p
1 g
F P
s
P
p
.002 w
.44282 .55388 m .46301 .53389 L p
.44298 .55409 L 1 g
F P
s
P
p
.002 w
.47115 .54185 m .47619 .55094 L .44314 .55429 L p
1 g
F P
s
P
p
.002 w
.44298 .55409 m .47115 .54185 L p
.44314 .55429 L 1 g
F P
s
P
p
.44257 .55357 m .4425 .5535 L .44277 .55382 L 1 g
F
P
p
.4425 .5535 m .4424 .55342 L .44292 .55403 L 1 g
F
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47619 .55094 m .4776 .56012 L .44335 .55454 L p
1 g
F P
s
P
p
.002 w
.44314 .55429 m .47619 .55094 L p
.44335 .55454 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.4776 .56012 m .47527 .56839 L .4437 .55496 L p
1 g
F P
s
P
p
.002 w
.4437 .55496 m .44232 .55438 L .44335 .55454 L p
1 g
F P
s
P
p
.002 w
.44335 .55454 m .4776 .56012 L p
.4437 .55496 L 1 g
F P
s
P
p
.4424 .55342 m .44229 .55332 L .44335 .55455 L 1 g
F
P
p
.44229 .55332 m .44218 .55323 L .4448 .55625 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.47527 .56839 m .46951 .57487 L .4448 .55625 L p
1 g
F P
s
P
p
.002 w
.4448 .55625 m .44232 .55438 L .4437 .55496 L p
1 g
F P
s
P
p
.002 w
.4437 .55496 m .47527 .56839 L p
.4448 .55625 L 1 g
F P
s
P
p
.002 w
.44701 .56055 m .44232 .55438 L p
.4685 .57534 L 1 g
F P
s
P
p
.002 w
.42878 .57373 m .41962 .56692 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.43948 .57827 m .42878 .57373 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.45059 .58005 m .43948 .57827 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.41962 .56692 m .41294 .55854 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.41294 .55854 m .40948 .54945 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.40948 .54945 m .40963 .54061 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.40963 .54061 m .41343 .53297 L .44232 .55438 L closepath p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45077 .56314 L p
1 g
F P
s
P
p
.44218 .55323 m .43743 .5491 L .45077 .56314 L 1 g
F
P
p
.002 w
.46818 .57513 m .4678 .57686 L p
.47374 .57735 L 1 g
F P
s
P
p
.46092 .57012 m .45843 .56854 L .4605 .56999 L 1 g
F
P
p
.45888 .56872 m .45843 .56854 L .46092 .57012 L 1 g
F
P
p
.002 w
.45002 .56518 m .45426 .56797 L p
.4605 .56999 L 1 g
F P
s
P
p
.45843 .56854 m .45002 .56518 L .4605 .56999 L 1 g
F
P
p
.002 w
.45426 .56797 m .4678 .57686 L .46817 .57517 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58097 L p
1 g
F P
s
P
p
.47695 .57761 m .4678 .57686 L .48904 .58097 L 1 g
F
P
p
.002 w
.4686 .57529 m .46951 .57487 L .47179 .57618 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.60581 .34236 m .54602 .30709 L .55622 .28489 L p
1 g
F P
s
P
p
.002 w
.60581 .34236 m .65085 .39056 L .63468 .41329 L p
1 g
F P
s
P
p
.002 w
.38438 .46489 m .3645 .48175 L .34618 .45384 L p
1 g
F P
s
P
p
.002 w
.34618 .45384 m .37141 .43168 L .38438 .46489 L p
1 g
F P
s
P
p
.002 w
.40474 .38367 m .36248 .3988 L .35784 .36743 L p
1 g
F P
s
P
p
.002 w
.35784 .36743 m .40544 .34974 L .40474 .38367 L p
1 g
F P
s
P
p
.002 w
.41343 .53297 m .40963 .54061 L .37998 .52366 L p
1 g
F P
s
P
p
.002 w
.37998 .52366 m .38717 .50846 L .41343 .53297 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.58282 .55369 m .57932 .51926 L .60992 .50286 L p
1 g
F P
s
P
p
.002 w
.46951 .57487 m .47527 .56839 L .50873 .57815 L p
1 g
F P
s
P
p
.002 w
.51366 .56194 m .50873 .57815 L .47527 .56839 L p
1 g
F P
s
P
p
.002 w
.50873 .57815 m .51366 .56194 L .54916 .55975 L p
1 g
F P
s
P
p
.002 w
.61396 .43712 m .63673 .48454 L .60992 .50286 L p
1 g
F P
s
P
p
.002 w
.63673 .48454 m .61396 .43712 L .63468 .41329 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40095 .4972 m .38717 .50846 L .3645 .48175 L p
1 g
F P
s
P
p
.002 w
.3645 .48175 m .38438 .46489 L .40095 .4972 L p
1 g
F P
s
P
p
.002 w
.46214 .34833 m .40544 .34974 L .409 .31889 L p
1 g
F P
s
P
p
.002 w
.409 .31889 m .47045 .31692 L .46214 .34833 L p
1 g
F P
s
P
p
.002 w
.53409 .33375 m .47045 .31692 L .47947 .28967 L p
1 g
F P
s
P
p
.002 w
.47947 .28967 m .54602 .30709 L .53409 .33375 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40697 .41947 m .37141 .43168 L .36248 .3988 L p
1 g
F P
s
P
p
.002 w
.36248 .3988 m .40474 .38367 L .40697 .41947 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.47527 .56839 m .4776 .56012 L .51366 .56194 L p
1 g
F P
s
P
p
.002 w
.546 .53307 m .54916 .55975 L .51366 .56194 L p
1 g
F P
s
P
p
.002 w
.63468 .41329 m .59137 .36743 L .60581 .34236 L p
1 g
F P
s
P
p
.002 w
.54602 .30709 m .60581 .34236 L .59137 .36743 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42051 .52739 m .41343 .53297 L .38717 .50846 L p
1 g
F P
s
P
p
.002 w
.38717 .50846 m .40095 .4972 L .42051 .52739 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59137 .36743 m .63468 .41329 L .61396 .43712 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.51119 .54376 m .51366 .56194 L .4776 .56012 L p
1 g
F P
s
P
p
.002 w
.51366 .56194 m .51119 .54376 L .546 .53307 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.59137 .36743 m .53409 .33375 L .54602 .30709 L p
1 g
F P
s
P
p
.002 w
.58934 .46117 m .60992 .50286 L .57932 .51926 L p
1 g
F P
s
P
p
.002 w
.60992 .50286 m .58934 .46117 L .61396 .43712 L p
1 g
F P
s
P
p
.002 w
.4776 .56012 m .47619 .55094 L .51119 .54376 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4121 .4558 m .38438 .46489 L .37141 .43168 L p
1 g
F P
s
P
p
.002 w
.37141 .43168 m .40697 .41947 L .4121 .4558 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43015 .52452 m .42051 .52739 L .40095 .4972 L p
1 g
F P
s
P
p
.002 w
.45487 .38283 m .40474 .38367 L .40544 .34974 L p
1 g
F P
s
P
p
.002 w
.40544 .34974 m .46214 .34833 L .45487 .38283 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.47619 .55094 m .47115 .54185 L .50141 .52565 L p
1 g
F P
s
P
p
.002 w
.50141 .52565 m .51119 .54376 L .47619 .55094 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.41993 .49126 m .40095 .4972 L .38438 .46489 L p
1 g
F P
s
P
p
.002 w
.38438 .46489 m .4121 .4558 L .41993 .49126 L p
1 g
F P
s
P
p
.002 w
.40095 .4972 m .41993 .49126 L .43015 .52452 L p
1 g
F P
s
P
p
.002 w
.57932 .51926 m .56167 .48454 L .58934 .46117 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.52083 .36404 m .46214 .34833 L .47045 .31692 L p
1 g
F P
s
P
p
.002 w
.47045 .31692 m .53409 .33375 L .52083 .36404 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.47115 .54185 m .46301 .53389 L .48532 .50971 L p
1 g
F P
s
P
p
.002 w
.48532 .50971 m .50141 .52565 L .47115 .54185 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57375 .39504 m .61396 .43712 L .58934 .46117 L p
1 g
F P
s
P
p
.002 w
.61396 .43712 m .57375 .39504 L .59137 .36743 L p
1 g
F P
s
P
p
.002 w
.51119 .54376 m .50141 .52565 L .53198 .50631 L p
1 g
F P
s
P
p
.002 w
.53198 .50631 m .546 .53307 L .51119 .54376 L p
1 g
F P
s
P
p
.002 w
.53409 .33375 m .59137 .36743 L .57375 .39504 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.46301 .53389 m .45266 .52794 L .46472 .49784 L p
1 g
F P
s
P
p
.002 w
.46472 .49784 m .48532 .50971 L .46301 .53389 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44895 .41912 m .40697 .41947 L .40474 .38367 L p
1 g
F P
s
P
p
.002 w
.40474 .38367 m .45487 .38283 L .44895 .41912 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.57375 .39504 m .52083 .36404 L .53409 .33375 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.44204 .49145 m .41993 .49126 L .4121 .4558 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50141 .52565 m .48532 .50971 L .50844 .48268 L p
1 g
F P
s
P
p
.002 w
.50844 .48268 m .53198 .50631 L .50141 .52565 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.55354 .4242 m .58934 .46117 L .56167 .48454 L p
1 g
F P
s
P
p
.002 w
.58934 .46117 m .55354 .4242 L .57375 .39504 L p
1 g
F P
s
P
p
.002 w
.44462 .45581 m .4121 .4558 L .40697 .41947 L p
1 g
F P
s
P
p
.002 w
.40697 .41947 m .44895 .41912 L .44462 .45581 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.4121 .4558 m .44462 .45581 L .44204 .49145 L p
1 g
F P
s
P
p
.002 w
.50671 .39688 m .45487 .38283 L .46214 .34833 L p
1 g
F P
s
P
p
.002 w
.46214 .34833 m .52083 .36404 L .50671 .39688 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.56167 .48454 m .53149 .4538 L .55354 .4242 L p
1 g
F P
s
P
p
.002 w
.52083 .36404 m .57375 .39504 L .55354 .4242 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55354 .4242 m .50671 .39688 L .52083 .36404 L p
1 g
F P
s
P
p
.002 w
.49228 .43102 m .44895 .41912 L .45487 .38283 L p
1 g
F P
s
P
p
.002 w
.45487 .38283 m .50671 .39688 L .49228 .43102 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.4781 .46512 m .44462 .45581 L .44895 .41912 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.004 w
.40824 .62756 m
.41857 .60537 L
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.004 w
.41857 .60537 m
.42287 .59614 L
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.50671 .39688 m .55354 .4242 L .53149 .4538 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.44895 .41912 m .49228 .43102 L .4781 .46512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.53149 .4538 m .49228 .43102 L .50671 .39688 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .39823 .70262 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40824 .62756 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.596899)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.596899)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45838 .41353 m .48146 .43958 L .49997 .41782 L p
1 g
F P
s
P
p
.002 w
.49997 .41782 m .48215 .3976 L .45838 .41353 L p
1 g
F P
s
P
p
.002 w
.52286 .43232 m .49997 .41782 L .48146 .43958 L p
1 g
F P
s
P
p
.002 w
.48215 .3976 m .49997 .41782 L .51851 .39631 L p
1 g
F P
s
P
p
.002 w
.49997 .41782 m .52286 .43232 L .53417 .40622 L p
1 g
F P
s
P
p
.002 w
.53417 .40622 m .51851 .39631 L .49997 .41782 L p
1 g
F P
s
P
p
.002 w
.43549 .42996 m .46333 .46122 L .48146 .43958 L p
1 g
F P
s
P
p
.002 w
.48146 .43958 m .45838 .41353 L .43549 .42996 L p
1 g
F P
s
P
p
.002 w
.511 .45833 m .48146 .43958 L .46333 .46122 L p
1 g
F P
s
P
p
.002 w
.48146 .43958 m .511 .45833 L .52286 .43232 L p
1 g
F P
s
P
p
.002 w
.54855 .43965 m .52286 .43232 L .511 .45833 L p
1 g
F P
s
P
p
.002 w
.52286 .43232 m .54855 .43965 L .55175 .41116 L p
1 g
F P
s
P
p
.002 w
.55175 .41116 m .53417 .40622 L .52286 .43232 L p
1 g
F P
s
P
p
.002 w
.54416 .46793 m .511 .45833 L .49883 .48379 L p
1 g
F P
s
P
p
.002 w
.46333 .46122 m .49883 .48379 L .511 .45833 L p
1 g
F P
s
P
p
.002 w
.511 .45833 m .54416 .46793 L .54855 .43965 L p
1 g
F P
s
P
p
.002 w
.44407 .38264 m .45838 .41353 L .48215 .3976 L p
1 g
F P
s
P
p
.002 w
.48215 .3976 m .47122 .37364 L .44407 .38264 L p
1 g
F P
s
P
p
.002 w
.47122 .37364 m .48215 .3976 L .50636 .38246 L p
1 g
F P
s
P
p
.002 w
.51851 .39631 m .50636 .38246 L .48215 .3976 L p
1 g
F P
s
P
p
.002 w
.50636 .38246 m .51851 .39631 L .53676 .37545 L p
1 g
F P
s
P
p
.002 w
.51851 .39631 m .53417 .40622 L .54475 .3805 L p
1 g
F P
s
P
p
.002 w
.54475 .3805 m .53676 .37545 L .51851 .39631 L p
1 g
F P
s
P
p
.002 w
.53417 .40622 m .55175 .41116 L .55372 .38298 L p
1 g
F P
s
P
p
.002 w
.55372 .38298 m .54475 .3805 L .53417 .40622 L p
1 g
F P
s
P
p
.002 w
.41806 .39288 m .43549 .42996 L .45838 .41353 L p
1 g
F P
s
P
p
.002 w
.45838 .41353 m .44407 .38264 L .41806 .39288 L p
1 g
F P
s
P
p
.002 w
.41392 .44659 m .4459 .48233 L .46333 .46122 L p
1 g
F P
s
P
p
.002 w
.46333 .46122 m .43549 .42996 L .41392 .44659 L p
1 g
F P
s
P
p
.002 w
.49883 .48379 m .46333 .46122 L .4459 .48233 L p
1 g
F P
s
P
p
.002 w
.50636 .38246 m .49899 .36606 L .47122 .37364 L p
1 g
F P
s
P
p
.002 w
.49899 .36606 m .50636 .38246 L .53059 .36838 L p
1 g
F P
s
P
p
.002 w
.53676 .37545 m .53059 .36838 L .50636 .38246 L p
1 g
F P
s
P
p
.002 w
.57449 .43899 m .54855 .43965 L .54416 .46793 L p
1 g
F P
s
P
p
.002 w
.54855 .43965 m .57449 .43899 L .56945 .41058 L p
1 g
F P
s
P
p
.002 w
.56945 .41058 m .55175 .41116 L .54855 .43965 L p
1 g
F P
s
P
p
.002 w
.53867 .4955 m .49883 .48379 L .48656 .50822 L p
1 g
F P
s
P
p
.002 w
.49883 .48379 m .53867 .4955 L .54416 .46793 L p
1 g
F P
s
P
p
.002 w
.4459 .48233 m .48656 .50822 L .49883 .48379 L p
1 g
F P
s
P
p
.002 w
.55175 .41116 m .56945 .41058 L .56271 .38263 L p
1 g
F P
s
P
p
.002 w
.56271 .38263 m .55372 .38298 L .55175 .41116 L p
1 g
F P
s
P
p
.002 w
.57773 .46732 m .54416 .46793 L .53867 .4955 L p
1 g
F P
s
P
p
.002 w
.54416 .46793 m .57773 .46732 L .57449 .43899 L p
1 g
F P
s
P
p
.002 w
.44014 .3499 m .44407 .38264 L .47122 .37364 L p
1 g
F P
s
P
p
.002 w
.47122 .37364 m .4684 .34833 L .44014 .3499 L p
1 g
F P
s
P
p
.002 w
.4684 .34833 m .47122 .37364 L .49899 .36606 L p
1 g
F P
s
P
p
.002 w
.49899 .36606 m .49722 .34879 L .4684 .34833 L p
1 g
F P
s
P
p
.002 w
.49722 .34879 m .49899 .36606 L .52689 .36001 L p
1 g
F P
s
P
p
.002 w
.53059 .36838 m .52689 .36001 L .49899 .36606 L p
1 g
F P
s
P
p
.002 w
.39371 .4042 m .41392 .44659 L .43549 .42996 L p
1 g
F P
s
P
p
.002 w
.43549 .42996 m .41806 .39288 L .39371 .4042 L p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .53059 .36838 L .53676 .37545 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .53676 .37545 L .54475 .3805 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .54475 .3805 L .55372 .38298 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .52689 .36001 L .53059 .36838 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .55372 .38298 L .56271 .38263 L closepath p
1 g
F P
s
P
p
.002 w
.58542 .40449 m .56945 .41058 L .57449 .43899 L p
1 g
F P
s
P
p
.002 w
.56945 .41058 m .58542 .40449 L .57078 .37945 L p
1 g
F P
s
P
p
.002 w
.57078 .37945 m .56271 .38263 L .56945 .41058 L p
1 g
F P
s
P
p
.002 w
.413 .35348 m .41806 .39288 L .44407 .38264 L p
1 g
F P
s
P
p
.002 w
.44407 .38264 m .44014 .3499 L .413 .35348 L p
1 g
F P
s
P
p
.002 w
.39409 .46312 m .42951 .50253 L .4459 .48233 L p
1 g
F P
s
P
p
.002 w
.4459 .48233 m .41392 .44659 L .39409 .46312 L p
1 g
F P
s
P
p
.002 w
.48656 .50822 m .4459 .48233 L .42951 .50253 L p
1 g
F P
s
P
p
.002 w
.59803 .43026 m .57449 .43899 L .57773 .46732 L p
1 g
F P
s
P
p
.002 w
.57449 .43899 m .59803 .43026 L .58542 .40449 L p
1 g
F P
s
P
p
.002 w
.52689 .36001 m .52606 .35124 L .49722 .34879 L p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .52606 .35124 L .52689 .36001 L closepath p
1 g
F P
s
P
p
.002 w
.48656 .50822 m .53216 .52181 L .53867 .4955 L p
1 g
F P
s
P
p
.002 w
.57909 .49504 m .53867 .4955 L .53216 .52181 L p
1 g
F P
s
P
p
.002 w
.53867 .4955 m .57909 .49504 L .57773 .46732 L p
1 g
F P
s
P
p
.002 w
.53216 .52181 m .48656 .50822 L .4744 .53115 L p
1 g
F P
s
P
p
.002 w
.42951 .50253 m .4744 .53115 L .48656 .50822 L p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .56271 .38263 L .57078 .37945 L closepath p
1 g
F P
s
P
p
.002 w
.47415 .32426 m .4684 .34833 L .49722 .34879 L p
1 g
F P
s
P
p
.002 w
.49722 .34879 m .50131 .33245 L .47415 .32426 L p
1 g
F P
s
P
p
.002 w
.50131 .33245 m .49722 .34879 L .52606 .35124 L p
1 g
F P
s
P
p
.002 w
.52606 .35124 m .52822 .34299 L .50131 .33245 L p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .52822 .34299 L .52606 .35124 L closepath p
1 g
F P
s
P
p
.002 w
.60834 .4563 m .57773 .46732 L .57909 .49504 L p
1 g
F P
s
P
p
.002 w
.57773 .46732 m .60834 .4563 L .59803 .43026 L p
1 g
F P
s
P
p
.002 w
.57705 .37378 m .57078 .37945 L .58542 .40449 L p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .57078 .37945 L .57705 .37378 L closepath p
1 g
F P
s
P
p
.002 w
.37152 .41641 m .39409 .46312 L .41392 .44659 L p
1 g
F P
s
P
p
.002 w
.41392 .44659 m .39371 .4042 L .37152 .41641 L p
1 g
F P
s
P
p
.002 w
.44729 .31861 m .44014 .3499 L .4684 .34833 L p
1 g
F P
s
P
p
.002 w
.4684 .34833 m .47415 .32426 L .44729 .31861 L p
1 g
F P
s
P
p
.002 w
.59794 .39342 m .58542 .40449 L .59803 .43026 L p
1 g
F P
s
P
p
.002 w
.58542 .40449 m .59794 .39342 L .57705 .37378 L p
1 g
F P
s
P
p
.002 w
.38755 .35906 m .39371 .4042 L .41806 .39288 L p
1 g
F P
s
P
p
.002 w
.41806 .39288 m .413 .35348 L .38755 .35906 L p
1 g
F P
s
P
p
.002 w
.51094 .31883 m .50131 .33245 L .52822 .34299 L p
1 g
F P
s
P
p
.002 w
.52822 .34299 m .53316 .33616 L .51094 .31883 L p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .53316 .33616 L .52822 .34299 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .57705 .37378 L .58083 .3662 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .58083 .3662 L .58167 .35752 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .58167 .35752 L .57946 .34869 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .57946 .34869 L .57443 .34069 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .57443 .34069 L .56712 .33441 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .56712 .33441 L .55834 .33056 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .55834 .33056 L .54909 .32956 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .54909 .32956 L .54038 .3315 L closepath p
1 g
F P
s
P
p
.002 w
.55438 .35564 m .54038 .3315 L .53316 .33616 L closepath p
1 g
F P
s
P
p
.002 w
.58083 .3662 m .57705 .37378 L .59794 .39342 L p
1 g
F P
s
P
p
.002 w
.4744 .53115 m .52473 .54635 L .53216 .52181 L p
1 g
F P
s
P
p
.002 w
.57851 .5216 m .53216 .52181 L .52473 .54635 L p
1 g
F P
s
P
p
.002 w
.53216 .52181 m .57851 .5216 L .57909 .49504 L p
1 g
F P
s
P
p
.002 w
.61663 .41418 m .59803 .43026 L .60834 .4563 L p
1 g
F P
s
P
p
.002 w
.59803 .43026 m .61663 .41418 L .59794 .39342 L p
1 g
F P
s
P
p
.002 w
.48811 .30404 m .47415 .32426 L .50131 .33245 L p
1 g
F P
s
P
p
.002 w
.50131 .33245 m .51094 .31883 L .48811 .30404 L p
1 g
F P
s
P
p
.002 w
.52515 .30945 m .51094 .31883 L .53316 .33616 L p
1 g
F P
s
P
p
.002 w
.53316 .33616 m .54038 .3315 L .52515 .30945 L p
1 g
F P
s
P
p
.002 w
.42125 .31567 m .413 .35348 L .44014 .3499 L p
1 g
F P
s
P
p
.002 w
.44014 .3499 m .44729 .31861 L .42125 .31567 L p
1 g
F P
s
P
p
.002 w
.37645 .47922 m .41451 .52138 L .42951 .50253 L p
1 g
F P
s
P
p
.002 w
.42951 .50253 m .39409 .46312 L .37645 .47922 L p
1 g
F P
s
P
p
.002 w
.4744 .53115 m .42951 .50253 L .41451 .52138 L p
1 g
F P
s
P
p
.002 w
.61609 .48209 m .57909 .49504 L .57851 .5216 L p
1 g
F P
s
P
p
.002 w
.57909 .49504 m .61609 .48209 L .60834 .4563 L p
1 g
F P
s
P
p
.002 w
.59794 .39342 m .60559 .37848 L .58083 .3662 L p
1 g
F P
s
P
p
.002 w
.58167 .35752 m .58083 .3662 L .60559 .37848 L p
1 g
F P
s
P
p
.002 w
.52473 .54635 m .4744 .53115 L .46261 .55209 L p
1 g
F P
s
P
p
.002 w
.41451 .52138 m .46261 .55209 L .4744 .53115 L p
1 g
F P
s
P
p
.002 w
.60559 .37848 m .59794 .39342 L .61663 .41418 L p
1 g
F P
s
P
p
.002 w
.54246 .30546 m .52515 .30945 L .54038 .3315 L p
1 g
F P
s
P
p
.002 w
.54038 .3315 m .54909 .32956 L .54246 .30546 L p
1 g
F P
s
P
p
.002 w
.46515 .29215 m .44729 .31861 L .47415 .32426 L p
1 g
F P
s
P
p
.002 w
.47415 .32426 m .48811 .30404 L .46515 .29215 L p
1 g
F P
s
P
p
.002 w
.36436 .36659 m .37152 .41641 L .39371 .4042 L p
1 g
F P
s
P
p
.002 w
.39371 .4042 m .38755 .35906 L .36436 .36659 L p
1 g
F P
s
P
p
.002 w
.60559 .37848 m .60742 .36125 L .58167 .35752 L p
1 g
F P
s
P
p
.002 w
.57946 .34869 m .58167 .35752 L .60742 .36125 L p
1 g
F P
s
P
p
.002 w
.35204 .42928 m .37645 .47922 L .39409 .46312 L p
1 g
F P
s
P
p
.002 w
.39409 .46312 m .37152 .41641 L .35204 .42928 L p
1 g
F P
s
P
p
.002 w
.63268 .43569 m .60834 .4563 L .61609 .48209 L p
1 g
F P
s
P
p
.002 w
.60834 .4563 m .63268 .43569 L .61663 .41418 L p
1 g
F P
s
P
p
.002 w
.50898 .29 m .48811 .30404 L .51094 .31883 L p
1 g
F P
s
P
p
.002 w
.51094 .31883 m .52515 .30945 L .50898 .29 L p
1 g
F P
s
P
p
.002 w
.56094 .30737 m .54246 .30546 L .54909 .32956 L p
1 g
F P
s
P
p
.002 w
.54909 .32956 m .55834 .33056 L .56094 .30737 L p
1 g
F P
s
P
p
.002 w
.60742 .36125 m .60312 .34363 L .57946 .34869 L p
1 g
F P
s
P
p
.002 w
.57443 .34069 m .57946 .34869 L .60312 .34363 L p
1 g
F P
s
P
p
.002 w
.5785 .31504 m .56094 .30737 L .55834 .33056 L p
1 g
F P
s
P
p
.002 w
.55834 .33056 m .56712 .33441 L .5785 .31504 L p
1 g
F P
s
P
p
.002 w
.39663 .31559 m .38755 .35906 L .413 .35348 L p
1 g
F P
s
P
p
.002 w
.413 .35348 m .42125 .31567 L .39663 .31559 L p
1 g
F P
s
P
p
.002 w
.60312 .34363 m .59312 .32761 L .57443 .34069 L p
1 g
F P
s
P
p
.002 w
.56712 .33441 m .57443 .34069 L .59312 .32761 L p
1 g
F P
s
P
p
.002 w
.59312 .32761 m .5785 .31504 L .56712 .33441 L p
1 g
F P
s
P
p
.002 w
.61663 .41418 m .62812 .39228 L .60559 .37848 L p
1 g
F P
s
P
p
.002 w
.60742 .36125 m .60559 .37848 L .62812 .39228 L p
1 g
F P
s
P
p
.002 w
.62812 .39228 m .61663 .41418 L .63268 .43569 L p
1 g
F P
s
P
p
.002 w
.46261 .55209 m .5165 .56856 L .52473 .54635 L p
1 g
F P
s
P
p
.002 w
.57594 .54643 m .52473 .54635 L .5165 .56856 L p
1 g
F P
s
P
p
.002 w
.52473 .54635 m .57594 .54643 L .57851 .5216 L p
1 g
F P
s
P
p
.002 w
.62108 .50711 m .57851 .5216 L .57594 .54643 L p
1 g
F P
s
P
p
.002 w
.57851 .5216 m .62108 .50711 L .61609 .48209 L p
1 g
F P
s
P
p
.002 w
.53457 .2839 m .50898 .29 L .52515 .30945 L p
1 g
F P
s
P
p
.002 w
.52515 .30945 m .54246 .30546 L .53457 .2839 L p
1 g
F P
s
P
p
.002 w
.44252 .28352 m .42125 .31567 L .44729 .31861 L p
1 g
F P
s
P
p
.002 w
.44729 .31861 m .46515 .29215 L .44252 .28352 L p
1 g
F P
s
P
p
.002 w
.36146 .49454 m .40125 .53845 L .41451 .52138 L p
1 g
F P
s
P
p
.002 w
.41451 .52138 m .37645 .47922 L .36146 .49454 L p
1 g
F P
s
P
p
.002 w
.46261 .55209 m .41451 .52138 L .40125 .53845 L p
1 g
F P
s
P
p
.002 w
.49216 .27364 m .46515 .29215 L .48811 .30404 L p
1 g
F P
s
P
p
.002 w
.48811 .30404 m .50898 .29 L .49216 .27364 L p
1 g
F P
s
P
p
.002 w
.64572 .45751 m .61609 .48209 L .62108 .50711 L p
1 g
F P
s
P
p
.002 w
.61609 .48209 m .64572 .45751 L .63268 .43569 L p
1 g
F P
s
P
p
.002 w
.5165 .56856 m .46261 .55209 L .45144 .57054 L p
1 g
F P
s
P
p
.002 w
.40125 .53845 m .45144 .57054 L .46261 .55209 L p
1 g
F P
s
P
p
.002 w
.62812 .39228 m .63104 .36683 L .60742 .36125 L p
1 g
F P
s
P
p
.002 w
.60312 .34363 m .60742 .36125 L .63104 .36683 L p
1 g
F P
s
P
p
.002 w
.34402 .37597 m .35204 .42928 L .37152 .41641 L p
1 g
F P
s
P
p
.002 w
.37152 .41641 m .36436 .36659 L .34402 .37597 L p
1 g
F P
s
P
p
.002 w
.56205 .28663 m .53457 .2839 L .54246 .30546 L p
1 g
F P
s
P
p
.002 w
.54246 .30546 m .56094 .30737 L .56205 .28663 L p
1 g
F P
s
P
p
.002 w
.64791 .40735 m .63268 .43569 L .64572 .45751 L p
1 g
F P
s
P
p
.002 w
.63268 .43569 m .64791 .40735 L .62812 .39228 L p
1 g
F P
s
P
p
.002 w
.33578 .44256 m .36146 .49454 L .37645 .47922 L p
1 g
F P
s
P
p
.002 w
.37645 .47922 m .35204 .42928 L .33578 .44256 L p
1 g
F P
s
P
p
.002 w
.374 .31847 m .36436 .36659 L .38755 .35906 L p
1 g
F P
s
P
p
.002 w
.38755 .35906 m .39663 .31559 L .374 .31847 L p
1 g
F P
s
P
p
.002 w
.63104 .36683 m .62812 .39228 L .64791 .40735 L p
1 g
F P
s
P
p
.002 w
.63104 .36683 m .62482 .34064 L .60312 .34363 L p
1 g
F P
s
P
p
.002 w
.59312 .32761 m .60312 .34363 L .62482 .34064 L p
1 g
F P
s
P
p
.002 w
.58823 .29801 m .56205 .28663 L .56094 .30737 L p
1 g
F P
s
P
p
.002 w
.56094 .30737 m .5785 .31504 L .58823 .29801 L p
1 g
F P
s
P
p
.002 w
.5165 .56856 m .57136 .56895 L .57594 .54643 L p
1 g
F P
s
P
p
.002 w
.62309 .53079 m .57594 .54643 L .57136 .56895 L p
1 g
F P
s
P
p
.002 w
.57594 .54643 m .62309 .53079 L .62108 .50711 L p
1 g
F P
s
P
p
.002 w
.62482 .34064 m .61 .31676 L .59312 .32761 L p
1 g
F P
s
P
p
.002 w
.5785 .31504 m .59312 .32761 L .61 .31676 L p
1 g
F P
s
P
p
.002 w
.45144 .57054 m .50761 .58789 L .5165 .56856 L p
1 g
F P
s
P
p
.002 w
.57136 .56895 m .5165 .56856 L .50761 .58789 L p
1 g
F P
s
P
p
.002 w
.42075 .27845 m .39663 .31559 L .42125 .31567 L p
1 g
F P
s
P
p
.002 w
.42125 .31567 m .44252 .28352 L .42075 .27845 L p
1 g
F P
s
P
p
.002 w
.61 .31676 m .58823 .29801 L .5785 .31504 L p
1 g
F P
s
P
p
.002 w
.52555 .26547 m .49216 .27364 L .50898 .29 L p
1 g
F P
s
P
p
.002 w
.50898 .29 m .53457 .2839 L .52555 .26547 L p
1 g
F P
s
P
p
.002 w
.47505 .26086 m .44252 .28352 L .46515 .29215 L p
1 g
F P
s
P
p
.002 w
.46515 .29215 m .49216 .27364 L .47505 .26086 L p
1 g
F P
s
P
p
.002 w
.65533 .47919 m .62108 .50711 L .62309 .53079 L p
1 g
F P
s
P
p
.002 w
.62108 .50711 m .65533 .47919 L .64572 .45751 L p
1 g
F P
s
P
p
.002 w
.64791 .40735 m .65196 .37419 L .63104 .36683 L p
1 g
F P
s
P
p
.002 w
.62482 .34064 m .63104 .36683 L .65196 .37419 L p
1 g
F P
s
P
p
.002 w
.34955 .50872 m .39011 .55331 L .40125 .53845 L p
1 g
F P
s
P
p
.002 w
.40125 .53845 m .36146 .49454 L .34955 .50872 L p
1 g
F P
s
P
p
.002 w
.45144 .57054 m .40125 .53845 L .39011 .55331 L p
1 g
F P
s
P
p
.002 w
.32711 .38707 m .33578 .44256 L .35204 .42928 L p
1 g
F P
s
P
p
.002 w
.35204 .42928 m .34402 .37597 L .32711 .38707 L p
1 g
F P
s
P
p
.002 w
.66442 .42342 m .64572 .45751 L .65533 .47919 L p
1 g
F P
s
P
p
.002 w
.64572 .45751 m .66442 .42342 L .64791 .40735 L p
1 g
F P
s
P
p
.002 w
.50761 .58789 m .45144 .57054 L .44115 .58598 L p
1 g
F P
s
P
p
.002 w
.39011 .55331 m .44115 .58598 L .45144 .57054 L p
1 g
F P
s
P
p
.002 w
.65196 .37419 m .64791 .40735 L .66442 .42342 L p
1 g
F P
s
P
p
.002 w
.35398 .3244 m .34402 .37597 L .36436 .36659 L p
1 g
F P
s
P
p
.002 w
.36436 .36659 m .374 .31847 L .35398 .3244 L p
1 g
F P
s
P
p
.002 w
.56159 .26893 m .52555 .26547 L .53457 .2839 L p
1 g
F P
s
P
p
.002 w
.53457 .2839 m .56205 .28663 L .56159 .26893 L p
1 g
F P
s
P
p
.002 w
.32327 .45598 m .34955 .50872 L .36146 .49454 L p
1 g
F P
s
P
p
.002 w
.36146 .49454 m .33578 .44256 L .32327 .45598 L p
1 g
F P
s
P
p
.002 w
.65196 .37419 m .64398 .33988 L .62482 .34064 L p
1 g
F P
s
P
p
.002 w
.61 .31676 m .62482 .34064 L .64398 .33988 L p
1 g
F P
s
P
p
.002 w
.40036 .27724 m .374 .31847 L .39663 .31559 L p
1 g
F P
s
P
p
.002 w
.39663 .31559 m .42075 .27845 L .40036 .27724 L p
1 g
F P
s
P
p
.002 w
.50761 .58789 m .56479 .58857 L .57136 .56895 L p
1 g
F P
s
P
p
.002 w
.62196 .55256 m .57136 .56895 L .56479 .58857 L p
1 g
F P
s
P
p
.002 w
.57136 .56895 m .62196 .55256 L .62309 .53079 L p
1 g
F P
s
P
p
.002 w
.59601 .28383 m .56159 .26893 L .56205 .28663 L p
1 g
F P
s
P
p
.002 w
.56205 .28663 m .58823 .29801 L .59601 .28383 L p
1 g
F P
s
P
p
.002 w
.51555 .25074 m .47505 .26086 L .49216 .27364 L p
1 g
F P
s
P
p
.002 w
.49216 .27364 m .52555 .26547 L .51555 .25074 L p
1 g
F P
s
P
p
.002 w
.44115 .58598 m .49822 .60377 L .50761 .58789 L p
1 g
F P
s
P
p
.002 w
.56479 .58857 m .50761 .58789 L .49822 .60377 L p
1 g
F P
s
P
p
.002 w
.45802 .25214 m .42075 .27845 L .44252 .28352 L p
1 g
F P
s
P
p
.002 w
.44252 .28352 m .47505 .26086 L .45802 .25214 L p
1 g
F P
s
P
p
.002 w
.64398 .33988 m .62461 .30849 L .61 .31676 L p
1 g
F P
s
P
p
.002 w
.58823 .29801 m .61 .31676 L .62461 .30849 L p
1 g
F P
s
P
p
.002 w
.66118 .50025 m .62309 .53079 L .62196 .55256 L p
1 g
F P
s
P
p
.002 w
.62309 .53079 m .66118 .50025 L .65533 .47919 L p
1 g
F P
s
P
p
.002 w
.62461 .30849 m .59601 .28383 L .58823 .29801 L p
1 g
F P
s
P
p
.002 w
.66442 .42342 m .66958 .38326 L .65196 .37419 L p
1 g
F P
s
P
p
.002 w
.64398 .33988 m .65196 .37419 L .66958 .38326 L p
1 g
F P
s
P
p
.002 w
.67713 .44018 m .65533 .47919 L .66118 .50025 L p
1 g
F P
s
P
p
.002 w
.65533 .47919 m .67713 .44018 L .66442 .42342 L p
1 g
F P
s
P
p
.002 w
.66958 .38326 m .66442 .42342 L .67713 .44018 L p
1 g
F P
s
P
p
.002 w
.31423 .39973 m .32327 .45598 L .33578 .44256 L p
1 g
F P
s
P
p
.002 w
.33578 .44256 m .32711 .38707 L .31423 .39973 L p
1 g
F P
s
P
p
.002 w
.34117 .52135 m .38143 .5655 L .39011 .55331 L p
1 g
F P
s
P
p
.002 w
.39011 .55331 m .34955 .50872 L .34117 .52135 L p
1 g
F P
s
P
p
.002 w
.44115 .58598 m .39011 .55331 L .38143 .5655 L p
1 g
F P
s
P
p
.002 w
.33718 .33336 m .32711 .38707 L .34402 .37597 L p
1 g
F P
s
P
p
.002 w
.34402 .37597 m .35398 .3244 L .33718 .33336 L p
1 g
F P
s
P
p
.002 w
.49822 .60377 m .44115 .58598 L .43202 .59791 L p
1 g
F P
s
P
p
.002 w
.38143 .5655 m .43202 .59791 L .44115 .58598 L p
1 g
F P
s
P
p
.002 w
.55948 .25483 m .51555 .25074 L .52555 .26547 L p
1 g
F P
s
P
p
.002 w
.52555 .26547 m .56159 .26893 L .55948 .25483 L p
1 g
F P
s
P
p
.002 w
.38195 .2801 m .35398 .3244 L .374 .31847 L p
1 g
F P
s
P
p
.002 w
.374 .31847 m .40036 .27724 L .38195 .2801 L p
1 g
F P
s
P
p
.002 w
.31502 .46922 m .34117 .52135 L .34955 .50872 L p
1 g
F P
s
P
p
.002 w
.34955 .50872 m .32327 .45598 L .31502 .46922 L p
1 g
F P
s
P
p
.002 w
.66958 .38326 m .66004 .34149 L .64398 .33988 L p
1 g
F P
s
P
p
.002 w
.62461 .30849 m .64398 .33988 L .66004 .34149 L p
1 g
F P
s
P
p
.002 w
.49822 .60377 m .55629 .6047 L .56479 .58857 L p
1 g
F P
s
P
p
.002 w
.61757 .57181 m .56479 .58857 L .55629 .6047 L p
1 g
F P
s
P
p
.002 w
.56479 .58857 m .61757 .57181 L .62196 .55256 L p
1 g
F P
s
P
p
.002 w
.4415 .24789 m .40036 .27724 L .42075 .27845 L p
1 g
F P
s
P
p
.002 w
.42075 .27845 m .45802 .25214 L .4415 .24789 L p
1 g
F P
s
P
p
.002 w
.50476 .24027 m .45802 .25214 L .47505 .26086 L p
1 g
F P
s
P
p
.002 w
.47505 .26086 m .51555 .25074 L .50476 .24027 L p
1 g
F P
s
P
p
.002 w
.66294 .52014 m .62196 .55256 L .61757 .57181 L p
1 g
F P
s
P
p
.002 w
.62196 .55256 m .66294 .52014 L .66118 .50025 L p
1 g
F P
s
P
p
.002 w
.60154 .273 m .55948 .25483 L .56159 .26893 L p
1 g
F P
s
P
p
.002 w
.56159 .26893 m .59601 .28383 L .60154 .273 L p
1 g
F P
s
P
p
.002 w
.43202 .59791 m .48853 .61565 L .49822 .60377 L p
1 g
F P
s
P
p
.002 w
.55629 .6047 m .49822 .60377 L .48853 .61565 L p
1 g
F P
s
P
p
.002 w
.66004 .34149 m .63648 .30314 L .62461 .30849 L p
1 g
F P
s
P
p
.002 w
.59601 .28383 m .62461 .30849 L .63648 .30314 L p
1 g
F P
s
P
p
.002 w
.63648 .30314 m .60154 .273 L .59601 .28383 L p
1 g
F P
s
P
p
.002 w
.68556 .45724 m .66118 .50025 L .66294 .52014 L p
1 g
F P
s
P
p
.002 w
.66118 .50025 m .68556 .45724 L .67713 .44018 L p
1 g
F P
s
P
p
.002 w
.67713 .44018 m .68332 .39391 L .66958 .38326 L p
1 g
F P
s
P
p
.002 w
.66004 .34149 m .66958 .38326 L .68332 .39391 L p
1 g
F P
s
P
p
.002 w
.68332 .39391 m .67713 .44018 L .68556 .45724 L p
1 g
F P
s
P
p
.002 w
.3242 .3453 m .31423 .39973 L .32711 .38707 L p
1 g
F P
s
P
p
.002 w
.32711 .38707 m .33718 .33336 L .3242 .3453 L p
1 g
F P
s
P
p
.002 w
.30591 .41369 m .31502 .46922 L .32327 .45598 L p
1 g
F P
s
P
p
.002 w
.32327 .45598 m .31423 .39973 L .30591 .41369 L p
1 g
F P
s
P
p
.002 w
.33673 .53205 m .37557 .57457 L .38143 .5655 L p
1 g
F P
s
P
p
.002 w
.38143 .5655 m .34117 .52135 L .33673 .53205 L p
1 g
F P
s
P
p
.002 w
.43202 .59791 m .38143 .5655 L .37557 .57457 L p
1 g
F P
s
P
p
.002 w
.55568 .24492 m .50476 .24027 L .51555 .25074 L p
1 g
F P
s
P
p
.002 w
.51555 .25074 m .55948 .25483 L .55568 .24492 L p
1 g
F P
s
P
p
.002 w
.36609 .28717 m .33718 .33336 L .35398 .3244 L p
1 g
F P
s
P
p
.002 w
.35398 .3244 m .38195 .2801 L .36609 .28717 L p
1 g
F P
s
P
p
.002 w
.48853 .61565 m .43202 .59791 L .42435 .60583 L p
1 g
F P
s
P
p
.002 w
.37557 .57457 m .42435 .60583 L .43202 .59791 L p
1 g
F P
s
P
p
.002 w
.42595 .24849 m .38195 .2801 L .40036 .27724 L p
1 g
F P
s
P
p
.002 w
.40036 .27724 m .4415 .24789 L .42595 .24849 L p
1 g
F P
s
P
p
.002 w
.31148 .48193 m .33673 .53205 L .34117 .52135 L p
1 g
F P
s
P
p
.002 w
.34117 .52135 m .31502 .46922 L .31148 .48193 L p
1 g
F P
s
P
p
.002 w
.48853 .61565 m .54595 .61675 L .55629 .6047 L p
1 g
F P
s
P
p
.002 w
.60987 .58795 m .55629 .6047 L .54595 .61675 L p
1 g
F P
s
P
p
.002 w
.55629 .6047 m .60987 .58795 L .61757 .57181 L p
1 g
F P
s
P
p
.002 w
.68332 .39391 m .67243 .34556 L .66004 .34149 L p
1 g
F P
s
P
p
.002 w
.63648 .30314 m .66004 .34149 L .67243 .34556 L p
1 g
F P
s
P
p
.002 w
.4934 .23458 m .4415 .24789 L .45802 .25214 L p
1 g
F P
s
P
p
.002 w
.45802 .25214 m .50476 .24027 L .4934 .23458 L p
1 g
F P
s
P
p
.002 w
.66037 .53831 m .61757 .57181 L .60987 .58795 L p
1 g
F P
s
P
p
.002 w
.61757 .57181 m .66037 .53831 L .66294 .52014 L p
1 g
F P
s
P
p
.002 w
.60454 .26598 m .55568 .24492 L .55948 .25483 L p
1 g
F P
s
P
p
.002 w
.55948 .25483 m .60154 .273 L .60454 .26598 L p
1 g
F P
s
P
p
.002 w
.42435 .60583 m .47876 .623 L .48853 .61565 L p
1 g
F P
s
P
p
.002 w
.54595 .61675 m .48853 .61565 L .47876 .623 L p
1 g
F P
s
P
p
.002 w
.68927 .4742 m .66294 .52014 L .66037 .53831 L p
1 g
F P
s
P
p
.002 w
.66294 .52014 m .68927 .4742 L .68556 .45724 L p
1 g
F P
s
P
p
.002 w
.67243 .34556 m .64515 .30102 L .63648 .30314 L p
1 g
F P
s
P
p
.002 w
.60154 .273 m .63648 .30314 L .64515 .30102 L p
1 g
F P
s
P
p
.002 w
.68556 .45724 m .69262 .40595 L .68332 .39391 L p
1 g
F P
s
P
p
.002 w
.67243 .34556 m .68332 .39391 L .69262 .40595 L p
1 g
F P
s
P
p
.002 w
.64515 .30102 m .60454 .26598 L .60154 .273 L p
1 g
F P
s
P
p
.002 w
.69262 .40595 m .68556 .45724 L .68927 .4742 L p
1 g
F P
s
P
p
.002 w
.31562 .36004 m .30591 .41369 L .31423 .39973 L p
1 g
F P
s
P
p
.002 w
.31423 .39973 m .3242 .3453 L .31562 .36004 L p
1 g
F P
s
P
p
.002 w
.30264 .42867 m .31148 .48193 L .31502 .46922 L p
1 g
F P
s
P
p
.002 w
.31502 .46922 m .30591 .41369 L .30264 .42867 L p
1 g
F P
s
P
p
.002 w
.35336 .29851 m .3242 .3453 L .33718 .33336 L p
1 g
F P
s
P
p
.002 w
.33718 .33336 m .36609 .28717 L .35336 .29851 L p
1 g
F P
s
P
p
.002 w
.55017 .2397 m .4934 .23458 L .50476 .24027 L p
1 g
F P
s
P
p
.002 w
.50476 .24027 m .55568 .24492 L .55017 .2397 L p
1 g
F P
s
P
p
.002 w
.33659 .5404 m .37287 .58008 L .37557 .57457 L p
1 g
F P
s
P
p
.002 w
.37557 .57457 m .33673 .53205 L .33659 .5404 L p
1 g
F P
s
P
p
.002 w
.42435 .60583 m .37557 .57457 L .37287 .58008 L p
1 g
F P
s
P
p
.002 w
.47876 .623 m .42435 .60583 L .41843 .60929 L p
1 g
F P
s
P
p
.002 w
.37287 .58008 m .41843 .60929 L .42435 .60583 L p
1 g
F P
s
P
p
.002 w
.41187 .2542 m .36609 .28717 L .38195 .2801 L p
1 g
F P
s
P
p
.002 w
.38195 .2801 m .42595 .24849 L .41187 .2542 L p
1 g
F P
s
P
p
.002 w
.48175 .23412 m .42595 .24849 L .4415 .24789 L p
1 g
F P
s
P
p
.002 w
.4415 .24789 m .4934 .23458 L .48175 .23412 L p
1 g
F P
s
P
p
.002 w
.47876 .623 m .53395 .62416 L .54595 .61675 L p
1 g
F P
s
P
p
.002 w
.59886 .60038 m .54595 .61675 L .53395 .62416 L p
1 g
F P
s
P
p
.002 w
.54595 .61675 m .59886 .60038 L .60987 .58795 L p
1 g
F P
s
P
p
.002 w
.65328 .55419 m .60987 .58795 L .59886 .60038 L p
1 g
F P
s
P
p
.002 w
.60987 .58795 m .65328 .55419 L .66037 .53831 L p
1 g
F P
s
P
p
.002 w
.69262 .40595 m .68059 .35213 L .67243 .34556 L p
1 g
F P
s
P
p
.002 w
.64515 .30102 m .67243 .34556 L .68059 .35213 L p
1 g
F P
s
P
p
.002 w
.31303 .49374 m .33659 .5404 L .33673 .53205 L p
1 g
F P
s
P
p
.002 w
.33673 .53205 m .31148 .48193 L .31303 .49374 L p
1 g
F P
s
P
p
.002 w
.68789 .49059 m .66037 .53831 L .65328 .55419 L p
1 g
F P
s
P
p
.002 w
.66037 .53831 m .68789 .49059 L .68927 .4742 L p
1 g
F P
s
P
p
.002 w
.41843 .60929 m .46917 .62534 L .47876 .623 L p
1 g
F P
s
P
p
.002 w
.53395 .62416 m .47876 .623 L .46917 .62534 L p
1 g
F P
s
P
p
.002 w
.60477 .26323 m .55017 .2397 L .55568 .24492 L p
1 g
F P
s
P
p
.002 w
.55568 .24492 m .60454 .26598 L .60477 .26323 L p
1 g
F P
s
P
p
.002 w
.68927 .4742 m .69697 .41916 L .69262 .40595 L p
1 g
F P
s
P
p
.002 w
.68059 .35213 m .69262 .40595 L .69697 .41916 L p
1 g
F P
s
P
p
.002 w
.69697 .41916 m .68927 .4742 L .68789 .49059 L p
1 g
F P
s
P
p
.002 w
.68059 .35213 m .65016 .3024 L .64515 .30102 L p
1 g
F P
s
P
p
.002 w
.60454 .26598 m .64515 .30102 L .65016 .3024 L p
1 g
F P
s
P
p
.002 w
.31192 .37734 m .30264 .42867 L .30591 .41369 L p
1 g
F P
s
P
p
.002 w
.30591 .41369 m .31562 .36004 L .31192 .37734 L p
1 g
F P
s
P
p
.002 w
.65016 .3024 m .60477 .26323 L .60454 .26598 L p
1 g
F P
s
P
p
.002 w
.34431 .31403 m .31562 .36004 L .3242 .3453 L p
1 g
F P
s
P
p
.002 w
.3242 .3453 m .35336 .29851 L .34431 .31403 L p
1 g
F P
s
P
p
.002 w
.30482 .44428 m .31303 .49374 L .31148 .48193 L p
1 g
F P
s
P
p
.002 w
.31148 .48193 m .30264 .42867 L .30482 .44428 L p
1 g
F P
s
P
p
.004 w
.28715 .63822 m
.31912 .60702 L
s
P
p
.002 w
.543 .23965 m .48175 .23412 L .4934 .23458 L p
1 g
F P
s
P
p
.002 w
.4934 .23458 m .55017 .2397 L .543 .23965 L p
1 g
F P
s
P
p
.002 w
.39973 .26516 m .35336 .29851 L .36609 .28717 L p
1 g
F P
s
P
p
.002 w
.36609 .28717 m .41187 .2542 L .39973 .26516 L p
1 g
F P
s
P
p
.002 w
.34104 .54604 m .37361 .58165 L .37287 .58008 L p
1 g
F P
s
P
p
.002 w
.37287 .58008 m .33659 .5404 L .34104 .54604 L p
1 g
F P
s
P
p
.004 w
.35942 .56769 m
.36017 .56696 L
s
P
p
.004 w
.36045 .56669 m
.5 .43051 L
s
P
p
.004 w
.31912 .60702 m
.35942 .56769 L
s
P
p
.002 w
.41843 .60929 m .37287 .58008 L .37361 .58165 L p
1 g
F P
s
P
p
.002 w
.47014 .23922 m .41187 .2542 L .42595 .24849 L p
1 g
F P
s
P
p
.002 w
.42595 .24849 m .48175 .23412 L .47014 .23922 L p
1 g
F P
s
P
p
.002 w
.37361 .58165 m .41453 .60789 L .41843 .60929 L p
1 g
F P
s
P
p
.002 w
.46917 .62534 m .41843 .60929 L .41453 .60789 L p
1 g
F P
s
P
p
.002 w
.53395 .62416 m .58466 .60854 L .59886 .60038 L p
1 g
F P
s
P
p
.002 w
.59886 .60038 m .64163 .5672 L .65328 .55419 L p
1 g
F P
s
P
p
.002 w
.64163 .5672 m .59886 .60038 L .58466 .60854 L p
1 g
F P
s
P
p
.002 w
.46917 .62534 m .52051 .62645 L .53395 .62416 L p
1 g
F P
s
P
p
.002 w
.58466 .60854 m .53395 .62416 L .52051 .62645 L p
1 g
F P
s
P
p
.002 w
.69697 .41916 m .68402 .36118 L .68059 .35213 L p
1 g
F P
s
P
p
.002 w
.65016 .3024 m .68059 .35213 L .68402 .36118 L p
1 g
F P
s
P
p
.002 w
.31995 .50424 m .34104 .54604 L .33659 .5404 L p
1 g
F P
s
P
p
.002 w
.33659 .5404 m .31303 .49374 L .31995 .50424 L p
1 g
F P
s
P
p
.002 w
.65328 .55419 m .68116 .50593 L .68789 .49059 L p
1 g
F P
s
P
p
.002 w
.68116 .50593 m .65328 .55419 L .64163 .5672 L p
1 g
F P
s
P
p
.002 w
.41453 .60789 m .46004 .62228 L .46917 .62534 L p
1 g
F P
s
P
p
.002 w
.52051 .62645 m .46917 .62534 L .46004 .62228 L p
1 g
F P
s
P
p
.002 w
.68789 .49059 m .69593 .43322 L .69697 .41916 L p
1 g
F P
s
P
p
.002 w
.69593 .43322 m .68789 .49059 L .68116 .50593 L p
1 g
F P
s
P
p
.002 w
.68402 .36118 m .69697 .41916 L .69593 .43322 L p
1 g
F P
s
P
p
.002 w
.60204 .26511 m .543 .23965 L .55017 .2397 L p
1 g
F P
s
P
p
.002 w
.55017 .2397 m .60477 .26323 L .60204 .26511 L p
1 g
F P
s
P
p
.002 w
.3135 .39682 m .30482 .44428 L .30264 .42867 L p
1 g
F P
s
P
p
.002 w
.30264 .42867 m .31192 .37734 L .3135 .39682 L p
1 g
F P
s
P
p
.002 w
.68402 .36118 m .65114 .30748 L .65016 .3024 L p
1 g
F P
s
P
p
.002 w
.60477 .26323 m .65016 .3024 L .65114 .30748 L p
1 g
F P
s
P
p
.002 w
.33942 .33348 m .31192 .37734 L .31562 .36004 L p
1 g
F P
s
P
p
.002 w
.31562 .36004 m .34431 .31403 L .33942 .33348 L p
1 g
F P
s
P
p
.002 w
.65114 .30748 m .60204 .26511 L .60477 .26323 L p
1 g
F P
s
P
p
.002 w
.3127 .4601 m .31995 .50424 L .31303 .49374 L p
1 g
F P
s
P
p
.002 w
.31303 .49374 m .30482 .44428 L .3127 .4601 L p
1 g
F P
s
P
p
.002 w
.39005 .28133 m .34431 .31403 L .35336 .29851 L p
1 g
F P
s
P
p
.002 w
.35336 .29851 m .39973 .26516 L .39005 .28133 L p
1 g
F P
s
P
p
.002 w
.53429 .2451 m .47014 .23922 L .48175 .23412 L p
1 g
F P
s
P
p
.002 w
.48175 .23412 m .543 .23965 L .53429 .2451 L p
1 g
F P
s
P
p
.002 w
.52051 .62645 m .56751 .61194 L .58466 .60854 L p
1 g
F P
s
P
p
.002 w
.62551 .57679 m .58466 .60854 L .56751 .61194 L p
1 g
F P
s
P
p
.002 w
.58466 .60854 m .62551 .57679 L .64163 .5672 L p
1 g
F P
s
P
p
.002 w
.45892 .25009 m .39973 .26516 L .41187 .2542 L p
1 g
F P
s
P
p
.002 w
.41187 .2542 m .47014 .23922 L .45892 .25009 L p
1 g
F P
s
P
p
.002 w
.35024 .5486 m .378 .57897 L .37361 .58165 L p
1 g
F P
s
P
p
.002 w
.37361 .58165 m .34104 .54604 L .35024 .5486 L p
1 g
F P
s
P
p
.002 w
.41453 .60789 m .37361 .58165 L .378 .57897 L p
1 g
F P
s
P
p
.002 w
.46004 .62228 m .50594 .62324 L .52051 .62645 L p
1 g
F P
s
P
p
.002 w
.56751 .61194 m .52051 .62645 L .50594 .62324 L p
1 g
F P
s
P
p
.002 w
.378 .57897 m .4129 .60135 L .41453 .60789 L p
1 g
F P
s
P
p
.002 w
.46004 .62228 m .41453 .60789 L .4129 .60135 L p
1 g
F P
s
P
p
.002 w
.66899 .51968 m .64163 .5672 L .62551 .57679 L p
1 g
F P
s
P
p
.002 w
.64163 .5672 m .66899 .51968 L .68116 .50593 L p
1 g
F P
s
P
p
.002 w
.69593 .43322 m .68233 .37261 L .68402 .36118 L p
1 g
F P
s
P
p
.002 w
.65114 .30748 m .68402 .36118 L .68233 .37261 L p
1 g
F P
s
P
p
.002 w
.33236 .51304 m .35024 .5486 L .34104 .54604 L p
1 g
F P
s
P
p
.002 w
.34104 .54604 m .31995 .50424 L .33236 .51304 L p
1 g
F P
s
P
p
.002 w
.68922 .44776 m .68116 .50593 L .66899 .51968 L p
1 g
F P
s
P
p
.002 w
.68116 .50593 m .68922 .44776 L .69593 .43322 L p
1 g
F P
s
P
p
.002 w
.68233 .37261 m .69593 .43322 L .68922 .44776 L p
1 g
F P
s
P
p
.002 w
.4129 .60135 m .45167 .61357 L .46004 .62228 L p
1 g
F P
s
P
p
.002 w
.50594 .62324 m .46004 .62228 L .45167 .61357 L p
1 g
F P
s
P
p
.002 w
.32059 .41796 m .3127 .4601 L .30482 .44428 L p
1 g
F P
s
P
p
.002 w
.30482 .44428 m .3135 .39682 L .32059 .41796 L p
1 g
F P
s
P
p
.002 w
.59623 .27186 m .53429 .2451 L .543 .23965 L p
1 g
F P
s
P
p
.002 w
.543 .23965 m .60204 .26511 L .59623 .27186 L p
1 g
F P
s
P
p
.002 w
.33909 .35646 m .3135 .39682 L .31192 .37734 L p
1 g
F P
s
P
p
.002 w
.31192 .37734 m .33942 .33348 L .33909 .35646 L p
1 g
F P
s
P
p
.002 w
.68233 .37261 m .64779 .31633 L .65114 .30748 L p
1 g
F P
s
P
p
.002 w
.60204 .26511 m .65114 .30748 L .64779 .31633 L p
1 g
F P
s
P
p
.002 w
.32635 .47564 m .33236 .51304 L .31995 .50424 L p
1 g
F P
s
P
p
.002 w
.31995 .50424 m .3127 .4601 L .32635 .47564 L p
1 g
F P
s
P
p
.002 w
.38326 .30248 m .33942 .33348 L .34431 .31403 L p
1 g
F P
s
P
p
.002 w
.34431 .31403 m .39005 .28133 L .38326 .30248 L p
1 g
F P
s
P
p
.002 w
.64779 .31633 m .59623 .27186 L .60204 .26511 L p
1 g
F P
s
P
p
.002 w
.5242 .25623 m .45892 .25009 L .47014 .23922 L p
1 g
F P
s
P
p
.002 w
.47014 .23922 m .53429 .2451 L .5242 .25623 L p
1 g
F P
s
P
p
.002 w
.50594 .62324 m .54776 .61021 L .56751 .61194 L p
1 g
F P
s
P
p
.002 w
.60515 .58248 m .56751 .61194 L .54776 .61021 L p
1 g
F P
s
P
p
.002 w
.56751 .61194 m .60515 .58248 L .62551 .57679 L p
1 g
F P
s
P
p
.002 w
.44849 .26671 m .39005 .28133 L .39973 .26516 L p
1 g
F P
s
P
p
.002 w
.39973 .26516 m .45892 .25009 L .44849 .26671 L p
1 g
F P
s
P
p
.002 w
.45167 .61357 m .49063 .6143 L .50594 .62324 L p
1 g
F P
s
P
p
.002 w
.54776 .61021 m .50594 .62324 L .49063 .6143 L p
1 g
F P
s
P
p
.002 w
.65144 .53133 m .62551 .57679 L .60515 .58248 L p
1 g
F P
s
P
p
.002 w
.62551 .57679 m .65144 .53133 L .66899 .51968 L p
1 g
F P
s
P
p
.002 w
.36422 .54781 m .38613 .57184 L .378 .57897 L p
1 g
F P
s
P
p
.002 w
.378 .57897 m .35024 .5486 L .36422 .54781 L p
1 g
F P
s
P
p
.002 w
.4129 .60135 m .378 .57897 L .38613 .57184 L p
1 g
F P
s
P
p
.002 w
.45167 .61357 m .4129 .60135 L .41375 .58953 L p
1 g
F P
s
P
p
.002 w
.38613 .57184 m .41375 .58953 L .4129 .60135 L p
1 g
F P
s
P
p
.002 w
.68922 .44776 m .67524 .38619 L .68233 .37261 L p
1 g
F P
s
P
p
.002 w
.64779 .31633 m .68233 .37261 L .67524 .38619 L p
1 g
F P
s
P
p
.002 w
.67672 .46235 m .66899 .51968 L .65144 .53133 L p
1 g
F P
s
P
p
.002 w
.66899 .51968 m .67672 .46235 L .68922 .44776 L p
1 g
F P
s
P
p
.002 w
.3502 .51974 m .36422 .54781 L .35024 .5486 L p
1 g
F P
s
P
p
.002 w
.35024 .5486 m .33236 .51304 L .3502 .51974 L p
1 g
F P
s
P
p
.002 w
.67524 .38619 m .68922 .44776 L .67672 .46235 L p
1 g
F P
s
P
p
.002 w
.33323 .44015 m .32635 .47564 L .3127 .4601 L p
1 g
F P
s
P
p
.002 w
.3127 .4601 m .32059 .41796 L .33323 .44015 L p
1 g
F P
s
P
p
.002 w
.34353 .38236 m .32059 .41796 L .3135 .39682 L p
1 g
F P
s
P
p
.002 w
.3135 .39682 m .33909 .35646 L .34353 .38236 L p
1 g
F P
s
P
p
.002 w
.41375 .58953 m .44438 .59914 L .45167 .61357 L p
1 g
F P
s
P
p
.002 w
.49063 .6143 m .45167 .61357 L .44438 .59914 L p
1 g
F P
s
P
p
.002 w
.58732 .28359 m .5242 .25623 L .53429 .2451 L p
1 g
F P
s
P
p
.002 w
.53429 .2451 m .59623 .27186 L .58732 .28359 L p
1 g
F P
s
P
p
.002 w
.37976 .32814 m .33909 .35646 L .33942 .33348 L p
1 g
F P
s
P
p
.002 w
.33942 .33348 m .38326 .30248 L .37976 .32814 L p
1 g
F P
s
P
p
.002 w
.34563 .49036 m .3502 .51974 L .33236 .51304 L p
1 g
F P
s
P
p
.002 w
.33236 .51304 m .32635 .47564 L .34563 .49036 L p
1 g
F P
s
P
p
.002 w
.67524 .38619 m .63994 .32893 L .64779 .31633 L p
1 g
F P
s
P
p
.002 w
.59623 .27186 m .64779 .31633 L .63994 .32893 L p
1 g
F P
s
P
p
.002 w
.49063 .6143 m .52592 .60313 L .54776 .61021 L p
1 g
F P
s
P
p
.002 w
.58102 .58388 m .54776 .61021 L .52592 .60313 L p
1 g
F P
s
P
p
.002 w
.54776 .61021 m .58102 .58388 L .60515 .58248 L p
1 g
F P
s
P
p
.002 w
.63994 .32893 m .58732 .28359 L .59623 .27186 L p
1 g
F P
s
P
p
.002 w
.43925 .28883 m .38326 .30248 L .39005 .28133 L p
1 g
F P
s
P
p
.002 w
.39005 .28133 m .44849 .26671 L .43925 .28883 L p
1 g
F P
s
P
p
.002 w
.513 .27301 m .44849 .26671 L .45892 .25009 L p
1 g
F P
s
P
p
.002 w
.45892 .25009 m .5242 .25623 L .513 .27301 L p
1 g
F P
s
P
p
.002 w
.62882 .54039 m .60515 .58248 L .58102 .58388 L p
1 g
F P
s
P
p
.002 w
.60515 .58248 m .62882 .54039 L .65144 .53133 L p
1 g
F P
s
P
p
.002 w
.44438 .59914 m .47504 .5996 L .49063 .6143 L p
1 g
F P
s
P
p
.002 w
.52592 .60313 m .49063 .6143 L .47504 .5996 L p
1 g
F P
s
P
p
.002 w
.65851 .47651 m .65144 .53133 L .62882 .54039 L p
1 g
F P
s
P
p
.002 w
.65144 .53133 m .65851 .47651 L .67672 .46235 L p
1 g
F P
s
P
p
.002 w
.38279 .54349 m .39799 .56022 L .38613 .57184 L p
1 g
F P
s
P
p
.002 w
.38613 .57184 m .36422 .54781 L .38279 .54349 L p
1 g
F P
s
P
p
.002 w
.41375 .58953 m .38613 .57184 L .39799 .56022 L p
1 g
F P
s
P
p
.002 w
.39799 .56022 m .4172 .57251 L .41375 .58953 L p
1 g
F P
s
P
p
.002 w
.44438 .59914 m .41375 .58953 L .4172 .57251 L p
1 g
F P
s
P
p
.002 w
.67672 .46235 m .66267 .40161 L .67524 .38619 L p
1 g
F P
s
P
p
.002 w
.63994 .32893 m .67524 .38619 L .66267 .40161 L p
1 g
F P
s
P
p
.002 w
.35282 .41041 m .33323 .44015 L .32059 .41796 L p
1 g
F P
s
P
p
.002 w
.32059 .41796 m .34353 .38236 L .35282 .41041 L p
1 g
F P
s
P
p
.002 w
.66267 .40161 m .67672 .46235 L .65851 .47651 L p
1 g
F P
s
P
p
.002 w
.37315 .524 m .38279 .54349 L .36422 .54781 L p
1 g
F P
s
P
p
.002 w
.36422 .54781 m .3502 .51974 L .37315 .524 L p
1 g
F P
s
P
p
.002 w
.35125 .46268 m .34563 .49036 L .32635 .47564 L p
1 g
F P
s
P
p
.002 w
.32635 .47564 m .33323 .44015 L .35125 .46268 L p
1 g
F P
s
P
p
.002 w
.4172 .57251 m .43848 .57913 L .44438 .59914 L p
1 g
F P
s
P
p
.002 w
.47504 .5996 m .44438 .59914 L .43848 .57913 L p
1 g
F P
s
P
p
.002 w
.3798 .35762 m .34353 .38236 L .33909 .35646 L p
1 g
F P
s
P
p
.002 w
.33909 .35646 m .37976 .32814 L .3798 .35762 L p
1 g
F P
s
P
p
.002 w
.57545 .3002 m .513 .27301 L .5242 .25623 L p
1 g
F P
s
P
p
.002 w
.5242 .25623 m .58732 .28359 L .57545 .3002 L p
1 g
F P
s
P
p
.002 w
.47504 .5996 m .50262 .59066 L .52592 .60313 L p
1 g
F P
s
P
p
.002 w
.55374 .58074 m .52592 .60313 L .50262 .59066 L p
1 g
F P
s
P
p
.002 w
.52592 .60313 m .55374 .58074 L .58102 .58388 L p
1 g
F P
s
P
p
.002 w
.37014 .50372 m .37315 .524 L .3502 .51974 L p
1 g
F P
s
P
p
.002 w
.3502 .51974 m .34563 .49036 L .37014 .50372 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.60166 .54641 m .58102 .58388 L .55374 .58074 L p
1 g
F P
s
P
p
.002 w
.58102 .58388 m .60166 .54641 L .62882 .54039 L p
1 g
F P
s
P
p
.002 w
.43157 .31592 m .37976 .32814 L .38326 .30248 L p
1 g
F P
s
P
p
.002 w
.38326 .30248 m .43925 .28883 L .43157 .31592 L p
1 g
F P
s
P
p
.002 w
.66267 .40161 m .62758 .34506 L .63994 .32893 L p
1 g
F P
s
P
p
.002 w
.58732 .28359 m .63994 .32893 L .62758 .34506 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.50103 .29515 m .43925 .28883 L .44849 .26671 L p
1 g
F P
s
P
p
.002 w
.44849 .26671 m .513 .27301 L .50103 .29515 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.43848 .57913 m .45969 .57934 L .47504 .5996 L p
1 g
F P
s
P
p
.002 w
.50262 .59066 m .47504 .5996 L .45969 .57934 L p
1 g
F P
s
P
p
.002 w
.62758 .34506 m .57545 .3002 L .58732 .28359 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.63496 .48972 m .62882 .54039 L .60166 .54641 L p
1 g
F P
s
P
p
.002 w
.62882 .54039 m .63496 .48972 L .65851 .47651 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.36679 .43969 m .35125 .46268 L .33323 .44015 L p
1 g
F P
s
P
p
.002 w
.33323 .44015 m .35282 .41041 L .36679 .43969 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.3742 .48475 m .37014 .50372 L .34563 .49036 L p
1 g
F P
s
P
p
.002 w
.34563 .49036 m .35125 .46268 L .3742 .48475 L p
1 g
F P
s
P
p
.002 w
.65851 .47651 m .64474 .41844 L .66267 .40161 L p
1 g
F P
s
P
p
.002 w
.62758 .34506 m .66267 .40161 L .64474 .41844 L p
1 g
F P
s
P
p
.002 w
.64474 .41844 m .65851 .47651 L .63496 .48972 L p
1 g
F P
s
P
p
.002 w
.40556 .5356 m .41338 .54423 L .39799 .56022 L p
1 g
F P
s
P
p
.002 w
.39799 .56022 m .38279 .54349 L .40556 .5356 L p
1 g
F P
s
P
p
.002 w
.4172 .57251 m .39799 .56022 L .41338 .54423 L p
1 g
F P
s
P
p
.004 w
.39101 .58056 m
.40346 .56341 L
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.41338 .54423 m .42328 .55056 L .4172 .57251 L p
1 g
F P
s
P
p
.002 w
.43848 .57913 m .4172 .57251 L .42328 .55056 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.38352 .38998 m .35282 .41041 L .34353 .38236 L p
1 g
F P
s
P
p
.002 w
.34353 .38236 m .3798 .35762 L .38352 .38998 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.40066 .52556 m .40556 .5356 L .38279 .54349 L p
1 g
F P
s
P
p
.002 w
.38279 .54349 m .37315 .524 L .40066 .52556 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.42328 .55056 m .43425 .55393 L .43848 .57913 L p
1 g
F P
s
P
p
.002 w
.45969 .57934 m .43848 .57913 L .43425 .55393 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.50262 .59066 m .49485 .58861 L .47054 .57571 L 1 g
F
P
p
.002 w
.45969 .57934 m .46987 .57594 L p
.49485 .58861 L 1 g
F P
s
P
p
.002 w
.46987 .57594 m .47054 .57571 L p
.49485 .58861 L 1 g
F P
s
P
p
.002 w
.43425 .55393 m .43785 .55395 L p
.45969 .57934 L 1 g
F P
s
P
p
.002 w
.43785 .55395 m .44287 .55396 L p
.45015 .56273 L 1 g
F P
s
P
p
.002 w
.44967 .56189 m .45015 .56273 L p
.44287 .55396 L 1 g
F P
s
P
p
.002 w
.45015 .56273 m .45969 .57934 L p
.43785 .55395 L 1 g
F P
s
P
p
.45146 .56129 m .44264 .55363 L .44967 .56189 L 1 g
F
P
p
.002 w
.43425 .55393 m .43314 .53984 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.44287 .55396 m .44045 .55395 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.44045 .55395 m .43425 .55393 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.43834 .54738 m .43925 .54566 L p
.43524 .53772 L 1 g
F P
s
P
p
.44264 .55363 m .44287 .55396 L .44967 .56189 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4324 .52889 L p
1 g
F P
s
P
p
.43925 .54566 m .4324 .52889 L .43524 .53772 L 1 g
F
P
p
.4325 .52581 m .43248 .52628 L .43192 .52424 L 1 g
F
P
p
.002 w
.43314 .53984 m .43224 .5284 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.4324 .52889 m .43346 .52734 L p
.43313 .51793 L 1 g
F P
s
P
p
.43313 .51793 m .43308 .51851 L .4324 .52889 L 1 g
F
P
p
.43313 .51778 m .43302 .51903 L .4324 .52889 L 1 g
F
P
p
.43312 .51746 m .43294 .51954 L .4324 .52889 L 1 g
F
P
p
.002 w
.43267 .52299 m .43192 .52424 L .43331 .51597 L p
1 g
F P
s
P
p
.002 w
.43331 .51597 m .43192 .52424 L p
.43348 .51031 L 1 g
F P
s
P
p
.43553 .49199 m .43392 .50936 L .43348 .51031 L 1 g
F
P
p
.43392 .50936 m .43331 .51597 L .43348 .51031 L 1 g
F
P
p
.002 w
.43192 .52424 m .42602 .49063 L .43553 .49199 L p
1 g
F P
s
P
p
.002 w
.43392 .50936 m .43485 .50826 L p
.43867 .49934 L 1 g
F P
s
P
p
.002 w
.43732 .49225 m .44118 .49402 L p
.43511 .50686 L 1 g
F P
s
P
p
.43867 .49934 m .43471 .5077 L .43392 .50936 L 1 g
F
P
p
.43288 .52063 m .43278 .52177 L .4324 .52889 L 1 g
F
P
p
.43307 .51621 m .43277 .52097 L .4324 .52889 L 1 g
F
P
p
.43304 .51525 m .43267 .52209 L .4324 .52889 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43331 .51597 m .43471 .5077 L p
.43267 .52299 L 1 g
F P
s
P
p
.002 w
.43471 .5077 m .43732 .49225 L p
.43511 .50686 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44245 .4915 L p
1 g
F P
s
P
p
.44691 .48262 m .44245 .4915 L .43732 .49225 L 1 g
F
P
p
.002 w
.44118 .49402 m .44028 .49361 L p
.44245 .4915 L 1 g
F P
s
P
p
.002 w
.44028 .49361 m .43732 .49225 L p
.44245 .4915 L 1 g
F P
s
P
p
.002 w
.44245 .4915 m .44166 .49233 L p
.43956 .49726 L 1 g
F P
s
P
p
.43485 .50826 m .44245 .4915 L .43956 .49726 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44245 .4915 m .44339 .4905 L p
.45022 .48396 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44817 .49723 m .44118 .49402 L p
.44245 .4915 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45767 .47673 L p
1 g
F P
s
P
p
.44339 .4905 m .45767 .47673 L .45022 .48396 L 1 g
F
P
p
.44691 .48262 m .44727 .48682 L .44245 .4915 L 1 g
F
P
p
.44727 .48682 m .44817 .49723 L .44245 .4915 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45767 .47673 m .45826 .47608 L p
.4697 .47107 L 1 g
F P
s
P
p
.46499 .47329 m .45737 .50502 L .46201 .4747 L 1 g
F
P
p
.4697 .47107 m .46201 .4747 L .45767 .47673 L 1 g
F
P
p
.002 w
.48461 .48313 m .45737 .50502 L p
.46499 .47329 L 1 g
F P
s
P
p
.002 w
.47015 .47085 m .48461 .48313 L p
.46499 .47329 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47756 .46717 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48461 .48313 m .47015 .47085 L p
.47756 .46717 L 1 g
F P
s
P
p
.002 w
.47756 .46717 m .47786 .46667 L p
.48773 .46567 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46385 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46385 L .48773 .46567 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51261 .45936 m .54027 .43464 L p
.53451 .46867 L 1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54225 .47664 L p
1 g
F P
s
P
p
.53384 .47262 m .53125 .4879 L .52243 .46715 L 1 g
F
P
p
.52214 .46667 m .54225 .47664 L .53095 .47123 L 1 g
F
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56604 .50932 L p
1 g
F P
s
P
p
.002 w
.57452 .51127 m .5677 .51272 L p
.56604 .50932 L 1 g
F P
s
P
p
.55758 .49193 m .56503 .50043 L .56604 .50932 L 1 g
F
P
p
.56503 .50043 m .57452 .51127 L .56604 .50932 L 1 g
F
P
p
.002 w
.56604 .50932 m .56515 .50826 L p
.56674 .51859 L 1 g
F P
s
P
p
.57452 .51127 m .56829 .54899 L .56724 .52836 L 1 g
F
P
p
.57143 .51431 m .56724 .52836 L .56676 .51891 L 1 g
F
P
p
.57452 .51127 m .56724 .52836 L .57143 .51431 L 1 g
F
P
p
.002 w
.56724 .52836 m .56654 .52734 L p
.56496 .53601 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5616 .54726 L p
1 g
F P
s
P
p
.56724 .52836 m .56773 .53807 L .56397 .5393 L 1 g
F
P
p
.002 w
.56829 .54899 m .56059 .54878 L p
.56773 .53807 L 1 g
F P
s
P
p
.56654 .52734 m .5616 .54726 L .56496 .53601 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54899 .56251 L p
1 g
F P
s
P
p
.57074 .54906 m .53725 .57641 L .54899 .56251 L 1 g
F
P
p
.56064 .55424 m .54899 .56251 L .5524 .55847 L 1 g
F
P
p
.57074 .54906 m .54899 .56251 L .56064 .55424 L 1 g
F
P
p
.002 w
.54899 .56251 m .54854 .56129 L p
.54223 .56731 L 1 g
F P
s
P
p
.56075 .54566 m .54899 .56251 L .5557 .55456 L 1 g
F
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58058 L p
1 g
F P
s
P
p
.002 w
.50262 .59066 m .49404 .58436 L p
.51094 .58058 L 1 g
F P
s
P
p
.002 w
.51636 .57937 m .51491 .58056 L p
.51094 .58058 L 1 g
F P
s
P
p
.002 w
.51491 .58056 m .50262 .59066 L p
.51094 .58058 L 1 g
F P
s
P
p
.002 w
.51094 .58058 m .51079 .57862 L p
.50074 .58063 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .58058 L .51636 .57937 L 1 g
F
P
p
.002 w
.53142 .57488 m .53152 .5749 L p
.51636 .57937 L 1 g
F P
s
P
p
.002 w
.53152 .5749 m .55374 .58074 L p
.52271 .5796 L 1 g
F P
s
P
p
.52271 .5796 m .51636 .57937 L .53152 .5749 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53174 .57475 L p
1 g
F P
s
P
p
.54854 .56129 m .53174 .57475 L .53217 .57444 L 1 g
F
P
p
.002 w
.53725 .57641 m .53152 .5749 L p
.53174 .57475 L 1 g
F P
s
P
p
.54899 .56251 m .54239 .57032 L .53174 .57475 L 1 g
F
P
p
.54239 .57032 m .53725 .57641 L .53174 .57475 L 1 g
F
P
p
.002 w
.50262 .59066 m .51636 .57937 L p
.55374 .58074 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51365 .58226 L p
.53128 .57265 L 1 g
F P
s
P
p
.002 w
.53174 .57475 m .53128 .57265 L p
.51365 .58226 L 1 g
F P
s
P
p
.54223 .56731 m .53175 .57478 L .53773 .57159 L 1 g
F
P
p
.54854 .56129 m .53217 .57444 L .54223 .56731 L 1 g
F
P
p
.53217 .57444 m .53175 .57478 L .54223 .56731 L 1 g
F
P
p
.53128 .57265 m .51636 .57937 L .52072 .57807 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53152 .5749 m .52415 .57297 L p
.54899 .56251 L 1 g
F P
s
P
p
.002 w
.51365 .58226 m .5322 .57686 L .53174 .57475 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.5524 .55847 m .54899 .56251 L .52415 .57297 L 1 g
F
P
p
.002 w
.53174 .57475 m .53175 .57478 L p
.53217 .57444 L 1 g
F P
s
P
p
.002 w
.53175 .57478 m .5322 .57686 L p
.53773 .57159 L 1 g
F P
s
P
p
.52072 .57807 m .51636 .57937 L .5196 .57864 L 1 g
F
P
p
.002 w
.51636 .57937 m .52415 .57297 L .53142 .57488 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58069 L p
1 g
F P
s
P
p
.51094 .58058 m .5 .58302 L .49494 .58066 L 1 g
F
P
p
.002 w
.49404 .58436 m .48905 .58069 L p
.5 .58302 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58069 L .50074 .58063 L 1 g
F
P
p
.48921 .57862 m .4779 .57769 L .48905 .58069 L 1 g
F
P
p
.002 w
.48906 .58069 m .48921 .57862 L p
.48905 .58069 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46824 .57484 L p
1 g
F P
s
P
p
.46824 .57484 m .46379 .57797 L .45849 .57116 L 1 g
F
P
p
.002 w
.47054 .57571 m .46987 .57594 L p
.46824 .57484 L 1 g
F P
s
P
p
.002 w
.46987 .57594 m .46379 .57797 L p
.46824 .57484 L 1 g
F P
s
P
p
.002 w
.46824 .57484 m .46872 .57265 L p
.4616 .5704 L 1 g
F P
s
P
p
.002 w
.48905 .58069 m .48905 .58069 L p
.47054 .57571 L 1 g
F P
s
P
p
.002 w
.48905 .58069 m .50262 .59066 L p
.47978 .58002 L 1 g
F P
s
P
p
.47978 .58002 m .47054 .57571 L .48905 .58069 L 1 g
F
P
p
.48921 .57862 m .48528 .57791 L .48587 .57835 L 1 g
F
P
p
.48528 .57791 m .46824 .57484 L .48587 .57835 L 1 g
F
P
p
.48587 .57835 m .46824 .57484 L .47517 .57747 L 1 g
F
P
p
.002 w
.48905 .58069 m .47862 .57302 L p
.49494 .58066 L 1 g
F P
s
P
p
.5 .58302 m .48906 .58069 L .49494 .58066 L 1 g
F
P
p
.48906 .58069 m .48905 .58069 L .49494 .58066 L 1 g
F
P
p
.002 w
.48906 .58069 m .48906 .58069 L p
.50074 .58063 L 1 g
F P
s
P
p
.002 w
.48906 .58069 m .48889 .583 L p
.49744 .58129 L 1 g
F P
s
P
p
.50074 .58063 m .48906 .58069 L .49744 .58129 L 1 g
F
P
p
.002 w
.45077 .56314 m .45146 .56129 L p
.44967 .56189 L 1 g
F P
s
P
p
.46872 .57265 m .45941 .56893 L .4616 .5704 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46824 .57484 m .45849 .57116 L .45388 .56523 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56314 L p
1 g
F P
s
P
p
.002 w
.46379 .57797 m .45969 .57934 L .45015 .56273 L p
1 g
F P
s
P
p
.46379 .57797 m .45015 .56273 L .45077 .56314 L 1 g
F
P
p
.46872 .57265 m .45077 .56314 L .45941 .56893 L 1 g
F
P
p
.002 w
.44967 .56189 m .44512 .55397 L p
.46379 .57797 L 1 g
F P
s
P
p
.002 w
.45077 .56314 m .45002 .56518 L p
.45941 .56893 L 1 g
F P
s
P
p
.002 w
.45015 .56273 m .44967 .56189 L p
.45077 .56314 L 1 g
F P
s
P
p
.47054 .57571 m .46824 .57484 L .44512 .55397 L 1 g
F
P
p
.46824 .57484 m .45388 .56523 L .44512 .55397 L 1 g
F
P
p
.4616 .5704 m .45812 .56841 L .46034 .57 L 1 g
F
P
p
.45941 .56893 m .45812 .56841 L .4616 .5704 L 1 g
F
P
p
.002 w
.46819 .57508 m .46824 .57484 L p
.45458 .56818 L 1 g
F P
s
P
p
.4616 .5704 m .45458 .56818 L .46824 .57484 L 1 g
F
P
p
.002 w
.46824 .57484 m .4678 .57686 L p
.47517 .57747 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47862 .57302 m .47054 .57571 L p
.44512 .55397 L 1 g
F P
s
P
p
.51636 .57937 m .51094 .58058 L .47862 .57302 L 1 g
F
P
p
.51094 .58058 m .49494 .58066 L .47862 .57302 L 1 g
F
P
p
.002 w
.48906 .58069 m .48906 .58069 L p
.48905 .58069 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58058 L p
1 g
F P
s
P
p
.50074 .58063 m .48889 .583 L .51094 .58058 L 1 g
F
P
p
.002 w
.51094 .58058 m .51111 .583 L p
.5196 .57864 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52415 .57297 m .51636 .57937 L p
.47862 .57302 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54899 .56251 L p
1 g
F P
s
P
p
.54223 .56731 m .5322 .57686 L .54899 .56251 L 1 g
F
P
p
.56075 .54566 m .5557 .55456 L .5561 .5541 L 1 g
F
P
p
.55836 .55541 m .5524 .55847 L .56114 .5488 L 1 g
F
P
p
.002 w
.5617 .54746 m .56075 .54566 L p
.5561 .5541 L 1 g
F P
s
P
p
.5524 .55847 m .52415 .57297 L .55987 .54963 L 1 g
F
P
p
.5524 .55847 m .55987 .54963 L .56114 .5488 L 1 g
F
P
p
.002 w
.56059 .54878 m .56114 .5488 L p
.55987 .54963 L 1 g
F P
s
P
p
.002 w
.56114 .5488 m .57074 .54906 L p
.55836 .55541 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5617 .54746 L p
1 g
F P
s
P
p
.5561 .5541 m .54998 .56518 L .5617 .54746 L 1 g
F
P
p
.5561 .5541 m .54987 .56486 L .55157 .5623 L 1 g
F
P
p
.5557 .55456 m .54987 .56486 L .5561 .5541 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.52415 .57297 m .53707 .54814 L .56059 .54878 L p
1 g
F P
s
P
p
.55987 .54963 m .52415 .57297 L .56059 .54878 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56059 .54878 m .53707 .54814 L p
.56397 .5393 L 1 g
F P
s
P
p
.56773 .53807 m .5616 .54726 L .56397 .5393 L 1 g
F
P
p
.5616 .54726 m .56059 .54878 L .56397 .5393 L 1 g
F
P
p
.002 w
.5616 .54726 m .5617 .54746 L p
.56496 .53601 L 1 g
F P
s
P
p
.002 w
.5617 .54746 m .56257 .5491 L p
.56376 .54256 L 1 g
F P
s
P
p
.56496 .53601 m .5617 .54746 L .56376 .54256 L 1 g
F
P
p
.002 w
.54899 .56251 m .54987 .56486 L p
.5557 .55456 L 1 g
F P
s
P
p
.002 w
.57074 .54906 m .55374 .58074 L .53725 .57641 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56724 .52836 L p
1 g
F P
s
P
p
.002 w
.56646 .51298 m .57452 .51127 L p
.56676 .51891 L 1 g
F P
s
P
p
.002 w
.56724 .52836 m .56854 .53025 L p
.56674 .51859 L 1 g
F P
s
P
p
.56515 .50826 m .56724 .52836 L .56674 .51859 L 1 g
F
P
p
.56674 .51859 m .56646 .51298 L .56604 .50932 L 1 g
F
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53707 .54814 m .53965 .51869 L .56646 .51298 L p
1 g
F P
s
P
p
.56676 .51891 m .53707 .54814 L .56646 .51298 L 1 g
F
P
p
.56676 .51891 m .56724 .52836 L .53707 .54814 L 1 g
F
P
p
.56724 .52836 m .56397 .5393 L .53707 .54814 L 1 g
F
P
p
.002 w
.54987 .56486 m .54998 .56518 L p
.55157 .5623 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56724 .52836 L p
1 g
F P
s
P
p
.56496 .53601 m .56257 .5491 L .56724 .52836 L 1 g
F
P
p
.56674 .51859 m .56811 .52749 L .56646 .51298 L 1 g
F
P
p
.002 w
.57452 .51127 m .57074 .54906 L .56829 .54899 L p
1 g
F P
s
P
p
.55661 .4905 m .56604 .50932 L .56055 .49804 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55717 .4911 m .55661 .4905 L p
.56055 .49804 L 1 g
F P
s
P
p
.002 w
.57333 .50673 m .57452 .51127 L p
.55503 .48903 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55717 .4911 L p
1 g
F P
s
P
p
.56055 .49804 m .56713 .51061 L .55717 .4911 L 1 g
F
P
p
.002 w
.5641 .47154 m .57333 .50673 L p
.55717 .4911 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55717 .4911 L p
1 g
F P
s
P
p
.54174 .47608 m .55717 .4911 L .55042 .48456 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55562 .4879 m .55717 .4911 L .55503 .48903 L 1 g
F
P
p
.5641 .47154 m .55717 .4911 L .55562 .4879 L 1 g
F
P
p
.002 w
.5677 .51272 m .53965 .51869 L p
.55758 .49193 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56604 .50932 L p
1 g
F P
s
P
p
.56811 .52749 m .56854 .53025 L .56604 .50932 L 1 g
F
P
p
.002 w
.56604 .50932 m .56713 .51061 L p
.56055 .49804 L 1 g
F P
s
P
p
.55503 .48903 m .55758 .49193 L .53965 .51869 L 1 g
F
P
p
.002 w
.53965 .51869 m .53125 .4879 L .54618 .48047 L p
1 g
F P
s
P
p
.54174 .47608 m .55042 .48456 L .54932 .48351 L 1 g
F
P
p
.55503 .48903 m .53965 .51869 L .54618 .48047 L 1 g
F
P
p
.002 w
.54618 .48047 m .53125 .4879 L p
.53384 .47262 L 1 g
F P
s
P
p
.53445 .46904 m .54225 .47664 L .53384 .47262 L 1 g
F
P
p
.54225 .47664 m .54618 .48047 L .53384 .47262 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46715 L p
1 g
F P
s
P
p
.002 w
.52243 .46715 m .52214 .46667 L p
.53095 .47123 L 1 g
F P
s
P
p
.53095 .47123 m .54302 .47747 L .52243 .46715 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54618 .48047 m .5641 .47154 L p
.55503 .48903 L 1 g
F P
s
P
p
.54932 .48351 m .55803 .49201 L .55334 .48744 L 1 g
F
P
p
.55042 .48456 m .55803 .49201 L .54932 .48351 L 1 g
F
P
p
.002 w
.55717 .4911 m .55803 .49201 L p
.55042 .48456 L 1 g
F P
s
P
p
.002 w
.54027 .43464 m .5641 .47154 L .54618 .48047 L p
1 g
F P
s
P
p
.54027 .43464 m .54618 .48047 L .53445 .46904 L 1 g
F
P
p
.002 w
.55803 .49201 m .55834 .49233 L p
.55334 .48744 L 1 g
F P
s
P
p
.002 w
.54225 .47664 m .54302 .47747 L p
.53095 .47123 L 1 g
F P
s
P
p
.002 w
.53125 .4879 m .51727 .46651 L p
.52243 .46715 L 1 g
F P
s
P
p
.53451 .46867 m .53384 .47262 L .52243 .46715 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46715 L p
1 g
F P
s
P
p
.5 .4634 m .52243 .46715 L .52004 .46685 L 1 g
F
P
p
.5 .4634 m .52251 .46728 L .5148 .46614 L 1 g
F
P
p
.002 w
.51727 .46651 m .51261 .45936 L p
.53451 .46867 L 1 g
F P
s
P
p
.002 w
.52243 .46715 m .52251 .46728 L p
.52004 .46685 L 1 g
F P
s
P
p
.002 w
.53125 .4879 m .49741 .50249 L p
.51045 .4655 L 1 g
F P
s
P
p
.5 .4634 m .5148 .46614 L .51247 .4658 L 1 g
F
P
p
.002 w
.51727 .46651 m .53125 .4879 L p
.51045 .4655 L 1 g
F P
s
P
p
.002 w
.49741 .50249 m .48461 .48313 L .50613 .46486 L p
1 g
F P
s
P
p
.51045 .4655 m .49741 .50249 L .50613 .46486 L 1 g
F
P
p
.002 w
.50613 .46486 m .48461 .48313 L p
.48516 .46139 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51261 .45936 m .51727 .46651 L p
.51045 .4655 L 1 g
F P
s
P
p
.51247 .4658 m .52271 .4676 L .51674 .46662 L 1 g
F
P
p
.5148 .46614 m .52271 .4676 L .51247 .4658 L 1 g
F
P
p
.002 w
.52251 .46728 m .52271 .4676 L p
.5148 .46614 L 1 g
F P
s
P
p
.002 w
.50613 .46486 m .51261 .45936 L p
.51045 .4655 L 1 g
F P
s
P
p
.002 w
.48579 .43653 m .51261 .45936 L .50613 .46486 L p
1 g
F P
s
P
p
.48579 .43653 m .50613 .46486 L .48516 .46139 L 1 g
F
P
p
.002 w
.52271 .4676 m .52282 .46778 L p
.51674 .46662 L 1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .46442 L p
.48773 .46567 L 1 g
F P
s
P
p
.48511 .46343 m .47756 .46717 L .46636 .46763 L 1 g
F
P
p
.45826 .47608 m .47756 .46717 L .46988 .47099 L 1 g
F
P
p
.002 w
.47015 .47085 m .46757 .46866 L p
.47756 .46717 L 1 g
F P
s
P
p
.002 w
.46757 .46866 m .46636 .46763 L p
.47756 .46717 L 1 g
F P
s
P
p
.48511 .46343 m .48504 .46606 L .47756 .46717 L 1 g
F
P
p
.48504 .46606 m .48461 .48313 L .47756 .46717 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46717 L p
1 g
F P
s
P
p
.48773 .46567 m .5 .46442 L .47756 .46717 L 1 g
F
P
p
.002 w
.47756 .46717 m .47718 .46778 L p
.46988 .47099 L 1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46636 .46763 m .48579 .43653 L p
.48511 .46343 L 1 g
F P
s
P
p
.002 w
.46636 .46763 m .47015 .47085 L p
.46499 .47329 L 1 g
F P
s
P
p
.002 w
.45737 .50502 m .44817 .49723 L .46201 .4747 L p
1 g
F P
s
P
p
.002 w
.46201 .4747 m .44817 .49723 L p
.44684 .48178 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45762 .47678 L p
1 g
F P
s
P
p
.002 w
.45762 .47678 m .45767 .47673 L p
.45964 .47582 L 1 g
F P
s
P
p
.45964 .47582 m .47718 .46778 L .45762 .47678 L 1 g
F
P
p
.4697 .47107 m .47154 .47026 L .46201 .4747 L 1 g
F
P
p
.002 w
.46201 .4747 m .46636 .46763 L p
.46499 .47329 L 1 g
F P
s
P
p
.002 w
.44476 .45779 m .46636 .46763 L .46201 .4747 L p
1 g
F P
s
P
p
.44476 .45779 m .46201 .4747 L .44684 .48178 L 1 g
F
P
p
.47154 .47026 m .47718 .46778 L .45767 .47673 L 1 g
F
P
p
.002 w
.45767 .47673 m .45698 .47747 L p
.45022 .48396 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44245 .4915 L p
1 g
F P
s
P
p
.45022 .48396 m .45698 .47747 L .44245 .4915 L 1 g
F
P
p
.002 w
.43732 .49225 m .44476 .45779 L p
.44691 .48262 L 1 g
F P
s
P
p
.43511 .50686 m .43267 .52299 L .43471 .5077 L 1 g
F
P
p
.002 w
.43553 .49199 m .43732 .49225 L .43471 .5077 L p
1 g
F P
s
P
p
.002 w
.43471 .5077 m .43331 .51597 L p
.43392 .50936 L 1 g
F P
s
P
p
.43553 .49199 m .43471 .5077 L .43392 .50936 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43392 .50937 L p
1 g
F P
s
P
p
.002 w
.43392 .50937 m .43392 .50936 L p
.43397 .50925 L 1 g
F P
s
P
p
.43397 .50925 m .44166 .49233 L .43392 .50937 L 1 g
F
P
p
.43867 .49934 m .43877 .4991 L .43471 .5077 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44817 .49723 m .43267 .52299 L p
.43511 .50686 L 1 g
F P
s
P
p
.002 w
.44118 .49402 m .44817 .49723 L p
.43511 .50686 L 1 g
F P
s
P
p
.43877 .4991 m .44166 .49233 L .43392 .50936 L 1 g
F
P
p
.4331 .51694 m .43286 .52015 L .43278 .52177 L 1 g
F
P
p
.4331 .51694 m .43278 .52177 L .43288 .52063 L 1 g
F
P
p
.43313 .51793 m .43313 .51778 L .43308 .51851 L 1 g
F
P
p
.43313 .51778 m .43312 .51746 L .43302 .51903 L 1 g
F
P
p
.002 w
.4326 .52372 m .43192 .52424 L .43267 .52299 L p
1 g
F P
s
P
p
.433 .51412 m .43259 .52359 L .4324 .52889 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44817 .49723 m .45737 .50502 L .4326 .52372 L p
1 g
F P
s
P
p
.002 w
.43267 .52299 m .44817 .49723 L p
.4326 .52372 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45737 .50502 m .46387 .51475 L .43258 .52404 L p
1 g
F P
s
P
p
.002 w
.43258 .52404 m .43192 .52424 L .4326 .52372 L p
1 g
F P
s
P
p
.002 w
.4326 .52372 m .45737 .50502 L p
.43258 .52404 L 1 g
F P
s
P
p
.43312 .51746 m .4331 .51694 L .43294 .51954 L 1 g
F
P
p
.4331 .51694 m .43307 .51621 L .43286 .52015 L 1 g
F
P
p
.002 w
.46387 .51475 m .46696 .5253 L .43256 .52426 L p
1 g
F P
s
P
p
.002 w
.43256 .52426 m .43192 .52424 L .43258 .52404 L p
1 g
F P
s
P
p
.002 w
.43258 .52404 m .46387 .51475 L p
.43256 .52426 L 1 g
F P
s
P
p
.002 w
.43255 .52445 m .43192 .52424 L .43256 .52426 L p
1 g
F P
s
P
p
.43296 .51298 m .4325 .52556 L .4324 .52889 L 1 g
F
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.46696 .5253 m .46634 .53552 L .43255 .52445 L p
1 g
F P
s
P
p
.002 w
.43256 .52426 m .46696 .5253 L p
.43255 .52445 L 1 g
F P
s
P
p
.43307 .51621 m .43304 .51525 L .43277 .52097 L 1 g
F
P
p
.43304 .51525 m .433 .51412 L .43267 .52209 L 1 g
F
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.46634 .53552 m .4621 .54428 L .43254 .52465 L p
1 g
F P
s
P
p
.002 w
.43254 .52465 m .43192 .52424 L .43255 .52445 L p
1 g
F P
s
P
p
.002 w
.43255 .52445 m .46634 .53552 L p
.43254 .52465 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.4621 .54428 m .45475 .55064 L .43253 .52495 L p
1 g
F P
s
P
p
.002 w
.43253 .52495 m .43192 .52424 L .43254 .52465 L p
1 g
F P
s
P
p
.002 w
.43254 .52465 m .4621 .54428 L p
.43253 .52495 L 1 g
F P
s
P
p
.433 .51412 m .43296 .51298 L .43259 .52359 L 1 g
F
P
p
.43296 .51298 m .43293 .51211 L .4325 .52556 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45475 .55064 m .44512 .55397 L .4325 .52556 L p
1 g
F P
s
P
p
.002 w
.4325 .52556 m .43192 .52424 L .43253 .52495 L p
1 g
F P
s
P
p
.002 w
.43253 .52495 m .45475 .55064 L p
.4325 .52556 L 1 g
F P
s
P
p
.002 w
.43224 .5284 m .43192 .52424 L p
.43834 .54738 L 1 g
F P
s
P
p
.002 w
.43192 .52424 m .44512 .55397 L .44287 .55396 L p
1 g
F P
s
P
p
.002 w
.41338 .54423 m .40556 .5356 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.42328 .55056 m .41338 .54423 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.4324 .52889 m .4324 .52889 L p
.43524 .53772 L 1 g
F P
s
P
p
.002 w
.42328 .55056 m .43141 .52578 L p
.43237 .52996 L 1 g
F P
s
P
p
.002 w
.43224 .5284 m .43237 .52996 L p
.43141 .52578 L 1 g
F P
s
P
p
.002 w
.43237 .52996 m .43425 .55393 L .43166 .55314 L p
1 g
F P
s
P
p
.002 w
.43166 .55314 m .42328 .55056 L p
.43237 .52996 L 1 g
F P
s
P
p
.002 w
.4324 .52889 m .43146 .53025 L p
.43514 .53754 L 1 g
F P
s
P
p
.43524 .53772 m .4324 .52889 L .43514 .53754 L 1 g
F
P
p
.002 w
.43141 .52578 m .43192 .52424 L .43224 .5284 L p
1 g
F P
s
P
p
.002 w
.40556 .5356 m .40066 .52556 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.40066 .52556 m .39921 .51517 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.39921 .51517 m .4014 .50553 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.4014 .50553 m .40703 .49769 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.41554 .49252 m .42602 .49063 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.40703 .49769 m .41554 .49252 L .43192 .52424 L closepath p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4324 .52889 L p
1 g
F P
s
P
p
.002 w
.4324 .52889 m .4324 .52889 L p
.43241 .52862 L 1 g
F P
s
P
p
.43241 .52862 m .43287 .51061 L .4324 .52889 L 1 g
F
P
p
.43293 .51211 m .43287 .51061 L .4324 .52889 L 1 g
F
P
p
.44287 .55396 m .43834 .54738 L .43248 .52628 L 1 g
F
P
p
.44287 .55396 m .43248 .52628 L .4325 .52581 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43834 .54738 L p
1 g
F P
s
P
p
.43524 .53772 m .43146 .53025 L .43834 .54738 L 1 g
F
P
p
.44264 .55363 m .44242 .55344 L .44287 .55396 L 1 g
F
P
p
.002 w
.45076 .56317 m .45077 .56314 L p
.44967 .56189 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45076 .56317 L p
1 g
F P
s
P
p
.44242 .55344 m .43743 .5491 L .45076 .56317 L 1 g
F
P
p
.002 w
.44287 .55396 m .44512 .55397 L .44967 .56189 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .45458 .56818 L p
.46034 .57 L 1 g
F P
s
P
p
.45812 .56841 m .45002 .56518 L .46034 .57 L 1 g
F
P
p
.002 w
.45458 .56818 m .4678 .57686 L .46819 .57508 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .58069 L p
1 g
F P
s
P
p
.4779 .57769 m .4678 .57686 L .48906 .58069 L 1 g
F
P
p
.002 w
.47054 .57571 m .47862 .57302 L .48905 .58069 L p
1 g
F P
s
P
p
.004 w
.49187 .44171 m
.5 .43051 L
s
P
p
.002 w
.55374 .58074 m .57074 .54906 L .60166 .54641 L p
1 g
F P
s
P
p
.002 w
.56086 .32135 m .50103 .29515 L .513 .27301 L p
1 g
F P
s
P
p
.002 w
.513 .27301 m .57545 .3002 L .56086 .32135 L p
1 g
F P
s
P
p
.002 w
.42582 .3472 m .3798 .35762 L .37976 .32814 L p
1 g
F P
s
P
p
.002 w
.37976 .32814 m .43157 .31592 L .42582 .3472 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.39921 .51517 m .40066 .52556 L .37315 .524 L p
1 g
F P
s
P
p
.002 w
.37315 .524 m .37014 .50372 L .39921 .51517 L p
1 g
F P
s
P
p
.002 w
.60667 .50147 m .60166 .54641 L .57074 .54906 L p
1 g
F P
s
P
p
.002 w
.60166 .54641 m .60667 .50147 L .63496 .48972 L p
1 g
F P
s
P
p
.002 w
.48868 .32209 m .43157 .31592 L .43925 .28883 L p
1 g
F P
s
P
p
.002 w
.43925 .28883 m .50103 .29515 L .48868 .32209 L p
1 g
F P
s
P
p
.002 w
.64474 .41844 m .61091 .36434 L .62758 .34506 L p
1 g
F P
s
P
p
.002 w
.57545 .3002 m .62758 .34506 L .61091 .36434 L p
1 g
F P
s
P
p
.002 w
.38506 .46915 m .3742 .48475 L .35125 .46268 L p
1 g
F P
s
P
p
.002 w
.35125 .46268 m .36679 .43969 L .38506 .46915 L p
1 g
F P
s
P
p
.002 w
.61091 .36434 m .56086 .32135 L .57545 .3002 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.4014 .50553 m .39921 .51517 L .37014 .50372 L p
1 g
F P
s
P
p
.002 w
.37014 .50372 m .3742 .48475 L .4014 .50553 L p
1 g
F P
s
P
p
.002 w
.39089 .4241 m .36679 .43969 L .35282 .41041 L p
1 g
F P
s
P
p
.002 w
.35282 .41041 m .38352 .38998 L .39089 .4241 L p
1 g
F P
s
P
p
.002 w
.62186 .43613 m .63496 .48972 L .60667 .50147 L p
1 g
F P
s
P
p
.002 w
.63496 .48972 m .62186 .43613 L .64474 .41844 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61091 .36434 m .64474 .41844 L .62186 .43613 L p
1 g
F P
s
P
p
.002 w
.47862 .57302 m .49323 .5607 L .52415 .57297 L p
1 g
F P
s
P
p
.002 w
.53707 .54814 m .52415 .57297 L .49323 .5607 L p
1 g
F P
s
P
p
.002 w
.44512 .55397 m .45475 .55064 L .47862 .57302 L p
1 g
F P
s
P
p
.002 w
.49323 .5607 m .47862 .57302 L .45475 .55064 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.42226 .38162 m .38352 .38998 L .3798 .35762 L p
1 g
F P
s
P
p
.002 w
.3798 .35762 m .42582 .3472 L .42226 .38162 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.57074 .54906 m .57452 .51127 L .60667 .50147 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.40703 .49769 m .4014 .50553 L .3742 .48475 L p
1 g
F P
s
P
p
.002 w
.3742 .48475 m .38506 .46915 L .40703 .49769 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.54399 .34648 m .48868 .32209 L .50103 .29515 L p
1 g
F P
s
P
p
.002 w
.50103 .29515 m .56086 .32135 L .54399 .34648 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40169 .45871 m .38506 .46915 L .36679 .43969 L p
1 g
F P
s
P
p
.002 w
.36679 .43969 m .39089 .4241 L .40169 .45871 L p
1 g
F P
s
P
p
.002 w
.47641 .353 m .42582 .3472 L .43157 .31592 L p
1 g
F P
s
P
p
.002 w
.43157 .31592 m .48868 .32209 L .47641 .353 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.45475 .55064 m .4621 .54428 L .49323 .5607 L p
1 g
F P
s
P
p
.002 w
.50184 .54358 m .49323 .5607 L .4621 .54428 L p
1 g
F P
s
P
p
.002 w
.49323 .5607 m .50184 .54358 L .53707 .54814 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.62186 .43613 m .59034 .38622 L .61091 .36434 L p
1 g
F P
s
P
p
.002 w
.56086 .32135 m .61091 .36434 L .59034 .38622 L p
1 g
F P
s
P
p
.002 w
.59467 .45406 m .60667 .50147 L .57452 .51127 L p
1 g
F P
s
P
p
.002 w
.60667 .50147 m .59467 .45406 L .62186 .43613 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.59034 .38622 m .54399 .34648 L .56086 .32135 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42108 .41793 m .39089 .4241 L .38352 .38998 L p
1 g
F P
s
P
p
.002 w
.38352 .38998 m .42226 .38162 L .42108 .41793 L p
1 g
F P
s
P
p
.002 w
.53965 .51869 m .53707 .54814 L .50184 .54358 L p
1 g
F P
s
P
p
.002 w
.59034 .38622 m .62186 .43613 L .59467 .45406 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.41554 .49252 m .40703 .49769 L .38506 .46915 L p
1 g
F P
s
P
p
.002 w
.38506 .46915 m .40169 .45871 L .41554 .49252 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4621 .54428 m .46634 .53552 L .50184 .54358 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.50333 .52344 m .50184 .54358 L .46634 .53552 L p
1 g
F P
s
P
p
.002 w
.50184 .54358 m .50333 .52344 L .53965 .51869 L p
1 g
F P
s
P
p
.002 w
.4647 .38678 m .42226 .38162 L .42582 .3472 L p
1 g
F P
s
P
p
.002 w
.42582 .3472 m .47641 .353 L .4647 .38678 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.46634 .53552 m .46696 .5253 L .50333 .52344 L p
1 g
F P
s
P
p
.002 w
.57452 .51127 m .5641 .47154 L .59467 .45406 L p
1 g
F P
s
P
p
.002 w
.42235 .45474 m .40169 .45871 L .39089 .4241 L p
1 g
F P
s
P
p
.002 w
.39089 .4241 m .42108 .41793 L .42235 .45474 L p
1 g
F P
s
P
p
.002 w
.52538 .37476 m .47641 .353 L .48868 .32209 L p
1 g
F P
s
P
p
.002 w
.48868 .32209 m .54399 .34648 L .52538 .37476 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.42602 .49063 m .41554 .49252 L .40169 .45871 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.40169 .45871 m .42235 .45474 L .42602 .49063 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.59467 .45406 m .56652 .40994 L .59034 .38622 L p
1 g
F P
s
P
p
.002 w
.54399 .34648 m .59034 .38622 L .56652 .40994 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.46696 .5253 m .46387 .51475 L .49741 .50249 L p
1 g
F P
s
P
p
.002 w
.49741 .50249 m .50333 .52344 L .46696 .5253 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.56652 .40994 m .59467 .45406 L .5641 .47154 L p
1 g
F P
s
P
p
.002 w
.53125 .4879 m .53965 .51869 L .50333 .52344 L p
1 g
F P
s
P
p
.002 w
.43732 .49225 m .42602 .49063 L .42235 .45474 L p
1 g
F P
s
P
p
.002 w
.56652 .40994 m .52538 .37476 L .54399 .34648 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.50333 .52344 m .49741 .50249 L .53125 .4879 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45401 .42218 m .42108 .41793 L .42226 .38162 L p
1 g
F P
s
P
p
.002 w
.42226 .38162 m .4647 .38678 L .45401 .42218 L p
1 g
F P
s
P
p
.002 w
.46387 .51475 m .45737 .50502 L .48461 .48313 L p
1 g
F P
s
P
p
.002 w
.48461 .48313 m .49741 .50249 L .46387 .51475 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42235 .45474 m .44476 .45779 L .43732 .49225 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.44476 .45779 m .42235 .45474 L .42108 .41793 L p
1 g
F P
s
P
p
.002 w
.50573 .40517 m .4647 .38678 L .47641 .353 L p
1 g
F P
s
P
p
.002 w
.47641 .353 m .52538 .37476 L .50573 .40517 L p
1 g
F P
s
P
p
.002 w
.42108 .41793 m .45401 .42218 L .44476 .45779 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.5641 .47154 m .54027 .43464 L .56652 .40994 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.52538 .37476 m .56652 .40994 L .54027 .43464 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.46636 .46763 m .44476 .45779 L .45401 .42218 L p
1 g
F P
s
P
p
.002 w
.54027 .43464 m .50573 .40517 L .52538 .37476 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.48579 .43653 m .45401 .42218 L .4647 .38678 L p
1 g
F P
s
P
p
.002 w
.4647 .38678 m .50573 .40517 L .48579 .43653 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45401 .42218 m .48579 .43653 L .46636 .46763 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50573 .40517 m .54027 .43464 L .51261 .45936 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51261 .45936 m .48579 .43653 L .50573 .40517 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.40346 .56341 m
.40905 .55572 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28715 .63822 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39101 .58056 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.602326)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.602326)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46755 .41339 m .48196 .43625 L .50353 .41751 L p
1 g
F P
s
P
p
.002 w
.50353 .41751 m .49374 .40191 L .46755 .41339 L p
1 g
F P
s
P
p
.002 w
.49374 .40191 m .50353 .41751 L .52507 .39905 L p
1 g
F P
s
P
p
.002 w
.51763 .42948 m .50353 .41751 L .48196 .43625 L p
1 g
F P
s
P
p
.002 w
.50353 .41751 m .51763 .42948 L .53224 .40512 L p
1 g
F P
s
P
p
.002 w
.53224 .40512 m .52507 .39905 L .50353 .41751 L p
1 g
F P
s
P
p
.002 w
.48196 .43625 m .50263 .4538 L .51763 .42948 L p
1 g
F P
s
P
p
.002 w
.53457 .43655 m .51763 .42948 L .50263 .4538 L p
1 g
F P
s
P
p
.002 w
.51763 .42948 m .53457 .43655 L .54086 .4087 L p
1 g
F P
s
P
p
.002 w
.54086 .4087 m .53224 .40512 L .51763 .42948 L p
1 g
F P
s
P
p
.002 w
.50263 .4538 m .48196 .43625 L .46074 .45492 L p
1 g
F P
s
P
p
.002 w
.44202 .42535 m .46074 .45492 L .48196 .43625 L p
1 g
F P
s
P
p
.002 w
.48196 .43625 m .46755 .41339 L .44202 .42535 L p
1 g
F P
s
P
p
.002 w
.46074 .45492 m .4875 .47766 L .50263 .4538 L p
1 g
F P
s
P
p
.002 w
.52745 .46425 m .50263 .4538 L .4875 .47766 L p
1 g
F P
s
P
p
.002 w
.50263 .4538 m .52745 .46425 L .53457 .43655 L p
1 g
F P
s
P
p
.002 w
.46091 .38753 m .46755 .41339 L .49374 .40191 L p
1 g
F P
s
P
p
.002 w
.49374 .40191 m .48929 .38428 L .46091 .38753 L p
1 g
F P
s
P
p
.002 w
.48929 .38428 m .49374 .40191 L .52011 .39111 L p
1 g
F P
s
P
p
.002 w
.52507 .39905 m .52011 .39111 L .49374 .40191 L p
1 g
F P
s
P
p
.002 w
.55261 .43798 m .53457 .43655 L .52745 .46425 L p
1 g
F P
s
P
p
.002 w
.53457 .43655 m .55261 .43798 L .55001 .40937 L p
1 g
F P
s
P
p
.002 w
.55001 .40937 m .54086 .4087 L .53457 .43655 L p
1 g
F P
s
P
p
.002 w
.43327 .39186 m .44202 .42535 L .46755 .41339 L p
1 g
F P
s
P
p
.002 w
.46755 .41339 m .46091 .38753 L .43327 .39186 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .52507 .39905 L .53224 .40512 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .52011 .39111 L .52507 .39905 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .53224 .40512 L .54086 .4087 L closepath p
1 g
F P
s
P
p
.002 w
.4875 .47766 m .51963 .49129 L .52745 .46425 L p
1 g
F P
s
P
p
.002 w
.55393 .46647 m .52745 .46425 L .51963 .49129 L p
1 g
F P
s
P
p
.002 w
.52745 .46425 m .55393 .46647 L .55261 .43798 L p
1 g
F P
s
P
p
.002 w
.52011 .39111 m .51789 .38215 L .48929 .38428 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .51789 .38215 L .52011 .39111 L closepath p
1 g
F P
s
P
p
.002 w
.4875 .47766 m .46074 .45492 L .44026 .47318 L p
1 g
F P
s
P
p
.002 w
.41761 .43756 m .44026 .47318 L .46074 .45492 L p
1 g
F P
s
P
p
.002 w
.46074 .45492 m .44202 .42535 L .41761 .43756 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .54086 .4087 L .55001 .40937 L closepath p
1 g
F P
s
P
p
.002 w
.46281 .36131 m .46091 .38753 L .48929 .38428 L p
1 g
F P
s
P
p
.002 w
.48929 .38428 m .4907 .36645 L .46281 .36131 L p
1 g
F P
s
P
p
.002 w
.4907 .36645 m .48929 .38428 L .51789 .38215 L p
1 g
F P
s
P
p
.002 w
.44026 .47318 m .47252 .50061 L .4875 .47766 L p
1 g
F P
s
P
p
.002 w
.51963 .49129 m .4875 .47766 L .47252 .50061 L p
1 g
F P
s
P
p
.002 w
.51789 .38215 m .51866 .37311 L .4907 .36645 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .51866 .37311 L .51789 .38215 L closepath p
1 g
F P
s
P
p
.002 w
.56984 .43355 m .55261 .43798 L .55393 .46647 L p
1 g
F P
s
P
p
.002 w
.55261 .43798 m .56984 .43355 L .55872 .40707 L p
1 g
F P
s
P
p
.002 w
.55872 .40707 m .55001 .40937 L .55261 .43798 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .55001 .40937 L .55872 .40707 L closepath p
1 g
F P
s
P
p
.002 w
.43554 .35782 m .43327 .39186 L .46091 .38753 L p
1 g
F P
s
P
p
.002 w
.46091 .38753 m .46281 .36131 L .43554 .35782 L p
1 g
F P
s
P
p
.002 w
.40689 .3972 m .41761 .43756 L .44202 .42535 L p
1 g
F P
s
P
p
.002 w
.44202 .42535 m .43327 .39186 L .40689 .3972 L p
1 g
F P
s
P
p
.002 w
.49787 .35032 m .4907 .36645 L .51866 .37311 L p
1 g
F P
s
P
p
.002 w
.51866 .37311 m .52235 .36498 L .49787 .35032 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .52235 .36498 L .51866 .37311 L closepath p
1 g
F P
s
P
p
.002 w
.56606 .40202 m .55872 .40707 L .56984 .43355 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .55872 .40707 L .56606 .40202 L closepath p
1 g
F P
s
P
p
.002 w
.47252 .50061 m .51123 .51715 L .51963 .49129 L p
1 g
F P
s
P
p
.002 w
.55394 .49433 m .51963 .49129 L .51123 .51715 L p
1 g
F P
s
P
p
.002 w
.51963 .49129 m .55394 .49433 L .55393 .46647 L p
1 g
F P
s
P
p
.002 w
.47321 .33749 m .46281 .36131 L .4907 .36645 L p
1 g
F P
s
P
p
.002 w
.4907 .36645 m .49787 .35032 L .47321 .33749 L p
1 g
F P
s
P
p
.002 w
.57932 .46013 m .55393 .46647 L .55394 .49433 L p
1 g
F P
s
P
p
.002 w
.55393 .46647 m .57932 .46013 L .56984 .43355 L p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .56606 .40202 L .57121 .39474 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .57121 .39474 L .5736 .38602 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .5736 .38602 L .57295 .37681 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .57295 .37681 L .56932 .36811 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .56932 .36811 L .56309 .36089 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .56309 .36089 L .55496 .35595 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .55496 .35595 L .54583 .35384 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .54583 .35384 L .5367 .35477 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .5367 .35477 L .52858 .35864 L closepath p
1 g
F P
s
P
p
.002 w
.54619 .38118 m .52858 .35864 L .52235 .36498 L closepath p
1 g
F P
s
P
p
.002 w
.51012 .33765 m .49787 .35032 L .52235 .36498 L p
1 g
F P
s
P
p
.002 w
.52235 .36498 m .52858 .35864 L .51012 .33765 L p
1 g
F P
s
P
p
.002 w
.58442 .42367 m .56984 .43355 L .57932 .46013 L p
1 g
F P
s
P
p
.002 w
.56984 .43355 m .58442 .42367 L .56606 .40202 L p
1 g
F P
s
P
p
.002 w
.57121 .39474 m .56606 .40202 L .58442 .42367 L p
1 g
F P
s
P
p
.002 w
.39482 .44981 m .42092 .49069 L .44026 .47318 L p
1 g
F P
s
P
p
.002 w
.44026 .47318 m .41761 .43756 L .39482 .44981 L p
1 g
F P
s
P
p
.002 w
.47252 .50061 m .44026 .47318 L .42092 .49069 L p
1 g
F P
s
P
p
.002 w
.42092 .49069 m .45797 .52222 L .47252 .50061 L p
1 g
F P
s
P
p
.002 w
.51123 .51715 m .47252 .50061 L .45797 .52222 L p
1 g
F P
s
P
p
.002 w
.4094 .35607 m .40689 .3972 L .43327 .39186 L p
1 g
F P
s
P
p
.002 w
.43327 .39186 m .43554 .35782 L .4094 .35607 L p
1 g
F P
s
P
p
.002 w
.52618 .32988 m .51012 .33765 L .52858 .35864 L p
1 g
F P
s
P
p
.002 w
.52858 .35864 m .5367 .35477 L .52618 .32988 L p
1 g
F P
s
P
p
.002 w
.44883 .32676 m .43554 .35782 L .46281 .36131 L p
1 g
F P
s
P
p
.002 w
.46281 .36131 m .47321 .33749 L .44883 .32676 L p
1 g
F P
s
P
p
.002 w
.58442 .42367 m .59474 .40933 L .57121 .39474 L p
1 g
F P
s
P
p
.002 w
.5736 .38602 m .57121 .39474 L .59474 .40933 L p
1 g
F P
s
P
p
.002 w
.49114 .31867 m .47321 .33749 L .49787 .35032 L p
1 g
F P
s
P
p
.002 w
.49787 .35032 m .51012 .33765 L .49114 .31867 L p
1 g
F P
s
P
p
.002 w
.38232 .40347 m .39482 .44981 L .41761 .43756 L p
1 g
F P
s
P
p
.002 w
.41761 .43756 m .40689 .3972 L .38232 .40347 L p
1 g
F P
s
P
p
.002 w
.51123 .51715 m .55263 .52103 L .55394 .49433 L p
1 g
F P
s
P
p
.002 w
.58696 .4863 m .55394 .49433 L .55263 .52103 L p
1 g
F P
s
P
p
.002 w
.55394 .49433 m .58696 .4863 L .57932 .46013 L p
1 g
F P
s
P
p
.002 w
.54433 .32793 m .52618 .32988 L .5367 .35477 L p
1 g
F P
s
P
p
.002 w
.5367 .35477 m .54583 .35384 L .54433 .32793 L p
1 g
F P
s
P
p
.002 w
.60091 .44573 m .57932 .46013 L .58696 .4863 L p
1 g
F P
s
P
p
.002 w
.57932 .46013 m .60091 .44573 L .58442 .42367 L p
1 g
F P
s
P
p
.002 w
.59474 .40933 m .58442 .42367 L .60091 .44573 L p
1 g
F P
s
P
p
.002 w
.59474 .40933 m .5996 .39204 L .5736 .38602 L p
1 g
F P
s
P
p
.002 w
.57295 .37681 m .5736 .38602 L .5996 .39204 L p
1 g
F P
s
P
p
.002 w
.45797 .52222 m .5024 .54134 L .51123 .51715 L p
1 g
F P
s
P
p
.002 w
.55263 .52103 m .51123 .51715 L .5024 .54134 L p
1 g
F P
s
P
p
.002 w
.56254 .33207 m .54433 .32793 L .54583 .35384 L p
1 g
F P
s
P
p
.002 w
.54583 .35384 m .55496 .35595 L .56254 .33207 L p
1 g
F P
s
P
p
.002 w
.5996 .39204 m .5984 .37369 L .57295 .37681 L p
1 g
F P
s
P
p
.002 w
.56932 .36811 m .57295 .37681 L .5984 .37369 L p
1 g
F P
s
P
p
.002 w
.57878 .3419 m .56254 .33207 L .55496 .35595 L p
1 g
F P
s
P
p
.002 w
.55496 .35595 m .56309 .36089 L .57878 .3419 L p
1 g
F P
s
P
p
.002 w
.5984 .37369 m .5912 .35632 L .56932 .36811 L p
1 g
F P
s
P
p
.002 w
.56309 .36089 m .56932 .36811 L .5912 .35632 L p
1 g
F P
s
P
p
.002 w
.51481 .30702 m .49114 .31867 L .51012 .33765 L p
1 g
F P
s
P
p
.002 w
.51012 .33765 m .52618 .32988 L .51481 .30702 L p
1 g
F P
s
P
p
.002 w
.5912 .35632 m .57878 .3419 L .56309 .36089 L p
1 g
F P
s
P
p
.002 w
.472 .3021 m .44883 .32676 L .47321 .33749 L p
1 g
F P
s
P
p
.002 w
.47321 .33749 m .49114 .31867 L .472 .3021 L p
1 g
F P
s
P
p
.002 w
.60091 .44573 m .6163 .42467 L .59474 .40933 L p
1 g
F P
s
P
p
.002 w
.5996 .39204 m .59474 .40933 L .6163 .42467 L p
1 g
F P
s
P
p
.002 w
.42522 .31842 m .4094 .35607 L .43554 .35782 L p
1 g
F P
s
P
p
.002 w
.43554 .35782 m .44883 .32676 L .42522 .31842 L p
1 g
F P
s
P
p
.002 w
.38495 .35616 m .38232 .40347 L .40689 .3972 L p
1 g
F P
s
P
p
.002 w
.40689 .3972 m .4094 .35607 L .38495 .35616 L p
1 g
F P
s
P
p
.002 w
.45797 .52222 m .42092 .49069 L .40312 .5071 L p
1 g
F P
s
P
p
.002 w
.37414 .46187 m .40312 .5071 L .42092 .49069 L p
1 g
F P
s
P
p
.002 w
.42092 .49069 m .39482 .44981 L .37414 .46187 L p
1 g
F P
s
P
p
.002 w
.40312 .5071 m .44414 .54203 L .45797 .52222 L p
1 g
F P
s
P
p
.002 w
.5024 .54134 m .45797 .52222 L .44414 .54203 L p
1 g
F P
s
P
p
.002 w
.58696 .4863 m .61517 .46778 L .60091 .44573 L p
1 g
F P
s
P
p
.002 w
.6163 .42467 m .60091 .44573 L .61517 .46778 L p
1 g
F P
s
P
p
.002 w
.55263 .52103 m .59258 .51157 L .58696 .4863 L p
1 g
F P
s
P
p
.002 w
.61517 .46778 m .58696 .4863 L .59258 .51157 L p
1 g
F P
s
P
p
.002 w
.54168 .30399 m .51481 .30702 L .52618 .32988 L p
1 g
F P
s
P
p
.002 w
.52618 .32988 m .54433 .32793 L .54168 .30399 L p
1 g
F P
s
P
p
.002 w
.5024 .54134 m .54998 .546 L .55263 .52103 L p
1 g
F P
s
P
p
.002 w
.59258 .51157 m .55263 .52103 L .54998 .546 L p
1 g
F P
s
P
p
.002 w
.6163 .42467 m .62365 .39913 L .5996 .39204 L p
1 g
F P
s
P
p
.002 w
.5984 .37369 m .5996 .39204 L .62365 .39913 L p
1 g
F P
s
P
p
.002 w
.3601 .41058 m .37414 .46187 L .39482 .44981 L p
1 g
F P
s
P
p
.002 w
.39482 .44981 m .38232 .40347 L .3601 .41058 L p
1 g
F P
s
P
p
.002 w
.44414 .54203 m .49331 .56332 L .5024 .54134 L p
1 g
F P
s
P
p
.002 w
.54998 .546 m .5024 .54134 L .49331 .56332 L p
1 g
F P
s
P
p
.002 w
.56875 .31006 m .54168 .30399 L .54433 .32793 L p
1 g
F P
s
P
p
.002 w
.54433 .32793 m .56254 .33207 L .56875 .31006 L p
1 g
F P
s
P
p
.002 w
.50279 .28672 m .472 .3021 L .49114 .31867 L p
1 g
F P
s
P
p
.002 w
.49114 .31867 m .51481 .30702 L .50279 .28672 L p
1 g
F P
s
P
p
.002 w
.62365 .39913 m .62198 .37191 L .5984 .37369 L p
1 g
F P
s
P
p
.002 w
.5912 .35632 m .5984 .37369 L .62198 .37191 L p
1 g
F P
s
P
p
.002 w
.45309 .28837 m .42522 .31842 L .44883 .32676 L p
1 g
F P
s
P
p
.002 w
.44883 .32676 m .472 .3021 L .45309 .28837 L p
1 g
F P
s
P
p
.002 w
.61517 .46778 m .6354 .44049 L .6163 .42467 L p
1 g
F P
s
P
p
.002 w
.62365 .39913 m .6163 .42467 L .6354 .44049 L p
1 g
F P
s
P
p
.002 w
.5929 .32464 m .56875 .31006 L .56254 .33207 L p
1 g
F P
s
P
p
.002 w
.56254 .33207 m .57878 .3419 L .5929 .32464 L p
1 g
F P
s
P
p
.002 w
.4029 .31271 m .38495 .35616 L .4094 .35607 L p
1 g
F P
s
P
p
.002 w
.4094 .35607 m .42522 .31842 L .4029 .31271 L p
1 g
F P
s
P
p
.002 w
.62198 .37191 m .61135 .34609 L .5912 .35632 L p
1 g
F P
s
P
p
.002 w
.57878 .3419 m .5912 .35632 L .61135 .34609 L p
1 g
F P
s
P
p
.002 w
.61135 .34609 m .5929 .32464 L .57878 .3419 L p
1 g
F P
s
P
p
.002 w
.36277 .35814 m .3601 .41058 L .38232 .40347 L p
1 g
F P
s
P
p
.002 w
.38232 .40347 m .38495 .35616 L .36277 .35814 L p
1 g
F P
s
P
p
.002 w
.59258 .51157 m .62685 .48939 L .61517 .46778 L p
1 g
F P
s
P
p
.002 w
.6354 .44049 m .61517 .46778 L .62685 .48939 L p
1 g
F P
s
P
p
.002 w
.54998 .546 m .59599 .53538 L .59258 .51157 L p
1 g
F P
s
P
p
.002 w
.62685 .48939 m .59258 .51157 L .59599 .53538 L p
1 g
F P
s
P
p
.002 w
.44414 .54203 m .40312 .5071 L .38728 .52202 L p
1 g
F P
s
P
p
.002 w
.35606 .47347 m .38728 .52202 L .40312 .5071 L p
1 g
F P
s
P
p
.002 w
.40312 .5071 m .37414 .46187 L .35606 .47347 L p
1 g
F P
s
P
p
.002 w
.5379 .2826 m .50279 .28672 L .51481 .30702 L p
1 g
F P
s
P
p
.002 w
.51481 .30702 m .54168 .30399 L .5379 .2826 L p
1 g
F P
s
P
p
.002 w
.38728 .52202 m .43134 .55957 L .44414 .54203 L p
1 g
F P
s
P
p
.002 w
.49331 .56332 m .44414 .54203 L .43134 .55957 L p
1 g
F P
s
P
p
.002 w
.49331 .56332 m .54599 .56869 L .54998 .546 L p
1 g
F P
s
P
p
.002 w
.59599 .53538 m .54998 .546 L .54599 .56869 L p
1 g
F P
s
P
p
.002 w
.6354 .44049 m .64518 .40721 L .62365 .39913 L p
1 g
F P
s
P
p
.002 w
.62198 .37191 m .62365 .39913 L .64518 .40721 L p
1 g
F P
s
P
p
.002 w
.34081 .41841 m .35606 .47347 L .37414 .46187 L p
1 g
F P
s
P
p
.002 w
.37414 .46187 m .3601 .41058 L .34081 .41841 L p
1 g
F P
s
P
p
.002 w
.49034 .26951 m .45309 .28837 L .472 .3021 L p
1 g
F P
s
P
p
.002 w
.472 .3021 m .50279 .28672 L .49034 .26951 L p
1 g
F P
s
P
p
.002 w
.43134 .55957 m .48412 .58255 L .49331 .56332 L p
1 g
F P
s
P
p
.002 w
.54599 .56869 m .49331 .56332 L .48412 .58255 L p
1 g
F P
s
P
p
.002 w
.57338 .29045 m .5379 .2826 L .54168 .30399 L p
1 g
F P
s
P
p
.002 w
.54168 .30399 m .56875 .31006 L .57338 .29045 L p
1 g
F P
s
P
p
.002 w
.43483 .2779 m .4029 .31271 L .42522 .31842 L p
1 g
F P
s
P
p
.002 w
.42522 .31842 m .45309 .28837 L .43483 .2779 L p
1 g
F P
s
P
p
.002 w
.64518 .40721 m .64314 .37159 L .62198 .37191 L p
1 g
F P
s
P
p
.002 w
.61135 .34609 m .62198 .37191 L .64314 .37159 L p
1 g
F P
s
P
p
.002 w
.62685 .48939 m .65156 .45647 L .6354 .44049 L p
1 g
F P
s
P
p
.002 w
.64518 .40721 m .6354 .44049 L .65156 .45647 L p
1 g
F P
s
P
p
.002 w
.38241 .30987 m .36277 .35814 L .38495 .35616 L p
1 g
F P
s
P
p
.002 w
.38495 .35616 m .4029 .31271 L .38241 .30987 L p
1 g
F P
s
P
p
.002 w
.60509 .30955 m .57338 .29045 L .56875 .31006 L p
1 g
F P
s
P
p
.002 w
.56875 .31006 m .5929 .32464 L .60509 .30955 L p
1 g
F P
s
P
p
.002 w
.64314 .37159 m .62928 .3377 L .61135 .34609 L p
1 g
F P
s
P
p
.002 w
.5929 .32464 m .61135 .34609 L .62928 .3377 L p
1 g
F P
s
P
p
.002 w
.59599 .53538 m .6356 .51008 L .62685 .48939 L p
1 g
F P
s
P
p
.002 w
.65156 .45647 m .62685 .48939 L .6356 .51008 L p
1 g
F P
s
P
p
.002 w
.62928 .3377 m .60509 .30955 L .5929 .32464 L p
1 g
F P
s
P
p
.002 w
.34343 .36206 m .34081 .41841 L .3601 .41058 L p
1 g
F P
s
P
p
.002 w
.3601 .41058 m .36277 .35814 L .34343 .36206 L p
1 g
F P
s
P
p
.002 w
.54599 .56869 m .59704 .55718 L .59599 .53538 L p
1 g
F P
s
P
p
.002 w
.6356 .51008 m .59599 .53538 L .59704 .55718 L p
1 g
F P
s
P
p
.002 w
.53301 .26433 m .49034 .26951 L .50279 .28672 L p
1 g
F P
s
P
p
.002 w
.50279 .28672 m .5379 .2826 L .53301 .26433 L p
1 g
F P
s
P
p
.002 w
.3411 .48434 m .37382 .53507 L .38728 .52202 L p
1 g
F P
s
P
p
.002 w
.38728 .52202 m .35606 .47347 L .3411 .48434 L p
1 g
F P
s
P
p
.002 w
.43134 .55957 m .38728 .52202 L .37382 .53507 L p
1 g
F P
s
P
p
.002 w
.48412 .58255 m .5407 .58852 L .54599 .56869 L p
1 g
F P
s
P
p
.002 w
.59704 .55718 m .54599 .56869 L .5407 .58852 L p
1 g
F P
s
P
p
.002 w
.37382 .53507 m .41989 .57435 L .43134 .55957 L p
1 g
F P
s
P
p
.002 w
.48412 .58255 m .43134 .55957 L .41989 .57435 L p
1 g
F P
s
P
p
.002 w
.65156 .45647 m .66363 .41613 L .64518 .40721 L p
1 g
F P
s
P
p
.002 w
.64314 .37159 m .64518 .40721 L .66363 .41613 L p
1 g
F P
s
P
p
.002 w
.47773 .25593 m .43483 .2779 L .45309 .28837 L p
1 g
F P
s
P
p
.002 w
.45309 .28837 m .49034 .26951 L .47773 .25593 L p
1 g
F P
s
P
p
.002 w
.32501 .42682 m .3411 .48434 L .35606 .47347 L p
1 g
F P
s
P
p
.002 w
.35606 .47347 m .34081 .41841 L .32501 .42682 L p
1 g
F P
s
P
p
.002 w
.41765 .27108 m .38241 .30987 L .4029 .31271 L p
1 g
F P
s
P
p
.002 w
.4029 .31271 m .43483 .2779 L .41765 .27108 L p
1 g
F P
s
P
p
.002 w
.57627 .27381 m .53301 .26433 L .5379 .2826 L p
1 g
F P
s
P
p
.002 w
.5379 .2826 m .57338 .29045 L .57627 .27381 L p
1 g
F P
s
P
p
.002 w
.41989 .57435 m .47504 .59849 L .48412 .58255 L p
1 g
F P
s
P
p
.002 w
.5407 .58852 m .48412 .58255 L .47504 .59849 L p
1 g
F P
s
P
p
.002 w
.6356 .51008 m .6643 .47228 L .65156 .45647 L p
1 g
F P
s
P
p
.002 w
.66363 .41613 m .65156 .45647 L .6643 .47228 L p
1 g
F P
s
P
p
.002 w
.66363 .41613 m .6613 .37277 L .64314 .37159 L p
1 g
F P
s
P
p
.002 w
.62928 .3377 m .64314 .37159 L .6613 .37277 L p
1 g
F P
s
P
p
.002 w
.36432 .31011 m .34343 .36206 L .36277 .35814 L p
1 g
F P
s
P
p
.002 w
.36277 .35814 m .38241 .30987 L .36432 .31011 L p
1 g
F P
s
P
p
.002 w
.59704 .55718 m .64111 .52936 L .6356 .51008 L p
1 g
F P
s
P
p
.002 w
.6643 .47228 m .6356 .51008 L .64111 .52936 L p
1 g
F P
s
P
p
.002 w
.61498 .29707 m .57627 .27381 L .57338 .29045 L p
1 g
F P
s
P
p
.002 w
.57338 .29045 m .60509 .30955 L .61498 .29707 L p
1 g
F P
s
P
p
.002 w
.6613 .37277 m .64448 .33144 L .62928 .3377 L p
1 g
F P
s
P
p
.002 w
.60509 .30955 m .62928 .3377 L .64448 .33144 L p
1 g
F P
s
P
p
.002 w
.5407 .58852 m .5956 .5764 L .59704 .55718 L p
1 g
F P
s
P
p
.002 w
.64111 .52936 m .59704 .55718 L .5956 .5764 L p
1 g
F P
s
P
p
.002 w
.32755 .36793 m .32501 .42682 L .34081 .41841 L p
1 g
F P
s
P
p
.002 w
.34081 .41841 m .34343 .36206 L .32755 .36793 L p
1 g
F P
s
P
p
.002 w
.64448 .33144 m .61498 .29707 L .60509 .30955 L p
1 g
F P
s
P
p
.002 w
.52708 .24978 m .47773 .25593 L .49034 .26951 L p
1 g
F P
s
P
p
.002 w
.49034 .26951 m .53301 .26433 L .52708 .24978 L p
1 g
F P
s
P
p
.002 w
.47504 .59849 m .53417 .60491 L .5407 .58852 L p
1 g
F P
s
P
p
.002 w
.5956 .5764 m .5407 .58852 L .53417 .60491 L p
1 g
F P
s
P
p
.002 w
.41989 .57435 m .37382 .53507 L .36317 .54586 L p
1 g
F P
s
P
p
.002 w
.32977 .4942 m .36317 .54586 L .37382 .53507 L p
1 g
F P
s
P
p
.002 w
.37382 .53507 m .3411 .48434 L .32977 .4942 L p
1 g
F P
s
P
p
.002 w
.6643 .47228 m .67844 .42573 L .66363 .41613 L p
1 g
F P
s
P
p
.002 w
.6613 .37277 m .66363 .41613 L .67844 .42573 L p
1 g
F P
s
P
p
.002 w
.36317 .54586 m .41012 .58591 L .41989 .57435 L p
1 g
F P
s
P
p
.002 w
.47504 .59849 m .41989 .57435 L .41012 .58591 L p
1 g
F P
s
P
p
.002 w
.46524 .24648 m .41765 .27108 L .43483 .2779 L p
1 g
F P
s
P
p
.002 w
.43483 .2779 m .47773 .25593 L .46524 .24648 L p
1 g
F P
s
P
p
.002 w
.31326 .43565 m .32977 .4942 L .3411 .48434 L p
1 g
F P
s
P
p
.002 w
.3411 .48434 m .32501 .42682 L .31326 .43565 L p
1 g
F P
s
P
p
.002 w
.40204 .26826 m .36432 .31011 L .38241 .30987 L p
1 g
F P
s
P
p
.002 w
.38241 .30987 m .41765 .27108 L .40204 .26826 L p
1 g
F P
s
P
p
.002 w
.57724 .26067 m .52708 .24978 L .53301 .26433 L p
1 g
F P
s
P
p
.002 w
.53301 .26433 m .57627 .27381 L .57724 .26067 L p
1 g
F P
s
P
p
.002 w
.64111 .52936 m .67315 .48754 L .6643 .47228 L p
1 g
F P
s
P
p
.002 w
.67844 .42573 m .6643 .47228 L .67315 .48754 L p
1 g
F P
s
P
p
.002 w
.41012 .58591 m .46628 .61058 L .47504 .59849 L p
1 g
F P
s
P
p
.002 w
.53417 .60491 m .47504 .59849 L .46628 .61058 L p
1 g
F P
s
P
p
.002 w
.34918 .31358 m .32755 .36793 L .34343 .36206 L p
1 g
F P
s
P
p
.002 w
.34343 .36206 m .36432 .31011 L .34918 .31358 L p
1 g
F P
s
P
p
.002 w
.67844 .42573 m .67587 .37553 L .6613 .37277 L p
1 g
F P
s
P
p
.002 w
.64448 .33144 m .6613 .37277 L .67587 .37553 L p
1 g
F P
s
P
p
.002 w
.5956 .5764 m .64308 .5467 L .64111 .52936 L p
1 g
F P
s
P
p
.002 w
.67315 .48754 m .64111 .52936 L .64308 .5467 L p
1 g
F P
s
P
p
.002 w
.62219 .28765 m .57724 .26067 L .57627 .27381 L p
1 g
F P
s
P
p
.002 w
.57627 .27381 m .61498 .29707 L .62219 .28765 L p
1 g
F P
s
P
p
.002 w
.53417 .60491 m .59156 .59243 L .5956 .5764 L p
1 g
F P
s
P
p
.002 w
.64308 .5467 m .5956 .5764 L .59156 .59243 L p
1 g
F P
s
P
p
.002 w
.31569 .37571 m .31326 .43565 L .32501 .42682 L p
1 g
F P
s
P
p
.002 w
.32501 .42682 m .32755 .36793 L .31569 .37571 L p
1 g
F P
s
P
p
.002 w
.67587 .37553 m .65643 .32756 L .64448 .33144 L p
1 g
F P
s
P
p
.002 w
.61498 .29707 m .64448 .33144 L .65643 .32756 L p
1 g
F P
s
P
p
.002 w
.52017 .23952 m .46524 .24648 L .47773 .25593 L p
1 g
F P
s
P
p
.002 w
.47773 .25593 m .52708 .24978 L .52017 .23952 L p
1 g
F P
s
P
p
.002 w
.65643 .32756 m .62219 .28765 L .61498 .29707 L p
1 g
F P
s
P
p
.002 w
.46628 .61058 m .52647 .61726 L .53417 .60491 L p
1 g
F P
s
P
p
.002 w
.59156 .59243 m .53417 .60491 L .52647 .61726 L p
1 g
F P
s
P
p
.002 w
.67315 .48754 m .68904 .43583 L .67844 .42573 L p
1 g
F P
s
P
p
.002 w
.67587 .37553 m .67844 .42573 L .68904 .43583 L p
1 g
F P
s
P
p
.002 w
.41012 .58591 m .36317 .54586 L .35575 .554 L p
1 g
F P
s
P
p
.002 w
.32256 .50275 m .35575 .554 L .36317 .54586 L p
1 g
F P
s
P
p
.002 w
.36317 .54586 m .32977 .4942 L .32256 .50275 L p
1 g
F P
s
P
p
.002 w
.45319 .24166 m .40204 .26826 L .41765 .27108 L p
1 g
F P
s
P
p
.002 w
.41765 .27108 m .46524 .24648 L .45319 .24166 L p
1 g
F P
s
P
p
.002 w
.35575 .554 m .40236 .59378 L .41012 .58591 L p
1 g
F P
s
P
p
.002 w
.46628 .61058 m .41012 .58591 L .40236 .59378 L p
1 g
F P
s
P
p
.002 w
.38849 .26976 m .34918 .31358 L .36432 .31011 L p
1 g
F P
s
P
p
.002 w
.36432 .31011 m .40204 .26826 L .38849 .26976 L p
1 g
F P
s
P
p
.002 w
.3061 .4447 m .32256 .50275 L .32977 .4942 L p
1 g
F P
s
P
p
.002 w
.32977 .4942 m .31326 .43565 L .3061 .4447 L p
1 g
F P
s
P
p
.002 w
.64308 .5467 m .67769 .50185 L .67315 .48754 L p
1 g
F P
s
P
p
.002 w
.68904 .43583 m .67315 .48754 L .67769 .50185 L p
1 g
F P
s
P
p
.002 w
.57616 .2516 m .52017 .23952 L .52708 .24978 L p
1 g
F P
s
P
p
.002 w
.52708 .24978 m .57724 .26067 L .57616 .2516 L p
1 g
F P
s
P
p
.002 w
.40236 .59378 m .45807 .61832 L .46628 .61058 L p
1 g
F P
s
P
p
.002 w
.52647 .61726 m .46628 .61058 L .45807 .61832 L p
1 g
F P
s
P
p
.002 w
.33757 .3204 m .31569 .37571 L .32755 .36793 L p
1 g
F P
s
P
p
.002 w
.32755 .36793 m .34918 .31358 L .33757 .3204 L p
1 g
F P
s
P
p
.002 w
.68904 .43583 m .68628 .37989 L .67587 .37553 L p
1 g
F P
s
P
p
.002 w
.65643 .32756 m .67587 .37553 L .68628 .37989 L p
1 g
F P
s
P
p
.002 w
.59156 .59243 m .64126 .56157 L .64308 .5467 L p
1 g
F P
s
P
p
.002 w
.67769 .50185 m .64308 .5467 L .64126 .56157 L p
1 g
F P
s
P
p
.002 w
.52647 .61726 m .5849 .60472 L .59156 .59243 L p
1 g
F P
s
P
p
.002 w
.64126 .56157 m .59156 .59243 L .5849 .60472 L p
1 g
F P
s
P
p
.002 w
.62639 .28171 m .57616 .2516 L .57724 .26067 L p
1 g
F P
s
P
p
.002 w
.57724 .26067 m .62219 .28765 L .62639 .28171 L p
1 g
F P
s
P
p
.002 w
.30842 .38532 m .3061 .4447 L .31326 .43565 L p
1 g
F P
s
P
p
.002 w
.31326 .43565 m .31569 .37571 L .30842 .38532 L p
1 g
F P
s
P
p
.002 w
.68628 .37989 m .66464 .32632 L .65643 .32756 L p
1 g
F P
s
P
p
.002 w
.62219 .28765 m .65643 .32756 L .66464 .32632 L p
1 g
F P
s
P
p
.002 w
.51243 .23407 m .45319 .24166 L .46524 .24648 L p
1 g
F P
s
P
p
.002 w
.46524 .24648 m .52017 .23952 L .51243 .23407 L p
1 g
F P
s
P
p
.002 w
.66464 .32632 m .62639 .28171 L .62219 .28765 L p
1 g
F P
s
P
p
.002 w
.45807 .61832 m .51774 .62503 L .52647 .61726 L p
1 g
F P
s
P
p
.002 w
.5849 .60472 m .52647 .61726 L .51774 .62503 L p
1 g
F P
s
P
p
.002 w
.67769 .50185 m .69492 .44619 L .68904 .43583 L p
1 g
F P
s
P
p
.002 w
.68628 .37989 m .68904 .43583 L .69492 .44619 L p
1 g
F P
s
P
p
.002 w
.44195 .24187 m .38849 .26976 L .40204 .26826 L p
1 g
F P
s
P
p
.002 w
.40204 .26826 m .45319 .24166 L .44195 .24187 L p
1 g
F P
s
P
p
.002 w
.40236 .59378 m .35575 .554 L .35195 .55912 L p
1 g
F P
s
P
p
.002 w
.31991 .50967 m .35195 .55912 L .35575 .554 L p
1 g
F P
s
P
p
.002 w
.35575 .554 m .32256 .50275 L .31991 .50967 L p
1 g
F P
s
P
p
.002 w
.35195 .55912 m .39694 .59751 L .40236 .59378 L p
1 g
F P
s
P
p
.002 w
.45807 .61832 m .40236 .59378 L .39694 .59751 L p
1 g
F P
s
P
p
.002 w
.37748 .2758 m .33757 .3204 L .34918 .31358 L p
1 g
F P
s
P
p
.002 w
.34918 .31358 m .38849 .26976 L .37748 .2758 L p
1 g
F P
s
P
p
.002 w
.64126 .56157 m .67754 .51477 L .67769 .50185 L p
1 g
F P
s
P
p
.002 w
.69492 .44619 m .67769 .50185 L .67754 .51477 L p
1 g
F P
s
P
p
.002 w
.30401 .45373 m .31991 .50967 L .32256 .50275 L p
1 g
F P
s
P
p
.002 w
.32256 .50275 m .3061 .4447 L .30401 .45373 L p
1 g
F P
s
P
p
.002 w
.57292 .2471 m .51243 .23407 L .52017 .23952 L p
1 g
F P
s
P
p
.002 w
.52017 .23952 m .57616 .2516 L .57292 .2471 L p
1 g
F P
s
P
p
.002 w
.33002 .33057 m .30842 .38532 L .31569 .37571 L p
1 g
F P
s
P
p
.002 w
.31569 .37571 m .33757 .3204 L .33002 .33057 L p
1 g
F P
s
P
p
.002 w
.39694 .59751 m .45067 .62121 L .45807 .61832 L p
1 g
F P
s
P
p
.002 w
.51774 .62503 m .45807 .61832 L .45067 .62121 L p
1 g
F P
s
P
p
.002 w
.5849 .60472 m .63549 .57343 L .64126 .56157 L p
1 g
F P
s
P
p
.002 w
.67754 .51477 m .64126 .56157 L .63549 .57343 L p
1 g
F P
s
P
p
.002 w
.69492 .44619 m .69201 .38583 L .68628 .37989 L p
1 g
F P
s
P
p
.002 w
.66464 .32632 m .68628 .37989 L .69201 .38583 L p
1 g
F P
s
P
p
.002 w
.51774 .62503 m .57561 .61269 L .5849 .60472 L p
1 g
F P
s
P
p
.002 w
.63549 .57343 m .5849 .60472 L .57561 .61269 L p
1 g
F P
s
P
p
.002 w
.30622 .39659 m .30401 .45373 L .3061 .4447 L p
1 g
F P
s
P
p
.002 w
.3061 .4447 m .30842 .38532 L .30622 .39659 L p
1 g
F P
s
P
p
.002 w
.62725 .27966 m .57292 .2471 L .57616 .2516 L p
1 g
F P
s
P
p
.002 w
.57616 .2516 m .62639 .28171 L .62725 .27966 L p
1 g
F P
s
P
p
.002 w
.504 .2339 m .44195 .24187 L .45319 .24166 L p
1 g
F P
s
P
p
.002 w
.45319 .24166 m .51243 .23407 L .504 .2339 L p
1 g
F P
s
P
p
.002 w
.69201 .38583 m .66863 .32791 L .66464 .32632 L p
1 g
F P
s
P
p
.002 w
.62639 .28171 m .66464 .32632 L .66863 .32791 L p
1 g
F P
s
P
p
.002 w
.66863 .32791 m .62725 .27966 L .62639 .28171 L p
1 g
F P
s
P
p
.002 w
.45067 .62121 m .50815 .62771 L .51774 .62503 L p
1 g
F P
s
P
p
.002 w
.57561 .61269 m .51774 .62503 L .50815 .62771 L p
1 g
F P
s
P
p
.002 w
.67754 .51477 m .69562 .45656 L .69492 .44619 L p
1 g
F P
s
P
p
.002 w
.69201 .38583 m .69492 .44619 L .69562 .45656 L p
1 g
F P
s
P
p
.002 w
.43188 .24743 m .37748 .2758 L .38849 .26976 L p
1 g
F P
s
P
p
.002 w
.38849 .26976 m .44195 .24187 L .43188 .24743 L p
1 g
F P
s
P
p
.004 w
.22012 .53382 m
.28361 .51038 L
s
P
p
.002 w
.3222 .51468 m .35213 .56087 L .35195 .55912 L p
1 g
F P
s
P
p
.002 w
.35195 .55912 m .31991 .50967 L .3222 .51468 L p
1 g
F P
s
P
p
.002 w
.39694 .59751 m .35195 .55912 L .35213 .56087 L p
1 g
F P
s
P
p
.002 w
.3695 .28648 m .33002 .33057 L .33757 .3204 L p
1 g
F P
s
P
p
.002 w
.33757 .3204 m .37748 .2758 L .3695 .28648 L p
1 g
F P
s
P
p
.002 w
.35213 .56087 m .39416 .59674 L .39694 .59751 L p
1 g
F P
s
P
p
.002 w
.45067 .62121 m .39694 .59751 L .39416 .59674 L p
1 g
F P
s
P
p
.002 w
.63549 .57343 m .67241 .52587 L .67754 .51477 L p
1 g
F P
s
P
p
.002 w
.69562 .45656 m .67754 .51477 L .67241 .52587 L p
1 g
F P
s
P
p
.002 w
.30737 .4625 m .3222 .51468 L .31991 .50967 L p
1 g
F P
s
P
p
.002 w
.31991 .50967 m .30401 .45373 L .30737 .4625 L p
1 g
F P
s
P
p
.004 w
.28361 .51038 m
.30454 .50266 L
s
P
p
.002 w
.56747 .24759 m .504 .2339 L .51243 .23407 L p
1 g
F P
s
P
p
.002 w
.51243 .23407 m .57292 .2471 L .56747 .24759 L p
1 g
F P
s
P
p
.002 w
.327 .344 m .30622 .39659 L .30842 .38532 L p
1 g
F P
s
P
p
.002 w
.30842 .38532 m .33002 .33057 L .327 .344 L p
1 g
F P
s
P
p
.002 w
.57561 .61269 m .62568 .58177 L .63549 .57343 L p
1 g
F P
s
P
p
.002 w
.67241 .52587 m .63549 .57343 L .62568 .58177 L p
1 g
F P
s
P
p
.002 w
.39416 .59674 m .44433 .61887 L .45067 .62121 L p
1 g
F P
s
P
p
.002 w
.50815 .62771 m .45067 .62121 L .44433 .61887 L p
1 g
F P
s
P
p
.002 w
.69562 .45656 m .69257 .39328 L .69201 .38583 L p
1 g
F P
s
P
p
.002 w
.66863 .32791 m .69201 .38583 L .69257 .39328 L p
1 g
F P
s
P
p
.002 w
.50815 .62771 m .56381 .61585 L .57561 .61269 L p
1 g
F P
s
P
p
.002 w
.62568 .58177 m .57561 .61269 L .56381 .61585 L p
1 g
F P
s
P
p
.002 w
.30947 .4093 m .30737 .4625 L .30401 .45373 L p
1 g
F P
s
P
p
.002 w
.30401 .45373 m .30622 .39659 L .30947 .4093 L p
1 g
F P
s
P
p
.002 w
.4951 .23936 m .43188 .24743 L .44195 .24187 L p
1 g
F P
s
P
p
.002 w
.44195 .24187 m .504 .2339 L .4951 .23936 L p
1 g
F P
s
P
p
.002 w
.62454 .2818 m .56747 .24759 L .57292 .2471 L p
1 g
F P
s
P
p
.002 w
.57292 .2471 m .62725 .27966 L .62454 .2818 L p
1 g
F P
s
P
p
.002 w
.69257 .39328 m .66801 .33249 L .66863 .32791 L p
1 g
F P
s
P
p
.002 w
.62725 .27966 m .66863 .32791 L .66801 .33249 L p
1 g
F P
s
P
p
.002 w
.44433 .61887 m .49791 .62492 L .50815 .62771 L p
1 g
F P
s
P
p
.002 w
.56381 .61585 m .50815 .62771 L .49791 .62492 L p
1 g
F P
s
P
p
.002 w
.66801 .33249 m .62454 .2818 L .62725 .27966 L p
1 g
F P
s
P
p
.002 w
.42335 .25849 m .3695 .28648 L .37748 .2758 L p
1 g
F P
s
P
p
.002 w
.37748 .2758 m .43188 .24743 L .42335 .25849 L p
1 g
F P
s
P
p
.002 w
.67241 .52587 m .69079 .46661 L .69562 .45656 L p
1 g
F P
s
P
p
.002 w
.69257 .39328 m .69562 .45656 L .69079 .46661 L p
1 g
F P
s
P
p
.002 w
.36498 .30175 m .327 .344 L .33002 .33057 L p
1 g
F P
s
P
p
.002 w
.33002 .33057 m .3695 .28648 L .36498 .30175 L p
1 g
F P
s
P
p
.002 w
.32968 .5175 m .35654 .55897 L .35213 .56087 L p
1 g
F P
s
P
p
.002 w
.35213 .56087 m .3222 .51468 L .32968 .5175 L p
1 g
F P
s
P
p
.002 w
.39416 .59674 m .35213 .56087 L .35654 .55897 L p
1 g
F P
s
P
p
.002 w
.35654 .55897 m .39429 .59118 L .39416 .59674 L p
1 g
F P
s
P
p
.002 w
.44433 .61887 m .39416 .59674 L .39429 .59118 L p
1 g
F P
s
P
p
.002 w
.62568 .58177 m .66215 .53471 L .67241 .52587 L p
1 g
F P
s
P
p
.002 w
.69079 .46661 m .67241 .52587 L .66215 .53471 L p
1 g
F P
s
P
p
.002 w
.32888 .36048 m .30947 .4093 L .30622 .39659 L p
1 g
F P
s
P
p
.002 w
.30622 .39659 m .327 .344 L .32888 .36048 L p
1 g
F P
s
P
p
.002 w
.31644 .47072 m .32968 .5175 L .3222 .51468 L p
1 g
F P
s
P
p
.004 w
.3235 .49566 m
.5 .43051 L
s
P
p
.002 w
.3222 .51468 m .30737 .4625 L .31644 .47072 L p
1 g
F P
s
P
p
.004 w
.31764 .49782 m
.319 .49732 L
s
P
p
.004 w
.31086 .50032 m
.31764 .49782 L
s
P
p
.004 w
.30454 .50266 m
.31086 .50032 L
s
P
p
.002 w
.56381 .61585 m .61187 .58611 L .62568 .58177 L p
1 g
F P
s
P
p
.002 w
.66215 .53471 m .62568 .58177 L .61187 .58611 L p
1 g
F P
s
P
p
.002 w
.55983 .25339 m .4951 .23936 L .504 .2339 L p
1 g
F P
s
P
p
.002 w
.504 .2339 m .56747 .24759 L .55983 .25339 L p
1 g
F P
s
P
p
.002 w
.39429 .59118 m .43931 .61102 L .44433 .61887 L p
1 g
F P
s
P
p
.002 w
.49791 .62492 m .44433 .61887 L .43931 .61102 L p
1 g
F P
s
P
p
.002 w
.69079 .46661 m .68762 .40213 L .69257 .39328 L p
1 g
F P
s
P
p
.002 w
.66801 .33249 m .69257 .39328 L .68762 .40213 L p
1 g
F P
s
P
p
.002 w
.49791 .62492 m .54969 .61382 L .56381 .61585 L p
1 g
F P
s
P
p
.002 w
.61187 .58611 m .56381 .61585 L .54969 .61382 L p
1 g
F P
s
P
p
.002 w
.48597 .25064 m .42335 .25849 L .43188 .24743 L p
1 g
F P
s
P
p
.002 w
.43188 .24743 m .4951 .23936 L .48597 .25064 L p
1 g
F P
s
P
p
.002 w
.31842 .42315 m .31644 .47072 L .30737 .4625 L p
1 g
F P
s
P
p
.002 w
.30737 .4625 m .30947 .4093 L .31842 .42315 L p
1 g
F P
s
P
p
.002 w
.61809 .28835 m .55983 .25339 L .56747 .24759 L p
1 g
F P
s
P
p
.002 w
.56747 .24759 m .62454 .2818 L .61809 .28835 L p
1 g
F P
s
P
p
.002 w
.68762 .40213 m .6625 .34011 L .66801 .33249 L p
1 g
F P
s
P
p
.002 w
.62454 .2818 m .66801 .33249 L .6625 .34011 L p
1 g
F P
s
P
p
.002 w
.43931 .61102 m .48732 .61637 L .49791 .62492 L p
1 g
F P
s
P
p
.002 w
.54969 .61382 m .49791 .62492 L .48732 .61637 L p
1 g
F P
s
P
p
.002 w
.41674 .27505 m .36498 .30175 L .3695 .28648 L p
1 g
F P
s
P
p
.002 w
.3695 .28648 m .42335 .25849 L .41674 .27505 L p
1 g
F P
s
P
p
.002 w
.66215 .53471 m .68023 .47604 L .69079 .46661 L p
1 g
F P
s
P
p
.002 w
.68762 .40213 m .69079 .46661 L .68023 .47604 L p
1 g
F P
s
P
p
.002 w
.6625 .34011 m .61809 .28835 L .62454 .2818 L p
1 g
F P
s
P
p
.002 w
.36426 .32141 m .32888 .36048 L .327 .344 L p
1 g
F P
s
P
p
.002 w
.327 .344 m .36498 .30175 L .36426 .32141 L p
1 g
F P
s
P
p
.002 w
.61187 .58611 m .64676 .54087 L .66215 .53471 L p
1 g
F P
s
P
p
.002 w
.68023 .47604 m .66215 .53471 L .64676 .54087 L p
1 g
F P
s
P
p
.002 w
.34247 .5179 m .36532 .55324 L .35654 .55897 L p
1 g
F P
s
P
p
.002 w
.35654 .55897 m .32968 .5175 L .34247 .5179 L p
1 g
F P
s
P
p
.002 w
.39429 .59118 m .35654 .55897 L .36532 .55324 L p
1 g
F P
s
P
p
.002 w
.36532 .55324 m .3975 .58069 L .39429 .59118 L p
1 g
F P
s
P
p
.002 w
.43931 .61102 m .39429 .59118 L .3975 .58069 L p
1 g
F P
s
P
p
.002 w
.3359 .37965 m .31842 .42315 L .30947 .4093 L p
1 g
F P
s
P
p
.002 w
.30947 .4093 m .32888 .36048 L .3359 .37965 L p
1 g
F P
s
P
p
.002 w
.54969 .61382 m .59425 .58609 L .61187 .58611 L p
1 g
F P
s
P
p
.002 w
.64676 .54087 m .61187 .58611 L .59425 .58609 L p
1 g
F P
s
P
p
.002 w
.33128 .47808 m .34247 .5179 L .32968 .5175 L p
1 g
F P
s
P
p
.002 w
.32968 .5175 m .31644 .47072 L .33128 .47808 L p
1 g
F P
s
P
p
.002 w
.55011 .26466 m .48597 .25064 L .4951 .23936 L p
1 g
F P
s
P
p
.002 w
.4951 .23936 m .55983 .25339 L .55011 .26466 L p
1 g
F P
s
P
p
.002 w
.3975 .58069 m .43586 .59755 L .43931 .61102 L p
1 g
F P
s
P
p
.002 w
.48732 .61637 m .43931 .61102 L .43586 .59755 L p
1 g
F P
s
P
p
.002 w
.48732 .61637 m .53356 .60634 L .54969 .61382 L p
1 g
F P
s
P
p
.002 w
.59425 .58609 m .54969 .61382 L .53356 .60634 L p
1 g
F P
s
P
p
.002 w
.68023 .47604 m .67695 .41218 L .68762 .40213 L p
1 g
F P
s
P
p
.002 w
.6625 .34011 m .68762 .40213 L .67695 .41218 L p
1 g
F P
s
P
p
.002 w
.4769 .26771 m .41674 .27505 L .42335 .25849 L p
1 g
F P
s
P
p
.002 w
.42335 .25849 m .48597 .25064 L .4769 .26771 L p
1 g
F P
s
P
p
.002 w
.33309 .43773 m .33128 .47808 L .31644 .47072 L p
1 g
F P
s
P
p
.002 w
.31644 .47072 m .31842 .42315 L .33309 .43773 L p
1 g
F P
s
P
p
.002 w
.60787 .29939 m .55011 .26466 L .55983 .25339 L p
1 g
F P
s
P
p
.002 w
.55983 .25339 m .61809 .28835 L .60787 .29939 L p
1 g
F P
s
P
p
.002 w
.41238 .29686 m .36426 .32141 L .36498 .30175 L p
1 g
F P
s
P
p
.002 w
.36498 .30175 m .41674 .27505 L .41238 .29686 L p
1 g
F P
s
P
p
.002 w
.43586 .59755 m .47668 .602 L .48732 .61637 L p
1 g
F P
s
P
p
.002 w
.53356 .60634 m .48732 .61637 L .47668 .602 L p
1 g
F P
s
P
p
.002 w
.67695 .41218 m .65195 .35072 L .6625 .34011 L p
1 g
F P
s
P
p
.002 w
.61809 .28835 m .6625 .34011 L .65195 .35072 L p
1 g
F P
s
P
p
.002 w
.64676 .54087 m .66394 .4845 L .68023 .47604 L p
1 g
F P
s
P
p
.002 w
.67695 .41218 m .68023 .47604 L .66394 .4845 L p
1 g
F P
s
P
p
.002 w
.36759 .34501 m .3359 .37965 L .32888 .36048 L p
1 g
F P
s
P
p
.002 w
.32888 .36048 m .36426 .32141 L .36759 .34501 L p
1 g
F P
s
P
p
.002 w
.65195 .35072 m .60787 .29939 L .61809 .28835 L p
1 g
F P
s
P
p
.002 w
.59425 .58609 m .62645 .54399 L .64676 .54087 L p
1 g
F P
s
P
p
.002 w
.66394 .4845 m .64676 .54087 L .62645 .54399 L p
1 g
F P
s
P
p
.002 w
.36045 .5157 m .37847 .54363 L .36532 .55324 L p
1 g
F P
s
P
p
.002 w
.36532 .55324 m .34247 .5179 L .36045 .5157 L p
1 g
F P
s
P
p
.002 w
.3975 .58069 m .36532 .55324 L .37847 .54363 L p
1 g
F P
s
P
p
.002 w
.53356 .60634 m .57318 .58144 L .59425 .58609 L p
1 g
F P
s
P
p
.002 w
.62645 .54399 m .59425 .58609 L .57318 .58144 L p
1 g
F P
s
P
p
.002 w
.37847 .54363 m .4039 .56531 L .3975 .58069 L p
1 g
F P
s
P
p
.002 w
.43586 .59755 m .3975 .58069 L .4039 .56531 L p
1 g
F P
s
P
p
.002 w
.34808 .401 m .33309 .43773 L .31842 .42315 L p
1 g
F P
s
P
p
.002 w
.31842 .42315 m .3359 .37965 L .34808 .401 L p
1 g
F P
s
P
p
.002 w
.53851 .28135 m .4769 .26771 L .48597 .25064 L p
1 g
F P
s
P
p
.002 w
.48597 .25064 m .55011 .26466 L .53851 .28135 L p
1 g
F P
s
P
p
.002 w
.35172 .4843 m .36045 .5157 L .34247 .5179 L p
1 g
F P
s
P
p
.002 w
.34247 .5179 m .33128 .47808 L .35172 .4843 L p
1 g
F P
s
P
p
.002 w
.47668 .602 m .51584 .59334 L .53356 .60634 L p
1 g
F P
s
P
p
.002 w
.57318 .58144 m .53356 .60634 L .51584 .59334 L p
1 g
F P
s
P
p
.002 w
.4039 .56531 m .4342 .57857 L .43586 .59755 L p
1 g
F P
s
P
p
.002 w
.47668 .602 m .43586 .59755 L .4342 .57857 L p
1 g
F P
s
P
p
.002 w
.66394 .4845 m .66059 .42316 L .67695 .41218 L p
1 g
F P
s
P
p
.002 w
.65195 .35072 m .67695 .41218 L .66059 .42316 L p
1 g
F P
s
P
p
.002 w
.46821 .29031 m .41238 .29686 L .41674 .27505 L p
1 g
F P
s
P
p
.002 w
.41674 .27505 m .4769 .26771 L .46821 .29031 L p
1 g
F P
s
P
p
.002 w
.3533 .45258 m .35172 .4843 L .33128 .47808 L p
1 g
F P
s
P
p
.002 w
.33128 .47808 m .33309 .43773 L .3533 .45258 L p
1 g
F P
s
P
p
.002 w
.41054 .32343 m .36759 .34501 L .36426 .32141 L p
1 g
F P
s
P
p
.002 w
.36426 .32141 m .41238 .29686 L .41054 .32343 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.59401 .31481 m .53851 .28135 L .55011 .26466 L p
1 g
F P
s
P
p
.002 w
.55011 .26466 m .60787 .29939 L .59401 .31481 L p
1 g
F P
s
P
p
.002 w
.4342 .57857 m .46635 .58197 L .47668 .602 L p
1 g
F P
s
P
p
.002 w
.51584 .59334 m .47668 .602 L .46635 .58197 L p
1 g
F P
s
P
p
.002 w
.62645 .54399 m .64213 .49164 L .66394 .4845 L p
1 g
F P
s
P
p
.002 w
.66059 .42316 m .66394 .4845 L .64213 .49164 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37504 .37193 m .34808 .401 L .3359 .37965 L p
1 g
F P
s
P
p
.002 w
.3359 .37965 m .36759 .34501 L .37504 .37193 L p
1 g
F P
s
P
p
.002 w
.66059 .42316 m .63643 .36414 L .65195 .35072 L p
1 g
F P
s
P
p
.002 w
.60787 .29939 m .65195 .35072 L .63643 .36414 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.57318 .58144 m .60165 .5438 L .62645 .54399 L p
1 g
F P
s
P
p
.002 w
.64213 .49164 m .62645 .54399 L .60165 .5438 L p
1 g
F P
s
P
p
.002 w
.63643 .36414 m .59401 .31481 L .60787 .29939 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.51584 .59334 m .54923 .5721 L .57318 .58144 L p
1 g
F P
s
P
p
.002 w
.60165 .5438 m .57318 .58144 L .54923 .5721 L p
1 g
F P
s
P
p
.002 w
.36523 .42387 m .3533 .45258 L .33309 .43773 L p
1 g
F P
s
P
p
.002 w
.33309 .43773 m .34808 .401 L .36523 .42387 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.4039 .56531 m .37847 .54363 L .39578 .53024 L p
1 g
F P
s
P
p
.002 w
.38332 .51085 m .39578 .53024 L .37847 .54363 L p
1 g
F P
s
P
p
.002 w
.37847 .54363 m .36045 .5157 L .38332 .51085 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.39578 .53024 m .41343 .54528 L .4039 .56531 L p
1 g
F P
s
P
p
.002 w
.4342 .57857 m .4039 .56531 L .41343 .54528 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52534 .30315 m .46821 .29031 L .4769 .26771 L p
1 g
F P
s
P
p
.002 w
.4769 .26771 m .53851 .28135 L .52534 .30315 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.46635 .58197 m .4753 .57994 L p
.51584 .59334 L 1 g
F P
s
P
p
.002 w
.4753 .57994 m .4811 .57862 L p
.48503 .58029 L 1 g
F P
s
P
p
.51584 .59334 m .4753 .57994 L .48503 .58029 L 1 g
F
P
p
.51079 .57862 m .49977 .58082 L .50315 .58095 L 1 g
F
P
p
.002 w
.54017 .57786 m .51584 .59334 L .50447 .58223 L p
1 g
F P
s
P
p
.002 w
.50447 .58223 m .50315 .58095 L p
.51092 .5803 L 1 g
F P
s
P
p
.54017 .57786 m .50447 .58223 L .51092 .5803 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .5803 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .5803 L .52403 .57637 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5316 .5741 L p
1 g
F P
s
P
p
.002 w
.54923 .5721 m .54017 .57786 L p
.52654 .57696 L 1 g
F P
s
P
p
.54923 .5721 m .52654 .57696 L .52881 .57568 L 1 g
F
P
p
.54854 .56129 m .5316 .5741 L .54021 .56923 L 1 g
F
P
p
.002 w
.5316 .5741 m .53128 .57265 L p
.52403 .57637 L 1 g
F P
s
P
p
.53577 .57285 m .52287 .57672 L .49707 .575 L 1 g
F
P
p
.54923 .5721 m .52287 .57672 L .53577 .57285 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.54854 .56129 m .54021 .56923 L .54197 .56823 L 1 g
F
P
p
.002 w
.56518 .55069 m .54923 .5721 L .54405 .56934 L p
1 g
F P
s
P
p
.002 w
.54405 .56934 m .54197 .56823 L p
.54911 .56283 L 1 g
F P
s
P
p
.56518 .55069 m .54405 .56934 L .54911 .56283 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56283 L p
1 g
F P
s
P
p
.56075 .54566 m .54911 .56283 L .55654 .55329 L 1 g
F
P
p
.002 w
.54911 .56283 m .54854 .56129 L p
.54197 .56823 L 1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56145 .54698 m .56075 .54566 L p
.55654 .55329 L 1 g
F P
s
P
p
.002 w
.54197 .56823 m .5231 .55818 L p
.5575 .55206 L 1 g
F P
s
P
p
.56518 .55069 m .54911 .56283 L .5575 .55206 L 1 g
F
P
p
.54911 .56283 m .54197 .56823 L .5575 .55206 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.57303 .54016 m .56518 .55069 L p
.55972 .55166 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56145 .54698 L p
1 g
F P
s
P
p
.56654 .52734 m .56145 .54698 L .56441 .53898 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56258 .54393 m .55972 .55166 L .5231 .55818 L 1 g
F
P
p
.57303 .54016 m .55972 .55166 L .56258 .54393 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.56654 .52734 m .56441 .53898 L .56468 .53827 L 1 g
F
P
p
.58427 .50072 m .56757 .53272 L .57209 .50993 L 1 g
F
P
p
.56757 .53272 m .56468 .53827 L .56726 .52839 L 1 g
F
P
p
.56757 .53272 m .56726 .52839 L .57209 .50993 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56726 .52839 L p
1 g
F P
s
P
p
.56515 .50826 m .56726 .52839 L .56639 .51628 L 1 g
F
P
p
.002 w
.56726 .52839 m .56654 .52734 L p
.56468 .53827 L 1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56587 .50912 m .56515 .50826 L p
.56639 .51628 L 1 g
F P
s
P
p
.002 w
.56468 .53827 m .54149 .53305 L p
.56625 .51434 L 1 g
F P
s
P
p
.57209 .50993 m .56726 .52839 L .56625 .51434 L 1 g
F
P
p
.56726 .52839 m .56468 .53827 L .56625 .51434 L 1 g
F
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56587 .50912 L p
1 g
F P
s
P
p
.55661 .4905 m .56587 .50912 L .56242 .50167 L 1 g
F
P
p
.55759 .49152 m .56242 .50167 L .5575 .49165 L 1 g
F
P
p
.58129 .45811 m .5641 .49781 L .55759 .49152 L 1 g
F
P
p
.5641 .49781 m .56242 .50167 L .55759 .49152 L 1 g
F
P
p
.55661 .4905 m .56242 .50167 L .56208 .50097 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.58129 .45811 m .58427 .50072 L .56242 .50167 L p
1 g
F P
s
P
p
.002 w
.56242 .50167 m .58427 .50072 L p
.56776 .5132 L 1 g
F P
s
P
p
.002 w
.54747 .46899 m .58129 .45811 L p
.55759 .49152 L 1 g
F P
s
P
p
.55759 .49152 m .5575 .49165 L .55733 .49126 L 1 g
F
P
p
.55759 .49152 m .55733 .49126 L .54747 .46899 L 1 g
F
P
p
.002 w
.54768 .47169 m .54747 .46899 L p
.5575 .49165 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55729 .49122 L p
1 g
F P
s
P
p
.002 w
.55729 .49122 m .55661 .4905 L p
.56208 .50097 L 1 g
F P
s
P
p
.56208 .50097 m .56713 .51061 L .55729 .49122 L 1 g
F
P
p
.54174 .47608 m .55017 .48434 L .54853 .48275 L 1 g
F
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54853 .48275 m .55002 .5022 L p
.54119 .47618 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47673 L p
1 g
F P
s
P
p
.52214 .46667 m .54233 .47673 L .53389 .47272 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53389 .47272 m .51191 .47876 L p
.51837 .46657 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52242 .46713 L p
1 g
F P
s
P
p
.5 .4634 m .52242 .46713 L .51194 .4657 L 1 g
F
P
p
.51897 .46545 m .52242 .46713 L .51837 .46657 L 1 g
F
P
p
.52242 .46713 m .53389 .47272 L .51837 .46657 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50257 .45709 m .53395 .43722 L p
.51837 .46657 L 1 g
F P
s
P
p
.002 w
.51191 .47876 m .50593 .46487 L p
.51837 .46657 L 1 g
F P
s
P
p
.5 .4634 m .51194 .4657 L .50593 .46487 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50593 .46487 m .51191 .47876 L p
.49775 .46425 L 1 g
F P
s
P
p
.50593 .46487 m .49775 .46425 L .5 .46392 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.51191 .47876 m .47597 .48702 L p
.49597 .46452 L 1 g
F P
s
P
p
.49775 .46425 m .51191 .47876 L .49597 .46452 L 1 g
F
P
p
.47786 .46667 m .5 .46392 L .48934 .4655 L 1 g
F
P
p
.47786 .46667 m .48934 .4655 L .48846 .46563 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.48846 .46563 m .4712 .47608 L p
.47426 .46881 L 1 g
F P
s
P
p
.47754 .4672 m .48846 .46563 L .47426 .46881 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46965 .47109 L 1 g
F
P
p
.45826 .47608 m .46965 .47109 L .4677 .47205 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.4677 .47205 m .4712 .47608 L p
.45598 .47837 L 1 g
F P
s
P
p
.4677 .47205 m .45598 .47837 L .45764 .47675 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45764 .47675 L p
1 g
F P
s
P
p
.45598 .47837 m .4712 .47608 L .44375 .49024 L 1 g
F
P
p
.002 w
.45764 .47675 m .45698 .47747 L p
.45047 .48371 L 1 g
F P
s
P
p
.44339 .4905 m .45764 .47675 L .45047 .48371 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42594 .52109 m .44106 .49346 L .44091 .49459 L p
1 g
F P
s
P
p
.002 w
.43392 .50936 m .43485 .50826 L p
.43868 .4993 L 1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43259 .52396 m .42796 .52196 L p
.43392 .50936 L 1 g
F P
s
P
p
.002 w
.42796 .52196 m .42594 .52109 L p
.43419 .50649 L 1 g
F P
s
P
p
.43392 .50936 m .43419 .50649 L .44091 .49459 L 1 g
F
P
p
.42796 .52196 m .43419 .50649 L .43392 .50936 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43392 .50936 L p
1 g
F P
s
P
p
.002 w
.43392 .50936 m .43287 .51061 L p
.43313 .51799 L 1 g
F P
s
P
p
.43346 .52734 m .43392 .50936 L .43313 .51799 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.43446 .55443 m .43195 .54462 L .43439 .53504 L 1 g
F
P
p
.002 w
.43568 .53915 m .43446 .55443 L p
.43439 .53504 L 1 g
F P
s
P
p
.002 w
.42594 .52109 m .43064 .52312 L p
.43195 .54462 L 1 g
F P
s
P
p
.002 w
.43064 .52312 m .43259 .52396 L p
.43244 .52883 L 1 g
F P
s
P
p
.43195 .54462 m .43064 .52312 L .43244 .52883 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43244 .52883 L p
1 g
F P
s
P
p
.43925 .54566 m .43244 .52883 L .43523 .53771 L 1 g
F
P
p
.43346 .52734 m .43313 .51799 L .43259 .52396 L 1 g
F
P
p
.002 w
.43244 .52883 m .43346 .52734 L p
.43259 .52396 L 1 g
F P
s
P
p
.002 w
.43259 .52396 m .43675 .52576 L p
.43195 .54462 L 1 g
F P
s
P
p
.002 w
.43244 .52883 m .43146 .53025 L p
.43523 .53771 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.4442 .55541 m .44097 .55509 L p
.44022 .54986 L 1 g
F P
s
P
p
.002 w
.44097 .55509 m .43446 .55443 L .43537 .54308 L p
1 g
F P
s
P
p
.002 w
.43537 .54308 m .43568 .53915 L p
.43838 .54729 L 1 g
F P
s
P
p
.44097 .55509 m .43537 .54308 L .43838 .54729 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43838 .54729 L p
1 g
F P
s
P
p
.45146 .56129 m .43838 .54729 L .44337 .55426 L 1 g
F
P
p
.43925 .54566 m .43523 .53771 L .43568 .53915 L 1 g
F
P
p
.002 w
.43838 .54729 m .43925 .54566 L p
.43568 .53915 L 1 g
F P
s
P
p
.002 w
.43568 .53915 m .43675 .52576 L p
.44097 .55509 L 1 g
F P
s
P
p
.002 w
.43838 .54729 m .43743 .5491 L p
.44337 .55426 L 1 g
F P
s
P
p
.46635 .58197 m .43922 .55491 L .45003 .56241 L 1 g
F
P
p
.46872 .57265 m .45946 .56895 L .46208 .57077 L 1 g
F
P
p
.002 w
.47671 .57962 m .46635 .58197 L .46285 .57279 L p
1 g
F P
s
P
p
.002 w
.46285 .57279 m .46208 .57077 L p
.46831 .57454 L 1 g
F P
s
P
p
.47671 .57962 m .46285 .57279 L .46831 .57454 L 1 g
F
P
p
.002 w
.48907 .58044 m .48921 .57862 L p
.47827 .57772 L 1 g
F P
s
P
p
.47827 .57772 m .4811 .57862 L .48907 .58044 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.4811 .57862 m .47671 .57962 L p
.47381 .5763 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57454 L p
1 g
F P
s
P
p
.47671 .57962 m .46831 .57454 L .47381 .5763 L 1 g
F
P
p
.002 w
.46831 .57454 m .4678 .57686 L p
.47827 .57772 L 1 g
F P
s
P
p
.48921 .57862 m .46831 .57454 L .47827 .57772 L 1 g
F
P
p
.002 w
.46831 .57454 m .46872 .57265 L p
.46208 .57077 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45084 .56297 L p
1 g
F P
s
P
p
.46872 .57265 m .45084 .56297 L .45946 .56895 L 1 g
F
P
p
.45146 .56129 m .44337 .55426 L .4442 .55541 L 1 g
F
P
p
.002 w
.45084 .56297 m .45146 .56129 L p
.4442 .55541 L 1 g
F P
s
P
p
.002 w
.4442 .55541 m .45672 .55668 L .46208 .57077 L p
1 g
F P
s
P
p
.002 w
.46208 .57077 m .46544 .57959 L p
.45084 .56297 L 1 g
F P
s
P
p
.45084 .56297 m .4442 .55541 L .46208 .57077 L 1 g
F
P
p
.002 w
.46544 .57959 m .46635 .58197 L p
.4442 .55541 L 1 g
F P
s
P
p
.002 w
.45084 .56297 m .45002 .56518 L p
.45946 .56895 L 1 g
F P
s
P
p
.002 w
.46208 .57077 m .45672 .55668 L p
.47381 .5763 L 1 g
F P
s
P
p
.46831 .57454 m .46208 .57077 L .47381 .5763 L 1 g
F
P
p
.002 w
.49707 .575 m .4811 .57862 L p
.45672 .55668 L 1 g
F P
s
P
p
.4811 .57862 m .47381 .5763 L .45672 .55668 L 1 g
F
P
p
.47827 .57772 m .47648 .57757 L .4811 .57862 L 1 g
F
P
p
.002 w
.50674 .58445 m .51584 .59334 L p
.48503 .58029 L 1 g
F P
s
P
p
.48503 .58029 m .4811 .57862 L .48907 .58044 L 1 g
F
P
p
.48503 .58029 m .48907 .58044 L .50674 .58445 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48907 .58044 L p
1 g
F P
s
P
p
.51079 .57862 m .48907 .58044 L .49977 .58082 L 1 g
F
P
p
.002 w
.4811 .57862 m .49707 .575 L .50315 .58095 L p
1 g
F P
s
P
p
.002 w
.50315 .58095 m .50674 .58445 L p
.48907 .58044 L 1 g
F P
s
P
p
.48907 .58044 m .4811 .57862 L .50315 .58095 L 1 g
F
P
p
.002 w
.48907 .58044 m .48889 .583 L p
.49977 .58082 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58116 L p
1 g
F P
s
P
p
.002 w
.48902 .58116 m .48907 .58044 L p
.48421 .57962 L 1 g
F P
s
P
p
.48421 .57962 m .4678 .57686 L .48902 .58116 L 1 g
F
P
p
.002 w
.4682 .57502 m .46831 .57454 L p
.46208 .57077 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4682 .57502 L p
1 g
F P
s
P
p
.45946 .56895 m .45002 .56518 L .4682 .57502 L 1 g
F
P
p
.002 w
.43446 .55443 m .43922 .55491 L p
.46635 .58197 L 1 g
F P
s
P
p
.002 w
.43922 .55491 m .4442 .55541 L p
.45003 .56241 L 1 g
F P
s
P
p
.002 w
.45041 .5641 m .45084 .56297 L p
.4442 .55541 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45041 .5641 L p
1 g
F P
s
P
p
.44337 .55426 m .43743 .5491 L .45041 .5641 L 1 g
F
P
p
.002 w
.45672 .55668 m .4442 .55541 L p
.43675 .52576 L 1 g
F P
s
P
p
.4442 .55541 m .44022 .54986 L .43675 .52576 L 1 g
F
P
p
.002 w
.43829 .54746 m .43838 .54729 L p
.43568 .53915 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43829 .54746 L p
1 g
F P
s
P
p
.43523 .53771 m .43146 .53025 L .43829 .54746 L 1 g
F
P
p
.002 w
.43675 .52576 m .43568 .53915 L p
.43439 .53504 L 1 g
F P
s
P
p
.002 w
.4321 .52933 m .43244 .52883 L p
.43259 .52396 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4321 .52933 L p
1 g
F P
s
P
p
.43313 .51799 m .43287 .51061 L .4321 .52933 L 1 g
F
P
p
.002 w
.44161 .49314 m .44106 .49346 L .44204 .49229 L p
1 g
F P
s
P
p
.002 w
.44106 .49346 m .45294 .46056 L .45678 .46293 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44241 .49154 L p
1 g
F P
s
P
p
.43485 .50826 m .44241 .49154 L .44236 .49164 L 1 g
F
P
p
.002 w
.44204 .49229 m .44106 .49346 L p
.44169 .49224 L 1 g
F P
s
P
p
.45678 .46293 m .44241 .49154 L .44169 .49224 L 1 g
F
P
p
.44241 .49154 m .44204 .49229 L .44169 .49224 L 1 g
F
P
p
.44339 .4905 m .45047 .48371 L .44375 .49024 L 1 g
F
P
p
.002 w
.44241 .49154 m .44339 .4905 L p
.44375 .49024 L 1 g
F P
s
P
p
.44229 .49178 m .4424 .49155 L .44233 .4917 L 1 g
F
P
p
.43485 .50826 m .44236 .49164 L .44229 .49178 L 1 g
F
P
p
.44236 .49164 m .4424 .49155 L .44229 .49178 L 1 g
F
P
p
.43485 .50826 m .44239 .49156 L .44229 .49177 L 1 g
F
P
p
.43485 .50826 m .44237 .49158 L .44224 .49184 L 1 g
F
P
p
.43485 .50826 m .44235 .4916 L .44221 .49189 L 1 g
F
P
p
.43485 .50826 m .44233 .49162 L .44219 .49192 L 1 g
F
P
p
.43485 .50826 m .44231 .49164 L .44219 .4919 L 1 g
F
P
p
.43485 .50826 m .4423 .49166 L .43874 .49916 L 1 g
F
P
p
.002 w
.4712 .47608 m .44161 .49314 L p
.44375 .49024 L 1 g
F P
s
P
p
.002 w
.44204 .49229 m .44375 .49024 L p
.44161 .49314 L 1 g
F P
s
P
p
.44375 .49024 m .45698 .47747 L .44241 .49154 L 1 g
F
P
p
.45047 .48371 m .45053 .48366 L .44375 .49024 L 1 g
F
P
p
.45053 .48366 m .45698 .47747 L .44375 .49024 L 1 g
F
P
p
.002 w
.45678 .46293 m .46324 .46692 L .44375 .49024 L p
1 g
F P
s
P
p
.002 w
.44375 .49024 m .44204 .49229 L p
.44241 .49154 L 1 g
F P
s
P
p
.45678 .46293 m .44375 .49024 L .44241 .49154 L 1 g
F
P
p
.002 w
.44241 .49154 m .44241 .49154 L p
.44375 .49024 L 1 g
F P
s
P
p
.002 w
.44241 .49154 m .4424 .49155 L p
.44236 .49164 L 1 g
F P
s
P
p
.002 w
.4424 .49155 m .44239 .49156 L p
.44233 .4917 L 1 g
F P
s
P
p
.002 w
.4712 .47608 m .47597 .48702 L .44149 .49338 L p
1 g
F P
s
P
p
.002 w
.44149 .49338 m .44106 .49346 L .44161 .49314 L p
1 g
F P
s
P
p
.002 w
.44161 .49314 m .4712 .47608 L p
.44149 .49338 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.47597 .48702 m .47701 .49851 L .44143 .49351 L p
1 g
F P
s
P
p
.002 w
.44143 .49351 m .44106 .49346 L .44149 .49338 L p
1 g
F P
s
P
p
.002 w
.44149 .49338 m .47597 .48702 L p
.44143 .49351 L 1 g
F P
s
P
p
.002 w
.44239 .49156 m .44237 .49158 L p
.44229 .49177 L 1 g
F P
s
P
p
.002 w
.44237 .49158 m .44235 .4916 L p
.44224 .49184 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.47701 .49851 m .47424 .50929 L .44138 .49361 L p
1 g
F P
s
P
p
.002 w
.44138 .49361 m .44106 .49346 L .44143 .49351 L p
1 g
F P
s
P
p
.002 w
.44143 .49351 m .47701 .49851 L p
.44138 .49361 L 1 g
F P
s
P
p
.002 w
.47424 .50929 m .46799 .51818 L .44133 .4937 L p
1 g
F P
s
P
p
.002 w
.44133 .4937 m .44106 .49346 L .44138 .49361 L p
1 g
F P
s
P
p
.002 w
.44138 .49361 m .47424 .50929 L p
.44133 .4937 L 1 g
F P
s
P
p
.002 w
.44235 .4916 m .44233 .49162 L p
.44221 .49189 L 1 g
F P
s
P
p
.002 w
.44233 .49162 m .44231 .49164 L p
.44219 .49192 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46799 .51818 m .45897 .52425 L .44127 .49382 L p
1 g
F P
s
P
p
.002 w
.44127 .49382 m .44106 .49346 L .44133 .4937 L p
1 g
F P
s
P
p
.002 w
.44133 .4937 m .46799 .51818 L p
.44127 .49382 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45897 .52425 m .44817 .52686 L .44118 .49402 L p
1 g
F P
s
P
p
.002 w
.44118 .49402 m .44106 .49346 L .44127 .49382 L p
1 g
F P
s
P
p
.002 w
.44127 .49382 m .45897 .52425 L p
.44118 .49402 L 1 g
F P
s
P
p
.002 w
.44231 .49164 m .4423 .49166 L p
.44219 .4919 L 1 g
F P
s
P
p
.002 w
.44091 .49459 m .44106 .49346 L .44118 .49402 L p
1 g
F P
s
P
p
.002 w
.4423 .49166 m .44166 .49233 L p
.43874 .49916 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44817 .52686 m .43675 .52576 L .44091 .49459 L p
1 g
F P
s
P
p
.002 w
.44118 .49402 m .44817 .52686 L p
.44091 .49459 L 1 g
F P
s
P
p
.002 w
.44091 .49459 m .43675 .52576 L .43259 .52396 L p
1 g
F P
s
P
p
.43259 .52396 m .43392 .50936 L .44091 .49459 L 1 g
F
P
p
.002 w
.43287 .51061 m .43392 .50936 L p
.43961 .49712 L 1 g
F P
s
P
p
.43868 .4993 m .43961 .49712 L .43392 .50936 L 1 g
F
P
p
.002 w
.44166 .49233 m .43338 .50956 L p
.43961 .49712 L 1 g
F P
s
P
p
.002 w
.43338 .50956 m .43287 .51061 L p
.43961 .49712 L 1 g
F P
s
P
p
.002 w
.44375 .49024 m .45334 .47877 L p
.45598 .47837 L 1 g
F P
s
P
p
.45764 .47675 m .45598 .47837 L .45334 .47877 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44241 .49154 L p
1 g
F P
s
P
p
.002 w
.45723 .47721 m .45764 .47675 L p
.4677 .47205 L 1 g
F P
s
P
p
.002 w
.45764 .47675 m .45826 .47608 L p
.4677 .47205 L 1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45334 .47877 m .46324 .46692 L .4677 .47205 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.4712 .47608 m .46324 .46692 L .48682 .43894 L p
1 g
F P
s
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46965 .47109 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.48682 .43894 m .48824 .46193 L .47477 .46759 L 1 g
F
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.48846 .46563 L 1 g
F P
s
P
p
.48824 .46193 m .48846 .46563 L .47754 .4672 L 1 g
F
P
p
.48824 .46193 m .47754 .4672 L .47477 .46759 L 1 g
F
P
p
.47477 .46759 m .47754 .4672 L .47426 .46881 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45723 .47721 L p
1 g
F P
s
P
p
.46965 .47109 m .47718 .46778 L .45723 .47721 L 1 g
F
P
p
.002 w
.4775 .46726 m .47754 .4672 L p
.48846 .46563 L 1 g
F P
s
P
p
.002 w
.48682 .43894 m .50257 .45709 L .48846 .46563 L p
1 g
F P
s
P
p
.002 w
.47597 .48702 m .4712 .47608 L .50257 .45709 L p
1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .46442 L p
.48934 .4655 L 1 g
F P
s
P
p
.49694 .46342 m .49775 .46425 L .49597 .46452 L 1 g
F
P
p
.5 .46392 m .49775 .46425 L .49694 .46342 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4775 .46726 L p
1 g
F P
s
P
p
.48934 .4655 m .5 .46442 L .4775 .46726 L 1 g
F
P
p
.002 w
.5 .46406 m .5 .46392 L p
.50593 .46487 L 1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .4634 L p
.50593 .46487 L 1 g
F P
s
P
p
.002 w
.50257 .45709 m .50593 .46487 L p
.49694 .46342 L 1 g
F P
s
P
p
.002 w
.50593 .46487 m .50257 .45709 L p
.51837 .46657 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46406 L p
1 g
F P
s
P
p
.51194 .4657 m .52282 .46778 L .5 .46406 L 1 g
F
P
p
.002 w
.52242 .46713 m .52282 .46778 L p
.51194 .4657 L 1 g
F P
s
P
p
.5329 .47224 m .53389 .47272 L .53321 .4724 L 1 g
F
P
p
.52214 .46667 m .53389 .47272 L .5329 .47224 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.53395 .43722 m .54747 .46899 L .53389 .47272 L p
1 g
F P
s
P
p
.54853 .48275 m .54119 .47618 L .54233 .47673 L 1 g
F
P
p
.002 w
.55002 .5022 m .5138 .50146 L p
.5409 .47533 L 1 g
F P
s
P
p
.002 w
.5138 .50146 m .51191 .47876 L .53389 .47272 L p
1 g
F P
s
P
p
.5404 .47581 m .5138 .50146 L .53389 .47272 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52255 .46734 L p
1 g
F P
s
P
p
.002 w
.52255 .46734 m .52214 .46667 L p
.53321 .4724 L 1 g
F P
s
P
p
.53321 .4724 m .54302 .47747 L .52255 .46734 L 1 g
F
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.53389 .47272 m .54747 .46899 L p
.5404 .47581 L 1 g
F P
s
P
p
.53395 .43722 m .53389 .47272 L .51897 .46545 L 1 g
F
P
p
.54233 .47673 m .54119 .47618 L .5409 .47533 L 1 g
F
P
p
.002 w
.54233 .47673 m .54302 .47747 L p
.53321 .4724 L 1 g
F P
s
P
p
.002 w
.54254 .47696 m .54233 .47673 L p
.54853 .48275 L 1 g
F P
s
P
p
.002 w
.54233 .47673 m .54174 .47608 L p
.54853 .48275 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55729 .49122 L p
1 g
F P
s
P
p
.54174 .47608 m .55729 .49122 L .55017 .48434 L 1 g
F
P
p
.002 w
.54747 .46899 m .54853 .48275 L p
.5409 .47533 L 1 g
F P
s
P
p
.002 w
.55002 .5022 m .54768 .47169 L p
.5575 .49165 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54254 .47696 L p
1 g
F P
s
P
p
.55017 .48434 m .55834 .49233 L .54254 .47696 L 1 g
F
P
p
.002 w
.55729 .49122 m .55834 .49233 L p
.55017 .48434 L 1 g
F P
s
P
p
.56208 .50097 m .56242 .50167 L .56226 .50131 L 1 g
F
P
p
.002 w
.56242 .50167 m .55002 .5022 L p
.5575 .49165 L 1 g
F P
s
P
p
.002 w
.54149 .53305 m .55002 .5022 L .56242 .50167 L p
1 g
F P
s
P
p
.56776 .5132 m .54149 .53305 L .56242 .50167 L 1 g
F
P
p
.002 w
.56587 .50912 m .56713 .51061 L p
.56226 .50131 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56587 .50912 L p
1 g
F P
s
P
p
.56639 .51628 m .56854 .53025 L .56587 .50912 L 1 g
F
P
p
.002 w
.56726 .52839 m .56854 .53025 L p
.56639 .51628 L 1 g
F P
s
P
p
.002 w
.56796 .52941 m .56726 .52839 L p
.56468 .53827 L 1 g
F P
s
P
p
.002 w
.58427 .50072 m .57303 .54016 L .56468 .53827 L p
1 g
F P
s
P
p
.002 w
.5231 .55818 m .54149 .53305 L .56468 .53827 L p
1 g
F P
s
P
p
.002 w
.56468 .53827 m .57303 .54016 L p
.56258 .54393 L 1 g
F P
s
P
p
.56258 .54393 m .5231 .55818 L .56468 .53827 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56796 .52941 L p
1 g
F P
s
P
p
.56441 .53898 m .56257 .5491 L .56796 .52941 L 1 g
F
P
p
.002 w
.56145 .54698 m .56257 .5491 L p
.56441 .53898 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56145 .54698 L p
1 g
F P
s
P
p
.55654 .55329 m .54998 .56518 L .56145 .54698 L 1 g
F
P
p
.002 w
.54911 .56283 m .54998 .56518 L p
.55654 .55329 L 1 g
F P
s
P
p
.002 w
.54953 .56396 m .54911 .56283 L p
.54197 .56823 L 1 g
F P
s
P
p
.002 w
.49707 .575 m .5231 .55818 L .54197 .56823 L p
1 g
F P
s
P
p
.002 w
.54197 .56823 m .54923 .5721 L p
.5336 .57297 L 1 g
F P
s
P
p
.5336 .57297 m .49707 .575 L .54197 .56823 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54953 .56396 L p
1 g
F P
s
P
p
.54021 .56923 m .5322 .57686 L .54953 .56396 L 1 g
F
P
p
.002 w
.5316 .5741 m .5322 .57686 L p
.54021 .56923 L 1 g
F P
s
P
p
.52881 .57568 m .52654 .57696 L .52287 .57672 L 1 g
F
P
p
.002 w
.51092 .5803 m .51079 .57862 L p
.50315 .58095 L 1 g
F P
s
P
p
.002 w
.50315 .58095 m .49707 .575 L p
.54017 .57786 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5316 .5741 L p
1 g
F P
s
P
p
.52403 .57637 m .51111 .583 L .5316 .5741 L 1 g
F
P
p
.002 w
.51092 .5803 m .51111 .583 L p
.52403 .57637 L 1 g
F P
s
P
p
.002 w
.51098 .58123 m .51092 .5803 L p
.50315 .58095 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51098 .58123 L p
1 g
F P
s
P
p
.49977 .58082 m .48889 .583 L .51098 .58123 L 1 g
F
P
p
.47648 .57757 m .4678 .57686 L .48907 .58044 L 1 g
F
P
p
.002 w
.37735 .48908 m .38332 .51085 L .36045 .5157 L p
1 g
F P
s
P
p
.002 w
.36045 .5157 m .35172 .4843 L .37735 .48908 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.41343 .54528 m .43446 .55443 L .4342 .57857 L p
1 g
F P
s
P
p
.002 w
.46635 .58197 m .4342 .57857 L .43446 .55443 L p
1 g
F P
s
P
p
.002 w
.64213 .49164 m .63879 .43475 L .66059 .42316 L p
1 g
F P
s
P
p
.002 w
.63643 .36414 m .66059 .42316 L .63879 .43475 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.46024 .31787 m .41054 .32343 L .41238 .29686 L p
1 g
F P
s
P
p
.002 w
.41238 .29686 m .46821 .29031 L .46024 .31787 L p
1 g
F P
s
P
p
.004 w
.48936 .44187 m
.5 .43051 L
s
P
p
.002 w
.37856 .46719 m .37735 .48908 L .35172 .4843 L p
1 g
F P
s
P
p
.002 w
.35172 .4843 m .3533 .45258 L .37856 .46719 L p
1 g
F P
s
P
p
.002 w
.4114 .35399 m .37504 .37193 L .36759 .34501 L p
1 g
F P
s
P
p
.002 w
.36759 .34501 m .41054 .32343 L .4114 .35399 L p
1 g
F P
s
P
p
.002 w
.3865 .4013 m .36523 .42387 L .34808 .401 L p
1 g
F P
s
P
p
.002 w
.34808 .401 m .37504 .37193 L .3865 .4013 L p
1 g
F P
s
P
p
.002 w
.60165 .5438 m .61532 .49713 L .64213 .49164 L p
1 g
F P
s
P
p
.002 w
.63879 .43475 m .64213 .49164 L .61532 .49713 L p
1 g
F P
s
P
p
.002 w
.57681 .33428 m .52534 .30315 L .53851 .28135 L p
1 g
F P
s
P
p
.002 w
.53851 .28135 m .59401 .31481 L .57681 .33428 L p
1 g
F P
s
P
p
.002 w
.54923 .5721 m .57303 .54016 L .60165 .5438 L p
1 g
F P
s
P
p
.002 w
.61532 .49713 m .60165 .5438 L .57303 .54016 L p
1 g
F P
s
P
p
.002 w
.63879 .43475 m .61621 .38004 L .63643 .36414 L p
1 g
F P
s
P
p
.002 w
.59401 .31481 m .63643 .36414 L .61621 .38004 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61621 .38004 m .57681 .33428 L .59401 .31481 L p
1 g
F P
s
P
p
.002 w
.38694 .44748 m .37856 .46719 L .3533 .45258 L p
1 g
F P
s
P
p
.002 w
.3533 .45258 m .36523 .42387 L .38694 .44748 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.45672 .55668 m .47788 .55174 L .49707 .575 L p
1 g
F P
s
P
p
.002 w
.5231 .55818 m .49707 .575 L .47788 .55174 L p
1 g
F P
s
P
p
.002 w
.41343 .54528 m .39578 .53024 L .41686 .51336 L p
1 g
F P
s
P
p
.002 w
.41047 .50337 m .41686 .51336 L .39578 .53024 L p
1 g
F P
s
P
p
.002 w
.39578 .53024 m .38332 .51085 L .41047 .50337 L p
1 g
F P
s
P
p
.002 w
.51102 .3295 m .46024 .31787 L .46821 .29031 L p
1 g
F P
s
P
p
.002 w
.46821 .29031 m .52534 .30315 L .51102 .3295 L p
1 g
F P
s
P
p
.002 w
.41686 .51336 m .42594 .52109 L .41343 .54528 L p
1 g
F P
s
P
p
.002 w
.43446 .55443 m .41343 .54528 L .42594 .52109 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.40745 .49219 m .41047 .50337 L .38332 .51085 L p
1 g
F P
s
P
p
.002 w
.38332 .51085 m .37735 .48908 L .40745 .49219 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.45332 .34958 m .4114 .35399 L .41054 .32343 L p
1 g
F P
s
P
p
.002 w
.41054 .32343 m .46024 .31787 L .45332 .34958 L p
1 g
F P
s
P
p
.002 w
.61532 .49713 m .61208 .44654 L .63879 .43475 L p
1 g
F P
s
P
p
.002 w
.61621 .38004 m .63879 .43475 L .61208 .44654 L p
1 g
F P
s
P
p
.002 w
.41502 .38754 m .3865 .4013 L .37504 .37193 L p
1 g
F P
s
P
p
.002 w
.37504 .37193 m .4114 .35399 L .41502 .38754 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40815 .481 m .40745 .49219 L .37735 .48908 L p
1 g
F P
s
P
p
.002 w
.37735 .48908 m .37856 .46719 L .40815 .481 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.40169 .43212 m .38694 .44748 L .36523 .42387 L p
1 g
F P
s
P
p
.002 w
.36523 .42387 m .3865 .4013 L .40169 .43212 L p
1 g
F P
s
P
p
.002 w
.43675 .52576 m .44817 .52686 L .45672 .55668 L p
1 g
F P
s
P
p
.002 w
.47788 .55174 m .45672 .55668 L .44817 .52686 L p
1 g
F P
s
P
p
.002 w
.57303 .54016 m .58427 .50072 L .61532 .49713 L p
1 g
F P
s
P
p
.002 w
.61208 .44654 m .61532 .49713 L .58427 .50072 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.55675 .35727 m .51102 .3295 L .52534 .30315 L p
1 g
F P
s
P
p
.002 w
.52534 .30315 m .57681 .33428 L .55675 .35727 L p
1 g
F P
s
P
p
.002 w
.47788 .55174 m .49569 .54001 L .5231 .55818 L p
1 g
F P
s
P
p
.002 w
.54149 .53305 m .5231 .55818 L .49569 .54001 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.41251 .47098 m .40815 .481 L .37856 .46719 L p
1 g
F P
s
P
p
.002 w
.37856 .46719 m .38694 .44748 L .41251 .47098 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.61208 .44654 m .59184 .39794 L .61621 .38004 L p
1 g
F P
s
P
p
.002 w
.57681 .33428 m .61621 .38004 L .59184 .39794 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44817 .52686 m .45897 .52425 L .47788 .55174 L p
1 g
F P
s
P
p
.002 w
.49569 .54001 m .47788 .55174 L .45897 .52425 L p
1 g
F P
s
P
p
.002 w
.59184 .39794 m .55675 .35727 L .57681 .33428 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.49604 .35957 m .45332 .34958 L .46024 .31787 L p
1 g
F P
s
P
p
.002 w
.46024 .31787 m .51102 .3295 L .49604 .35957 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.42594 .52109 m .41686 .51336 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.41686 .51336 m .41047 .50337 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.42132 .42286 m .40169 .43212 L .3865 .4013 L p
1 g
F P
s
P
p
.002 w
.3865 .4013 m .41502 .38754 L .42132 .42286 L p
1 g
F P
s
P
p
.002 w
.44773 .38433 m .41502 .38754 L .4114 .35399 L p
1 g
F P
s
P
p
.002 w
.4114 .35399 m .45332 .34958 L .44773 .38433 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.41047 .50337 m .40745 .49219 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.4201 .46324 m .41251 .47098 L .38694 .44748 L p
1 g
F P
s
P
p
.002 w
.38694 .44748 m .40169 .43212 L .4201 .46324 L p
1 g
F P
s
P
p
.002 w
.58427 .50072 m .58129 .45811 L .61208 .44654 L p
1 g
F P
s
P
p
.002 w
.59184 .39794 m .61208 .44654 L .58129 .45811 L p
1 g
F P
s
P
p
.002 w
.40745 .49219 m .40815 .481 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.49569 .54001 m .50815 .52265 L .54149 .53305 L p
1 g
F P
s
P
p
.002 w
.55002 .5022 m .54149 .53305 L .50815 .52265 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45897 .52425 m .46799 .51818 L .49569 .54001 L p
1 g
F P
s
P
p
.002 w
.50815 .52265 m .49569 .54001 L .46799 .51818 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.40815 .481 m .41251 .47098 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53451 .38302 m .49604 .35957 L .51102 .3295 L p
1 g
F P
s
P
p
.002 w
.51102 .3295 m .55675 .35727 L .53451 .38302 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.41251 .47098 m .4201 .46324 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.4201 .46324 m .43012 .45863 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.44148 .4577 m .45294 .46056 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.43012 .45863 m .44148 .4577 L .44106 .49346 L closepath p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43012 .45863 m .4201 .46324 L .40169 .43212 L p
1 g
F P
s
P
p
.002 w
.40169 .43212 m .42132 .42286 L .43012 .45863 L p
1 g
F P
s
P
p
.002 w
.58129 .45811 m .56409 .41724 L .59184 .39794 L p
1 g
F P
s
P
p
.002 w
.55675 .35727 m .59184 .39794 L .56409 .41724 L p
1 g
F P
s
P
p
.002 w
.44373 .42084 m .42132 .42286 L .41502 .38754 L p
1 g
F P
s
P
p
.002 w
.41502 .38754 m .44773 .38433 L .44373 .42084 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.48098 .39228 m .44773 .38433 L .45332 .34958 L p
1 g
F P
s
P
p
.002 w
.45332 .34958 m .49604 .35957 L .48098 .39228 L p
1 g
F P
s
P
p
.002 w
.46799 .51818 m .47424 .50929 L .50815 .52265 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.56409 .41724 m .53451 .38302 L .55675 .35727 L p
1 g
F P
s
P
p
.002 w
.5138 .50146 m .50815 .52265 L .47424 .50929 L p
1 g
F P
s
P
p
.002 w
.50815 .52265 m .5138 .50146 L .55002 .5022 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56409 .41724 m .58129 .45811 L .54747 .46899 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.47424 .50929 m .47701 .49851 L .5138 .50146 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.44148 .4577 m .43012 .45863 L .42132 .42286 L p
1 g
F P
s
P
p
.002 w
.42132 .42286 m .44373 .42084 L .44148 .4577 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51191 .47876 m .5138 .50146 L .47701 .49851 L p
1 g
F P
s
P
p
.002 w
.47701 .49851 m .47597 .48702 L .51191 .47876 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.51089 .4106 m .48098 .39228 L .49604 .35957 L p
1 g
F P
s
P
p
.002 w
.49604 .35957 m .53451 .38302 L .51089 .4106 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.46642 .42639 m .44373 .42084 L .44773 .38433 L p
1 g
F P
s
P
p
.002 w
.44773 .38433 m .48098 .39228 L .46642 .42639 L p
1 g
F P
s
P
p
.002 w
.54747 .46899 m .53395 .43722 L .56409 .41724 L p
1 g
F P
s
P
p
.002 w
.53451 .38302 m .56409 .41724 L .53395 .43722 L p
1 g
F P
s
P
p
.002 w
.45294 .46056 m .44148 .4577 L .44373 .42084 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.53395 .43722 m .51089 .4106 L .53451 .38302 L p
1 g
F P
s
P
p
.002 w
.44373 .42084 m .46642 .42639 L .45294 .46056 L p
1 g
F P
s
P
p
.002 w
.46324 .46692 m .45294 .46056 L .46642 .42639 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.46642 .42639 m .48682 .43894 L .46324 .46692 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.48682 .43894 m .46642 .42639 L .48098 .39228 L p
1 g
F P
s
P
p
.002 w
.48098 .39228 m .51089 .4106 L .48682 .43894 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51089 .4106 m .53395 .43722 L .50257 .45709 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.50257 .45709 m .48682 .43894 L .51089 .4106 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.004 w
.40504 .53193 m
.42118 .51469 L
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .22012 .53382 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .40504 .53193 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.607752)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.607752)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47743 .43042 m .48999 .44399 L .50758 .42148 L p
1 g
F P
s
P
p
.002 w
.50758 .42148 m .50122 .4146 L .47743 .43042 L p
1 g
F P
s
P
p
.002 w
.51579 .42599 m .50758 .42148 L .48999 .44399 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .50122 .4146 L .50758 .42148 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .50758 .42148 L .51579 .42599 L closepath p
1 g
F P
s
P
p
.002 w
.46983 .41363 m .47743 .43042 L .50122 .4146 L p
1 g
F P
s
P
p
.002 w
.50122 .4146 m .49739 .40609 L .46983 .41363 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .49739 .40609 L .50122 .4146 L closepath p
1 g
F P
s
P
p
.002 w
.48999 .44399 m .50619 .4529 L .51579 .42599 L p
1 g
F P
s
P
p
.002 w
.52498 .42764 m .51579 .42599 L .50619 .4529 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .51579 .42599 L .52498 .42764 L closepath p
1 g
F P
s
P
p
.002 w
.45408 .44632 m .47257 .46626 L .48999 .44399 L p
1 g
F P
s
P
p
.002 w
.48999 .44399 m .47743 .43042 L .45408 .44632 L p
1 g
F P
s
P
p
.002 w
.50619 .4529 m .48999 .44399 L .47257 .46626 L p
1 g
F P
s
P
p
.002 w
.44286 .42162 m .45408 .44632 L .47743 .43042 L p
1 g
F P
s
P
p
.002 w
.47743 .43042 m .46983 .41363 L .44286 .42162 L p
1 g
F P
s
P
p
.002 w
.47257 .46626 m .49639 .47938 L .50619 .4529 L p
1 g
F P
s
P
p
.002 w
.52431 .4562 m .50619 .4529 L .49639 .47938 L p
1 g
F P
s
P
p
.002 w
.50619 .4529 m .52431 .4562 L .52498 .42764 L p
1 g
F P
s
P
p
.002 w
.46804 .39538 m .46983 .41363 L .49739 .40609 L p
1 g
F P
s
P
p
.002 w
.49739 .40609 m .49651 .39684 L .46804 .39538 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .49651 .39684 L .49739 .40609 L closepath p
1 g
F P
s
P
p
.002 w
.53415 .42625 m .52498 .42764 L .52431 .4562 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .52498 .42764 L .53415 .42625 L closepath p
1 g
F P
s
P
p
.002 w
.47227 .3776 m .46804 .39538 L .49651 .39684 L p
1 g
F P
s
P
p
.002 w
.49651 .39684 m .49868 .38787 L .47227 .3776 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .49868 .38787 L .49651 .39684 L closepath p
1 g
F P
s
P
p
.002 w
.52431 .4562 m .54245 .45352 L .53415 .42625 L p
1 g
F P
s
P
p
.002 w
.54233 .42197 m .53415 .42625 L .54245 .45352 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .53415 .42625 L .54233 .42197 L closepath p
1 g
F P
s
P
p
.002 w
.44013 .39475 m .44286 .42162 L .46983 .41363 L p
1 g
F P
s
P
p
.002 w
.46983 .41363 m .46804 .39538 L .44013 .39475 L p
1 g
F P
s
P
p
.002 w
.49639 .47938 m .52306 .4843 L .52431 .4562 L p
1 g
F P
s
P
p
.002 w
.54245 .45352 m .52431 .4562 L .52306 .4843 L p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .54233 .42197 L .54862 .41524 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .54862 .41524 L .55234 .40678 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .55234 .40678 L .55306 .39751 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .55306 .39751 L .55071 .38843 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .55071 .38843 L .54552 .38055 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .54552 .38055 L .53807 .37473 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .53807 .37473 L .52917 .37161 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .52917 .37161 L .5198 .37152 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .5198 .37152 L .51099 .37447 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .51099 .37447 L .50369 .38013 L closepath p
1 g
F P
s
P
p
.002 w
.52503 .39913 m .50369 .38013 L .49868 .38787 L closepath p
1 g
F P
s
P
p
.002 w
.48211 .36223 m .47227 .3776 L .49868 .38787 L p
1 g
F P
s
P
p
.002 w
.49868 .38787 m .50369 .38013 L .48211 .36223 L p
1 g
F P
s
P
p
.002 w
.54245 .45352 m .55867 .44511 L .54233 .42197 L p
1 g
F P
s
P
p
.002 w
.54862 .41524 m .54233 .42197 L .55867 .44511 L p
1 g
F P
s
P
p
.002 w
.43161 .46199 m .45565 .48788 L .47257 .46626 L p
1 g
F P
s
P
p
.002 w
.47257 .46626 m .45408 .44632 L .43161 .46199 L p
1 g
F P
s
P
p
.002 w
.49639 .47938 m .47257 .46626 L .45565 .48788 L p
1 g
F P
s
P
p
.002 w
.44626 .36853 m .44013 .39475 L .46804 .39538 L p
1 g
F P
s
P
p
.002 w
.46804 .39538 m .47227 .3776 L .44626 .36853 L p
1 g
F P
s
P
p
.002 w
.52306 .4843 m .54979 .48044 L .54245 .45352 L p
1 g
F P
s
P
p
.002 w
.55867 .44511 m .54245 .45352 L .54979 .48044 L p
1 g
F P
s
P
p
.002 w
.41697 .42993 m .43161 .46199 L .45408 .44632 L p
1 g
F P
s
P
p
.002 w
.45408 .44632 m .44286 .42162 L .41697 .42993 L p
1 g
F P
s
P
p
.002 w
.45565 .48788 m .48658 .50495 L .49639 .47938 L p
1 g
F P
s
P
p
.002 w
.52306 .4843 m .49639 .47938 L .48658 .50495 L p
1 g
F P
s
P
p
.002 w
.49654 .35095 m .48211 .36223 L .50369 .38013 L p
1 g
F P
s
P
p
.002 w
.50369 .38013 m .51099 .37447 L .49654 .35095 L p
1 g
F P
s
P
p
.002 w
.55867 .44511 m .57119 .43183 L .54862 .41524 L p
1 g
F P
s
P
p
.002 w
.55234 .40678 m .54862 .41524 L .57119 .43183 L p
1 g
F P
s
P
p
.002 w
.51403 .34503 m .49654 .35095 L .51099 .37447 L p
1 g
F P
s
P
p
.002 w
.51099 .37447 m .5198 .37152 L .51403 .34503 L p
1 g
F P
s
P
p
.002 w
.57119 .43183 m .57863 .41508 L .55234 .40678 L p
1 g
F P
s
P
p
.002 w
.55306 .39751 m .55234 .40678 L .57863 .41508 L p
1 g
F P
s
P
p
.002 w
.41331 .39499 m .41697 .42993 L .44286 .42162 L p
1 g
F P
s
P
p
.002 w
.44286 .42162 m .44013 .39475 L .41331 .39499 L p
1 g
F P
s
P
p
.002 w
.48658 .50495 m .52123 .51141 L .52306 .4843 L p
1 g
F P
s
P
p
.002 w
.54979 .48044 m .52306 .4843 L .52123 .51141 L p
1 g
F P
s
P
p
.002 w
.46069 .34578 m .44626 .36853 L .47227 .3776 L p
1 g
F P
s
P
p
.002 w
.47227 .3776 m .48211 .36223 L .46069 .34578 L p
1 g
F P
s
P
p
.002 w
.54979 .48044 m .57374 .46813 L .55867 .44511 L p
1 g
F P
s
P
p
.002 w
.57119 .43183 m .55867 .44511 L .57374 .46813 L p
1 g
F P
s
P
p
.002 w
.53265 .34515 m .51403 .34503 L .5198 .37152 L p
1 g
F P
s
P
p
.002 w
.5198 .37152 m .52917 .37161 L .53265 .34515 L p
1 g
F P
s
P
p
.002 w
.57863 .41508 m .58014 .39667 L .55306 .39751 L p
1 g
F P
s
P
p
.002 w
.55071 .38843 m .55306 .39751 L .58014 .39667 L p
1 g
F P
s
P
p
.002 w
.55037 .35134 m .53265 .34515 L .52917 .37161 L p
1 g
F P
s
P
p
.002 w
.52917 .37161 m .53807 .37473 L .55037 .35134 L p
1 g
F P
s
P
p
.002 w
.58014 .39667 m .5755 .37862 L .55071 .38843 L p
1 g
F P
s
P
p
.002 w
.54552 .38055 m .55071 .38843 L .5755 .37862 L p
1 g
F P
s
P
p
.002 w
.5652 .36293 m .55037 .35134 L .53807 .37473 L p
1 g
F P
s
P
p
.002 w
.53807 .37473 m .54552 .38055 L .5652 .36293 L p
1 g
F P
s
P
p
.002 w
.5755 .37862 m .5652 .36293 L .54552 .38055 L p
1 g
F P
s
P
p
.002 w
.42116 .36084 m .41331 .39499 L .44013 .39475 L p
1 g
F P
s
P
p
.002 w
.44013 .39475 m .44626 .36853 L .42116 .36084 L p
1 g
F P
s
P
p
.002 w
.52123 .51141 m .556 .5065 L .54979 .48044 L p
1 g
F P
s
P
p
.002 w
.57374 .46813 m .54979 .48044 L .556 .5065 L p
1 g
F P
s
P
p
.002 w
.48195 .32902 m .46069 .34578 L .48211 .36223 L p
1 g
F P
s
P
p
.002 w
.48211 .36223 m .49654 .35095 L .48195 .32902 L p
1 g
F P
s
P
p
.002 w
.57374 .46813 m .59231 .44861 L .57119 .43183 L p
1 g
F P
s
P
p
.002 w
.57863 .41508 m .57119 .43183 L .59231 .44861 L p
1 g
F P
s
P
p
.002 w
.41045 .47715 m .43955 .50844 L .45565 .48788 L p
1 g
F P
s
P
p
.002 w
.45565 .48788 m .43161 .46199 L .41045 .47715 L p
1 g
F P
s
P
p
.002 w
.48658 .50495 m .45565 .48788 L .43955 .50844 L p
1 g
F P
s
P
p
.002 w
.39266 .4384 m .41045 .47715 L .43161 .46199 L p
1 g
F P
s
P
p
.002 w
.43161 .46199 m .41697 .42993 L .39266 .4384 L p
1 g
F P
s
P
p
.002 w
.43955 .50844 m .47694 .52911 L .48658 .50495 L p
1 g
F P
s
P
p
.002 w
.52123 .51141 m .48658 .50495 L .47694 .52911 L p
1 g
F P
s
P
p
.002 w
.5078 .32016 m .48195 .32902 L .49654 .35095 L p
1 g
F P
s
P
p
.002 w
.49654 .35095 m .51403 .34503 L .5078 .32016 L p
1 g
F P
s
P
p
.002 w
.59231 .44861 m .60341 .4239 L .57863 .41508 L p
1 g
F P
s
P
p
.002 w
.58014 .39667 m .57863 .41508 L .60341 .4239 L p
1 g
F P
s
P
p
.002 w
.43984 .33112 m .42116 .36084 L .44626 .36853 L p
1 g
F P
s
P
p
.002 w
.44626 .36853 m .46069 .34578 L .43984 .33112 L p
1 g
F P
s
P
p
.002 w
.556 .5065 m .58723 .4906 L .57374 .46813 L p
1 g
F P
s
P
p
.002 w
.59231 .44861 m .57374 .46813 L .58723 .4906 L p
1 g
F P
s
P
p
.002 w
.38812 .39612 m .39266 .4384 L .41697 .42993 L p
1 g
F P
s
P
p
.002 w
.41697 .42993 m .41331 .39499 L .38812 .39612 L p
1 g
F P
s
P
p
.002 w
.47694 .52911 m .51884 .53701 L .52123 .51141 L p
1 g
F P
s
P
p
.002 w
.556 .5065 m .52123 .51141 L .51884 .53701 L p
1 g
F P
s
P
p
.002 w
.5354 .32028 m .5078 .32016 L .51403 .34503 L p
1 g
F P
s
P
p
.002 w
.51403 .34503 m .53265 .34515 L .5354 .32028 L p
1 g
F P
s
P
p
.002 w
.60341 .4239 m .60573 .39666 L .58014 .39667 L p
1 g
F P
s
P
p
.002 w
.5755 .37862 m .58014 .39667 L .60573 .39666 L p
1 g
F P
s
P
p
.002 w
.56168 .32942 m .5354 .32028 L .53265 .34515 L p
1 g
F P
s
P
p
.002 w
.53265 .34515 m .55037 .35134 L .56168 .32942 L p
1 g
F P
s
P
p
.002 w
.60573 .39666 m .59892 .3699 L .5755 .37862 L p
1 g
F P
s
P
p
.002 w
.5652 .36293 m .5755 .37862 L .59892 .3699 L p
1 g
F P
s
P
p
.002 w
.4675 .30915 m .43984 .33112 L .46069 .34578 L p
1 g
F P
s
P
p
.002 w
.46069 .34578 m .48195 .32902 L .4675 .30915 L p
1 g
F P
s
P
p
.002 w
.39748 .35471 m .38812 .39612 L .41331 .39499 L p
1 g
F P
s
P
p
.002 w
.41331 .39499 m .42116 .36084 L .39748 .35471 L p
1 g
F P
s
P
p
.002 w
.58368 .34661 m .56168 .32942 L .55037 .35134 L p
1 g
F P
s
P
p
.002 w
.55037 .35134 m .5652 .36293 L .58368 .34661 L p
1 g
F P
s
P
p
.002 w
.59892 .3699 m .58368 .34661 L .5652 .36293 L p
1 g
F P
s
P
p
.002 w
.58723 .4906 m .61153 .46526 L .59231 .44861 L p
1 g
F P
s
P
p
.002 w
.60341 .4239 m .59231 .44861 L .61153 .46526 L p
1 g
F P
s
P
p
.002 w
.51884 .53701 m .56094 .53119 L .556 .5065 L p
1 g
F P
s
P
p
.002 w
.58723 .4906 m .556 .5065 L .56094 .53119 L p
1 g
F P
s
P
p
.002 w
.39105 .49148 m .42459 .52752 L .43955 .50844 L p
1 g
F P
s
P
p
.002 w
.43955 .50844 m .41045 .47715 L .39105 .49148 L p
1 g
F P
s
P
p
.002 w
.47694 .52911 m .43955 .50844 L .42459 .52752 L p
1 g
F P
s
P
p
.002 w
.37048 .44686 m .39105 .49148 L .41045 .47715 L p
1 g
F P
s
P
p
.002 w
.41045 .47715 m .39266 .4384 L .37048 .44686 L p
1 g
F P
s
P
p
.002 w
.42459 .52752 m .46766 .55136 L .47694 .52911 L p
1 g
F P
s
P
p
.002 w
.51884 .53701 m .47694 .52911 L .46766 .55136 L p
1 g
F P
s
P
p
.002 w
.50122 .29747 m .4675 .30915 L .48195 .32902 L p
1 g
F P
s
P
p
.002 w
.48195 .32902 m .5078 .32016 L .50122 .29747 L p
1 g
F P
s
P
p
.002 w
.61153 .46526 m .62614 .43308 L .60341 .4239 L p
1 g
F P
s
P
p
.002 w
.60573 .39666 m .60341 .4239 L .62614 .43308 L p
1 g
F P
s
P
p
.002 w
.41999 .3186 m .39748 .35471 L .42116 .36084 L p
1 g
F P
s
P
p
.002 w
.42116 .36084 m .43984 .33112 L .41999 .3186 L p
1 g
F P
s
P
p
.002 w
.56094 .53119 m .59885 .51207 L .58723 .4906 L p
1 g
F P
s
P
p
.002 w
.61153 .46526 m .58723 .4906 L .59885 .51207 L p
1 g
F P
s
P
p
.002 w
.36511 .39815 m .37048 .44686 L .39266 .4384 L p
1 g
F P
s
P
p
.002 w
.39266 .4384 m .38812 .39612 L .36511 .39815 L p
1 g
F P
s
P
p
.002 w
.46766 .55136 m .51592 .56054 L .51884 .53701 L p
1 g
F P
s
P
p
.002 w
.56094 .53119 m .51884 .53701 L .51592 .56054 L p
1 g
F P
s
P
p
.002 w
.53732 .29755 m .50122 .29747 L .5078 .32016 L p
1 g
F P
s
P
p
.002 w
.5078 .32016 m .5354 .32028 L .53732 .29755 L p
1 g
F P
s
P
p
.002 w
.62614 .43308 m .62928 .3975 L .60573 .39666 L p
1 g
F P
s
P
p
.002 w
.59892 .3699 m .60573 .39666 L .62928 .3975 L p
1 g
F P
s
P
p
.002 w
.57173 .30947 m .53732 .29755 L .5354 .32028 L p
1 g
F P
s
P
p
.002 w
.5354 .32028 m .56168 .32942 L .57173 .30947 L p
1 g
F P
s
P
p
.002 w
.62928 .3975 m .62045 .36248 L .59892 .3699 L p
1 g
F P
s
P
p
.002 w
.58368 .34661 m .59892 .3699 L .62045 .36248 L p
1 g
F P
s
P
p
.002 w
.45348 .29181 m .41999 .3186 L .43984 .33112 L p
1 g
F P
s
P
p
.002 w
.43984 .33112 m .4675 .30915 L .45348 .29181 L p
1 g
F P
s
P
p
.002 w
.59885 .51207 m .62843 .48144 L .61153 .46526 L p
1 g
F P
s
P
p
.002 w
.62614 .43308 m .61153 .46526 L .62843 .48144 L p
1 g
F P
s
P
p
.002 w
.37575 .35035 m .36511 .39815 L .38812 .39612 L p
1 g
F P
s
P
p
.002 w
.38812 .39612 m .39748 .35471 L .37575 .35035 L p
1 g
F P
s
P
p
.002 w
.51592 .56054 m .56448 .55396 L .56094 .53119 L p
1 g
F P
s
P
p
.002 w
.59885 .51207 m .56094 .53119 L .56448 .55396 L p
1 g
F P
s
P
p
.002 w
.60053 .33197 m .57173 .30947 L .56168 .32942 L p
1 g
F P
s
P
p
.002 w
.56168 .32942 m .58368 .34661 L .60053 .33197 L p
1 g
F P
s
P
p
.002 w
.62045 .36248 m .60053 .33197 L .58368 .34661 L p
1 g
F P
s
P
p
.002 w
.37387 .50467 m .41113 .54467 L .42459 .52752 L p
1 g
F P
s
P
p
.002 w
.42459 .52752 m .39105 .49148 L .37387 .50467 L p
1 g
F P
s
P
p
.002 w
.46766 .55136 m .42459 .52752 L .41113 .54467 L p
1 g
F P
s
P
p
.002 w
.35094 .45516 m .37387 .50467 L .39105 .49148 L p
1 g
F P
s
P
p
.002 w
.39105 .49148 m .37048 .44686 L .35094 .45516 L p
1 g
F P
s
P
p
.002 w
.41113 .54467 m .45893 .57117 L .46766 .55136 L p
1 g
F P
s
P
p
.002 w
.51592 .56054 m .46766 .55136 L .45893 .57117 L p
1 g
F P
s
P
p
.002 w
.49443 .27751 m .45348 .29181 L .4675 .30915 L p
1 g
F P
s
P
p
.002 w
.4675 .30915 m .50122 .29747 L .49443 .27751 L p
1 g
F P
s
P
p
.002 w
.62843 .48144 m .64629 .44243 L .62614 .43308 L p
1 g
F P
s
P
p
.002 w
.62928 .3975 m .62614 .43308 L .64629 .44243 L p
1 g
F P
s
P
p
.002 w
.40161 .30857 m .37575 .35035 L .39748 .35471 L p
1 g
F P
s
P
p
.002 w
.39748 .35471 m .41999 .3186 L .40161 .30857 L p
1 g
F P
s
P
p
.002 w
.56448 .55396 m .60827 .53205 L .59885 .51207 L p
1 g
F P
s
P
p
.002 w
.62843 .48144 m .59885 .51207 L .60827 .53205 L p
1 g
F P
s
P
p
.002 w
.34485 .40106 m .35094 .45516 L .37048 .44686 L p
1 g
F P
s
P
p
.002 w
.37048 .44686 m .36511 .39815 L .34485 .40106 L p
1 g
F P
s
P
p
.002 w
.45893 .57117 m .51251 .58145 L .51592 .56054 L p
1 g
F P
s
P
p
.002 w
.56448 .55396 m .51592 .56054 L .51251 .58145 L p
1 g
F P
s
P
p
.002 w
.53835 .27751 m .49443 .27751 L .50122 .29747 L p
1 g
F P
s
P
p
.002 w
.50122 .29747 m .53732 .29755 L .53835 .27751 L p
1 g
F P
s
P
p
.002 w
.64629 .44243 m .65023 .3992 L .62928 .3975 L p
1 g
F P
s
P
p
.002 w
.62045 .36248 m .62928 .3975 L .65023 .3992 L p
1 g
F P
s
P
p
.002 w
.44021 .2775 m .40161 .30857 L .41999 .3186 L p
1 g
F P
s
P
p
.002 w
.41999 .3186 m .45348 .29181 L .44021 .2775 L p
1 g
F P
s
P
p
.002 w
.58026 .29199 m .53835 .27751 L .53732 .29755 L p
1 g
F P
s
P
p
.002 w
.53732 .29755 m .57173 .30947 L .58026 .29199 L p
1 g
F P
s
P
p
.002 w
.60827 .53205 m .64254 .49681 L .62843 .48144 L p
1 g
F P
s
P
p
.002 w
.64629 .44243 m .62843 .48144 L .64254 .49681 L p
1 g
F P
s
P
p
.002 w
.65023 .3992 m .63957 .35657 L .62045 .36248 L p
1 g
F P
s
P
p
.002 w
.60053 .33197 m .62045 .36248 L .63957 .35657 L p
1 g
F P
s
P
p
.002 w
.35653 .34791 m .34485 .40106 L .36511 .39815 L p
1 g
F P
s
P
p
.002 w
.36511 .39815 m .37575 .35035 L .35653 .34791 L p
1 g
F P
s
P
p
.002 w
.51251 .58145 m .56647 .57427 L .56448 .55396 L p
1 g
F P
s
P
p
.002 w
.60827 .53205 m .56448 .55396 L .56647 .57427 L p
1 g
F P
s
P
p
.002 w
.61535 .31939 m .58026 .29199 L .57173 .30947 L p
1 g
F P
s
P
p
.002 w
.57173 .30947 m .60053 .33197 L .61535 .31939 L p
1 g
F P
s
P
p
.002 w
.63957 .35657 m .61535 .31939 L .60053 .33197 L p
1 g
F P
s
P
p
.002 w
.35937 .51639 m .39951 .55944 L .41113 .54467 L p
1 g
F P
s
P
p
.002 w
.41113 .54467 m .37387 .50467 L .35937 .51639 L p
1 g
F P
s
P
p
.002 w
.45893 .57117 m .41113 .54467 L .39951 .55944 L p
1 g
F P
s
P
p
.002 w
.48755 .26084 m .44021 .2775 L .45348 .29181 L p
1 g
F P
s
P
p
.002 w
.45348 .29181 m .49443 .27751 L .48755 .26084 L p
1 g
F P
s
P
p
.002 w
.33461 .4631 m .35937 .51639 L .37387 .50467 L p
1 g
F P
s
P
p
.002 w
.37387 .50467 m .35094 .45516 L .33461 .4631 L p
1 g
F P
s
P
p
.002 w
.39951 .55944 m .45098 .58801 L .45893 .57117 L p
1 g
F P
s
P
p
.002 w
.51251 .58145 m .45893 .57117 L .45098 .58801 L p
1 g
F P
s
P
p
.002 w
.64254 .49681 m .66332 .45178 L .64629 .44243 L p
1 g
F P
s
P
p
.002 w
.65023 .3992 m .64629 .44243 L .66332 .45178 L p
1 g
F P
s
P
p
.002 w
.38516 .30137 m .35653 .34791 L .37575 .35035 L p
1 g
F P
s
P
p
.002 w
.37575 .35035 m .40161 .30857 L .38516 .30137 L p
1 g
F P
s
P
p
.002 w
.56647 .57427 m .61521 .55005 L .60827 .53205 L p
1 g
F P
s
P
p
.002 w
.64254 .49681 m .60827 .53205 L .61521 .55005 L p
1 g
F P
s
P
p
.002 w
.32793 .40484 m .33461 .4631 L .35094 .45516 L p
1 g
F P
s
P
p
.002 w
.35094 .45516 m .34485 .40106 L .32793 .40484 L p
1 g
F P
s
P
p
.002 w
.45098 .58801 m .50866 .59916 L .51251 .58145 L p
1 g
F P
s
P
p
.002 w
.56647 .57427 m .51251 .58145 L .50866 .59916 L p
1 g
F P
s
P
p
.002 w
.53841 .26075 m .48755 .26084 L .49443 .27751 L p
1 g
F P
s
P
p
.002 w
.49443 .27751 m .53835 .27751 L .53841 .26075 L p
1 g
F P
s
P
p
.002 w
.66332 .45178 m .66799 .40178 L .65023 .3992 L p
1 g
F P
s
P
p
.002 w
.63957 .35657 m .65023 .3992 L .66799 .40178 L p
1 g
F P
s
P
p
.002 w
.42803 .26668 m .38516 .30137 L .40161 .30857 L p
1 g
F P
s
P
p
.002 w
.40161 .30857 m .44021 .2775 L .42803 .26668 L p
1 g
F P
s
P
p
.002 w
.61521 .55005 m .65343 .51097 L .64254 .49681 L p
1 g
F P
s
P
p
.002 w
.66332 .45178 m .64254 .49681 L .65343 .51097 L p
1 g
F P
s
P
p
.002 w
.58701 .2775 m .53841 .26075 L .53835 .27751 L p
1 g
F P
s
P
p
.002 w
.53835 .27751 m .58026 .29199 L .58701 .2775 L p
1 g
F P
s
P
p
.002 w
.34038 .34755 m .32793 .40484 L .34485 .40106 L p
1 g
F P
s
P
p
.002 w
.34485 .40106 m .35653 .34791 L .34038 .34755 L p
1 g
F P
s
P
p
.002 w
.66799 .40178 m .65572 .35237 L .63957 .35657 L p
1 g
F P
s
P
p
.002 w
.61535 .31939 m .63957 .35657 L .65572 .35237 L p
1 g
F P
s
P
p
.002 w
.50866 .59916 m .5668 .59154 L .56647 .57427 L p
1 g
F P
s
P
p
.002 w
.61521 .55005 m .56647 .57427 L .5668 .59154 L p
1 g
F P
s
P
p
.002 w
.62768 .30927 m .58701 .2775 L .58026 .29199 L p
1 g
F P
s
P
p
.002 w
.58026 .29199 m .61535 .31939 L .62768 .30927 L p
1 g
F P
s
P
p
.002 w
.65572 .35237 m .62768 .30927 L .61535 .31939 L p
1 g
F P
s
P
p
.002 w
.34802 .52628 m .3901 .57138 L .39951 .55944 L p
1 g
F P
s
P
p
.002 w
.39951 .55944 m .35937 .51639 L .34802 .52628 L p
1 g
F P
s
P
p
.002 w
.45098 .58801 m .39951 .55944 L .3901 .57138 L p
1 g
F P
s
P
p
.002 w
.48073 .24802 m .42803 .26668 L .44021 .2775 L p
1 g
F P
s
P
p
.002 w
.44021 .2775 m .48755 .26084 L .48073 .24802 L p
1 g
F P
s
P
p
.002 w
.65343 .51097 m .67668 .46091 L .66332 .45178 L p
1 g
F P
s
P
p
.002 w
.66799 .40178 m .66332 .45178 L .67668 .46091 L p
1 g
F P
s
P
p
.002 w
.32202 .47047 m .34802 .52628 L .35937 .51639 L p
1 g
F P
s
P
p
.002 w
.35937 .51639 m .33461 .4631 L .32202 .47047 L p
1 g
F P
s
P
p
.002 w
.3901 .57138 m .44402 .60133 L .45098 .58801 L p
1 g
F P
s
P
p
.002 w
.50866 .59916 m .45098 .58801 L .44402 .60133 L p
1 g
F P
s
P
p
.002 w
.37112 .29732 m .34038 .34755 L .35653 .34791 L p
1 g
F P
s
P
p
.002 w
.35653 .34791 m .38516 .30137 L .37112 .29732 L p
1 g
F P
s
P
p
.002 w
.5668 .59154 m .61937 .56557 L .61521 .55005 L p
1 g
F P
s
P
p
.002 w
.65343 .51097 m .61521 .55005 L .61937 .56557 L p
1 g
F P
s
P
p
.002 w
.31493 .40945 m .32202 .47047 L .33461 .4631 L p
1 g
F P
s
P
p
.002 w
.33461 .4631 m .32793 .40484 L .31493 .40945 L p
1 g
F P
s
P
p
.002 w
.44402 .60133 m .50445 .61309 L .50866 .59916 L p
1 g
F P
s
P
p
.002 w
.5668 .59154 m .50866 .59916 L .50445 .61309 L p
1 g
F P
s
P
p
.002 w
.53746 .24785 m .48073 .24802 L .48755 .26084 L p
1 g
F P
s
P
p
.002 w
.48755 .26084 m .53841 .26075 L .53746 .24785 L p
1 g
F P
s
P
p
.002 w
.67668 .46091 m .68199 .4052 L .66799 .40178 L p
1 g
F P
s
P
p
.002 w
.65572 .35237 m .66799 .40178 L .68199 .4052 L p
1 g
F P
s
P
p
.002 w
.4173 .25982 m .37112 .29732 L .38516 .30137 L p
1 g
F P
s
P
p
.002 w
.38516 .30137 m .42803 .26668 L .4173 .25982 L p
1 g
F P
s
P
p
.002 w
.61937 .56557 m .66066 .52353 L .65343 .51097 L p
1 g
F P
s
P
p
.002 w
.67668 .46091 m .65343 .51097 L .66066 .52353 L p
1 g
F P
s
P
p
.002 w
.32787 .34939 m .31493 .40945 L .32793 .40484 L p
1 g
F P
s
P
p
.002 w
.32793 .40484 m .34038 .34755 L .32787 .34939 L p
1 g
F P
s
P
p
.002 w
.5917 .26651 m .53746 .24785 L .53841 .26075 L p
1 g
F P
s
P
p
.002 w
.53841 .26075 m .58701 .2775 L .5917 .26651 L p
1 g
F P
s
P
p
.002 w
.68199 .4052 m .66837 .35009 L .65572 .35237 L p
1 g
F P
s
P
p
.002 w
.62768 .30927 m .65572 .35237 L .66837 .35009 L p
1 g
F P
s
P
p
.002 w
.50445 .61309 m .56537 .6052 L .5668 .59154 L p
1 g
F P
s
P
p
.002 w
.61937 .56557 m .5668 .59154 L .56537 .6052 L p
1 g
F P
s
P
p
.002 w
.63711 .30197 m .5917 .26651 L .58701 .2775 L p
1 g
F P
s
P
p
.002 w
.58701 .2775 m .62768 .30927 L .63711 .30197 L p
1 g
F P
s
P
p
.002 w
.66837 .35009 m .63711 .30197 L .62768 .30927 L p
1 g
F P
s
P
p
.002 w
.34029 .53401 m .38325 .58003 L .3901 .57138 L p
1 g
F P
s
P
p
.002 w
.3901 .57138 m .34802 .52628 L .34029 .53401 L p
1 g
F P
s
P
p
.002 w
.44402 .60133 m .3901 .57138 L .38325 .58003 L p
1 g
F P
s
P
p
.002 w
.47416 .23959 m .4173 .25982 L .42803 .26668 L p
1 g
F P
s
P
p
.002 w
.42803 .26668 m .48073 .24802 L .47416 .23959 L p
1 g
F P
s
P
p
.002 w
.66066 .52353 m .68583 .46959 L .67668 .46091 L p
1 g
F P
s
P
p
.002 w
.68199 .4052 m .67668 .46091 L .68583 .46959 L p
1 g
F P
s
P
p
.002 w
.31371 .47708 m .34029 .53401 L .34802 .52628 L p
1 g
F P
s
P
p
.002 w
.34802 .52628 m .32202 .47047 L .31371 .47708 L p
1 g
F P
s
P
p
.002 w
.38325 .58003 m .43827 .61062 L .44402 .60133 L p
1 g
F P
s
P
p
.002 w
.50445 .61309 m .44402 .60133 L .43827 .61062 L p
1 g
F P
s
P
p
.002 w
.36001 .2967 m .32787 .34939 L .34038 .34755 L p
1 g
F P
s
P
p
.002 w
.34038 .34755 m .37112 .29732 L .36001 .2967 L p
1 g
F P
s
P
p
.002 w
.56537 .6052 m .6205 .57808 L .61937 .56557 L p
1 g
F P
s
P
p
.002 w
.66066 .52353 m .61937 .56557 L .6205 .57808 L p
1 g
F P
s
P
p
.002 w
.30641 .41482 m .31371 .47708 L .32202 .47047 L p
1 g
F P
s
P
p
.002 w
.32202 .47047 m .31493 .40945 L .30641 .41482 L p
1 g
F P
s
P
p
.002 w
.43827 .61062 m .49994 .62267 L .50445 .61309 L p
1 g
F P
s
P
p
.002 w
.56537 .6052 m .50445 .61309 L .49994 .62267 L p
1 g
F P
s
P
p
.002 w
.53545 .23937 m .47416 .23959 L .48073 .24802 L p
1 g
F P
s
P
p
.002 w
.48073 .24802 m .53746 .24785 L .53545 .23937 L p
1 g
F P
s
P
p
.002 w
.68583 .46959 m .69165 .40946 L .68199 .4052 L p
1 g
F P
s
P
p
.002 w
.66837 .35009 m .68199 .4052 L .69165 .40946 L p
1 g
F P
s
P
p
.002 w
.40838 .25733 m .36001 .2967 L .37112 .29732 L p
1 g
F P
s
P
p
.002 w
.37112 .29732 m .4173 .25982 L .40838 .25733 L p
1 g
F P
s
P
p
.002 w
.6205 .57808 m .66383 .53409 L .66066 .52353 L p
1 g
F P
s
P
p
.002 w
.68583 .46959 m .66066 .52353 L .66383 .53409 L p
1 g
F P
s
P
p
.002 w
.31955 .35354 m .30641 .41482 L .31493 .40945 L p
1 g
F P
s
P
p
.002 w
.31493 .40945 m .32787 .34939 L .31955 .35354 L p
1 g
F P
s
P
p
.002 w
.5941 .25951 m .53545 .23937 L .53746 .24785 L p
1 g
F P
s
P
p
.002 w
.53746 .24785 m .5917 .26651 L .5941 .25951 L p
1 g
F P
s
P
p
.002 w
.49994 .62267 m .56211 .61469 L .56537 .6052 L p
1 g
F P
s
P
p
.002 w
.6205 .57808 m .56537 .6052 L .56211 .61469 L p
1 g
F P
s
P
p
.002 w
.69165 .40946 m .67698 .3499 L .66837 .35009 L p
1 g
F P
s
P
p
.002 w
.63711 .30197 m .66837 .35009 L .67698 .3499 L p
1 g
F P
s
P
p
.002 w
.6432 .29785 m .5941 .25951 L .5917 .26651 L p
1 g
F P
s
P
p
.002 w
.5917 .26651 m .63711 .30197 L .6432 .29785 L p
1 g
F P
s
P
p
.002 w
.67698 .3499 m .6432 .29785 L .63711 .30197 L p
1 g
F P
s
P
p
.002 w
.46802 .23607 m .40838 .25733 L .4173 .25982 L p
1 g
F P
s
P
p
.002 w
.4173 .25982 m .47416 .23959 L .46802 .23607 L p
1 g
F P
s
P
p
.002 w
.33659 .53924 m .3793 .58497 L .38325 .58003 L p
1 g
F P
s
P
p
.002 w
.38325 .58003 m .34029 .53401 L .33659 .53924 L p
1 g
F P
s
P
p
.002 w
.43827 .61062 m .38325 .58003 L .3793 .58497 L p
1 g
F P
s
P
p
.002 w
.66383 .53409 m .6903 .47756 L .68583 .46959 L p
1 g
F P
s
P
p
.002 w
.69165 .40946 m .68583 .46959 L .6903 .47756 L p
1 g
F P
s
P
p
.002 w
.35229 .29976 m .31955 .35354 L .32787 .34939 L p
1 g
F P
s
P
p
.002 w
.32787 .34939 m .36001 .2967 L .35229 .29976 L p
1 g
F P
s
P
p
.002 w
.31016 .48268 m .33659 .53924 L .34029 .53401 L p
1 g
F P
s
P
p
.002 w
.34029 .53401 m .31371 .47708 L .31016 .48268 L p
1 g
F P
s
P
p
.002 w
.3793 .58497 m .43397 .61538 L .43827 .61062 L p
1 g
F P
s
P
p
.002 w
.49994 .62267 m .43827 .61062 L .43397 .61538 L p
1 g
F P
s
P
p
.002 w
.56211 .61469 m .61838 .58708 L .6205 .57808 L p
1 g
F P
s
P
p
.002 w
.66383 .53409 m .6205 .57808 L .61838 .58708 L p
1 g
F P
s
P
p
.002 w
.30288 .42085 m .31016 .48268 L .31371 .47708 L p
1 g
F P
s
P
p
.002 w
.31371 .47708 m .30641 .41482 L .30288 .42085 L p
1 g
F P
s
P
p
.002 w
.43397 .61538 m .49523 .62737 L .49994 .62267 L p
1 g
F P
s
P
p
.002 w
.56211 .61469 m .49994 .62267 L .49523 .62737 L p
1 g
F P
s
P
p
.002 w
.53237 .23581 m .46802 .23607 L .47416 .23959 L p
1 g
F P
s
P
p
.002 w
.47416 .23959 m .53545 .23937 L .53237 .23581 L p
1 g
F P
s
P
p
.002 w
.6903 .47756 m .69644 .41447 L .69165 .40946 L p
1 g
F P
s
P
p
.002 w
.67698 .3499 m .69165 .40946 L .69644 .41447 L p
1 g
F P
s
P
p
.002 w
.40163 .25957 m .35229 .29976 L .36001 .2967 L p
1 g
F P
s
P
p
.002 w
.36001 .2967 m .40838 .25733 L .40163 .25957 L p
1 g
F P
s
P
p
.002 w
.61838 .58708 m .66262 .54224 L .66383 .53409 L p
1 g
F P
s
P
p
.002 w
.6903 .47756 m .66383 .53409 L .66262 .54224 L p
1 g
F P
s
P
p
.002 w
.31591 .36001 m .30288 .42085 L .30641 .41482 L p
1 g
F P
s
P
p
.002 w
.30641 .41482 m .31955 .35354 L .31591 .36001 L p
1 g
F P
s
P
p
.002 w
.49523 .62737 m .55698 .61948 L .56211 .61469 L p
1 g
F P
s
P
p
.002 w
.61838 .58708 m .56211 .61469 L .55698 .61948 L p
1 g
F P
s
P
p
.002 w
.59399 .25696 m .53237 .23581 L .53545 .23937 L p
1 g
F P
s
P
p
.002 w
.53545 .23937 m .5941 .25951 L .59399 .25696 L p
1 g
F P
s
P
p
.002 w
.69644 .41447 m .68106 .35193 L .67698 .3499 L p
1 g
F P
s
P
p
.002 w
.6432 .29785 m .67698 .3499 L .68106 .35193 L p
1 g
F P
s
P
p
.002 w
.64558 .29725 m .59399 .25696 L .5941 .25951 L p
1 g
F P
s
P
p
.002 w
.5941 .25951 m .6432 .29785 L .64558 .29725 L p
1 g
F P
s
P
p
.002 w
.68106 .35193 m .64558 .29725 L .6432 .29785 L p
1 g
F P
s
P
p
.004 w
.29019 .41508 m
.29802 .41565 L
s
P
p
.004 w
.27514 .41397 m
.29019 .41508 L
s
P
p
.004 w
.21715 .40971 m
.27514 .41397 L
s
P
p
.002 w
.46252 .23786 m .40163 .25957 L .40838 .25733 L p
1 g
F P
s
P
p
.002 w
.40838 .25733 m .46802 .23607 L .46252 .23786 L p
1 g
F P
s
P
p
.002 w
.66262 .54224 m .68964 .48456 L .6903 .47756 L p
1 g
F P
s
P
p
.002 w
.69644 .41447 m .6903 .47756 L .68964 .48456 L p
1 g
F P
s
P
p
.002 w
.33731 .54166 m .37854 .58581 L .3793 .58497 L p
1 g
F P
s
P
p
.002 w
.3793 .58497 m .33659 .53924 L .33731 .54166 L p
1 g
F P
s
P
p
.002 w
.43397 .61538 m .3793 .58497 L .37854 .58581 L p
1 g
F P
s
P
p
.002 w
.3484 .30664 m .31591 .36001 L .31955 .35354 L p
1 g
F P
s
P
p
.002 w
.31955 .35354 m .35229 .29976 L .3484 .30664 L p
1 g
F P
s
P
p
.002 w
.31179 .48707 m .33731 .54166 L .33659 .53924 L p
1 g
F P
s
P
p
.002 w
.33659 .53924 m .31016 .48268 L .31179 .48707 L p
1 g
F P
s
P
p
.002 w
.55698 .61948 m .61285 .59208 L .61838 .58708 L p
1 g
F P
s
P
p
.002 w
.66262 .54224 m .61838 .58708 L .61285 .59208 L p
1 g
F P
s
P
p
.002 w
.37854 .58581 m .43133 .61518 L .43397 .61538 L p
1 g
F P
s
P
p
.002 w
.49523 .62737 m .43397 .61538 L .43133 .61518 L p
1 g
F P
s
P
p
.002 w
.30477 .42742 m .31179 .48707 L .31016 .48268 L p
1 g
F P
s
P
p
.002 w
.31016 .48268 m .30288 .42085 L .30477 .42742 L p
1 g
F P
s
P
p
.002 w
.43133 .61518 m .49046 .62675 L .49523 .62737 L p
1 g
F P
s
P
p
.002 w
.55698 .61948 m .49523 .62737 L .49046 .62675 L p
1 g
F P
s
P
p
.002 w
.52824 .2376 m .46252 .23786 L .46802 .23607 L p
1 g
F P
s
P
p
.002 w
.46802 .23607 m .53237 .23581 L .52824 .2376 L p
1 g
F P
s
P
p
.002 w
.68964 .48456 m .69591 .42016 L .69644 .41447 L p
1 g
F P
s
P
p
.002 w
.68106 .35193 m .69644 .41447 L .69591 .42016 L p
1 g
F P
s
P
p
.002 w
.39739 .26677 m .3484 .30664 L .35229 .29976 L p
1 g
F P
s
P
p
.002 w
.35229 .29976 m .40163 .25957 L .39739 .26677 L p
1 g
F P
s
P
p
.002 w
.61285 .59208 m .65675 .54758 L .66262 .54224 L p
1 g
F P
s
P
p
.002 w
.68964 .48456 m .66262 .54224 L .65675 .54758 L p
1 g
F P
s
P
p
.002 w
.31736 .36878 m .30477 .42742 L .30288 .42085 L p
1 g
F P
s
P
p
.002 w
.30288 .42085 m .31591 .36001 L .31736 .36878 L p
1 g
F P
s
P
p
.002 w
.49046 .62675 m .55002 .61913 L .55698 .61948 L p
1 g
F P
s
P
p
.002 w
.61285 .59208 m .55698 .61948 L .55002 .61913 L p
1 g
F P
s
P
p
.002 w
.5912 .25923 m .52824 .2376 L .53237 .23581 L p
1 g
F P
s
P
p
.002 w
.53237 .23581 m .59399 .25696 L .5912 .25923 L p
1 g
F P
s
P
p
.002 w
.69591 .42016 m .68019 .35628 L .68106 .35193 L p
1 g
F P
s
P
p
.002 w
.64558 .29725 m .68106 .35193 L .68019 .35628 L p
1 g
F P
s
P
p
.002 w
.64393 .30041 m .5912 .25923 L .59399 .25696 L p
1 g
F P
s
P
p
.002 w
.59399 .25696 m .64558 .29725 L .64393 .30041 L p
1 g
F P
s
P
p
.002 w
.68019 .35628 m .64393 .30041 L .64558 .29725 L p
1 g
F P
s
P
p
.002 w
.45784 .24527 m .39739 .26677 L .40163 .25957 L p
1 g
F P
s
P
p
.002 w
.40163 .25957 m .46252 .23786 L .45784 .24527 L p
1 g
F P
s
P
p
.002 w
.65675 .54758 m .68355 .49032 L .68964 .48456 L p
1 g
F P
s
P
p
.002 w
.69591 .42016 m .68964 .48456 L .68355 .49032 L p
1 g
F P
s
P
p
.002 w
.3427 .54101 m .38122 .58226 L .37854 .58581 L p
1 g
F P
s
P
p
.002 w
.37854 .58581 m .33731 .54166 L .3427 .54101 L p
1 g
F P
s
P
p
.002 w
.43133 .61518 m .37854 .58581 L .38122 .58226 L p
1 g
F P
s
P
p
.002 w
.34872 .31739 m .31736 .36878 L .31591 .36001 L p
1 g
F P
s
P
p
.002 w
.31591 .36001 m .3484 .30664 L .34872 .31739 L p
1 g
F P
s
P
p
.002 w
.55002 .61913 m .60386 .59269 L .61285 .59208 L p
1 g
F P
s
P
p
.002 w
.65675 .54758 m .61285 .59208 L .60386 .59269 L p
1 g
F P
s
P
p
.002 w
.31889 .49002 m .3427 .54101 L .33731 .54166 L p
1 g
F P
s
P
p
.002 w
.33731 .54166 m .31179 .48707 L .31889 .49002 L p
1 g
F P
s
P
p
.002 w
.38122 .58226 m .43054 .60968 L .43133 .61518 L p
1 g
F P
s
P
p
.002 w
.49046 .62675 m .43133 .61518 L .43054 .60968 L p
1 g
F P
s
P
p
.002 w
.31239 .43437 m .31889 .49002 L .31179 .48707 L p
1 g
F P
s
P
p
.002 w
.31179 .48707 m .30477 .42742 L .31239 .43437 L p
1 g
F P
s
P
p
.002 w
.43054 .60968 m .48575 .62047 L .49046 .62675 L p
1 g
F P
s
P
p
.002 w
.55002 .61913 m .49046 .62675 L .48575 .62047 L p
1 g
F P
s
P
p
.002 w
.52311 .24506 m .45784 .24527 L .46252 .23786 L p
1 g
F P
s
P
p
.002 w
.46252 .23786 m .52824 .2376 L .52311 .24506 L p
1 g
F P
s
P
p
.002 w
.68355 .49032 m .68973 .42639 L .69591 .42016 L p
1 g
F P
s
P
p
.002 w
.68019 .35628 m .69591 .42016 L .68973 .42639 L p
1 g
F P
s
P
p
.002 w
.39595 .27905 m .34872 .31739 L .3484 .30664 L p
1 g
F P
s
P
p
.002 w
.3484 .30664 m .39739 .26677 L .39595 .27905 L p
1 g
F P
s
P
p
.002 w
.60386 .59269 m .64612 .54978 L .65675 .54758 L p
1 g
F P
s
P
p
.002 w
.68355 .49032 m .65675 .54758 L .64612 .54978 L p
1 g
F P
s
P
p
.002 w
.3242 .37972 m .31239 .43437 L .30477 .42742 L p
1 g
F P
s
P
p
.002 w
.30477 .42742 m .31736 .36878 L .3242 .37972 L p
1 g
F P
s
P
p
.004 w
.29802 .41565 m
.30516 .41618 L
s
P
p
.004 w
.30516 .41618 m
.31166 .41666 L
s
P
p
.002 w
.48575 .62047 m .54131 .61331 L .55002 .61913 L p
1 g
F P
s
P
p
.002 w
.60386 .59269 m .55002 .61913 L .54131 .61331 L p
1 g
F P
s
P
p
.002 w
.58564 .26658 m .52311 .24506 L .52824 .2376 L p
1 g
F P
s
P
p
.002 w
.52824 .2376 m .5912 .25923 L .58564 .26658 L p
1 g
F P
s
P
p
.002 w
.68973 .42639 m .67407 .36296 L .68019 .35628 L p
1 g
F P
s
P
p
.002 w
.64393 .30041 m .68019 .35628 L .67407 .36296 L p
1 g
F P
s
P
p
.002 w
.63802 .30748 m .58564 .26658 L .5912 .25923 L p
1 g
F P
s
P
p
.002 w
.5912 .25923 m .64393 .30041 L .63802 .30748 L p
1 g
F P
s
P
p
.002 w
.67407 .36296 m .63802 .30748 L .64393 .30041 L p
1 g
F P
s
P
p
.002 w
.45421 .25842 m .39595 .27905 L .39739 .26677 L p
1 g
F P
s
P
p
.002 w
.39739 .26677 m .45784 .24527 L .45421 .25842 L p
1 g
F P
s
P
p
.002 w
.64612 .54978 m .67185 .49459 L .68355 .49032 L p
1 g
F P
s
P
p
.002 w
.68973 .42639 m .68355 .49032 L .67185 .49459 L p
1 g
F P
s
P
p
.002 w
.35349 .3319 m .3242 .37972 L .31736 .36878 L p
1 g
F P
s
P
p
.002 w
.31736 .36878 m .34872 .31739 L .35349 .3319 L p
1 g
F P
s
P
p
.002 w
.35292 .5371 m .38747 .57413 L .38122 .58226 L p
1 g
F P
s
P
p
.002 w
.38122 .58226 m .3427 .54101 L .35292 .5371 L p
1 g
F P
s
P
p
.002 w
.43054 .60968 m .38122 .58226 L .38747 .57413 L p
1 g
F P
s
P
p
.002 w
.54131 .61331 m .59147 .5886 L .60386 .59269 L p
1 g
F P
s
P
p
.002 w
.64612 .54978 m .60386 .59269 L .59147 .5886 L p
1 g
F P
s
P
p
.002 w
.33161 .49136 m .35292 .5371 L .3427 .54101 L p
1 g
F P
s
P
p
.002 w
.3427 .54101 m .31889 .49002 L .33161 .49136 L p
1 g
F P
s
P
p
.002 w
.38747 .57413 m .43173 .59872 L .43054 .60968 L p
1 g
F P
s
P
p
.002 w
.48575 .62047 m .43054 .60968 L .43173 .59872 L p
1 g
F P
s
P
p
.002 w
.32585 .44148 m .33161 .49136 L .31889 .49002 L p
1 g
F P
s
P
p
.002 w
.31889 .49002 m .31239 .43437 L .32585 .44148 L p
1 g
F P
s
P
p
.002 w
.43173 .59872 m .48125 .60835 L .48575 .62047 L p
1 g
F P
s
P
p
.002 w
.54131 .61331 m .48575 .62047 L .48125 .60835 L p
1 g
F P
s
P
p
.002 w
.51708 .25831 m .45421 .25842 L .45784 .24527 L p
1 g
F P
s
P
p
.002 w
.45784 .24527 m .52311 .24506 L .51708 .25831 L p
1 g
F P
s
P
p
.002 w
.67185 .49459 m .67771 .433 L .68973 .42639 L p
1 g
F P
s
P
p
.002 w
.67407 .36296 m .68973 .42639 L .67771 .433 L p
1 g
F P
s
P
p
.002 w
.39754 .29631 m .35349 .3319 L .34872 .31739 L p
1 g
F P
s
P
p
.002 w
.34872 .31739 m .39595 .27905 L .39754 .29631 L p
1 g
F P
s
P
p
.002 w
.59147 .5886 m .63075 .54856 L .64612 .54978 L p
1 g
F P
s
P
p
.002 w
.67185 .49459 m .64612 .54978 L .63075 .54856 L p
1 g
F P
s
P
p
.002 w
.33652 .3926 m .32585 .44148 L .31239 .43437 L p
1 g
F P
s
P
p
.002 w
.31239 .43437 m .3242 .37972 L .33652 .3926 L p
1 g
F P
s
P
p
.004 w
.31166 .41666 m
.31302 .41676 L
s
P
p
.004 w
.33096 .41808 m
.5 .43051 L
s
P
p
.004 w
.31861 .41717 m
.32 .41727 L
s
P
p
.004 w
.31302 .41676 m
.31861 .41717 L
s
P
p
.002 w
.48125 .60835 m .53103 .60186 L .54131 .61331 L p
1 g
F P
s
P
p
.002 w
.59147 .5886 m .54131 .61331 L .53103 .60186 L p
1 g
F P
s
P
p
.002 w
.57731 .27908 m .51708 .25831 L .52311 .24506 L p
1 g
F P
s
P
p
.002 w
.52311 .24506 m .58564 .26658 L .57731 .27908 L p
1 g
F P
s
P
p
.002 w
.67771 .433 m .66255 .37192 L .67407 .36296 L p
1 g
F P
s
P
p
.002 w
.63802 .30748 m .67407 .36296 L .66255 .37192 L p
1 g
F P
s
P
p
.002 w
.62778 .3185 m .57731 .27908 L .58564 .26658 L p
1 g
F P
s
P
p
.002 w
.58564 .26658 m .63802 .30748 L .62778 .3185 L p
1 g
F P
s
P
p
.002 w
.66255 .37192 m .62778 .3185 L .63802 .30748 L p
1 g
F P
s
P
p
.002 w
.4518 .27724 m .39754 .29631 L .39595 .27905 L p
1 g
F P
s
P
p
.002 w
.39595 .27905 m .45421 .25842 L .4518 .27724 L p
1 g
F P
s
P
p
.002 w
.63075 .54856 m .65459 .49713 L .67185 .49459 L p
1 g
F P
s
P
p
.002 w
.67771 .433 m .67185 .49459 L .65459 .49713 L p
1 g
F P
s
P
p
.002 w
.36283 .34992 m .33652 .3926 L .3242 .37972 L p
1 g
F P
s
P
p
.002 w
.3242 .37972 m .35349 .3319 L .36283 .34992 L p
1 g
F P
s
P
p
.002 w
.53103 .60186 m .57586 .57966 L .59147 .5886 L p
1 g
F P
s
P
p
.002 w
.63075 .54856 m .59147 .5886 L .57586 .57966 L p
1 g
F P
s
P
p
.002 w
.36793 .52987 m .39733 .56139 L .38747 .57413 L p
1 g
F P
s
P
p
.002 w
.38747 .57413 m .35292 .5371 L .36793 .52987 L p
1 g
F P
s
P
p
.002 w
.43173 .59872 m .38747 .57413 L .39733 .56139 L p
1 g
F P
s
P
p
.002 w
.34985 .49094 m .36793 .52987 L .35292 .5371 L p
1 g
F P
s
P
p
.002 w
.35292 .5371 m .33161 .49136 L .34985 .49094 L p
1 g
F P
s
P
p
.002 w
.39733 .56139 m .43501 .58231 L .43173 .59872 L p
1 g
F P
s
P
p
.002 w
.48125 .60835 m .43173 .59872 L .43501 .58231 L p
1 g
F P
s
P
p
.002 w
.34505 .44855 m .34985 .49094 L .33161 .49136 L p
1 g
F P
s
P
p
.002 w
.33161 .49136 m .32585 .44148 L .34505 .44855 L p
1 g
F P
s
P
p
.002 w
.43501 .58231 m .47714 .59045 L .48125 .60835 L p
1 g
F P
s
P
p
.002 w
.53103 .60186 m .48125 .60835 L .47714 .59045 L p
1 g
F P
s
P
p
.002 w
.51031 .27724 m .4518 .27724 L .45421 .25842 L p
1 g
F P
s
P
p
.002 w
.45421 .25842 m .51708 .25831 L .51031 .27724 L p
1 g
F P
s
P
p
.002 w
.65459 .49713 m .65991 .4398 L .67771 .433 L p
1 g
F P
s
P
p
.002 w
.66255 .37192 m .67771 .433 L .65991 .4398 L p
1 g
F P
s
P
p
.002 w
.40228 .31825 m .36283 .34992 L .35349 .3319 L p
1 g
F P
s
P
p
.002 w
.35349 .3319 m .39754 .29631 L .40228 .31825 L p
1 g
F P
s
P
p
.002 w
.57586 .57966 m .61088 .54376 L .63075 .54856 L p
1 g
F P
s
P
p
.002 w
.65459 .49713 m .63075 .54856 L .61088 .54376 L p
1 g
F P
s
P
p
.002 w
.35423 .40709 m .34505 .44855 L .32585 .44148 L p
1 g
F P
s
P
p
.002 w
.32585 .44148 m .33652 .3926 L .35423 .40709 L p
1 g
F P
s
P
p
.002 w
.47714 .59045 m .51942 .58484 L .53103 .60186 L p
1 g
F P
s
P
p
.002 w
.57586 .57966 m .53103 .60186 L .51942 .58484 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.56633 .29663 m .51031 .27724 L .51708 .25831 L p
1 g
F P
s
P
p
.002 w
.51708 .25831 m .57731 .27908 L .56633 .29663 L p
1 g
F P
s
P
p
.002 w
.65991 .4398 m .64571 .38299 L .66255 .37192 L p
1 g
F P
s
P
p
.002 w
.62778 .3185 m .66255 .37192 L .64571 .38299 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.6133 .33331 m .56633 .29663 L .57731 .27908 L p
1 g
F P
s
P
p
.002 w
.57731 .27908 m .62778 .3185 L .6133 .33331 L p
1 g
F P
s
P
p
.002 w
.64571 .38299 m .6133 .33331 L .62778 .3185 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.45078 .30137 m .40228 .31825 L .39754 .29631 L p
1 g
F P
s
P
p
.002 w
.39754 .29631 m .4518 .27724 L .45078 .30137 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.61088 .54376 m .63203 .49776 L .65459 .49713 L p
1 g
F P
s
P
p
.002 w
.65991 .4398 m .65459 .49713 L .63203 .49776 L p
1 g
F P
s
P
p
.002 w
.37666 .371 m .35423 .40709 L .33652 .3926 L p
1 g
F P
s
P
p
.002 w
.33652 .3926 m .36283 .34992 L .37666 .371 L p
1 g
F P
s
P
p
.002 w
.51942 .58484 m .55741 .56588 L .57586 .57966 L p
1 g
F P
s
P
p
.002 w
.61088 .54376 m .57586 .57966 L .55741 .56588 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.3875 .51936 m .41066 .54422 L .39733 .56139 L p
1 g
F P
s
P
p
.002 w
.39733 .56139 m .36793 .52987 L .3875 .51936 L p
1 g
F P
s
P
p
.002 w
.43501 .58231 m .39733 .56139 L .41066 .54422 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.37331 .48866 m .3875 .51936 L .36793 .52987 L p
1 g
F P
s
P
p
.002 w
.36793 .52987 m .34985 .49094 L .37331 .48866 L p
1 g
F P
s
P
p
.002 w
.41066 .54422 m .44037 .56069 L .43501 .58231 L p
1 g
F P
s
P
p
.002 w
.47714 .59045 m .43501 .58231 L .44037 .56069 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.36962 .4553 m .37331 .48866 L .34985 .49094 L p
1 g
F P
s
P
p
.002 w
.34985 .49094 m .34505 .44855 L .36962 .4553 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.47714 .59045 m .44774 .56665 L .46836 .57432 L 1 g
F
P
p
.002 w
.47506 .57681 m .47536 .57875 L p
.46836 .57432 L 1 g
F P
s
P
p
.002 w
.47536 .57875 m .47714 .59045 L p
.46836 .57432 L 1 g
F P
s
P
p
.002 w
.46836 .57432 m .46872 .57265 L p
.46059 .5694 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46816 .57521 L p
1 g
F P
s
P
p
.002 w
.51322 .58566 m .47714 .59045 L .47552 .57982 L p
1 g
F P
s
P
p
.002 w
.47552 .57982 m .47506 .57681 L p
.4891 .58007 L 1 g
F P
s
P
p
.51322 .58566 m .47552 .57982 L .4891 .58007 L 1 g
F
P
p
.002 w
.51093 .58047 m .51079 .57862 L p
.50232 .58031 L 1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58047 L p
1 g
F P
s
P
p
.51942 .58484 m .50473 .58168 L .5061 .58141 L 1 g
F
P
p
.51942 .58484 m .50181 .5803 L .50803 .58042 L 1 g
F
P
p
.53128 .57265 m .51093 .58047 L .51636 .57942 L 1 g
F
P
p
.002 w
.55741 .56588 m .51942 .58484 L .51818 .58265 L p
1 g
F P
s
P
p
.002 w
.51818 .58265 m .51636 .57942 L p
.53082 .57465 L 1 g
F P
s
P
p
.55741 .56588 m .51818 .58265 L .53082 .57465 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53161 .57415 L p
1 g
F P
s
P
p
.54854 .56129 m .53161 .57415 L .54183 .56768 L 1 g
F
P
p
.53128 .57265 m .51636 .57942 L .52165 .57759 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.55741 .56588 m .51636 .57942 L .55585 .56578 L 1 g
F
P
p
.002 w
.47358 .56705 m .50683 .56254 L .51636 .57942 L p
1 g
F P
s
P
p
.002 w
.51636 .57942 m .51942 .58484 L p
.50909 .58083 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58007 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58007 L .50232 .58031 L 1 g
F
P
p
.50909 .58083 m .47358 .56705 L .51636 .57942 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53209 .57636 L p
1 g
F P
s
P
p
.002 w
.53209 .57636 m .53128 .57265 L p
.51914 .57888 L 1 g
F P
s
P
p
.51914 .57888 m .51111 .583 L .53209 .57636 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54919 .56303 m .54854 .56129 L p
.54183 .56768 L 1 g
F P
s
P
p
.002 w
.51636 .57942 m .50683 .56254 L p
.54588 .56512 L 1 g
F P
s
P
p
.55585 .56578 m .53161 .57415 L .54588 .56512 L 1 g
F
P
p
.53161 .57415 m .51636 .57942 L .54588 .56512 L 1 g
F
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54919 .56303 L p
1 g
F P
s
P
p
.56075 .54566 m .54919 .56303 L .55142 .5606 L 1 g
F
P
p
.58697 .53535 m .55828 .55572 L .56582 .54047 L 1 g
F
P
p
.55828 .55572 m .55142 .5606 L .56133 .54675 L 1 g
F
P
p
.55828 .55572 m .56133 .54675 L .56582 .54047 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56133 .54675 L p
1 g
F P
s
P
p
.56654 .52734 m .56133 .54675 L .56494 .53609 L 1 g
F
P
p
.56075 .54566 m .55142 .5606 L .5562 .55391 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.58697 .53535 m .55741 .56588 L .55142 .5606 L p
1 g
F P
s
P
p
.002 w
.55142 .5606 m .55741 .56588 L p
.54719 .56521 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55142 .5606 m .53662 .54754 L p
.56324 .54109 L 1 g
F P
s
P
p
.56582 .54047 m .56133 .54675 L .56324 .54109 L 1 g
F
P
p
.56133 .54675 m .55142 .5606 L .56324 .54109 L 1 g
F
P
p
.002 w
.56746 .52867 m .56654 .52734 L p
.56494 .53609 L 1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56746 .52867 L p
1 g
F P
s
P
p
.56515 .50826 m .56746 .52867 L .56742 .52684 L 1 g
F
P
p
.60472 .49634 m .56742 .52684 L .56684 .51918 L 1 g
F
P
p
.56685 .51927 m .56742 .52684 L .56733 .52241 L 1 g
F
P
p
.56515 .50826 m .56742 .52684 L .56685 .51927 L 1 g
F
P
p
.002 w
.60472 .49634 m .58697 .53535 L .56742 .52684 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56742 .52684 m .58697 .53535 L p
.56768 .54002 L 1 g
F P
s
P
p
.002 w
.57347 .49285 m .60472 .49634 L p
.56684 .51918 L 1 g
F P
s
P
p
.002 w
.56609 .50926 m .57347 .49285 L p
.56817 .5139 L 1 g
F P
s
P
p
.56684 .51918 m .5661 .50939 L .56817 .5139 L 1 g
F
P
p
.5661 .50939 m .56609 .50926 L .56817 .5139 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5661 .50939 L p
1 g
F P
s
P
p
.55661 .4905 m .5661 .50939 L .56607 .50932 L 1 g
F
P
p
.002 w
.57347 .49285 m .56607 .50932 L p
.56039 .49755 L 1 g
F P
s
P
p
.56157 .49999 m .56607 .50932 L .56337 .50343 L 1 g
F
P
p
.55661 .4905 m .56607 .50932 L .56157 .49999 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55684 .49017 m .57347 .49285 L p
.56289 .49665 L 1 g
F P
s
P
p
.56289 .49665 m .56039 .49755 L .5574 .49134 L 1 g
F
P
p
.56289 .49665 m .5574 .49134 L .55684 .49017 L 1 g
F
P
p
.002 w
.5574 .49134 m .55661 .4905 L p
.56157 .49999 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5574 .49134 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .5574 .49134 L p
1 g
F P
s
P
p
.56157 .49999 m .56713 .51061 L .5574 .49134 L 1 g
F
P
p
.54174 .47608 m .5574 .49134 L .55607 .49005 L 1 g
F
P
p
.002 w
.55607 .49005 m .53934 .48736 L p
.54711 .48137 L 1 g
F P
s
P
p
.55001 .48417 m .55607 .49005 L .55143 .48557 L 1 g
F
P
p
.54174 .47608 m .55607 .49005 L .55001 .48417 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.57625 .45894 m .57347 .49285 L .55607 .49005 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52998 .50846 m .53934 .48736 L .55607 .49005 L p
1 g
F P
s
P
p
.002 w
.55607 .49005 m .55684 .49017 L p
.55646 .49043 L 1 g
F P
s
P
p
.55646 .49043 m .52998 .50846 L .55607 .49005 L 1 g
F
P
p
.56039 .49755 m .52998 .50846 L .55684 .49017 L 1 g
F
P
p
.002 w
.54239 .47679 m .54174 .47608 L p
.55001 .48417 L 1 g
F P
s
P
p
.002 w
.54114 .46406 m .57625 .45894 L p
.54711 .48137 L 1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54239 .47679 L p
1 g
F P
s
P
p
.002 w
.53934 .48736 m .54023 .4758 L p
.54711 .48137 L 1 g
F P
s
P
p
.54711 .48137 m .54023 .4758 L .54239 .47679 L 1 g
F
P
p
.002 w
.53934 .48736 m .50359 .48002 L p
.52775 .46975 L 1 g
F P
s
P
p
.002 w
.54023 .4758 m .53934 .48736 L p
.52775 .46975 L 1 g
F P
s
P
p
.52214 .46667 m .54239 .47679 L .53608 .47389 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.52775 .46975 m .50359 .48002 L .52008 .46686 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46719 L .51831 .46662 L 1 g
F
P
p
.002 w
.51831 .46662 m .50445 .46817 L p
.50788 .46516 L 1 g
F P
s
P
p
.51251 .46581 m .51831 .46662 L .51289 .46588 L 1 g
F
P
p
.5 .4634 m .51831 .46662 L .51251 .46581 L 1 g
F
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.53513 .44114 m .54114 .46406 L .51831 .46662 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.52775 .46975 m .52008 .46686 L .52245 .46719 L 1 g
F
P
p
.002 w
.50359 .48002 m .50445 .46817 L .51831 .46662 L p
1 g
F P
s
P
p
.52008 .46686 m .50359 .48002 L .51831 .46662 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50445 .46817 m .47002 .47092 L p
.47788 .46717 L 1 g
F P
s
P
p
.002 w
.47753 .46722 m .47786 .46667 L p
.48937 .4655 L 1 g
F P
s
P
p
.4953 .46464 m .50445 .46817 L .47788 .46717 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46396 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46396 L .48937 .4655 L 1 g
F
P
p
.002 w
.50349 .46454 m .50445 .46817 L p
.4886 .46205 L 1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .46442 L p
.48937 .4655 L 1 g
F P
s
P
p
.002 w
.48388 .46409 m .4886 .46205 L p
.47002 .47092 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45692 .50418 m .44637 .49835 L .46642 .47265 L p
1 g
F P
s
P
p
.002 w
.48043 .5047 m .4687 .50638 L .46765 .47207 L p
1 g
F P
s
P
p
.002 w
.49889 .49079 m .49088 .49932 L .4682 .47181 L p
1 g
F P
s
P
p
.002 w
.50445 .46817 m .50359 .48002 L .46896 .47144 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46722 L p
1 g
F P
s
P
p
.002 w
.47753 .46722 m .47752 .46723 L p
.47722 .46737 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46722 L .47722 .46737 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.46762 .47111 m .49464 .44642 L .50082 .45574 L p
1 g
F P
s
P
p
.002 w
.50082 .45574 m .50136 .45655 L .48388 .46409 L p
1 g
F P
s
P
p
.002 w
.48388 .46409 m .46762 .47111 L p
.50082 .45574 L 1 g
F P
s
P
p
.45826 .47608 m .47752 .46723 L .47681 .46758 L 1 g
F
P
p
.45826 .47608 m .4775 .46727 L .47647 .46777 L 1 g
F
P
p
.45826 .47608 m .47747 .46731 L .4762 .46793 L 1 g
F
P
p
.45826 .47608 m .47744 .46737 L .47602 .46805 L 1 g
F
P
p
.45826 .47608 m .4774 .46742 L .47596 .46811 L 1 g
F
P
p
.45826 .47608 m .47737 .46747 L .47609 .46808 L 1 g
F
P
p
.45826 .47608 m .47735 .46752 L .47641 .46796 L 1 g
F
P
p
.002 w
.47002 .47092 m .50445 .46817 L p
.46896 .47144 L 1 g
F P
s
P
p
.45826 .47608 m .47733 .46755 L .47144 .4703 L 1 g
F
P
p
.002 w
.50359 .48002 m .49889 .49079 L .4685 .47166 L p
1 g
F P
s
P
p
.002 w
.46896 .47144 m .50359 .48002 L p
.4685 .47166 L 1 g
F P
s
P
p
.002 w
.4685 .47166 m .49889 .49079 L p
.4682 .47181 L 1 g
F P
s
P
p
.002 w
.49088 .49932 m .48043 .5047 L .46794 .47193 L p
1 g
F P
s
P
p
.002 w
.4682 .47181 m .49088 .49932 L p
.46794 .47193 L 1 g
F P
s
P
p
.002 w
.46794 .47193 m .48043 .5047 L p
.46765 .47207 L 1 g
F P
s
P
p
.002 w
.4687 .50638 m .45692 .50418 L .46725 .47226 L p
1 g
F P
s
P
p
.002 w
.46765 .47207 m .4687 .50638 L p
.46725 .47226 L 1 g
F P
s
P
p
.002 w
.46725 .47226 m .45692 .50418 L p
.46642 .47265 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.43816 .48952 m .44583 .48473 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44158 .4932 m .44117 .49275 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44117 .49275 m .43816 .48952 L p
.44242 .49153 L 1 g
F P
s
P
p
.42717 .523 m .4349 .49947 L .434 .50888 L 1 g
F
P
p
.002 w
.44325 .49079 m .44228 .49174 L p
.43485 .50826 L 1 g
F P
s
P
p
.43485 .50826 m .44228 .49174 L .43853 .49966 L 1 g
F
P
p
.002 w
.43816 .48952 m .44158 .4932 L p
.434 .50888 L 1 g
F P
s
P
p
.4349 .49947 m .43816 .48952 L .434 .50888 L 1 g
F
P
p
.002 w
.42798 .52196 m .42717 .523 L p
.434 .50888 L 1 g
F P
s
P
p
.434 .50888 m .44158 .4932 L .43396 .50932 L 1 g
F
P
p
.434 .50888 m .43396 .50932 L .42798 .52196 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43396 .50932 L p
1 g
F P
s
P
p
.43346 .52734 m .43396 .50932 L .43342 .51498 L 1 g
F
P
p
.002 w
.43252 .52596 m .42717 .523 L .43342 .51498 L p
1 g
F P
s
P
p
.43314 .5183 m .43342 .51498 L .43313 .51795 L 1 g
F
P
p
.43346 .52734 m .43342 .51498 L .43314 .5183 L 1 g
F
P
p
.43346 .52734 m .43313 .51795 L .43256 .52395 L 1 g
F
P
p
.002 w
.42717 .523 m .43129 .52528 L p
.43226 .53754 L 1 g
F P
s
P
p
.002 w
.43129 .52528 m .43252 .52596 L p
.43245 .5288 L 1 g
F P
s
P
p
.43226 .53754 m .43129 .52528 L .43245 .5288 L 1 g
F
P
p
.002 w
.43849 .5471 m .43925 .54566 L p
.43569 .53862 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44254 .55295 m .44037 .56069 L p
.43267 .5387 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43825 .54755 L p
1 g
F P
s
P
p
.002 w
.45017 .56256 m .44037 .56069 L .44254 .55295 L p
1 g
F P
s
P
p
.002 w
.43825 .54755 m .43743 .5491 L p
.44404 .55484 L 1 g
F P
s
P
p
.45146 .56129 m .43825 .54755 L .44404 .55484 L 1 g
F
P
p
.45146 .56129 m .44356 .55443 L .44668 .55893 L 1 g
F
P
p
.002 w
.44037 .56069 m .44962 .56246 L p
.4548 .56739 L 1 g
F P
s
P
p
.002 w
.44962 .56246 m .45017 .56256 L p
.45076 .56318 L 1 g
F P
s
P
p
.4548 .56739 m .44962 .56246 L .45076 .56318 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45076 .56318 L p
1 g
F P
s
P
p
.46872 .57265 m .45076 .56318 L .46059 .5694 L 1 g
F
P
p
.48921 .57862 m .46816 .57521 L .47938 .57781 L 1 g
F
P
p
.002 w
.47358 .56705 m .47506 .57681 L p
.4548 .56739 L 1 g
F P
s
P
p
.002 w
.45076 .56318 m .45146 .56129 L p
.44668 .55893 L 1 g
F P
s
P
p
.002 w
.45017 .56256 m .47358 .56705 L p
.4548 .56739 L 1 g
F P
s
P
p
.44774 .56665 m .44037 .56069 L .46465 .57197 L 1 g
F
P
p
.46836 .57432 m .46465 .57197 L .47506 .57681 L 1 g
F
P
p
.44774 .56665 m .46465 .57197 L .46836 .57432 L 1 g
F
P
p
.002 w
.45076 .56318 m .45002 .56518 L p
.46059 .5694 L 1 g
F P
s
P
p
.002 w
.45036 .56425 m .45076 .56318 L p
.44668 .55893 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47358 .56705 m .45017 .56256 L p
.44774 .53439 L 1 g
F P
s
P
p
.002 w
.44254 .55295 m .44774 .53439 L p
.45017 .56256 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43245 .5288 L p
1 g
F P
s
P
p
.43834 .54665 m .43226 .53754 L .43514 .53695 L 1 g
F
P
p
.43925 .54566 m .43245 .5288 L .43569 .53862 L 1 g
F
P
p
.002 w
.43245 .5288 m .43346 .52734 L p
.43256 .52395 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43252 .52596 m .44774 .53439 L p
.43226 .53754 L 1 g
F P
s
P
p
.002 w
.43245 .5288 m .43146 .53025 L p
.43569 .53862 L 1 g
F P
s
P
p
.002 w
.44774 .53439 m .44254 .55295 L p
.43834 .54665 L 1 g
F P
s
P
p
.43834 .54665 m .43514 .53695 L .44774 .53439 L 1 g
F
P
p
.43267 .5387 m .43226 .53754 L .44254 .55295 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45036 .56425 L p
1 g
F P
s
P
p
.44356 .55443 m .43743 .5491 L .45036 .56425 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43849 .5471 L p
1 g
F P
s
P
p
.43569 .53862 m .43146 .53025 L .43849 .5471 L 1 g
F
P
p
.002 w
.43204 .52941 m .43245 .5288 L p
.43256 .52395 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.44774 .53439 m .43252 .52596 L p
.44637 .49835 L 1 g
F P
s
P
p
.002 w
.43342 .51498 m .44637 .49835 L p
.43252 .52596 L 1 g
F P
s
P
p
.002 w
.44158 .4932 m .44637 .49835 L .43342 .51498 L p
1 g
F P
s
P
p
.002 w
.43342 .51498 m .42798 .52196 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43396 .50932 L p
.43958 .49721 L 1 g
F P
s
P
p
.002 w
.43396 .50932 m .43485 .50826 L p
.43853 .49966 L 1 g
F P
s
P
p
.43853 .49966 m .43958 .49721 L .43396 .50932 L 1 g
F
P
p
.43396 .50932 m .44158 .4932 L .43342 .51498 L 1 g
F
P
p
.002 w
.43396 .50932 m .43287 .51061 L p
.43313 .51795 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43204 .52941 L p
1 g
F P
s
P
p
.43313 .51795 m .43287 .51061 L .43204 .52941 L 1 g
F
P
p
.002 w
.44228 .49174 m .44166 .49233 L p
.43853 .49966 L 1 g
F P
s
P
p
.002 w
.44331 .49067 m .44339 .4905 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44242 .49153 m .44339 .4905 L p
.45047 .48372 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44158 .4932 m .44242 .49153 L .46138 .47501 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45764 .47675 L p
1 g
F P
s
P
p
.45826 .47608 m .46989 .47098 L .46792 .47195 L 1 g
F
P
p
.002 w
.46138 .47501 m .45594 .47841 L p
.45764 .47675 L 1 g
F P
s
P
p
.002 w
.45594 .47841 m .46138 .47501 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.44637 .49835 m .44158 .4932 L p
.46138 .47501 L 1 g
F P
s
P
p
.002 w
.46642 .47265 m .44637 .49835 L p
.46138 .47501 L 1 g
F P
s
P
p
.002 w
.45721 .47723 m .45764 .47675 L p
.46792 .47195 L 1 g
F P
s
P
p
.002 w
.45764 .47675 m .45826 .47608 L p
.46792 .47195 L 1 g
F P
s
P
p
.002 w
.46225 .47228 m .46762 .47111 L .46138 .47501 L p
1 g
F P
s
P
p
.45764 .47675 m .46225 .47228 L .46138 .47501 L 1 g
F
P
p
.002 w
.45764 .47675 m .45764 .47676 L p
.45758 .47681 L 1 g
F P
s
P
p
.44339 .4905 m .45764 .47675 L .45758 .47681 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.43816 .48952 m .43318 .47862 L .46225 .47228 L p
1 g
F P
s
P
p
.44339 .4905 m .45764 .47676 L .45047 .48372 L 1 g
F
P
p
.002 w
.45594 .47841 m .43816 .48952 L p
.46225 .47228 L 1 g
F P
s
P
p
.002 w
.44583 .48473 m .45594 .47841 L p
.44242 .49153 L 1 g
F P
s
P
p
.002 w
.45764 .47676 m .45698 .47747 L p
.45047 .48372 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44242 .49153 L p
1 g
F P
s
P
p
.45047 .48372 m .45698 .47747 L .44242 .49153 L 1 g
F
P
p
.002 w
.44166 .49233 m .43311 .51013 L p
.43958 .49721 L 1 g
F P
s
P
p
.002 w
.43311 .51013 m .43287 .51061 L p
.43958 .49721 L 1 g
F P
s
P
p
.002 w
.46896 .47144 m .46762 .47111 L .47002 .47092 L p
1 g
F P
s
P
p
.002 w
.47752 .46723 m .4775 .46727 L p
.47681 .46758 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .47747 .46731 L p
.47647 .46777 L 1 g
F P
s
P
p
.002 w
.4685 .47166 m .46762 .47111 L .46896 .47144 L p
1 g
F P
s
P
p
.002 w
.4682 .47181 m .46762 .47111 L .4685 .47166 L p
1 g
F P
s
P
p
.002 w
.47747 .46731 m .47744 .46737 L p
.4762 .46793 L 1 g
F P
s
P
p
.002 w
.47744 .46737 m .4774 .46742 L p
.47602 .46805 L 1 g
F P
s
P
p
.002 w
.46794 .47193 m .46762 .47111 L .4682 .47181 L p
1 g
F P
s
P
p
.002 w
.46765 .47207 m .46762 .47111 L .46794 .47193 L p
1 g
F P
s
P
p
.002 w
.4774 .46742 m .47737 .46747 L p
.47596 .46811 L 1 g
F P
s
P
p
.002 w
.47737 .46747 m .47735 .46752 L p
.47609 .46808 L 1 g
F P
s
P
p
.002 w
.46725 .47226 m .46762 .47111 L .46765 .47207 L p
1 g
F P
s
P
p
.002 w
.46642 .47265 m .46762 .47111 L .46725 .47226 L p
1 g
F P
s
P
p
.002 w
.47735 .46752 m .47733 .46755 L p
.47641 .46796 L 1 g
F P
s
P
p
.002 w
.47733 .46755 m .47718 .46778 L p
.47144 .4703 L 1 g
F P
s
P
p
.002 w
.46138 .47501 m .46762 .47111 L .46642 .47265 L p
1 g
F P
s
P
p
.002 w
.47002 .47092 m .46762 .47111 L .47618 .46741 L p
1 g
F P
s
P
p
.002 w
.47618 .46741 m .48388 .46409 L p
.47753 .46722 L 1 g
F P
s
P
p
.47753 .46722 m .47002 .47092 L .47618 .46741 L 1 g
F
P
p
.4886 .46205 m .4953 .46464 L .47788 .46717 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47753 .46722 L p
1 g
F P
s
P
p
.48937 .4655 m .5 .46442 L .47753 .46722 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45721 .47723 L p
1 g
F P
s
P
p
.46989 .47098 m .47718 .46778 L .45721 .47723 L 1 g
F
P
p
.002 w
.50445 .46817 m .50349 .46454 L p
.50788 .46516 L 1 g
F P
s
P
p
.50489 .46474 m .51289 .46588 L .50524 .46483 L 1 g
F
P
p
.5 .4634 m .51251 .46581 L .50489 .46474 L 1 g
F
P
p
.51251 .46581 m .51289 .46588 L .50489 .46474 L 1 g
F
P
p
.002 w
.50136 .45655 m .53513 .44114 L p
.50788 .46516 L 1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .4634 L p
.50524 .46483 L 1 g
F P
s
P
p
.002 w
.50349 .46454 m .50136 .45655 L p
.50788 .46516 L 1 g
F P
s
P
p
.002 w
.4886 .46205 m .50136 .45655 L .50349 .46454 L p
1 g
F P
s
P
p
.002 w
.5 .46412 m .5 .46396 L p
.50524 .46483 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46412 L p
1 g
F P
s
P
p
.51289 .46588 m .52282 .46778 L .5 .46412 L 1 g
F
P
p
.002 w
.51831 .46662 m .52072 .46635 L p
.52008 .46686 L 1 g
F P
s
P
p
.53513 .44114 m .51831 .46662 L .50788 .46516 L 1 g
F
P
p
.52245 .46719 m .52008 .46686 L .52072 .46635 L 1 g
F
P
p
.002 w
.52245 .46719 m .52282 .46778 L p
.51289 .46588 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.53308 .47233 L 1 g
F P
s
P
p
.53308 .47233 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.52072 .46635 m .54114 .46406 L p
.52775 .46975 L 1 g
F P
s
P
p
.002 w
.54114 .46406 m .54023 .4758 L p
.52775 .46975 L 1 g
F P
s
P
p
.53608 .47389 m .54023 .4758 L .54302 .47747 L 1 g
F
P
p
.002 w
.54239 .47679 m .54248 .47688 L p
.54023 .4758 L 1 g
F P
s
P
p
.002 w
.54248 .47688 m .54302 .47747 L p
.54023 .4758 L 1 g
F P
s
P
p
.002 w
.54023 .4758 m .54031 .47478 L p
.54239 .47679 L 1 g
F P
s
P
p
.002 w
.54031 .47478 m .54114 .46406 L p
.54711 .48137 L 1 g
F P
s
P
p
.002 w
.54272 .47715 m .54239 .47679 L p
.55143 .48557 L 1 g
F P
s
P
p
.55001 .48417 m .55143 .48557 L .54239 .47679 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54272 .47715 L p
1 g
F P
s
P
p
.55143 .48557 m .55834 .49233 L .54272 .47715 L 1 g
F
P
p
.57625 .45894 m .55607 .49005 L .54711 .48137 L 1 g
F
P
p
.002 w
.5574 .49134 m .55834 .49233 L p
.55143 .48557 L 1 g
F P
s
P
p
.002 w
.5597 .52348 m .52998 .50846 L p
.56039 .49755 L 1 g
F P
s
P
p
.002 w
.5661 .50939 m .56515 .50826 L p
.56685 .51927 L 1 g
F P
s
P
p
.002 w
.56607 .50932 m .5597 .52348 L p
.56039 .49755 L 1 g
F P
s
P
p
.002 w
.5597 .52348 m .56609 .50926 L p
.56684 .51918 L 1 g
F P
s
P
p
.002 w
.5661 .50939 m .56713 .51061 L p
.56337 .50343 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .5661 .50939 L p
1 g
F P
s
P
p
.56685 .51927 m .56854 .53025 L .5661 .50939 L 1 g
F
P
p
.002 w
.56742 .52684 m .5597 .52348 L p
.56684 .51918 L 1 g
F P
s
P
p
.002 w
.53662 .54754 m .5597 .52348 L .56742 .52684 L p
1 g
F P
s
P
p
.56768 .54002 m .53662 .54754 L .56742 .52684 L 1 g
F
P
p
.002 w
.56746 .52867 m .56854 .53025 L p
.56733 .52241 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56746 .52867 L p
1 g
F P
s
P
p
.56494 .53609 m .56257 .5491 L .56746 .52867 L 1 g
F
P
p
.002 w
.56133 .54675 m .56257 .5491 L p
.56494 .53609 L 1 g
F P
s
P
p
.5562 .55391 m .55142 .5606 L .55417 .55759 L 1 g
F
P
p
.002 w
.50683 .56254 m .53662 .54754 L .55142 .5606 L p
1 g
F P
s
P
p
.54719 .56521 m .50683 .56254 L .55142 .5606 L 1 g
F
P
p
.002 w
.54919 .56303 m .54998 .56518 L p
.55417 .55759 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54919 .56303 L p
1 g
F P
s
P
p
.54183 .56768 m .5322 .57686 L .54919 .56303 L 1 g
F
P
p
.002 w
.53161 .57415 m .5322 .57686 L p
.54183 .56768 L 1 g
F P
s
P
p
.52165 .57759 m .51636 .57942 L .51914 .57888 L 1 g
F
P
p
.002 w
.51093 .58047 m .51111 .583 L p
.51914 .57888 L 1 g
F P
s
P
p
.002 w
.51942 .58484 m .51322 .58566 L p
.50473 .58168 L 1 g
F P
s
P
p
.5061 .58141 m .50473 .58168 L .50181 .5803 L 1 g
F
P
p
.50803 .58042 m .50181 .5803 L .47358 .56705 L 1 g
F
P
p
.002 w
.48896 .58198 m .48921 .57862 L p
.4773 .57764 L 1 g
F P
s
P
p
.002 w
.47506 .57681 m .47358 .56705 L p
.51322 .58566 L 1 g
F P
s
P
p
.002 w
.4891 .58007 m .48889 .583 L p
.50232 .58031 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58047 L p
1 g
F P
s
P
p
.50232 .58031 m .48889 .583 L .51093 .58047 L 1 g
F
P
p
.002 w
.46816 .57521 m .4678 .57686 L p
.47938 .57781 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46836 .57432 L p
1 g
F P
s
P
p
.46059 .5694 m .45002 .56518 L .46836 .57432 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48896 .58198 L p
1 g
F P
s
P
p
.4773 .57764 m .4678 .57686 L .48896 .58198 L 1 g
F
P
p
.002 w
.50299 .30149 m .45078 .30137 L .4518 .27724 L p
1 g
F P
s
P
p
.002 w
.4518 .27724 m .51031 .27724 L .50299 .30149 L p
1 g
F P
s
P
p
.002 w
.63203 .49776 m .63663 .44656 L .65991 .4398 L p
1 g
F P
s
P
p
.002 w
.64571 .38299 m .65991 .4398 L .63663 .44656 L p
1 g
F P
s
P
p
.002 w
.41016 .34432 m .37666 .371 L .36283 .34992 L p
1 g
F P
s
P
p
.002 w
.36283 .34992 m .40228 .31825 L .41016 .34432 L p
1 g
F P
s
P
p
.002 w
.55741 .56588 m .58697 .53535 L .61088 .54376 L p
1 g
F P
s
P
p
.002 w
.63203 .49776 m .61088 .54376 L .58697 .53535 L p
1 g
F P
s
P
p
.002 w
.37695 .42275 m .36962 .4553 L .34505 .44855 L p
1 g
F P
s
P
p
.002 w
.34505 .44855 m .35423 .40709 L .37695 .42275 L p
1 g
F P
s
P
p
.002 w
.55296 .31886 m .50299 .30149 L .51031 .27724 L p
1 g
F P
s
P
p
.002 w
.51031 .27724 m .56633 .29663 L .55296 .31886 L p
1 g
F P
s
P
p
.002 w
.63663 .44656 m .62384 .39589 L .64571 .38299 L p
1 g
F P
s
P
p
.002 w
.6133 .33331 m .64571 .38299 L .62384 .39589 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59486 .35159 m .55296 .31886 L .56633 .29663 L p
1 g
F P
s
P
p
.002 w
.56633 .29663 m .6133 .33331 L .59486 .35159 L p
1 g
F P
s
P
p
.002 w
.62384 .39589 m .59486 .35159 L .6133 .33331 L p
1 g
F P
s
P
p
.002 w
.45123 .33019 m .41016 .34432 L .40228 .31825 L p
1 g
F P
s
P
p
.002 w
.40228 .31825 m .45078 .30137 L .45123 .33019 L p
1 g
F P
s
P
p
.002 w
.58697 .53535 m .60472 .49634 L .63203 .49776 L p
1 g
F P
s
P
p
.002 w
.63663 .44656 m .63203 .49776 L .60472 .49634 L p
1 g
F P
s
P
p
.002 w
.39467 .39451 m .37695 .42275 L .35423 .40709 L p
1 g
F P
s
P
p
.002 w
.35423 .40709 m .37666 .371 L .39467 .39451 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41115 .50578 m .42717 .523 L .41066 .54422 L p
1 g
F P
s
P
p
.002 w
.41066 .54422 m .3875 .51936 L .41115 .50578 L p
1 g
F P
s
P
p
.002 w
.44037 .56069 m .41066 .54422 L .42717 .523 L p
1 g
F P
s
P
p
.002 w
.40137 .48453 m .41115 .50578 L .3875 .51936 L p
1 g
F P
s
P
p
.002 w
.3875 .51936 m .37331 .48866 L .40137 .48453 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.3989 .46147 m .40137 .48453 L .37331 .48866 L p
1 g
F P
s
P
p
.002 w
.37331 .48866 m .36962 .4553 L .3989 .46147 L p
1 g
F P
s
P
p
.002 w
.44774 .53439 m .47071 .53873 L .47358 .56705 L p
1 g
F P
s
P
p
.002 w
.50683 .56254 m .47358 .56705 L .47071 .53873 L p
1 g
F P
s
P
p
.002 w
.49537 .33042 m .45123 .33019 L .45078 .30137 L p
1 g
F P
s
P
p
.002 w
.45078 .30137 m .50299 .30149 L .49537 .33042 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60472 .49634 m .60846 .45303 L .63663 .44656 L p
1 g
F P
s
P
p
.002 w
.62384 .39589 m .63663 .44656 L .60846 .45303 L p
1 g
F P
s
P
p
.002 w
.42102 .37373 m .39467 .39451 L .37666 .371 L p
1 g
F P
s
P
p
.002 w
.37666 .371 m .41016 .34432 L .42102 .37373 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.40406 .43904 m .3989 .46147 L .36962 .4553 L p
1 g
F P
s
P
p
.002 w
.36962 .4553 m .37695 .42275 L .40406 .43904 L p
1 g
F P
s
P
p
.002 w
.47071 .53873 m .49367 .53555 L .50683 .56254 L p
1 g
F P
s
P
p
.002 w
.53662 .54754 m .50683 .56254 L .49367 .53555 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.53757 .34516 m .49537 .33042 L .50299 .30149 L p
1 g
F P
s
P
p
.002 w
.50299 .30149 m .55296 .31886 L .53757 .34516 L p
1 g
F P
s
P
p
.002 w
.60846 .45303 m .59752 .41022 L .62384 .39589 L p
1 g
F P
s
P
p
.002 w
.59486 .35159 m .62384 .39589 L .59752 .41022 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.45321 .36281 m .42102 .37373 L .41016 .34432 L p
1 g
F P
s
P
p
.002 w
.41016 .34432 m .45123 .33019 L .45321 .36281 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.60846 .45303 m .60472 .49634 L .57347 .49285 L p
1 g
F P
s
P
p
.002 w
.57298 .37282 m .53757 .34516 L .55296 .31886 L p
1 g
F P
s
P
p
.002 w
.55296 .31886 m .59486 .35159 L .57298 .37282 L p
1 g
F P
s
P
p
.002 w
.59752 .41022 m .57298 .37282 L .59486 .35159 L p
1 g
F P
s
P
p
.002 w
.41636 .41966 m .40406 .43904 L .37695 .42275 L p
1 g
F P
s
P
p
.002 w
.37695 .42275 m .39467 .39451 L .41636 .41966 L p
1 g
F P
s
P
p
.002 w
.49367 .53555 m .51417 .52511 L .53662 .54754 L p
1 g
F P
s
P
p
.002 w
.5597 .52348 m .53662 .54754 L .51417 .52511 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42717 .523 m .41115 .50578 L .43816 .48952 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43318 .47862 m .43816 .48952 L .41115 .50578 L p
1 g
F P
s
P
p
.002 w
.41115 .50578 m .40137 .48453 L .43318 .47862 L p
1 g
F P
s
P
p
.002 w
.44637 .49835 m .45692 .50418 L .44774 .53439 L p
1 g
F P
s
P
p
.002 w
.47071 .53873 m .44774 .53439 L .45692 .50418 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.43196 .46682 m .43318 .47862 L .40137 .48453 L p
1 g
F P
s
P
p
.002 w
.40137 .48453 m .3989 .46147 L .43196 .46682 L p
1 g
F P
s
P
p
.002 w
.45692 .50418 m .4687 .50638 L .47071 .53873 L p
1 g
F P
s
P
p
.002 w
.49367 .53555 m .47071 .53873 L .4687 .50638 L p
1 g
F P
s
P
p
.002 w
.48773 .3631 m .45321 .36281 L .45123 .33019 L p
1 g
F P
s
P
p
.002 w
.45123 .33019 m .49537 .33042 L .48773 .3631 L p
1 g
F P
s
P
p
.002 w
.43455 .40547 m .41636 .41966 L .39467 .39451 L p
1 g
F P
s
P
p
.002 w
.39467 .39451 m .42102 .37373 L .43455 .40547 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.57347 .49285 m .57625 .45894 L .60846 .45303 L p
1 g
F P
s
P
p
.002 w
.59752 .41022 m .60846 .45303 L .57625 .45894 L p
1 g
F P
s
P
p
.002 w
.51417 .52511 m .52998 .50846 L .5597 .52348 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.43465 .45538 m .43196 .46682 L .3989 .46147 L p
1 g
F P
s
P
p
.002 w
.3989 .46147 m .40406 .43904 L .43465 .45538 L p
1 g
F P
s
P
p
.002 w
.4687 .50638 m .48043 .5047 L .49367 .53555 L p
1 g
F P
s
P
p
.002 w
.51417 .52511 m .49367 .53555 L .48043 .5047 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5207 .37468 m .48773 .3631 L .49537 .33042 L p
1 g
F P
s
P
p
.002 w
.49537 .33042 m .53757 .34516 L .5207 .37468 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57625 .45894 m .56759 .42549 L .59752 .41022 L p
1 g
F P
s
P
p
.002 w
.57298 .37282 m .59752 .41022 L .56759 .42549 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.45669 .39807 m .43455 .40547 L .42102 .37373 L p
1 g
F P
s
P
p
.002 w
.42102 .37373 m .45321 .36281 L .45669 .39807 L p
1 g
F P
s
P
p
.002 w
.44098 .44553 m .43465 .45538 L .40406 .43904 L p
1 g
F P
s
P
p
.002 w
.40406 .43904 m .41636 .41966 L .44098 .44553 L p
1 g
F P
s
P
p
.002 w
.48043 .5047 m .49088 .49932 L .51417 .52511 L p
1 g
F P
s
P
p
.002 w
.52998 .50846 m .51417 .52511 L .49088 .49932 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54837 .39629 m .5207 .37468 L .53757 .34516 L p
1 g
F P
s
P
p
.002 w
.53757 .34516 m .57298 .37282 L .54837 .39629 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.56759 .42549 m .54837 .39629 L .57298 .37282 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.45028 .43835 m .44098 .44553 L .41636 .41966 L p
1 g
F P
s
P
p
.002 w
.41636 .41966 m .43455 .40547 L .45028 .43835 L p
1 g
F P
s
P
p
.002 w
.49088 .49932 m .49889 .49079 L .52998 .50846 L p
1 g
F P
s
P
p
.002 w
.53934 .48736 m .52998 .50846 L .49889 .49079 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.43318 .47862 m .43196 .46682 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.48037 .39835 m .45669 .39807 L .45321 .36281 L p
1 g
F P
s
P
p
.002 w
.45321 .36281 m .48773 .3631 L .48037 .39835 L p
1 g
F P
s
P
p
.002 w
.56759 .42549 m .57625 .45894 L .54114 .46406 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43196 .46682 m .43465 .45538 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.46155 .43465 m .45028 .43835 L .43455 .40547 L p
1 g
F P
s
P
p
.002 w
.43455 .40547 m .45669 .39807 L .46155 .43465 L p
1 g
F P
s
P
p
.002 w
.43465 .45538 m .44098 .44553 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49889 .49079 m .50359 .48002 L .53934 .48736 L p
1 g
F P
s
P
p
.002 w
.50295 .40633 m .48037 .39835 L .48773 .3631 L p
1 g
F P
s
P
p
.002 w
.48773 .3631 m .5207 .37468 L .50295 .40633 L p
1 g
F P
s
P
p
.002 w
.54114 .46406 m .53513 .44114 L .56759 .42549 L p
1 g
F P
s
P
p
.002 w
.54837 .39629 m .56759 .42549 L .53513 .44114 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.44098 .44553 m .45028 .43835 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.52191 .42115 m .50295 .40633 L .5207 .37468 L p
1 g
F P
s
P
p
.002 w
.5207 .37468 m .54837 .39629 L .52191 .42115 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.53513 .44114 m .52191 .42115 L .54837 .39629 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47357 .43483 m .46155 .43465 L .45669 .39807 L p
1 g
F P
s
P
p
.002 w
.45669 .39807 m .48037 .39835 L .47357 .43483 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48502 .4389 m .49464 .44642 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.004 w
.49013 .44289 m
.5 .43051 L
s
P
p
.002 w
.47357 .43483 m .48502 .4389 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.46155 .43465 m .47357 .43483 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.45028 .43835 m .46155 .43465 L .46762 .47111 L closepath p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.48502 .4389 m .47357 .43483 L .48037 .39835 L p
1 g
F P
s
P
p
.002 w
.48037 .39835 m .50295 .40633 L .48502 .4389 L p
1 g
F P
s
P
p
.002 w
.52191 .42115 m .53513 .44114 L .50136 .45655 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.50136 .45655 m .49464 .44642 L .52191 .42115 L p
1 g
F P
s
P
p
.002 w
.49464 .44642 m .48502 .4389 L .50295 .40633 L p
1 g
F P
s
P
p
.002 w
.50295 .40633 m .52191 .42115 L .49464 .44642 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.44759 .49623 m
.46762 .47111 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .21715 .40971 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .44759 .49623 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.613178)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.613178)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49024 .46126 m .50874 .46043 L .50289 .43255 L p
1 g
F P
s
P
p
.002 w
.50289 .43255 m .49352 .43297 L .49024 .46126 L p
1 g
F P
s
P
p
.002 w
.51161 .42915 m .50289 .43255 L .50874 .46043 L p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .49352 .43297 L .50289 .43255 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .50289 .43255 L .51161 .42915 L closepath p
1 g
F P
s
P
p
.002 w
.47246 .45612 m .49024 .46126 L .49352 .43297 L p
1 g
F P
s
P
p
.002 w
.49352 .43297 m .48454 .43036 L .47246 .45612 L p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .48454 .43036 L .49352 .43297 L closepath p
1 g
F P
s
P
p
.002 w
.50874 .46043 m .52599 .45372 L .51161 .42915 L p
1 g
F P
s
P
p
.002 w
.51876 .42313 m .51161 .42915 L .52599 .45372 L p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .51161 .42915 L .51876 .42313 L closepath p
1 g
F P
s
P
p
.002 w
.45731 .44555 m .47246 .45612 L .48454 .43036 L p
1 g
F P
s
P
p
.002 w
.48454 .43036 m .47689 .425 L .45731 .44555 L p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .47689 .425 L .48454 .43036 L closepath p
1 g
F P
s
P
p
.002 w
.52599 .45372 m .54016 .44183 L .51876 .42313 L p
1 g
F P
s
P
p
.002 w
.52357 .41514 m .51876 .42313 L .54016 .44183 L p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .51876 .42313 L .52357 .41514 L closepath p
1 g
F P
s
P
p
.002 w
.44642 .43066 m .45731 .44555 L .47689 .425 L p
1 g
F P
s
P
p
.002 w
.47689 .425 m .4714 .41747 L .44642 .43066 L p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .4714 .41747 L .47689 .425 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .46903 .39925 L .46868 .40856 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .46868 .40856 L .4714 .41747 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .52357 .41514 L .52551 .40602 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .52551 .40602 L .52436 .39678 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .52436 .39678 L .52024 .38841 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .52024 .38841 L .51358 .38182 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .51358 .38182 L .50512 .37774 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .50512 .37774 L .49577 .37661 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .49577 .37661 L .48655 .37856 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .48655 .37856 L .47847 .38338 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .47847 .38338 L .47242 .39054 L closepath p
1 g
F P
s
P
p
.002 w
.49696 .40465 m .47242 .39054 L .46903 .39925 L closepath p
1 g
F P
s
P
p
.002 w
.54016 .44183 m .5497 .42604 L .52357 .41514 L p
1 g
F P
s
P
p
.002 w
.52551 .40602 m .52357 .41514 L .5497 .42604 L p
1 g
F P
s
P
p
.002 w
.48717 .489 m .51442 .48777 L .50874 .46043 L p
1 g
F P
s
P
p
.002 w
.50874 .46043 m .49024 .46126 L .48717 .489 L p
1 g
F P
s
P
p
.002 w
.52599 .45372 m .50874 .46043 L .51442 .48777 L p
1 g
F P
s
P
p
.002 w
.44099 .41303 m .44642 .43066 L .4714 .41747 L p
1 g
F P
s
P
p
.002 w
.4714 .41747 m .46868 .40856 L .44099 .41303 L p
1 g
F P
s
P
p
.002 w
.46097 .48146 m .48717 .489 L .49024 .46126 L p
1 g
F P
s
P
p
.002 w
.49024 .46126 m .47246 .45612 L .46097 .48146 L p
1 g
F P
s
P
p
.002 w
.51442 .48777 m .53985 .4779 L .52599 .45372 L p
1 g
F P
s
P
p
.002 w
.54016 .44183 m .52599 .45372 L .53985 .4779 L p
1 g
F P
s
P
p
.002 w
.5497 .42604 m .55359 .40801 L .52551 .40602 L p
1 g
F P
s
P
p
.002 w
.52436 .39678 m .52551 .40602 L .55359 .40801 L p
1 g
F P
s
P
p
.002 w
.43861 .46592 m .46097 .48146 L .47246 .45612 L p
1 g
F P
s
P
p
.002 w
.47246 .45612 m .45731 .44555 L .43861 .46592 L p
1 g
F P
s
P
p
.002 w
.44163 .39456 m .44099 .41303 L .46868 .40856 L p
1 g
F P
s
P
p
.002 w
.46868 .40856 m .46903 .39925 L .44163 .39456 L p
1 g
F P
s
P
p
.002 w
.55359 .40801 m .55136 .38968 L .52436 .39678 L p
1 g
F P
s
P
p
.002 w
.52024 .38841 m .52436 .39678 L .55136 .38968 L p
1 g
F P
s
P
p
.002 w
.53985 .4779 m .56075 .46042 L .54016 .44183 L p
1 g
F P
s
P
p
.002 w
.5497 .42604 m .54016 .44183 L .56075 .46042 L p
1 g
F P
s
P
p
.002 w
.4483 .37726 m .44163 .39456 L .46903 .39925 L p
1 g
F P
s
P
p
.002 w
.46903 .39925 m .47242 .39054 L .4483 .37726 L p
1 g
F P
s
P
p
.002 w
.42249 .44399 m .43861 .46592 L .45731 .44555 L p
1 g
F P
s
P
p
.002 w
.45731 .44555 m .44642 .43066 L .42249 .44399 L p
1 g
F P
s
P
p
.002 w
.55136 .38968 m .54323 .37305 L .52024 .38841 L p
1 g
F P
s
P
p
.002 w
.51358 .38182 m .52024 .38841 L .54323 .37305 L p
1 g
F P
s
P
p
.002 w
.46031 .36303 m .4483 .37726 L .47242 .39054 L p
1 g
F P
s
P
p
.002 w
.47242 .39054 m .47847 .38338 L .46031 .36303 L p
1 g
F P
s
P
p
.002 w
.56075 .46042 m .57488 .43715 L .5497 .42604 L p
1 g
F P
s
P
p
.002 w
.55359 .40801 m .5497 .42604 L .57488 .43715 L p
1 g
F P
s
P
p
.002 w
.54323 .37305 m .53005 .35994 L .51358 .38182 L p
1 g
F P
s
P
p
.002 w
.50512 .37774 m .51358 .38182 L .53005 .35994 L p
1 g
F P
s
P
p
.002 w
.47635 .35343 m .46031 .36303 L .47847 .38338 L p
1 g
F P
s
P
p
.002 w
.47847 .38338 m .48655 .37856 L .47635 .35343 L p
1 g
F P
s
P
p
.002 w
.53005 .35994 m .51325 .3518 L .50512 .37774 L p
1 g
F P
s
P
p
.002 w
.49577 .37661 m .50512 .37774 L .51325 .3518 L p
1 g
F P
s
P
p
.002 w
.41439 .41799 m .42249 .44399 L .44642 .43066 L p
1 g
F P
s
P
p
.002 w
.44642 .43066 m .44099 .41303 L .41439 .41799 L p
1 g
F P
s
P
p
.002 w
.49467 .34955 m .47635 .35343 L .48655 .37856 L p
1 g
F P
s
P
p
.002 w
.48655 .37856 m .49577 .37661 L .49467 .34955 L p
1 g
F P
s
P
p
.002 w
.51325 .3518 m .49467 .34955 L .49577 .37661 L p
1 g
F P
s
P
p
.002 w
.57488 .43715 m .58068 .41056 L .55359 .40801 L p
1 g
F P
s
P
p
.002 w
.55136 .38968 m .55359 .40801 L .58068 .41056 L p
1 g
F P
s
P
p
.002 w
.48437 .51568 m .51983 .51407 L .51442 .48777 L p
1 g
F P
s
P
p
.002 w
.51442 .48777 m .48717 .489 L .48437 .51568 L p
1 g
F P
s
P
p
.002 w
.53985 .4779 m .51442 .48777 L .51983 .51407 L p
1 g
F P
s
P
p
.002 w
.45027 .5059 m .48437 .51568 L .48717 .489 L p
1 g
F P
s
P
p
.002 w
.48717 .489 m .46097 .48146 L .45027 .5059 L p
1 g
F P
s
P
p
.002 w
.41526 .3907 m .41439 .41799 L .44099 .41303 L p
1 g
F P
s
P
p
.002 w
.44099 .41303 m .44163 .39456 L .41526 .3907 L p
1 g
F P
s
P
p
.002 w
.51983 .51407 m .55292 .50125 L .53985 .4779 L p
1 g
F P
s
P
p
.002 w
.56075 .46042 m .53985 .4779 L .55292 .50125 L p
1 g
F P
s
P
p
.002 w
.42112 .48572 m .45027 .5059 L .46097 .48146 L p
1 g
F P
s
P
p
.002 w
.46097 .48146 m .43861 .46592 L .42112 .48572 L p
1 g
F P
s
P
p
.002 w
.58068 .41056 m .57746 .38348 L .55136 .38968 L p
1 g
F P
s
P
p
.002 w
.54323 .37305 m .55136 .38968 L .57746 .38348 L p
1 g
F P
s
P
p
.002 w
.55292 .50125 m .58015 .47854 L .56075 .46042 L p
1 g
F P
s
P
p
.002 w
.57488 .43715 m .56075 .46042 L .58015 .47854 L p
1 g
F P
s
P
p
.002 w
.42507 .36509 m .41526 .3907 L .44163 .39456 L p
1 g
F P
s
P
p
.002 w
.44163 .39456 m .4483 .37726 L .42507 .36509 L p
1 g
F P
s
P
p
.002 w
.40006 .45721 m .42112 .48572 L .43861 .46592 L p
1 g
F P
s
P
p
.002 w
.43861 .46592 m .42249 .44399 L .40006 .45721 L p
1 g
F P
s
P
p
.002 w
.57746 .38348 m .5655 .35887 L .54323 .37305 L p
1 g
F P
s
P
p
.002 w
.53005 .35994 m .54323 .37305 L .5655 .35887 L p
1 g
F P
s
P
p
.002 w
.4428 .34399 m .42507 .36509 L .4483 .37726 L p
1 g
F P
s
P
p
.002 w
.4483 .37726 m .46031 .36303 L .4428 .34399 L p
1 g
F P
s
P
p
.002 w
.58015 .47854 m .59861 .44828 L .57488 .43715 L p
1 g
F P
s
P
p
.002 w
.58068 .41056 m .57488 .43715 L .59861 .44828 L p
1 g
F P
s
P
p
.002 w
.5655 .35887 m .54605 .33943 L .53005 .35994 L p
1 g
F P
s
P
p
.002 w
.51325 .3518 m .53005 .35994 L .54605 .33943 L p
1 g
F P
s
P
p
.002 w
.46654 .32976 m .4428 .34399 L .46031 .36303 L p
1 g
F P
s
P
p
.002 w
.46031 .36303 m .47635 .35343 L .46654 .32976 L p
1 g
F P
s
P
p
.002 w
.38943 .42334 m .40006 .45721 L .42249 .44399 L p
1 g
F P
s
P
p
.002 w
.42249 .44399 m .41439 .41799 L .38943 .42334 L p
1 g
F P
s
P
p
.002 w
.54605 .33943 m .5212 .32735 L .51325 .3518 L p
1 g
F P
s
P
p
.002 w
.49467 .34955 m .51325 .3518 L .5212 .32735 L p
1 g
F P
s
P
p
.002 w
.49368 .324 m .46654 .32976 L .47635 .35343 L p
1 g
F P
s
P
p
.002 w
.47635 .35343 m .49467 .34955 L .49368 .324 L p
1 g
F P
s
P
p
.002 w
.5212 .32735 m .49368 .324 L .49467 .34955 L p
1 g
F P
s
P
p
.002 w
.59861 .44828 m .60626 .41365 L .58068 .41056 L p
1 g
F P
s
P
p
.002 w
.57746 .38348 m .58068 .41056 L .60626 .41365 L p
1 g
F P
s
P
p
.002 w
.4819 .54077 m .52485 .53881 L .51983 .51407 L p
1 g
F P
s
P
p
.002 w
.51983 .51407 m .48437 .51568 L .4819 .54077 L p
1 g
F P
s
P
p
.002 w
.55292 .50125 m .51983 .51407 L .52485 .53881 L p
1 g
F P
s
P
p
.002 w
.39047 .38774 m .38943 .42334 L .41439 .41799 L p
1 g
F P
s
P
p
.002 w
.41439 .41799 m .41526 .3907 L .39047 .38774 L p
1 g
F P
s
P
p
.002 w
.44059 .52896 m .4819 .54077 L .48437 .51568 L p
1 g
F P
s
P
p
.002 w
.48437 .51568 m .45027 .5059 L .44059 .52896 L p
1 g
F P
s
P
p
.002 w
.52485 .53881 m .56493 .52331 L .55292 .50125 L p
1 g
F P
s
P
p
.002 w
.58015 .47854 m .55292 .50125 L .56493 .52331 L p
1 g
F P
s
P
p
.002 w
.40523 .50457 m .44059 .52896 L .45027 .5059 L p
1 g
F P
s
P
p
.002 w
.45027 .5059 m .42112 .48572 L .40523 .50457 L p
1 g
F P
s
P
p
.002 w
.60626 .41365 m .60215 .37833 L .57746 .38348 L p
1 g
F P
s
P
p
.002 w
.5655 .35887 m .57746 .38348 L .60215 .37833 L p
1 g
F P
s
P
p
.002 w
.56493 .52331 m .59797 .49584 L .58015 .47854 L p
1 g
F P
s
P
p
.002 w
.59861 .44828 m .58015 .47854 L .59797 .49584 L p
1 g
F P
s
P
p
.002 w
.4032 .35428 m .39047 .38774 L .41526 .3907 L p
1 g
F P
s
P
p
.002 w
.41526 .3907 m .42507 .36509 L .4032 .35428 L p
1 g
F P
s
P
p
.002 w
.37963 .47006 m .40523 .50457 L .42112 .48572 L p
1 g
F P
s
P
p
.002 w
.42112 .48572 m .40006 .45721 L .37963 .47006 L p
1 g
F P
s
P
p
.002 w
.60215 .37833 m .58662 .34617 L .5655 .35887 L p
1 g
F P
s
P
p
.002 w
.54605 .33943 m .5655 .35887 L .58662 .34617 L p
1 g
F P
s
P
p
.002 w
.42633 .32667 m .4032 .35428 L .42507 .36509 L p
1 g
F P
s
P
p
.002 w
.42507 .36509 m .4428 .34399 L .42633 .32667 L p
1 g
F P
s
P
p
.002 w
.59797 .49584 m .62041 .45921 L .59861 .44828 L p
1 g
F P
s
P
p
.002 w
.60626 .41365 m .59861 .44828 L .62041 .45921 L p
1 g
F P
s
P
p
.002 w
.58662 .34617 m .56126 .32073 L .54605 .33943 L p
1 g
F P
s
P
p
.002 w
.5212 .32735 m .54605 .33943 L .56126 .32073 L p
1 g
F P
s
P
p
.002 w
.36663 .42901 m .37963 .47006 L .40006 .45721 L p
1 g
F P
s
P
p
.002 w
.40006 .45721 m .38943 .42334 L .36663 .42901 L p
1 g
F P
s
P
p
.002 w
.45734 .30804 m .42633 .32667 L .4428 .34399 L p
1 g
F P
s
P
p
.002 w
.4428 .34399 m .46654 .32976 L .45734 .30804 L p
1 g
F P
s
P
p
.002 w
.56126 .32073 m .5288 .3049 L .5212 .32735 L p
1 g
F P
s
P
p
.002 w
.49368 .324 m .5212 .32735 L .5288 .3049 L p
1 g
F P
s
P
p
.002 w
.49282 .3005 m .45734 .30804 L .46654 .32976 L p
1 g
F P
s
P
p
.002 w
.46654 .32976 m .49368 .324 L .49282 .3005 L p
1 g
F P
s
P
p
.002 w
.5288 .3049 m .49282 .3005 L .49368 .324 L p
1 g
F P
s
P
p
.002 w
.62041 .45921 m .62978 .41724 L .60626 .41365 L p
1 g
F P
s
P
p
.002 w
.60215 .37833 m .60626 .41365 L .62978 .41724 L p
1 g
F P
s
P
p
.002 w
.3678 .38578 m .36663 .42901 L .38943 .42334 L p
1 g
F P
s
P
p
.002 w
.38943 .42334 m .39047 .38774 L .3678 .38578 L p
1 g
F P
s
P
p
.002 w
.47983 .56371 m .52937 .56145 L .52485 .53881 L p
1 g
F P
s
P
p
.002 w
.52485 .53881 m .4819 .54077 L .47983 .56371 L p
1 g
F P
s
P
p
.002 w
.56493 .52331 m .52485 .53881 L .52937 .56145 L p
1 g
F P
s
P
p
.002 w
.43215 .55014 m .47983 .56371 L .4819 .54077 L p
1 g
F P
s
P
p
.002 w
.4819 .54077 m .44059 .52896 L .43215 .55014 L p
1 g
F P
s
P
p
.002 w
.52937 .56145 m .57562 .54359 L .56493 .52331 L p
1 g
F P
s
P
p
.002 w
.59797 .49584 m .56493 .52331 L .57562 .54359 L p
1 g
F P
s
P
p
.002 w
.62978 .41724 m .6249 .37436 L .60215 .37833 L p
1 g
F P
s
P
p
.002 w
.58662 .34617 m .60215 .37833 L .6249 .37436 L p
1 g
F P
s
P
p
.002 w
.39131 .52205 m .43215 .55014 L .44059 .52896 L p
1 g
F P
s
P
p
.002 w
.44059 .52896 m .40523 .50457 L .39131 .52205 L p
1 g
F P
s
P
p
.002 w
.38319 .3451 m .3678 .38578 L .39047 .38774 L p
1 g
F P
s
P
p
.002 w
.39047 .38774 m .4032 .35428 L .38319 .3451 L p
1 g
F P
s
P
p
.002 w
.57562 .54359 m .61378 .51195 L .59797 .49584 L p
1 g
F P
s
P
p
.002 w
.62041 .45921 m .59797 .49584 L .61378 .51195 L p
1 g
F P
s
P
p
.002 w
.36168 .48227 m .39131 .52205 L .40523 .50457 L p
1 g
F P
s
P
p
.002 w
.40523 .50457 m .37963 .47006 L .36168 .48227 L p
1 g
F P
s
P
p
.002 w
.6249 .37436 m .60612 .33526 L .58662 .34617 L p
1 g
F P
s
P
p
.002 w
.56126 .32073 m .58662 .34617 L .60612 .33526 L p
1 g
F P
s
P
p
.002 w
.41125 .3115 m .38319 .3451 L .4032 .35428 L p
1 g
F P
s
P
p
.002 w
.4032 .35428 m .42633 .32667 L .41125 .3115 L p
1 g
F P
s
P
p
.002 w
.61378 .51195 m .63976 .46972 L .62041 .45921 L p
1 g
F P
s
P
p
.002 w
.62978 .41724 m .62041 .45921 L .63976 .46972 L p
1 g
F P
s
P
p
.002 w
.60612 .33526 m .57534 .30429 L .56126 .32073 L p
1 g
F P
s
P
p
.002 w
.5288 .3049 m .56126 .32073 L .57534 .30429 L p
1 g
F P
s
P
p
.002 w
.34656 .43488 m .36168 .48227 L .37963 .47006 L p
1 g
F P
s
P
p
.002 w
.37963 .47006 m .36663 .42901 L .34656 .43488 L p
1 g
F P
s
P
p
.002 w
.44896 .2888 m .41125 .3115 L .42633 .32667 L p
1 g
F P
s
P
p
.002 w
.42633 .32667 m .45734 .30804 L .44896 .2888 L p
1 g
F P
s
P
p
.002 w
.57534 .30429 m .53589 .285 L .5288 .3049 L p
1 g
F P
s
P
p
.002 w
.49282 .3005 m .5288 .3049 L .53589 .285 L p
1 g
F P
s
P
p
.002 w
.49212 .27961 m .44896 .2888 L .45734 .30804 L p
1 g
F P
s
P
p
.002 w
.45734 .30804 m .49282 .3005 L .49212 .27961 L p
1 g
F P
s
P
p
.002 w
.53589 .285 m .49212 .27961 L .49282 .3005 L p
1 g
F P
s
P
p
.002 w
.63976 .46972 m .65067 .42126 L .62978 .41724 L p
1 g
F P
s
P
p
.002 w
.6249 .37436 m .62978 .41724 L .65067 .42126 L p
1 g
F P
s
P
p
.002 w
.34781 .38491 m .34656 .43488 L .36663 .42901 L p
1 g
F P
s
P
p
.002 w
.36663 .42901 m .3678 .38578 L .34781 .38491 L p
1 g
F P
s
P
p
.002 w
.47821 .58396 m .53328 .58143 L .52937 .56145 L p
1 g
F P
s
P
p
.002 w
.52937 .56145 m .47983 .56371 L .47821 .58396 L p
1 g
F P
s
P
p
.002 w
.57562 .54359 m .52937 .56145 L .53328 .58143 L p
1 g
F P
s
P
p
.002 w
.42519 .56891 m .47821 .58396 L .47983 .56371 L p
1 g
F P
s
P
p
.002 w
.47983 .56371 m .43215 .55014 L .42519 .56891 L p
1 g
F P
s
P
p
.002 w
.53328 .58143 m .58471 .56161 L .57562 .54359 L p
1 g
F P
s
P
p
.002 w
.61378 .51195 m .57562 .54359 L .58471 .56161 L p
1 g
F P
s
P
p
.002 w
.65067 .42126 m .64514 .37171 L .6249 .37436 L p
1 g
F P
s
P
p
.002 w
.60612 .33526 m .6249 .37436 L .64514 .37171 L p
1 g
F P
s
P
p
.002 w
.37973 .53774 m .42519 .56891 L .43215 .55014 L p
1 g
F P
s
P
p
.002 w
.43215 .55014 m .39131 .52205 L .37973 .53774 L p
1 g
F P
s
P
p
.002 w
.36553 .33782 m .34781 .38491 L .3678 .38578 L p
1 g
F P
s
P
p
.002 w
.3678 .38578 m .38319 .3451 L .36553 .33782 L p
1 g
F P
s
P
p
.002 w
.58471 .56161 m .62717 .52647 L .61378 .51195 L p
1 g
F P
s
P
p
.002 w
.63976 .46972 m .61378 .51195 L .62717 .52647 L p
1 g
F P
s
P
p
.002 w
.3467 .49354 m .37973 .53774 L .39131 .52205 L p
1 g
F P
s
P
p
.002 w
.39131 .52205 m .36168 .48227 L .3467 .49354 L p
1 g
F P
s
P
p
.002 w
.64514 .37171 m .62351 .32645 L .60612 .33526 L p
1 g
F P
s
P
p
.002 w
.57534 .30429 m .60612 .33526 L .62351 .32645 L p
1 g
F P
s
P
p
.002 w
.39796 .29889 m .36553 .33782 L .38319 .3451 L p
1 g
F P
s
P
p
.002 w
.38319 .3451 m .41125 .3115 L .39796 .29889 L p
1 g
F P
s
P
p
.002 w
.62717 .52647 m .65614 .47955 L .63976 .46972 L p
1 g
F P
s
P
p
.002 w
.65067 .42126 m .63976 .46972 L .65614 .47955 L p
1 g
F P
s
P
p
.002 w
.62351 .32645 m .58795 .29057 L .57534 .30429 L p
1 g
F P
s
P
p
.002 w
.53589 .285 m .57534 .30429 L .58795 .29057 L p
1 g
F P
s
P
p
.002 w
.32978 .44084 m .3467 .49354 L .36168 .48227 L p
1 g
F P
s
P
p
.002 w
.36168 .48227 m .34656 .43488 L .32978 .44084 L p
1 g
F P
s
P
p
.002 w
.44161 .27257 m .39796 .29889 L .41125 .3115 L p
1 g
F P
s
P
p
.002 w
.41125 .3115 m .44896 .2888 L .44161 .27257 L p
1 g
F P
s
P
p
.002 w
.58795 .29057 m .54229 .26818 L .53589 .285 L p
1 g
F P
s
P
p
.002 w
.49212 .27961 m .53589 .285 L .54229 .26818 L p
1 g
F P
s
P
p
.002 w
.4916 .26192 m .44161 .27257 L .44896 .2888 L p
1 g
F P
s
P
p
.002 w
.44896 .2888 m .49212 .27961 L .4916 .26192 L p
1 g
F P
s
P
p
.002 w
.65614 .47955 m .66837 .42566 L .65067 .42126 L p
1 g
F P
s
P
p
.002 w
.64514 .37171 m .65067 .42126 L .66837 .42566 L p
1 g
F P
s
P
p
.002 w
.54229 .26818 m .4916 .26192 L .49212 .27961 L p
1 g
F P
s
P
p
.002 w
.33108 .3852 m .32978 .44084 L .34656 .43488 L p
1 g
F P
s
P
p
.002 w
.34656 .43488 m .34781 .38491 L .33108 .3852 L p
1 g
F P
s
P
p
.002 w
.4771 .60093 m .53646 .59819 L .53328 .58143 L p
1 g
F P
s
P
p
.002 w
.53328 .58143 m .47821 .58396 L .4771 .60093 L p
1 g
F P
s
P
p
.002 w
.58471 .56161 m .53328 .58143 L .53646 .59819 L p
1 g
F P
s
P
p
.002 w
.41993 .58474 m .4771 .60093 L .47821 .58396 L p
1 g
F P
s
P
p
.002 w
.47821 .58396 m .42519 .56891 L .41993 .58474 L p
1 g
F P
s
P
p
.002 w
.53646 .59819 m .59191 .57685 L .58471 .56161 L p
1 g
F P
s
P
p
.002 w
.62717 .52647 m .58471 .56161 L .59191 .57685 L p
1 g
F P
s
P
p
.002 w
.66837 .42566 m .66231 .37049 L .64514 .37171 L p
1 g
F P
s
P
p
.002 w
.62351 .32645 m .64514 .37171 L .66231 .37049 L p
1 g
F P
s
P
p
.002 w
.37088 .55119 m .41993 .58474 L .42519 .56891 L p
1 g
F P
s
P
p
.002 w
.42519 .56891 m .37973 .53774 L .37088 .55119 L p
1 g
F P
s
P
p
.002 w
.35075 .33271 m .33108 .3852 L .34781 .38491 L p
1 g
F P
s
P
p
.002 w
.34781 .38491 m .36553 .33782 L .35075 .33271 L p
1 g
F P
s
P
p
.002 w
.59191 .57685 m .63772 .53901 L .62717 .52647 L p
1 g
F P
s
P
p
.002 w
.65614 .47955 m .62717 .52647 L .63772 .53901 L p
1 g
F P
s
P
p
.002 w
.3352 .50357 m .37088 .55119 L .37973 .53774 L p
1 g
F P
s
P
p
.002 w
.37973 .53774 m .3467 .49354 L .3352 .50357 L p
1 g
F P
s
P
p
.002 w
.66231 .37049 m .63829 .32005 L .62351 .32645 L p
1 g
F P
s
P
p
.002 w
.58795 .29057 m .62351 .32645 L .63829 .32005 L p
1 g
F P
s
P
p
.002 w
.38686 .28927 m .35075 .33271 L .36553 .33782 L p
1 g
F P
s
P
p
.002 w
.36553 .33782 m .39796 .29889 L .38686 .28927 L p
1 g
F P
s
P
p
.002 w
.63772 .53901 m .66902 .48846 L .65614 .47955 L p
1 g
F P
s
P
p
.002 w
.66837 .42566 m .65614 .47955 L .66902 .48846 L p
1 g
F P
s
P
p
.002 w
.63829 .32005 m .59871 .28001 L .58795 .29057 L p
1 g
F P
s
P
p
.002 w
.54229 .26818 m .58795 .29057 L .59871 .28001 L p
1 g
F P
s
P
p
.002 w
.31687 .44675 m .3352 .50357 L .3467 .49354 L p
1 g
F P
s
P
p
.002 w
.3467 .49354 m .32978 .44084 L .31687 .44675 L p
1 g
F P
s
P
p
.002 w
.43552 .25989 m .38686 .28927 L .39796 .29889 L p
1 g
F P
s
P
p
.002 w
.39796 .29889 m .44161 .27257 L .43552 .25989 L p
1 g
F P
s
P
p
.002 w
.59871 .28001 m .54782 .255 L .54229 .26818 L p
1 g
F P
s
P
p
.002 w
.4916 .26192 m .54229 .26818 L .54782 .255 L p
1 g
F P
s
P
p
.002 w
.49129 .24801 m .43552 .25989 L .44161 .27257 L p
1 g
F P
s
P
p
.002 w
.44161 .27257 m .4916 .26192 L .49129 .24801 L p
1 g
F P
s
P
p
.002 w
.66902 .48846 m .6823 .43036 L .66837 .42566 L p
1 g
F P
s
P
p
.002 w
.66231 .37049 m .66837 .42566 L .6823 .43036 L p
1 g
F P
s
P
p
.002 w
.54782 .255 m .49129 .24801 L .4916 .26192 L p
1 g
F P
s
P
p
.002 w
.31819 .3867 m .31687 .44675 L .32978 .44084 L p
1 g
F P
s
P
p
.002 w
.32978 .44084 m .33108 .3852 L .31819 .3867 L p
1 g
F P
s
P
p
.002 w
.47655 .61404 m .53879 .61117 L .53646 .59819 L p
1 g
F P
s
P
p
.002 w
.53646 .59819 m .4771 .60093 L .47655 .61404 L p
1 g
F P
s
P
p
.002 w
.59191 .57685 m .53646 .59819 L .53879 .61117 L p
1 g
F P
s
P
p
.002 w
.41659 .5971 m .47655 .61404 L .4771 .60093 L p
1 g
F P
s
P
p
.002 w
.4771 .60093 m .41993 .58474 L .41659 .5971 L p
1 g
F P
s
P
p
.002 w
.53879 .61117 m .59695 .5888 L .59191 .57685 L p
1 g
F P
s
P
p
.002 w
.63772 .53901 m .59191 .57685 L .59695 .5888 L p
1 g
F P
s
P
p
.002 w
.6823 .43036 m .67583 .37082 L .66231 .37049 L p
1 g
F P
s
P
p
.002 w
.63829 .32005 m .66231 .37049 L .67583 .37082 L p
1 g
F P
s
P
p
.002 w
.36513 .56195 m .41659 .5971 L .41993 .58474 L p
1 g
F P
s
P
p
.002 w
.41993 .58474 m .37088 .55119 L .36513 .56195 L p
1 g
F P
s
P
p
.002 w
.33937 .33 m .31819 .3867 L .33108 .3852 L p
1 g
F P
s
P
p
.002 w
.33108 .3852 m .35075 .33271 L .33937 .33 L p
1 g
F P
s
P
p
.002 w
.59695 .5888 m .64502 .54916 L .63772 .53901 L p
1 g
F P
s
P
p
.002 w
.66902 .48846 m .63772 .53901 L .64502 .54916 L p
1 g
F P
s
P
p
.002 w
.32765 .51205 m .36513 .56195 L .37088 .55119 L p
1 g
F P
s
P
p
.002 w
.37088 .55119 m .3352 .50357 L .32765 .51205 L p
1 g
F P
s
P
p
.002 w
.67583 .37082 m .64997 .31634 L .63829 .32005 L p
1 g
F P
s
P
p
.002 w
.59871 .28001 m .63829 .32005 L .64997 .31634 L p
1 g
F P
s
P
p
.002 w
.37834 .28305 m .33937 .33 L .35075 .33271 L p
1 g
F P
s
P
p
.002 w
.35075 .33271 m .38686 .28927 L .37834 .28305 L p
1 g
F P
s
P
p
.002 w
.64502 .54916 m .67789 .49617 L .66902 .48846 L p
1 g
F P
s
P
p
.002 w
.6823 .43036 m .66902 .48846 L .67789 .49617 L p
1 g
F P
s
P
p
.002 w
.64997 .31634 m .60727 .27305 L .59871 .28001 L p
1 g
F P
s
P
p
.002 w
.54782 .255 m .59871 .28001 L .60727 .27305 L p
1 g
F P
s
P
p
.002 w
.30836 .45246 m .32765 .51205 L .3352 .50357 L p
1 g
F P
s
P
p
.002 w
.3352 .50357 m .31687 .44675 L .30836 .45246 L p
1 g
F P
s
P
p
.002 w
.43091 .25128 m .37834 .28305 L .38686 .28927 L p
1 g
F P
s
P
p
.002 w
.38686 .28927 m .43552 .25989 L .43091 .25128 L p
1 g
F P
s
P
p
.002 w
.60727 .27305 m .55229 .246 L .54782 .255 L p
1 g
F P
s
P
p
.002 w
.49129 .24801 m .54782 .255 L .55229 .246 L p
1 g
F P
s
P
p
.002 w
.67789 .49617 m .69189 .43524 L .6823 .43036 L p
1 g
F P
s
P
p
.002 w
.67583 .37082 m .6823 .43036 L .69189 .43524 L p
1 g
F P
s
P
p
.002 w
.49119 .23843 m .43091 .25128 L .43552 .25989 L p
1 g
F P
s
P
p
.002 w
.43552 .25989 m .49129 .24801 L .49119 .23843 L p
1 g
F P
s
P
p
.002 w
.55229 .246 m .49119 .23843 L .49129 .24801 L p
1 g
F P
s
P
p
.002 w
.3097 .38946 m .30836 .45246 L .31687 .44675 L p
1 g
F P
s
P
p
.002 w
.31687 .44675 m .31819 .3867 L .3097 .38946 L p
1 g
F P
s
P
p
.002 w
.47661 .62273 m .54018 .6198 L .53879 .61117 L p
1 g
F P
s
P
p
.002 w
.53879 .61117 m .47655 .61404 L .47661 .62273 L p
1 g
F P
s
P
p
.002 w
.59695 .5888 m .53879 .61117 L .54018 .6198 L p
1 g
F P
s
P
p
.002 w
.41537 .60545 m .47661 .62273 L .47655 .61404 L p
1 g
F P
s
P
p
.002 w
.47655 .61404 m .41659 .5971 L .41537 .60545 L p
1 g
F P
s
P
p
.002 w
.54018 .6198 m .59958 .59697 L .59695 .5888 L p
1 g
F P
s
P
p
.002 w
.64502 .54916 m .59695 .5888 L .59958 .59697 L p
1 g
F P
s
P
p
.002 w
.69189 .43524 m .68516 .37278 L .67583 .37082 L p
1 g
F P
s
P
p
.002 w
.64997 .31634 m .67583 .37082 L .68516 .37278 L p
1 g
F P
s
P
p
.002 w
.3628 .56959 m .41537 .60545 L .41659 .5971 L p
1 g
F P
s
P
p
.002 w
.41659 .5971 m .36513 .56195 L .3628 .56959 L p
1 g
F P
s
P
p
.002 w
.33189 .32993 m .3097 .38946 L .31819 .3867 L p
1 g
F P
s
P
p
.002 w
.31819 .3867 m .33937 .33 L .33189 .32993 L p
1 g
F P
s
P
p
.002 w
.59958 .59697 m .64869 .5565 L .64502 .54916 L p
1 g
F P
s
P
p
.002 w
.67789 .49617 m .64502 .54916 L .64869 .5565 L p
1 g
F P
s
P
p
.002 w
.3245 .51866 m .3628 .56959 L .36513 .56195 L p
1 g
F P
s
P
p
.002 w
.36513 .56195 m .32765 .51205 L .3245 .51866 L p
1 g
F P
s
P
p
.002 w
.68516 .37278 m .65806 .31558 L .64997 .31634 L p
1 g
F P
s
P
p
.002 w
.60727 .27305 m .64997 .31634 L .65806 .31558 L p
1 g
F P
s
P
p
.002 w
.37279 .2806 m .33189 .32993 L .33937 .33 L p
1 g
F P
s
P
p
.002 w
.33937 .33 m .37834 .28305 L .37279 .2806 L p
1 g
F P
s
P
p
.002 w
.64869 .5565 m .68229 .50242 L .67789 .49617 L p
1 g
F P
s
P
p
.002 w
.69189 .43524 m .67789 .49617 L .68229 .50242 L p
1 g
F P
s
P
p
.002 w
.65806 .31558 m .61325 .27011 L .60727 .27305 L p
1 g
F P
s
P
p
.002 w
.55229 .246 m .60727 .27305 L .61325 .27011 L p
1 g
F P
s
P
p
.002 w
.30478 .45781 m .3245 .51866 L .32765 .51205 L p
1 g
F P
s
P
p
.002 w
.32765 .51205 m .30836 .45246 L .30478 .45781 L p
1 g
F P
s
P
p
.002 w
.42801 .24722 m .37279 .2806 L .37834 .28305 L p
1 g
F P
s
P
p
.002 w
.37834 .28305 m .43091 .25128 L .42801 .24722 L p
1 g
F P
s
P
p
.002 w
.61325 .27011 m .55552 .24169 L .55229 .246 L p
1 g
F P
s
P
p
.002 w
.49119 .23843 m .55229 .246 L .55552 .24169 L p
1 g
F P
s
P
p
.002 w
.68229 .50242 m .69661 .44021 L .69189 .43524 L p
1 g
F P
s
P
p
.002 w
.68516 .37278 m .69189 .43524 L .69661 .44021 L p
1 g
F P
s
P
p
.002 w
.49133 .23372 m .42801 .24722 L .43091 .25128 L p
1 g
F P
s
P
p
.002 w
.43091 .25128 m .49119 .23843 L .49133 .23372 L p
1 g
F P
s
P
p
.002 w
.55552 .24169 m .49133 .23372 L .49119 .23843 L p
1 g
F P
s
P
p
.002 w
.30612 .39347 m .30478 .45781 L .30836 .45246 L p
1 g
F P
s
P
p
.002 w
.30836 .45246 m .3097 .38946 L .30612 .39347 L p
1 g
F P
s
P
p
.002 w
.47732 .6265 m .54052 .62358 L .54018 .6198 L p
1 g
F P
s
P
p
.002 w
.54018 .6198 m .47661 .62273 L .47732 .6265 L p
1 g
F P
s
P
p
.002 w
.59958 .59697 m .54018 .6198 L .54052 .62358 L p
1 g
F P
s
P
p
.002 w
.41645 .60933 m .47732 .6265 L .47661 .62273 L p
1 g
F P
s
P
p
.002 w
.47661 .62273 m .41537 .60545 L .41645 .60933 L p
1 g
F P
s
P
p
.002 w
.69661 .44021 m .68977 .37641 L .68516 .37278 L p
1 g
F P
s
P
p
.002 w
.65806 .31558 m .68516 .37278 L .68977 .37641 L p
1 g
F P
s
P
p
.002 w
.54052 .62358 m .59957 .60089 L .59958 .59697 L p
1 g
F P
s
P
p
.002 w
.64869 .5565 m .59958 .59697 L .59957 .60089 L p
1 g
F P
s
P
p
.002 w
.36419 .57369 m .41645 .60933 L .41537 .60545 L p
1 g
F P
s
P
p
.002 w
.41537 .60545 m .3628 .56959 L .36419 .57369 L p
1 g
F P
s
P
p
.002 w
.32878 .33266 m .30612 .39347 L .3097 .38946 L p
1 g
F P
s
P
p
.002 w
.3097 .38946 m .33189 .32993 L .32878 .33266 L p
1 g
F P
s
P
p
.002 w
.59957 .60089 m .64839 .56068 L .64869 .5565 L p
1 g
F P
s
P
p
.002 w
.68229 .50242 m .64869 .5565 L .64839 .56068 L p
1 g
F P
s
P
p
.002 w
.32613 .52309 m .36419 .57369 L .3628 .56959 L p
1 g
F P
s
P
p
.002 w
.3628 .56959 m .3245 .51866 L .32613 .52309 L p
1 g
F P
s
P
p
.002 w
.68977 .37641 m .66211 .31798 L .65806 .31558 L p
1 g
F P
s
P
p
.002 w
.61325 .27011 m .65806 .31558 L .66211 .31798 L p
1 g
F P
s
P
p
.004 w
.30266 .30637 m
.32411 .31986 L
s
P
p
.004 w
.29221 .2998 m
.30266 .30637 L
s
P
p
.004 w
.28659 .29627 m
.29221 .2998 L
s
P
p
.002 w
.37057 .28226 m .32878 .33266 L .33189 .32993 L p
1 g
F P
s
P
p
.002 w
.33189 .32993 m .37279 .2806 L .37057 .28226 L p
1 g
F P
s
P
p
.002 w
.64839 .56068 m .68179 .50693 L .68229 .50242 L p
1 g
F P
s
P
p
.002 w
.69661 .44021 m .68229 .50242 L .68179 .50693 L p
1 g
F P
s
P
p
.002 w
.66211 .31798 m .61633 .27153 L .61325 .27011 L p
1 g
F P
s
P
p
.002 w
.55552 .24169 m .61325 .27011 L .61633 .27153 L p
1 g
F P
s
P
p
.002 w
.30653 .46264 m .32613 .52309 L .3245 .51866 L p
1 g
F P
s
P
p
.002 w
.3245 .51866 m .30478 .45781 L .30653 .46264 L p
1 g
F P
s
P
p
.002 w
.427 .24814 m .37057 .28226 L .37279 .2806 L p
1 g
F P
s
P
p
.002 w
.37279 .2806 m .42801 .24722 L .427 .24814 L p
1 g
F P
s
P
p
.002 w
.61633 .27153 m .55733 .24248 L .55552 .24169 L p
1 g
F P
s
P
p
.002 w
.49133 .23372 m .55552 .24169 L .55733 .24248 L p
1 g
F P
s
P
p
.002 w
.68179 .50693 m .69602 .44512 L .69661 .44021 L p
1 g
F P
s
P
p
.002 w
.68977 .37641 m .69661 .44021 L .69602 .44512 L p
1 g
F P
s
P
p
.002 w
.49172 .23434 m .427 .24814 L .42801 .24722 L p
1 g
F P
s
P
p
.002 w
.42801 .24722 m .49133 .23372 L .49172 .23434 L p
1 g
F P
s
P
p
.002 w
.55733 .24248 m .49172 .23434 L .49133 .23372 L p
1 g
F P
s
P
p
.002 w
.30788 .39871 m .30653 .46264 L .30478 .45781 L p
1 g
F P
s
P
p
.002 w
.30478 .45781 m .30612 .39347 L .30788 .39871 L p
1 g
F P
s
P
p
.002 w
.47871 .62489 m .53973 .62207 L .54052 .62358 L p
1 g
F P
s
P
p
.002 w
.54052 .62358 m .47732 .6265 L .47871 .62489 L p
1 g
F P
s
P
p
.002 w
.59957 .60089 m .54052 .62358 L .53973 .62207 L p
1 g
F P
s
P
p
.002 w
.41994 .60831 m .47871 .62489 L .47732 .6265 L p
1 g
F P
s
P
p
.002 w
.47732 .6265 m .41645 .60933 L .41994 .60831 L p
1 g
F P
s
P
p
.002 w
.69602 .44512 m .68922 .38174 L .68977 .37641 L p
1 g
F P
s
P
p
.002 w
.66211 .31798 m .68977 .37641 L .68922 .38174 L p
1 g
F P
s
P
p
.002 w
.53973 .62207 m .59674 .60016 L .59957 .60089 L p
1 g
F P
s
P
p
.002 w
.64839 .56068 m .59957 .60089 L .59674 .60016 L p
1 g
F P
s
P
p
.002 w
.36951 .57391 m .41994 .60831 L .41645 .60933 L p
1 g
F P
s
P
p
.002 w
.41645 .60933 m .36419 .57369 L .36951 .57391 L p
1 g
F P
s
P
p
.002 w
.33041 .3383 m .30788 .39871 L .30612 .39347 L p
1 g
F P
s
P
p
.002 w
.30612 .39347 m .32878 .33266 L .33041 .3383 L p
1 g
F P
s
P
p
.002 w
.59674 .60016 m .64386 .56134 L .64839 .56068 L p
1 g
F P
s
P
p
.002 w
.68179 .50693 m .64839 .56068 L .64386 .56134 L p
1 g
F P
s
P
p
.002 w
.3328 .52506 m .36951 .57391 L .36419 .57369 L p
1 g
F P
s
P
p
.002 w
.36419 .57369 m .32613 .52309 L .3328 .52506 L p
1 g
F P
s
P
p
.002 w
.68922 .38174 m .66172 .3237 L .66211 .31798 L p
1 g
F P
s
P
p
.002 w
.61633 .27153 m .66211 .31798 L .66172 .3237 L p
1 g
F P
s
P
p
.002 w
.37195 .28823 m .33041 .3383 L .32878 .33266 L p
1 g
F P
s
P
p
.002 w
.32878 .33266 m .37057 .28226 L .37195 .28823 L p
1 g
F P
s
P
p
.002 w
.64386 .56134 m .67608 .50947 L .68179 .50693 L p
1 g
F P
s
P
p
.002 w
.69602 .44512 m .68179 .50693 L .67608 .50947 L p
1 g
F P
s
P
p
.002 w
.66172 .3237 m .61621 .27756 L .61633 .27153 L p
1 g
F P
s
P
p
.002 w
.55733 .24248 m .61633 .27153 L .61621 .27756 L p
1 g
F P
s
P
p
.002 w
.31393 .46675 m .3328 .52506 L .32613 .52309 L p
1 g
F P
s
P
p
.002 w
.32613 .52309 m .30653 .46264 L .31393 .46675 L p
1 g
F P
s
P
p
.002 w
.42804 .25434 m .37195 .28823 L .37057 .28226 L p
1 g
F P
s
P
p
.002 w
.37057 .28226 m .427 .24814 L .42804 .25434 L p
1 g
F P
s
P
p
.002 w
.61621 .27756 m .55758 .24871 L .55733 .24248 L p
1 g
F P
s
P
p
.002 w
.49172 .23434 m .55733 .24248 L .55758 .24871 L p
1 g
F P
s
P
p
.002 w
.67608 .50947 m .68978 .44983 L .69602 .44512 L p
1 g
F P
s
P
p
.002 w
.68922 .38174 m .69602 .44512 L .68978 .44983 L p
1 g
F P
s
P
p
.002 w
.49237 .24063 m .42804 .25434 L .427 .24814 L p
1 g
F P
s
P
p
.002 w
.427 .24814 m .49172 .23434 L .49237 .24063 L p
1 g
F P
s
P
p
.002 w
.55758 .24871 m .49237 .24063 L .49172 .23434 L p
1 g
F P
s
P
p
.002 w
.31527 .4051 m .31393 .46675 L .30653 .46264 L p
1 g
F P
s
P
p
.002 w
.30653 .46264 m .30788 .39871 L .31527 .4051 L p
1 g
F P
s
P
p
.002 w
.48077 .6176 m .53776 .61497 L .53973 .62207 L p
1 g
F P
s
P
p
.002 w
.53973 .62207 m .47871 .62489 L .48077 .6176 L p
1 g
F P
s
P
p
.002 w
.59674 .60016 m .53973 .62207 L .53776 .61497 L p
1 g
F P
s
P
p
.002 w
.42589 .6021 m .48077 .6176 L .47871 .62489 L p
1 g
F P
s
P
p
.002 w
.47871 .62489 m .41994 .60831 L .42589 .6021 L p
1 g
F P
s
P
p
.002 w
.68978 .44983 m .68318 .38871 L .68922 .38174 L p
1 g
F P
s
P
p
.002 w
.66172 .3237 m .68922 .38174 L .68318 .38871 L p
1 g
F P
s
P
p
.002 w
.53776 .61497 m .59099 .5945 L .59674 .60016 L p
1 g
F P
s
P
p
.002 w
.64386 .56134 m .59674 .60016 L .59099 .5945 L p
1 g
F P
s
P
p
.002 w
.37884 .56996 m .42589 .6021 L .41994 .60831 L p
1 g
F P
s
P
p
.002 w
.41994 .60831 m .36951 .57391 L .37884 .56996 L p
1 g
F P
s
P
p
.002 w
.33705 .34687 m .31527 .4051 L .30788 .39871 L p
1 g
F P
s
P
p
.002 w
.30788 .39871 m .33041 .3383 L .33705 .34687 L p
1 g
F P
s
P
p
.002 w
.59099 .5945 m .63496 .55824 L .64386 .56134 L p
1 g
F P
s
P
p
.002 w
.67608 .50947 m .64386 .56134 L .63496 .55824 L p
1 g
F P
s
P
p
.002 w
.34463 .52436 m .37884 .56996 L .36951 .57391 L p
1 g
F P
s
P
p
.002 w
.36951 .57391 m .3328 .52506 L .34463 .52436 L p
1 g
F P
s
P
p
.002 w
.68318 .38871 m .65661 .33277 L .66172 .3237 L p
1 g
F P
s
P
p
.002 w
.61621 .27756 m .66172 .3237 L .65661 .33277 L p
1 g
F P
s
P
p
.002 w
.37714 .29862 m .33705 .34687 L .33041 .3383 L p
1 g
F P
s
P
p
.002 w
.33041 .3383 m .37195 .28823 L .37714 .29862 L p
1 g
F P
s
P
p
.004 w
.32411 .31986 m
.33175 .32467 L
s
P
p
.002 w
.63496 .55824 m .66499 .50981 L .67608 .50947 L p
1 g
F P
s
P
p
.002 w
.68978 .44983 m .67608 .50947 L .66499 .50981 L p
1 g
F P
s
P
p
.002 w
.65661 .33277 m .6127 .28831 L .61621 .27756 L p
1 g
F P
s
P
p
.002 w
.55758 .24871 m .61621 .27756 L .6127 .28831 L p
1 g
F P
s
P
p
.002 w
.32711 .46996 m .34463 .52436 L .3328 .52506 L p
1 g
F P
s
P
p
.002 w
.3328 .52506 m .31393 .46675 L .32711 .46996 L p
1 g
F P
s
P
p
.002 w
.43124 .26597 m .37714 .29862 L .37195 .28823 L p
1 g
F P
s
P
p
.002 w
.37195 .28823 m .42804 .25434 L .43124 .26597 L p
1 g
F P
s
P
p
.002 w
.66499 .50981 m .67771 .45418 L .68978 .44983 L p
1 g
F P
s
P
p
.002 w
.68318 .38871 m .68978 .44983 L .67771 .45418 L p
1 g
F P
s
P
p
.002 w
.6127 .28831 m .55615 .26053 L .55758 .24871 L p
1 g
F P
s
P
p
.002 w
.49237 .24063 m .55758 .24871 L .55615 .26053 L p
1 g
F P
s
P
p
.002 w
.49327 .25276 m .43124 .26597 L .42804 .25434 L p
1 g
F P
s
P
p
.002 w
.42804 .25434 m .49237 .24063 L .49327 .25276 L p
1 g
F P
s
P
p
.002 w
.55615 .26053 m .49327 .25276 L .49237 .24063 L p
1 g
F P
s
P
p
.002 w
.32844 .41251 m .32711 .46996 L .31393 .46675 L p
1 g
F P
s
P
p
.002 w
.31393 .46675 m .31527 .4051 L .32844 .41251 L p
1 g
F P
s
P
p
.002 w
.48348 .60449 m .53459 .60214 L .53776 .61497 L p
1 g
F P
s
P
p
.002 w
.53776 .61497 m .48077 .6176 L .48348 .60449 L p
1 g
F P
s
P
p
.002 w
.59099 .5945 m .53776 .61497 L .53459 .60214 L p
1 g
F P
s
P
p
.002 w
.43429 .59057 m .48348 .60449 L .48077 .6176 L p
1 g
F P
s
P
p
.002 w
.48077 .6176 m .42589 .6021 L .43429 .59057 L p
1 g
F P
s
P
p
.002 w
.67771 .45418 m .67148 .39721 L .68318 .38871 L p
1 g
F P
s
P
p
.002 w
.65661 .33277 m .68318 .38871 L .67148 .39721 L p
1 g
F P
s
P
p
.002 w
.53459 .60214 m .58232 .58377 L .59099 .5945 L p
1 g
F P
s
P
p
.002 w
.63496 .55824 m .59099 .5945 L .58232 .58377 L p
1 g
F P
s
P
p
.002 w
.39215 .56173 m .43429 .59057 L .42589 .6021 L p
1 g
F P
s
P
p
.002 w
.42589 .6021 m .37884 .56996 L .39215 .56173 L p
1 g
F P
s
P
p
.002 w
.3488 .35827 m .32844 .41251 L .31527 .4051 L p
1 g
F P
s
P
p
.002 w
.31527 .4051 m .33705 .34687 L .3488 .35827 L p
1 g
F P
s
P
p
.002 w
.58232 .58377 m .62171 .55123 L .63496 .55824 L p
1 g
F P
s
P
p
.002 w
.66499 .50981 m .63496 .55824 L .62171 .55123 L p
1 g
F P
s
P
p
.002 w
.36157 .52084 m .39215 .56173 L .37884 .56996 L p
1 g
F P
s
P
p
.002 w
.37884 .56996 m .34463 .52436 L .36157 .52084 L p
1 g
F P
s
P
p
.002 w
.67148 .39721 m .64666 .3451 L .65661 .33277 L p
1 g
F P
s
P
p
.002 w
.6127 .28831 m .65661 .33277 L .64666 .3451 L p
1 g
F P
s
P
p
.002 w
.3862 .31337 m .3488 .35827 L .33705 .34687 L p
1 g
F P
s
P
p
.002 w
.33705 .34687 m .37714 .29862 L .3862 .31337 L p
1 g
F P
s
P
p
.002 w
.62171 .55123 m .64856 .50781 L .66499 .50981 L p
1 g
F P
s
P
p
.002 w
.67771 .45418 m .66499 .50981 L .64856 .50781 L p
1 g
F P
s
P
p
.002 w
.34597 .47213 m .36157 .52084 L .34463 .52436 L p
1 g
F P
s
P
p
.002 w
.34463 .52436 m .32711 .46996 L .34597 .47213 L p
1 g
F P
s
P
p
.002 w
.64666 .3451 m .60569 .30373 L .6127 .28831 L p
1 g
F P
s
P
p
.002 w
.55615 .26053 m .6127 .28831 L .60569 .30373 L p
1 g
F P
s
P
p
.002 w
.43662 .28298 m .3862 .31337 L .37714 .29862 L p
1 g
F P
s
P
p
.002 w
.37714 .29862 m .43124 .26597 L .43662 .28298 L p
1 g
F P
s
P
p
.002 w
.64856 .50781 m .65987 .45799 L .67771 .45418 L p
1 g
F P
s
P
p
.002 w
.67148 .39721 m .67771 .45418 L .65987 .45799 L p
1 g
F P
s
P
p
.002 w
.60569 .30373 m .55298 .2779 L .55615 .26053 L p
1 g
F P
s
P
p
.002 w
.49327 .25276 m .55615 .26053 L .55298 .2779 L p
1 g
F P
s
P
p
.002 w
.49441 .27068 m .43662 .28298 L .43124 .26597 L p
1 g
F P
s
P
p
.002 w
.43124 .26597 m .49327 .25276 L .49441 .27068 L p
1 g
F P
s
P
p
.002 w
.55298 .2779 m .49441 .27068 L .49327 .25276 L p
1 g
F P
s
P
p
.002 w
.34726 .42074 m .34597 .47213 L .32711 .46996 L p
1 g
F P
s
P
p
.002 w
.32711 .46996 m .32844 .41251 L .34726 .42074 L p
1 g
F P
s
P
p
.002 w
.4868 .58565 m .53026 .58365 L .53459 .60214 L p
1 g
F P
s
P
p
.002 w
.53459 .60214 m .48348 .60449 L .4868 .58565 L p
1 g
F P
s
P
p
.002 w
.58232 .58377 m .53459 .60214 L .53026 .58365 L p
1 g
F P
s
P
p
.002 w
.44499 .57378 m .4868 .58565 L .48348 .60449 L p
1 g
F P
s
P
p
.002 w
.48348 .60449 m .43429 .59057 L .44499 .57378 L p
1 g
F P
s
P
p
.002 w
.65987 .45799 m .6542 .40703 L .67148 .39721 L p
1 g
F P
s
P
p
.002 w
.64666 .3451 m .67148 .39721 L .6542 .40703 L p
1 g
F P
s
P
p
.002 w
.53026 .58365 m .57084 .56801 L .58232 .58377 L p
1 g
F P
s
P
p
.002 w
.62171 .55123 m .58232 .58377 L .57084 .56801 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.40922 .54922 m .44499 .57378 L .43429 .59057 L p
1 g
F P
s
P
p
.002 w
.43429 .59057 m .39215 .56173 L .40922 .54922 L p
1 g
F P
s
P
p
.002 w
.36555 .37228 m .34726 .42074 L .32844 .41251 L p
1 g
F P
s
P
p
.002 w
.32844 .41251 m .3488 .35827 L .36555 .37228 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.57084 .56801 m .60428 .54032 L .62171 .55123 L p
1 g
F P
s
P
p
.002 w
.64856 .50781 m .62171 .55123 L .60428 .54032 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.38332 .51446 m .40922 .54922 L .39215 .56173 L p
1 g
F P
s
P
p
.002 w
.39215 .56173 m .36157 .52084 L .38332 .51446 L p
1 g
F P
s
P
p
.002 w
.6542 .40703 m .63191 .36048 L .64666 .3451 L p
1 g
F P
s
P
p
.002 w
.60569 .30373 m .64666 .3451 L .63191 .36048 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.39904 .3322 m .36555 .37228 L .3488 .35827 L p
1 g
F P
s
P
p
.004 w
.37998 .35501 m
.5 .43051 L
s
P
p
.002 w
.3488 .35827 m .3862 .31337 L .39904 .3322 L p
1 g
F P
s
P
p
.004 w
.3598 .34232 m
.36511 .34566 L
s
P
p
.004 w
.34936 .33575 m
.3598 .34232 L
s
P
p
.004 w
.33175 .32467 m
.34936 .33575 L
s
P
p
.004 w
.36511 .34566 m
.36617 .34633 L
s
P
p
.002 w
.60428 .54032 m .62702 .50341 L .64856 .50781 L p
1 g
F P
s
P
p
.002 w
.65987 .45799 m .64856 .50781 L .62702 .50341 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.37018 .47311 m .38332 .51446 L .36157 .52084 L p
1 g
F P
s
P
p
.002 w
.36157 .52084 m .34597 .47213 L .37018 .47311 L p
1 g
F P
s
P
p
.002 w
.63191 .36048 m .59523 .32356 L .60569 .30373 L p
1 g
F P
s
P
p
.002 w
.55298 .2779 m .60569 .30373 L .59523 .32356 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.44412 .30509 m .39904 .3322 L .3862 .31337 L p
1 g
F P
s
P
p
.002 w
.3862 .31337 m .43662 .28298 L .44412 .30509 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.62702 .50341 m .63653 .4611 L .65987 .45799 L p
1 g
F P
s
P
p
.002 w
.6542 .40703 m .65987 .45799 L .63653 .4611 L p
1 g
F P
s
P
p
.002 w
.59523 .32356 m .5481 .30053 L .55298 .2779 L p
1 g
F P
s
P
p
.002 w
.49441 .27068 m .55298 .2779 L .5481 .30053 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.49576 .29411 m .44412 .30509 L .43662 .28298 L p
1 g
F P
s
P
p
.002 w
.43662 .28298 m .49441 .27068 L .49576 .29411 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.5481 .30053 m .49576 .29411 L .49441 .27068 L p
1 g
F P
s
P
p
.002 w
.37137 .42954 m .37018 .47311 L .34597 .47213 L p
1 g
F P
s
P
p
.002 w
.34597 .47213 m .34726 .42074 L .37137 .42954 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .5109 .58013 L p
1 g
F P
s
P
p
.002 w
.52846 .57575 m .53026 .58365 L p
.51996 .57787 L 1 g
F P
s
P
p
.53128 .57265 m .5109 .58013 L .52218 .57732 L 1 g
F
P
p
.002 w
.53026 .58365 m .50933 .58461 L p
.50583 .58028 L 1 g
F P
s
P
p
.53026 .58365 m .50583 .58028 L .52333 .57976 L 1 g
F
P
p
.002 w
.50933 .58461 m .4868 .58565 L .48756 .58082 L p
1 g
F P
s
P
p
.002 w
.48756 .58082 m .48761 .5805 L p
.48905 .58077 L 1 g
F P
s
P
p
.50933 .58461 m .48756 .58082 L .48905 .58077 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48905 .58077 L p
1 g
F P
s
P
p
.51079 .57862 m .48905 .58077 L .50192 .58039 L 1 g
F
P
p
.002 w
.5109 .58013 m .51079 .57862 L p
.50192 .58039 L 1 g
F P
s
P
p
.002 w
.48905 .58077 m .48921 .57862 L p
.47973 .57784 L 1 g
F P
s
P
p
.002 w
.48761 .5805 m .4868 .58565 L p
.48018 .57799 L 1 g
F P
s
P
p
.47973 .57784 m .48761 .5805 L .48905 .58077 L 1 g
F
P
p
.002 w
.4868 .58565 m .44499 .57378 L .44873 .56739 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.4868 .58565 m .44873 .56739 L .46842 .57403 L 1 g
F
P
p
.48628 .58505 m .46842 .57403 L .48018 .57799 L 1 g
F
P
p
.4868 .58565 m .46842 .57403 L .48628 .58505 L 1 g
F
P
p
.002 w
.46842 .57403 m .46872 .57265 L p
.46153 .56978 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46842 .57403 L p
1 g
F P
s
P
p
.002 w
.46842 .57403 m .4678 .57686 L p
.47973 .57784 L 1 g
F P
s
P
p
.48921 .57862 m .46842 .57403 L .47973 .57784 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45079 .56309 L p
1 g
F P
s
P
p
.46872 .57265 m .45079 .56309 L .451 .56326 L 1 g
F
P
p
.44499 .57378 m .43673 .5517 L .45079 .56309 L 1 g
F
P
p
.002 w
.4511 .56334 m .45105 .56344 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.45105 .56344 m .44499 .57378 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44558 .55618 L 1 g
F P
s
P
p
.46872 .57265 m .451 .56326 L .46153 .56978 L 1 g
F
P
p
.451 .56326 m .45077 .56314 L .4511 .56334 L 1 g
F
P
p
.451 .56326 m .4511 .56334 L .46153 .56978 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43859 .54691 L p
1 g
F P
s
P
p
.43673 .5517 m .43137 .53734 L .43859 .54691 L 1 g
F
P
p
.44196 .55593 m .43859 .54691 L .45079 .56309 L 1 g
F
P
p
.43673 .5517 m .43859 .54691 L .44196 .55593 L 1 g
F
P
p
.002 w
.43859 .54691 m .43925 .54566 L p
.43492 .53709 L 1 g
F P
s
P
p
.45146 .56129 m .43859 .54691 L .44558 .55618 L 1 g
F
P
p
.45079 .56309 m .42962 .53267 L .4511 .56334 L 1 g
F
P
p
.43137 .53734 m .42962 .53267 L .45079 .56309 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43242 .52885 L p
1 g
F P
s
P
p
.43925 .54566 m .43242 .52885 L .43253 .52931 L 1 g
F
P
p
.42962 .53267 m .43146 .52487 L .43242 .52885 L 1 g
F
P
p
.002 w
.4327 .52999 m .4323 .53034 L p
.43242 .52885 L 1 g
F P
s
P
p
.002 w
.4323 .53034 m .42962 .53267 L p
.43242 .52885 L 1 g
F P
s
P
p
.002 w
.43242 .52885 m .43346 .52734 L p
.43319 .51965 L 1 g
F P
s
P
p
.43925 .54566 m .43253 .52931 L .43354 .53277 L 1 g
F
P
p
.43253 .52931 m .43237 .52892 L .4327 .52999 L 1 g
F
P
p
.43253 .52931 m .4327 .52999 L .43354 .53277 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43407 .50919 L p
1 g
F P
s
P
p
.43146 .52487 m .43347 .51631 L .43242 .52885 L 1 g
F
P
p
.43346 .52734 m .43407 .50919 L .43319 .51965 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.40933 .5053 m .43882 .49359 L p
.43624 .50454 L 1 g
F P
s
P
p
.002 w
.43407 .50919 m .43485 .50826 L p
.43859 .49951 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44246 .49149 L p
1 g
F P
s
P
p
.43882 .49359 m .4435 .48941 L .44246 .49149 L 1 g
F
P
p
.002 w
.44213 .49215 m .44149 .49243 L p
.44246 .49149 L 1 g
F P
s
P
p
.002 w
.44149 .49243 m .43882 .49359 L p
.44246 .49149 L 1 g
F P
s
P
p
.002 w
.44246 .49149 m .44245 .4915 L p
.4424 .49161 L 1 g
F P
s
P
p
.43485 .50826 m .44246 .49149 L .4424 .49161 L 1 g
F
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44246 .49149 m .44339 .4905 L p
.45016 .48402 L 1 g
F P
s
P
p
.43485 .50826 m .44245 .4915 L .44123 .49396 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44246 .49149 m .45872 .47623 L .44213 .49215 L 1 g
F
P
p
.45872 .47623 m .45897 .47612 L .44213 .49215 L 1 g
F
P
p
.002 w
.45767 .47672 m .45826 .47608 L p
.46984 .471 L 1 g
F P
s
P
p
.002 w
.51147 .49905 m .49936 .4996 L .50388 .4646 L p
1 g
F P
s
P
p
.5 .4634 m .51716 .46645 L .51281 .46585 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.53825 .47665 m .50619 .46493 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54243 .47683 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54049 .47594 m .54243 .47683 L .53825 .47665 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56609 .50938 L p
1 g
F P
s
P
p
.6009 .49662 m .56878 .51513 L .56609 .50938 L 1 g
F
P
p
.56577 .50585 m .56609 .50938 L .56459 .50616 L 1 g
F
P
p
.6009 .49662 m .56609 .50938 L .56577 .50585 L 1 g
F
P
p
.002 w
.56609 .50938 m .56515 .50826 L p
.56678 .51881 L 1 g
F P
s
P
p
.002 w
.56646 .51342 m .58308 .52569 L p
.56712 .52461 L 1 g
F P
s
P
p
.56678 .51881 m .56719 .52151 L .56646 .51342 L 1 g
F
P
p
.56678 .51881 m .56646 .51342 L .56609 .50938 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56735 .52852 L p
1 g
F P
s
P
p
.002 w
.58308 .52569 m .56792 .53827 L p
.56735 .52852 L 1 g
F P
s
P
p
.56843 .52469 m .56735 .52852 L .56712 .52461 L 1 g
F
P
p
.58308 .52569 m .56735 .52852 L .56843 .52469 L 1 g
F
P
p
.002 w
.56735 .52852 m .56654 .52734 L p
.56449 .53858 L 1 g
F P
s
P
p
.56515 .50826 m .56735 .52852 L .56698 .52227 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56165 .54735 L p
1 g
F P
s
P
p
.60428 .54032 m .55998 .55216 L .56165 .54735 L 1 g
F
P
p
.5621 .54671 m .56165 .54735 L .56186 .54675 L 1 g
F
P
p
.60428 .54032 m .56165 .54735 L .5621 .54671 L 1 g
F
P
p
.002 w
.60428 .54032 m .57084 .56801 L .55998 .55216 L p
1 g
F P
s
P
p
.002 w
.56165 .54735 m .56075 .54566 L p
.55559 .55502 L 1 g
F P
s
P
p
.57084 .56801 m .54782 .56392 L .54901 .56256 L 1 g
F
P
p
.002 w
.55914 .55095 m .56131 .55411 L p
.54901 .56256 L 1 g
F P
s
P
p
.002 w
.56131 .55411 m .57084 .56801 L p
.54901 .56256 L 1 g
F P
s
P
p
.002 w
.54901 .56256 m .54854 .56129 L p
.54256 .56699 L 1 g
F P
s
P
p
.55559 .55502 m .55914 .55095 L .56165 .54735 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53168 .57447 L p
1 g
F P
s
P
p
.002 w
.57084 .56801 m .53026 .58365 L .52864 .57655 L p
1 g
F P
s
P
p
.57084 .56801 m .52864 .57655 L .53168 .57447 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54901 .56256 L p
1 g
F P
s
P
p
.55487 .56518 m .54235 .57019 L .54782 .56392 L 1 g
F
P
p
.002 w
.54901 .56256 m .54998 .56518 L p
.55559 .55502 L 1 g
F P
s
P
p
.56075 .54566 m .54901 .56256 L .55559 .55502 L 1 g
F
P
p
.54782 .56392 m .53168 .57447 L .54719 .56381 L 1 g
F
P
p
.54235 .57019 m .53168 .57447 L .54782 .56392 L 1 g
F
P
p
.57084 .56801 m .53168 .57447 L .55487 .56518 L 1 g
F
P
p
.002 w
.53168 .57447 m .53128 .57265 L p
.52218 .57732 L 1 g
F P
s
P
p
.52333 .57976 m .5109 .58013 L .51996 .57787 L 1 g
F
P
p
.52218 .57732 m .51372 .58166 L .52846 .57575 L 1 g
F
P
p
.52218 .57732 m .52846 .57575 L .53168 .57447 L 1 g
F
P
p
.51996 .57787 m .50583 .58028 L .49063 .56141 L 1 g
F
P
p
.5109 .58013 m .50583 .58028 L .51996 .57787 L 1 g
F
P
p
.54854 .56129 m .53168 .57447 L .54256 .56699 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52864 .57655 m .52485 .55985 L p
.54719 .56381 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53168 .57447 L p
1 g
F P
s
P
p
.51372 .58166 m .51111 .583 L .53168 .57447 L 1 g
F
P
p
.002 w
.53168 .57447 m .5322 .57686 L p
.54256 .56699 L 1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.54782 .56392 m .52485 .55985 L .55914 .55095 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54901 .56256 L p
1 g
F P
s
P
p
.54256 .56699 m .5322 .57686 L .54901 .56256 L 1 g
F
P
p
.55559 .55502 m .5529 .55989 L .55914 .55095 L 1 g
F
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.52485 .55985 m .55679 .54751 L .55914 .55095 L p
1 g
F P
s
P
p
.56654 .52734 m .56165 .54735 L .56258 .54467 L 1 g
F
P
p
.002 w
.55998 .55216 m .55679 .54751 L p
.56186 .54675 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56165 .54735 L p
1 g
F P
s
P
p
.5529 .55989 m .54998 .56518 L .56165 .54735 L 1 g
F
P
p
.002 w
.58308 .52569 m .60428 .54032 L p
.56186 .54675 L 1 g
F P
s
P
p
.002 w
.56354 .54191 m .58308 .52569 L p
.56186 .54675 L 1 g
F P
s
P
p
.56654 .52734 m .56187 .54778 L .56449 .53858 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55679 .54751 m .56354 .54191 L p
.56186 .54675 L 1 g
F P
s
P
p
.002 w
.56792 .53827 m .56354 .54191 L p
.56735 .52852 L 1 g
F P
s
P
p
.002 w
.56187 .54778 m .56257 .5491 L p
.56425 .53985 L 1 g
F P
s
P
p
.56449 .53858 m .56354 .54191 L .56425 .53985 L 1 g
F
P
p
.56354 .54191 m .56187 .54778 L .56425 .53985 L 1 g
F
P
p
.002 w
.56165 .54735 m .56187 .54778 L p
.56258 .54467 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56735 .52852 m .55679 .54751 L .56712 .52461 L 1 g
F
P
p
.002 w
.56354 .54191 m .55679 .54751 L p
.56735 .52852 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56735 .52852 L p
1 g
F P
s
P
p
.56449 .53858 m .56257 .5491 L .56735 .52852 L 1 g
F
P
p
.002 w
.56735 .52852 m .5679 .52932 L p
.56698 .52227 L 1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55679 .54751 m .54059 .52281 L p
.56712 .52461 L 1 g
F P
s
P
p
.56515 .50826 m .5679 .52932 L .56719 .52151 L 1 g
F
P
p
.55661 .4905 m .56609 .50938 L .56282 .50238 L 1 g
F
P
p
.56459 .50616 m .56609 .50938 L .55872 .5077 L 1 g
F
P
p
.002 w
.56878 .51513 m .56646 .51342 L p
.56609 .50938 L 1 g
F P
s
P
p
.002 w
.56646 .51342 m .55872 .5077 L p
.56609 .50938 L 1 g
F P
s
P
p
.002 w
.5679 .52932 m .56854 .53025 L p
.56719 .52151 L 1 g
F P
s
P
p
.002 w
.54059 .52281 m .55872 .5077 L .56646 .51342 L p
1 g
F P
s
P
p
.56712 .52461 m .54059 .52281 L .56646 .51342 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56609 .50938 L p
1 g
F P
s
P
p
.56719 .52151 m .56854 .53025 L .56609 .50938 L 1 g
F
P
p
.002 w
.57097 .48761 m .6009 .49662 L p
.56459 .50616 L 1 g
F P
s
P
p
.55661 .4905 m .56282 .50238 L .56245 .50159 L 1 g
F
P
p
.002 w
.55739 .49133 m .55661 .4905 L p
.56245 .50159 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55493 .48895 L 1 g
F
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55872 .5077 m .53201 .48693 L p
.55323 .4873 L 1 g
F P
s
P
p
.54174 .47608 m .55493 .48895 L .55012 .48428 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55542 .48734 m .55582 .48981 L .55323 .4873 L 1 g
F
P
p
.55582 .48981 m .55872 .5077 L .55323 .4873 L 1 g
F
P
p
.002 w
.5645 .49822 m .56245 .50159 L p
.55739 .49133 L 1 g
F P
s
P
p
.002 w
.55791 .49188 m .55739 .49133 L p
.56245 .50159 L 1 g
F P
s
P
p
.002 w
.56245 .50159 m .55872 .5077 L p
.55542 .48734 L 1 g
F P
s
P
p
.002 w
.53201 .48693 m .53825 .47665 L .54435 .47869 L p
1 g
F P
s
P
p
.54174 .47608 m .55012 .48428 L .54435 .47869 L 1 g
F
P
p
.002 w
.54435 .47869 m .53825 .47665 L p
.54243 .47683 L 1 g
F P
s
P
p
.002 w
.54245 .47685 m .54243 .47683 L p
.54435 .47869 L 1 g
F P
s
P
p
.002 w
.54243 .47683 m .54174 .47608 L p
.54435 .47869 L 1 g
F P
s
P
p
.57599 .46467 m .552 .48126 L .54243 .47683 L 1 g
F
P
p
.52214 .46667 m .54243 .47683 L .54025 .47582 L 1 g
F
P
p
.54126 .47569 m .54243 .47683 L .54049 .47594 L 1 g
F
P
p
.57599 .46467 m .54243 .47683 L .54126 .47569 L 1 g
F
P
p
.002 w
.54435 .47869 m .57097 .48761 L p
.55323 .4873 L 1 g
F P
s
P
p
.55323 .4873 m .53201 .48693 L .54435 .47869 L 1 g
F
P
p
.002 w
.56245 .50159 m .57097 .48761 L p
.56459 .50616 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55791 .49188 L p
1 g
F P
s
P
p
.56282 .50238 m .56713 .51061 L .55791 .49188 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54245 .47685 L p
1 g
F P
s
P
p
.55012 .48428 m .55834 .49233 L .54245 .47685 L 1 g
F
P
p
.55012 .48428 m .55759 .49154 L .55096 .48511 L 1 g
F
P
p
.55493 .48895 m .55759 .49154 L .55012 .48428 L 1 g
F
P
p
.002 w
.55739 .49133 m .55759 .49154 L p
.55493 .48895 L 1 g
F P
s
P
p
.002 w
.57097 .48761 m .5645 .49822 L p
.55542 .48734 L 1 g
F P
s
P
p
.5645 .49822 m .55739 .49133 L .55542 .48734 L 1 g
F
P
p
.002 w
.55872 .5077 m .56245 .50159 L p
.56459 .50616 L 1 g
F P
s
P
p
.002 w
.56609 .50938 m .56713 .51061 L p
.56282 .50238 L 1 g
F P
s
P
p
.002 w
.6009 .49662 m .58308 .52569 L .56878 .51513 L p
1 g
F P
s
P
p
.002 w
.552 .48126 m .54435 .47869 L p
.54243 .47683 L 1 g
F P
s
P
p
.002 w
.55759 .49154 m .55834 .49233 L p
.55096 .48511 L 1 g
F P
s
P
p
.002 w
.54077 .46493 m .57599 .46467 L p
.54049 .47594 L 1 g
F P
s
P
p
.002 w
.53825 .47665 m .53859 .47506 L p
.54049 .47594 L 1 g
F P
s
P
p
.52214 .46667 m .54259 .477 L .5343 .47296 L 1 g
F
P
p
.002 w
.53859 .47506 m .54077 .46493 L p
.54049 .47594 L 1 g
F P
s
P
p
.002 w
.53859 .47506 m .53825 .47665 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.54259 .477 m .54302 .47747 L p
.53625 .47398 L 1 g
F P
s
P
p
.5343 .47296 m .53859 .47506 L .53625 .47398 L 1 g
F
P
p
.53859 .47506 m .54259 .477 L .53625 .47398 L 1 g
F
P
p
.002 w
.54243 .47683 m .54259 .477 L p
.54025 .47582 L 1 g
F P
s
P
p
.002 w
.57599 .46467 m .57097 .48761 L .552 .48126 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.5343 .47296 L 1 g
F P
s
P
p
.5343 .47296 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52259 .46742 L p
.51716 .46645 L 1 g
F P
s
P
p
.5 .4634 m .52245 .46719 L .51716 .46645 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.54077 .46493 m .53976 .46959 L p
.52172 .46683 L 1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.50394 .46411 m .51672 .46439 L p
.52172 .46683 L 1 g
F P
s
P
p
.002 w
.51672 .46439 m .54077 .46493 L p
.52172 .46683 L 1 g
F P
s
P
p
.002 w
.53976 .46959 m .53859 .47506 L p
.52245 .46719 L 1 g
F P
s
P
p
.51631 .46653 m .5228 .46776 L .52196 .46762 L 1 g
F
P
p
.002 w
.53201 .48693 m .52275 .49467 L .50429 .46466 L p
1 g
F P
s
P
p
.51271 .46584 m .51336 .46596 L .51311 .46592 L 1 g
F
P
p
.5 .4634 m .51294 .46588 L .51271 .46584 L 1 g
F
P
p
.51294 .46588 m .51336 .46596 L .51271 .46584 L 1 g
F
P
p
.002 w
.53825 .47665 m .53201 .48693 L .5047 .46472 L p
1 g
F P
s
P
p
.002 w
.50619 .46493 m .53825 .47665 L p
.5047 .46472 L 1 g
F P
s
P
p
.002 w
.5047 .46472 m .53201 .48693 L p
.50429 .46466 L 1 g
F P
s
P
p
.002 w
.49936 .4996 m .48774 .49626 L .50371 .46458 L p
1 g
F P
s
P
p
.002 w
.50388 .4646 m .49936 .4996 L p
.50371 .46458 L 1 g
F P
s
P
p
.002 w
.52275 .49467 m .51147 .49905 L .50406 .46463 L p
1 g
F P
s
P
p
.002 w
.50429 .46466 m .52275 .49467 L p
.50406 .46463 L 1 g
F P
s
P
p
.002 w
.50406 .46463 m .51147 .49905 L p
.50388 .4646 L 1 g
F P
s
P
p
.46831 .47175 m .47753 .46722 L .50215 .46432 L 1 g
F
P
p
.46831 .47175 m .50215 .46432 L .50261 .4644 L 1 g
F
P
p
.002 w
.48174 .46661 m .50212 .46432 L p
.47753 .46722 L 1 g
F P
s
P
p
.47753 .46722 m .50212 .46432 L .50215 .46432 L 1 g
F
P
p
.5 .4634 m .51811 .46688 L .50042 .46403 L 1 g
F
P
p
.002 w
.5 .46396 m .5 .4634 L p
.50042 .46403 L 1 g
F P
s
P
p
.51811 .46688 m .5035 .46454 L .5 .46396 L 1 g
F
P
p
.002 w
.5035 .46454 m .47785 .48938 L p
.50314 .46449 L 1 g
F P
s
P
p
.5035 .46454 m .50335 .46452 L .50314 .46449 L 1 g
F
P
p
.5035 .46454 m .50314 .46449 L .5 .46396 L 1 g
F
P
p
.002 w
.47785 .48938 m .47075 .4797 L .50314 .46449 L p
1 g
F P
s
P
p
.002 w
.50314 .46449 m .50394 .46411 L .5035 .46454 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46396 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46396 L .48945 .46549 L 1 g
F
P
p
.002 w
.47753 .46722 m .47786 .46667 L p
.48947 .46549 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46722 L p
1 g
F P
s
P
p
.002 w
.47753 .46722 m .47718 .46778 L p
.47004 .47091 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46722 L .47004 .47091 L 1 g
F
P
p
.002 w
.46723 .46824 m .4676 .45852 L p
.48817 .46197 L 1 g
F P
s
P
p
.47842 .46678 m .48817 .46197 L .5 .46396 L 1 g
F
P
p
.46723 .46824 m .48817 .46197 L .47842 .46678 L 1 g
F
P
p
.002 w
.50212 .46432 m .48174 .46661 L p
.5 .46396 L 1 g
F P
s
P
p
.002 w
.48174 .46661 m .46723 .46824 L p
.5 .46396 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47753 .46722 L p
1 g
F P
s
P
p
.002 w
.47753 .46722 m .47753 .46722 L p
.47756 .46722 L 1 g
F P
s
P
p
.47756 .46722 m .5 .46442 L .47753 .46722 L 1 g
F
P
p
.002 w
.5 .46396 m .5 .46442 L p
.48945 .46549 L 1 g
F P
s
P
p
.002 w
.50394 .46411 m .50212 .46432 L p
.50037 .46391 L 1 g
F P
s
P
p
.002 w
.46768 .45626 m .50195 .46368 L p
.50037 .46391 L 1 g
F P
s
P
p
.002 w
.50195 .46368 m .50394 .46411 L p
.50037 .46391 L 1 g
F P
s
P
p
.002 w
.4676 .45852 m .46768 .45626 L p
.50212 .46432 L 1 g
F P
s
P
p
.002 w
.5 .46396 m .5 .46396 L p
.50042 .46403 L 1 g
F P
s
P
p
.002 w
.48774 .49626 m .47785 .48938 L .5035 .46454 L p
1 g
F P
s
P
p
.002 w
.50371 .46458 m .48774 .49626 L p
.5035 .46454 L 1 g
F P
s
P
p
.51811 .46688 m .52196 .46762 L .50335 .46452 L 1 g
F
P
p
.002 w
.5035 .46454 m .50394 .46411 L .50371 .46458 L p
1 g
F P
s
P
p
.002 w
.50394 .46411 m .47075 .4797 L .46831 .47175 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46396 L p
1 g
F P
s
P
p
.52196 .46762 m .52282 .46778 L .5 .46396 L 1 g
F
P
p
.002 w
.50212 .46432 m .50394 .46411 L p
.50215 .46432 L 1 g
F P
s
P
p
.002 w
.5047 .46472 m .50394 .46411 L .50619 .46493 L p
1 g
F P
s
P
p
.002 w
.50429 .46466 m .50394 .46411 L .5047 .46472 L p
1 g
F P
s
P
p
.51311 .46592 m .51674 .4666 L .51631 .46653 L 1 g
F
P
p
.51336 .46596 m .51674 .4666 L .51311 .46592 L 1 g
F
P
p
.51674 .4666 m .5228 .46776 L .51631 .46653 L 1 g
F
P
p
.002 w
.50371 .46458 m .50394 .46411 L .50388 .4646 L p
1 g
F P
s
P
p
.002 w
.50619 .46493 m .50394 .46411 L p
.53976 .46959 L 1 g
F P
s
P
p
.51281 .46585 m .51998 .46696 L .51411 .4661 L 1 g
F
P
p
.51716 .46645 m .51998 .46696 L .51281 .46585 L 1 g
F
P
p
.51411 .4661 m .52259 .46742 L .51522 .46631 L 1 g
F
P
p
.51998 .46696 m .52259 .46742 L .51411 .4661 L 1 g
F
P
p
.002 w
.50406 .46463 m .50394 .46411 L .50429 .46466 L p
1 g
F P
s
P
p
.002 w
.50388 .4646 m .50394 .46411 L .50406 .46463 L p
1 g
F P
s
P
p
.002 w
.52259 .46742 m .5228 .46776 L p
.51522 .46631 L 1 g
F P
s
P
p
.002 w
.5228 .46776 m .52282 .46778 L p
.52196 .46762 L 1 g
F P
s
P
p
.50261 .4644 m .50215 .46432 L .50394 .46411 L 1 g
F
P
p
.002 w
.47789 .46704 m .48174 .46661 L p
.47753 .46722 L 1 g
F P
s
P
p
.48947 .46549 m .5 .46442 L .47753 .46722 L 1 g
F
P
p
.46984 .471 m .47119 .47041 L .46831 .47175 L 1 g
F
P
p
.46984 .471 m .46831 .47175 L .45767 .47672 L 1 g
F
P
p
.002 w
.46831 .47175 m .46723 .46824 L .47789 .46704 L p
1 g
F P
s
P
p
.45702 .47735 m .46723 .46824 L .44246 .49149 L 1 g
F
P
p
.002 w
.46723 .46824 m .47075 .4797 L .44213 .49215 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45767 .47672 L p
1 g
F P
s
P
p
.44339 .4905 m .45767 .47672 L .45016 .48402 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.43882 .49359 m .43184 .47117 L .46723 .46824 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45767 .47672 L p
1 g
F P
s
P
p
.47119 .47041 m .47718 .46778 L .45767 .47672 L 1 g
F
P
p
.45872 .47623 m .46723 .46824 L .45897 .47612 L 1 g
F
P
p
.4435 .48941 m .45702 .47735 L .44246 .49149 L 1 g
F
P
p
.002 w
.45767 .47672 m .45698 .47747 L p
.45016 .48402 L 1 g
F P
s
P
p
.002 w
.44037 .4957 m .43882 .49359 L .44213 .49215 L p
1 g
F P
s
P
p
.002 w
.44245 .4915 m .44223 .49174 L p
.44123 .49396 L 1 g
F P
s
P
p
.43485 .50826 m .44223 .49174 L .43859 .49951 L 1 g
F
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43882 .49359 m .45276 .51251 L .4327 .52999 L p
1 g
F P
s
P
p
.002 w
.44223 .49174 m .44166 .49233 L p
.43859 .49951 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44246 .49149 L p
1 g
F P
s
P
p
.45016 .48402 m .45698 .47747 L .44246 .49149 L 1 g
F
P
p
.002 w
.45276 .51251 m .44037 .4957 L p
.47075 .4797 L 1 g
F P
s
P
p
.002 w
.44213 .49215 m .47075 .4797 L p
.44037 .4957 L 1 g
F P
s
P
p
.43242 .52885 m .4372 .50248 L .4327 .52999 L 1 g
F
P
p
.4372 .50248 m .43882 .49359 L .43739 .50209 L 1 g
F
P
p
.4372 .50248 m .43739 .50209 L .4327 .52999 L 1 g
F
P
p
.002 w
.42962 .53267 m .42562 .52727 L p
.43624 .50454 L 1 g
F P
s
P
p
.002 w
.42562 .52727 m .40933 .5053 L p
.43624 .50454 L 1 g
F P
s
P
p
.43347 .51631 m .43882 .49359 L .43242 .52885 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43407 .50919 L p
1 g
F P
s
P
p
.43859 .49951 m .44166 .49233 L .43407 .50919 L 1 g
F
P
p
.002 w
.43407 .50919 m .43287 .51061 L p
.43319 .51965 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43242 .52885 L p
1 g
F P
s
P
p
.43319 .51965 m .43287 .51061 L .43242 .52885 L 1 g
F
P
p
.002 w
.43242 .52885 m .43237 .52892 L p
.43253 .52931 L 1 g
F P
s
P
p
.002 w
.43453 .53605 m .42962 .53267 L .4327 .52999 L p
1 g
F P
s
P
p
.002 w
.43237 .52892 m .43204 .5294 L p
.43354 .53277 L 1 g
F P
s
P
p
.43925 .54566 m .43204 .5294 L .43492 .53709 L 1 g
F
P
p
.002 w
.45773 .55204 m .43453 .53605 L p
.45276 .51251 L 1 g
F P
s
P
p
.002 w
.4327 .52999 m .45276 .51251 L p
.43453 .53605 L 1 g
F P
s
P
p
.002 w
.45773 .55204 m .4511 .56334 L p
.43743 .54383 L 1 g
F P
s
P
p
.002 w
.42962 .53267 m .43453 .53605 L p
.43743 .54383 L 1 g
F P
s
P
p
.002 w
.43453 .53605 m .45773 .55204 L p
.43743 .54383 L 1 g
F P
s
P
p
.002 w
.43204 .5294 m .43146 .53025 L p
.43492 .53709 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43859 .54691 L p
1 g
F P
s
P
p
.43492 .53709 m .43146 .53025 L .43859 .54691 L 1 g
F
P
p
.002 w
.43859 .54691 m .43743 .5491 L p
.44558 .55618 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56309 L p
1 g
F P
s
P
p
.44558 .55618 m .43743 .5491 L .45079 .56309 L 1 g
F
P
p
.002 w
.45079 .56309 m .45077 .56314 L p
.451 .56326 L 1 g
F P
s
P
p
.002 w
.44873 .56739 m .4511 .56334 L p
.46842 .57403 L 1 g
F P
s
P
p
.002 w
.45077 .56314 m .45002 .56518 L p
.46153 .56978 L 1 g
F P
s
P
p
.48018 .57799 m .46842 .57403 L .45773 .55204 L 1 g
F
P
p
.002 w
.4511 .56334 m .45773 .55204 L p
.46842 .57403 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46842 .57403 L p
1 g
F P
s
P
p
.46153 .56978 m .45002 .56518 L .46842 .57403 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58098 L p
1 g
F P
s
P
p
.002 w
.48903 .58098 m .48905 .58077 L p
.48766 .58052 L 1 g
F P
s
P
p
.48766 .58052 m .4678 .57686 L .48903 .58098 L 1 g
F
P
p
.47973 .57784 m .46884 .57695 L .48761 .5805 L 1 g
F
P
p
.002 w
.45773 .55204 m .49063 .56141 L .48761 .5805 L p
1 g
F P
s
P
p
.48018 .57799 m .45773 .55204 L .48761 .5805 L 1 g
F
P
p
.002 w
.48761 .5805 m .49063 .56141 L p
.50933 .58461 L 1 g
F P
s
P
p
.002 w
.48905 .58077 m .48889 .583 L p
.50192 .58039 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58013 L p
1 g
F P
s
P
p
.50192 .58039 m .48889 .583 L .5109 .58013 L 1 g
F
P
p
.46884 .57695 m .4678 .57686 L .48905 .58077 L 1 g
F
P
p
.002 w
.5109 .58013 m .51111 .583 L p
.52218 .57732 L 1 g
F P
s
P
p
.002 w
.49063 .56141 m .52485 .55985 L .52846 .57575 L p
1 g
F P
s
P
p
.51996 .57787 m .49063 .56141 L .52846 .57575 L 1 g
F
P
p
.002 w
.63653 .4611 m .63162 .4179 L .6542 .40703 L p
1 g
F P
s
P
p
.002 w
.63191 .36048 m .6542 .40703 L .63162 .4179 L p
1 g
F P
s
P
p
.002 w
.44499 .57378 m .40922 .54922 L .42962 .53267 L p
1 g
F P
s
P
p
.002 w
.38697 .38853 m .37137 .42954 L .34726 .42074 L p
1 g
F P
s
P
p
.002 w
.34726 .42074 m .36555 .37228 L .38697 .38853 L p
1 g
F P
s
P
p
.002 w
.62702 .50341 m .60428 .54032 L .58308 .52569 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.40933 .5053 m .42962 .53267 L .40922 .54922 L p
1 g
F P
s
P
p
.002 w
.40922 .54922 m .38332 .51446 L .40933 .5053 L p
1 g
F P
s
P
p
.002 w
.63162 .4179 m .61264 .3785 L .63191 .36048 L p
1 g
F P
s
P
p
.002 w
.59523 .32356 m .63191 .36048 L .61264 .3785 L p
1 g
F P
s
P
p
.002 w
.41539 .35465 m .38697 .38853 L .36555 .37228 L p
1 g
F P
s
P
p
.002 w
.36555 .37228 m .39904 .3322 L .41539 .35465 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.58308 .52569 m .6009 .49662 L .62702 .50341 L p
1 g
F P
s
P
p
.002 w
.63653 .4611 m .62702 .50341 L .6009 .49662 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.3991 .4728 m .40933 .5053 L .38332 .51446 L p
1 g
F P
s
P
p
.002 w
.38332 .51446 m .37018 .47311 L .3991 .4728 L p
1 g
F P
s
P
p
.002 w
.61264 .3785 m .58151 .3473 L .59523 .32356 L p
1 g
F P
s
P
p
.002 w
.5481 .30053 m .59523 .32356 L .58151 .3473 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.45357 .33175 m .41539 .35465 L .39904 .3322 L p
1 g
F P
s
P
p
.002 w
.39904 .3322 m .44412 .30509 L .45357 .33175 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.6009 .49662 m .60828 .46337 L .63653 .4611 L p
1 g
F P
s
P
p
.002 w
.63162 .4179 m .63653 .4611 L .60828 .46337 L p
1 g
F P
s
P
p
.002 w
.58151 .3473 m .54158 .32787 L .5481 .30053 L p
1 g
F P
s
P
p
.002 w
.49576 .29411 m .5481 .30053 L .54158 .32787 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49728 .32247 m .45357 .33175 L .44412 .30509 L p
1 g
F P
s
P
p
.002 w
.44412 .30509 m .49576 .29411 L .49728 .32247 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.40014 .43863 m .3991 .4728 L .37018 .47311 L p
1 g
F P
s
P
p
.002 w
.37018 .47311 m .37137 .42954 L .40014 .43863 L p
1 g
F P
s
P
p
.002 w
.54158 .32787 m .49728 .32247 L .49576 .29411 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5 .43051 L
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.60828 .46337 m .60433 .42948 L .63162 .4179 L p
1 g
F P
s
P
p
.002 w
.61264 .3785 m .63162 .4179 L .60433 .42948 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.49487 .53242 m .51852 .53135 L .52485 .55985 L p
1 g
F P
s
P
p
.002 w
.52485 .55985 m .49063 .56141 L .49487 .53242 L p
1 g
F P
s
P
p
.002 w
.55679 .54751 m .52485 .55985 L .51852 .53135 L p
1 g
F P
s
P
p
.002 w
.47214 .52592 m .49487 .53242 L .49063 .56141 L p
1 g
F P
s
P
p
.002 w
.49063 .56141 m .45773 .55204 L .47214 .52592 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.51852 .53135 m .54059 .52281 L .55679 .54751 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.45276 .51251 m .47214 .52592 L .45773 .55204 L p
1 g
F P
s
P
p
.002 w
.41245 .40651 m .40014 .43863 L .37137 .42954 L p
1 g
F P
s
P
p
.002 w
.37137 .42954 m .38697 .38853 L .41245 .40651 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.60433 .42948 m .58936 .39862 L .61264 .3785 L p
1 g
F P
s
P
p
.002 w
.58151 .3473 m .61264 .3785 L .58936 .39862 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.60828 .46337 m .6009 .49662 L .57097 .48761 L p
1 g
F P
s
P
p
.002 w
.43478 .38001 m .41245 .40651 L .38697 .38853 L p
1 g
F P
s
P
p
.002 w
.38697 .38853 m .41539 .35465 L .43478 .38001 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43184 .47117 m .43882 .49359 L .40933 .5053 L p
1 g
F P
s
P
p
.002 w
.40933 .5053 m .3991 .4728 L .43184 .47117 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.58936 .39862 m .5649 .37424 L .58151 .3473 L p
1 g
F P
s
P
p
.002 w
.54158 .32787 m .58151 .3473 L .5649 .37424 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.4647 .36212 m .43478 .38001 L .41539 .35465 L p
1 g
F P
s
P
p
.002 w
.41539 .35465 m .45357 .33175 L .4647 .36212 L p
1 g
F P
s
P
p
.002 w
.57097 .48761 m .57599 .46467 L .60828 .46337 L p
1 g
F P
s
P
p
.002 w
.60433 .42948 m .60828 .46337 L .57599 .46467 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.5649 .37424 m .53361 .35907 L .54158 .32787 L p
1 g
F P
s
P
p
.002 w
.49728 .32247 m .54158 .32787 L .53361 .35907 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.43263 .44765 m .43184 .47117 L .3991 .4728 L p
1 g
F P
s
P
p
.002 w
.3991 .4728 m .40014 .43863 L .43263 .44765 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.49892 .35487 m .4647 .36212 L .45357 .33175 L p
1 g
F P
s
P
p
.002 w
.45357 .33175 m .49728 .32247 L .49892 .35487 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.53361 .35907 m .49892 .35487 L .49728 .32247 L p
1 g
F P
s
P
p
.002 w
.57599 .46467 m .57319 .44134 L .60433 .42948 L p
1 g
F P
s
P
p
.002 w
.58936 .39862 m .60433 .42948 L .57319 .44134 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.49936 .4996 m .51147 .49905 L .51852 .53135 L p
1 g
F P
s
P
p
.002 w
.51852 .53135 m .49487 .53242 L .49936 .4996 L p
1 g
F P
s
P
p
.002 w
.54059 .52281 m .51852 .53135 L .51147 .49905 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48774 .49626 m .49936 .4996 L .49487 .53242 L p
1 g
F P
s
P
p
.002 w
.49487 .53242 m .47214 .52592 L .48774 .49626 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.51147 .49905 m .52275 .49467 L .54059 .52281 L p
1 g
F P
s
P
p
.002 w
.55872 .5077 m .54059 .52281 L .52275 .49467 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.44117 .42559 m .43263 .44765 L .40014 .43863 L p
1 g
F P
s
P
p
.002 w
.40014 .43863 m .41245 .40651 L .44117 .42559 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.47785 .48938 m .48774 .49626 L .47214 .52592 L p
1 g
F P
s
P
p
.002 w
.47214 .52592 m .45276 .51251 L .47785 .48938 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.52275 .49467 m .53201 .48693 L .55872 .5077 L p
1 g
F P
s
P
p
.002 w
.57319 .44134 m .56282 .42014 L .58936 .39862 L p
1 g
F P
s
P
p
.002 w
.5649 .37424 m .58936 .39862 L .56282 .42014 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.47075 .4797 m .47785 .48938 L .45276 .51251 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.45655 .40741 m .44117 .42559 L .41245 .40651 L p
1 g
F P
s
P
p
.002 w
.41245 .40651 m .43478 .38001 L .45655 .40741 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56282 .42014 m .54596 .40343 L .5649 .37424 L p
1 g
F P
s
P
p
.002 w
.53361 .35907 m .5649 .37424 L .54596 .40343 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57319 .44134 m .57599 .46467 L .54077 .46493 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.47712 .39515 m .45655 .40741 L .43478 .38001 L p
1 g
F P
s
P
p
.002 w
.43478 .38001 m .4647 .36212 L .47712 .39515 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.46768 .45626 m .46723 .46824 L .43184 .47117 L p
1 g
F P
s
P
p
.002 w
.43184 .47117 m .43263 .44765 L .46768 .45626 L p
1 g
F P
s
P
p
.002 w
.54596 .40343 m .52444 .39305 L .53361 .35907 L p
1 g
F P
s
P
p
.002 w
.49892 .35487 m .53361 .35907 L .52444 .39305 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.50062 .39018 m .47712 .39515 L .4647 .36212 L p
1 g
F P
s
P
p
.002 w
.4647 .36212 m .49892 .35487 L .50062 .39018 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52444 .39305 m .50062 .39018 L .49892 .35487 L p
1 g
F P
s
P
p
.002 w
.54077 .46493 m .5393 .45304 L .57319 .44134 L p
1 g
F P
s
P
p
.002 w
.56282 .42014 m .57319 .44134 L .5393 .45304 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.47206 .44504 m .46768 .45626 L .43263 .44765 L p
1 g
F P
s
P
p
.002 w
.43263 .44765 m .44117 .42559 L .47206 .44504 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.5393 .45304 m .53398 .44226 L .56282 .42014 L p
1 g
F P
s
P
p
.002 w
.54596 .40343 m .56282 .42014 L .53398 .44226 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.47991 .43582 m .47206 .44504 L .44117 .42559 L p
1 g
F P
s
P
p
.002 w
.44117 .42559 m .45655 .40741 L .47991 .43582 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5393 .45304 m .54077 .46493 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.53398 .44226 m .52538 .43378 L .54596 .40343 L p
1 g
F P
s
P
p
.002 w
.52444 .39305 m .54596 .40343 L .52538 .43378 L p
1 g
F P
s
P
p
.002 w
.49038 .4296 m .47991 .43582 L .45655 .40741 L p
1 g
F P
s
P
p
.002 w
.45655 .40741 m .47712 .39515 L .49038 .4296 L p
1 g
F P
s
P
p
.002 w
.53398 .44226 m .5393 .45304 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.52538 .43378 m .51443 .42852 L .52444 .39305 L p
1 g
F P
s
P
p
.002 w
.50062 .39018 m .52444 .39305 L .51443 .42852 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.50232 .42708 m .49038 .4296 L .47712 .39515 L p
1 g
F P
s
P
p
.002 w
.47712 .39515 m .50062 .39018 L .50232 .42708 L p
1 g
F P
s
P
p
.002 w
.46768 .45626 m .47206 .44504 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.51443 .42852 m .50232 .42708 L .50062 .39018 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.52538 .43378 m .53398 .44226 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.51443 .42852 m .52538 .43378 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.50232 .42708 m .51443 .42852 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.49038 .4296 m .50232 .42708 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.47991 .43582 m .49038 .4296 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.47206 .44504 m .47991 .43582 L .50394 .46411 L closepath p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.50394 .46411 m
.50639 .48498 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .28659 .29627 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .50639 .48498 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.618605)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.618605)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50517 .4738 m .52774 .45868 L .50844 .43788 L p
1 g
F P
s
P
p
.002 w
.50844 .43788 m .49308 .44816 L .50517 .4738 L p
1 g
F P
s
P
p
.002 w
.51981 .42332 m .50844 .43788 L .52774 .45868 L p
1 g
F P
s
P
p
.002 w
.49308 .44816 m .50844 .43788 L .48899 .41696 L p
1 g
F P
s
P
p
.002 w
.50844 .43788 m .51981 .42332 L .49475 .40957 L p
1 g
F P
s
P
p
.002 w
.49475 .40957 m .48899 .41696 L .50844 .43788 L p
1 g
F P
s
P
p
.002 w
.48899 .41696 m .4812 .42217 L .49308 .44816 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .4812 .42217 L .48899 .41696 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .48899 .41696 L .49475 .40957 L closepath p
1 g
F P
s
P
p
.002 w
.47909 .48107 m .50517 .4738 L .49308 .44816 L p
1 g
F P
s
P
p
.002 w
.49308 .44816 m .47534 .45306 L .47909 .48107 L p
1 g
F P
s
P
p
.002 w
.47534 .45306 m .49308 .44816 L .4812 .42217 L p
1 g
F P
s
P
p
.002 w
.4812 .42217 m .4722 .42463 L .47534 .45306 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .4722 .42463 L .4812 .42217 L closepath p
1 g
F P
s
P
p
.002 w
.52774 .45868 m .54447 .43728 L .51981 .42332 L p
1 g
F P
s
P
p
.002 w
.52597 .40599 m .51981 .42332 L .54447 .43728 L p
1 g
F P
s
P
p
.002 w
.51981 .42332 m .52597 .40599 L .49785 .40078 L p
1 g
F P
s
P
p
.002 w
.49785 .40078 m .49475 .40957 L .51981 .42332 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .49475 .40957 L .49785 .40078 L closepath p
1 g
F P
s
P
p
.002 w
.45708 .45204 m .47534 .45306 L .4722 .42463 L p
1 g
F P
s
P
p
.002 w
.4722 .42463 m .46296 .42408 L .45708 .45204 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .46296 .42408 L .4722 .42463 L closepath p
1 g
F P
s
P
p
.002 w
.49796 .39153 m .49785 .40078 L .52597 .40599 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .49785 .40078 L .49796 .39153 L closepath p
1 g
F P
s
P
p
.002 w
.4522 .47966 m .47909 .48107 L .47534 .45306 L p
1 g
F P
s
P
p
.002 w
.47534 .45306 m .45708 .45204 L .4522 .47966 L p
1 g
F P
s
P
p
.002 w
.54447 .43728 m .5536 .41181 L .52597 .40599 L p
1 g
F P
s
P
p
.002 w
.52626 .38772 m .52597 .40599 L .5536 .41181 L p
1 g
F P
s
P
p
.002 w
.52597 .40599 m .52626 .38772 L .49796 .39153 L p
1 g
F P
s
P
p
.002 w
.44024 .44516 m .45708 .45204 L .46296 .42408 L p
1 g
F P
s
P
p
.002 w
.46296 .42408 m .45446 .42056 L .44024 .44516 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .45446 .42056 L .46296 .42408 L closepath p
1 g
F P
s
P
p
.002 w
.49505 .38282 m .49796 .39153 L .52626 .38772 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .49796 .39153 L .49505 .38282 L closepath p
1 g
F P
s
P
p
.002 w
.51724 .49863 m .54653 .47897 L .52774 .45868 L p
1 g
F P
s
P
p
.002 w
.52774 .45868 m .50517 .4738 L .51724 .49863 L p
1 g
F P
s
P
p
.002 w
.54447 .43728 m .52774 .45868 L .54653 .47897 L p
1 g
F P
s
P
p
.002 w
.48338 .50813 m .51724 .49863 L .50517 .4738 L p
1 g
F P
s
P
p
.002 w
.50517 .4738 m .47909 .48107 L .48338 .50813 L p
1 g
F P
s
P
p
.002 w
.54653 .47897 m .56828 .45121 L .54447 .43728 L p
1 g
F P
s
P
p
.002 w
.5536 .41181 m .54447 .43728 L .56828 .45121 L p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .4478 .37974 L .4433 .38803 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .4433 .38803 L .44172 .39725 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .44172 .39725 L .44322 .40639 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .44322 .40639 L .44763 .41445 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .44763 .41445 L .45446 .42056 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .49505 .38282 L .48943 .37558 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .48943 .37558 L .48169 .37061 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .48169 .37061 L .47266 .36847 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .47266 .36847 L .46334 .36939 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .46334 .36939 L .45474 .37329 L closepath p
1 g
F P
s
P
p
.002 w
.46973 .39628 m .45474 .37329 L .4478 .37974 L closepath p
1 g
F P
s
P
p
.002 w
.42666 .43313 m .44024 .44516 L .45446 .42056 L p
1 g
F P
s
P
p
.002 w
.45446 .42056 m .44763 .41445 L .42666 .43313 L p
1 g
F P
s
P
p
.002 w
.52626 .38772 m .52059 .37046 L .49505 .38282 L p
1 g
F P
s
P
p
.002 w
.48943 .37558 m .49505 .38282 L .52059 .37046 L p
1 g
F P
s
P
p
.002 w
.42735 .46964 m .4522 .47966 L .45708 .45204 L p
1 g
F P
s
P
p
.002 w
.45708 .45204 m .44024 .44516 L .42735 .46964 L p
1 g
F P
s
P
p
.002 w
.5536 .41181 m .55412 .38492 L .52626 .38772 L p
1 g
F P
s
P
p
.002 w
.52059 .37046 m .52626 .38772 L .55412 .38492 L p
1 g
F P
s
P
p
.002 w
.44844 .50643 m .48338 .50813 L .47909 .48107 L p
1 g
F P
s
P
p
.002 w
.47909 .48107 m .4522 .47966 L .44844 .50643 L p
1 g
F P
s
P
p
.002 w
.41784 .41718 m .42666 .43313 L .44763 .41445 L p
1 g
F P
s
P
p
.002 w
.44763 .41445 m .44322 .40639 L .41784 .41718 L p
1 g
F P
s
P
p
.002 w
.52059 .37046 m .50953 .35607 L .48943 .37558 L p
1 g
F P
s
P
p
.002 w
.48169 .37061 m .48943 .37558 L .50953 .35607 L p
1 g
F P
s
P
p
.002 w
.56828 .45121 m .58022 .41816 L .5536 .41181 L p
1 g
F P
s
P
p
.002 w
.55412 .38492 m .5536 .41181 L .58022 .41816 L p
1 g
F P
s
P
p
.002 w
.40723 .45198 m .42735 .46964 L .44024 .44516 L p
1 g
F P
s
P
p
.002 w
.44024 .44516 m .42666 .43313 L .40723 .45198 L p
1 g
F P
s
P
p
.002 w
.41478 .39904 m .41784 .41718 L .44322 .40639 L p
1 g
F P
s
P
p
.002 w
.44322 .40639 m .44172 .39725 L .41478 .39904 L p
1 g
F P
s
P
p
.002 w
.50953 .35607 m .49422 .34614 L .48169 .37061 L p
1 g
F P
s
P
p
.002 w
.47266 .36847 m .48169 .37061 L .49422 .34614 L p
1 g
F P
s
P
p
.002 w
.55412 .38492 m .54588 .35944 L .52059 .37046 L p
1 g
F P
s
P
p
.002 w
.50953 .35607 m .52059 .37046 L .54588 .35944 L p
1 g
F P
s
P
p
.002 w
.41787 .3807 m .41478 .39904 L .44172 .39725 L p
1 g
F P
s
P
p
.002 w
.44172 .39725 m .4433 .38803 L .41787 .3807 L p
1 g
F P
s
P
p
.002 w
.52907 .52216 m .56447 .49838 L .54653 .47897 L p
1 g
F P
s
P
p
.002 w
.54653 .47897 m .51724 .49863 L .52907 .52216 L p
1 g
F P
s
P
p
.002 w
.56828 .45121 m .54653 .47897 L .56447 .49838 L p
1 g
F P
s
P
p
.002 w
.49422 .34614 m .47631 .3418 L .47266 .36847 L p
1 g
F P
s
P
p
.002 w
.46334 .36939 m .47266 .36847 L .47631 .3418 L p
1 g
F P
s
P
p
.002 w
.41606 .49353 m .44844 .50643 L .4522 .47966 L p
1 g
F P
s
P
p
.002 w
.4522 .47966 m .42735 .46964 L .41606 .49353 L p
1 g
F P
s
P
p
.002 w
.48817 .53374 m .52907 .52216 L .51724 .49863 L p
1 g
F P
s
P
p
.002 w
.51724 .49863 m .48338 .50813 L .48817 .53374 L p
1 g
F P
s
P
p
.002 w
.58022 .41816 m .58102 .38321 L .55412 .38492 L p
1 g
F P
s
P
p
.002 w
.54588 .35944 m .55412 .38492 L .58102 .38321 L p
1 g
F P
s
P
p
.002 w
.42681 .36417 m .41787 .3807 L .4433 .38803 L p
1 g
F P
s
P
p
.002 w
.4433 .38803 m .4478 .37974 L .42681 .36417 L p
1 g
F P
s
P
p
.002 w
.47631 .3418 m .45775 .34359 L .46334 .36939 L p
1 g
F P
s
P
p
.002 w
.45474 .37329 m .46334 .36939 L .45775 .34359 L p
1 g
F P
s
P
p
.002 w
.56447 .49838 m .59078 .46484 L .56828 .45121 L p
1 g
F P
s
P
p
.002 w
.58022 .41816 m .56828 .45121 L .59078 .46484 L p
1 g
F P
s
P
p
.002 w
.44062 .35133 m .42681 .36417 L .4478 .37974 L p
1 g
F P
s
P
p
.002 w
.4478 .37974 m .45474 .37329 L .44062 .35133 L p
1 g
F P
s
P
p
.002 w
.45775 .34359 m .44062 .35133 L .45474 .37329 L p
1 g
F P
s
P
p
.002 w
.39407 .42848 m .40723 .45198 L .42666 .43313 L p
1 g
F P
s
P
p
.002 w
.42666 .43313 m .41784 .41718 L .39407 .42848 L p
1 g
F P
s
P
p
.002 w
.54588 .35944 m .52966 .33812 L .50953 .35607 L p
1 g
F P
s
P
p
.002 w
.49422 .34614 m .50953 .35607 L .52966 .33812 L p
1 g
F P
s
P
p
.002 w
.44588 .53181 m .48817 .53374 L .48338 .50813 L p
1 g
F P
s
P
p
.002 w
.48338 .50813 m .44844 .50643 L .44588 .53181 L p
1 g
F P
s
P
p
.002 w
.59078 .46484 m .60531 .42492 L .58022 .41816 L p
1 g
F P
s
P
p
.002 w
.58102 .38321 m .58022 .41816 L .60531 .42492 L p
1 g
F P
s
P
p
.002 w
.38973 .47065 m .41606 .49353 L .42735 .46964 L p
1 g
F P
s
P
p
.002 w
.42735 .46964 m .40723 .45198 L .38973 .47065 L p
1 g
F P
s
P
p
.002 w
.38944 .40165 m .39407 .42848 L .41784 .41718 L p
1 g
F P
s
P
p
.002 w
.41784 .41718 m .41478 .39904 L .38944 .40165 L p
1 g
F P
s
P
p
.002 w
.52966 .33812 m .5071 .32334 L .49422 .34614 L p
1 g
F P
s
P
p
.002 w
.47631 .3418 m .49422 .34614 L .5071 .32334 L p
1 g
F P
s
P
p
.002 w
.58102 .38321 m .57045 .35 L .54588 .35944 L p
1 g
F P
s
P
p
.002 w
.52966 .33812 m .54588 .35944 L .57045 .35 L p
1 g
F P
s
P
p
.002 w
.39395 .37445 m .38944 .40165 L .41478 .39904 L p
1 g
F P
s
P
p
.002 w
.41478 .39904 m .41787 .3807 L .39395 .37445 L p
1 g
F P
s
P
p
.002 w
.40661 .51636 m .44588 .53181 L .44844 .50643 L p
1 g
F P
s
P
p
.002 w
.44844 .50643 m .41606 .49353 L .40661 .51636 L p
1 g
F P
s
P
p
.002 w
.5071 .32334 m .48061 .31683 L .47631 .3418 L p
1 g
F P
s
P
p
.002 w
.45775 .34359 m .47631 .3418 L .48061 .31683 L p
1 g
F P
s
P
p
.002 w
.54043 .54392 m .58117 .51651 L .56447 .49838 L p
1 g
F P
s
P
p
.002 w
.56447 .49838 m .52907 .52216 L .54043 .54392 L p
1 g
F P
s
P
p
.002 w
.59078 .46484 m .56447 .49838 L .58117 .51651 L p
1 g
F P
s
P
p
.002 w
.60531 .42492 m .60642 .38263 L .58102 .38321 L p
1 g
F P
s
P
p
.002 w
.57045 .35 m .58102 .38321 L .60642 .38263 L p
1 g
F P
s
P
p
.002 w
.37244 .44007 m .38973 .47065 L .40723 .45198 L p
1 g
F P
s
P
p
.002 w
.40723 .45198 m .39407 .42848 L .37244 .44007 L p
1 g
F P
s
P
p
.002 w
.40717 .34992 m .39395 .37445 L .41787 .3807 L p
1 g
F P
s
P
p
.002 w
.41787 .3807 m .42681 .36417 L .40717 .34992 L p
1 g
F P
s
P
p
.002 w
.49335 .55735 m .54043 .54392 L .52907 .52216 L p
1 g
F P
s
P
p
.002 w
.52907 .52216 m .48817 .53374 L .49335 .55735 L p
1 g
F P
s
P
p
.002 w
.48061 .31683 m .4531 .3194 L .45775 .34359 L p
1 g
F P
s
P
p
.002 w
.44062 .35133 m .45775 .34359 L .4531 .3194 L p
1 g
F P
s
P
p
.002 w
.57045 .35 m .54944 .32213 L .52966 .33812 L p
1 g
F P
s
P
p
.002 w
.5071 .32334 m .52966 .33812 L .54944 .32213 L p
1 g
F P
s
P
p
.002 w
.58117 .51651 m .6115 .47792 L .59078 .46484 L p
1 g
F P
s
P
p
.002 w
.60531 .42492 m .59078 .46484 L .6115 .47792 L p
1 g
F P
s
P
p
.002 w
.42766 .33085 m .40717 .34992 L .42681 .36417 L p
1 g
F P
s
P
p
.002 w
.42681 .36417 m .44062 .35133 L .42766 .33085 L p
1 g
F P
s
P
p
.002 w
.4531 .3194 m .42766 .33085 L .44062 .35133 L p
1 g
F P
s
P
p
.002 w
.44463 .55527 m .49335 .55735 L .48817 .53374 L p
1 g
F P
s
P
p
.002 w
.48817 .53374 m .44588 .53181 L .44463 .55527 L p
1 g
F P
s
P
p
.002 w
.37459 .48876 m .40661 .51636 L .41606 .49353 L p
1 g
F P
s
P
p
.002 w
.41606 .49353 m .38973 .47065 L .37459 .48876 L p
1 g
F P
s
P
p
.002 w
.6115 .47792 m .62833 .43197 L .60531 .42492 L p
1 g
F P
s
P
p
.002 w
.60642 .38263 m .60531 .42492 L .62833 .43197 L p
1 g
F P
s
P
p
.002 w
.36627 .40505 m .37244 .44007 L .39407 .42848 L p
1 g
F P
s
P
p
.002 w
.39407 .42848 m .38944 .40165 L .36627 .40505 L p
1 g
F P
s
P
p
.002 w
.60642 .38263 m .59378 .34237 L .57045 .35 L p
1 g
F P
s
P
p
.002 w
.54944 .32213 m .57045 .35 L .59378 .34237 L p
1 g
F P
s
P
p
.002 w
.54944 .32213 m .52009 .30273 L .5071 .32334 L p
1 g
F P
s
P
p
.002 w
.48061 .31683 m .5071 .32334 L .52009 .30273 L p
1 g
F P
s
P
p
.002 w
.37207 .36945 m .36627 .40505 L .38944 .40165 L p
1 g
F P
s
P
p
.002 w
.38944 .40165 m .39395 .37445 L .37207 .36945 L p
1 g
F P
s
P
p
.002 w
.39928 .53762 m .44463 .55527 L .44588 .53181 L p
1 g
F P
s
P
p
.002 w
.44588 .53181 m .40661 .51636 L .39928 .53762 L p
1 g
F P
s
P
p
.002 w
.52009 .30273 m .48551 .29409 L .48061 .31683 L p
1 g
F P
s
P
p
.002 w
.4531 .3194 m .48061 .31683 L .48551 .29409 L p
1 g
F P
s
P
p
.002 w
.62833 .43197 m .62977 .38325 L .60642 .38263 L p
1 g
F P
s
P
p
.002 w
.59378 .34237 m .60642 .38263 L .62977 .38325 L p
1 g
F P
s
P
p
.002 w
.35346 .45173 m .37459 .48876 L .38973 .47065 L p
1 g
F P
s
P
p
.002 w
.38973 .47065 m .37244 .44007 L .35346 .45173 L p
1 g
F P
s
P
p
.002 w
.55108 .5634 m .59628 .53296 L .58117 .51651 L p
1 g
F P
s
P
p
.002 w
.58117 .51651 m .54043 .54392 L .55108 .5634 L p
1 g
F P
s
P
p
.002 w
.6115 .47792 m .58117 .51651 L .59628 .53296 L p
1 g
F P
s
P
p
.002 w
.59378 .34237 m .56846 .30848 L .54944 .32213 L p
1 g
F P
s
P
p
.002 w
.52009 .30273 m .54944 .32213 L .56846 .30848 L p
1 g
F P
s
P
p
.002 w
.38934 .33731 m .37207 .36945 L .39395 .37445 L p
1 g
F P
s
P
p
.002 w
.39395 .37445 m .40717 .34992 L .38934 .33731 L p
1 g
F P
s
P
p
.002 w
.49884 .57839 m .55108 .5634 L .54043 .54392 L p
1 g
F P
s
P
p
.002 w
.54043 .54392 m .49335 .55735 L .49884 .57839 L p
1 g
F P
s
P
p
.002 w
.48551 .29409 m .44951 .29738 L .4531 .3194 L p
1 g
F P
s
P
p
.002 w
.42766 .33085 m .4531 .3194 L .44951 .29738 L p
1 g
F P
s
P
p
.002 w
.59628 .53296 m .62997 .49015 L .6115 .47792 L p
1 g
F P
s
P
p
.002 w
.62833 .43197 m .6115 .47792 L .62997 .49015 L p
1 g
F P
s
P
p
.002 w
.41618 .31233 m .38934 .33731 L .40717 .34992 L p
1 g
F P
s
P
p
.002 w
.40717 .34992 m .42766 .33085 L .41618 .31233 L p
1 g
F P
s
P
p
.002 w
.44951 .29738 m .41618 .31233 L .42766 .33085 L p
1 g
F P
s
P
p
.002 w
.36221 .50591 m .39928 .53762 L .40661 .51636 L p
1 g
F P
s
P
p
.002 w
.40661 .51636 m .37459 .48876 L .36221 .50591 L p
1 g
F P
s
P
p
.002 w
.44474 .57624 m .49884 .57839 L .49335 .55735 L p
1 g
F P
s
P
p
.002 w
.49335 .55735 m .44463 .55527 L .44474 .57624 L p
1 g
F P
s
P
p
.002 w
.34582 .40919 m .35346 .45173 L .37244 .44007 L p
1 g
F P
s
P
p
.002 w
.37244 .44007 m .36627 .40505 L .34582 .40919 L p
1 g
F P
s
P
p
.002 w
.62997 .49015 m .64875 .43918 L .62833 .43197 L p
1 g
F P
s
P
p
.002 w
.62977 .38325 m .62833 .43197 L .64875 .43918 L p
1 g
F P
s
P
p
.002 w
.62977 .38325 m .61537 .33677 L .59378 .34237 L p
1 g
F P
s
P
p
.002 w
.56846 .30848 m .59378 .34237 L .61537 .33677 L p
1 g
F P
s
P
p
.002 w
.56846 .30848 m .53292 .28478 L .52009 .30273 L p
1 g
F P
s
P
p
.002 w
.48551 .29409 m .52009 .30273 L .53292 .28478 L p
1 g
F P
s
P
p
.002 w
.35278 .36585 m .34582 .40919 L .36627 .40505 L p
1 g
F P
s
P
p
.002 w
.36627 .40505 m .37207 .36945 L .35278 .36585 L p
1 g
F P
s
P
p
.002 w
.39432 .5568 m .44474 .57624 L .44463 .55527 L p
1 g
F P
s
P
p
.002 w
.44463 .55527 m .39928 .53762 L .39432 .5568 L p
1 g
F P
s
P
p
.002 w
.53292 .28478 m .49092 .27416 L .48551 .29409 L p
1 g
F P
s
P
p
.002 w
.44951 .29738 m .48551 .29409 L .49092 .27416 L p
1 g
F P
s
P
p
.002 w
.64875 .43918 m .6505 .38509 L .62977 .38325 L p
1 g
F P
s
P
p
.002 w
.61537 .33677 m .62977 .38325 L .6505 .38509 L p
1 g
F P
s
P
p
.002 w
.33765 .46322 m .36221 .50591 L .37459 .48876 L p
1 g
F P
s
P
p
.002 w
.37459 .48876 m .35346 .45173 L .33765 .46322 L p
1 g
F P
s
P
p
.002 w
.61537 .33677 m .58629 .29754 L .56846 .30848 L p
1 g
F P
s
P
p
.002 w
.53292 .28478 m .56846 .30848 L .58629 .29754 L p
1 g
F P
s
P
p
.002 w
.56076 .58009 m .60939 .5473 L .59628 .53296 L p
1 g
F P
s
P
p
.002 w
.59628 .53296 m .55108 .5634 L .56076 .58009 L p
1 g
F P
s
P
p
.002 w
.62997 .49015 m .59628 .53296 L .60939 .5473 L p
1 g
F P
s
P
p
.002 w
.37378 .32668 m .35278 .36585 L .37207 .36945 L p
1 g
F P
s
P
p
.002 w
.37207 .36945 m .38934 .33731 L .37378 .32668 L p
1 g
F P
s
P
p
.002 w
.50455 .59632 m .56076 .58009 L .55108 .5634 L p
1 g
F P
s
P
p
.002 w
.55108 .5634 m .49884 .57839 L .50455 .59632 L p
1 g
F P
s
P
p
.002 w
.49092 .27416 m .4471 .27807 L .44951 .29738 L p
1 g
F P
s
P
p
.002 w
.41618 .31233 m .44951 .29738 L .4471 .27807 L p
1 g
F P
s
P
p
.002 w
.60939 .5473 m .6457 .50124 L .62997 .49015 L p
1 g
F P
s
P
p
.002 w
.64875 .43918 m .62997 .49015 L .6457 .50124 L p
1 g
F P
s
P
p
.002 w
.40647 .29624 m .37378 .32668 L .38934 .33731 L p
1 g
F P
s
P
p
.002 w
.38934 .33731 m .41618 .31233 L .40647 .29624 L p
1 g
F P
s
P
p
.002 w
.4471 .27807 m .40647 .29624 L .41618 .31233 L p
1 g
F P
s
P
p
.002 w
.35299 .52168 m .39432 .5568 L .39928 .53762 L p
1 g
F P
s
P
p
.002 w
.39928 .53762 m .36221 .50591 L .35299 .52168 L p
1 g
F P
s
P
p
.002 w
.4463 .59413 m .50455 .59632 L .49884 .57839 L p
1 g
F P
s
P
p
.002 w
.49884 .57839 m .44474 .57624 L .4463 .59413 L p
1 g
F P
s
P
p
.002 w
.32868 .41403 m .33765 .46322 L .35346 .45173 L p
1 g
F P
s
P
p
.002 w
.35346 .45173 m .34582 .40919 L .32868 .41403 L p
1 g
F P
s
P
p
.002 w
.6505 .38509 m .63467 .33341 L .61537 .33677 L p
1 g
F P
s
P
p
.002 w
.58629 .29754 m .61537 .33677 L .63467 .33341 L p
1 g
F P
s
P
p
.002 w
.6457 .50124 m .666 .44641 L .64875 .43918 L p
1 g
F P
s
P
p
.002 w
.6505 .38509 m .64875 .43918 L .666 .44641 L p
1 g
F P
s
P
p
.002 w
.58629 .29754 m .54532 .27003 L .53292 .28478 L p
1 g
F P
s
P
p
.002 w
.49092 .27416 m .53292 .28478 L .54532 .27003 L p
1 g
F P
s
P
p
.002 w
.33665 .36382 m .32868 .41403 L .34582 .40919 L p
1 g
F P
s
P
p
.002 w
.34582 .40919 m .35278 .36585 L .33665 .36382 L p
1 g
F P
s
P
p
.002 w
.39194 .57334 m .4463 .59413 L .44474 .57624 L p
1 g
F P
s
P
p
.002 w
.44474 .57624 m .39432 .5568 L .39194 .57334 L p
1 g
F P
s
P
p
.002 w
.54532 .27003 m .49675 .25761 L .49092 .27416 L p
1 g
F P
s
P
p
.002 w
.4471 .27807 m .49092 .27416 L .49675 .25761 L p
1 g
F P
s
P
p
.002 w
.32554 .47426 m .35299 .52168 L .36221 .50591 L p
1 g
F P
s
P
p
.002 w
.36221 .50591 m .33765 .46322 L .32554 .47426 L p
1 g
F P
s
P
p
.002 w
.666 .44641 m .66802 .38818 L .6505 .38509 L p
1 g
F P
s
P
p
.002 w
.63467 .33341 m .6505 .38509 L .66802 .38818 L p
1 g
F P
s
P
p
.002 w
.63467 .33341 m .60248 .28969 L .58629 .29754 L p
1 g
F P
s
P
p
.002 w
.54532 .27003 m .58629 .29754 L .60248 .28969 L p
1 g
F P
s
P
p
.002 w
.5692 .59347 m .62013 .5591 L .60939 .5473 L p
1 g
F P
s
P
p
.002 w
.60939 .5473 m .56076 .58009 L .5692 .59347 L p
1 g
F P
s
P
p
.002 w
.6457 .50124 m .60939 .5473 L .62013 .5591 L p
1 g
F P
s
P
p
.002 w
.36095 .31838 m .33665 .36382 L .35278 .36585 L p
1 g
F P
s
P
p
.002 w
.35278 .36585 m .37378 .32668 L .36095 .31838 L p
1 g
F P
s
P
p
.002 w
.49675 .25761 m .44598 .26205 L .4471 .27807 L p
1 g
F P
s
P
p
.002 w
.40647 .29624 m .4471 .27807 L .44598 .26205 L p
1 g
F P
s
P
p
.002 w
.51035 .61054 m .5692 .59347 L .56076 .58009 L p
1 g
F P
s
P
p
.002 w
.56076 .58009 m .50455 .59632 L .51035 .61054 L p
1 g
F P
s
P
p
.002 w
.62013 .5591 m .65818 .51088 L .6457 .50124 L p
1 g
F P
s
P
p
.002 w
.666 .44641 m .6457 .50124 L .65818 .51088 L p
1 g
F P
s
P
p
.002 w
.39886 .28308 m .36095 .31838 L .37378 .32668 L p
1 g
F P
s
P
p
.002 w
.37378 .32668 m .40647 .29624 L .39886 .28308 L p
1 g
F P
s
P
p
.002 w
.44598 .26205 m .39886 .28308 L .40647 .29624 L p
1 g
F P
s
P
p
.002 w
.34733 .53562 m .39194 .57334 L .39432 .5568 L p
1 g
F P
s
P
p
.002 w
.39432 .5568 m .35299 .52168 L .34733 .53562 L p
1 g
F P
s
P
p
.002 w
.31542 .4195 m .32554 .47426 L .33765 .46322 L p
1 g
F P
s
P
p
.002 w
.33765 .46322 m .32868 .41403 L .31542 .4195 L p
1 g
F P
s
P
p
.002 w
.44934 .60836 m .51035 .61054 L .50455 .59632 L p
1 g
F P
s
P
p
.002 w
.50455 .59632 m .4463 .59413 L .44934 .60836 L p
1 g
F P
s
P
p
.002 w
.66802 .38818 m .65112 .33248 L .63467 .33341 L p
1 g
F P
s
P
p
.002 w
.60248 .28969 m .63467 .33341 L .65112 .33248 L p
1 g
F P
s
P
p
.002 w
.65818 .51088 m .67952 .45348 L .666 .44641 L p
1 g
F P
s
P
p
.002 w
.66802 .38818 m .666 .44641 L .67952 .45348 L p
1 g
F P
s
P
p
.002 w
.60248 .28969 m .55697 .25895 L .54532 .27003 L p
1 g
F P
s
P
p
.002 w
.49675 .25761 m .54532 .27003 L .55697 .25895 L p
1 g
F P
s
P
p
.002 w
.32424 .36349 m .31542 .4195 L .32868 .41403 L p
1 g
F P
s
P
p
.002 w
.32868 .41403 m .33665 .36382 L .32424 .36349 L p
1 g
F P
s
P
p
.002 w
.39237 .5867 m .44934 .60836 L .4463 .59413 L p
1 g
F P
s
P
p
.002 w
.4463 .59413 m .39194 .57334 L .39237 .5867 L p
1 g
F P
s
P
p
.002 w
.55697 .25895 m .50289 .24501 L .49675 .25761 L p
1 g
F P
s
P
p
.002 w
.44598 .26205 m .49675 .25761 L .50289 .24501 L p
1 g
F P
s
P
p
.002 w
.31762 .48456 m .34733 .53562 L .35299 .52168 L p
1 g
F P
s
P
p
.002 w
.35299 .52168 m .32554 .47426 L .31762 .48456 L p
1 g
F P
s
P
p
.002 w
.67952 .45348 m .68175 .39251 L .66802 .38818 L p
1 g
F P
s
P
p
.002 w
.65112 .33248 m .66802 .38818 L .68175 .39251 L p
1 g
F P
s
P
p
.002 w
.65112 .33248 m .61656 .28529 L .60248 .28969 L p
1 g
F P
s
P
p
.002 w
.55697 .25895 m .60248 .28969 L .61656 .28529 L p
1 g
F P
s
P
p
.002 w
.57613 .60304 m .62809 .56796 L .62013 .5591 L p
1 g
F P
s
P
p
.002 w
.62013 .5591 m .5692 .59347 L .57613 .60304 L p
1 g
F P
s
P
p
.002 w
.65818 .51088 m .62013 .5591 L .62809 .56796 L p
1 g
F P
s
P
p
.002 w
.35132 .31275 m .32424 .36349 L .33665 .36382 L p
1 g
F P
s
P
p
.002 w
.33665 .36382 m .36095 .31838 L .35132 .31275 L p
1 g
F P
s
P
p
.002 w
.50289 .24501 m .44626 .24989 L .44598 .26205 L p
1 g
F P
s
P
p
.002 w
.39886 .28308 m .44598 .26205 L .44626 .24989 L p
1 g
F P
s
P
p
.002 w
.5161 .62051 m .57613 .60304 L .5692 .59347 L p
1 g
F P
s
P
p
.002 w
.5692 .59347 m .51035 .61054 L .5161 .62051 L p
1 g
F P
s
P
p
.002 w
.62809 .56796 m .66694 .51877 L .65818 .51088 L p
1 g
F P
s
P
p
.002 w
.67952 .45348 m .65818 .51088 L .66694 .51877 L p
1 g
F P
s
P
p
.002 w
.39365 .27333 m .35132 .31275 L .36095 .31838 L p
1 g
F P
s
P
p
.002 w
.36095 .31838 m .39886 .28308 L .39365 .27333 L p
1 g
F P
s
P
p
.002 w
.44626 .24989 m .39365 .27333 L .39886 .28308 L p
1 g
F P
s
P
p
.002 w
.34556 .54728 m .39237 .5867 L .39194 .57334 L p
1 g
F P
s
P
p
.002 w
.39194 .57334 m .34733 .53562 L .34556 .54728 L p
1 g
F P
s
P
p
.002 w
.30661 .42548 m .31762 .48456 L .32554 .47426 L p
1 g
F P
s
P
p
.002 w
.32554 .47426 m .31542 .4195 L .30661 .42548 L p
1 g
F P
s
P
p
.002 w
.68175 .39251 m .66417 .33414 L .65112 .33248 L p
1 g
F P
s
P
p
.002 w
.61656 .28529 m .65112 .33248 L .66417 .33414 L p
1 g
F P
s
P
p
.002 w
.45387 .61837 m .5161 .62051 L .51035 .61054 L p
1 g
F P
s
P
p
.002 w
.51035 .61054 m .44934 .60836 L .45387 .61837 L p
1 g
F P
s
P
p
.002 w
.61656 .28529 m .56756 .25204 L .55697 .25895 L p
1 g
F P
s
P
p
.002 w
.50289 .24501 m .55697 .25895 L .56756 .25204 L p
1 g
F P
s
P
p
.002 w
.66694 .51877 m .68877 .46022 L .67952 .45348 L p
1 g
F P
s
P
p
.002 w
.68175 .39251 m .67952 .45348 L .68877 .46022 L p
1 g
F P
s
P
p
.002 w
.31609 .36496 m .30661 .42548 L .31542 .4195 L p
1 g
F P
s
P
p
.002 w
.31542 .4195 m .32424 .36349 L .31609 .36496 L p
1 g
F P
s
P
p
.002 w
.39575 .59636 m .45387 .61837 L .44934 .60836 L p
1 g
F P
s
P
p
.002 w
.44934 .60836 m .39237 .5867 L .39575 .59636 L p
1 g
F P
s
P
p
.002 w
.31436 .49381 m .34556 .54728 L .34733 .53562 L p
1 g
F P
s
P
p
.002 w
.34733 .53562 m .31762 .48456 L .31436 .49381 L p
1 g
F P
s
P
p
.002 w
.56756 .25204 m .50921 .23691 L .50289 .24501 L p
1 g
F P
s
P
p
.002 w
.44626 .24989 m .50289 .24501 L .50921 .23691 L p
1 g
F P
s
P
p
.002 w
.68877 .46022 m .69112 .39804 L .68175 .39251 L p
1 g
F P
s
P
p
.002 w
.66417 .33414 m .68175 .39251 L .69112 .39804 L p
1 g
F P
s
P
p
.002 w
.66417 .33414 m .62806 .28464 L .61656 .28529 L p
1 g
F P
s
P
p
.002 w
.56756 .25204 m .61656 .28529 L .62806 .28464 L p
1 g
F P
s
P
p
.002 w
.58128 .60832 m .6329 .57345 L .62809 .56796 L p
1 g
F P
s
P
p
.002 w
.62809 .56796 m .57613 .60304 L .58128 .60832 L p
1 g
F P
s
P
p
.002 w
.66694 .51877 m .62809 .56796 L .6329 .57345 L p
1 g
F P
s
P
p
.002 w
.34534 .3101 m .31609 .36496 L .32424 .36349 L p
1 g
F P
s
P
p
.002 w
.32424 .36349 m .35132 .31275 L .34534 .3101 L p
1 g
F P
s
P
p
.002 w
.50921 .23691 m .44802 .24213 L .44626 .24989 L p
1 g
F P
s
P
p
.002 w
.39365 .27333 m .44626 .24989 L .44802 .24213 L p
1 g
F P
s
P
p
.002 w
.52165 .62571 m .58128 .60832 L .57613 .60304 L p
1 g
F P
s
P
p
.002 w
.57613 .60304 m .5161 .62051 L .52165 .62571 L p
1 g
F P
s
P
p
.002 w
.6329 .57345 m .67151 .52458 L .66694 .51877 L p
1 g
F P
s
P
p
.002 w
.68877 .46022 m .66694 .51877 L .67151 .52458 L p
1 g
F P
s
P
p
.002 w
.39112 .26747 m .34534 .3101 L .35132 .31275 L p
1 g
F P
s
P
p
.002 w
.35132 .31275 m .39365 .27333 L .39112 .26747 L p
1 g
F P
s
P
p
.002 w
.34799 .55621 m .39575 .59636 L .39237 .5867 L p
1 g
F P
s
P
p
.002 w
.39237 .5867 m .34556 .54728 L .34799 .55621 L p
1 g
F P
s
P
p
.002 w
.44802 .24213 m .39112 .26747 L .39365 .27333 L p
1 g
F P
s
P
p
.002 w
.30277 .43185 m .31436 .49381 L .31762 .48456 L p
1 g
F P
s
P
p
.002 w
.31762 .48456 m .30661 .42548 L .30277 .43185 L p
1 g
F P
s
P
p
.002 w
.69112 .39804 m .67327 .3385 L .66417 .33414 L p
1 g
F P
s
P
p
.002 w
.62806 .28464 m .66417 .33414 L .67327 .3385 L p
1 g
F P
s
P
p
.002 w
.45987 .62361 m .52165 .62571 L .5161 .62051 L p
1 g
F P
s
P
p
.002 w
.5161 .62051 m .45387 .61837 L .45987 .62361 L p
1 g
F P
s
P
p
.002 w
.62806 .28464 m .57674 .24973 L .56756 .25204 L p
1 g
F P
s
P
p
.002 w
.50921 .23691 m .56756 .25204 L .57674 .24973 L p
1 g
F P
s
P
p
.002 w
.67151 .52458 m .69323 .46644 L .68877 .46022 L p
1 g
F P
s
P
p
.002 w
.69112 .39804 m .68877 .46022 L .69323 .46644 L p
1 g
F P
s
P
p
.002 w
.40218 .6018 m .45987 .62361 L .45387 .61837 L p
1 g
F P
s
P
p
.002 w
.45387 .61837 m .39575 .59636 L .40218 .6018 L p
1 g
F P
s
P
p
.002 w
.31269 .36833 m .30277 .43185 L .30661 .42548 L p
1 g
F P
s
P
p
.002 w
.30661 .42548 m .31609 .36496 L .31269 .36833 L p
1 g
F P
s
P
p
.002 w
.31614 .5017 m .34799 .55621 L .34556 .54728 L p
1 g
F P
s
P
p
.002 w
.34556 .54728 m .31436 .49381 L .31614 .5017 L p
1 g
F P
s
P
p
.002 w
.57674 .24973 m .51555 .23382 L .50921 .23691 L p
1 g
F P
s
P
p
.002 w
.44802 .24213 m .50921 .23691 L .51555 .23382 L p
1 g
F P
s
P
p
.002 w
.69323 .46644 m .69561 .4047 L .69112 .39804 L p
1 g
F P
s
P
p
.002 w
.67327 .3385 m .69112 .39804 L .69561 .4047 L p
1 g
F P
s
P
p
.002 w
.67327 .3385 m .63649 .288 L .62806 .28464 L p
1 g
F P
s
P
p
.002 w
.57674 .24973 m .62806 .28464 L .63649 .288 L p
1 g
F P
s
P
p
.002 w
.58439 .60887 m .63423 .5752 L .6329 .57345 L p
1 g
F P
s
P
p
.002 w
.6329 .57345 m .58128 .60832 L .58439 .60887 L p
1 g
F P
s
P
p
.002 w
.67151 .52458 m .6329 .57345 L .63423 .5752 L p
1 g
F P
s
P
p
.002 w
.34342 .31069 m .31269 .36833 L .31609 .36496 L p
1 g
F P
s
P
p
.002 w
.31609 .36496 m .34534 .3101 L .34342 .31069 L p
1 g
F P
s
P
p
.002 w
.51555 .23382 m .4513 .23928 L .44802 .24213 L p
1 g
F P
s
P
p
.002 w
.39112 .26747 m .44802 .24213 L .4513 .23928 L p
1 g
F P
s
P
p
.002 w
.52685 .62566 m .58439 .60887 L .58128 .60832 L p
1 g
F P
s
P
p
.002 w
.58128 .60832 m .52165 .62571 L .52685 .62566 L p
1 g
F P
s
P
p
.002 w
.63423 .5752 m .67151 .52802 L .67151 .52458 L p
1 g
F P
s
P
p
.002 w
.69323 .46644 m .67151 .52458 L .67151 .52802 L p
1 g
F P
s
P
p
.002 w
.35481 .56198 m .40218 .6018 L .39575 .59636 L p
1 g
F P
s
P
p
.002 w
.39575 .59636 m .34799 .55621 L .35481 .56198 L p
1 g
F P
s
P
p
.002 w
.39153 .26589 m .34342 .31069 L .34534 .3101 L p
1 g
F P
s
P
p
.002 w
.34534 .3101 m .39112 .26747 L .39153 .26589 L p
1 g
F P
s
P
p
.002 w
.4513 .23928 m .39153 .26589 L .39112 .26747 L p
1 g
F P
s
P
p
.002 w
.30432 .43847 m .31614 .5017 L .31436 .49381 L p
1 g
F P
s
P
p
.002 w
.31436 .49381 m .30277 .43185 L .30432 .43847 L p
1 g
F P
s
P
p
.002 w
.69561 .4047 m .67792 .34562 L .67327 .3385 L p
1 g
F P
s
P
p
.002 w
.63649 .288 m .67327 .3385 L .67792 .34562 L p
1 g
F P
s
P
p
.002 w
.46726 .62364 m .52685 .62566 L .52165 .62571 L p
1 g
F P
s
P
p
.002 w
.52165 .62571 m .45987 .62361 L .46726 .62364 L p
1 g
F P
s
P
p
.002 w
.63649 .288 m .58417 .25238 L .57674 .24973 L p
1 g
F P
s
P
p
.002 w
.51555 .23382 m .57674 .24973 L .58417 .25238 L p
1 g
F P
s
P
p
.002 w
.67151 .52802 m .69248 .47192 L .69323 .46644 L p
1 g
F P
s
P
p
.002 w
.69561 .4047 m .69323 .46644 L .69248 .47192 L p
1 g
F P
s
P
p
.002 w
.41168 .6026 m .46726 .62364 L .45987 .62361 L p
1 g
F P
s
P
p
.002 w
.45987 .62361 m .40218 .6018 L .41168 .6026 L p
1 g
F P
s
P
p
.002 w
.31447 .37361 m .30432 .43847 L .30277 .43185 L p
1 g
F P
s
P
p
.002 w
.30277 .43185 m .31269 .36833 L .31447 .37361 L p
1 g
F P
s
P
p
.002 w
.32325 .50789 m .35481 .56198 L .34799 .55621 L p
1 g
F P
s
P
p
.002 w
.34799 .55621 m .31614 .5017 L .32325 .50789 L p
1 g
F P
s
P
p
.002 w
.69248 .47192 m .69477 .41239 L .69561 .4047 L p
1 g
F P
s
P
p
.002 w
.67792 .34562 m .69561 .4047 L .69477 .41239 L p
1 g
F P
s
P
p
.002 w
.58417 .25238 m .52172 .23615 L .51555 .23382 L p
1 g
F P
s
P
p
.002 w
.4513 .23928 m .51555 .23382 L .52172 .23615 L p
1 g
F P
s
P
p
.002 w
.67792 .34562 m .64144 .29553 L .63649 .288 L p
1 g
F P
s
P
p
.002 w
.58417 .25238 m .63649 .288 L .64144 .29553 L p
1 g
F P
s
P
p
.002 w
.58523 .60438 m .6318 .57292 L .63423 .5752 L p
1 g
F P
s
P
p
.002 w
.63423 .5752 m .58439 .60887 L .58523 .60438 L p
1 g
F P
s
P
p
.002 w
.67151 .52802 m .63423 .5752 L .6318 .57292 L p
1 g
F P
s
P
p
.002 w
.34588 .31473 m .31447 .37361 L .31269 .36833 L p
1 g
F P
s
P
p
.002 w
.31269 .36833 m .34342 .31069 L .34588 .31473 L p
1 g
F P
s
P
p
.002 w
.52172 .23615 m .45611 .24174 L .4513 .23928 L p
1 g
F P
s
P
p
.002 w
.39153 .26589 m .4513 .23928 L .45611 .24174 L p
1 g
F P
s
P
p
.002 w
.5315 .62003 m .58523 .60438 L .58439 .60887 L p
1 g
F P
s
P
p
.002 w
.58439 .60887 m .52685 .62566 L .5315 .62003 L p
1 g
F P
s
P
p
.002 w
.6318 .57292 m .66663 .52884 L .67151 .52802 L p
1 g
F P
s
P
p
.002 w
.69248 .47192 m .67151 .52802 L .66663 .52884 L p
1 g
F P
s
P
p
.002 w
.3661 .56421 m .41168 .6026 L .40218 .6018 L p
1 g
F P
s
P
p
.002 w
.40218 .6018 m .35481 .56198 L .3661 .56421 L p
1 g
F P
s
P
p
.002 w
.39505 .26895 m .34588 .31473 L .34342 .31069 L p
1 g
F P
s
P
p
.002 w
.34342 .31069 m .39153 .26589 L .39505 .26895 L p
1 g
F P
s
P
p
.002 w
.31158 .44515 m .32325 .50789 L .31614 .5017 L p
1 g
F P
s
P
p
.002 w
.31614 .5017 m .30432 .43847 L .31158 .44515 L p
1 g
F P
s
P
p
.002 w
.45611 .24174 m .39505 .26895 L .39153 .26589 L p
1 g
F P
s
P
p
.002 w
.69477 .41239 m .6777 .35547 L .67792 .34562 L p
1 g
F P
s
P
p
.002 w
.64144 .29553 m .67792 .34562 L .6777 .35547 L p
1 g
F P
s
P
p
.002 w
.64144 .29553 m .58952 .26023 L .58417 .25238 L p
1 g
F P
s
P
p
.002 w
.52172 .23615 m .58417 .25238 L .58952 .26023 L p
1 g
F P
s
P
p
.002 w
.47591 .61811 m .5315 .62003 L .52685 .62566 L p
1 g
F P
s
P
p
.002 w
.52685 .62566 m .46726 .62364 L .47591 .61811 L p
1 g
F P
s
P
p
.002 w
.66663 .52884 m .68618 .47645 L .69248 .47192 L p
1 g
F P
s
P
p
.002 w
.69477 .41239 m .69248 .47192 L .68618 .47645 L p
1 g
F P
s
P
p
.002 w
.42415 .59843 m .47591 .61811 L .46726 .62364 L p
1 g
F P
s
P
p
.002 w
.46726 .62364 m .41168 .6026 L .42415 .59843 L p
1 g
F P
s
P
p
.002 w
.3358 .51209 m .3661 .56421 L .35481 .56198 L p
1 g
F P
s
P
p
.002 w
.35481 .56198 m .32325 .50789 L .3358 .51209 L p
1 g
F P
s
P
p
.002 w
.32171 .38077 m .31158 .44515 L .30432 .43847 L p
1 g
F P
s
P
p
.002 w
.30432 .43847 m .31447 .37361 L .32171 .38077 L p
1 g
F P
s
P
p
.002 w
.68618 .47645 m .68827 .42092 L .69477 .41239 L p
1 g
F P
s
P
p
.002 w
.6777 .35547 m .69477 .41239 L .68827 .42092 L p
1 g
F P
s
P
p
.002 w
.58952 .26023 m .52753 .24418 L .52172 .23615 L p
1 g
F P
s
P
p
.002 w
.45611 .24174 m .52172 .23615 L .52753 .24418 L p
1 g
F P
s
P
p
.002 w
.6777 .35547 m .64251 .30728 L .64144 .29553 L p
1 g
F P
s
P
p
.002 w
.58952 .26023 m .64144 .29553 L .64251 .30728 L p
1 g
F P
s
P
p
.002 w
.35294 .32232 m .32171 .38077 L .31447 .37361 L p
1 g
F P
s
P
p
.002 w
.31447 .37361 m .34588 .31473 L .35294 .32232 L p
1 g
F P
s
P
p
.002 w
.58364 .59463 m .62544 .56641 L .6318 .57292 L p
1 g
F P
s
P
p
.002 w
.6318 .57292 m .58523 .60438 L .58364 .59463 L p
1 g
F P
s
P
p
.002 w
.66663 .52884 m .6318 .57292 L .62544 .56641 L p
1 g
F P
s
P
p
.002 w
.52753 .24418 m .4624 .2498 L .45611 .24174 L p
1 g
F P
s
P
p
.002 w
.39505 .26895 m .45611 .24174 L .4624 .2498 L p
1 g
F P
s
P
p
.004 w
.41583 .22753 m
.42231 .24316 L
s
P
p
.002 w
.53543 .60863 m .58364 .59463 L .58523 .60438 L p
1 g
F P
s
P
p
.002 w
.58523 .60438 m .5315 .62003 L .53543 .60863 L p
1 g
F P
s
P
p
.002 w
.62544 .56641 m .65668 .52684 L .66663 .52884 L p
1 g
F P
s
P
p
.002 w
.68618 .47645 m .66663 .52884 L .65668 .52684 L p
1 g
F P
s
P
p
.002 w
.38179 .5626 m .42415 .59843 L .41168 .6026 L p
1 g
F P
s
P
p
.002 w
.41168 .6026 m .3661 .56421 L .38179 .5626 L p
1 g
F P
s
P
p
.002 w
.32467 .45167 m .3358 .51209 L .32325 .50789 L p
1 g
F P
s
P
p
.002 w
.32325 .50789 m .31158 .44515 L .32467 .45167 L p
1 g
F P
s
P
p
.002 w
.68827 .42092 m .67229 .36792 L .6777 .35547 L p
1 g
F P
s
P
p
.002 w
.64251 .30728 m .6777 .35547 L .67229 .36792 L p
1 g
F P
s
P
p
.002 w
.40178 .27685 m .35294 .32232 L .34588 .31473 L p
1 g
F P
s
P
p
.002 w
.34588 .31473 m .39505 .26895 L .40178 .27685 L p
1 g
F P
s
P
p
.002 w
.4624 .2498 m .40178 .27685 L .39505 .26895 L p
1 g
F P
s
P
p
.002 w
.64251 .30728 m .59248 .27338 L .58952 .26023 L p
1 g
F P
s
P
p
.002 w
.52753 .24418 m .58952 .26023 L .59248 .27338 L p
1 g
F P
s
P
p
.002 w
.48563 .60683 m .53543 .60863 L .5315 .62003 L p
1 g
F P
s
P
p
.002 w
.5315 .62003 m .47591 .61811 L .48563 .60683 L p
1 g
F P
s
P
p
.002 w
.65668 .52684 m .67418 .47984 L .68618 .47645 L p
1 g
F P
s
P
p
.002 w
.68827 .42092 m .68618 .47645 L .67418 .47984 L p
1 g
F P
s
P
p
.002 w
.35372 .51403 m .38179 .5626 L .3661 .56421 L p
1 g
F P
s
P
p
.002 w
.3661 .56421 m .3358 .51209 L .35372 .51403 L p
1 g
F P
s
P
p
.002 w
.43936 .58912 m .48563 .60683 L .47591 .61811 L p
1 g
F P
s
P
p
.002 w
.47591 .61811 m .42415 .59843 L .43936 .58912 L p
1 g
F P
s
P
p
.002 w
.33453 .3897 m .32467 .45167 L .31158 .44515 L p
1 g
F P
s
P
p
.002 w
.31158 .44515 m .32171 .38077 L .33453 .3897 L p
1 g
F P
s
P
p
.002 w
.67418 .47984 m .67597 .4301 L .68827 .42092 L p
1 g
F P
s
P
p
.002 w
.67229 .36792 m .68827 .42092 L .67597 .4301 L p
1 g
F P
s
P
p
.002 w
.67229 .36792 m .63944 .32313 L .64251 .30728 L p
1 g
F P
s
P
p
.002 w
.59248 .27338 m .64251 .30728 L .63944 .32313 L p
1 g
F P
s
P
p
.002 w
.59248 .27338 m .53278 .25804 L .52753 .24418 L p
1 g
F P
s
P
p
.002 w
.4624 .2498 m .52753 .24418 L .53278 .25804 L p
1 g
F P
s
P
p
.002 w
.36466 .33343 m .33453 .3897 L .32171 .38077 L p
1 g
F P
s
P
p
.002 w
.32171 .38077 m .35294 .32232 L .36466 .33343 L p
1 g
F P
s
P
p
.002 w
.5795 .57961 m .6151 .5556 L .62544 .56641 L p
1 g
F P
s
P
p
.002 w
.62544 .56641 m .58364 .59463 L .5795 .57961 L p
1 g
F P
s
P
p
.002 w
.65668 .52684 m .62544 .56641 L .6151 .5556 L p
1 g
F P
s
P
p
.002 w
.53278 .25804 m .47007 .26354 L .4624 .2498 L p
1 g
F P
s
P
p
.002 w
.40178 .27685 m .4624 .2498 L .47007 .26354 L p
1 g
F P
s
P
p
.002 w
.4016 .55698 m .43936 .58912 L .42415 .59843 L p
1 g
F P
s
P
p
.002 w
.42415 .59843 m .38179 .5626 L .4016 .55698 L p
1 g
F P
s
P
p
.002 w
.53847 .59148 m .5795 .57961 L .58364 .59463 L p
1 g
F P
s
P
p
.002 w
.58364 .59463 m .53543 .60863 L .53847 .59148 L p
1 g
F P
s
P
p
.002 w
.6151 .5556 m .64168 .5219 L .65668 .52684 L p
1 g
F P
s
P
p
.002 w
.67418 .47984 m .65668 .52684 L .64168 .5219 L p
1 g
F P
s
P
p
.002 w
.34352 .45781 m .35372 .51403 L .3358 .51209 L p
1 g
F P
s
P
p
.002 w
.3358 .51209 m .32467 .45167 L .34352 .45781 L p
1 g
F P
s
P
p
.002 w
.67597 .4301 m .66155 .38271 L .67229 .36792 L p
1 g
F P
s
P
p
.002 w
.63944 .32313 m .67229 .36792 L .66155 .38271 L p
1 g
F P
s
P
p
.002 w
.4117 .28964 m .36466 .33343 L .35294 .32232 L p
1 g
F P
s
P
p
.002 w
.35294 .32232 m .40178 .27685 L .4117 .28964 L p
1 g
F P
s
P
p
.002 w
.47007 .26354 m .4117 .28964 L .40178 .27685 L p
1 g
F P
s
P
p
.002 w
.63944 .32313 m .59281 .29171 L .59248 .27338 L p
1 g
F P
s
P
p
.002 w
.53278 .25804 m .59248 .27338 L .59281 .29171 L p
1 g
F P
s
P
p
.002 w
.49615 .58985 m .53847 .59148 L .53543 .60863 L p
1 g
F P
s
P
p
.002 w
.53543 .60863 m .48563 .60683 L .49615 .58985 L p
1 g
F P
s
P
p
.002 w
.64168 .5219 m .65651 .4819 L .67418 .47984 L p
1 g
F P
s
P
p
.002 w
.67597 .4301 m .67418 .47984 L .65651 .4819 L p
1 g
F P
s
P
p
.002 w
.3767 .51353 m .4016 .55698 L .38179 .5626 L p
1 g
F P
s
P
p
.002 w
.38179 .5626 m .35372 .51403 L .3767 .51353 L p
1 g
F P
s
P
p
.002 w
.45694 .57469 m .49615 .58985 L .48563 .60683 L p
1 g
F P
s
P
p
.002 w
.48563 .60683 m .43936 .58912 L .45694 .57469 L p
1 g
F P
s
P
p
.002 w
.35282 .40019 m .34352 .45781 L .32467 .45167 L p
1 g
F P
s
P
p
.002 w
.32467 .45167 m .33453 .3897 L .35282 .40019 L p
1 g
F P
s
P
p
.002 w
.66155 .38271 m .63207 .34279 L .63944 .32313 L p
1 g
F P
s
P
p
.002 w
.59281 .29171 m .63944 .32313 L .63207 .34279 L p
1 g
F P
s
P
p
.002 w
.65651 .4819 m .65793 .43963 L .67597 .4301 L p
1 g
F P
s
P
p
.002 w
.66155 .38271 m .67597 .4301 L .65793 .43963 L p
1 g
F P
s
P
p
.002 w
.59281 .29171 m .53724 .27759 L .53278 .25804 L p
1 g
F P
s
P
p
.002 w
.47007 .26354 m .53278 .25804 L .53724 .27759 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.38091 .3479 m .35282 .40019 L .33453 .3897 L p
1 g
F P
s
P
p
.002 w
.33453 .3897 m .36466 .33343 L .38091 .3479 L p
1 g
F P
s
P
p
.002 w
.57281 .55953 m .60089 .5406 L .6151 .5556 L p
1 g
F P
s
P
p
.002 w
.6151 .5556 m .5795 .57961 L .57281 .55953 L p
1 g
F P
s
P
p
.002 w
.64168 .5219 m .6151 .5556 L .60089 .5406 L p
1 g
F P
s
P
p
.002 w
.42507 .54733 m .45694 .57469 L .43936 .58912 L p
1 g
F P
s
P
p
.002 w
.43936 .58912 m .4016 .55698 L .42507 .54733 L p
1 g
F P
s
P
p
.002 w
.53724 .27759 m .47893 .28283 L .47007 .26354 L p
1 g
F P
s
P
p
.002 w
.4117 .28964 m .47007 .26354 L .47893 .28283 L p
1 g
F P
s
P
p
.004 w
.42231 .24316 m
.43399 .27132 L
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53165 .57435 L p
1 g
F P
s
P
p
.54854 .56129 m .53165 .57435 L .53587 .5721 L 1 g
F
P
p
.53847 .59148 m .5225 .57922 L .53165 .57435 L 1 g
F
P
p
.002 w
.54038 .5697 m .54018 .57196 L p
.53165 .57435 L 1 g
F P
s
P
p
.002 w
.54018 .57196 m .53847 .59148 L p
.53165 .57435 L 1 g
F P
s
P
p
.002 w
.53165 .57435 m .53128 .57265 L p
.52354 .57662 L 1 g
F P
s
P
p
.53887 .5705 m .5319 .57549 L .53804 .5713 L 1 g
F
P
p
.54854 .56129 m .53587 .5721 L .53887 .5705 L 1 g
F
P
p
.53587 .5721 m .5319 .57549 L .53887 .5705 L 1 g
F
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51091 .58016 L p
1 g
F P
s
P
p
.5225 .57922 m .52029 .57753 L .53165 .57435 L 1 g
F
P
p
.53128 .57265 m .51091 .58016 L .52354 .57662 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53847 .59148 m .49615 .58985 L .50054 .58091 L p
1 g
F P
s
P
p
.002 w
.51091 .58016 m .51079 .57862 L p
.49961 .58085 L 1 g
F P
s
P
p
.002 w
.50054 .58091 m .49615 .58985 L p
.49068 .58031 L 1 g
F P
s
P
p
.49961 .58085 m .49863 .58105 L .50054 .58091 L 1 g
F
P
p
.49961 .58085 m .50054 .58091 L .51091 .58016 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58021 L p
1 g
F P
s
P
p
.002 w
.49615 .58985 m .46785 .57891 L p
.48909 .58021 L 1 g
F P
s
P
p
.49092 .58073 m .48909 .58021 L .49068 .58031 L 1 g
F
P
p
.49615 .58985 m .48909 .58021 L .49092 .58073 L 1 g
F
P
p
.002 w
.48909 .58021 m .48921 .57862 L p
.48111 .57795 L 1 g
F P
s
P
p
.51079 .57862 m .48909 .58021 L .49961 .58085 L 1 g
F
P
p
.002 w
.46785 .57891 m .45694 .57469 L p
.47413 .57755 L 1 g
F P
s
P
p
.002 w
.46835 .57435 m .46872 .57265 L p
.45909 .5688 L 1 g
F P
s
P
p
.002 w
.46125 .57042 m .45694 .57469 L p
.45583 .56637 L 1 g
F P
s
P
p
.45909 .5688 m .45639 .56772 L .46125 .57042 L 1 g
F
P
p
.45909 .5688 m .46125 .57042 L .46835 .57435 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46835 .57435 L p
1 g
F P
s
P
p
.48921 .57862 m .46835 .57435 L .48111 .57795 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.49068 .58031 m .47413 .57755 L .4764 .55541 L 1 g
F
P
p
.002 w
.45694 .57469 m .46125 .57042 L p
.47413 .57755 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45093 .5627 L p
1 g
F P
s
P
p
.45694 .57469 m .42822 .54572 L .45093 .5627 L 1 g
F
P
p
.45624 .56942 m .45093 .5627 L .45583 .56637 L 1 g
F
P
p
.45694 .57469 m .45093 .5627 L .45624 .56942 L 1 g
F
P
p
.002 w
.45093 .5627 m .45146 .56129 L p
.44621 .55673 L 1 g
F P
s
P
p
.46872 .57265 m .45093 .5627 L .45744 .56757 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43853 .54701 L p
1 g
F P
s
P
p
.45146 .56129 m .43853 .54701 L .44621 .55673 L 1 g
F
P
p
.45583 .56637 m .45093 .5627 L .4515 .53382 L 1 g
F
P
p
.002 w
.42822 .54572 m .43484 .54234 L p
.43853 .54701 L 1 g
F P
s
P
p
.44194 .55598 m .42822 .54572 L .43853 .54701 L 1 g
F
P
p
.002 w
.43853 .54701 m .43925 .54566 L p
.43559 .53842 L 1 g
F P
s
P
p
.42507 .54733 m .43112 .52221 L .4328 .5283 L 1 g
F
P
p
.002 w
.43644 .54152 m .43191 .54384 L p
.4328 .5283 L 1 g
F P
s
P
p
.002 w
.43191 .54384 m .42507 .54733 L p
.4328 .5283 L 1 g
F P
s
P
p
.002 w
.4328 .5283 m .43346 .52734 L p
.43323 .52075 L 1 g
F P
s
P
p
.43559 .53842 m .43644 .54152 L .43853 .54701 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.45093 .5627 m .43853 .54701 L .4515 .53382 L 1 g
F
P
p
.002 w
.43484 .54234 m .43644 .54152 L p
.43853 .54701 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43191 .52959 L p
1 g
F P
s
P
p
.43925 .54566 m .43191 .52959 L .43429 .53585 L 1 g
F
P
p
.002 w
.43644 .54152 m .4515 .53382 L p
.43853 .54701 L 1 g
F P
s
P
p
.002 w
.43191 .52959 m .43146 .53025 L p
.43429 .53585 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43388 .50941 L p
1 g
F P
s
P
p
.43346 .52734 m .43388 .50941 L .43323 .52075 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.43485 .50826 m .43854 .49963 L .43806 .5006 L 1 g
F
P
p
.002 w
.43529 .50487 m .43436 .49932 L p
.44194 .49197 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43529 .50487 m .45168 .47309 L .43663 .50349 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44269 .49124 m .44339 .4905 L p
.4493 .48483 L 1 g
F P
s
P
p
.002 w
.43604 .50469 m .43529 .50487 L p
.43663 .50349 L 1 g
F P
s
P
p
.002 w
.43565 .50551 m .43529 .50487 L .43604 .50469 L p
1 g
F P
s
P
p
.002 w
.43388 .50941 m .43485 .50826 L p
.44061 .49453 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.43663 .50349 m .44269 .49124 L .46528 .474 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45765 .47674 L p
1 g
F P
s
P
p
.44339 .4905 m .45765 .47674 L .4493 .48483 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.50222 .47504 m .5041 .46464 L p
.53605 .47382 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50935 L p
1 g
F P
s
P
p
.58312 .52173 m .56837 .51432 L .56601 .50856 L 1 g
F
P
p
.002 w
.56229 .49952 m .56558 .50303 L p
.56601 .50856 L 1 g
F P
s
P
p
.002 w
.56558 .50303 m .58312 .52173 L p
.56601 .50856 L 1 g
F P
s
P
p
.002 w
.56607 .50935 m .56515 .50826 L p
.56682 .51908 L 1 g
F P
s
P
p
.55661 .4905 m .56607 .50935 L .56363 .50412 L 1 g
F
P
p
.002 w
.56169 .49992 m .56229 .49952 L p
.56837 .51432 L 1 g
F P
s
P
p
.55661 .4905 m .56677 .51018 L .56643 .50952 L 1 g
F
P
p
.56436 .50532 m .5668 .51023 L .56454 .50568 L 1 g
F
P
p
.55661 .4905 m .56643 .50952 L .56436 .50532 L 1 g
F
P
p
.56643 .50952 m .5668 .51023 L .56436 .50532 L 1 g
F
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56058 .4977 m .56229 .49952 L p
.56062 .49776 L 1 g
F P
s
P
p
.002 w
.56229 .49952 m .56169 .49992 L p
.56062 .49776 L 1 g
F P
s
P
p
.002 w
.56971 .49006 m .56229 .49952 L .56058 .4977 L p
1 g
F P
s
P
p
.56971 .49006 m .56239 .49619 L .55272 .48186 L 1 g
F
P
p
.56239 .49619 m .56058 .4977 L .55746 .4914 L 1 g
F
P
p
.56239 .49619 m .55746 .4914 L .55272 .48186 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55035 .48451 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56058 .4977 m .54005 .47574 L p
.54254 .47694 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54174 .47608 L p
.55035 .48451 L 1 g
F P
s
P
p
.55272 .48186 m .55746 .4914 L .54254 .47694 L 1 g
F
P
p
.55746 .4914 m .56058 .4977 L .54254 .47694 L 1 g
F
P
p
.002 w
.55408 .48222 m .56971 .49006 L p
.54005 .47574 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54244 .47684 L p
1 g
F P
s
P
p
.55035 .48451 m .55834 .49233 L .54244 .47684 L 1 g
F
P
p
.002 w
.55746 .4914 m .55834 .49233 L p
.55035 .48451 L 1 g
F P
s
P
p
.002 w
.54005 .47574 m .56058 .4977 L p
.53938 .47543 L 1 g
F P
s
P
p
.56062 .49776 m .53938 .47543 L .56058 .4977 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56757 .52884 L p
1 g
F P
s
P
p
.56515 .50826 m .56757 .52884 L .56682 .51908 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5523 .50623 m .56169 .49992 L p
.56607 .50935 L 1 g
F P
s
P
p
.56837 .51432 m .56637 .51331 L .56607 .50935 L 1 g
F
P
p
.56637 .51331 m .5523 .50623 L .56607 .50935 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56151 .54709 L p
1 g
F P
s
P
p
.56654 .52734 m .56151 .54709 L .56256 .54428 L 1 g
F
P
p
.57281 .55953 m .55971 .55193 L .56151 .54709 L 1 g
F
P
p
.002 w
.56487 .53807 m .56603 .54123 L p
.56151 .54709 L 1 g
F P
s
P
p
.002 w
.56603 .54123 m .57281 .55953 L p
.56151 .54709 L 1 g
F P
s
P
p
.002 w
.56151 .54709 m .56075 .54566 L p
.55605 .55418 L 1 g
F P
s
P
p
.5643 .53958 m .56178 .5476 L .56421 .54009 L 1 g
F
P
p
.56654 .52734 m .56256 .54428 L .5643 .53958 L 1 g
F
P
p
.56256 .54428 m .56178 .5476 L .5643 .53958 L 1 g
F
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5492 .56307 L p
1 g
F P
s
P
p
.56075 .54566 m .5492 .56307 L .55605 .55418 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.57281 .55953 m .5795 .57961 L p
.54132 .56906 L 1 g
F P
s
P
p
.002 w
.54254 .56822 m .57281 .55953 L p
.54132 .56906 L 1 g
F P
s
P
p
.002 w
.5492 .56307 m .54854 .56129 L p
.53804 .5713 L 1 g
F P
s
P
p
.002 w
.5795 .57961 m .53847 .59148 L .54038 .5697 L p
1 g
F P
s
P
p
.5795 .57961 m .54038 .5697 L .54132 .56906 L 1 g
F
P
p
.53804 .5713 m .53576 .57347 L .54254 .56822 L 1 g
F
P
p
.53804 .5713 m .54254 .56822 L .5492 .56307 L 1 g
F
P
p
.002 w
.54038 .5697 m .54045 .56882 L p
.54132 .56906 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54045 .56882 m .54126 .54121 L p
.56194 .55322 L 1 g
F P
s
P
p
.002 w
.57281 .55953 m .54254 .56822 L p
.56194 .55322 L 1 g
F P
s
P
p
.002 w
.54254 .56822 m .54045 .56882 L p
.56194 .55322 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5492 .56307 L p
1 g
F P
s
P
p
.53576 .57347 m .5322 .57686 L .5492 .56307 L 1 g
F
P
p
.002 w
.5492 .56307 m .54998 .56518 L p
.55605 .55418 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.58312 .52173 m .60089 .5406 L p
.56581 .53516 L 1 g
F P
s
P
p
.002 w
.56655 .53289 m .58312 .52173 L p
.56581 .53516 L 1 g
F P
s
P
p
.002 w
.56366 .53483 m .5523 .50623 L p
.57093 .5156 L 1 g
F P
s
P
p
.002 w
.58312 .52173 m .56655 .53289 L p
.57093 .5156 L 1 g
F P
s
P
p
.002 w
.56757 .52884 m .56654 .52734 L p
.56421 .54009 L 1 g
F P
s
P
p
.002 w
.60089 .5406 m .57281 .55953 L .56487 .53807 L p
1 g
F P
s
P
p
.60089 .5406 m .56487 .53807 L .56581 .53516 L 1 g
F
P
p
.56421 .54009 m .56291 .54725 L .56655 .53289 L 1 g
F
P
p
.56421 .54009 m .56655 .53289 L .56757 .52884 L 1 g
F
P
p
.002 w
.56487 .53807 m .56366 .53483 L p
.56581 .53516 L 1 g
F P
s
P
p
.002 w
.56655 .53289 m .56366 .53483 L p
.57093 .5156 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56757 .52884 L p
1 g
F P
s
P
p
.56291 .54725 m .56257 .5491 L .56757 .52884 L 1 g
F
P
p
.56151 .54709 m .54126 .54121 L .56487 .53807 L 1 g
F
P
p
.55971 .55193 m .55838 .55115 L .56151 .54709 L 1 g
F
P
p
.55838 .55115 m .54126 .54121 L .56151 .54709 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56151 .54709 L p
1 g
F P
s
P
p
.55605 .55418 m .54998 .56518 L .56151 .54709 L 1 g
F
P
p
.002 w
.54126 .54121 m .56366 .53483 L .56487 .53807 L p
1 g
F P
s
P
p
.002 w
.56151 .54709 m .56178 .5476 L p
.56256 .54428 L 1 g
F P
s
P
p
.002 w
.56178 .5476 m .56257 .5491 L p
.56421 .54009 L 1 g
F P
s
P
p
.002 w
.56366 .53483 m .56655 .53289 L p
.56581 .53516 L 1 g
F P
s
P
p
.002 w
.56757 .52884 m .56854 .53025 L p
.56682 .51908 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56607 .50935 L p
1 g
F P
s
P
p
.56682 .51908 m .56854 .53025 L .56607 .50935 L 1 g
F
P
p
.002 w
.56607 .50935 m .56677 .51018 L p
.56363 .50412 L 1 g
F P
s
P
p
.002 w
.5523 .50623 m .53938 .47543 L p
.56062 .49776 L 1 g
F P
s
P
p
.002 w
.56169 .49992 m .5523 .50623 L p
.56062 .49776 L 1 g
F P
s
P
p
.002 w
.56677 .51018 m .5668 .51023 L p
.56643 .50952 L 1 g
F P
s
P
p
.002 w
.5668 .51023 m .56713 .51061 L p
.56454 .50568 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47684 L p
1 g
F P
s
P
p
.52214 .46667 m .54244 .47684 L .54235 .4768 L 1 g
F
P
p
.52214 .46667 m .54244 .47685 L .54043 .47591 L 1 g
F
P
p
.54041 .47591 m .54258 .477 L .54237 .4769 L 1 g
F
P
p
.52214 .46667 m .5405 .47595 L .54041 .47591 L 1 g
F
P
p
.5405 .47595 m .54258 .477 L .54041 .47591 L 1 g
F
P
p
.002 w
.5523 .50623 m .54081 .50947 L .5391 .4753 L p
1 g
F P
s
P
p
.002 w
.53938 .47543 m .5523 .50623 L p
.5391 .4753 L 1 g
F P
s
P
p
.002 w
.53786 .4747 m .50222 .47504 L p
.53605 .47382 L 1 g
F P
s
P
p
.002 w
.54081 .50947 m .52903 .5089 L .53892 .47521 L p
1 g
F P
s
P
p
.52214 .46667 m .54055 .47598 L .53436 .473 L 1 g
F
P
p
.002 w
.53892 .47521 m .53907 .47469 L .5391 .4753 L p
1 g
F P
s
P
p
.002 w
.5391 .4753 m .54081 .50947 L p
.53892 .47521 L 1 g
F P
s
P
p
.002 w
.52903 .5089 m .51824 .50454 L .53876 .47513 L p
1 g
F P
s
P
p
.002 w
.53876 .47513 m .53907 .47469 L .53892 .47521 L p
1 g
F P
s
P
p
.002 w
.53892 .47521 m .52903 .5089 L p
.53876 .47513 L 1 g
F P
s
P
p
.002 w
.51824 .50454 m .50959 .49686 L .53859 .47505 L p
1 g
F P
s
P
p
.002 w
.53859 .47505 m .53907 .47469 L .53876 .47513 L p
1 g
F P
s
P
p
.002 w
.53876 .47513 m .51824 .50454 L p
.53859 .47505 L 1 g
F P
s
P
p
.53884 .47517 m .54237 .4769 L .5386 .47506 L 1 g
F
P
p
.53892 .47521 m .53898 .47524 L .53884 .47517 L 1 g
F
P
p
.53898 .47524 m .54237 .4769 L .53884 .47517 L 1 g
F
P
p
.54055 .47598 m .54077 .47609 L .53892 .47521 L 1 g
F
P
p
.54077 .47609 m .54237 .4769 L .53892 .47521 L 1 g
F
P
p
.002 w
.50959 .49686 m .50405 .48666 L .53834 .47494 L p
1 g
F P
s
P
p
.002 w
.53834 .47494 m .53907 .47469 L .53859 .47505 L p
1 g
F P
s
P
p
.002 w
.53859 .47505 m .50959 .49686 L p
.53834 .47494 L 1 g
F P
s
P
p
.54055 .47598 m .53876 .47514 L .53436 .473 L 1 g
F
P
p
.002 w
.50405 .48666 m .50222 .47504 L .53786 .4747 L p
1 g
F P
s
P
p
.002 w
.53786 .4747 m .53907 .47469 L .53834 .47494 L p
1 g
F P
s
P
p
.002 w
.53834 .47494 m .50405 .48666 L p
.53786 .4747 L 1 g
F P
s
P
p
.53834 .47494 m .5386 .47506 L .53821 .47487 L 1 g
F
P
p
.53876 .47514 m .53868 .4751 L .53834 .47494 L 1 g
F
P
p
.53868 .4751 m .5386 .47506 L .53834 .47494 L 1 g
F
P
p
.53876 .47514 m .53821 .47487 L .53436 .473 L 1 g
F
P
p
.54237 .4769 m .54259 .47701 L .53526 .47344 L 1 g
F
P
p
.54237 .4769 m .53526 .47344 L .53436 .473 L 1 g
F
P
p
.002 w
.51174 .4657 m .53526 .47344 L p
.5041 .46464 L 1 g
F P
s
P
p
.002 w
.53526 .47344 m .53907 .47469 L p
.53605 .47382 L 1 g
F P
s
P
p
.5041 .46464 m .53526 .47344 L .53605 .47382 L 1 g
F
P
p
.002 w
.5391 .4753 m .53907 .47469 L .53938 .47543 L p
1 g
F P
s
P
p
.002 w
.54005 .47574 m .53907 .47469 L .55408 .48222 L p
1 g
F P
s
P
p
.002 w
.54244 .47684 m .54244 .47685 L p
.54235 .4768 L 1 g
F P
s
P
p
.002 w
.54244 .47685 m .54258 .477 L p
.54043 .47591 L 1 g
F P
s
P
p
.002 w
.53938 .47543 m .53907 .47469 L .54005 .47574 L p
1 g
F P
s
P
p
.002 w
.53907 .47469 m .53786 .4747 L p
.53605 .47382 L 1 g
F P
s
P
p
.002 w
.54258 .477 m .54259 .47701 L p
.54237 .4769 L 1 g
F P
s
P
p
.002 w
.53526 .47344 m .51174 .4657 L p
.52245 .46719 L 1 g
F P
s
P
p
.002 w
.54259 .47701 m .54302 .47747 L p
.53436 .473 L 1 g
F P
s
P
p
.002 w
.53075 .46834 m .53907 .47469 L .53526 .47344 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52245 .46719 L p
1 g
F P
s
P
p
.002 w
.52245 .46719 m .52214 .46667 L p
.53436 .473 L 1 g
F P
s
P
p
.53436 .473 m .54302 .47747 L .52245 .46719 L 1 g
F
P
p
.002 w
.51019 .45265 m .53075 .46834 L p
.52096 .46646 L 1 g
F P
s
P
p
.002 w
.50434 .46327 m .50648 .4594 L p
.52096 .46646 L 1 g
F P
s
P
p
.002 w
.50648 .4594 m .51019 .45265 L p
.52096 .46646 L 1 g
F P
s
P
p
.52245 .46719 m .53075 .46834 L .53526 .47344 L 1 g
F
P
p
.5 .4634 m .52245 .46719 L .52215 .46715 L 1 g
F
P
p
.5 .4634 m .52246 .4672 L .51265 .46583 L 1 g
F
P
p
.002 w
.46528 .474 m .46544 .47314 L p
.50101 .46412 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .52228 .4677 L p
.5 .4634 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .4634 L p
.52228 .4677 L 1 g
F P
s
P
p
.50115 .46414 m .50101 .46412 L .50388 .46339 L 1 g
F
P
p
.46528 .474 m .50101 .46412 L .50115 .46414 L 1 g
F
P
p
.46528 .474 m .50388 .46339 L .50396 .46338 L 1 g
F
P
p
.002 w
.47756 .46718 m .47786 .46667 L p
.48884 .46555 L 1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49342 .45938 m .50434 .46327 L p
.50388 .46339 L 1 g
F P
s
P
p
.46544 .47314 m .47756 .46718 L .50388 .46339 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46395 L .48884 .46555 L 1 g
F
P
p
.47756 .46718 m .49342 .45938 L .50388 .46339 L 1 g
F
P
p
.002 w
.5 .46395 m .5 .46442 L p
.48884 .46555 L 1 g
F P
s
P
p
.002 w
.50434 .46327 m .50222 .47504 L .46528 .474 L p
1 g
F P
s
P
p
.002 w
.52228 .4677 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.002 w
.51174 .4657 m .50434 .46327 L p
.53075 .46834 L 1 g
F P
s
P
p
.002 w
.52245 .46719 m .52246 .4672 L p
.52215 .46715 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52282 .46778 L p
.51265 .46583 L 1 g
F P
s
P
p
.002 w
.5041 .46464 m .50434 .46327 L .51174 .4657 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46718 L p
1 g
F P
s
P
p
.48884 .46555 m .5 .46442 L .47756 .46718 L 1 g
F
P
p
.50396 .46338 m .50388 .46339 L .50434 .46327 L 1 g
F
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.46923 .47127 L 1 g
F P
s
P
p
.46923 .47127 m .46653 .4726 L .45765 .47674 L 1 g
F
P
p
.47156 .47025 m .46381 .4739 L .45765 .47674 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.44269 .49124 m .45765 .47674 L .46528 .474 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47723 .46771 L p
1 g
F P
s
P
p
.45826 .47608 m .47723 .46771 L .47491 .46878 L 1 g
F
P
p
.002 w
.46079 .4737 m .46381 .4739 L p
.45765 .47674 L 1 g
F P
s
P
p
.002 w
.46381 .4739 m .46528 .474 L p
.45765 .47674 L 1 g
F P
s
P
p
.002 w
.47723 .46771 m .47718 .46778 L p
.47491 .46878 L 1 g
F P
s
P
p
.002 w
.46544 .47314 m .46936 .45079 L .49342 .45938 L p
1 g
F P
s
P
p
.46923 .47127 m .47156 .47025 L .46653 .4726 L 1 g
F
P
p
.002 w
.46544 .47314 m .46528 .474 L .46381 .4739 L p
1 g
F P
s
P
p
.47156 .47025 m .47491 .46878 L .46381 .4739 L 1 g
F
P
p
.002 w
.46936 .45079 m .46544 .47314 L p
.42969 .47162 L 1 g
F P
s
P
p
.002 w
.46381 .4739 m .42969 .47162 L p
.46544 .47314 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.47491 .46878 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.002 w
.45168 .47309 m .46079 .4737 L p
.45765 .47674 L 1 g
F P
s
P
p
.44269 .49124 m .44757 .4814 L .45765 .47674 L 1 g
F
P
p
.44757 .4814 m .45168 .47309 L .45765 .47674 L 1 g
F
P
p
.002 w
.45765 .47674 m .45698 .47747 L p
.4493 .48483 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44269 .49124 L p
1 g
F P
s
P
p
.4493 .48483 m .45698 .47747 L .44269 .49124 L 1 g
F
P
p
.002 w
.42969 .47162 m .45168 .47309 L p
.44194 .49197 L 1 g
F P
s
P
p
.002 w
.43436 .49932 m .42969 .47162 L p
.44194 .49197 L 1 g
F P
s
P
p
.43509 .50674 m .43529 .50487 L .43533 .5062 L 1 g
F
P
p
.43378 .51113 m .43456 .50792 L .4328 .5283 L 1 g
F
P
p
.43456 .50792 m .43529 .50487 L .43509 .50674 L 1 g
F
P
p
.43456 .50792 m .43509 .50674 L .4328 .5283 L 1 g
F
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43529 .50487 m .4515 .53382 L .43644 .54152 L p
1 g
F P
s
P
p
.002 w
.42507 .54733 m .40417 .51048 L .43529 .50487 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44061 .49453 L p
.43993 .49417 L 1 g
F P
s
P
p
.002 w
.44061 .49453 m .44166 .49233 L .44154 .49246 L p
1 g
F P
s
P
p
.002 w
.44154 .49246 m .43993 .49417 L p
.44061 .49453 L 1 g
F P
s
P
p
.002 w
.44061 .49453 m .43287 .51061 L .43344 .50994 L p
1 g
F P
s
P
p
.002 w
.43344 .50994 m .43388 .50941 L p
.43579 .50518 L 1 g
F P
s
P
p
.43579 .50518 m .44061 .49453 L .43344 .50994 L 1 g
F
P
p
.43806 .5006 m .43929 .49788 L .43857 .49938 L 1 g
F
P
p
.43854 .49963 m .43929 .49788 L .43806 .5006 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.46528 .474 m .469 .49684 L .43604 .50469 L p
1 g
F P
s
P
p
.43663 .50349 m .46528 .474 L .43604 .50469 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.4515 .53382 m .43565 .50551 L p
.469 .49684 L 1 g
F P
s
P
p
.002 w
.43604 .50469 m .469 .49684 L p
.43565 .50551 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44061 .49453 L p
.43857 .49938 L 1 g
F P
s
P
p
.43929 .49788 m .44166 .49233 L .43857 .49938 L 1 g
F
P
p
.4328 .5283 m .43509 .50674 L .43644 .54152 L 1 g
F
P
p
.43509 .50674 m .43533 .5062 L .43644 .54152 L 1 g
F
P
p
.43112 .52221 m .43378 .51113 L .4328 .5283 L 1 g
F
P
p
.002 w
.43388 .50941 m .43287 .51061 L p
.43323 .52075 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4328 .5283 L p
1 g
F P
s
P
p
.43323 .52075 m .43287 .51061 L .4328 .5283 L 1 g
F
P
p
.43559 .53842 m .43429 .53585 L .43644 .54152 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43853 .54701 L p
1 g
F P
s
P
p
.43429 .53585 m .43146 .53025 L .43853 .54701 L 1 g
F
P
p
.45093 .5627 m .44194 .55598 L .43853 .54701 L 1 g
F
P
p
.002 w
.43853 .54701 m .43743 .5491 L p
.44621 .55673 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45093 .5627 L p
1 g
F P
s
P
p
.44621 .55673 m .43743 .5491 L .45093 .5627 L 1 g
F
P
p
.002 w
.45093 .5627 m .45032 .56436 L p
.45744 .56757 L 1 g
F P
s
P
p
.002 w
.45694 .57469 m .42507 .54733 L .42822 .54572 L p
1 g
F P
s
P
p
.46872 .57265 m .45032 .56436 L .45639 .56772 L 1 g
F
P
p
.002 w
.46125 .57042 m .4764 .55541 L p
.47413 .57755 L 1 g
F P
s
P
p
.002 w
.45032 .56436 m .45002 .56518 L p
.45639 .56772 L 1 g
F P
s
P
p
.002 w
.4515 .53382 m .4764 .55541 L .46125 .57042 L p
1 g
F P
s
P
p
.45583 .56637 m .4515 .53382 L .46125 .57042 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46835 .57435 L p
1 g
F P
s
P
p
.45639 .56772 m .45002 .56518 L .46835 .57435 L 1 g
F
P
p
.47735 .57934 m .47413 .57755 L .48765 .5798 L 1 g
F
P
p
.46785 .57891 m .47413 .57755 L .47735 .57934 L 1 g
F
P
p
.48909 .58021 m .48765 .5798 L .49068 .58031 L 1 g
F
P
p
.46785 .57891 m .48765 .5798 L .48909 .58021 L 1 g
F
P
p
.002 w
.46835 .57435 m .4678 .57686 L p
.48111 .57795 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58021 L p
1 g
F P
s
P
p
.48111 .57795 m .4678 .57686 L .48909 .58021 L 1 g
F
P
p
.002 w
.48909 .58021 m .48889 .583 L p
.49961 .58085 L 1 g
F P
s
P
p
.002 w
.4764 .55541 m .50715 .56745 L .50054 .58091 L p
1 g
F P
s
P
p
.49068 .58031 m .4764 .55541 L .50054 .58091 L 1 g
F
P
p
.002 w
.50054 .58091 m .50715 .56745 L p
.52261 .57931 L 1 g
F P
s
P
p
.53847 .59148 m .50054 .58091 L .52261 .57931 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51091 .58016 L p
1 g
F P
s
P
p
.49863 .58105 m .48889 .583 L .51091 .58016 L 1 g
F
P
p
.002 w
.51091 .58016 m .51111 .583 L p
.52354 .57662 L 1 g
F P
s
P
p
.53165 .57435 m .50715 .56745 L .54038 .5697 L 1 g
F
P
p
.52029 .57753 m .50715 .56745 L .53165 .57435 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53165 .57435 L p
1 g
F P
s
P
p
.52354 .57662 m .51111 .583 L .53165 .57435 L 1 g
F
P
p
.002 w
.50715 .56745 m .54045 .56882 L .54038 .5697 L p
1 g
F P
s
P
p
.002 w
.53165 .57435 m .5319 .57549 L p
.53587 .5721 L 1 g
F P
s
P
p
.002 w
.5319 .57549 m .5322 .57686 L p
.53804 .5713 L 1 g
F P
s
P
p
.002 w
.54045 .56882 m .54254 .56822 L p
.54132 .56906 L 1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.60089 .5406 m .62184 .51401 L .64168 .5219 L p
1 g
F P
s
P
p
.002 w
.65651 .4819 m .64168 .5219 L .62184 .51401 L p
1 g
F P
s
P
p
.002 w
.65793 .43963 m .64556 .39948 L .66155 .38271 L p
1 g
F P
s
P
p
.002 w
.63207 .34279 m .66155 .38271 L .64556 .39948 L p
1 g
F P
s
P
p
.002 w
.36778 .46334 m .3767 .51353 L .35372 .51403 L p
1 g
F P
s
P
p
.002 w
.35372 .51403 m .34352 .45781 L .36778 .46334 L p
1 g
F P
s
P
p
.002 w
.63207 .34279 m .59034 .31489 L .59281 .29171 L p
1 g
F P
s
P
p
.002 w
.53724 .27759 m .59281 .29171 L .59034 .31489 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.42467 .30717 m .38091 .3479 L .36466 .33343 L p
1 g
F P
s
P
p
.002 w
.36466 .33343 m .4117 .28964 L .42467 .30717 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47893 .28283 m .42467 .30717 L .4117 .28964 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.62184 .51401 m .63346 .48247 L .65651 .4819 L p
1 g
F P
s
P
p
.002 w
.65793 .43963 m .65651 .4819 L .63346 .48247 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.40417 .51048 m .42507 .54733 L .4016 .55698 L p
1 g
F P
s
P
p
.002 w
.4016 .55698 m .3767 .51353 L .40417 .51048 L p
1 g
F P
s
P
p
.002 w
.37622 .41197 m .36778 .46334 L .34352 .45781 L p
1 g
F P
s
P
p
.002 w
.34352 .45781 m .35282 .40019 L .37622 .41197 L p
1 g
F P
s
P
p
.002 w
.64556 .39948 m .62045 .36577 L .63207 .34279 L p
1 g
F P
s
P
p
.002 w
.59034 .31489 m .63207 .34279 L .62045 .36577 L p
1 g
F P
s
P
p
.002 w
.63346 .48247 m .63447 .44921 L .65793 .43963 L p
1 g
F P
s
P
p
.002 w
.64556 .39948 m .65793 .43963 L .63447 .44921 L p
1 g
F P
s
P
p
.002 w
.59034 .31489 m .54073 .30247 L .53724 .27759 L p
1 g
F P
s
P
p
.002 w
.47893 .28283 m .53724 .27759 L .54073 .30247 L p
1 g
F P
s
P
p
.002 w
.40135 .36537 m .37622 .41197 L .35282 .40019 L p
1 g
F P
s
P
p
.002 w
.35282 .40019 m .38091 .3479 L .40135 .36537 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62184 .51401 m .60089 .5406 L .58312 .52173 L p
1 g
F P
s
P
p
.002 w
.54073 .30247 m .48873 .30728 L .47893 .28283 L p
1 g
F P
s
P
p
.002 w
.42467 .30717 m .47893 .28283 L .48873 .30728 L p
1 g
F P
s
P
p
.004 w
.44728 .30337 m
.4477 .30439 L
s
P
p
.004 w
.44517 .29829 m
.44728 .30337 L
s
P
p
.004 w
.44102 .28827 m
.44517 .29829 L
s
P
p
.004 w
.43399 .27132 m
.44102 .28827 L
s
P
p
.002 w
.63447 .44921 m .62463 .41771 L .64556 .39948 L p
1 g
F P
s
P
p
.002 w
.62045 .36577 m .64556 .39948 L .62463 .41771 L p
1 g
F P
s
P
p
.002 w
.39681 .46801 m .40417 .51048 L .3767 .51353 L p
1 g
F P
s
P
p
.002 w
.3767 .51353 m .36778 .46334 L .39681 .46801 L p
1 g
F P
s
P
p
.002 w
.58312 .52173 m .59761 .50331 L .62184 .51401 L p
1 g
F P
s
P
p
.002 w
.63346 .48247 m .62184 .51401 L .59761 .50331 L p
1 g
F P
s
P
p
.002 w
.62045 .36577 m .58504 .34233 L .59034 .31489 L p
1 g
F P
s
P
p
.002 w
.54073 .30247 m .59034 .31489 L .58504 .34233 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.44037 .32906 m .40135 .36537 L .38091 .3479 L p
1 g
F P
s
P
p
.002 w
.38091 .3479 m .42467 .30717 L .44037 .32906 L p
1 g
F P
s
P
p
.002 w
.48873 .30728 m .44037 .32906 L .42467 .30717 L p
1 g
F P
s
P
p
.004 w
.45517 .32239 m
.5 .43051 L
s
P
p
.002 w
.51825 .54018 m .54126 .54121 L .54045 .56882 L p
1 g
F P
s
P
p
.002 w
.54045 .56882 m .50715 .56745 L .51825 .54018 L p
1 g
F P
s
P
p
.002 w
.59761 .50331 m .6056 .48146 L .63346 .48247 L p
1 g
F P
s
P
p
.002 w
.63447 .44921 m .63346 .48247 L .6056 .48146 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49708 .53177 m .51825 .54018 L .50715 .56745 L p
1 g
F P
s
P
p
.002 w
.50715 .56745 m .4764 .55541 L .49708 .53177 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.62463 .41771 m .6048 .39138 L .62045 .36577 L p
1 g
F P
s
P
p
.002 w
.58504 .34233 m .62045 .36577 L .6048 .39138 L p
1 g
F P
s
P
p
.002 w
.40408 .42463 m .39681 .46801 L .36778 .46334 L p
1 g
F P
s
P
p
.002 w
.36778 .46334 m .37622 .41197 L .40408 .42463 L p
1 g
F P
s
P
p
.002 w
.6056 .48146 m .60621 .45848 L .63447 .44921 L p
1 g
F P
s
P
p
.002 w
.62463 .41771 m .63447 .44921 L .60621 .45848 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.58504 .34233 m .54306 .33201 L .54073 .30247 L p
1 g
F P
s
P
p
.002 w
.48873 .30728 m .54073 .30247 L .54306 .33201 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.48003 .51681 m .49708 .53177 L .4764 .55541 L p
1 g
F P
s
P
p
.002 w
.4764 .55541 m .4515 .53382 L .48003 .51681 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.60621 .45848 m .59931 .4368 L .62463 .41771 L p
1 g
F P
s
P
p
.002 w
.6048 .39138 m .62463 .41771 L .59931 .4368 L p
1 g
F P
s
P
p
.002 w
.42538 .38532 m .40408 .42463 L .37622 .41197 L p
1 g
F P
s
P
p
.002 w
.37622 .41197 m .40135 .36537 L .42538 .38532 L p
1 g
F P
s
P
p
.002 w
.42969 .47162 m .43529 .50487 L .40417 .51048 L p
1 g
F P
s
P
p
.002 w
.40417 .51048 m .39681 .46801 L .42969 .47162 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.54306 .33201 m .49914 .33621 L .48873 .30728 L p
1 g
F P
s
P
p
.002 w
.44037 .32906 m .48873 .30728 L .49914 .33621 L p
1 g
F P
s
P
p
.002 w
.59761 .50331 m .58312 .52173 L .56229 .49952 L p
1 g
F P
s
P
p
.002 w
.6048 .39138 m .57697 .37318 L .58504 .34233 L p
1 g
F P
s
P
p
.002 w
.54306 .33201 m .58504 .34233 L .57697 .37318 L p
1 g
F P
s
P
p
.002 w
.54081 .50947 m .5523 .50623 L .56366 .53483 L p
1 g
F P
s
P
p
.002 w
.56366 .53483 m .54126 .54121 L .54081 .50947 L p
1 g
F P
s
P
p
.002 w
.56229 .49952 m .56971 .49006 L .59761 .50331 L p
1 g
F P
s
P
p
.002 w
.6056 .48146 m .59761 .50331 L .56971 .49006 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.45834 .35466 m .42538 .38532 L .40135 .36537 L p
1 g
F P
s
P
p
.002 w
.40135 .36537 m .44037 .32906 L .45834 .35466 L p
1 g
F P
s
P
p
.002 w
.52903 .5089 m .54081 .50947 L .54126 .54121 L p
1 g
F P
s
P
p
.002 w
.54126 .54121 m .51825 .54018 L .52903 .5089 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.49914 .33621 m .45834 .35466 L .44037 .32906 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.56971 .49006 m .57377 .47885 L .6056 .48146 L p
1 g
F P
s
P
p
.002 w
.60621 .45848 m .6056 .48146 L .57377 .47885 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.469 .49684 m .48003 .51681 L .4515 .53382 L p
1 g
F P
s
P
p
.002 w
.59931 .4368 m .58556 .41876 L .6048 .39138 L p
1 g
F P
s
P
p
.002 w
.57697 .37318 m .6048 .39138 L .58556 .41876 L p
1 g
F P
s
P
p
.002 w
.51824 .50454 m .52903 .5089 L .51825 .54018 L p
1 g
F P
s
P
p
.002 w
.51825 .54018 m .49708 .53177 L .51824 .50454 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57377 .47885 m .57403 .46709 L .60621 .45848 L p
1 g
F P
s
P
p
.002 w
.59931 .4368 m .60621 .45848 L .57403 .46709 L p
1 g
F P
s
P
p
.002 w
.43551 .43774 m .42969 .47162 L .39681 .46801 L p
1 g
F P
s
P
p
.002 w
.39681 .46801 m .40408 .42463 L .43551 .43774 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.57697 .37318 m .5441 .36526 L .54306 .33201 L p
1 g
F P
s
P
p
.002 w
.49914 .33621 m .54306 .33201 L .5441 .36526 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.50959 .49686 m .51824 .50454 L .49708 .53177 L p
1 g
F P
s
P
p
.002 w
.49708 .53177 m .48003 .51681 L .50959 .49686 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57403 .46709 m .57045 .45604 L .59931 .4368 L p
1 g
F P
s
P
p
.002 w
.58556 .41876 m .59931 .4368 L .57045 .45604 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.45221 .40707 m .43551 .43774 L .40408 .42463 L p
1 g
F P
s
P
p
.002 w
.40408 .42463 m .42538 .38532 L .45221 .40707 L p
1 g
F P
s
P
p
.002 w
.58556 .41876 m .56636 .40636 L .57697 .37318 L p
1 g
F P
s
P
p
.002 w
.5441 .36526 m .57697 .37318 L .56636 .40636 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.5441 .36526 m .50979 .36867 L .49914 .33621 L p
1 g
F P
s
P
p
.002 w
.45834 .35466 m .49914 .33621 L .50979 .36867 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57377 .47885 m .56971 .49006 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.50405 .48666 m .50959 .49686 L .48003 .51681 L p
1 g
F P
s
P
p
.002 w
.48003 .51681 m .469 .49684 L .50405 .48666 L p
1 g
F P
s
P
p
.002 w
.57403 .46709 m .57377 .47885 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.47795 .38314 m .45221 .40707 L .42538 .38532 L p
1 g
F P
s
P
p
.002 w
.42538 .38532 m .45834 .35466 L .47795 .38314 L p
1 g
F P
s
P
p
.002 w
.50979 .36867 m .47795 .38314 L .45834 .35466 L p
1 g
F P
s
P
p
.002 w
.57045 .45604 m .56338 .44689 L .58556 .41876 L p
1 g
F P
s
P
p
.002 w
.56636 .40636 m .58556 .41876 L .56338 .44689 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.57045 .45604 m .57403 .46709 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.42969 .47162 m .43551 .43774 L .46936 .45079 L p
1 g
F P
s
P
p
.002 w
.56636 .40636 m .54377 .40104 L .5441 .36526 L p
1 g
F P
s
P
p
.002 w
.50979 .36867 m .5441 .36526 L .54377 .40104 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56338 .44689 m .57045 .45604 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.50222 .47504 m .50405 .48666 L .469 .49684 L p
1 g
F P
s
P
p
.002 w
.469 .49684 m .46528 .474 L .50222 .47504 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56338 .44689 m .55357 .44064 L .56636 .40636 L p
1 g
F P
s
P
p
.002 w
.54377 .40104 m .56636 .40636 L .55357 .44064 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55357 .44064 m .56338 .44689 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.48085 .42981 m .46936 .45079 L .43551 .43774 L p
1 g
F P
s
P
p
.002 w
.43551 .43774 m .45221 .40707 L .48085 .42981 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.54377 .40104 m .52027 .40347 L .50979 .36867 L p
1 g
F P
s
P
p
.002 w
.47795 .38314 m .50979 .36867 L .52027 .40347 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54208 .438 m .55357 .44064 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.53016 .43928 m .54208 .438 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.51912 .44435 m .53016 .43928 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.002 w
.51019 .45265 m .51912 .44435 L .53907 .47469 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51534 .44786 L
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.55357 .44064 m .54208 .438 L .54377 .40104 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.49848 .41342 m .48085 .42981 L .45221 .40707 L p
1 g
F P
s
P
p
.002 w
.45221 .40707 m .47795 .38314 L .49848 .41342 L p
1 g
F P
s
P
p
.002 w
.52027 .40347 m .54377 .40104 L .54208 .438 L p
1 g
F P
s
P
p
.002 w
.52027 .40347 m .49848 .41342 L .47795 .38314 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.54208 .438 m .53016 .43928 L .52027 .40347 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51019 .45265 m .50434 .46327 L .46936 .45079 L p
1 g
F P
s
P
p
.002 w
.46936 .45079 m .48085 .42981 L .51019 .45265 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.49848 .41342 m .52027 .40347 L .53016 .43928 L p
1 g
F P
s
P
p
.002 w
.53016 .43928 m .51912 .44435 L .49848 .41342 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.004 w
.53907 .47469 m
.54033 .47611 L
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.51912 .44435 m .51019 .45265 L .48085 .42981 L p
1 g
F P
s
P
p
.002 w
.48085 .42981 m .49848 .41342 L .51912 .44435 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.54033 .47611 m
.5632 .50197 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .41583 .22753 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .5632 .50197 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.624031)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.624031)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48577 .4838 m .51675 .46764 L .49991 .44481 L p
1 g
F P
s
P
p
.002 w
.49991 .44481 m .47596 .45724 L .48577 .4838 L p
1 g
F P
s
P
p
.002 w
.5192 .42577 m .49991 .44481 L .51675 .46764 L p
1 g
F P
s
P
p
.002 w
.47596 .45724 m .49991 .44481 L .48312 .42169 L p
1 g
F P
s
P
p
.002 w
.49991 .44481 m .5192 .42577 L .49628 .40869 L p
1 g
F P
s
P
p
.002 w
.49628 .40869 m .48312 .42169 L .49991 .44481 L p
1 g
F P
s
P
p
.002 w
.48312 .42169 m .46676 .43014 L .47596 .45724 L p
1 g
F P
s
P
p
.002 w
.46676 .43014 m .48312 .42169 L .46668 .3987 L p
1 g
F P
s
P
p
.002 w
.48312 .42169 m .49628 .40869 L .47337 .39209 L p
1 g
F P
s
P
p
.002 w
.47337 .39209 m .46668 .3987 L .48312 .42169 L p
1 g
F P
s
P
p
.002 w
.51675 .46764 m .54173 .44301 L .5192 .42577 L p
1 g
F P
s
P
p
.002 w
.53187 .40203 m .5192 .42577 L .54173 .44301 L p
1 g
F P
s
P
p
.002 w
.5192 .42577 m .53187 .40203 L .50487 .39248 L p
1 g
F P
s
P
p
.002 w
.50487 .39248 m .49628 .40869 L .5192 .42577 L p
1 g
F P
s
P
p
.002 w
.49628 .40869 m .50487 .39248 L .47771 .38383 L p
1 g
F P
s
P
p
.002 w
.47771 .38383 m .47337 .39209 L .49628 .40869 L p
1 g
F P
s
P
p
.002 w
.44974 .46175 m .47596 .45724 L .46676 .43014 L p
1 g
F P
s
P
p
.002 w
.46676 .43014 m .44888 .43313 L .44974 .46175 L p
1 g
F P
s
P
p
.002 w
.44888 .43313 m .46676 .43014 L .45835 .40298 L p
1 g
F P
s
P
p
.002 w
.46668 .3987 m .45835 .40298 L .46676 .43014 L p
1 g
F P
s
P
p
.002 w
.45183 .48981 m .48577 .4838 L .47596 .45724 L p
1 g
F P
s
P
p
.002 w
.47596 .45724 m .44974 .46175 L .45183 .48981 L p
1 g
F P
s
P
p
.002 w
.50797 .37472 m .50487 .39248 L .53187 .40203 L p
1 g
F P
s
P
p
.002 w
.50487 .39248 m .50797 .37472 L .47923 .37481 L p
1 g
F P
s
P
p
.002 w
.47923 .37481 m .47771 .38383 L .50487 .39248 L p
1 g
F P
s
P
p
.002 w
.49604 .50933 m .53333 .48977 L .51675 .46764 L p
1 g
F P
s
P
p
.002 w
.51675 .46764 m .48577 .4838 L .49604 .50933 L p
1 g
F P
s
P
p
.002 w
.54173 .44301 m .51675 .46764 L .53333 .48977 L p
1 g
F P
s
P
p
.002 w
.54173 .44301 m .55821 .41232 L .53187 .40203 L p
1 g
F P
s
P
p
.002 w
.53655 .37599 m .53187 .40203 L .55821 .41232 L p
1 g
F P
s
P
p
.002 w
.53187 .40203 m .53655 .37599 L .50797 .37472 L p
1 g
F P
s
P
p
.002 w
.53333 .48977 m .56344 .4601 L .54173 .44301 L p
1 g
F P
s
P
p
.002 w
.55821 .41232 m .54173 .44301 L .56344 .4601 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .45835 .40298 L .46668 .3987 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .46668 .3987 L .47337 .39209 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .47337 .39209 L .47771 .38383 L closepath p
1 g
F P
s
P
p
.002 w
.45835 .40298 m .44926 .40445 L .44888 .43313 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .44926 .40445 L .45835 .40298 L closepath p
1 g
F P
s
P
p
.002 w
.42394 .45778 m .44974 .46175 L .44888 .43313 L p
1 g
F P
s
P
p
.002 w
.44888 .43313 m .43134 .43031 L .42394 .45778 L p
1 g
F P
s
P
p
.002 w
.43134 .43031 m .44888 .43313 L .44926 .40445 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .47771 .38383 L .47923 .37481 L closepath p
1 g
F P
s
P
p
.002 w
.45514 .51676 m .49604 .50933 L .48577 .4838 L p
1 g
F P
s
P
p
.002 w
.48577 .4838 m .45183 .48981 L .45514 .51676 L p
1 g
F P
s
P
p
.002 w
.5052 .35727 m .50797 .37472 L .53655 .37599 L p
1 g
F P
s
P
p
.002 w
.50797 .37472 m .5052 .35727 L .47776 .36598 L p
1 g
F P
s
P
p
.002 w
.47776 .36598 m .47923 .37481 L .50797 .37472 L p
1 g
F P
s
P
p
.002 w
.44926 .40445 m .44037 .40296 L .43134 .43031 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .44037 .40296 L .44926 .40445 L closepath p
1 g
F P
s
P
p
.002 w
.41833 .48487 m .45183 .48981 L .44974 .46175 L p
1 g
F P
s
P
p
.002 w
.44974 .46175 m .42394 .45778 L .41833 .48487 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .47923 .37481 L .47776 .36598 L closepath p
1 g
F P
s
P
p
.002 w
.56344 .4601 m .58341 .42317 L .55821 .41232 L p
1 g
F P
s
P
p
.002 w
.56446 .37861 m .55821 .41232 L .58341 .42317 L p
1 g
F P
s
P
p
.002 w
.55821 .41232 m .56446 .37861 L .53655 .37599 L p
1 g
F P
s
P
p
.002 w
.53267 .35031 m .53655 .37599 L .56446 .37861 L p
1 g
F P
s
P
p
.002 w
.53655 .37599 m .53267 .35031 L .5052 .35727 L p
1 g
F P
s
P
p
.002 w
.41601 .4219 m .43134 .43031 L .44037 .40296 L p
1 g
F P
s
P
p
.002 w
.44037 .40296 m .43265 .39864 L .41601 .4219 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .43265 .39864 L .44037 .40296 L closepath p
1 g
F P
s
P
p
.002 w
.50656 .53333 m .54934 .51078 L .53333 .48977 L p
1 g
F P
s
P
p
.002 w
.53333 .48977 m .49604 .50933 L .50656 .53333 L p
1 g
F P
s
P
p
.002 w
.56344 .4601 m .53333 .48977 L .54934 .51078 L p
1 g
F P
s
P
p
.002 w
.47344 .35829 m .47776 .36598 L .5052 .35727 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .47776 .36598 L .47344 .35829 L closepath p
1 g
F P
s
P
p
.002 w
.40127 .44558 m .42394 .45778 L .43134 .43031 L p
1 g
F P
s
P
p
.002 w
.43134 .43031 m .41601 .4219 L .40127 .44558 L p
1 g
F P
s
P
p
.002 w
.54934 .51078 m .58392 .47672 L .56344 .4601 L p
1 g
F P
s
P
p
.002 w
.58341 .42317 m .56344 .4601 L .58392 .47672 L p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .44011 .35228 L .43237 .35787 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .43237 .35787 L .42671 .36555 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .42671 .36555 L .42377 .37444 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .42377 .37444 L .42385 .38357 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .42385 .38357 L .42693 .39194 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .42693 .39194 L .43265 .39864 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .47344 .35829 L .46671 .35258 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .46671 .35258 L .45828 .34949 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .45828 .34949 L .44908 .34938 L closepath p
1 g
F P
s
P
p
.002 w
.45087 .37625 m .44908 .34938 L .44011 .35228 L closepath p
1 g
F P
s
P
p
.002 w
.49678 .34199 m .5052 .35727 L .53267 .35031 L p
1 g
F P
s
P
p
.002 w
.5052 .35727 m .49678 .34199 L .47344 .35829 L p
1 g
F P
s
P
p
.002 w
.40457 .40873 m .41601 .4219 L .43265 .39864 L p
1 g
F P
s
P
p
.002 w
.43265 .39864 m .42693 .39194 L .40457 .40873 L p
1 g
F P
s
P
p
.002 w
.41466 .51106 m .45514 .51676 L .45183 .48981 L p
1 g
F P
s
P
p
.002 w
.45183 .48981 m .41833 .48487 L .41466 .51106 L p
1 g
F P
s
P
p
.002 w
.46671 .35258 m .47344 .35829 L .49678 .34199 L p
1 g
F P
s
P
p
.002 w
.45962 .54206 m .50656 .53333 L .49604 .50933 L p
1 g
F P
s
P
p
.002 w
.49604 .50933 m .45514 .51676 L .45962 .54206 L p
1 g
F P
s
P
p
.002 w
.38877 .46926 m .41833 .48487 L .42394 .45778 L p
1 g
F P
s
P
p
.002 w
.42394 .45778 m .40127 .44558 L .38877 .46926 L p
1 g
F P
s
P
p
.002 w
.39833 .39216 m .40457 .40873 L .42693 .39194 L p
1 g
F P
s
P
p
.002 w
.42693 .39194 m .42385 .38357 L .39833 .39216 L p
1 g
F P
s
P
p
.002 w
.58341 .42317 m .59116 .38253 L .56446 .37861 L p
1 g
F P
s
P
p
.002 w
.55965 .34524 m .56446 .37861 L .59116 .38253 L p
1 g
F P
s
P
p
.002 w
.56446 .37861 m .55965 .34524 L .53267 .35031 L p
1 g
F P
s
P
p
.002 w
.58392 .47672 m .60698 .43437 L .58341 .42317 L p
1 g
F P
s
P
p
.002 w
.59116 .38253 m .58341 .42317 L .60698 .43437 L p
1 g
F P
s
P
p
.002 w
.38424 .4263 m .40127 .44558 L .41601 .4219 L p
1 g
F P
s
P
p
.002 w
.41601 .4219 m .40457 .40873 L .38424 .4263 L p
1 g
F P
s
P
p
.002 w
.49678 .34199 m .48353 .33057 L .46671 .35258 L p
1 g
F P
s
P
p
.002 w
.45828 .34949 m .46671 .35258 L .48353 .33057 L p
1 g
F P
s
P
p
.002 w
.52045 .32771 m .53267 .35031 L .55965 .34524 L p
1 g
F P
s
P
p
.002 w
.53267 .35031 m .52045 .32771 L .49678 .34199 L p
1 g
F P
s
P
p
.002 w
.48353 .33057 m .49678 .34199 L .52045 .32771 L p
1 g
F P
s
P
p
.002 w
.39806 .37399 m .39833 .39216 L .42385 .38357 L p
1 g
F P
s
P
p
.002 w
.42385 .38357 m .42377 .37444 L .39806 .37399 L p
1 g
F P
s
P
p
.002 w
.48353 .33057 m .46684 .32432 L .45828 .34949 L p
1 g
F P
s
P
p
.002 w
.44908 .34938 m .45828 .34949 L .46684 .32432 L p
1 g
F P
s
P
p
.002 w
.51715 .55529 m .56446 .53024 L .54934 .51078 L p
1 g
F P
s
P
p
.002 w
.54934 .51078 m .50656 .53333 L .51715 .55529 L p
1 g
F P
s
P
p
.002 w
.58392 .47672 m .54934 .51078 L .56446 .53024 L p
1 g
F P
s
P
p
.002 w
.40386 .35623 m .39806 .37399 L .42377 .37444 L p
1 g
F P
s
P
p
.002 w
.42377 .37444 m .42671 .36555 L .40386 .35623 L p
1 g
F P
s
P
p
.002 w
.46684 .32432 m .44851 .32401 L .44908 .34938 L p
1 g
F P
s
P
p
.002 w
.44011 .35228 m .44908 .34938 L .44851 .32401 L p
1 g
F P
s
P
p
.002 w
.56446 .53024 m .60275 .49255 L .58392 .47672 L p
1 g
F P
s
P
p
.002 w
.60698 .43437 m .58392 .47672 L .60275 .49255 L p
1 g
F P
s
P
p
.002 w
.41306 .53578 m .45962 .54206 L .45514 .51676 L p
1 g
F P
s
P
p
.002 w
.45514 .51676 m .41466 .51106 L .41306 .53578 L p
1 g
F P
s
P
p
.002 w
.37485 .40187 m .38424 .4263 L .40457 .40873 L p
1 g
F P
s
P
p
.002 w
.40457 .40873 m .39833 .39216 L .37485 .40187 L p
1 g
F P
s
P
p
.002 w
.41513 .3409 m .40386 .35623 L .42671 .36555 L p
1 g
F P
s
P
p
.002 w
.42671 .36555 m .43237 .35787 L .41513 .3409 L p
1 g
F P
s
P
p
.002 w
.37879 .49244 m .41466 .51106 L .41833 .48487 L p
1 g
F P
s
P
p
.002 w
.41833 .48487 m .38877 .46926 L .37879 .49244 L p
1 g
F P
s
P
p
.002 w
.43237 .35787 m .44011 .35228 L .4306 .32974 L p
1 g
F P
s
P
p
.002 w
.44851 .32401 m .4306 .32974 L .44011 .35228 L p
1 g
F P
s
P
p
.002 w
.4306 .32974 m .41513 .3409 L .43237 .35787 L p
1 g
F P
s
P
p
.002 w
.36641 .44432 m .38877 .46926 L .40127 .44558 L p
1 g
F P
s
P
p
.002 w
.40127 .44558 m .38424 .4263 L .36641 .44432 L p
1 g
F P
s
P
p
.002 w
.52045 .32771 m .50103 .3107 L .48353 .33057 L p
1 g
F P
s
P
p
.002 w
.46684 .32432 m .48353 .33057 L .50103 .3107 L p
1 g
F P
s
P
p
.002 w
.60698 .43437 m .61611 .38773 L .59116 .38253 L p
1 g
F P
s
P
p
.002 w
.58562 .34221 m .59116 .38253 L .61611 .38773 L p
1 g
F P
s
P
p
.002 w
.59116 .38253 m .58562 .34221 L .55965 .34524 L p
1 g
F P
s
P
p
.002 w
.46522 .56516 m .51715 .55529 L .50656 .53333 L p
1 g
F P
s
P
p
.002 w
.50656 .53333 m .45962 .54206 L .46522 .56516 L p
1 g
F P
s
P
p
.002 w
.544 .31574 m .55965 .34524 L .58562 .34221 L p
1 g
F P
s
P
p
.002 w
.55965 .34524 m .544 .31574 L .52045 .32771 L p
1 g
F P
s
P
p
.002 w
.50103 .3107 m .52045 .32771 L .544 .31574 L p
1 g
F P
s
P
p
.002 w
.60275 .49255 m .6284 .44573 L .60698 .43437 L p
1 g
F P
s
P
p
.002 w
.61611 .38773 m .60698 .43437 L .6284 .44573 L p
1 g
F P
s
P
p
.002 w
.3743 .37494 m .37485 .40187 L .39833 .39216 L p
1 g
F P
s
P
p
.002 w
.39833 .39216 m .39806 .37399 L .3743 .37494 L p
1 g
F P
s
P
p
.002 w
.50103 .3107 m .4764 .30129 L .46684 .32432 L p
1 g
F P
s
P
p
.002 w
.44851 .32401 m .46684 .32432 L .4764 .30129 L p
1 g
F P
s
P
p
.002 w
.35395 .41255 m .36641 .44432 L .38424 .4263 L p
1 g
F P
s
P
p
.002 w
.38424 .4263 m .37485 .40187 L .35395 .41255 L p
1 g
F P
s
P
p
.002 w
.38284 .34854 m .3743 .37494 L .39806 .37399 L p
1 g
F P
s
P
p
.002 w
.39806 .37399 m .40386 .35623 L .38284 .34854 L p
1 g
F P
s
P
p
.002 w
.37166 .51464 m .41306 .53578 L .41466 .51106 L p
1 g
F P
s
P
p
.002 w
.41466 .51106 m .37879 .49244 L .37166 .51464 L p
1 g
F P
s
P
p
.002 w
.35153 .46246 m .37879 .49244 L .38877 .46926 L p
1 g
F P
s
P
p
.002 w
.38877 .46926 m .36641 .44432 L .35153 .46246 L p
1 g
F P
s
P
p
.002 w
.4764 .30129 m .44923 .3007 L .44851 .32401 L p
1 g
F P
s
P
p
.002 w
.4306 .32974 m .44851 .32401 L .44923 .3007 L p
1 g
F P
s
P
p
.002 w
.41362 .55848 m .46522 .56516 L .45962 .54206 L p
1 g
F P
s
P
p
.002 w
.45962 .54206 m .41306 .53578 L .41362 .55848 L p
1 g
F P
s
P
p
.002 w
.5276 .57469 m .57836 .5477 L .56446 .53024 L p
1 g
F P
s
P
p
.002 w
.56446 .53024 m .51715 .55529 L .5276 .57469 L p
1 g
F P
s
P
p
.002 w
.60275 .49255 m .56446 .53024 L .57836 .5477 L p
1 g
F P
s
P
p
.002 w
.544 .31574 m .51888 .29341 L .50103 .3107 L p
1 g
F P
s
P
p
.002 w
.4764 .30129 m .50103 .3107 L .51888 .29341 L p
1 g
F P
s
P
p
.002 w
.57836 .5477 m .61949 .50723 L .60275 .49255 L p
1 g
F P
s
P
p
.002 w
.6284 .44573 m .60275 .49255 L .61949 .50723 L p
1 g
F P
s
P
p
.002 w
.39956 .32572 m .38284 .34854 L .40386 .35623 L p
1 g
F P
s
P
p
.002 w
.40386 .35623 m .41513 .3409 L .39956 .32572 L p
1 g
F P
s
P
p
.002 w
.41513 .3409 m .4306 .32974 L .42259 .30913 L p
1 g
F P
s
P
p
.002 w
.44923 .3007 m .42259 .30913 L .4306 .32974 L p
1 g
F P
s
P
p
.002 w
.58562 .34221 m .56696 .30641 L .544 .31574 L p
1 g
F P
s
P
p
.002 w
.51888 .29341 m .544 .31574 L .56696 .30641 L p
1 g
F P
s
P
p
.002 w
.61611 .38773 m .61002 .34134 L .58562 .34221 L p
1 g
F P
s
P
p
.002 w
.56696 .30641 m .58562 .34221 L .61002 .34134 L p
1 g
F P
s
P
p
.002 w
.42259 .30913 m .39956 .32572 L .41513 .3409 L p
1 g
F P
s
P
p
.002 w
.6284 .44573 m .63873 .39414 L .61611 .38773 L p
1 g
F P
s
P
p
.002 w
.61002 .34134 m .61611 .38773 L .63873 .39414 L p
1 g
F P
s
P
p
.002 w
.47187 .58548 m .5276 .57469 L .51715 .55529 L p
1 g
F P
s
P
p
.002 w
.51715 .55529 m .46522 .56516 L .47187 .58548 L p
1 g
F P
s
P
p
.002 w
.35307 .37735 m .35395 .41255 L .37485 .40187 L p
1 g
F P
s
P
p
.002 w
.37485 .40187 m .3743 .37494 L .35307 .37735 L p
1 g
F P
s
P
p
.002 w
.61949 .50723 m .64715 .45702 L .6284 .44573 L p
1 g
F P
s
P
p
.002 w
.63873 .39414 m .6284 .44573 L .64715 .45702 L p
1 g
F P
s
P
p
.002 w
.51888 .29341 m .48681 .28093 L .4764 .30129 L p
1 g
F P
s
P
p
.002 w
.44923 .3007 m .4764 .30129 L .48681 .28093 L p
1 g
F P
s
P
p
.002 w
.33619 .42401 m .35153 .46246 L .36641 .44432 L p
1 g
F P
s
P
p
.002 w
.36641 .44432 m .35395 .41255 L .33619 .42401 L p
1 g
F P
s
P
p
.002 w
.34003 .4803 m .37166 .51464 L .37879 .49244 L p
1 g
F P
s
P
p
.002 w
.37879 .49244 m .35153 .46246 L .34003 .4803 L p
1 g
F P
s
P
p
.002 w
.36762 .53533 m .41362 .55848 L .41306 .53578 L p
1 g
F P
s
P
p
.002 w
.41306 .53578 m .37166 .51464 L .36762 .53533 L p
1 g
F P
s
P
p
.002 w
.36415 .34271 m .35307 .37735 L .3743 .37494 L p
1 g
F P
s
P
p
.002 w
.3743 .37494 m .38284 .34854 L .36415 .34271 L p
1 g
F P
s
P
p
.002 w
.56696 .30641 m .53673 .27916 L .51888 .29341 L p
1 g
F P
s
P
p
.002 w
.48681 .28093 m .51888 .29341 L .53673 .27916 L p
1 g
F P
s
P
p
.002 w
.41644 .57857 m .47187 .58548 L .46522 .56516 L p
1 g
F P
s
P
p
.002 w
.46522 .56516 m .41362 .55848 L .41644 .57857 L p
1 g
F P
s
P
p
.002 w
.48681 .28093 m .45127 .28001 L .44923 .3007 L p
1 g
F P
s
P
p
.002 w
.42259 .30913 m .44923 .3007 L .45127 .28001 L p
1 g
F P
s
P
p
.002 w
.53767 .591 m .59069 .56271 L .57836 .5477 L p
1 g
F P
s
P
p
.002 w
.57836 .5477 m .5276 .57469 L .53767 .591 L p
1 g
F P
s
P
p
.002 w
.61949 .50723 m .57836 .5477 L .59069 .56271 L p
1 g
F P
s
P
p
.002 w
.61002 .34134 m .58882 .3 L .56696 .30641 L p
1 g
F P
s
P
p
.002 w
.53673 .27916 m .56696 .30641 L .58882 .3 L p
1 g
F P
s
P
p
.002 w
.63873 .39414 m .63228 .34272 L .61002 .34134 L p
1 g
F P
s
P
p
.002 w
.58882 .3 m .61002 .34134 L .63228 .34272 L p
1 g
F P
s
P
p
.002 w
.59069 .56271 m .6337 .52041 L .61949 .50723 L p
1 g
F P
s
P
p
.002 w
.64715 .45702 m .61949 .50723 L .6337 .52041 L p
1 g
F P
s
P
p
.002 w
.38607 .31273 m .36415 .34271 L .38284 .34854 L p
1 g
F P
s
P
p
.002 w
.38284 .34854 m .39956 .32572 L .38607 .31273 L p
1 g
F P
s
P
p
.002 w
.64715 .45702 m .65846 .40166 L .63873 .39414 L p
1 g
F P
s
P
p
.002 w
.63228 .34272 m .63873 .39414 L .65846 .40166 L p
1 g
F P
s
P
p
.002 w
.39956 .32572 m .42259 .30913 L .41631 .29099 L p
1 g
F P
s
P
p
.002 w
.45127 .28001 m .41631 .29099 L .42259 .30913 L p
1 g
F P
s
P
p
.002 w
.41631 .29099 m .38607 .31273 L .39956 .32572 L p
1 g
F P
s
P
p
.002 w
.47948 .60245 m .53767 .591 L .5276 .57469 L p
1 g
F P
s
P
p
.002 w
.5276 .57469 m .47187 .58548 L .47948 .60245 L p
1 g
F P
s
P
p
.002 w
.33495 .38121 m .33619 .42401 L .35395 .41255 L p
1 g
F P
s
P
p
.002 w
.35395 .41255 m .35307 .37735 L .33495 .38121 L p
1 g
F P
s
P
p
.002 w
.6337 .52041 m .66271 .46799 L .64715 .45702 L p
1 g
F P
s
P
p
.002 w
.65846 .40166 m .64715 .45702 L .66271 .46799 L p
1 g
F P
s
P
p
.002 w
.53673 .27916 m .49789 .26381 L .48681 .28093 L p
1 g
F P
s
P
p
.002 w
.45127 .28001 m .48681 .28093 L .49789 .26381 L p
1 g
F P
s
P
p
.002 w
.32212 .43602 m .34003 .4803 L .35153 .46246 L p
1 g
F P
s
P
p
.002 w
.35153 .46246 m .33619 .42401 L .32212 .43602 L p
1 g
F P
s
P
p
.002 w
.33236 .49744 m .36762 .53533 L .37166 .51464 L p
1 g
F P
s
P
p
.002 w
.37166 .51464 m .34003 .4803 L .33236 .49744 L p
1 g
F P
s
P
p
.002 w
.36694 .55396 m .41644 .57857 L .41362 .55848 L p
1 g
F P
s
P
p
.002 w
.41362 .55848 m .36762 .53533 L .36694 .55396 L p
1 g
F P
s
P
p
.002 w
.58882 .3 m .55417 .26839 L .53673 .27916 L p
1 g
F P
s
P
p
.002 w
.49789 .26381 m .53673 .27916 L .55417 .26839 L p
1 g
F P
s
P
p
.002 w
.34835 .33897 m .33495 .38121 L .35307 .37735 L p
1 g
F P
s
P
p
.002 w
.35307 .37735 m .36415 .34271 L .34835 .33897 L p
1 g
F P
s
P
p
.002 w
.42157 .59546 m .47948 .60245 L .47187 .58548 L p
1 g
F P
s
P
p
.002 w
.47187 .58548 m .41644 .57857 L .42157 .59546 L p
1 g
F P
s
P
p
.002 w
.63228 .34272 m .60906 .29678 L .58882 .3 L p
1 g
F P
s
P
p
.002 w
.55417 .26839 m .58882 .3 L .60906 .29678 L p
1 g
F P
s
P
p
.002 w
.49789 .26381 m .45464 .26253 L .45127 .28001 L p
1 g
F P
s
P
p
.002 w
.41631 .29099 m .45127 .28001 L .45464 .26253 L p
1 g
F P
s
P
p
.002 w
.65846 .40166 m .65181 .34643 L .63228 .34272 L p
1 g
F P
s
P
p
.002 w
.60906 .29678 m .63228 .34272 L .65181 .34643 L p
1 g
F P
s
P
p
.002 w
.54713 .6037 m .6011 .57481 L .59069 .56271 L p
1 g
F P
s
P
p
.002 w
.59069 .56271 m .53767 .591 L .54713 .6037 L p
1 g
F P
s
P
p
.002 w
.6337 .52041 m .59069 .56271 L .6011 .57481 L p
1 g
F P
s
P
p
.002 w
.66271 .46799 m .67472 .4102 L .65846 .40166 L p
1 g
F P
s
P
p
.002 w
.65181 .34643 m .65846 .40166 L .67472 .4102 L p
1 g
F P
s
P
p
.002 w
.6011 .57481 m .64493 .53172 L .6337 .52041 L p
1 g
F P
s
P
p
.002 w
.66271 .46799 m .6337 .52041 L .64493 .53172 L p
1 g
F P
s
P
p
.002 w
.37507 .30236 m .34835 .33897 L .36415 .34271 L p
1 g
F P
s
P
p
.002 w
.36415 .34271 m .38607 .31273 L .37507 .30236 L p
1 g
F P
s
P
p
.002 w
.45464 .26253 m .41199 .27583 L .41631 .29099 L p
1 g
F P
s
P
p
.002 w
.38607 .31273 m .41631 .29099 L .41199 .27583 L p
1 g
F P
s
P
p
.002 w
.41199 .27583 m .37507 .30236 L .38607 .31273 L p
1 g
F P
s
P
p
.002 w
.32052 .38652 m .32212 .43602 L .33619 .42401 L p
1 g
F P
s
P
p
.002 w
.33619 .42401 m .33495 .38121 L .32052 .38652 L p
1 g
F P
s
P
p
.002 w
.48791 .6155 m .54713 .6037 L .53767 .591 L p
1 g
F P
s
P
p
.002 w
.53767 .591 m .47948 .60245 L .48791 .6155 L p
1 g
F P
s
P
p
.002 w
.55417 .26839 m .5094 .25047 L .49789 .26381 L p
1 g
F P
s
P
p
.002 w
.45464 .26253 m .49789 .26381 L .5094 .25047 L p
1 g
F P
s
P
p
.002 w
.64493 .53172 m .67456 .47838 L .66271 .46799 L p
1 g
F P
s
P
p
.002 w
.67472 .4102 m .66271 .46799 L .67456 .47838 L p
1 g
F P
s
P
p
.002 w
.31227 .44834 m .33236 .49744 L .34003 .4803 L p
1 g
F P
s
P
p
.002 w
.34003 .4803 m .32212 .43602 L .31227 .44834 L p
1 g
F P
s
P
p
.002 w
.32889 .51341 m .36694 .55396 L .36762 .53533 L p
1 g
F P
s
P
p
.002 w
.36762 .53533 m .33236 .49744 L .32889 .51341 L p
1 g
F P
s
P
p
.002 w
.3698 .56996 m .42157 .59546 L .41644 .57857 L p
1 g
F P
s
P
p
.002 w
.41644 .57857 m .36694 .55396 L .3698 .56996 L p
1 g
F P
s
P
p
.002 w
.60906 .29678 m .57079 .26153 L .55417 .26839 L p
1 g
F P
s
P
p
.002 w
.5094 .25047 m .55417 .26839 L .57079 .26153 L p
1 g
F P
s
P
p
.002 w
.33597 .33753 m .32052 .38652 L .33495 .38121 L p
1 g
F P
s
P
p
.002 w
.33495 .38121 m .34835 .33897 L .33597 .33753 L p
1 g
F P
s
P
p
.002 w
.65181 .34643 m .6271 .29699 L .60906 .29678 L p
1 g
F P
s
P
p
.002 w
.57079 .26153 m .60906 .29678 L .6271 .29699 L p
1 g
F P
s
P
p
.002 w
.429 .60856 m .48791 .6155 L .47948 .60245 L p
1 g
F P
s
P
p
.002 w
.47948 .60245 m .42157 .59546 L .429 .60856 L p
1 g
F P
s
P
p
.002 w
.67472 .4102 m .668 .3525 L .65181 .34643 L p
1 g
F P
s
P
p
.002 w
.6271 .29699 m .65181 .34643 L .668 .3525 L p
1 g
F P
s
P
p
.002 w
.5094 .25047 m .45935 .24884 L .45464 .26253 L p
1 g
F P
s
P
p
.002 w
.41199 .27583 m .45464 .26253 L .45935 .24884 L p
1 g
F P
s
P
p
.002 w
.67456 .47838 m .68694 .41959 L .67472 .4102 L p
1 g
F P
s
P
p
.002 w
.668 .3525 m .67472 .4102 L .68694 .41959 L p
1 g
F P
s
P
p
.002 w
.55569 .61226 m .60922 .58354 L .6011 .57481 L p
1 g
F P
s
P
p
.002 w
.6011 .57481 m .54713 .6037 L .55569 .61226 L p
1 g
F P
s
P
p
.002 w
.64493 .53172 m .6011 .57481 L .60922 .58354 L p
1 g
F P
s
P
p
.002 w
.60922 .58354 m .65274 .54078 L .64493 .53172 L p
1 g
F P
s
P
p
.002 w
.67456 .47838 m .64493 .53172 L .65274 .54078 L p
1 g
F P
s
P
p
.002 w
.36696 .295 m .33597 .33753 L .34835 .33897 L p
1 g
F P
s
P
p
.002 w
.34835 .33897 m .37507 .30236 L .36696 .295 L p
1 g
F P
s
P
p
.002 w
.45935 .24884 m .40985 .2642 L .41199 .27583 L p
1 g
F P
s
P
p
.002 w
.37507 .30236 m .41199 .27583 L .40985 .2642 L p
1 g
F P
s
P
p
.002 w
.31036 .39324 m .31227 .44834 L .32212 .43602 L p
1 g
F P
s
P
p
.002 w
.32212 .43602 m .32052 .38652 L .31036 .39324 L p
1 g
F P
s
P
p
.002 w
.40985 .2642 m .36696 .295 L .37507 .30236 L p
1 g
F P
s
P
p
.002 w
.49701 .62406 m .55569 .61226 L .54713 .6037 L p
1 g
F P
s
P
p
.002 w
.54713 .6037 m .48791 .6155 L .49701 .62406 L p
1 g
F P
s
P
p
.002 w
.57079 .26153 m .5211 .24144 L .5094 .25047 L p
1 g
F P
s
P
p
.002 w
.45935 .24884 m .5094 .25047 L .5211 .24144 L p
1 g
F P
s
P
p
.002 w
.30714 .46065 m .32889 .51341 L .33236 .49744 L p
1 g
F P
s
P
p
.002 w
.33236 .49744 m .31227 .44834 L .30714 .46065 L p
1 g
F P
s
P
p
.002 w
.65274 .54078 m .6822 .48789 L .67456 .47838 L p
1 g
F P
s
P
p
.002 w
.68694 .41959 m .67456 .47838 L .6822 .48789 L p
1 g
F P
s
P
p
.002 w
.32996 .52775 m .3698 .56996 L .36694 .55396 L p
1 g
F P
s
P
p
.002 w
.36694 .55396 m .32889 .51341 L .32996 .52775 L p
1 g
F P
s
P
p
.002 w
.37633 .58278 m .429 .60856 L .42157 .59546 L p
1 g
F P
s
P
p
.002 w
.42157 .59546 m .3698 .56996 L .37633 .58278 L p
1 g
F P
s
P
p
.002 w
.6271 .29699 m .58613 .25896 L .57079 .26153 L p
1 g
F P
s
P
p
.002 w
.5211 .24144 m .57079 .26153 L .58613 .25896 L p
1 g
F P
s
P
p
.002 w
.668 .3525 m .6424 .30081 L .6271 .29699 L p
1 g
F P
s
P
p
.002 w
.58613 .25896 m .6271 .29699 L .6424 .30081 L p
1 g
F P
s
P
p
.002 w
.32753 .33855 m .31036 .39324 L .32052 .38652 L p
1 g
F P
s
P
p
.002 w
.32052 .38652 m .33597 .33753 L .32753 .33855 L p
1 g
F P
s
P
p
.002 w
.68694 .41959 m .68028 .36091 L .668 .3525 L p
1 g
F P
s
P
p
.002 w
.6424 .30081 m .668 .3525 L .68028 .36091 L p
1 g
F P
s
P
p
.002 w
.43867 .61729 m .49701 .62406 L .48791 .6155 L p
1 g
F P
s
P
p
.002 w
.48791 .6155 m .429 .60856 L .43867 .61729 L p
1 g
F P
s
P
p
.002 w
.5211 .24144 m .46535 .23952 L .45935 .24884 L p
1 g
F P
s
P
p
.002 w
.40985 .2642 m .45935 .24884 L .46535 .23952 L p
1 g
F P
s
P
p
.002 w
.6822 .48789 m .69458 .42966 L .68694 .41959 L p
1 g
F P
s
P
p
.002 w
.68028 .36091 m .68694 .41959 L .69458 .42966 L p
1 g
F P
s
P
p
.002 w
.5631 .61622 m .61472 .58849 L .60922 .58354 L p
1 g
F P
s
P
p
.002 w
.60922 .58354 m .55569 .61226 L .5631 .61622 L p
1 g
F P
s
P
p
.002 w
.65274 .54078 m .60922 .58354 L .61472 .58849 L p
1 g
F P
s
P
p
.002 w
.61472 .58849 m .65672 .54722 L .65274 .54078 L p
1 g
F P
s
P
p
.002 w
.6822 .48789 m .65274 .54078 L .65672 .54722 L p
1 g
F P
s
P
p
.002 w
.36215 .29102 m .32753 .33855 L .33597 .33753 L p
1 g
F P
s
P
p
.002 w
.33597 .33753 m .36696 .295 L .36215 .29102 L p
1 g
F P
s
P
p
.002 w
.30501 .40126 m .30714 .46065 L .31227 .44834 L p
1 g
F P
s
P
p
.002 w
.31227 .44834 m .31036 .39324 L .30501 .40126 L p
1 g
F P
s
P
p
.002 w
.46535 .23952 m .41008 .25662 L .40985 .2642 L p
1 g
F P
s
P
p
.002 w
.36696 .295 m .40985 .2642 L .41008 .25662 L p
1 g
F P
s
P
p
.002 w
.41008 .25662 m .36215 .29102 L .36696 .295 L p
1 g
F P
s
P
p
.002 w
.50656 .62763 m .5631 .61622 L .55569 .61226 L p
1 g
F P
s
P
p
.002 w
.55569 .61226 m .49701 .62406 L .50656 .62763 L p
1 g
F P
s
P
p
.002 w
.30716 .47264 m .32996 .52775 L .32889 .51341 L p
1 g
F P
s
P
p
.002 w
.32889 .51341 m .30714 .46065 L .30716 .47264 L p
1 g
F P
s
P
p
.002 w
.58613 .25896 m .5327 .23722 L .5211 .24144 L p
1 g
F P
s
P
p
.002 w
.46535 .23952 m .5211 .24144 L .5327 .23722 L p
1 g
F P
s
P
p
.002 w
.33581 .53995 m .37633 .58278 L .3698 .56996 L p
1 g
F P
s
P
p
.002 w
.3698 .56996 m .32996 .52775 L .33581 .53995 L p
1 g
F P
s
P
p
.002 w
.65672 .54722 m .68517 .49623 L .6822 .48789 L p
1 g
F P
s
P
p
.002 w
.69458 .42966 m .6822 .48789 L .68517 .49623 L p
1 g
F P
s
P
p
.002 w
.38657 .59187 m .43867 .61729 L .429 .60856 L p
1 g
F P
s
P
p
.002 w
.429 .60856 m .37633 .58278 L .38657 .59187 L p
1 g
F P
s
P
p
.002 w
.6424 .30081 m .59971 .261 L .58613 .25896 L p
1 g
F P
s
P
p
.002 w
.5327 .23722 m .58613 .25896 L .59971 .261 L p
1 g
F P
s
P
p
.002 w
.68028 .36091 m .65439 .30834 L .6424 .30081 L p
1 g
F P
s
P
p
.002 w
.59971 .261 m .6424 .30081 L .65439 .30834 L p
1 g
F P
s
P
p
.002 w
.69458 .42966 m .68808 .37158 L .68028 .36091 L p
1 g
F P
s
P
p
.002 w
.65439 .30834 m .68028 .36091 L .68808 .37158 L p
1 g
F P
s
P
p
.002 w
.32354 .34219 m .30501 .40126 L .31036 .39324 L p
1 g
F P
s
P
p
.002 w
.31036 .39324 m .32753 .33855 L .32354 .34219 L p
1 g
F P
s
P
p
.002 w
.45046 .62116 m .50656 .62763 L .49701 .62406 L p
1 g
F P
s
P
p
.002 w
.49701 .62406 m .43867 .61729 L .45046 .62116 L p
1 g
F P
s
P
p
.002 w
.5327 .23722 m .47256 .23509 L .46535 .23952 L p
1 g
F P
s
P
p
.002 w
.41008 .25662 m .46535 .23952 L .47256 .23509 L p
1 g
F P
s
P
p
.002 w
.68517 .49623 m .69714 .44016 L .69458 .42966 L p
1 g
F P
s
P
p
.002 w
.68808 .37158 m .69458 .42966 L .69714 .44016 L p
1 g
F P
s
P
p
.002 w
.30492 .41045 m .30716 .47264 L .30714 .46065 L p
1 g
F P
s
P
p
.002 w
.30714 .46065 m .30501 .40126 L .30492 .41045 L p
1 g
F P
s
P
p
.002 w
.56906 .61516 m .61727 .58925 L .61472 .58849 L p
1 g
F P
s
P
p
.002 w
.61472 .58849 m .5631 .61622 L .56906 .61516 L p
1 g
F P
s
P
p
.002 w
.65672 .54722 m .61472 .58849 L .61727 .58925 L p
1 g
F P
s
P
p
.002 w
.61727 .58925 m .65651 .5507 L .65672 .54722 L p
1 g
F P
s
P
p
.002 w
.68517 .49623 m .65672 .54722 L .65651 .5507 L p
1 g
F P
s
P
p
.002 w
.36097 .29077 m .32354 .34219 L .32753 .33855 L p
1 g
F P
s
P
p
.002 w
.32753 .33855 m .36215 .29102 L .36097 .29077 L p
1 g
F P
s
P
p
.002 w
.36215 .29102 m .41008 .25662 L .41283 .25356 L p
1 g
F P
s
P
p
.002 w
.47256 .23509 m .41283 .25356 L .41008 .25662 L p
1 g
F P
s
P
p
.002 w
.31265 .48392 m .33581 .53995 L .32996 .52775 L p
1 g
F P
s
P
p
.002 w
.32996 .52775 m .30716 .47264 L .31265 .48392 L p
1 g
F P
s
P
p
.002 w
.59971 .261 m .54387 .23821 L .5327 .23722 L p
1 g
F P
s
P
p
.002 w
.47256 .23509 m .5327 .23722 L .54387 .23821 L p
1 g
F P
s
P
p
.002 w
.41283 .25356 m .36097 .29077 L .36215 .29102 L p
1 g
F P
s
P
p
.002 w
.51634 .6258 m .56906 .61516 L .5631 .61622 L p
1 g
F P
s
P
p
.002 w
.5631 .61622 m .50656 .62763 L .51634 .6258 L p
1 g
F P
s
P
p
.002 w
.34657 .54954 m .38657 .59187 L .37633 .58278 L p
1 g
F P
s
P
p
.002 w
.37633 .58278 m .33581 .53995 L .34657 .54954 L p
1 g
F P
s
P
p
.002 w
.65651 .5507 m .68308 .5031 L .68517 .49623 L p
1 g
F P
s
P
p
.002 w
.69714 .44016 m .68517 .49623 L .68308 .5031 L p
1 g
F P
s
P
p
.002 w
.40046 .59673 m .45046 .62116 L .43867 .61729 L p
1 g
F P
s
P
p
.002 w
.43867 .61729 m .38657 .59187 L .40046 .59673 L p
1 g
F P
s
P
p
.002 w
.65439 .30834 m .61105 .26786 L .59971 .261 L p
1 g
F P
s
P
p
.002 w
.54387 .23821 m .59971 .261 L .61105 .26786 L p
1 g
F P
s
P
p
.002 w
.68808 .37158 m .66253 .3196 L .65439 .30834 L p
1 g
F P
s
P
p
.002 w
.61105 .26786 m .65439 .30834 L .66253 .3196 L p
1 g
F P
s
P
p
.002 w
.69714 .44016 m .69091 .38434 L .68808 .37158 L p
1 g
F P
s
P
p
.002 w
.66253 .3196 m .68808 .37158 L .69091 .38434 L p
1 g
F P
s
P
p
.002 w
.32438 .34849 m .30492 .41045 L .30501 .40126 L p
1 g
F P
s
P
p
.002 w
.30501 .40126 m .32354 .34219 L .32438 .34849 L p
1 g
F P
s
P
p
.002 w
.46414 .61974 m .51634 .6258 L .50656 .62763 L p
1 g
F P
s
P
p
.002 w
.50656 .62763 m .45046 .62116 L .46414 .61974 L p
1 g
F P
s
P
p
.002 w
.54387 .23821 m .48087 .23599 L .47256 .23509 L p
1 g
F P
s
P
p
.002 w
.41283 .25356 m .47256 .23509 L .48087 .23599 L p
1 g
F P
s
P
p
.002 w
.68308 .5031 m .69423 .45084 L .69714 .44016 L p
1 g
F P
s
P
p
.002 w
.69091 .38434 m .69714 .44016 L .69423 .45084 L p
1 g
F P
s
P
p
.002 w
.31044 .42061 m .31265 .48392 L .30716 .47264 L p
1 g
F P
s
P
p
.002 w
.30716 .47264 m .30492 .41045 L .31044 .42061 L p
1 g
F P
s
P
p
.002 w
.57332 .60878 m .6166 .58553 L .61727 .58925 L p
1 g
F P
s
P
p
.002 w
.61727 .58925 m .56906 .61516 L .57332 .60878 L p
1 g
F P
s
P
p
.002 w
.65651 .5507 m .61727 .58925 L .6166 .58553 L p
1 g
F P
s
P
p
.002 w
.6166 .58553 m .65184 .55091 L .65651 .5507 L p
1 g
F P
s
P
p
.002 w
.68308 .5031 m .65651 .5507 L .65184 .55091 L p
1 g
F P
s
P
p
.002 w
.36372 .2945 m .32438 .34849 L .32354 .34219 L p
1 g
F P
s
P
p
.002 w
.32354 .34219 m .36097 .29077 L .36372 .2945 L p
1 g
F P
s
P
p
.002 w
.32377 .49413 m .34657 .54954 L .33581 .53995 L p
1 g
F P
s
P
p
.002 w
.33581 .53995 m .31265 .48392 L .32377 .49413 L p
1 g
F P
s
P
p
.002 w
.48087 .23599 m .41819 .2554 L .41283 .25356 L p
1 g
F P
s
P
p
.002 w
.36097 .29077 m .41283 .25356 L .41819 .2554 L p
1 g
F P
s
P
p
.002 w
.61105 .26786 m .55425 .24473 L .54387 .23821 L p
1 g
F P
s
P
p
.004 w
.56381 .24282 m
.56915 .22711 L
s
P
p
.002 w
.48087 .23599 m .54387 .23821 L .55425 .24473 L p
1 g
F P
s
P
p
.002 w
.36219 .55606 m .40046 .59673 L .38657 .59187 L p
1 g
F P
s
P
p
.002 w
.38657 .59187 m .34657 .54954 L .36219 .55606 L p
1 g
F P
s
P
p
.002 w
.52606 .61827 m .57332 .60878 L .56906 .61516 L p
1 g
F P
s
P
p
.002 w
.56906 .61516 m .51634 .6258 L .52606 .61827 L p
1 g
F P
s
P
p
.002 w
.41819 .2554 m .36372 .2945 L .36097 .29077 L p
1 g
F P
s
P
p
.002 w
.41778 .59696 m .46414 .61974 L .45046 .62116 L p
1 g
F P
s
P
p
.002 w
.45046 .62116 m .40046 .59673 L .41778 .59696 L p
1 g
F P
s
P
p
.002 w
.66253 .3196 m .61969 .27965 L .61105 .26786 L p
1 g
F P
s
P
p
.002 w
.55425 .24473 m .61105 .26786 L .61969 .27965 L p
1 g
F P
s
P
p
.002 w
.65184 .55091 m .67567 .50818 L .68308 .5031 L p
1 g
F P
s
P
p
.002 w
.69423 .45084 m .68308 .5031 L .67567 .50818 L p
1 g
F P
s
P
p
.002 w
.69091 .38434 m .66635 .33449 L .66253 .3196 L p
1 g
F P
s
P
p
.002 w
.61969 .27965 m .66253 .3196 L .66635 .33449 L p
1 g
F P
s
P
p
.002 w
.69423 .45084 m .68838 .39894 L .69091 .38434 L p
1 g
F P
s
P
p
.002 w
.66635 .33449 m .69091 .38434 L .68838 .39894 L p
1 g
F P
s
P
p
.002 w
.33036 .35745 m .31044 .42061 L .30492 .41045 L p
1 g
F P
s
P
p
.002 w
.30492 .41045 m .32438 .34849 L .33036 .35745 L p
1 g
F P
s
P
p
.002 w
.47942 .61276 m .52606 .61827 L .51634 .6258 L p
1 g
F P
s
P
p
.002 w
.51634 .6258 m .46414 .61974 L .47942 .61276 L p
1 g
F P
s
P
p
.002 w
.55425 .24473 m .49007 .24255 L .48087 .23599 L p
1 g
F P
s
P
p
.002 w
.41819 .2554 m .48087 .23599 L .49007 .24255 L p
1 g
F P
s
P
p
.002 w
.67567 .50818 m .68559 .46138 L .69423 .45084 L p
1 g
F P
s
P
p
.002 w
.68838 .39894 m .69423 .45084 L .68559 .46138 L p
1 g
F P
s
P
p
.002 w
.32174 .43148 m .32377 .49413 L .31265 .48392 L p
1 g
F P
s
P
p
.002 w
.31265 .48392 m .31044 .42061 L .32174 .43148 L p
1 g
F P
s
P
p
.002 w
.34051 .50285 m .36219 .55606 L .34657 .54954 L p
1 g
F P
s
P
p
.002 w
.34657 .54954 m .32377 .49413 L .34051 .50285 L p
1 g
F P
s
P
p
.002 w
.57562 .59693 m .61251 .57715 L .6166 .58553 L p
1 g
F P
s
P
p
.002 w
.6166 .58553 m .57332 .60878 L .57562 .59693 L p
1 g
F P
s
P
p
.002 w
.65184 .55091 m .6166 .58553 L .61251 .57715 L p
1 g
F P
s
P
p
.002 w
.37055 .30236 m .33036 .35745 L .32438 .34849 L p
1 g
F P
s
P
p
.002 w
.32438 .34849 m .36372 .2945 L .37055 .30236 L p
1 g
F P
s
P
p
.002 w
.61251 .57715 m .64256 .54763 L .65184 .55091 L p
1 g
F P
s
P
p
.002 w
.67567 .50818 m .65184 .55091 L .64256 .54763 L p
1 g
F P
s
P
p
.002 w
.38245 .55912 m .41778 .59696 L .40046 .59673 L p
1 g
F P
s
P
p
.002 w
.40046 .59673 m .36219 .55606 L .38245 .55912 L p
1 g
F P
s
P
p
.002 w
.61969 .27965 m .56348 .2569 L .55425 .24473 L p
1 g
F P
s
P
p
.002 w
.49007 .24255 m .55425 .24473 L .56348 .2569 L p
1 g
F P
s
P
p
.002 w
.36372 .2945 m .41819 .2554 L .42615 .26241 L p
1 g
F P
s
P
p
.002 w
.49007 .24255 m .42615 .26241 L .41819 .2554 L p
1 g
F P
s
P
p
.002 w
.53542 .60493 m .57562 .59693 L .57332 .60878 L p
1 g
F P
s
P
p
.002 w
.57332 .60878 m .52606 .61827 L .53542 .60493 L p
1 g
F P
s
P
p
.002 w
.43817 .59229 m .47942 .61276 L .46414 .61974 L p
1 g
F P
s
P
p
.002 w
.46414 .61974 m .41778 .59696 L .43817 .59229 L p
1 g
F P
s
P
p
.002 w
.66635 .33449 m .62517 .29629 L .61969 .27965 L p
1 g
F P
s
P
p
.002 w
.56348 .2569 m .61969 .27965 L .62517 .29629 L p
1 g
F P
s
P
p
.002 w
.42615 .26241 m .37055 .30236 L .36372 .2945 L p
1 g
F P
s
P
p
.002 w
.68838 .39894 m .66547 .35275 L .66635 .33449 L p
1 g
F P
s
P
p
.002 w
.62517 .29629 m .66635 .33449 L .66547 .35275 L p
1 g
F P
s
P
p
.002 w
.64256 .54763 m .66281 .51122 L .67567 .50818 L p
1 g
F P
s
P
p
.002 w
.68559 .46138 m .67567 .50818 L .66281 .51122 L p
1 g
F P
s
P
p
.002 w
.68559 .46138 m .68025 .41504 L .68838 .39894 L p
1 g
F P
s
P
p
.002 w
.66547 .35275 m .68838 .39894 L .68025 .41504 L p
1 g
F P
s
P
p
.002 w
.34161 .36894 m .32174 .43148 L .31044 .42061 L p
1 g
F P
s
P
p
.002 w
.31044 .42061 m .33036 .35745 L .34161 .36894 L p
1 g
F P
s
P
p
.002 w
.49587 .60012 m .53542 .60493 L .52606 .61827 L p
1 g
F P
s
P
p
.002 w
.52606 .61827 m .47942 .61276 L .49587 .60012 L p
1 g
F P
s
P
p
.002 w
.56348 .2569 m .49995 .2549 L .49007 .24255 L p
1 g
F P
s
P
p
.002 w
.42615 .26241 m .49007 .24255 L .49995 .2549 L p
1 g
F P
s
P
p
.002 w
.66281 .51122 m .67115 .47142 L .68559 .46138 L p
1 g
F P
s
P
p
.002 w
.68025 .41504 m .68559 .46138 L .67115 .47142 L p
1 g
F P
s
P
p
.002 w
.3388 .44273 m .34051 .50285 L .32377 .49413 L p
1 g
F P
s
P
p
.002 w
.32377 .49413 m .32174 .43148 L .3388 .44273 L p
1 g
F P
s
P
p
.002 w
.36262 .50972 m .38245 .55912 L .36219 .55606 L p
1 g
F P
s
P
p
.002 w
.36219 .55606 m .34051 .50285 L .36262 .50972 L p
1 g
F P
s
P
p
.002 w
.40692 .55844 m .43817 .59229 L .41778 .59696 L p
1 g
F P
s
P
p
.002 w
.41778 .59696 m .38245 .55912 L .40692 .55844 L p
1 g
F P
s
P
p
.002 w
.62517 .29629 m .57119 .27467 L .56348 .2569 L p
1 g
F P
s
P
p
.002 w
.49995 .2549 m .56348 .2569 L .57119 .27467 L p
1 g
F P
s
P
p
.002 w
.57576 .57967 m .60492 .56408 L .61251 .57715 L p
1 g
F P
s
P
p
.002 w
.61251 .57715 m .57562 .59693 L .57576 .57967 L p
1 g
F P
s
P
p
.002 w
.64256 .54763 m .61251 .57715 L .60492 .56408 L p
1 g
F P
s
P
p
.002 w
.38152 .31435 m .34161 .36894 L .33036 .35745 L p
1 g
F P
s
P
p
.002 w
.33036 .35745 m .37055 .30236 L .38152 .31435 L p
1 g
F P
s
P
p
.002 w
.60492 .56408 m .62866 .54074 L .64256 .54763 L p
1 g
F P
s
P
p
.002 w
.66281 .51122 m .64256 .54763 L .62866 .54074 L p
1 g
F P
s
P
p
.002 w
.49995 .2549 m .43664 .27471 L .42615 .26241 L p
1 g
F P
s
P
p
.002 w
.37055 .30236 m .42615 .26241 L .43664 .27471 L p
1 g
F P
s
P
p
.002 w
.66547 .35275 m .62716 .31752 L .62517 .29629 L p
1 g
F P
s
P
p
.002 w
.57119 .27467 m .62517 .29629 L .62716 .31752 L p
1 g
F P
s
P
p
.002 w
.46109 .58261 m .49587 .60012 L .47942 .61276 L p
1 g
F P
s
P
p
.002 w
.47942 .61276 m .43817 .59229 L .46109 .58261 L p
1 g
F P
s
P
p
.002 w
.68025 .41504 m .65966 .37398 L .66547 .35275 L p
1 g
F P
s
P
p
.002 w
.62716 .31752 m .66547 .35275 L .65966 .37398 L p
1 g
F P
s
P
p
.002 w
.54406 .58588 m .57576 .57967 L .57562 .59693 L p
1 g
F P
s
P
p
.002 w
.57562 .59693 m .53542 .60493 L .54406 .58588 L p
1 g
F P
s
P
p
.002 w
.43664 .27471 m .38152 .31435 L .37055 .30236 L p
1 g
F P
s
P
p
.002 w
.62866 .54074 m .6446 .51197 L .66281 .51122 L p
1 g
F P
s
P
p
.002 w
.67115 .47142 m .66281 .51122 L .6446 .51197 L p
1 g
F P
s
P
p
.002 w
.67115 .47142 m .66647 .43218 L .68025 .41504 L p
1 g
F P
s
P
p
.002 w
.65966 .37398 m .68025 .41504 L .66647 .43218 L p
1 g
F P
s
P
p
.002 w
.35806 .38272 m .3388 .44273 L .32174 .43148 L p
1 g
F P
s
P
p
.002 w
.32174 .43148 m .34161 .36894 L .35806 .38272 L p
1 g
F P
s
P
p
.002 w
.51301 .58195 m .54406 .58588 L .53542 .60493 L p
1 g
F P
s
P
p
.002 w
.53542 .60493 m .49587 .60012 L .51301 .58195 L p
1 g
F P
s
P
p
.002 w
.6446 .51197 m .65107 .48061 L .67115 .47142 L p
1 g
F P
s
P
p
.002 w
.66647 .43218 m .67115 .47142 L .65107 .48061 L p
1 g
F P
s
P
p
.002 w
.57119 .27467 m .51021 .27298 L .49995 .2549 L p
1 g
F P
s
P
p
.004 w
.55888 .25732 m
.56381 .24282 L
s
P
p
.002 w
.43664 .27471 m .49995 .2549 L .51021 .27298 L p
1 g
F P
s
P
p
.002 w
.36132 .45399 m .36262 .50972 L .34051 .50285 L p
1 g
F P
s
P
p
.002 w
.34051 .50285 m .3388 .44273 L .36132 .45399 L p
1 g
F P
s
P
p
.002 w
.38959 .5144 m .40692 .55844 L .38245 .55912 L p
1 g
F P
s
P
p
.002 w
.38245 .55912 m .36262 .50972 L .38959 .5144 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.43494 .55386 m .46109 .58261 L .43817 .59229 L p
1 g
F P
s
P
p
.002 w
.43817 .59229 m .40692 .55844 L .43494 .55386 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.62716 .31752 m .57704 .29775 L .57119 .27467 L p
1 g
F P
s
P
p
.002 w
.51021 .27298 m .57119 .27467 L .57704 .29775 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.65966 .37398 m .62538 .34285 L .62716 .31752 L p
1 g
F P
s
P
p
.002 w
.57704 .29775 m .62716 .31752 L .62538 .34285 L p
1 g
F P
s
P
p
.002 w
.39648 .3303 m .35806 .38272 L .34161 .36894 L p
1 g
F P
s
P
p
.002 w
.34161 .36894 m .38152 .31435 L .39648 .3303 L p
1 g
F P
s
P
p
.002 w
.57363 .55726 m .59388 .54648 L .60492 .56408 L p
1 g
F P
s
P
p
.002 w
.60492 .56408 m .57576 .57967 L .57363 .55726 L p
1 g
F P
s
P
p
.002 w
.62866 .54074 m .60492 .56408 L .59388 .54648 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.4891 .58009 m .48921 .57862 L p
.48012 .57787 L 1 g
F P
s
P
p
.002 w
.49587 .60012 m .46109 .58261 L .47239 .57596 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .57441 L p
1 g
F P
s
P
p
.46109 .58261 m .46237 .57212 L .46834 .57441 L 1 g
F
P
p
.002 w
.47239 .57596 m .47144 .57652 L p
.46834 .57441 L 1 g
F P
s
P
p
.002 w
.47144 .57652 m .46109 .58261 L p
.46834 .57441 L 1 g
F P
s
P
p
.002 w
.46834 .57441 m .46872 .57265 L p
.46145 .56975 L 1 g
F P
s
P
p
.48921 .57862 m .46834 .57441 L .47095 .57542 L 1 g
F
P
p
.48921 .57862 m .46822 .57494 L .48012 .57787 L 1 g
F
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45096 .56263 L p
1 g
F P
s
P
p
.46872 .57265 m .45096 .56263 L .46145 .56975 L 1 g
F
P
p
.46834 .57441 m .46562 .54538 L .47239 .57596 L 1 g
F
P
p
.46237 .57212 m .46256 .5705 L .46834 .57441 L 1 g
F
P
p
.46256 .5705 m .46562 .54538 L .46834 .57441 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46109 .58261 m .43494 .55386 L .44172 .55198 L p
1 g
F P
s
P
p
.002 w
.45096 .56263 m .45146 .56129 L p
.44469 .55541 L 1 g
F P
s
P
p
.46109 .58261 m .44172 .55198 L .46198 .57533 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43846 .54715 L p
1 g
F P
s
P
p
.002 w
.44172 .55198 m .43494 .55386 L p
.43847 .54715 L 1 g
F P
s
P
p
.45146 .56129 m .43846 .54715 L .44309 .55402 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.42064 .51662 m .42916 .51652 L p
.43276 .52837 L 1 g
F P
s
P
p
.43846 .54714 m .43237 .53671 L .43276 .52837 L 1 g
F
P
p
.43237 .53671 m .42064 .51662 L .43276 .52837 L 1 g
F
P
p
.002 w
.43276 .52837 m .43346 .52734 L p
.43318 .51929 L 1 g
F P
s
P
p
.002 w
.43846 .54715 m .43925 .54566 L p
.43614 .53951 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43846 .54714 m .43276 .52837 L .45473 .51623 L 1 g
F
P
p
.002 w
.42916 .51652 m .43331 .51648 L p
.43276 .52837 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43411 .50914 L p
1 g
F P
s
P
p
.42064 .51662 m .43479 .50293 L .43411 .50914 L 1 g
F
P
p
.002 w
.43331 .51648 m .43056 .51651 L p
.43411 .50914 L 1 g
F P
s
P
p
.002 w
.43056 .51651 m .42064 .51662 L p
.43411 .50914 L 1 g
F P
s
P
p
.002 w
.43411 .50914 m .43485 .50826 L p
.43736 .50239 L 1 g
F P
s
P
p
.43346 .52734 m .43411 .50914 L .43359 .51394 L 1 g
F
P
p
.43346 .52734 m .43363 .50972 L .43318 .51929 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44276 .49117 L p
1 g
F P
s
P
p
.43485 .50826 m .44276 .49117 L .43736 .50239 L 1 g
F
P
p
.43411 .50914 m .45467 .4837 L .43331 .51648 L 1 g
F
P
p
.43479 .50293 m .43911 .49875 L .43411 .50914 L 1 g
F
P
p
.43911 .49875 m .45467 .4837 L .43411 .50914 L 1 g
F
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.42064 .51662 m .4206 .51257 L p
.45467 .4837 L 1 g
F P
s
P
p
.002 w
.44276 .49117 m .44339 .4905 L p
.45153 .4827 L 1 g
F P
s
P
p
.002 w
.45674 .47764 m .45467 .4837 L .45137 .48286 L p
1 g
F P
s
P
p
.45153 .4827 m .45166 .48257 L .45137 .48286 L 1 g
F
P
p
.45153 .4827 m .45137 .48286 L .44276 .49117 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45761 .47679 L p
1 g
F P
s
P
p
.002 w
.45467 .4837 m .45674 .47764 L p
.49842 .46895 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.45674 .47764 m .45761 .47679 L .49842 .46895 L 1 g
F
P
p
.002 w
.45761 .47679 m .45826 .47608 L p
.46695 .47227 L 1 g
F P
s
P
p
.45761 .47679 m .47759 .46712 L .49842 .46895 L 1 g
F
P
p
.002 w
.47759 .46712 m .47786 .46667 L p
.4898 .46545 L 1 g
F P
s
P
p
.002 w
.49145 .46523 m .49842 .46895 L p
.47759 .46712 L 1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.51276 .4498 m .50244 .46358 L p
.46567 .45148 L 1 g
F P
s
P
p
.002 w
.49842 .46895 m .50193 .46427 L p
.53836 .47551 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52244 .46716 L p
1 g
F P
s
P
p
.5 .4634 m .52244 .46716 L .51197 .46569 L 1 g
F
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.50193 .46427 m .52244 .46716 L .53836 .47551 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54244 .47684 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.55464 .48248 m .56245 .49949 L p
.56045 .49743 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5661 .50939 L p
1 g
F P
s
P
p
.002 w
.5633 .50339 m .56245 .49949 L p
.56596 .50761 L 1 g
F P
s
P
p
.57451 .52744 m .5661 .50939 L .56596 .50761 L 1 g
F
P
p
.5661 .50939 m .5633 .50339 L .56596 .50761 L 1 g
F
P
p
.002 w
.5661 .50939 m .56515 .50826 L p
.56696 .52 L 1 g
F P
s
P
p
.55661 .4905 m .5661 .50939 L .56364 .5041 L 1 g
F
P
p
.002 w
.56223 .50109 m .56245 .49949 L .5633 .50339 L p
1 g
F P
s
P
p
.56293 .5026 m .5668 .51022 L .56451 .50561 L 1 g
F
P
p
.55661 .4905 m .56364 .50412 L .56293 .5026 L 1 g
F
P
p
.56364 .50412 m .5668 .51022 L .56293 .5026 L 1 g
F
P
p
.002 w
.56917 .53027 m .5678 .53053 L p
.56768 .529 L 1 g
F P
s
P
p
.56829 .52657 m .56768 .529 L .56708 .52148 L 1 g
F
P
p
.56917 .53027 m .56768 .529 L .56829 .52657 L 1 g
F
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56917 .53027 m .57363 .55726 L p
.56356 .54135 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56155 .54717 L p
1 g
F P
s
P
p
.56654 .52734 m .56155 .54717 L .56445 .53877 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56727 .53063 m .56917 .53027 L p
.56356 .54135 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.54406 .58588 m .53843 .57478 L .55044 .56271 L 1 g
F
P
p
.002 w
.55148 .56207 m .54406 .58588 L p
.55044 .56271 L 1 g
F P
s
P
p
.002 w
.54932 .5634 m .54854 .56129 L p
.54087 .5686 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54932 .5634 L p
1 g
F P
s
P
p
.56075 .54566 m .54932 .5634 L .55058 .56208 L 1 g
F
P
p
.002 w
.55121 .56143 m .55166 .56149 L p
.53843 .57478 L 1 g
F P
s
P
p
.56075 .54566 m .55 .56302 L .55467 .55668 L 1 g
F
P
p
.55 .56302 m .55185 .56058 L .55467 .55668 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.53024 .55864 m .54694 .53084 L p
.55158 .56094 L 1 g
F P
s
P
p
.002 w
.55166 .56149 m .55121 .56143 L p
.55158 .56094 L 1 g
F P
s
P
p
.002 w
.55121 .56143 m .53024 .55864 L p
.55158 .56094 L 1 g
F P
s
P
p
.002 w
.55185 .56058 m .55166 .56149 L p
.55158 .56094 L 1 g
F P
s
P
p
.002 w
.55166 .56149 m .55148 .56207 L p
.55044 .56271 L 1 g
F P
s
P
p
.002 w
.55166 .56149 m .55185 .56058 L p
.55373 .55798 L 1 g
F P
s
P
p
.002 w
.55695 .56047 m .55166 .56149 L p
.55373 .55798 L 1 g
F P
s
P
p
.002 w
.56155 .54717 m .56075 .54566 L p
.55467 .55668 L 1 g
F P
s
P
p
.56155 .54717 m .55373 .55798 L .56356 .54135 L 1 g
F
P
p
.55695 .56047 m .55373 .55798 L .56155 .54717 L 1 g
F
P
p
.002 w
.57363 .55726 m .55695 .56047 L p
.56356 .54135 L 1 g
F P
s
P
p
.002 w
.55166 .56149 m .57363 .55726 L .57576 .57967 L p
1 g
F P
s
P
p
.002 w
.57576 .57967 m .54406 .58588 L .55166 .56149 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56155 .54717 L p
1 g
F P
s
P
p
.55467 .55668 m .54998 .56518 L .56155 .54717 L 1 g
F
P
p
.002 w
.54949 .56385 m .54998 .56518 L p
.55431 .55734 L 1 g
F P
s
P
p
.55467 .55668 m .55185 .56058 L .55431 .55734 L 1 g
F
P
p
.55185 .56058 m .54949 .56385 L .55431 .55734 L 1 g
F
P
p
.55 .56302 m .54949 .56385 L .55185 .56058 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54694 .53084 m .55788 .53238 L .55185 .56058 L p
1 g
F P
s
P
p
.55158 .56094 m .54694 .53084 L .55185 .56058 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53164 .57428 L p
1 g
F P
s
P
p
.54854 .56129 m .53164 .57428 L .54087 .5686 L 1 g
F
P
p
.002 w
.53024 .55864 m .55121 .56143 L p
.54932 .5634 L 1 g
F P
s
P
p
.53843 .57478 m .53662 .57121 L .54932 .5634 L 1 g
F
P
p
.53662 .57121 m .53024 .55864 L .54932 .5634 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54406 .58588 m .51301 .58195 L .51426 .58025 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58109 L p
1 g
F P
s
P
p
.50533 .58196 m .51097 .58109 L .51301 .58195 L 1 g
F
P
p
.002 w
.51126 .58105 m .51138 .58111 L p
.51097 .58109 L 1 g
F P
s
P
p
.002 w
.51138 .58111 m .51301 .58195 L p
.51097 .58109 L 1 g
F P
s
P
p
.002 w
.51301 .58195 m .50991 .58523 L p
.50533 .58196 L 1 g
F P
s
P
p
.002 w
.51097 .58109 m .51079 .57862 L p
.50076 .58063 L 1 g
F P
s
P
p
.53128 .57265 m .51097 .58109 L .51126 .58105 L 1 g
F
P
p
.53128 .57265 m .51126 .58105 L .51253 .58071 L 1 g
F
P
p
.002 w
.51301 .58195 m .51126 .58105 L p
.51295 .5806 L 1 g
F P
s
P
p
.002 w
.51426 .58025 m .51301 .58195 L p
.51295 .5806 L 1 g
F P
s
P
p
.53128 .57265 m .51099 .58137 L .52094 .57795 L 1 g
F
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58009 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58009 L .50076 .58063 L 1 g
F
P
p
.002 w
.48586 .56804 m .51126 .58105 L p
.51097 .58109 L 1 g
F P
s
P
p
.50533 .58196 m .50365 .58076 L .51097 .58109 L 1 g
F
P
p
.50365 .58076 m .48586 .56804 L .51097 .58109 L 1 g
F
P
p
.002 w
.47239 .57596 m .48586 .56804 L p
.48966 .58023 L 1 g
F P
s
P
p
.49587 .60012 m .47239 .57596 L .48966 .58023 L 1 g
F
P
p
.002 w
.50991 .58523 m .49587 .60012 L p
.48966 .58023 L 1 g
F P
s
P
p
.48966 .58023 m .48586 .56804 L .50991 .58523 L 1 g
F
P
p
.002 w
.4891 .58009 m .48889 .583 L p
.50076 .58063 L 1 g
F P
s
P
p
.002 w
.48586 .56804 m .51164 .5489 L p
.51295 .5806 L 1 g
F P
s
P
p
.002 w
.51126 .58105 m .48586 .56804 L p
.51295 .5806 L 1 g
F P
s
P
p
.51201 .58093 m .51126 .58105 L .51099 .58137 L 1 g
F
P
p
.002 w
.51097 .58109 m .51098 .58112 L p
.51126 .58105 L 1 g
F P
s
P
p
.002 w
.51098 .58112 m .51099 .58137 L p
.51126 .58105 L 1 g
F P
s
P
p
.51253 .58071 m .51126 .58105 L .51201 .58093 L 1 g
F
P
p
.002 w
.51164 .5489 m .53024 .55864 L .51426 .58025 L p
1 g
F P
s
P
p
.51295 .5806 m .51164 .5489 L .51426 .58025 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51097 .58109 L p
1 g
F P
s
P
p
.50076 .58063 m .48889 .583 L .51097 .58109 L 1 g
F
P
p
.54406 .58588 m .51426 .58025 L .5372 .57237 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.51426 .58025 m .53024 .55864 L p
.5372 .57237 L 1 g
F P
s
P
p
.002 w
.51099 .58137 m .51111 .583 L p
.52094 .57795 L 1 g
F P
s
P
p
.002 w
.53164 .57428 m .5322 .57686 L p
.54087 .5686 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54932 .5634 L p
1 g
F P
s
P
p
.54087 .5686 m .5322 .57686 L .54932 .5634 L 1 g
F
P
p
.002 w
.54932 .5634 m .54949 .56385 L p
.55058 .56208 L 1 g
F P
s
P
p
.56356 .54135 m .55373 .55798 L .55788 .53238 L 1 g
F
P
p
.002 w
.55185 .56058 m .55788 .53238 L p
.55373 .55798 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .5628 .54838 L p
.56456 .53846 L 1 g
F P
s
P
p
.56654 .52734 m .56445 .53877 L .56456 .53846 L 1 g
F
P
p
.56445 .53877 m .56257 .5491 L .56456 .53846 L 1 g
F
P
p
.002 w
.5678 .53053 m .56727 .53063 L p
.56768 .529 L 1 g
F P
s
P
p
.002 w
.5628 .54838 m .56854 .53025 L .56768 .529 L p
1 g
F P
s
P
p
.002 w
.56768 .529 m .56654 .52734 L p
.5628 .54838 L 1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56768 .529 L p
1 g
F P
s
P
p
.002 w
.56698 .52023 m .56917 .53027 L p
.56708 .52148 L 1 g
F P
s
P
p
.002 w
.57451 .52744 m .56917 .53027 L .56698 .52023 L p
1 g
F P
s
P
p
.56515 .50826 m .56768 .529 L .56696 .52 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.56698 .52023 m .5633 .50339 L p
.5661 .50939 L 1 g
F P
s
P
p
.57451 .52744 m .56698 .52023 L .5661 .50939 L 1 g
F
P
p
.56696 .52 m .56698 .52023 L .56854 .53025 L 1 g
F
P
p
.002 w
.56768 .529 m .56769 .52902 L p
.56698 .52023 L 1 g
F P
s
P
p
.002 w
.56769 .52902 m .56854 .53025 L p
.56698 .52023 L 1 g
F P
s
P
p
.55255 .48151 m .55464 .48248 L .5585 .49241 L 1 g
F
P
p
.55746 .4914 m .5585 .49241 L .56045 .49743 L 1 g
F
P
p
.55255 .48151 m .5585 .49241 L .55746 .4914 L 1 g
F
P
p
.002 w
.55746 .4914 m .55661 .4905 L p
.56297 .50267 L 1 g
F P
s
P
p
.002 w
.56195 .5005 m .56245 .49949 L .56223 .50109 L p
1 g
F P
s
P
p
.56297 .50267 m .56187 .50033 L .55746 .4914 L 1 g
F
P
p
.56187 .50033 m .56168 .49993 L .55746 .4914 L 1 g
F
P
p
.56168 .49993 m .56152 .4996 L .55746 .4914 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.5306 .51773 m .52702 .50751 L .56157 .49969 L p
1 g
F P
s
P
p
.002 w
.56157 .49969 m .56245 .49949 L .56168 .49993 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56168 .49993 m .5306 .51773 L p
.56157 .49969 L 1 g
F P
s
P
p
.56168 .49993 m .56157 .49969 L .56152 .4996 L 1 g
F
P
p
.002 w
.56118 .49891 m .56245 .49949 L .56142 .4994 L p
1 g
F P
s
P
p
.56157 .49969 m .56096 .49846 L .55746 .4914 L 1 g
F
P
p
.002 w
.53111 .48516 m .53836 .47551 L .56052 .49756 L p
1 g
F P
s
P
p
.002 w
.56052 .49756 m .56245 .49949 L .56118 .49891 L p
1 g
F P
s
P
p
.002 w
.56118 .49891 m .53111 .48516 L p
.56052 .49756 L 1 g
F P
s
P
p
.56118 .49891 m .56143 .49941 L .56096 .49846 L 1 g
F
P
p
.56157 .49969 m .5615 .49956 L .56118 .49891 L 1 g
F
P
p
.5615 .49956 m .56143 .49941 L .56118 .49891 L 1 g
F
P
p
.002 w
.52719 .49624 m .53111 .48516 L .56118 .49891 L p
1 g
F P
s
P
p
.002 w
.56142 .4994 m .52719 .49624 L p
.56118 .49891 L 1 g
F P
s
P
p
.002 w
.52702 .50751 m .52719 .49624 L .56142 .4994 L p
1 g
F P
s
P
p
.002 w
.56142 .4994 m .56245 .49949 L .56157 .49969 L p
1 g
F P
s
P
p
.002 w
.56157 .49969 m .52702 .50751 L p
.56142 .4994 L 1 g
F P
s
P
p
.56163 .49982 m .56158 .49971 L .56143 .49941 L 1 g
F
P
p
.002 w
.56168 .49993 m .56245 .49949 L .5618 .50018 L p
1 g
F P
s
P
p
.56187 .50033 m .56174 .50006 L .56163 .49982 L 1 g
F
P
p
.56174 .50006 m .56158 .49971 L .56163 .49982 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5375 .52579 m .5306 .51773 L .56168 .49993 L p
1 g
F P
s
P
p
.002 w
.5618 .50018 m .5375 .52579 L p
.56168 .49993 L 1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54694 .53084 m .5375 .52579 L .5618 .50018 L p
1 g
F P
s
P
p
.002 w
.5618 .50018 m .56245 .49949 L .56195 .5005 L p
1 g
F P
s
P
p
.002 w
.56195 .5005 m .54694 .53084 L p
.5618 .50018 L 1 g
F P
s
P
p
.56195 .5005 m .56451 .50561 L .56158 .49971 L 1 g
F
P
p
.56297 .50267 m .56306 .50285 L .56195 .5005 L 1 g
F
P
p
.56306 .50285 m .56451 .50561 L .56195 .5005 L 1 g
F
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55788 .53238 m .54694 .53084 L .56195 .5005 L p
1 g
F P
s
P
p
.002 w
.56223 .50109 m .55788 .53238 L p
.56195 .5005 L 1 g
F P
s
P
p
.002 w
.53836 .47551 m .53882 .47517 L p
.56045 .49743 L 1 g
F P
s
P
p
.002 w
.56245 .49949 m .56052 .49756 L p
.56045 .49743 L 1 g
F P
s
P
p
.002 w
.56052 .49756 m .53836 .47551 L p
.56045 .49743 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55746 .4914 L p
1 g
F P
s
P
p
.56451 .50561 m .56713 .51061 L .55746 .4914 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55034 .48451 L 1 g
F
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.53882 .47517 m .54244 .47684 L .56045 .49743 L 1 g
F
P
p
.002 w
.54244 .47684 m .54174 .47608 L p
.55034 .48451 L 1 g
F P
s
P
p
.54244 .47684 m .55255 .48151 L .55746 .4914 L 1 g
F
P
p
.54244 .47684 m .55746 .4914 L .56045 .49743 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54244 .47684 L p
1 g
F P
s
P
p
.55034 .48451 m .55834 .49233 L .54244 .47684 L 1 g
F
P
p
.002 w
.55746 .4914 m .55834 .49233 L p
.55034 .48451 L 1 g
F P
s
P
p
.002 w
.5633 .50339 m .56698 .52023 L p
.56223 .50109 L 1 g
F P
s
P
p
.56708 .52148 m .56223 .50109 L .56698 .52023 L 1 g
F
P
p
.56768 .529 m .55788 .53238 L .56708 .52148 L 1 g
F
P
p
.002 w
.56727 .53063 m .55788 .53238 L p
.56768 .529 L 1 g
F P
s
P
p
.002 w
.55788 .53238 m .56727 .53063 L p
.56356 .54135 L 1 g
F P
s
P
p
.002 w
.56155 .54717 m .56257 .5491 L p
.56445 .53877 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .5628 .54838 L p
.5644 .55256 L 1 g
F P
s
P
p
.002 w
.5628 .54838 m .56257 .5491 L .5626 .54916 L p
1 g
F P
s
P
p
.002 w
.5626 .54916 m .5644 .55256 L p
.5628 .54838 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56611 .50941 L p
1 g
F P
s
P
p
.002 w
.56611 .50941 m .5661 .50939 L p
.56614 .50973 L 1 g
F P
s
P
p
.56614 .50973 m .56854 .53025 L .56611 .50941 L 1 g
F
P
p
.002 w
.55788 .53238 m .56223 .50109 L p
.56708 .52148 L 1 g
F P
s
P
p
.56696 .52 m .56854 .53025 L .5661 .50939 L 1 g
F
P
p
.002 w
.5661 .50939 m .5668 .51022 L p
.56364 .5041 L 1 g
F P
s
P
p
.002 w
.56245 .49949 m .5796 .52475 L .57451 .52744 L p
1 g
F P
s
P
p
.002 w
.5668 .51022 m .56713 .51061 L p
.56451 .50561 L 1 g
F P
s
P
p
.002 w
.54244 .47684 m .54261 .47703 L p
.54014 .47578 L 1 g
F P
s
P
p
.52214 .46667 m .54244 .47684 L .54014 .47578 L 1 g
F
P
p
.52214 .46667 m .5416 .47652 L .53429 .47296 L 1 g
F
P
p
.5416 .47652 m .54261 .47703 L .53728 .47442 L 1 g
F
P
p
.5416 .47652 m .53728 .47442 L .53429 .47296 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54815 .46836 m .53882 .47517 L p
.51276 .4498 L 1 g
F P
s
P
p
.002 w
.53882 .47517 m .53836 .47551 L .53728 .47442 L p
1 g
F P
s
P
p
.002 w
.53728 .47442 m .51276 .4498 L p
.53882 .47517 L 1 g
F P
s
P
p
.002 w
.53882 .47517 m .54815 .46836 L .55464 .48248 L p
1 g
F P
s
P
p
.002 w
.53728 .47442 m .53836 .47551 L p
.52244 .46716 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52244 .46716 L p
1 g
F P
s
P
p
.002 w
.52244 .46716 m .52214 .46667 L p
.53429 .47296 L 1 g
F P
s
P
p
.53429 .47296 m .54302 .47747 L .52244 .46716 L 1 g
F
P
p
.002 w
.51276 .4498 m .5313 .46841 L p
.52244 .46716 L 1 g
F P
s
P
p
.51169 .46565 m .5228 .46775 L .52172 .46757 L 1 g
F
P
p
.5 .4634 m .51197 .46569 L .51169 .46565 L 1 g
F
P
p
.51197 .46569 m .5228 .46775 L .51169 .46565 L 1 g
F
P
p
.002 w
.50193 .46427 m .49842 .46895 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46395 L p
1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .4634 L p
.52172 .46757 L 1 g
F P
s
P
p
.52172 .46757 m .52282 .46778 L .5 .46395 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46395 L p
1 g
F P
s
P
p
.46567 .45148 m .50244 .46358 L .5 .46395 L 1 g
F
P
p
.47786 .46667 m .5 .46395 L .49632 .4645 L 1 g
F
P
p
.002 w
.49842 .46895 m .49145 .46523 L p
.5 .46395 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46407 L .4898 .46545 L 1 g
F
P
p
.002 w
.49145 .46523 m .48405 .46129 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.48405 .46129 m .46567 .45148 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.50193 .46427 m .50584 .45905 L p
.52244 .46716 L 1 g
F P
s
P
p
.002 w
.50584 .45905 m .51276 .4498 L p
.52244 .46716 L 1 g
F P
s
P
p
.002 w
.5313 .46841 m .53728 .47442 L p
.52244 .46716 L 1 g
F P
s
P
p
.002 w
.54261 .47703 m .54302 .47747 L p
.53429 .47296 L 1 g
F P
s
P
p
.002 w
.52244 .46716 m .5228 .46775 L p
.51197 .46569 L 1 g
F P
s
P
p
.002 w
.5228 .46775 m .52282 .46778 L p
.52172 .46757 L 1 g
F P
s
P
p
.002 w
.50244 .46358 m .50193 .46427 L p
.5 .46395 L 1 g
F P
s
P
p
.002 w
.5 .46395 m .5 .46407 L p
.49632 .4645 L 1 g
F P
s
P
p
.002 w
.5 .46407 m .5 .46442 L p
.4898 .46545 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46712 L p
1 g
F P
s
P
p
.002 w
.47759 .46712 m .47718 .46778 L p
.46695 .47227 L 1 g
F P
s
P
p
.45826 .47608 m .47759 .46712 L .46695 .47227 L 1 g
F
P
p
.002 w
.47725 .45765 m .48671 .4627 L p
.47759 .46712 L 1 g
F P
s
P
p
.45761 .47679 m .4659 .46871 L .47759 .46712 L 1 g
F
P
p
.4659 .46871 m .47725 .45765 L .47759 .46712 L 1 g
F
P
p
.002 w
.48671 .4627 m .49145 .46523 L p
.47759 .46712 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46712 L p
1 g
F P
s
P
p
.4898 .46545 m .5 .46442 L .47759 .46712 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45761 .47679 L p
1 g
F P
s
P
p
.46695 .47227 m .47718 .46778 L .45761 .47679 L 1 g
F
P
p
.002 w
.45761 .47679 m .45698 .47747 L p
.45242 .48185 L 1 g
F P
s
P
p
.44339 .4905 m .45761 .47679 L .45242 .48185 L 1 g
F
P
p
.002 w
.45674 .47764 m .46567 .45148 L .47725 .45765 L p
1 g
F P
s
P
p
.002 w
.46567 .45148 m .45674 .47764 L p
.42022 .47489 L 1 g
F P
s
P
p
.002 w
.45137 .48286 m .42022 .47489 L p
.45674 .47764 L 1 g
F P
s
P
p
.002 w
.4206 .51257 m .42022 .47489 L .45137 .48286 L p
1 g
F P
s
P
p
.002 w
.45137 .48286 m .45467 .4837 L p
.4206 .51257 L 1 g
F P
s
P
p
.002 w
.44276 .49117 m .44166 .49233 L p
.43736 .50239 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44276 .49117 L p
1 g
F P
s
P
p
.45166 .48257 m .45698 .47747 L .44276 .49117 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43411 .50914 L p
1 g
F P
s
P
p
.43736 .50239 m .44166 .49233 L .43411 .50914 L 1 g
F
P
p
.002 w
.43411 .50914 m .43363 .50972 L p
.43359 .51394 L 1 g
F P
s
P
p
.002 w
.45467 .4837 m .45473 .51623 L .43331 .51648 L p
1 g
F P
s
P
p
.002 w
.43331 .51648 m .45473 .51623 L p
.43276 .52837 L 1 g
F P
s
P
p
.002 w
.43363 .50972 m .43287 .51061 L p
.43318 .51929 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43276 .52837 L p
1 g
F P
s
P
p
.43318 .51929 m .43287 .51061 L .43276 .52837 L 1 g
F
P
p
.002 w
.43494 .55386 m .42427 .52609 L p
.43847 .54715 L 1 g
F P
s
P
p
.002 w
.42427 .52609 m .42064 .51662 L p
.43847 .54715 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43846 .54715 L p
1 g
F P
s
P
p
.43614 .53951 m .43146 .53025 L .43846 .54715 L 1 g
F
P
p
.43847 .54715 m .43846 .54714 L .45473 .51623 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45023 .56461 L p
1 g
F P
s
P
p
.002 w
.45023 .56461 m .45096 .56263 L p
.44463 .5563 L 1 g
F P
s
P
p
.44463 .5563 m .43743 .5491 L .45023 .56461 L 1 g
F
P
p
.002 w
.43846 .54715 m .43743 .5491 L p
.44309 .55402 L 1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45473 .51623 m .46562 .54538 L .44172 .55198 L p
1 g
F P
s
P
p
.43847 .54715 m .45473 .51623 L .44172 .55198 L 1 g
F
P
p
.002 w
.44172 .55198 m .46562 .54538 L p
.46198 .57533 L 1 g
F P
s
P
p
.44469 .55541 m .43743 .5491 L .45096 .56263 L 1 g
F
P
p
.002 w
.45096 .56263 m .45002 .56518 L p
.46145 .56975 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46834 .57441 L p
1 g
F P
s
P
p
.46145 .56975 m .45002 .56518 L .46834 .57441 L 1 g
F
P
p
.002 w
.46834 .57441 m .46822 .57494 L p
.47095 .57542 L 1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46562 .54538 m .48586 .56804 L .47239 .57596 L p
1 g
F P
s
P
p
.002 w
.46822 .57494 m .4678 .57686 L p
.48012 .57787 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58009 L p
1 g
F P
s
P
p
.48012 .57787 m .4678 .57686 L .4891 .58009 L 1 g
F
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.59388 .54648 m .61036 .53027 L .62866 .54074 L p
1 g
F P
s
P
p
.002 w
.6446 .51197 m .62866 .54074 L .61036 .53027 L p
1 g
F P
s
P
p
.002 w
.66647 .43218 m .64885 .39759 L .65966 .37398 L p
1 g
F P
s
P
p
.002 w
.62538 .34285 m .65966 .37398 L .64885 .39759 L p
1 g
F P
s
P
p
.002 w
.51021 .27298 m .44943 .29216 L .43664 .27471 L p
1 g
F P
s
P
p
.002 w
.38152 .31435 m .43664 .27471 L .44943 .29216 L p
1 g
F P
s
P
p
.002 w
.65107 .48061 m .64722 .44982 L .66647 .43218 L p
1 g
F P
s
P
p
.002 w
.64885 .39759 m .66647 .43218 L .64722 .44982 L p
1 g
F P
s
P
p
.002 w
.61036 .53027 m .62137 .51029 L .6446 .51197 L p
1 g
F P
s
P
p
.002 w
.65107 .48061 m .6446 .51197 L .62137 .51029 L p
1 g
F P
s
P
p
.002 w
.44943 .29216 m .39648 .3303 L .38152 .31435 L p
1 g
F P
s
P
p
.002 w
.37939 .39841 m .36132 .45399 L .3388 .44273 L p
1 g
F P
s
P
p
.002 w
.3388 .44273 m .35806 .38272 L .37939 .39841 L p
1 g
F P
s
P
p
.002 w
.62137 .51029 m .62575 .48857 L .65107 .48061 L p
1 g
F P
s
P
p
.002 w
.64722 .44982 m .65107 .48061 L .62575 .48857 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52171 .45449 L
s
P
p
.002 w
.38874 .46485 m .38959 .5144 L .36262 .50972 L p
1 g
F P
s
P
p
.002 w
.36262 .50972 m .36132 .45399 L .38874 .46485 L p
1 g
F P
s
P
p
.002 w
.42064 .51662 m .43494 .55386 L .40692 .55844 L p
1 g
F P
s
P
p
.002 w
.40692 .55844 m .38959 .5144 L .42064 .51662 L p
1 g
F P
s
P
p
.002 w
.57704 .29775 m .52049 .29645 L .51021 .27298 L p
1 g
F P
s
P
p
.004 w
.55206 .27738 m
.55888 .25732 L
s
P
p
.002 w
.44943 .29216 m .51021 .27298 L .52049 .29645 L p
1 g
F P
s
P
p
.002 w
.62538 .34285 m .58071 .32558 L .57704 .29775 L p
1 g
F P
s
P
p
.002 w
.52049 .29645 m .57704 .29775 L .58071 .32558 L p
1 g
F P
s
P
p
.004 w
.54291 .30428 m
.54326 .30326 L
s
P
p
.002 w
.64885 .39759 m .61974 .37156 L .62538 .34285 L p
1 g
F P
s
P
p
.002 w
.58071 .32558 m .62538 .34285 L .61974 .37156 L p
1 g
F P
s
P
p
.002 w
.64722 .44982 m .63322 .42286 L .64885 .39759 L p
1 g
F P
s
P
p
.002 w
.61974 .37156 m .64885 .39759 L .63322 .42286 L p
1 g
F P
s
P
p
.002 w
.4151 .34984 m .37939 .39841 L .35806 .38272 L p
1 g
F P
s
P
p
.002 w
.35806 .38272 m .39648 .3303 L .4151 .34984 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.56917 .53027 m .5796 .52475 L .59388 .54648 L p
1 g
F P
s
P
p
.002 w
.59388 .54648 m .57363 .55726 L .56917 .53027 L p
1 g
F P
s
P
p
.002 w
.61036 .53027 m .59388 .54648 L .5796 .52475 L p
1 g
F P
s
P
p
.002 w
.5796 .52475 m .58807 .5164 L .61036 .53027 L p
1 g
F P
s
P
p
.002 w
.62137 .51029 m .61036 .53027 L .58807 .5164 L p
1 g
F P
s
P
p
.002 w
.62575 .48857 m .62295 .46736 L .64722 .44982 L p
1 g
F P
s
P
p
.002 w
.63322 .42286 m .64722 .44982 L .62295 .46736 L p
1 g
F P
s
P
p
.002 w
.39648 .3303 m .44943 .29216 L .46419 .31442 L p
1 g
F P
s
P
p
.002 w
.52049 .29645 m .46419 .31442 L .44943 .29216 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.54203 .30687 L
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.58807 .5164 m .59371 .50611 L .62137 .51029 L p
1 g
F P
s
P
p
.002 w
.62575 .48857 m .62137 .51029 L .59371 .50611 L p
1 g
F P
s
P
p
.002 w
.46419 .31442 m .4151 .34984 L .39648 .3303 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.40502 .41551 m .38874 .46485 L .36132 .45399 L p
1 g
F P
s
P
p
.002 w
.36132 .45399 m .37939 .39841 L .40502 .41551 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.42022 .47489 m .42064 .51662 L .38959 .5144 L p
1 g
F P
s
P
p
.002 w
.38959 .5144 m .38874 .46485 L .42022 .47489 L p
1 g
F P
s
P
p
.002 w
.59371 .50611 m .59589 .49496 L .62575 .48857 L p
1 g
F P
s
P
p
.002 w
.62295 .46736 m .62575 .48857 L .59589 .49496 L p
1 g
F P
s
P
p
.002 w
.49791 .53321 m .51164 .5489 L .48586 .56804 L p
1 g
F P
s
P
p
.002 w
.48586 .56804 m .46562 .54538 L .49791 .53321 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.58071 .32558 m .53044 .32471 L .52049 .29645 L p
1 g
F P
s
P
p
.004 w
.54326 .30326 m
.55206 .27738 L
s
P
p
.002 w
.46419 .31442 m .52049 .29645 L .53044 .32471 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.63322 .42286 m .61029 .40274 L .61974 .37156 L p
1 g
F P
s
P
p
.002 w
.58198 .35731 m .61974 .37156 L .61029 .40274 L p
1 g
F P
s
P
p
.002 w
.61974 .37156 m .58198 .35731 L .58071 .32558 L p
1 g
F P
s
P
p
.002 w
.62295 .46736 m .61315 .4489 L .63322 .42286 L p
1 g
F P
s
P
p
.002 w
.61029 .40274 m .63322 .42286 L .61315 .4489 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.53044 .32471 m .58071 .32558 L .58198 .35731 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.5375 .52579 m .54694 .53084 L .53024 .55864 L p
1 g
F P
s
P
p
.002 w
.53024 .55864 m .51164 .5489 L .5375 .52579 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59589 .49496 m .59437 .48413 L .62295 .46736 L p
1 g
F P
s
P
p
.002 w
.61315 .4489 m .62295 .46736 L .59437 .48413 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43685 .37241 m .40502 .41551 L .37939 .39841 L p
1 g
F P
s
P
p
.002 w
.37939 .39841 m .4151 .34984 L .43685 .37241 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58807 .5164 m .5796 .52475 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.59371 .50611 m .58807 .5164 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.53044 .32471 m .48045 .34088 L .46419 .31442 L p
1 g
F P
s
P
p
.002 w
.4151 .34984 m .46419 .31442 L .48045 .34088 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.59589 .49496 m .59371 .50611 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.49065 .51316 m .49791 .53321 L .46562 .54538 L p
1 g
F P
s
P
p
.002 w
.46562 .54538 m .45473 .51623 L .49065 .51316 L p
1 g
F P
s
P
p
.002 w
.5306 .51773 m .5375 .52579 L .51164 .5489 L p
1 g
F P
s
P
p
.002 w
.51164 .5489 m .49791 .53321 L .5306 .51773 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.48045 .34088 m .43685 .37241 L .4151 .34984 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43413 .43343 m .42022 .47489 L .38874 .46485 L p
1 g
F P
s
P
p
.002 w
.38874 .46485 m .40502 .41551 L .43413 .43343 L p
1 g
F P
s
P
p
.002 w
.59437 .48413 m .59589 .49496 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.59437 .48413 m .58928 .47478 L .61315 .4489 L p
1 g
F P
s
P
p
.002 w
.59728 .43527 m .61315 .4489 L .58928 .47478 L p
1 g
F P
s
P
p
.002 w
.61315 .4489 m .59728 .43527 L .61029 .40274 L p
1 g
F P
s
P
p
.002 w
.58074 .39189 m .61029 .40274 L .59728 .43527 L p
1 g
F P
s
P
p
.002 w
.61029 .40274 m .58074 .39189 L .58198 .35731 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58198 .35731 m .53965 .35687 L .53044 .32471 L p
1 g
F P
s
P
p
.002 w
.48045 .34088 m .53044 .32471 L .53965 .35687 L p
1 g
F P
s
P
p
.002 w
.53965 .35687 m .58198 .35731 L .58074 .39189 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.58928 .47478 m .59437 .48413 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.52702 .50751 m .5306 .51773 L .49791 .53321 L p
1 g
F P
s
P
p
.002 w
.49791 .53321 m .49065 .51316 L .52702 .50751 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58113 .46793 m .58928 .47478 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.58928 .47478 m .58113 .46793 L .59728 .43527 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57697 .42803 m .59728 .43527 L .58113 .46793 L p
1 g
F P
s
P
p
.002 w
.59728 .43527 m .57697 .42803 L .58074 .39189 L p
1 g
F P
s
P
p
.002 w
.49079 .49091 m .49065 .51316 L .45473 .51623 L p
1 g
F P
s
P
p
.002 w
.45473 .51623 m .45467 .4837 L .49079 .49091 L p
1 g
F P
s
P
p
.002 w
.46098 .39722 m .43413 .43343 L .40502 .41551 L p
1 g
F P
s
P
p
.002 w
.40502 .41551 m .43685 .37241 L .46098 .39722 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57079 .46437 m .58113 .46793 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.55938 .46451 m .57079 .46437 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.54815 .46836 m .55938 .46451 L .56245 .49949 L closepath p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.43685 .37241 m .48045 .34088 L .49763 .37065 L p
1 g
F P
s
P
p
.002 w
.53965 .35687 m .49763 .37065 L .48045 .34088 L p
1 g
F P
s
P
p
.002 w
.42022 .47489 m .43413 .43343 L .46567 .45148 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.54776 .39178 m .58074 .39189 L .57697 .42803 L p
1 g
F P
s
P
p
.002 w
.58074 .39189 m .54776 .39178 L .53965 .35687 L p
1 g
F P
s
P
p
.002 w
.58113 .46793 m .57079 .46437 L .57697 .42803 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.004 w
.56245 .49949 m
.56283 .49991 L
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.004 w
.56337 .50051 m
.56445 .5017 L
s
P
p
.002 w
.49763 .37065 m .46098 .39722 L .43685 .37241 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.49763 .37065 m .53965 .35687 L .54776 .39178 L p
1 g
F P
s
P
p
.002 w
.52719 .49624 m .52702 .50751 L .49065 .51316 L p
1 g
F P
s
P
p
.002 w
.49065 .51316 m .49079 .49091 L .52719 .49624 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.57079 .46437 m .55938 .46451 L .55442 .42813 L p
1 g
F P
s
P
p
.002 w
.55442 .42813 m .57697 .42803 L .57079 .46437 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57697 .42803 m .55442 .42813 L .54776 .39178 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.004 w
.56445 .5017 m
.56466 .50192 L
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.53111 .48516 m .52719 .49624 L .49079 .49091 L p
1 g
F P
s
P
p
.002 w
.49842 .46895 m .49079 .49091 L .45467 .4837 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55938 .46451 m .54815 .46836 L .53217 .43565 L p
1 g
F P
s
P
p
.002 w
.53217 .43565 m .55442 .42813 L .55938 .46451 L p
1 g
F P
s
P
p
.002 w
.48662 .42335 m .46567 .45148 L .43413 .43343 L p
1 g
F P
s
P
p
.002 w
.43413 .43343 m .46098 .39722 L .48662 .42335 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.53836 .47551 m .53111 .48516 L .49842 .46895 L p
1 g
F P
s
P
p
.002 w
.49079 .49091 m .49842 .46895 L .53111 .48516 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.5151 .40265 m .54776 .39178 L .55442 .42813 L p
1 g
F P
s
P
p
.002 w
.54776 .39178 m .5151 .40265 L .49763 .37065 L p
1 g
F P
s
P
p
.002 w
.51276 .4498 m .53217 .43565 L .54815 .46836 L p
1 g
F P
s
P
p
.002 w
.46098 .39722 m .49763 .37065 L .5151 .40265 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.004 w
.5652 .50253 m
.5665 .50396 L
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.55442 .42813 m .53217 .43565 L .5151 .40265 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.5151 .40265 m .48662 .42335 L .46098 .39722 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.46567 .45148 m .48662 .42335 L .51276 .4498 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.004 w
.56705 .50457 m
.56835 .50601 L
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.53217 .43565 m .51276 .4498 L .48662 .42335 L p
1 g
F P
s
P
p
.002 w
.48662 .42335 m .5151 .40265 L .53217 .43565 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.004 w
.56891 .50662 m
.57022 .50807 L
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.004 w
.57078 .50869 m
.5721 .51015 L
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.004 w
.57267 .51077 m
.574 .51224 L
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.004 w
.57457 .51287 m
.57591 .51435 L
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.57648 .51499 m
.57783 .51648 L
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.004 w
.57841 .51712 m
.57977 .51862 L
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.004 w
.58173 .52078 m
.6005 .54151 L
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .56915 .22711 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .6005 .54151 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.629457)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.629457)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4707 .48786 m .50986 .47343 L .49632 .44854 L p
1 g
F P
s
P
p
.002 w
.49632 .44854 m .46371 .46045 L .4707 .48786 L p
1 g
F P
s
P
p
.002 w
.52467 .42803 m .49632 .44854 L .50986 .47343 L p
1 g
F P
s
P
p
.002 w
.46371 .46045 m .49632 .44854 L .48291 .42331 L p
1 g
F P
s
P
p
.002 w
.49632 .44854 m .52467 .42803 L .50487 .4074 L p
1 g
F P
s
P
p
.002 w
.50487 .4074 m .48291 .42331 L .49632 .44854 L p
1 g
F P
s
P
p
.002 w
.48291 .42331 m .45762 .43245 L .46371 .46045 L p
1 g
F P
s
P
p
.002 w
.45762 .43245 m .48291 .42331 L .46987 .39816 L p
1 g
F P
s
P
p
.002 w
.48291 .42331 m .50487 .4074 L .4849 .38727 L p
1 g
F P
s
P
p
.002 w
.4849 .38727 m .46987 .39816 L .48291 .42331 L p
1 g
F P
s
P
p
.002 w
.52132 .38631 m .50487 .4074 L .52467 .42803 L p
1 g
F P
s
P
p
.002 w
.50487 .4074 m .52132 .38631 L .49609 .3728 L p
1 g
F P
s
P
p
.002 w
.49609 .3728 m .4849 .38727 L .50487 .4074 L p
1 g
F P
s
P
p
.002 w
.50986 .47343 m .54393 .44879 L .52467 .42803 L p
1 g
F P
s
P
p
.002 w
.54601 .40088 m .52467 .42803 L .54393 .44879 L p
1 g
F P
s
P
p
.002 w
.52467 .42803 m .54601 .40088 L .52132 .38631 L p
1 g
F P
s
P
p
.002 w
.42996 .46251 m .46371 .46045 L .45762 .43245 L p
1 g
F P
s
P
p
.002 w
.45762 .43245 m .4315 .43388 L .42996 .46251 L p
1 g
F P
s
P
p
.002 w
.4315 .43388 m .45762 .43245 L .45256 .40437 L p
1 g
F P
s
P
p
.002 w
.46987 .39816 m .45256 .40437 L .45762 .43245 L p
1 g
F P
s
P
p
.002 w
.47849 .51416 m .52329 .4975 L .50986 .47343 L p
1 g
F P
s
P
p
.002 w
.50986 .47343 m .4707 .48786 L .47849 .51416 L p
1 g
F P
s
P
p
.002 w
.54393 .44879 m .50986 .47343 L .52329 .4975 L p
1 g
F P
s
P
p
.002 w
.45256 .40437 m .46987 .39816 L .45745 .37357 L p
1 g
F P
s
P
p
.002 w
.46987 .39816 m .4849 .38727 L .46511 .36801 L p
1 g
F P
s
P
p
.002 w
.46511 .36801 m .45745 .37357 L .46987 .39816 L p
1 g
F P
s
P
p
.002 w
.4849 .38727 m .49609 .3728 L .47078 .36061 L p
1 g
F P
s
P
p
.002 w
.47078 .36061 m .46511 .36801 L .4849 .38727 L p
1 g
F P
s
P
p
.002 w
.43012 .49058 m .4707 .48786 L .46371 .46045 L p
1 g
F P
s
P
p
.002 w
.46371 .46045 m .42996 .46251 L .43012 .49058 L p
1 g
F P
s
P
p
.002 w
.52329 .4975 m .56232 .46931 L .54393 .44879 L p
1 g
F P
s
P
p
.002 w
.56972 .41624 m .54393 .44879 L .56232 .46931 L p
1 g
F P
s
P
p
.002 w
.54393 .44879 m .56972 .41624 L .54601 .40088 L p
1 g
F P
s
P
p
.002 w
.53056 .36208 m .52132 .38631 L .54601 .40088 L p
1 g
F P
s
P
p
.002 w
.52132 .38631 m .53056 .36208 L .50228 .35622 L p
1 g
F P
s
P
p
.002 w
.50228 .35622 m .49609 .3728 L .52132 .38631 L p
1 g
F P
s
P
p
.002 w
.45256 .40437 m .43471 .40523 L .4315 .43388 L p
1 g
F P
s
P
p
.002 w
.43471 .40523 m .45256 .40437 L .44861 .3767 L p
1 g
F P
s
P
p
.002 w
.45745 .37357 m .44861 .3767 L .45256 .40437 L p
1 g
F P
s
P
p
.002 w
.55818 .36964 m .54601 .40088 L .56972 .41624 L p
1 g
F P
s
P
p
.002 w
.54601 .40088 m .55818 .36964 L .53056 .36208 L p
1 g
F P
s
P
p
.002 w
.49609 .3728 m .50228 .35622 L .47387 .35216 L p
1 g
F P
s
P
p
.002 w
.47387 .35216 m .47078 .36061 L .49609 .3728 L p
1 g
F P
s
P
p
.002 w
.43201 .51756 m .47849 .51416 L .4707 .48786 L p
1 g
F P
s
P
p
.002 w
.4707 .48786 m .43012 .49058 L .43201 .51756 L p
1 g
F P
s
P
p
.002 w
.39839 .45429 m .42996 .46251 L .4315 .43388 L p
1 g
F P
s
P
p
.002 w
.4315 .43388 m .40717 .4273 L .39839 .45429 L p
1 g
F P
s
P
p
.002 w
.40717 .4273 m .4315 .43388 L .43471 .40523 L p
1 g
F P
s
P
p
.002 w
.43471 .40523 m .41817 .40059 L .40717 .4273 L p
1 g
F P
s
P
p
.002 w
.41817 .40059 m .43471 .40523 L .43952 .37708 L p
1 g
F P
s
P
p
.002 w
.44861 .3767 m .43952 .37708 L .43471 .40523 L p
1 g
F P
s
P
p
.002 w
.48695 .53883 m .53635 .5203 L .52329 .4975 L p
1 g
F P
s
P
p
.002 w
.52329 .4975 m .47849 .51416 L .48695 .53883 L p
1 g
F P
s
P
p
.002 w
.56232 .46931 m .52329 .4975 L .53635 .5203 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .44861 .3767 L .45745 .37357 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .45745 .37357 L .46511 .36801 L closepath p
1 g
F P
s
P
p
.002 w
.56232 .46931 m .59199 .43214 L .56972 .41624 L p
1 g
F P
s
P
p
.002 w
.58462 .37876 m .56972 .41624 L .59199 .43214 L p
1 g
F P
s
P
p
.002 w
.56972 .41624 m .58462 .37876 L .55818 .36964 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .46511 .36801 L .47078 .36061 L closepath p
1 g
F P
s
P
p
.002 w
.53635 .5203 m .57946 .48919 L .56232 .46931 L p
1 g
F P
s
P
p
.002 w
.59199 .43214 m .56232 .46931 L .57946 .48919 L p
1 g
F P
s
P
p
.002 w
.50275 .33921 m .50228 .35622 L .53056 .36208 L p
1 g
F P
s
P
p
.002 w
.50228 .35622 m .50275 .33921 L .47402 .34352 L p
1 g
F P
s
P
p
.002 w
.47402 .34352 m .47387 .35216 L .50228 .35622 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .43952 .37708 L .44861 .3767 L closepath p
1 g
F P
s
P
p
.002 w
.5315 .33713 m .53056 .36208 L .55818 .36964 L p
1 g
F P
s
P
p
.002 w
.53056 .36208 m .5315 .33713 L .50275 .33921 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .47078 .36061 L .47387 .35216 L closepath p
1 g
F P
s
P
p
.002 w
.39202 .48102 m .43012 .49058 L .42996 .46251 L p
1 g
F P
s
P
p
.002 w
.42996 .46251 m .39839 .45429 L .39202 .48102 L p
1 g
F P
s
P
p
.002 w
.43952 .37708 m .43115 .37465 L .41817 .40059 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .43115 .37465 L .43952 .37708 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .47387 .35216 L .47402 .34352 L closepath p
1 g
F P
s
P
p
.002 w
.55972 .33734 m .55818 .36964 L .58462 .37876 L p
1 g
F P
s
P
p
.002 w
.55818 .36964 m .55972 .33734 L .5315 .33713 L p
1 g
F P
s
P
p
.002 w
.43564 .54288 m .48695 .53883 L .47849 .51416 L p
1 g
F P
s
P
p
.002 w
.47849 .51416 m .43201 .51756 L .43564 .54288 L p
1 g
F P
s
P
p
.002 w
.38722 .41321 m .40717 .4273 L .41817 .40059 L p
1 g
F P
s
P
p
.002 w
.41817 .40059 m .4047 .39085 L .38722 .41321 L p
1 g
F P
s
P
p
.002 w
.4047 .39085 m .41817 .40059 L .43115 .37465 L p
1 g
F P
s
P
p
.002 w
.43115 .37465 m .42438 .36964 L .4047 .39085 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .42438 .36964 L .43115 .37465 L closepath p
1 g
F P
s
P
p
.002 w
.4712 .33565 m .47402 .34352 L .50275 .33921 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .47402 .34352 L .4712 .33565 L closepath p
1 g
F P
s
P
p
.002 w
.49736 .32358 m .50275 .33921 L .5315 .33713 L p
1 g
F P
s
P
p
.002 w
.50275 .33921 m .49736 .32358 L .4712 .33565 L p
1 g
F P
s
P
p
.002 w
.57946 .48919 m .61237 .44827 L .59199 .43214 L p
1 g
F P
s
P
p
.002 w
.60936 .3893 m .59199 .43214 L .61237 .44827 L p
1 g
F P
s
P
p
.002 w
.59199 .43214 m .60936 .3893 L .58462 .37876 L p
1 g
F P
s
P
p
.002 w
.38825 .50697 m .43201 .51756 L .43012 .49058 L p
1 g
F P
s
P
p
.002 w
.43012 .49058 m .39202 .48102 L .38825 .50697 L p
1 g
F P
s
P
p
.002 w
.37233 .43631 m .39839 .45429 L .40717 .4273 L p
1 g
F P
s
P
p
.002 w
.40717 .4273 m .38722 .41321 L .37233 .43631 L p
1 g
F P
s
P
p
.002 w
.49591 .56135 m .54879 .54136 L .53635 .5203 L p
1 g
F P
s
P
p
.002 w
.53635 .5203 m .48695 .53883 L .49591 .56135 L p
1 g
F P
s
P
p
.002 w
.57946 .48919 m .53635 .5203 L .54879 .54136 L p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .44908 .32424 L .43982 .32598 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .43982 .32598 L .43127 .33046 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .43127 .33046 L .4244 .33718 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .4244 .33718 L .41996 .3454 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .41996 .3454 L .41844 .35418 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .41844 .35418 L .41998 .36257 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .41998 .36257 L .42438 .36964 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .4712 .33565 L .46568 .32938 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .46568 .32938 L .45803 .32542 L closepath p
1 g
F P
s
P
p
.002 w
.44587 .34998 m .45803 .32542 L .44908 .32424 L closepath p
1 g
F P
s
P
p
.002 w
.39582 .37696 m .4047 .39085 L .42438 .36964 L p
1 g
F P
s
P
p
.002 w
.42438 .36964 m .41998 .36257 L .39582 .37696 L p
1 g
F P
s
P
p
.002 w
.52384 .31406 m .5315 .33713 L .55972 .33734 L p
1 g
F P
s
P
p
.002 w
.5315 .33713 m .52384 .31406 L .49736 .32358 L p
1 g
F P
s
P
p
.002 w
.54879 .54136 m .59499 .50804 L .57946 .48919 L p
1 g
F P
s
P
p
.002 w
.61237 .44827 m .57946 .48919 L .59499 .50804 L p
1 g
F P
s
P
p
.002 w
.46568 .32938 m .4712 .33565 L .49736 .32358 L p
1 g
F P
s
P
p
.002 w
.58685 .33988 m .58462 .37876 L .60936 .3893 L p
1 g
F P
s
P
p
.002 w
.58462 .37876 m .58685 .33988 L .55972 .33734 L p
1 g
F P
s
P
p
.002 w
.37391 .39291 m .38722 .41321 L .4047 .39085 L p
1 g
F P
s
P
p
.002 w
.4047 .39085 m .39582 .37696 L .37391 .39291 L p
1 g
F P
s
P
p
.002 w
.36038 .45968 m .39202 .48102 L .39839 .45429 L p
1 g
F P
s
P
p
.002 w
.39839 .45429 m .37233 .43631 L .36038 .45968 L p
1 g
F P
s
P
p
.002 w
.3926 .36036 m .39582 .37696 L .41998 .36257 L p
1 g
F P
s
P
p
.002 w
.41998 .36257 m .41844 .35418 L .3926 .36036 L p
1 g
F P
s
P
p
.002 w
.49736 .32358 m .48657 .31105 L .46568 .32938 L p
1 g
F P
s
P
p
.002 w
.45803 .32542 m .46568 .32938 L .48657 .31105 L p
1 g
F P
s
P
p
.002 w
.48657 .31105 m .49736 .32358 L .52384 .31406 L p
1 g
F P
s
P
p
.002 w
.44099 .56597 m .49591 .56135 L .48695 .53883 L p
1 g
F P
s
P
p
.002 w
.48695 .53883 m .43564 .54288 L .44099 .56597 L p
1 g
F P
s
P
p
.002 w
.38723 .53157 m .43564 .54288 L .43201 .51756 L p
1 g
F P
s
P
p
.002 w
.43201 .51756 m .38825 .50697 L .38723 .53157 L p
1 g
F P
s
P
p
.002 w
.55011 .30731 m .55972 .33734 L .58685 .33988 L p
1 g
F P
s
P
p
.002 w
.55972 .33734 m .55011 .30731 L .52384 .31406 L p
1 g
F P
s
P
p
.002 w
.39549 .34285 m .3926 .36036 L .41844 .35418 L p
1 g
F P
s
P
p
.002 w
.41844 .35418 m .41996 .3454 L .39549 .34285 L p
1 g
F P
s
P
p
.002 w
.48657 .31105 m .47146 .30305 L .45803 .32542 L p
1 g
F P
s
P
p
.002 w
.44908 .32424 m .45803 .32542 L .47146 .30305 L p
1 g
F P
s
P
p
.002 w
.59499 .50804 m .63039 .46432 L .61237 .44827 L p
1 g
F P
s
P
p
.002 w
.63184 .40109 m .61237 .44827 L .63039 .46432 L p
1 g
F P
s
P
p
.002 w
.61237 .44827 m .63184 .40109 L .60936 .3893 L p
1 g
F P
s
P
p
.002 w
.35476 .41013 m .37233 .43631 L .38722 .41321 L p
1 g
F P
s
P
p
.002 w
.38722 .41321 m .37391 .39291 L .35476 .41013 L p
1 g
F P
s
P
p
.002 w
.40428 .3264 m .39549 .34285 L .41996 .3454 L p
1 g
F P
s
P
p
.002 w
.41996 .3454 m .4244 .33718 L .40428 .3264 L p
1 g
F P
s
P
p
.002 w
.6123 .34475 m .60936 .3893 L .63184 .40109 L p
1 g
F P
s
P
p
.002 w
.60936 .3893 m .6123 .34475 L .58685 .33988 L p
1 g
F P
s
P
p
.002 w
.36891 .36844 m .37391 .39291 L .39582 .37696 L p
1 g
F P
s
P
p
.002 w
.39582 .37696 m .3926 .36036 L .36891 .36844 L p
1 g
F P
s
P
p
.002 w
.47146 .30305 m .45364 .30057 L .44908 .32424 L p
1 g
F P
s
P
p
.002 w
.43982 .32598 m .44908 .32424 L .45364 .30057 L p
1 g
F P
s
P
p
.002 w
.50814 .29541 m .52384 .31406 L .55011 .30731 L p
1 g
F P
s
P
p
.002 w
.52384 .31406 m .50814 .29541 L .48657 .31105 L p
1 g
F P
s
P
p
.002 w
.35172 .48285 m .38825 .50697 L .39202 .48102 L p
1 g
F P
s
P
p
.002 w
.39202 .48102 m .36038 .45968 L .35172 .48285 L p
1 g
F P
s
P
p
.002 w
.41801 .31292 m .40428 .3264 L .4244 .33718 L p
1 g
F P
s
P
p
.002 w
.4244 .33718 m .43127 .33046 L .41801 .31292 L p
1 g
F P
s
P
p
.002 w
.47146 .30305 m .48657 .31105 L .50814 .29541 L p
1 g
F P
s
P
p
.002 w
.45364 .30057 m .43512 .30397 L .43982 .32598 L p
1 g
F P
s
P
p
.002 w
.43127 .33046 m .43982 .32598 L .43512 .30397 L p
1 g
F P
s
P
p
.002 w
.50523 .58116 m .56034 .56019 L .54879 .54136 L p
1 g
F P
s
P
p
.002 w
.54879 .54136 m .49591 .56135 L .50523 .58116 L p
1 g
F P
s
P
p
.002 w
.59499 .50804 m .54879 .54136 L .56034 .56019 L p
1 g
F P
s
P
p
.002 w
.43512 .30397 m .41801 .31292 L .43127 .33046 L p
1 g
F P
s
P
p
.002 w
.56034 .56019 m .60855 .52545 L .59499 .50804 L p
1 g
F P
s
P
p
.002 w
.63039 .46432 m .59499 .50804 L .60855 .52545 L p
1 g
F P
s
P
p
.002 w
.57565 .30355 m .58685 .33988 L .6123 .34475 L p
1 g
F P
s
P
p
.002 w
.58685 .33988 m .57565 .30355 L .55011 .30731 L p
1 g
F P
s
P
p
.002 w
.33886 .42829 m .36038 .45968 L .37233 .43631 L p
1 g
F P
s
P
p
.002 w
.37233 .43631 m .35476 .41013 L .33886 .42829 L p
1 g
F P
s
P
p
.002 w
.37303 .34246 m .36891 .36844 L .3926 .36036 L p
1 g
F P
s
P
p
.002 w
.3926 .36036 m .39549 .34285 L .37303 .34246 L p
1 g
F P
s
P
p
.002 w
.38909 .55424 m .44099 .56597 L .43564 .54288 L p
1 g
F P
s
P
p
.002 w
.43564 .54288 m .38723 .53157 L .38909 .55424 L p
1 g
F P
s
P
p
.002 w
.50814 .29541 m .48592 .28339 L .47146 .30305 L p
1 g
F P
s
P
p
.002 w
.45364 .30057 m .47146 .30305 L .48592 .28339 L p
1 g
F P
s
P
p
.002 w
.44801 .58625 m .50523 .58116 L .49591 .56135 L p
1 g
F P
s
P
p
.002 w
.49591 .56135 m .44099 .56597 L .44801 .58625 L p
1 g
F P
s
P
p
.002 w
.34797 .37832 m .35476 .41013 L .37391 .39291 L p
1 g
F P
s
P
p
.002 w
.37391 .39291 m .36891 .36844 L .34797 .37832 L p
1 g
F P
s
P
p
.002 w
.52997 .28286 m .55011 .30731 L .57565 .30355 L p
1 g
F P
s
P
p
.002 w
.55011 .30731 m .52997 .28286 L .50814 .29541 L p
1 g
F P
s
P
p
.002 w
.60855 .52545 m .6456 .47996 L .63039 .46432 L p
1 g
F P
s
P
p
.002 w
.65154 .41392 m .63039 .46432 L .6456 .47996 L p
1 g
F P
s
P
p
.002 w
.63039 .46432 m .65154 .41392 L .63184 .40109 L p
1 g
F P
s
P
p
.002 w
.6355 .35193 m .63184 .40109 L .65154 .41392 L p
1 g
F P
s
P
p
.002 w
.63184 .40109 m .6355 .35193 L .6123 .34475 L p
1 g
F P
s
P
p
.002 w
.48592 .28339 m .50814 .29541 L .52997 .28286 L p
1 g
F P
s
P
p
.002 w
.34667 .50529 m .38723 .53157 L .38825 .50697 L p
1 g
F P
s
P
p
.002 w
.38825 .50697 m .35172 .48285 L .34667 .50529 L p
1 g
F P
s
P
p
.002 w
.38599 .31796 m .37303 .34246 L .39549 .34285 L p
1 g
F P
s
P
p
.002 w
.39549 .34285 m .40428 .3264 L .38599 .31796 L p
1 g
F P
s
P
p
.002 w
.43512 .30397 m .45364 .30057 L .45952 .27955 L p
1 g
F P
s
P
p
.002 w
.48592 .28339 m .45952 .27955 L .45364 .30057 L p
1 g
F P
s
P
p
.002 w
.59986 .30296 m .6123 .34475 L .6355 .35193 L p
1 g
F P
s
P
p
.002 w
.6123 .34475 m .59986 .30296 L .57565 .30355 L p
1 g
F P
s
P
p
.002 w
.40642 .29784 m .38599 .31796 L .40428 .3264 L p
1 g
F P
s
P
p
.002 w
.40428 .3264 m .41801 .31292 L .40642 .29784 L p
1 g
F P
s
P
p
.002 w
.45952 .27955 m .43194 .28453 L .43512 .30397 L p
1 g
F P
s
P
p
.002 w
.41801 .31292 m .43512 .30397 L .43194 .28453 L p
1 g
F P
s
P
p
.002 w
.3267 .44703 m .35172 .48285 L .36038 .45968 L p
1 g
F P
s
P
p
.002 w
.36038 .45968 m .33886 .42829 L .3267 .44703 L p
1 g
F P
s
P
p
.002 w
.51472 .59773 m .57071 .57629 L .56034 .56019 L p
1 g
F P
s
P
p
.002 w
.56034 .56019 m .50523 .58116 L .51472 .59773 L p
1 g
F P
s
P
p
.002 w
.60855 .52545 m .56034 .56019 L .57071 .57629 L p
1 g
F P
s
P
p
.002 w
.43194 .28453 m .40642 .29784 L .41801 .31292 L p
1 g
F P
s
P
p
.002 w
.57071 .57629 m .61975 .54098 L .60855 .52545 L p
1 g
F P
s
P
p
.002 w
.6456 .47996 m .60855 .52545 L .61975 .54098 L p
1 g
F P
s
P
p
.002 w
.35314 .34435 m .34797 .37832 L .36891 .36844 L p
1 g
F P
s
P
p
.002 w
.36891 .36844 m .37303 .34246 L .35314 .34435 L p
1 g
F P
s
P
p
.002 w
.33035 .38987 m .33886 .42829 L .35476 .41013 L p
1 g
F P
s
P
p
.002 w
.35476 .41013 m .34797 .37832 L .33035 .38987 L p
1 g
F P
s
P
p
.002 w
.39391 .57437 m .44801 .58625 L .44099 .56597 L p
1 g
F P
s
P
p
.002 w
.44099 .56597 m .38909 .55424 L .39391 .57437 L p
1 g
F P
s
P
p
.002 w
.55161 .27379 m .57565 .30355 L .59986 .30296 L p
1 g
F P
s
P
p
.002 w
.57565 .30355 m .55161 .27379 L .52997 .28286 L p
1 g
F P
s
P
p
.002 w
.52997 .28286 m .50114 .26696 L .48592 .28339 L p
1 g
F P
s
P
p
.002 w
.45952 .27955 m .48592 .28339 L .50114 .26696 L p
1 g
F P
s
P
p
.002 w
.50114 .26696 m .52997 .28286 L .55161 .27379 L p
1 g
F P
s
P
p
.002 w
.45663 .60313 m .51472 .59773 L .50523 .58116 L p
1 g
F P
s
P
p
.002 w
.50523 .58116 m .44801 .58625 L .45663 .60313 L p
1 g
F P
s
P
p
.002 w
.34551 .52645 m .38909 .55424 L .38723 .53157 L p
1 g
F P
s
P
p
.002 w
.38723 .53157 m .34667 .50529 L .34551 .52645 L p
1 g
F P
s
P
p
.002 w
.6456 .47996 m .6679 .42756 L .65154 .41392 L p
1 g
F P
s
P
p
.002 w
.65584 .36135 m .65154 .41392 L .6679 .42756 L p
1 g
F P
s
P
p
.002 w
.65154 .41392 m .65584 .36135 L .6355 .35193 L p
1 g
F P
s
P
p
.002 w
.61975 .54098 m .65753 .49483 L .6456 .47996 L p
1 g
F P
s
P
p
.002 w
.6679 .42756 m .6456 .47996 L .65753 .49483 L p
1 g
F P
s
P
p
.002 w
.37004 .31216 m .35314 .34435 L .37303 .34246 L p
1 g
F P
s
P
p
.002 w
.37303 .34246 m .38599 .31796 L .37004 .31216 L p
1 g
F P
s
P
p
.002 w
.43194 .28453 m .45952 .27955 L .46664 .26177 L p
1 g
F P
s
P
p
.002 w
.50114 .26696 m .46664 .26177 L .45952 .27955 L p
1 g
F P
s
P
p
.002 w
.62216 .30567 m .6355 .35193 L .65584 .36135 L p
1 g
F P
s
P
p
.002 w
.6355 .35193 m .62216 .30567 L .59986 .30296 L p
1 g
F P
s
P
p
.002 w
.31874 .46593 m .34667 .50529 L .35172 .48285 L p
1 g
F P
s
P
p
.002 w
.35172 .48285 m .3267 .44703 L .31874 .46593 L p
1 g
F P
s
P
p
.002 w
.39686 .28569 m .37004 .31216 L .38599 .31796 L p
1 g
F P
s
P
p
.002 w
.38599 .31796 m .40642 .29784 L .39686 .28569 L p
1 g
F P
s
P
p
.002 w
.33643 .34857 m .33035 .38987 L .34797 .37832 L p
1 g
F P
s
P
p
.002 w
.34797 .37832 m .35314 .34435 L .33643 .34857 L p
1 g
F P
s
P
p
.002 w
.46664 .26177 m .43043 .2682 L .43194 .28453 L p
1 g
F P
s
P
p
.002 w
.40642 .29784 m .43194 .28453 L .43043 .2682 L p
1 g
F P
s
P
p
.002 w
.31662 .40288 m .3267 .44703 L .33886 .42829 L p
1 g
F P
s
P
p
.002 w
.33886 .42829 m .33035 .38987 L .31662 .40288 L p
1 g
F P
s
P
p
.002 w
.57253 .26855 m .59986 .30296 L .62216 .30567 L p
1 g
F P
s
P
p
.002 w
.59986 .30296 m .57253 .26855 L .55161 .27379 L p
1 g
F P
s
P
p
.002 w
.52417 .6105 m .57961 .58917 L .57071 .57629 L p
1 g
F P
s
P
p
.002 w
.57071 .57629 m .51472 .59773 L .52417 .6105 L p
1 g
F P
s
P
p
.002 w
.61975 .54098 m .57071 .57629 L .57961 .58917 L p
1 g
F P
s
P
p
.002 w
.43043 .2682 m .39686 .28569 L .40642 .29784 L p
1 g
F P
s
P
p
.002 w
.57961 .58917 m .62822 .55418 L .61975 .54098 L p
1 g
F P
s
P
p
.002 w
.65753 .49483 m .61975 .54098 L .62822 .55418 L p
1 g
F P
s
P
p
.002 w
.55161 .27379 m .51682 .25429 L .50114 .26696 L p
1 g
F P
s
P
p
.002 w
.46664 .26177 m .50114 .26696 L .51682 .25429 L p
1 g
F P
s
P
p
.002 w
.40173 .59136 m .45663 .60313 L .44801 .58625 L p
1 g
F P
s
P
p
.002 w
.44801 .58625 m .39391 .57437 L .40173 .59136 L p
1 g
F P
s
P
p
.002 w
.51682 .25429 m .55161 .27379 L .57253 .26855 L p
1 g
F P
s
P
p
.002 w
.34844 .54576 m .39391 .57437 L .38909 .55424 L p
1 g
F P
s
P
p
.002 w
.38909 .55424 m .34551 .52645 L .34844 .54576 L p
1 g
F P
s
P
p
.002 w
.46672 .61602 m .52417 .6105 L .51472 .59773 L p
1 g
F P
s
P
p
.002 w
.51472 .59773 m .45663 .60313 L .46672 .61602 L p
1 g
F P
s
P
p
.002 w
.65753 .49483 m .6804 .44173 L .6679 .42756 L p
1 g
F P
s
P
p
.002 w
.67273 .37289 m .6679 .42756 L .6804 .44173 L p
1 g
F P
s
P
p
.002 w
.6679 .42756 m .67273 .37289 L .65584 .36135 L p
1 g
F P
s
P
p
.002 w
.62822 .55418 m .66574 .50855 L .65753 .49483 L p
1 g
F P
s
P
p
.002 w
.6804 .44173 m .65753 .49483 L .66574 .50855 L p
1 g
F P
s
P
p
.002 w
.35693 .30928 m .33643 .34857 L .35314 .34435 L p
1 g
F P
s
P
p
.002 w
.35314 .34435 m .37004 .31216 L .35693 .30928 L p
1 g
F P
s
P
p
.002 w
.64193 .31177 m .65584 .36135 L .67273 .37289 L p
1 g
F P
s
P
p
.002 w
.65584 .36135 m .64193 .31177 L .62216 .30567 L p
1 g
F P
s
P
p
.002 w
.31539 .48453 m .34551 .52645 L .34667 .50529 L p
1 g
F P
s
P
p
.002 w
.34667 .50529 m .31874 .46593 L .31539 .48453 L p
1 g
F P
s
P
p
.002 w
.51682 .25429 m .4749 .2478 L .46664 .26177 L p
1 g
F P
s
P
p
.002 w
.43043 .2682 m .46664 .26177 L .4749 .2478 L p
1 g
F P
s
P
p
.002 w
.30735 .41711 m .31874 .46593 L .3267 .44703 L p
1 g
F P
s
P
p
.002 w
.3267 .44703 m .31662 .40288 L .30735 .41711 L p
1 g
F P
s
P
p
.002 w
.32348 .35516 m .31662 .40288 L .33035 .38987 L p
1 g
F P
s
P
p
.002 w
.33035 .38987 m .33643 .34857 L .32348 .35516 L p
1 g
F P
s
P
p
.002 w
.59223 .26745 m .62216 .30567 L .64193 .31177 L p
1 g
F P
s
P
p
.002 w
.62216 .30567 m .59223 .26745 L .57253 .26855 L p
1 g
F P
s
P
p
.002 w
.38968 .27691 m .35693 .30928 L .37004 .31216 L p
1 g
F P
s
P
p
.002 w
.37004 .31216 m .39686 .28569 L .38968 .27691 L p
1 g
F P
s
P
p
.002 w
.4749 .2478 m .43071 .25555 L .43043 .2682 L p
1 g
F P
s
P
p
.002 w
.39686 .28569 m .43043 .2682 L .43071 .25555 L p
1 g
F P
s
P
p
.002 w
.57253 .26855 m .53259 .24587 L .51682 .25429 L p
1 g
F P
s
P
p
.002 w
.4749 .2478 m .51682 .25429 L .53259 .24587 L p
1 g
F P
s
P
p
.002 w
.53259 .24587 m .57253 .26855 L .59223 .26745 L p
1 g
F P
s
P
p
.002 w
.53334 .61895 m .58673 .59833 L .57961 .58917 L p
1 g
F P
s
P
p
.002 w
.57961 .58917 m .52417 .6105 L .53334 .61895 L p
1 g
F P
s
P
p
.002 w
.62822 .55418 m .57961 .58917 L .58673 .59833 L p
1 g
F P
s
P
p
.002 w
.43071 .25555 m .38968 .27691 L .39686 .28569 L p
1 g
F P
s
P
p
.002 w
.41251 .60459 m .46672 .61602 L .45663 .60313 L p
1 g
F P
s
P
p
.002 w
.45663 .60313 m .40173 .59136 L .41251 .60459 L p
1 g
F P
s
P
p
.002 w
.58673 .59833 m .63361 .5646 L .62822 .55418 L p
1 g
F P
s
P
p
.002 w
.66574 .50855 m .62822 .55418 L .63361 .5646 L p
1 g
F P
s
P
p
.002 w
.35562 .56261 m .40173 .59136 L .39391 .57437 L p
1 g
F P
s
P
p
.002 w
.39391 .57437 m .34844 .54576 L .35562 .56261 L p
1 g
F P
s
P
p
.002 w
.66574 .50855 m .68853 .45613 L .6804 .44173 L p
1 g
F P
s
P
p
.002 w
.68556 .38637 m .6804 .44173 L .68853 .45613 L p
1 g
F P
s
P
p
.002 w
.6804 .44173 m .68556 .38637 L .67273 .37289 L p
1 g
F P
s
P
p
.002 w
.47811 .62437 m .53334 .61895 L .52417 .6105 L p
1 g
F P
s
P
p
.002 w
.52417 .6105 m .46672 .61602 L .47811 .62437 L p
1 g
F P
s
P
p
.002 w
.31698 .50233 m .34844 .54576 L .34551 .52645 L p
1 g
F P
s
P
p
.002 w
.34551 .52645 m .31539 .48453 L .31698 .50233 L p
1 g
F P
s
P
p
.002 w
.65856 .32129 m .67273 .37289 L .68556 .38637 L p
1 g
F P
s
P
p
.002 w
.67273 .37289 m .65856 .32129 L .64193 .31177 L p
1 g
F P
s
P
p
.002 w
.34716 .30958 m .32348 .35516 L .33643 .34857 L p
1 g
F P
s
P
p
.002 w
.33643 .34857 m .35693 .30928 L .34716 .30958 L p
1 g
F P
s
P
p
.002 w
.63361 .5646 m .66981 .52071 L .66574 .50855 L p
1 g
F P
s
P
p
.002 w
.68853 .45613 m .66574 .50855 L .66981 .52071 L p
1 g
F P
s
P
p
.002 w
.53259 .24587 m .48416 .23821 L .4749 .2478 L p
1 g
F P
s
P
p
.002 w
.43071 .25555 m .4749 .2478 L .48416 .23821 L p
1 g
F P
s
P
p
.002 w
.30303 .43226 m .31539 .48453 L .31874 .46593 L p
1 g
F P
s
P
p
.002 w
.31874 .46593 m .30735 .41711 L .30303 .43226 L p
1 g
F P
s
P
p
.002 w
.61012 .27072 m .64193 .31177 L .65856 .32129 L p
1 g
F P
s
P
p
.002 w
.64193 .31177 m .61012 .27072 L .59223 .26745 L p
1 g
F P
s
P
p
.002 w
.31485 .36409 m .30735 .41711 L .31662 .40288 L p
1 g
F P
s
P
p
.002 w
.31662 .40288 m .32348 .35516 L .31485 .36409 L p
1 g
F P
s
P
p
.002 w
.54808 .24214 m .59223 .26745 L .61012 .27072 L p
1 g
F P
s
P
p
.002 w
.59223 .26745 m .54808 .24214 L .53259 .24587 L p
1 g
F P
s
P
p
.002 w
.48416 .23821 m .53259 .24587 L .54808 .24214 L p
1 g
F P
s
P
p
.002 w
.38519 .27195 m .34716 .30958 L .35693 .30928 L p
1 g
F P
s
P
p
.002 w
.35693 .30928 m .38968 .27691 L .38519 .27195 L p
1 g
F P
s
P
p
.002 w
.48416 .23821 m .43289 .24714 L .43071 .25555 L p
1 g
F P
s
P
p
.002 w
.38968 .27691 m .43071 .25555 L .43289 .24714 L p
1 g
F P
s
P
p
.002 w
.42612 .61352 m .47811 .62437 L .46672 .61602 L p
1 g
F P
s
P
p
.002 w
.46672 .61602 m .41251 .60459 L .42612 .61352 L p
1 g
F P
s
P
p
.002 w
.36707 .57642 m .41251 .60459 L .40173 .59136 L p
1 g
F P
s
P
p
.002 w
.40173 .59136 m .35562 .56261 L .36707 .57642 L p
1 g
F P
s
P
p
.002 w
.54198 .62258 m .5918 .6033 L .58673 .59833 L p
1 g
F P
s
P
p
.002 w
.58673 .59833 m .53334 .61895 L .54198 .62258 L p
1 g
F P
s
P
p
.002 w
.63361 .5646 m .58673 .59833 L .5918 .6033 L p
1 g
F P
s
P
p
.002 w
.43289 .24714 m .38519 .27195 L .38968 .27691 L p
1 g
F P
s
P
p
.002 w
.5918 .6033 m .63558 .57181 L .63361 .5646 L p
1 g
F P
s
P
p
.002 w
.66981 .52071 m .63361 .5646 L .63558 .57181 L p
1 g
F P
s
P
p
.002 w
.66981 .52071 m .69182 .47038 L .68853 .45613 L p
1 g
F P
s
P
p
.002 w
.6938 .40156 m .68853 .45613 L .69182 .47038 L p
1 g
F P
s
P
p
.002 w
.68853 .45613 m .6938 .40156 L .68556 .38637 L p
1 g
F P
s
P
p
.002 w
.32374 .51879 m .35562 .56261 L .34844 .54576 L p
1 g
F P
s
P
p
.002 w
.34844 .54576 m .31698 .50233 L .32374 .51879 L p
1 g
F P
s
P
p
.002 w
.67144 .33415 m .68556 .38637 L .6938 .40156 L p
1 g
F P
s
P
p
.002 w
.68556 .38637 m .67144 .33415 L .65856 .32129 L p
1 g
F P
s
P
p
.002 w
.49056 .62767 m .54198 .62258 L .53334 .61895 L p
1 g
F P
s
P
p
.002 w
.53334 .61895 m .47811 .62437 L .49056 .62767 L p
1 g
F P
s
P
p
.002 w
.34122 .31325 m .31485 .36409 L .32348 .35516 L p
1 g
F P
s
P
p
.002 w
.32348 .35516 m .34716 .30958 L .34122 .31325 L p
1 g
F P
s
P
p
.002 w
.63558 .57181 m .66938 .53089 L .66981 .52071 L p
1 g
F P
s
P
p
.002 w
.69182 .47038 m .66981 .52071 L .66938 .53089 L p
1 g
F P
s
P
p
.002 w
.30406 .44796 m .31698 .50233 L .31539 .48453 L p
1 g
F P
s
P
p
.002 w
.31539 .48453 m .30303 .43226 L .30406 .44796 L p
1 g
F P
s
P
p
.002 w
.62564 .27852 m .65856 .32129 L .67144 .33415 L p
1 g
F P
s
P
p
.002 w
.65856 .32129 m .62564 .27852 L .61012 .27072 L p
1 g
F P
s
P
p
.002 w
.54808 .24214 m .49425 .23353 L .48416 .23821 L p
1 g
F P
s
P
p
.002 w
.43289 .24714 m .48416 .23821 L .49425 .23353 L p
1 g
F P
s
P
p
.002 w
.31105 .37525 m .30303 .43226 L .30735 .41711 L p
1 g
F P
s
P
p
.002 w
.30735 .41711 m .31485 .36409 L .31105 .37525 L p
1 g
F P
s
P
p
.002 w
.56285 .24347 m .61012 .27072 L .62564 .27852 L p
1 g
F P
s
P
p
.002 w
.61012 .27072 m .56285 .24347 L .54808 .24214 L p
1 g
F P
s
P
p
.002 w
.49425 .23353 m .54808 .24214 L .56285 .24347 L p
1 g
F P
s
P
p
.002 w
.3827 .58661 m .42612 .61352 L .41251 .60459 L p
1 g
F P
s
P
p
.002 w
.41251 .60459 m .36707 .57642 L .3827 .58661 L p
1 g
F P
s
P
p
.002 w
.38371 .27119 m .34122 .31325 L .34716 .30958 L p
1 g
F P
s
P
p
.002 w
.34716 .30958 m .38519 .27195 L .38371 .27119 L p
1 g
F P
s
P
p
.002 w
.44234 .61762 m .49056 .62767 L .47811 .62437 L p
1 g
F P
s
P
p
.002 w
.47811 .62437 m .42612 .61352 L .44234 .61762 L p
1 g
F P
s
P
p
.002 w
.49425 .23353 m .43703 .24346 L .43289 .24714 L p
1 g
F P
s
P
p
.002 w
.38519 .27195 m .43289 .24714 L .43703 .24346 L p
1 g
F P
s
P
p
.002 w
.54982 .62098 m .59453 .60367 L .5918 .6033 L p
1 g
F P
s
P
p
.002 w
.5918 .6033 m .54198 .62258 L .54982 .62098 L p
1 g
F P
s
P
p
.002 w
.63558 .57181 m .5918 .6033 L .59453 .60367 L p
1 g
F P
s
P
p
.004 w
.68523 .30535 m
.70032 .29516 L
s
P
p
.002 w
.33577 .53334 m .36707 .57642 L .35562 .56261 L p
1 g
F P
s
P
p
.002 w
.35562 .56261 m .32374 .51879 L .33577 .53334 L p
1 g
F P
s
P
p
.002 w
.43703 .24346 m .38371 .27119 L .38519 .27195 L p
1 g
F P
s
P
p
.002 w
.59453 .60367 m .63385 .57539 L .63558 .57181 L p
1 g
F P
s
P
p
.002 w
.66938 .53089 m .63558 .57181 L .63385 .57539 L p
1 g
F P
s
P
p
.002 w
.66938 .53089 m .68989 .4841 L .69182 .47038 L p
1 g
F P
s
P
p
.002 w
.69182 .47038 m .69695 .41812 L .6938 .40156 L p
1 g
F P
s
P
p
.002 w
.69695 .41812 m .69182 .47038 L .68989 .4841 L p
1 g
F P
s
P
p
.002 w
.6938 .40156 m .68 .35018 L .67144 .33415 L p
1 g
F P
s
P
p
.002 w
.68 .35018 m .6938 .40156 L .69695 .41812 L p
1 g
F P
s
P
p
.002 w
.5038 .62553 m .54982 .62098 L .54198 .62258 L p
1 g
F P
s
P
p
.002 w
.54198 .62258 m .49056 .62767 L .5038 .62553 L p
1 g
F P
s
P
p
.002 w
.31073 .46376 m .32374 .51879 L .31698 .50233 L p
1 g
F P
s
P
p
.002 w
.31698 .50233 m .30406 .44796 L .31073 .46376 L p
1 g
F P
s
P
p
.002 w
.67144 .33415 m .63821 .2909 L .62564 .27852 L p
1 g
F P
s
P
p
.002 w
.63821 .2909 m .67144 .33415 L .68 .35018 L p
1 g
F P
s
P
p
.002 w
.33952 .32041 m .31105 .37525 L .31485 .36409 L p
1 g
F P
s
P
p
.002 w
.31485 .36409 m .34122 .31325 L .33952 .32041 L p
1 g
F P
s
P
p
.002 w
.63385 .57539 m .66417 .53869 L .66938 .53089 L p
1 g
F P
s
P
p
.002 w
.68989 .4841 m .66938 .53089 L .66417 .53869 L p
1 g
F P
s
P
p
.002 w
.31249 .38845 m .30406 .44796 L .30303 .43226 L p
1 g
F P
s
P
p
.002 w
.30303 .43226 m .31105 .37525 L .31249 .38845 L p
1 g
F P
s
P
p
.002 w
.56285 .24347 m .50491 .23419 L .49425 .23353 L p
1 g
F P
s
P
p
.002 w
.43703 .24346 m .49425 .23353 L .50491 .23419 L p
1 g
F P
s
P
p
.002 w
.62564 .27852 m .57643 .25013 L .56285 .24347 L p
1 g
F P
s
P
p
.002 w
.57643 .25013 m .62564 .27852 L .63821 .2909 L p
1 g
F P
s
P
p
.002 w
.50491 .23419 m .56285 .24347 L .57643 .25013 L p
1 g
F P
s
P
p
.002 w
.40228 .59267 m .44234 .61762 L .42612 .61352 L p
1 g
F P
s
P
p
.002 w
.42612 .61352 m .3827 .58661 L .40228 .59267 L p
1 g
F P
s
P
p
.002 w
.46084 .6165 m .5038 .62553 L .49056 .62767 L p
1 g
F P
s
P
p
.002 w
.49056 .62767 m .44234 .61762 L .46084 .6165 L p
1 g
F P
s
P
p
.002 w
.38548 .27494 m .33952 .32041 L .34122 .31325 L p
1 g
F P
s
P
p
.002 w
.34122 .31325 m .38371 .27119 L .38548 .27494 L p
1 g
F P
s
P
p
.002 w
.35299 .54544 m .3827 .58661 L .36707 .57642 L p
1 g
F P
s
P
p
.002 w
.36707 .57642 m .33577 .53334 L .35299 .54544 L p
1 g
F P
s
P
p
.002 w
.50491 .23419 m .44314 .24494 L .43703 .24346 L p
1 g
F P
s
P
p
.002 w
.38371 .27119 m .43703 .24346 L .44314 .24494 L p
1 g
F P
s
P
p
.002 w
.68989 .4841 m .69465 .43567 L .69695 .41812 L p
1 g
F P
s
P
p
.002 w
.68375 .36908 m .69695 .41812 L .69465 .43567 L p
1 g
F P
s
P
p
.002 w
.69695 .41812 m .68375 .36908 L .68 .35018 L p
1 g
F P
s
P
p
.002 w
.66417 .53869 m .6825 .49684 L .68989 .4841 L p
1 g
F P
s
P
p
.002 w
.69465 .43567 m .68989 .4841 L .6825 .49684 L p
1 g
F P
s
P
p
.002 w
.55657 .61386 m .59468 .59913 L .59453 .60367 L p
1 g
F P
s
P
p
.002 w
.59453 .60367 m .54982 .62098 L .55657 .61386 L p
1 g
F P
s
P
p
.002 w
.63385 .57539 m .59453 .60367 L .59468 .59913 L p
1 g
F P
s
P
p
.002 w
.44314 .24494 m .38548 .27494 L .38371 .27119 L p
1 g
F P
s
P
p
.002 w
.59468 .59913 m .62823 .575 L .63385 .57539 L p
1 g
F P
s
P
p
.002 w
.66417 .53869 m .63385 .57539 L .62823 .575 L p
1 g
F P
s
P
p
.002 w
.32317 .47918 m .33577 .53334 L .32374 .51879 L p
1 g
F P
s
P
p
.002 w
.32374 .51879 m .31073 .46376 L .32317 .47918 L p
1 g
F P
s
P
p
.002 w
.6473 .30772 m .68 .35018 L .68375 .36908 L p
1 g
F P
s
P
p
.002 w
.68 .35018 m .6473 .30772 L .63821 .2909 L p
1 g
F P
s
P
p
.002 w
.51746 .61767 m .55657 .61386 L .54982 .62098 L p
1 g
F P
s
P
p
.002 w
.54982 .62098 m .5038 .62553 L .51746 .61767 L p
1 g
F P
s
P
p
.002 w
.34239 .33106 m .31249 .38845 L .31105 .37525 L p
1 g
F P
s
P
p
.002 w
.31105 .37525 m .33952 .32041 L .34239 .33106 L p
1 g
F P
s
P
p
.002 w
.31946 .4034 m .31073 .46376 L .30406 .44796 L p
1 g
F P
s
P
p
.002 w
.30406 .44796 m .31249 .38845 L .31946 .4034 L p
1 g
F P
s
P
p
.002 w
.62823 .575 m .65404 .54372 L .66417 .53869 L p
1 g
F P
s
P
p
.002 w
.6825 .49684 m .66417 .53869 L .65404 .54372 L p
1 g
F P
s
P
p
.002 w
.58835 .26224 m .63821 .2909 L .6473 .30772 L p
1 g
F P
s
P
p
.002 w
.63821 .2909 m .58835 .26224 L .57643 .25013 L p
1 g
F P
s
P
p
.002 w
.57643 .25013 m .51589 .24051 L .50491 .23419 L p
1 g
F P
s
P
p
.002 w
.44314 .24494 m .50491 .23419 L .51589 .24051 L p
1 g
F P
s
P
p
.002 w
.51589 .24051 m .57643 .25013 L .58835 .26224 L p
1 g
F P
s
P
p
.002 w
.42539 .5942 m .46084 .6165 L .44234 .61762 L p
1 g
F P
s
P
p
.002 w
.44234 .61762 m .40228 .59267 L .42539 .5942 L p
1 g
F P
s
P
p
.002 w
.3751 .55457 m .40228 .59267 L .3827 .58661 L p
1 g
F P
s
P
p
.002 w
.3827 .58661 m .35299 .54544 L .3751 .55457 L p
1 g
F P
s
P
p
.002 w
.48115 .60991 m .51746 .61767 L .5038 .62553 L p
1 g
F P
s
P
p
.002 w
.5038 .62553 m .46084 .6165 L .48115 .60991 L p
1 g
F P
s
P
p
.002 w
.6825 .49684 m .68663 .45372 L .69465 .43567 L p
1 g
F P
s
P
p
.002 w
.68232 .39043 m .69465 .43567 L .68663 .45372 L p
1 g
F P
s
P
p
.002 w
.69465 .43567 m .68232 .39043 L .68375 .36908 L p
1 g
F P
s
P
p
.002 w
.39066 .28338 m .34239 .33106 L .33952 .32041 L p
1 g
F P
s
P
p
.002 w
.33952 .32041 m .38548 .27494 L .39066 .28338 L p
1 g
F P
s
P
p
.002 w
.65404 .54372 m .66953 .50816 L .6825 .49684 L p
1 g
F P
s
P
p
.002 w
.68663 .45372 m .6825 .49684 L .66953 .50816 L p
1 g
F P
s
P
p
.002 w
.51589 .24051 m .45117 .25187 L .44314 .24494 L p
1 g
F P
s
P
p
.002 w
.38548 .27494 m .44314 .24494 L .45117 .25187 L p
1 g
F P
s
P
p
.002 w
.34126 .49371 m .35299 .54544 L .33577 .53334 L p
1 g
F P
s
P
p
.002 w
.33577 .53334 m .32317 .47918 L .34126 .49371 L p
1 g
F P
s
P
p
.002 w
.65242 .32872 m .68375 .36908 L .68232 .39043 L p
1 g
F P
s
P
p
.002 w
.68375 .36908 m .65242 .32872 L .6473 .30772 L p
1 g
F P
s
P
p
.004 w
.67104 .31494 m
.68523 .30535 L
s
P
p
.002 w
.56195 .6011 m .59209 .58948 L .59468 .59913 L p
1 g
F P
s
P
p
.002 w
.59468 .59913 m .55657 .61386 L .56195 .6011 L p
1 g
F P
s
P
p
.002 w
.62823 .575 m .59468 .59913 L .59209 .58948 L p
1 g
F P
s
P
p
.002 w
.45117 .25187 m .39066 .28338 L .38548 .27494 L p
1 g
F P
s
P
p
.002 w
.59209 .58948 m .61863 .57038 L .62823 .575 L p
1 g
F P
s
P
p
.002 w
.65404 .54372 m .62823 .575 L .61863 .57038 L p
1 g
F P
s
P
p
.002 w
.35004 .34509 m .31946 .4034 L .31249 .38845 L p
1 g
F P
s
P
p
.002 w
.31249 .38845 m .34239 .33106 L .35004 .34509 L p
1 g
F P
s
P
p
.002 w
.33204 .41972 m .32317 .47918 L .31073 .46376 L p
1 g
F P
s
P
p
.002 w
.31073 .46376 m .31946 .4034 L .33204 .41972 L p
1 g
F P
s
P
p
.002 w
.53113 .60401 m .56195 .6011 L .55657 .61386 L p
1 g
F P
s
P
p
.002 w
.55657 .61386 m .51746 .61767 L .53113 .60401 L p
1 g
F P
s
P
p
.002 w
.59812 .27972 m .6473 .30772 L .65242 .32872 L p
1 g
F P
s
P
p
.002 w
.6473 .30772 m .59812 .27972 L .58835 .26224 L p
1 g
F P
s
P
p
.002 w
.61863 .57038 m .63899 .54564 L .65404 .54372 L p
1 g
F P
s
P
p
.002 w
.66953 .50816 m .65404 .54372 L .63899 .54564 L p
1 g
F P
s
P
p
.002 w
.58835 .26224 m .52684 .25265 L .51589 .24051 L p
1 g
F P
s
P
p
.002 w
.45117 .25187 m .51589 .24051 L .52684 .25265 L p
1 g
F P
s
P
p
.002 w
.45143 .59091 m .48115 .60991 L .46084 .6165 L p
1 g
F P
s
P
p
.002 w
.46084 .6165 m .42539 .5942 L .45143 .59091 L p
1 g
F P
s
P
p
.002 w
.52684 .25265 m .58835 .26224 L .59812 .27972 L p
1 g
F P
s
P
p
.002 w
.40161 .56028 m .42539 .5942 L .40228 .59267 L p
1 g
F P
s
P
p
.002 w
.40228 .59267 m .3751 .55457 L .40161 .56028 L p
1 g
F P
s
P
p
.002 w
.66953 .50816 m .67286 .47172 L .68663 .45372 L p
1 g
F P
s
P
p
.002 w
.67548 .41367 m .68663 .45372 L .67286 .47172 L p
1 g
F P
s
P
p
.002 w
.68663 .45372 m .67548 .41367 L .68232 .39043 L p
1 g
F P
s
P
p
.002 w
.50269 .59776 m .53113 .60401 L .51746 .61767 L p
1 g
F P
s
P
p
.002 w
.51746 .61767 m .48115 .60991 L .50269 .59776 L p
1 g
F P
s
P
p
.002 w
.6532 .35343 m .68232 .39043 L .67548 .41367 L p
1 g
F P
s
P
p
.002 w
.68232 .39043 m .6532 .35343 L .65242 .32872 L p
1 g
F P
s
P
p
.002 w
.36469 .50678 m .3751 .55457 L .35299 .54544 L p
1 g
F P
s
P
p
.002 w
.35299 .54544 m .34126 .49371 L .36469 .50678 L p
1 g
F P
s
P
p
.002 w
.63899 .54564 m .65108 .51762 L .66953 .50816 L p
1 g
F P
s
P
p
.002 w
.67286 .47172 m .66953 .50816 L .65108 .51762 L p
1 g
F P
s
P
p
.002 w
.3993 .29654 m .35004 .34509 L .34239 .33106 L p
1 g
F P
s
P
p
.002 w
.34239 .33106 m .39066 .28338 L .3993 .29654 L p
1 g
F P
s
P
p
.002 w
.52684 .25265 m .46097 .26437 L .45117 .25187 L p
1 g
F P
s
P
p
.002 w
.39066 .28338 m .45117 .25187 L .46097 .26437 L p
1 g
F P
s
P
p
.002 w
.5657 .58275 m .58666 .57472 L .59209 .58948 L p
1 g
F P
s
P
p
.002 w
.59209 .58948 m .56195 .6011 L .5657 .58275 L p
1 g
F P
s
P
p
.002 w
.61863 .57038 m .59209 .58948 L .58666 .57472 L p
1 g
F P
s
P
p
.002 w
.35011 .43692 m .34126 .49371 L .32317 .47918 L p
1 g
F P
s
P
p
.002 w
.32317 .47918 m .33204 .41972 L .35011 .43692 L p
1 g
F P
s
P
p
.002 w
.58666 .57472 m .60512 .56143 L .61863 .57038 L p
1 g
F P
s
P
p
.002 w
.63899 .54564 m .61863 .57038 L .60512 .56143 L p
1 g
F P
s
P
p
.002 w
.46097 .26437 m .3993 .29654 L .39066 .28338 L p
1 g
F P
s
P
p
.002 w
.60532 .30229 m .65242 .32872 L .6532 .35343 L p
1 g
F P
s
P
p
.002 w
.65242 .32872 m .60532 .30229 L .59812 .27972 L p
1 g
F P
s
P
p
.002 w
.36248 .36221 m .33204 .41972 L .31946 .4034 L p
1 g
F P
s
P
p
.002 w
.31946 .4034 m .35004 .34509 L .36248 .36221 L p
1 g
F P
s
P
p
.002 w
.54435 .58469 m .5657 .58275 L .56195 .6011 L p
1 g
F P
s
P
p
.002 w
.56195 .6011 m .53113 .60401 L .54435 .58469 L p
1 g
F P
s
P
p
.002 w
.60512 .56143 m .61922 .54422 L .63899 .54564 L p
1 g
F P
s
P
p
.002 w
.65108 .51762 m .63899 .54564 L .61922 .54422 L p
1 g
F P
s
P
p
.002 w
.47964 .58272 m .50269 .59776 L .48115 .60991 L p
1 g
F P
s
P
p
.002 w
.48115 .60991 m .45143 .59091 L .47964 .58272 L p
1 g
F P
s
P
p
.002 w
.53741 .27054 m .59812 .27972 L .60532 .30229 L p
1 g
F P
s
P
p
.002 w
.59812 .27972 m .53741 .27054 L .52684 .25265 L p
1 g
F P
s
P
p
.002 w
.43177 .56221 m .45143 .59091 L .42539 .5942 L p
1 g
F P
s
P
p
.002 w
.42539 .5942 m .40161 .56028 L .43177 .56221 L p
1 g
F P
s
P
p
.002 w
.46097 .26437 m .52684 .25265 L .53741 .27054 L p
1 g
F P
s
P
p
.002 w
.65108 .51762 m .65351 .48907 L .67286 .47172 L p
1 g
F P
s
P
p
.002 w
.66321 .43811 m .67286 .47172 L .65351 .48907 L p
1 g
F P
s
P
p
.002 w
.67286 .47172 m .66321 .43811 L .67548 .41367 L p
1 g
F P
s
P
p
.002 w
.64942 .38116 m .67548 .41367 L .66321 .43811 L p
1 g
F P
s
P
p
.002 w
.67548 .41367 m .64942 .38116 L .6532 .35343 L p
1 g
F P
s
P
p
.002 w
.52478 .58023 m .54435 .58469 L .53113 .60401 L p
1 g
F P
s
P
p
.002 w
.53113 .60401 m .50269 .59776 L .52478 .58023 L p
1 g
F P
s
P
p
.002 w
.39283 .51789 m .40161 .56028 L .3751 .55457 L p
1 g
F P
s
P
p
.002 w
.3751 .55457 m .36469 .50678 L .39283 .51789 L p
1 g
F P
s
P
p
.002 w
.61922 .54422 m .62749 .52479 L .65108 .51762 L p
1 g
F P
s
P
p
.002 w
.65351 .48907 m .65108 .51762 L .62749 .52479 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.41131 .31424 m .36248 .36221 L .35004 .34509 L p
1 g
F P
s
P
p
.002 w
.35004 .34509 m .3993 .29654 L .41131 .31424 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.60956 .32941 m .6532 .35343 L .64942 .38116 L p
1 g
F P
s
P
p
.002 w
.6532 .35343 m .60956 .32941 L .60532 .30229 L p
1 g
F P
s
P
p
.004 w
.65151 .32814 m
.67104 .31494 L
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37328 .45442 m .36469 .50678 L .34126 .49371 L p
1 g
F P
s
P
p
.002 w
.34126 .49371 m .35011 .43692 L .37328 .45442 L p
1 g
F P
s
P
p
.002 w
.53741 .27054 m .47232 .28234 L .46097 .26437 L p
1 g
F P
s
P
p
.002 w
.3993 .29654 m .46097 .26437 L .47232 .28234 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.37953 .38198 m .35011 .43692 L .33204 .41972 L p
1 g
F P
s
P
p
.002 w
.33204 .41972 m .36248 .36221 L .37953 .38198 L p
1 g
F P
s
P
p
.002 w
.5676 .55916 m .57841 .55504 L .58666 .57472 L p
1 g
F P
s
P
p
.002 w
.58666 .57472 m .5657 .58275 L .5676 .55916 L p
1 g
F P
s
P
p
.002 w
.60512 .56143 m .58666 .57472 L .57841 .55504 L p
1 g
F P
s
P
p
.004 w
.5956 .57273 m
.60788 .59101 L
s
P
p
.002 w
.57841 .55504 m .58793 .54819 L .60512 .56143 L p
1 g
F P
s
P
p
.002 w
.61922 .54422 m .60512 .56143 L .58793 .54819 L p
1 g
F P
s
P
p
.002 w
.47232 .28234 m .41131 .31424 L .3993 .29654 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47964 .58272 m .45143 .59091 L p
.45993 .57112 L 1 g
F P
s
P
p
.45993 .57112 m .46835 .57434 L .47964 .58272 L 1 g
F
P
p
.002 w
.47602 .57728 m .47842 .58089 L p
.46835 .57434 L 1 g
F P
s
P
p
.002 w
.47842 .58089 m .47964 .58272 L p
.46835 .57434 L 1 g
F P
s
P
p
.002 w
.46835 .57434 m .46872 .57265 L p
.461 .56957 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46819 .57507 L p
1 g
F P
s
P
p
.48921 .57862 m .46819 .57507 L .47633 .57737 L 1 g
F
P
p
.002 w
.47964 .58272 m .47602 .57728 L p
.48216 .57901 L 1 g
F P
s
P
p
.4773 .57764 m .46787 .57655 L .47071 .5771 L 1 g
F
P
p
.48921 .57862 m .47633 .57737 L .4773 .57764 L 1 g
F
P
p
.47633 .57737 m .46787 .57655 L .4773 .57764 L 1 g
F
P
p
.002 w
.48574 .58002 m .47964 .58272 L p
.48216 .57901 L 1 g
F P
s
P
p
.002 w
.50269 .59776 m .47964 .58272 L .48574 .58002 L p
1 g
F P
s
P
p
.50269 .59776 m .48638 .58069 L .50584 .58394 L 1 g
F
P
p
.48638 .58069 m .48574 .58002 L .48906 .58067 L 1 g
F
P
p
.48638 .58069 m .48906 .58067 L .50584 .58394 L 1 g
F
P
p
.002 w
.51093 .58048 m .51079 .57862 L p
.50107 .58056 L 1 g
F P
s
P
p
.48921 .57862 m .47687 .57761 L .48054 .57901 L 1 g
F
P
p
.002 w
.48894 .58223 m .48906 .58067 L p
.48054 .57901 L 1 g
F P
s
P
p
.002 w
.48906 .58067 m .48921 .57862 L p
.48054 .57901 L 1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58067 L p
1 g
F P
s
P
p
.50584 .58394 m .48906 .58067 L .50662 .58052 L 1 g
F
P
p
.002 w
.48906 .58067 m .48889 .583 L p
.50107 .58056 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58067 L .50107 .58056 L 1 g
F
P
p
.002 w
.48574 .58002 m .50908 .56972 L p
.50662 .58052 L 1 g
F P
s
P
p
.48906 .58067 m .48574 .58002 L .50662 .58052 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52478 .58023 m .50269 .59776 L p
.50641 .58144 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58048 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58048 L .51962 .57863 L 1 g
F
P
p
.002 w
.52172 .57818 m .52478 .58023 L p
.50641 .58144 L 1 g
F P
s
P
p
.002 w
.54435 .58469 m .52478 .58023 L .52924 .57564 L p
1 g
F P
s
P
p
.54435 .58469 m .52979 .57597 L .54565 .56946 L 1 g
F
P
p
.52979 .57597 m .52924 .57564 L .53173 .5747 L 1 g
F
P
p
.52979 .57597 m .53173 .5747 L .54565 .56946 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53173 .5747 L p
1 g
F P
s
P
p
.54854 .56129 m .53173 .5747 L .54041 .56903 L 1 g
F
P
p
.002 w
.53173 .5747 m .53128 .57265 L p
.51812 .5794 L 1 g
F P
s
P
p
.002 w
.52924 .57564 m .52478 .58023 L p
.52663 .57653 L 1 g
F P
s
P
p
.51812 .5794 m .52924 .57564 L .53173 .5747 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.50908 .56972 m .53873 .55227 L p
.52663 .57653 L 1 g
F P
s
P
p
.002 w
.52478 .58023 m .52172 .57818 L p
.52663 .57653 L 1 g
F P
s
P
p
.002 w
.52172 .57818 m .50908 .56972 L p
.52663 .57653 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53175 .57479 L p
1 g
F P
s
P
p
.002 w
.53175 .57479 m .53173 .5747 L p
.53021 .57531 L 1 g
F P
s
P
p
.53021 .57531 m .51111 .583 L .53175 .57479 L 1 g
F
P
p
.51812 .5794 m .51493 .58104 L .52924 .57564 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53873 .55227 m .54665 .55772 L .52924 .57564 L p
1 g
F P
s
P
p
.52663 .57653 m .53873 .55227 L .52924 .57564 L 1 g
F
P
p
.002 w
.54927 .56325 m .54854 .56129 L p
.54041 .56903 L 1 g
F P
s
P
p
.002 w
.52924 .57564 m .54665 .55772 L p
.54599 .56539 L 1 g
F P
s
P
p
.54565 .56946 m .53173 .5747 L .54599 .56539 L 1 g
F
P
p
.53173 .5747 m .52924 .57564 L .54599 .56539 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.55663 .56009 m .54435 .58469 L p
.54586 .56697 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54927 .56325 L p
1 g
F P
s
P
p
.56075 .54566 m .54927 .56325 L .55297 .55922 L 1 g
F
P
p
.002 w
.56117 .54789 m .55663 .56009 L .55297 .55922 L p
1 g
F P
s
P
p
.55424 .55746 m .55297 .55922 L .55373 .55839 L 1 g
F
P
p
.56075 .54566 m .55297 .55922 L .55424 .55746 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55297 .55922 m .55663 .56009 L p
.54586 .56697 L 1 g
F P
s
P
p
.002 w
.5676 .55916 m .55663 .56009 L .56117 .54789 L p
1 g
F P
s
P
p
.002 w
.56752 .53902 m .5676 .55916 L p
.56131 .54814 L 1 g
F P
s
P
p
.56131 .54814 m .56117 .54789 L .56161 .54728 L 1 g
F
P
p
.56131 .54814 m .56161 .54728 L .56752 .53902 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56161 .54728 L p
1 g
F P
s
P
p
.56654 .52734 m .56161 .54728 L .56403 .54019 L 1 g
F
P
p
.002 w
.56699 .53155 m .56749 .53091 L .56403 .54019 L p
1 g
F P
s
P
p
.56438 .53918 m .56403 .54019 L .56438 .53919 L 1 g
F
P
p
.56654 .52734 m .56403 .54019 L .56438 .53918 L 1 g
F
P
p
.002 w
.56161 .54728 m .56075 .54566 L p
.55399 .55791 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56749 .53091 m .56752 .53902 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.56117 .54789 m .56403 .54019 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.56403 .54019 m .56749 .53091 L p
.56161 .54728 L 1 g
F P
s
P
p
.002 w
.57841 .55504 m .5676 .55916 L .56749 .53091 L closepath p
1 g
F P
s
P
p
.002 w
.58793 .54819 m .57841 .55504 L .56749 .53091 L closepath p
1 g
F P
s
P
p
.002 w
.59516 .5393 m .58793 .54819 L .56749 .53091 L closepath p
1 g
F P
s
P
p
.002 w
.59935 .52931 m .59516 .5393 L .56749 .53091 L closepath p
1 g
F P
s
P
p
.002 w
.60001 .51926 m .59935 .52931 L .56749 .53091 L closepath p
1 g
F P
s
P
p
.56654 .52734 m .56438 .53919 L .56678 .53216 L 1 g
F
P
p
.56654 .52734 m .56678 .53216 L .56711 .53119 L 1 g
F
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56768 .529 L p
1 g
F P
s
P
p
.002 w
.57094 .49803 m .56769 .52895 L p
.56767 .52888 L 1 g
F P
s
P
p
.002 w
.56528 .49928 m .57094 .49803 L p
.56906 .51574 L 1 g
F P
s
P
p
.5661 .50939 m .56906 .51574 L .56767 .52888 L 1 g
F
P
p
.56528 .49928 m .56906 .51574 L .5661 .50939 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .5661 .50939 L p
1 g
F P
s
P
p
.55661 .4905 m .5661 .50939 L .56291 .50255 L 1 g
F
P
p
.56515 .50826 m .56768 .529 L .56695 .51992 L 1 g
F
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.59704 .51022 m .60001 .51926 L .56749 .53091 L closepath p
1 g
F P
s
P
p
.002 w
.59072 .50319 m .59704 .51022 L .56781 .53068 L p
1 g
F P
s
P
p
.002 w
.5678 .53053 m .59072 .50319 L p
.56781 .53068 L 1 g
F P
s
P
p
.002 w
.5817 .49896 m .59072 .50319 L .5678 .53053 L p
1 g
F P
s
P
p
.002 w
.5678 .53053 m .56749 .53091 L .56778 .53025 L p
1 g
F P
s
P
p
.002 w
.56778 .53025 m .5817 .49896 L p
.5678 .53053 L 1 g
F P
s
P
p
.56654 .52734 m .56711 .53119 L .56716 .53104 L 1 g
F
P
p
.002 w
.56719 .53094 m .56749 .53091 L .56716 .53104 L p
1 g
F P
s
P
p
.56717 .53098 m .56716 .53104 L .56717 .53099 L 1 g
F
P
p
.56654 .52734 m .56716 .53104 L .56717 .53098 L 1 g
F
P
p
.56654 .52734 m .56717 .53099 L .56719 .53094 L 1 g
F
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.53376 .54428 m .53231 .53459 L .56719 .53094 L p
1 g
F P
s
P
p
.002 w
.56716 .53104 m .53376 .54428 L p
.56719 .53094 L 1 g
F P
s
P
p
.56654 .52734 m .56719 .53094 L .5672 .53089 L 1 g
F
P
p
.56654 .52734 m .5672 .5309 L .56721 .53085 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.53231 .53459 m .53459 .52426 L .56721 .53085 L p
1 g
F P
s
P
p
.002 w
.56721 .53085 m .56749 .53091 L .56719 .53094 L p
1 g
F P
s
P
p
.002 w
.56719 .53094 m .53231 .53459 L p
.56721 .53085 L 1 g
F P
s
P
p
.56719 .53094 m .56717 .53099 L .56719 .53094 L 1 g
F
P
p
.5672 .53089 m .56719 .53094 L .5672 .5309 L 1 g
F
P
p
.56654 .52734 m .56722 .53086 L .56743 .53003 L 1 g
F
P
p
.002 w
.56769 .52895 m .56749 .53091 L .56734 .53036 L p
1 g
F P
s
P
p
.002 w
.56769 .52901 m .56768 .529 L p
.56743 .53003 L 1 g
F P
s
P
p
.002 w
.56768 .529 m .56654 .52734 L p
.56743 .53003 L 1 g
F P
s
P
p
.002 w
.5817 .49896 m .56749 .53091 L .56769 .52895 L p
1 g
F P
s
P
p
.002 w
.56769 .52895 m .57094 .49803 L .57521 .4984 L p
1 g
F P
s
P
p
.002 w
.57521 .4984 m .5817 .49896 L p
.56769 .52895 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.53459 .52426 m .54038 .51443 L .56724 .53076 L p
1 g
F P
s
P
p
.002 w
.56724 .53076 m .56749 .53091 L .56721 .53085 L p
1 g
F P
s
P
p
.002 w
.56721 .53085 m .53459 .52426 L p
.56724 .53076 L 1 g
F P
s
P
p
.002 w
.54038 .51443 m .54905 .50621 L .56727 .53062 L p
1 g
F P
s
P
p
.002 w
.56727 .53062 m .56749 .53091 L .56724 .53076 L p
1 g
F P
s
P
p
.002 w
.56724 .53076 m .54038 .51443 L p
.56727 .53062 L 1 g
F P
s
P
p
.56721 .53085 m .5672 .5309 L .56722 .53086 L 1 g
F
P
p
.002 w
.56777 .52914 m .56769 .52901 L p
.56722 .53086 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54905 .50621 m .55964 .50053 L .56734 .53036 L p
1 g
F P
s
P
p
.002 w
.56734 .53036 m .56749 .53091 L .56727 .53062 L p
1 g
F P
s
P
p
.002 w
.56727 .53062 m .54905 .50621 L p
.56734 .53036 L 1 g
F P
s
P
p
.002 w
.56734 .53036 m .55964 .50053 L p
.56769 .52895 L 1 g
F P
s
P
p
.002 w
.56768 .529 m .56769 .52901 L p
.56695 .51992 L 1 g
F P
s
P
p
.002 w
.56769 .52901 m .56854 .53025 L p
.56707 .52073 L 1 g
F P
s
P
p
.56695 .51992 m .56769 .52901 L .56707 .52073 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56641 .50976 L p
1 g
F P
s
P
p
.002 w
.56641 .50976 m .56515 .50826 L p
.5672 .52156 L 1 g
F P
s
P
p
.5672 .52156 m .56854 .53025 L .56641 .50976 L 1 g
F
P
p
.002 w
.56781 .53068 m .56749 .53091 L .5678 .53053 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.55661 .4905 m .56291 .50255 L .56175 .50007 L 1 g
F
P
p
.002 w
.5561 .48866 m .54977 .4674 L p
.55919 .49308 L 1 g
F P
s
P
p
.55919 .49308 m .56175 .50007 L .55746 .4914 L 1 g
F
P
p
.55919 .49308 m .55746 .4914 L .5561 .48866 L 1 g
F
P
p
.002 w
.55746 .4914 m .55661 .4905 L p
.56175 .50007 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.002 w
.55795 .49193 m .55746 .4914 L p
.56175 .50007 L 1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .5567 .49067 L 1 g
F
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5567 .49067 m .55964 .50053 L p
.54093 .47609 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47676 L p
1 g
F P
s
P
p
.52214 .46667 m .54237 .47676 L .53697 .47425 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53697 .47425 m .52871 .47866 L .5201 .46687 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52245 .46718 L p
1 g
F P
s
P
p
.5 .4634 m .52245 .46718 L .5201 .46687 L 1 g
F
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5201 .46687 m .52871 .47866 L p
.49663 .46437 L 1 g
F P
s
P
p
.5 .46384 m .5201 .46687 L .49663 .46437 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46384 L p
1 g
F P
s
P
p
.002 w
.48199 .47342 m .49039 .46537 L p
.52871 .47866 L 1 g
F P
s
P
p
.49039 .46537 m .49663 .46437 L .52871 .47866 L 1 g
F
P
p
.47786 .46667 m .5 .46384 L .48999 .46544 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.50722 .44925 m .49039 .46537 L p
.45295 .4504 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.49039 .46537 m .48199 .47342 L .47546 .46824 L p
1 g
F P
s
P
p
.47753 .46721 m .49039 .46537 L .47546 .46824 L 1 g
F
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.47546 .46824 m .48199 .47342 L p
.45227 .48194 L 1 g
F P
s
P
p
.45786 .47652 m .47546 .46824 L .45227 .48194 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45786 .47652 L p
1 g
F P
s
P
p
.44339 .4905 m .45786 .47652 L .44892 .4852 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44257 .49137 L p
1 g
F P
s
P
p
.43485 .50826 m .44257 .49137 L .44217 .49216 L 1 g
F
P
p
.002 w
.42484 .52654 m .43201 .48776 L .44217 .49216 L p
1 g
F P
s
P
p
.42484 .52654 m .43428 .50782 L .42631 .52567 L 1 g
F
P
p
.43428 .50782 m .44217 .49216 L .43417 .50907 L 1 g
F
P
p
.43428 .50782 m .43417 .50907 L .42631 .52567 L 1 g
F
P
p
.43346 .52734 m .4332 .51991 L .4325 .52783 L 1 g
F
P
p
.002 w
.43177 .56221 m .42484 .52654 L .43213 .52777 L p
1 g
F P
s
P
p
.002 w
.43213 .52777 m .4325 .52783 L p
.43248 .52877 L 1 g
F P
s
P
p
.43177 .56221 m .43213 .52777 L .43248 .52877 L 1 g
F
P
p
.002 w
.43866 .54677 m .43925 .54566 L p
.43622 .53968 L 1 g
F P
s
P
p
.002 w
.43248 .52877 m .43346 .52734 L p
.4325 .52783 L 1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.43181 .56217 m .43229 .53803 L .44196 .55129 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43866 .54677 L p
1 g
F P
s
P
p
.45146 .56129 m .43866 .54677 L .445 .55546 L 1 g
F
P
p
.002 w
.44913 .56114 m .43177 .56221 L p
.44196 .55129 L 1 g
F P
s
P
p
.45146 .56129 m .4376 .54879 L .43986 .55121 L 1 g
F
P
p
.45143 .59091 m .44919 .56189 L .45947 .5722 L 1 g
F
P
p
.44919 .56189 m .44913 .56114 L .45084 .56296 L 1 g
F
P
p
.44919 .56189 m .45084 .56296 L .45947 .5722 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45084 .56296 L p
1 g
F P
s
P
p
.46872 .57265 m .45084 .56296 L .461 .56957 L 1 g
F
P
p
.45146 .56129 m .44542 .55604 L .44913 .56114 L 1 g
F
P
p
.002 w
.45071 .5633 m .45084 .56296 L p
.44913 .56114 L 1 g
F P
s
P
p
.002 w
.45084 .56296 m .45146 .56129 L p
.44913 .56114 L 1 g
F P
s
P
p
.002 w
.44913 .56114 m .46463 .56018 L p
.45947 .5722 L 1 g
F P
s
P
p
.002 w
.46463 .56018 m .47602 .57728 L p
.46835 .57434 L 1 g
F P
s
P
p
.45993 .57112 m .46069 .56936 L .46835 .57434 L 1 g
F
P
p
.46069 .56936 m .46463 .56018 L .46835 .57434 L 1 g
F
P
p
.002 w
.45084 .56296 m .45002 .56518 L p
.461 .56957 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45962 .53237 m .46463 .56018 L .44913 .56114 L p
1 g
F P
s
P
p
.44196 .55129 m .45962 .53237 L .44913 .56114 L 1 g
F
P
p
.002 w
.43866 .54677 m .4376 .54879 L p
.445 .55546 L 1 g
F P
s
P
p
.002 w
.4376 .54879 m .43743 .5491 L p
.43986 .55121 L 1 g
F P
s
P
p
.002 w
.45143 .59091 m .43177 .56221 L .44913 .56114 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43248 .52877 L p
1 g
F P
s
P
p
.43229 .53803 m .43248 .52877 L .43866 .54677 L 1 g
F
P
p
.43177 .56221 m .4325 .52783 L .43181 .56217 L 1 g
F
P
p
.002 w
.43248 .52877 m .43146 .53025 L p
.43622 .53968 L 1 g
F P
s
P
p
.43925 .54566 m .43248 .52877 L .43622 .53968 L 1 g
F
P
p
.43866 .54677 m .4325 .52783 L .44196 .55129 L 1 g
F
P
p
.43248 .52877 m .4325 .52783 L .43866 .54677 L 1 g
F
P
p
.002 w
.4325 .52783 m .45962 .53237 L p
.44196 .55129 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45071 .5633 L p
1 g
F P
s
P
p
.44542 .55604 m .43743 .5491 L .45071 .5633 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43866 .54677 L p
1 g
F P
s
P
p
.43622 .53968 m .43146 .53025 L .43866 .54677 L 1 g
F
P
p
.002 w
.4324 .52888 m .43248 .52877 L p
.4325 .52783 L 1 g
F P
s
P
p
.43485 .50826 m .44217 .49216 L .43764 .50172 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43417 .50907 L p
1 g
F P
s
P
p
.43346 .52734 m .43417 .50907 L .4332 .51991 L 1 g
F
P
p
.002 w
.44217 .49216 m .46553 .50229 L p
.43305 .52165 L 1 g
F P
s
P
p
.42631 .52567 m .43417 .50907 L .43305 .52165 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43485 .50826 L p
1 g
F P
s
P
p
.43417 .50907 m .44217 .49216 L .43305 .52165 L 1 g
F
P
p
.002 w
.43417 .50907 m .43287 .51061 L p
.4332 .51991 L 1 g
F P
s
P
p
.002 w
.46553 .50229 m .45962 .53237 L .42484 .52654 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4324 .52888 L p
1 g
F P
s
P
p
.4332 .51991 m .43287 .51061 L .4324 .52888 L 1 g
F
P
p
.43764 .50172 m .44217 .49216 L .43932 .49781 L 1 g
F
P
p
.002 w
.48199 .47342 m .46553 .50229 L .44217 .49216 L p
1 g
F P
s
P
p
.002 w
.44217 .49216 m .43201 .48776 L p
.44649 .4836 L 1 g
F P
s
P
p
.002 w
.44257 .49137 m .44339 .4905 L p
.44892 .4852 L 1 g
F P
s
P
p
.44257 .49137 m .48199 .47342 L .44217 .49216 L 1 g
F
P
p
.44649 .4836 m .45227 .48194 L .44257 .49137 L 1 g
F
P
p
.45227 .48194 m .48199 .47342 L .44257 .49137 L 1 g
F
P
p
.002 w
.44257 .49137 m .44166 .49233 L p
.43932 .49781 L 1 g
F P
s
P
p
.002 w
.45786 .47652 m .45698 .47747 L p
.44892 .4852 L 1 g
F P
s
P
p
.43201 .48776 m .45857 .47582 L .43703 .48632 L 1 g
F
P
p
.002 w
.47467 .46762 m .45295 .4504 L p
.48533 .46335 L 1 g
F P
s
P
p
.002 w
.47739 .46745 m .47786 .46667 L p
.48999 .46544 L 1 g
F P
s
P
p
.48533 .46335 m .49039 .46537 L .47753 .46721 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46721 L p
1 g
F P
s
P
p
.48533 .46335 m .47753 .46721 L .47467 .46762 L 1 g
F
P
p
.002 w
.47753 .46721 m .47749 .46728 L p
.47615 .46789 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46721 L .47615 .46789 L 1 g
F
P
p
.002 w
.47749 .46728 m .47718 .46778 L p
.46608 .47265 L 1 g
F P
s
P
p
.45826 .47608 m .47749 .46728 L .46608 .47265 L 1 g
F
P
p
.002 w
.45786 .47652 m .45826 .47608 L p
.46608 .47265 L 1 g
F P
s
P
p
.45857 .47582 m .47546 .46824 L .45786 .47652 L 1 g
F
P
p
.45857 .47582 m .45786 .47652 L .43703 .48632 L 1 g
F
P
p
.43703 .48632 m .45786 .47652 L .45227 .48194 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44257 .49137 L p
1 g
F P
s
P
p
.44892 .4852 m .45698 .47747 L .44257 .49137 L 1 g
F
P
p
.002 w
.43201 .48776 m .45295 .4504 L .47546 .46824 L p
1 g
F P
s
P
p
.002 w
.45713 .47732 m .45786 .47652 L p
.47018 .47085 L 1 g
F P
s
P
p
.46608 .47265 m .47018 .47085 L .45786 .47652 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45713 .47732 L p
1 g
F P
s
P
p
.47018 .47085 m .47718 .46778 L .45713 .47732 L 1 g
F
P
p
.002 w
.47546 .46824 m .47467 .46762 L p
.47753 .46721 L 1 g
F P
s
P
p
.48999 .46544 m .49039 .46537 L .5 .46442 L 1 g
F
P
p
.002 w
.5 .46384 m .5 .464 L p
.49039 .46537 L 1 g
F P
s
P
p
.002 w
.5 .464 m .5 .46442 L p
.49039 .46537 L 1 g
F P
s
P
p
.002 w
.49039 .46537 m .49308 .46279 L p
.49663 .46437 L 1 g
F P
s
P
p
.49308 .46279 m .5 .46384 L .49663 .46437 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47739 .46745 L p
1 g
F P
s
P
p
.48999 .46544 m .5 .46442 L .47739 .46745 L 1 g
F
P
p
.51054 .46543 m .5201 .46687 L .5133 .46596 L 1 g
F
P
p
.5 .4634 m .5201 .46687 L .51054 .46543 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.52245 .46718 m .53697 .47425 L .5201 .46687 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49308 .46279 m .50722 .44925 L .5201 .46687 L p
1 g
F P
s
P
p
.002 w
.5201 .46687 m .51915 .46558 L p
.52245 .46718 L 1 g
F P
s
P
p
.002 w
.52245 .46718 m .52282 .46778 L p
.5133 .46596 L 1 g
F P
s
P
p
.53384 .47273 m .53697 .47425 L .5351 .47338 L 1 g
F
P
p
.52214 .46667 m .53697 .47425 L .53384 .47273 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.54977 .4674 m .53697 .47425 L p
.50722 .44925 L 1 g
F P
s
P
p
.54237 .47676 m .5567 .49067 L .54093 .47609 L 1 g
F
P
p
.002 w
.52871 .47866 m .53697 .47425 L p
.55964 .50053 L 1 g
F P
s
P
p
.53697 .47425 m .54093 .47609 L .55964 .50053 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52271 .46761 L p
1 g
F P
s
P
p
.002 w
.52271 .46761 m .52214 .46667 L p
.5351 .47338 L 1 g
F P
s
P
p
.5351 .47338 m .54302 .47747 L .52271 .46761 L 1 g
F
P
p
.002 w
.53697 .47425 m .53877 .47328 L p
.54093 .47609 L 1 g
F P
s
P
p
.002 w
.51915 .46558 m .50722 .44925 L p
.53697 .47425 L 1 g
F P
s
P
p
.53877 .47328 m .54237 .47676 L .54093 .47609 L 1 g
F
P
p
.002 w
.54237 .47676 m .54302 .47747 L p
.5351 .47338 L 1 g
F P
s
P
p
.54998 .48415 m .5567 .49067 L .55092 .48507 L 1 g
F
P
p
.54174 .47608 m .5567 .49067 L .54998 .48415 L 1 g
F
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.56175 .50007 m .55964 .50053 L .5567 .49067 L p
1 g
F P
s
P
p
.002 w
.5567 .49067 m .5561 .48866 L p
.55746 .4914 L 1 g
F P
s
P
p
.55746 .4914 m .56175 .50007 L .5567 .49067 L 1 g
F
P
p
.002 w
.57094 .49803 m .56175 .50007 L p
.54977 .4674 L 1 g
F P
s
P
p
.002 w
.56175 .50007 m .56528 .49928 L p
.5661 .50939 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55795 .49193 L p
1 g
F P
s
P
p
.56291 .50255 m .56713 .51061 L .55795 .49193 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54254 .47696 L p
1 g
F P
s
P
p
.002 w
.54254 .47696 m .54174 .47608 L p
.55092 .48507 L 1 g
F P
s
P
p
.55092 .48507 m .55834 .49233 L .54254 .47696 L 1 g
F
P
p
.002 w
.53877 .47328 m .54977 .4674 L .5567 .49067 L p
1 g
F P
s
P
p
.002 w
.55746 .4914 m .55834 .49233 L p
.55092 .48507 L 1 g
F P
s
P
p
.002 w
.55964 .50053 m .56175 .50007 L p
.56767 .52888 L 1 g
F P
s
P
p
.56175 .50007 m .5661 .50939 L .56767 .52888 L 1 g
F
P
p
.002 w
.5661 .50939 m .56713 .51061 L p
.56291 .50255 L 1 g
F P
s
P
p
.002 w
.56779 .52916 m .56777 .52914 L p
.56723 .53081 L 1 g
F P
s
P
p
.56723 .53081 m .56711 .53119 L .56722 .53086 L 1 g
F
P
p
.56723 .53081 m .56722 .53086 L .56779 .52916 L 1 g
F
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.53873 .55227 m .53376 .54428 L .56716 .53104 L p
1 g
F P
s
P
p
.002 w
.56716 .53104 m .56749 .53091 L .56711 .53119 L p
1 g
F P
s
P
p
.002 w
.56711 .53119 m .53873 .55227 L p
.56716 .53104 L 1 g
F P
s
P
p
.002 w
.54665 .55772 m .53873 .55227 L .56711 .53119 L p
1 g
F P
s
P
p
.002 w
.56711 .53119 m .56749 .53091 L .56699 .53155 L p
1 g
F P
s
P
p
.002 w
.56699 .53155 m .54665 .55772 L p
.56711 .53119 L 1 g
F P
s
P
p
.002 w
.5678 .52918 m .56779 .52916 L p
.56678 .53216 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5678 .52918 L p
1 g
F P
s
P
p
.56438 .53919 m .56257 .5491 L .5678 .52918 L 1 g
F
P
p
.002 w
.54665 .55772 m .56699 .53155 L p
.56117 .54789 L 1 g
F P
s
P
p
.002 w
.56403 .54019 m .56117 .54789 L p
.56699 .53155 L 1 g
F P
s
P
p
.002 w
.56161 .54728 m .56257 .5491 L p
.56438 .53919 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56161 .54728 L p
1 g
F P
s
P
p
.55399 .55791 m .54998 .56518 L .56161 .54728 L 1 g
F
P
p
.002 w
.55297 .55922 m .54665 .55772 L p
.56117 .54789 L 1 g
F P
s
P
p
.002 w
.54665 .55772 m .55297 .55922 L p
.54586 .56697 L 1 g
F P
s
P
p
.002 w
.54927 .56325 m .54998 .56518 L p
.55373 .55839 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54927 .56325 L p
1 g
F P
s
P
p
.54041 .56903 m .5322 .57686 L .54927 .56325 L 1 g
F
P
p
.002 w
.53173 .5747 m .5322 .57686 L p
.54041 .56903 L 1 g
F P
s
P
p
.51493 .58104 m .51111 .583 L .53173 .5747 L 1 g
F
P
p
.002 w
.50908 .56972 m .52172 .57818 L p
.50641 .58144 L 1 g
F P
s
P
p
.002 w
.51093 .58048 m .51111 .583 L p
.51962 .57863 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58048 L p
1 g
F P
s
P
p
.50107 .58056 m .48889 .583 L .51093 .58048 L 1 g
F
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46463 .56018 m .49904 .55415 L p
.48216 .57901 L 1 g
F P
s
P
p
.002 w
.47602 .57728 m .46463 .56018 L p
.48216 .57901 L 1 g
F P
s
P
p
.002 w
.49904 .55415 m .50908 .56972 L .48574 .58002 L p
1 g
F P
s
P
p
.48216 .57901 m .49904 .55415 L .48574 .58002 L 1 g
F
P
p
.002 w
.46819 .57507 m .46787 .57655 L p
.47633 .57737 L 1 g
F P
s
P
p
.002 w
.46787 .57655 m .4678 .57686 L p
.47071 .5771 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46835 .57434 L p
1 g
F P
s
P
p
.461 .56957 m .45002 .56518 L .46835 .57434 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48894 .58223 L p
1 g
F P
s
P
p
.47687 .57761 m .4678 .57686 L .48894 .58223 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51476 .45247 L
s
P
p
.004 w
.53568 .48359 m
.5504 .50549 L
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.54719 .29387 m .60532 .30229 L .60956 .32941 L p
1 g
F P
s
P
p
.002 w
.60532 .30229 m .54719 .29387 L .53741 .27054 L p
1 g
F P
s
P
p
.002 w
.55663 .56009 m .5676 .55916 L .5657 .58275 L p
1 g
F P
s
P
p
.002 w
.5657 .58275 m .54435 .58469 L .55663 .56009 L p
1 g
F P
s
P
p
.002 w
.58793 .54819 m .59516 .5393 L .61922 .54422 L p
1 g
F P
s
P
p
.002 w
.62749 .52479 m .61922 .54422 L .59516 .5393 L p
1 g
F P
s
P
p
.002 w
.62749 .52479 m .62899 .50512 L .65351 .48907 L p
1 g
F P
s
P
p
.002 w
.64571 .46293 m .65351 .48907 L .62899 .50512 L p
1 g
F P
s
P
p
.002 w
.65351 .48907 m .64571 .46293 L .66321 .43811 L p
1 g
F P
s
P
p
.002 w
.47232 .28234 m .53741 .27054 L .54719 .29387 L p
1 g
F P
s
P
p
.002 w
.64102 .41106 m .66321 .43811 L .64571 .46293 L p
1 g
F P
s
P
p
.002 w
.66321 .43811 m .64102 .41106 L .64942 .38116 L p
1 g
F P
s
P
p
.002 w
.42484 .52654 m .43177 .56221 L .40161 .56028 L p
1 g
F P
s
P
p
.002 w
.40161 .56028 m .39283 .51789 L .42484 .52654 L p
1 g
F P
s
P
p
.002 w
.59516 .5393 m .59935 .52931 L .62749 .52479 L p
1 g
F P
s
P
p
.002 w
.62899 .50512 m .62749 .52479 L .59935 .52931 L p
1 g
F P
s
P
p
.002 w
.61057 .36031 m .64942 .38116 L .64102 .41106 L p
1 g
F P
s
P
p
.002 w
.64942 .38116 m .61057 .36031 L .60956 .32941 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.61042 .3559 L
s
P
p
.004 w
.63982 .33603 m
.65151 .32814 L
s
P
p
.004 w
.6252 .34591 m
.6262 .34524 L
s
P
p
.004 w
.6262 .34524 m
.63982 .33603 L
s
P
p
.002 w
.40089 .47159 m .39283 .51789 L .36469 .50678 L p
1 g
F P
s
P
p
.002 w
.36469 .50678 m .37328 .45442 L .40089 .47159 L p
1 g
F P
s
P
p
.002 w
.42643 .33609 m .37953 .38198 L .36248 .36221 L p
1 g
F P
s
P
p
.002 w
.36248 .36221 m .41131 .31424 L .42643 .33609 L p
1 g
F P
s
P
p
.002 w
.54719 .29387 m .48489 .30543 L .47232 .28234 L p
1 g
F P
s
P
p
.002 w
.41131 .31424 m .47232 .28234 L .48489 .30543 L p
1 g
F P
s
P
p
.002 w
.40076 .40379 m .37328 .45442 L .35011 .43692 L p
1 g
F P
s
P
p
.002 w
.35011 .43692 m .37953 .38198 L .40076 .40379 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62899 .50512 m .62342 .48727 L .64571 .46293 L p
1 g
F P
s
P
p
.002 w
.62815 .44212 m .64571 .46293 L .62342 .48727 L p
1 g
F P
s
P
p
.002 w
.64571 .46293 m .62815 .44212 L .64102 .41106 L p
1 g
F P
s
P
p
.002 w
.55581 .32205 m .60956 .32941 L .61057 .36031 L p
1 g
F P
s
P
p
.002 w
.60956 .32941 m .55581 .32205 L .54719 .29387 L p
1 g
F P
s
P
p
.002 w
.59935 .52931 m .60001 .51926 L .62899 .50512 L p
1 g
F P
s
P
p
.002 w
.62342 .48727 m .62899 .50512 L .60001 .51926 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.48489 .30543 m .42643 .33609 L .41131 .31424 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.48489 .30543 m .54719 .29387 L .55581 .32205 L p
1 g
F P
s
P
p
.002 w
.6082 .39396 m .64102 .41106 L .62815 .44212 L p
1 g
F P
s
P
p
.002 w
.64102 .41106 m .6082 .39396 L .61057 .36031 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.53376 .54428 m .53873 .55227 L .50908 .56972 L p
1 g
F P
s
P
p
.002 w
.50908 .56972 m .49904 .55415 L .53376 .54428 L p
1 g
F P
s
P
p
.002 w
.43201 .48776 m .42484 .52654 L .39283 .51789 L p
1 g
F P
s
P
p
.002 w
.39283 .51789 m .40089 .47159 L .43201 .48776 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60001 .51926 m .59704 .51022 L .62342 .48727 L p
1 g
F P
s
P
p
.002 w
.6112 .47322 m .62342 .48727 L .59704 .51022 L p
1 g
F P
s
P
p
.002 w
.62342 .48727 m .6112 .47322 L .62815 .44212 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4959 .53509 m .49904 .55415 L .46463 .56018 L p
1 g
F P
s
P
p
.002 w
.46463 .56018 m .45962 .53237 L .4959 .53509 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.5629 .3542 m .61057 .36031 L .6082 .39396 L p
1 g
F P
s
P
p
.002 w
.61057 .36031 m .5629 .3542 L .55581 .32205 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44423 .36145 m .40076 .40379 L .37953 .38198 L p
1 g
F P
s
P
p
.002 w
.37953 .38198 m .42643 .33609 L .44423 .36145 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.42553 .42689 m .40089 .47159 L .37328 .45442 L p
1 g
F P
s
P
p
.002 w
.37328 .45442 m .40076 .40379 L .42553 .42689 L p
1 g
F P
s
P
p
.002 w
.60245 .42916 m .62815 .44212 L .6112 .47322 L p
1 g
F P
s
P
p
.002 w
.62815 .44212 m .60245 .42916 L .6082 .39396 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.55581 .32205 m .49827 .33302 L .48489 .30543 L p
1 g
F P
s
P
p
.002 w
.42643 .33609 m .48489 .30543 L .49827 .33302 L p
1 g
F P
s
P
p
.002 w
.59704 .51022 m .59072 .50319 L .6112 .47322 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53231 .53459 m .53376 .54428 L .49904 .55415 L p
1 g
F P
s
P
p
.002 w
.49904 .55415 m .4959 .53509 L .53231 .53459 L p
1 g
F P
s
P
p
.002 w
.49827 .33302 m .55581 .32205 L .5629 .3542 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.49827 .33302 m .44423 .36145 L .42643 .33609 L p
1 g
F P
s
P
p
.002 w
.59351 .46461 m .6112 .47322 L .59072 .50319 L p
1 g
F P
s
P
p
.002 w
.6112 .47322 m .59351 .46461 L .60245 .42916 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59072 .50319 m .5817 .49896 L .59351 .46461 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.56814 .38923 m .6082 .39396 L .60245 .42916 L p
1 g
F P
s
P
p
.002 w
.6082 .39396 m .56814 .38923 L .5629 .3542 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.50017 .51461 m .4959 .53509 L .45962 .53237 L p
1 g
F P
s
P
p
.002 w
.45962 .53237 m .46553 .50229 L .50017 .51461 L p
1 g
F P
s
P
p
.002 w
.53459 .52426 m .53231 .53459 L .4959 .53509 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45295 .4504 m .43201 .48776 L .40089 .47159 L p
1 g
F P
s
P
p
.002 w
.40089 .47159 m .42553 .42689 L .45295 .4504 L p
1 g
F P
s
P
p
.002 w
.5817 .49896 m .57094 .49803 L .57224 .46256 L p
1 g
F P
s
P
p
.002 w
.57224 .46256 m .59351 .46461 L .5817 .49896 L p
1 g
F P
s
P
p
.002 w
.4959 .53509 m .50017 .51461 L .53459 .52426 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.46414 .38948 m .42553 .42689 L .40076 .40379 L p
1 g
F P
s
P
p
.002 w
.40076 .40379 m .44423 .36145 L .46414 .38948 L p
1 g
F P
s
P
p
.002 w
.5713 .42582 m .60245 .42916 L .59351 .46461 L p
1 g
F P
s
P
p
.002 w
.60245 .42916 m .5713 .42582 L .56814 .38923 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.54038 .51443 m .53459 .52426 L .50017 .51461 L p
1 g
F P
s
P
p
.002 w
.59351 .46461 m .57224 .46256 L .5713 .42582 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.51197 .36421 m .5629 .3542 L .56814 .38923 L p
1 g
F P
s
P
p
.002 w
.5629 .3542 m .51197 .36421 L .49827 .33302 L p
1 g
F P
s
P
p
.002 w
.54977 .4674 m .57224 .46256 L .57094 .49803 L p
1 g
F P
s
P
p
.002 w
.44423 .36145 m .49827 .33302 L .51197 .36421 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.54905 .50621 m .54038 .51443 L .51152 .49504 L p
1 g
F P
s
P
p
.002 w
.50017 .51461 m .51152 .49504 L .54038 .51443 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.55964 .50053 m .54905 .50621 L .52871 .47866 L p
1 g
F P
s
P
p
.002 w
.51152 .49504 m .52871 .47866 L .54905 .50621 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.51197 .36421 m .46414 .38948 L .44423 .36145 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51152 .49504 m .50017 .51461 L .46553 .50229 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.52547 .39788 m .56814 .38923 L .5713 .42582 L p
1 g
F P
s
P
p
.002 w
.56814 .38923 m .52547 .39788 L .51197 .36421 L p
1 g
F P
s
P
p
.002 w
.46553 .50229 m .48199 .47342 L .51152 .49504 L p
1 g
F P
s
P
p
.002 w
.57224 .46256 m .54977 .4674 L .53824 .43273 L p
1 g
F P
s
P
p
.002 w
.53824 .43273 m .5713 .42582 L .57224 .46256 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.48541 .41913 m .45295 .4504 L .42553 .42689 L p
1 g
F P
s
P
p
.002 w
.42553 .42689 m .46414 .38948 L .48541 .41913 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5713 .42582 m .53824 .43273 L .52547 .39788 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.46414 .38948 m .51197 .36421 L .52547 .39788 L p
1 g
F P
s
P
p
.002 w
.52871 .47866 m .51152 .49504 L .48199 .47342 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.50722 .44925 m .53824 .43273 L .54977 .4674 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.52547 .39788 m .48541 .41913 L .46414 .38948 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.45295 .4504 m .48541 .41913 L .50722 .44925 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.48541 .41913 m .52547 .39788 L .53824 .43273 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53824 .43273 m .50722 .44925 L .48541 .41913 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.59081 .5656 m
.5956 .57273 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .70032 .29516 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60788 .59101 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.634884)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.634884)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.4564 .46324 m .49722 .45528 L .48821 .42818 L p
1 g
F P
s
P
p
.002 w
.48821 .42818 m .45416 .43471 L .4564 .46324 L p
1 g
F P
s
P
p
.002 w
.51976 .41311 m .48821 .42818 L .49722 .45528 L p
1 g
F P
s
P
p
.002 w
.45416 .43471 m .48821 .42818 L .47947 .4011 L p
1 g
F P
s
P
p
.002 w
.48821 .42818 m .51976 .41311 L .50396 .38938 L p
1 g
F P
s
P
p
.002 w
.50396 .38938 m .47947 .4011 L .48821 .42818 L p
1 g
F P
s
P
p
.002 w
.45973 .49116 m .50634 .48191 L .49722 .45528 L p
1 g
F P
s
P
p
.002 w
.49722 .45528 m .4564 .46324 L .45973 .49116 L p
1 g
F P
s
P
p
.002 w
.53507 .43724 m .49722 .45528 L .50634 .48191 L p
1 g
F P
s
P
p
.002 w
.49722 .45528 m .53507 .43724 L .51976 .41311 L p
1 g
F P
s
P
p
.002 w
.54583 .3909 m .51976 .41311 L .53507 .43724 L p
1 g
F P
s
P
p
.002 w
.51976 .41311 m .54583 .3909 L .5241 .37205 L p
1 g
F P
s
P
p
.002 w
.5241 .37205 m .50396 .38938 L .51976 .41311 L p
1 g
F P
s
P
p
.002 w
.50634 .48191 m .54961 .46134 L .53507 .43724 L p
1 g
F P
s
P
p
.002 w
.56648 .41075 m .53507 .43724 L .54961 .46134 L p
1 g
F P
s
P
p
.002 w
.53507 .43724 m .56648 .41075 L .54583 .3909 L p
1 g
F P
s
P
p
.002 w
.47947 .4011 m .45302 .40609 L .45416 .43471 L p
1 g
F P
s
P
p
.002 w
.45302 .40609 m .47947 .4011 L .47116 .37454 L p
1 g
F P
s
P
p
.002 w
.47947 .4011 m .50396 .38938 L .48795 .36648 L p
1 g
F P
s
P
p
.002 w
.48795 .36648 m .47116 .37454 L .47947 .4011 L p
1 g
F P
s
P
p
.002 w
.50396 .38938 m .5241 .37205 L .50169 .35454 L p
1 g
F P
s
P
p
.002 w
.50169 .35454 m .48795 .36648 L .50396 .38938 L p
1 g
F P
s
P
p
.002 w
.41635 .46026 m .4564 .46324 L .45416 .43471 L p
1 g
F P
s
P
p
.002 w
.45416 .43471 m .42081 .43199 L .41635 .46026 L p
1 g
F P
s
P
p
.002 w
.42081 .43199 m .45416 .43471 L .45302 .40609 L p
1 g
F P
s
P
p
.002 w
.46408 .51793 m .51541 .50759 L .50634 .48191 L p
1 g
F P
s
P
p
.002 w
.50634 .48191 m .45973 .49116 L .46408 .51793 L p
1 g
F P
s
P
p
.002 w
.54961 .46134 m .50634 .48191 L .51541 .50759 L p
1 g
F P
s
P
p
.002 w
.45302 .40609 m .42719 .40379 L .42081 .43199 L p
1 g
F P
s
P
p
.002 w
.42719 .40379 m .45302 .40609 L .45302 .3779 L p
1 g
F P
s
P
p
.002 w
.47116 .37454 m .45302 .3779 L .45302 .40609 L p
1 g
F P
s
P
p
.002 w
.41391 .48807 m .45973 .49116 L .4564 .46324 L p
1 g
F P
s
P
p
.002 w
.4564 .46324 m .41635 .46026 L .41391 .48807 L p
1 g
F P
s
P
p
.002 w
.51541 .50759 m .5631 .48497 L .54961 .46134 L p
1 g
F P
s
P
p
.002 w
.58566 .43123 m .54961 .46134 L .5631 .48497 L p
1 g
F P
s
P
p
.002 w
.54961 .46134 m .58566 .43123 L .56648 .41075 L p
1 g
F P
s
P
p
.002 w
.56382 .36356 m .54583 .3909 L .56648 .41075 L p
1 g
F P
s
P
p
.002 w
.54583 .3909 m .56382 .36356 L .53785 .35075 L p
1 g
F P
s
P
p
.002 w
.53785 .35075 m .5241 .37205 L .54583 .3909 L p
1 g
F P
s
P
p
.002 w
.45302 .3779 m .47116 .37454 L .46345 .34897 L p
1 g
F P
s
P
p
.002 w
.47116 .37454 m .48795 .36648 L .47203 .34485 L p
1 g
F P
s
P
p
.002 w
.47203 .34485 m .46345 .34897 L .47116 .37454 L p
1 g
F P
s
P
p
.002 w
.5241 .37205 m .53785 .35075 L .51096 .3399 L p
1 g
F P
s
P
p
.002 w
.51096 .3399 m .50169 .35454 L .5241 .37205 L p
1 g
F P
s
P
p
.002 w
.48795 .36648 m .50169 .35454 L .47901 .33872 L p
1 g
F P
s
P
p
.002 w
.47901 .33872 m .47203 .34485 L .48795 .36648 L p
1 g
F P
s
P
p
.002 w
.58838 .3781 m .56648 .41075 L .58566 .43123 L p
1 g
F P
s
P
p
.002 w
.56648 .41075 m .58838 .3781 L .56382 .36356 L p
1 g
F P
s
P
p
.002 w
.45302 .3779 m .43536 .3762 L .42719 .40379 L p
1 g
F P
s
P
p
.002 w
.43536 .3762 m .45302 .3779 L .45418 .35066 L p
1 g
F P
s
P
p
.002 w
.46345 .34897 m .45418 .35066 L .45302 .3779 L p
1 g
F P
s
P
p
.002 w
.41357 .51487 m .46408 .51793 L .45973 .49116 L p
1 g
F P
s
P
p
.002 w
.45973 .49116 m .41391 .48807 L .41357 .51487 L p
1 g
F P
s
P
p
.002 w
.50169 .35454 m .51096 .3399 L .48367 .33123 L p
1 g
F P
s
P
p
.002 w
.48367 .33123 m .47901 .33872 L .50169 .35454 L p
1 g
F P
s
P
p
.002 w
.39146 .42004 m .42081 .43199 L .42719 .40379 L p
1 g
F P
s
P
p
.002 w
.42719 .40379 m .40458 .3943 L .39146 .42004 L p
1 g
F P
s
P
p
.002 w
.40458 .3943 m .42719 .40379 L .43536 .3762 L p
1 g
F P
s
P
p
.002 w
.46941 .54303 m .52426 .53182 L .51541 .50759 L p
1 g
F P
s
P
p
.002 w
.51541 .50759 m .46408 .51793 L .46941 .54303 L p
1 g
F P
s
P
p
.002 w
.5631 .48497 m .51541 .50759 L .52426 .53182 L p
1 g
F P
s
P
p
.002 w
.38091 .44628 m .41635 .46026 L .42081 .43199 L p
1 g
F P
s
P
p
.002 w
.42081 .43199 m .39146 .42004 L .38091 .44628 L p
1 g
F P
s
P
p
.002 w
.52426 .53182 m .57528 .50766 L .5631 .48497 L p
1 g
F P
s
P
p
.002 w
.60298 .45197 m .5631 .48497 L .57528 .50766 L p
1 g
F P
s
P
p
.002 w
.5631 .48497 m .60298 .45197 L .58566 .43123 L p
1 g
F P
s
P
p
.002 w
.43536 .3762 m .42 .36955 L .40458 .3943 L p
1 g
F P
s
P
p
.002 w
.42 .36955 m .43536 .3762 L .44518 .34973 L p
1 g
F P
s
P
p
.002 w
.45418 .35066 m .44518 .34973 L .43536 .3762 L p
1 g
F P
s
P
p
.002 w
.61102 .39411 m .58566 .43123 L .60298 .45197 L p
1 g
F P
s
P
p
.002 w
.58566 .43123 m .61102 .39411 L .58838 .3781 L p
1 g
F P
s
P
p
.002 w
.54365 .32754 m .53785 .35075 L .56382 .36356 L p
1 g
F P
s
P
p
.002 w
.53785 .35075 m .54365 .32754 L .51472 .32402 L p
1 g
F P
s
P
p
.002 w
.51472 .32402 m .51096 .3399 L .53785 .35075 L p
1 g
F P
s
P
p
.002 w
.3732 .47251 m .41391 .48807 L .41635 .46026 L p
1 g
F P
s
P
p
.002 w
.41635 .46026 m .38091 .44628 L .3732 .47251 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .45418 .35066 L .46345 .34897 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .46345 .34897 L .47203 .34485 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .47203 .34485 L .47901 .33872 L closepath p
1 g
F P
s
P
p
.002 w
.51096 .3399 m .51472 .32402 L .48547 .32314 L p
1 g
F P
s
P
p
.002 w
.48547 .32314 m .48367 .33123 L .51096 .3399 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .44518 .34973 L .45418 .35066 L closepath p
1 g
F P
s
P
p
.002 w
.5717 .33364 m .56382 .36356 L .58838 .3781 L p
1 g
F P
s
P
p
.002 w
.56382 .36356 m .5717 .33364 L .54365 .32754 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .47901 .33872 L .48367 .33123 L closepath p
1 g
F P
s
P
p
.002 w
.41539 .5401 m .46941 .54303 L .46408 .51793 L p
1 g
F P
s
P
p
.002 w
.46408 .51793 m .41357 .51487 L .41539 .5401 L p
1 g
F P
s
P
p
.002 w
.44518 .34973 m .43741 .34627 L .42 .36955 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .43741 .34627 L .44518 .34973 L closepath p
1 g
F P
s
P
p
.002 w
.3876 .37839 m .40458 .3943 L .42 .36955 L p
1 g
F P
s
P
p
.002 w
.42 .36955 m .40858 .35855 L .3876 .37839 L p
1 g
F P
s
P
p
.002 w
.40858 .35855 m .42 .36955 L .43741 .34627 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .48367 .33123 L .48547 .32314 L closepath p
1 g
F P
s
P
p
.002 w
.3692 .39976 m .39146 .42004 L .40458 .3943 L p
1 g
F P
s
P
p
.002 w
.40458 .3943 m .3876 .37839 L .3692 .39976 L p
1 g
F P
s
P
p
.002 w
.59829 .34224 m .58838 .3781 L .61102 .39411 L p
1 g
F P
s
P
p
.002 w
.58838 .3781 m .59829 .34224 L .5717 .33364 L p
1 g
F P
s
P
p
.002 w
.36855 .49817 m .41357 .51487 L .41391 .48807 L p
1 g
F P
s
P
p
.002 w
.41391 .48807 m .3732 .47251 L .36855 .49817 L p
1 g
F P
s
P
p
.002 w
.47563 .5659 m .53271 .55407 L .52426 .53182 L p
1 g
F P
s
P
p
.002 w
.52426 .53182 m .46941 .54303 L .47563 .5659 L p
1 g
F P
s
P
p
.002 w
.57528 .50766 m .52426 .53182 L .53271 .55407 L p
1 g
F P
s
P
p
.002 w
.43741 .34627 m .4317 .34061 L .40858 .35855 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .4317 .34061 L .43741 .34627 L closepath p
1 g
F P
s
P
p
.002 w
.57528 .50766 m .61807 .47258 L .60298 .45197 L p
1 g
F P
s
P
p
.002 w
.63127 .4113 m .60298 .45197 L .61807 .47258 L p
1 g
F P
s
P
p
.002 w
.60298 .45197 m .63127 .4113 L .61102 .39411 L p
1 g
F P
s
P
p
.002 w
.51246 .30856 m .51472 .32402 L .54365 .32754 L p
1 g
F P
s
P
p
.002 w
.51472 .32402 m .51246 .30856 L .48421 .31533 L p
1 g
F P
s
P
p
.002 w
.48421 .31533 m .48547 .32314 L .51472 .32402 L p
1 g
F P
s
P
p
.002 w
.53271 .55407 m .58586 .52896 L .57528 .50766 L p
1 g
F P
s
P
p
.002 w
.61807 .47258 m .57528 .50766 L .58586 .52896 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .48547 .32314 L .48421 .31533 L closepath p
1 g
F P
s
P
p
.002 w
.35382 .42224 m .38091 .44628 L .39146 .42004 L p
1 g
F P
s
P
p
.002 w
.39146 .42004 m .3692 .39976 L .35382 .42224 L p
1 g
F P
s
P
p
.002 w
.54067 .30478 m .54365 .32754 L .5717 .33364 L p
1 g
F P
s
P
p
.002 w
.54365 .32754 m .54067 .30478 L .51246 .30856 L p
1 g
F P
s
P
p
.002 w
.40244 .34428 m .40858 .35855 L .4317 .34061 L p
1 g
F P
s
P
p
.002 w
.4317 .34061 m .4287 .33334 L .40244 .34428 L p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .4287 .33334 L .4317 .34061 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .47322 .30382 L .46463 .30142 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .46463 .30142 L .45517 .30173 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .45517 .30173 L .44589 .30473 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .44589 .30473 L .43784 .31009 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .43784 .31009 L .43192 .31719 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .43192 .31719 L .42876 .32524 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .42876 .32524 L .4287 .33334 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .48421 .31533 L .47999 .30864 L closepath p
1 g
F P
s
P
p
.002 w
.45649 .32492 m .47999 .30864 L .47322 .30382 L closepath p
1 g
F P
s
P
p
.002 w
.47999 .30864 m .48421 .31533 L .51246 .30856 L p
1 g
F P
s
P
p
.002 w
.37826 .35754 m .3876 .37839 L .40858 .35855 L p
1 g
F P
s
P
p
.002 w
.40858 .35855 m .40244 .34428 L .37826 .35754 L p
1 g
F P
s
P
p
.002 w
.41943 .56318 m .47563 .5659 L .46941 .54303 L p
1 g
F P
s
P
p
.002 w
.46941 .54303 m .41539 .5401 L .41943 .56318 L p
1 g
F P
s
P
p
.002 w
.62283 .35322 m .61102 .39411 L .63127 .4113 L p
1 g
F P
s
P
p
.002 w
.61102 .39411 m .62283 .35322 L .59829 .34224 L p
1 g
F P
s
P
p
.002 w
.34188 .44539 m .3732 .47251 L .38091 .44628 L p
1 g
F P
s
P
p
.002 w
.38091 .44628 m .35382 .42224 L .34188 .44539 L p
1 g
F P
s
P
p
.002 w
.40235 .32823 m .40244 .34428 L .4287 .33334 L p
1 g
F P
s
P
p
.002 w
.4287 .33334 m .42876 .32524 L .40235 .32823 L p
1 g
F P
s
P
p
.002 w
.56826 .30413 m .5717 .33364 L .59829 .34224 L p
1 g
F P
s
P
p
.002 w
.5717 .33364 m .56826 .30413 L .54067 .30478 L p
1 g
F P
s
P
p
.002 w
.36717 .52271 m .41539 .5401 L .41357 .51487 L p
1 g
F P
s
P
p
.002 w
.41357 .51487 m .36855 .49817 L .36717 .52271 L p
1 g
F P
s
P
p
.002 w
.50429 .29521 m .51246 .30856 L .54067 .30478 L p
1 g
F P
s
P
p
.002 w
.51246 .30856 m .50429 .29521 L .47999 .30864 L p
1 g
F P
s
P
p
.002 w
.47322 .30382 m .47999 .30864 L .50429 .29521 L p
1 g
F P
s
P
p
.002 w
.35673 .37291 m .3692 .39976 L .3876 .37839 L p
1 g
F P
s
P
p
.002 w
.3876 .37839 m .37826 .35754 L .35673 .37291 L p
1 g
F P
s
P
p
.002 w
.58586 .52896 m .63054 .49262 L .61807 .47258 L p
1 g
F P
s
P
p
.002 w
.64862 .42934 m .61807 .47258 L .63054 .49262 L p
1 g
F P
s
P
p
.002 w
.61807 .47258 m .64862 .42934 L .63127 .4113 L p
1 g
F P
s
P
p
.002 w
.40849 .31215 m .40235 .32823 L .42876 .32524 L p
1 g
F P
s
P
p
.002 w
.42876 .32524 m .43192 .31719 L .40849 .31215 L p
1 g
F P
s
P
p
.002 w
.48265 .58598 m .54057 .57384 L .53271 .55407 L p
1 g
F P
s
P
p
.002 w
.53271 .55407 m .47563 .5659 L .48265 .58598 L p
1 g
F P
s
P
p
.002 w
.58586 .52896 m .53271 .55407 L .54057 .57384 L p
1 g
F P
s
P
p
.002 w
.46463 .30142 m .47322 .30382 L .49097 .28549 L p
1 g
F P
s
P
p
.002 w
.50429 .29521 m .49097 .28549 L .47322 .30382 L p
1 g
F P
s
P
p
.002 w
.37785 .33388 m .37826 .35754 L .40244 .34428 L p
1 g
F P
s
P
p
.002 w
.40244 .34428 m .40235 .32823 L .37785 .33388 L p
1 g
F P
s
P
p
.002 w
.54057 .57384 m .59456 .54837 L .58586 .52896 L p
1 g
F P
s
P
p
.002 w
.63054 .49262 m .58586 .52896 L .59456 .54837 L p
1 g
F P
s
P
p
.002 w
.59462 .30668 m .59829 .34224 L .62283 .35322 L p
1 g
F P
s
P
p
.002 w
.59829 .34224 m .59462 .30668 L .56826 .30413 L p
1 g
F P
s
P
p
.002 w
.52891 .28497 m .54067 .30478 L .56826 .30413 L p
1 g
F P
s
P
p
.002 w
.54067 .30478 m .52891 .28497 L .50429 .29521 L p
1 g
F P
s
P
p
.002 w
.42025 .2979 m .40849 .31215 L .43192 .31719 L p
1 g
F P
s
P
p
.002 w
.43192 .31719 m .43784 .31009 L .42025 .2979 L p
1 g
F P
s
P
p
.002 w
.64476 .3664 m .63127 .4113 L .64862 .42934 L p
1 g
F P
s
P
p
.002 w
.63127 .4113 m .64476 .3664 L .62283 .35322 L p
1 g
F P
s
P
p
.002 w
.33374 .46871 m .36855 .49817 L .3732 .47251 L p
1 g
F P
s
P
p
.002 w
.3732 .47251 m .34188 .44539 L .33374 .46871 L p
1 g
F P
s
P
p
.002 w
.49097 .28549 m .47389 .28058 L .46463 .30142 L p
1 g
F P
s
P
p
.002 w
.45517 .30173 m .46463 .30142 L .47389 .28058 L p
1 g
F P
s
P
p
.002 w
.3384 .39013 m .35382 .42224 L .3692 .39976 L p
1 g
F P
s
P
p
.002 w
.3692 .39976 m .35673 .37291 L .3384 .39013 L p
1 g
F P
s
P
p
.002 w
.49097 .28549 m .50429 .29521 L .52891 .28497 L p
1 g
F P
s
P
p
.002 w
.43636 .28713 m .42025 .2979 L .43784 .31009 L p
1 g
F P
s
P
p
.002 w
.43784 .31009 m .44589 .30473 L .43636 .28713 L p
1 g
F P
s
P
p
.002 w
.47389 .28058 m .45496 .28113 L .45517 .30173 L p
1 g
F P
s
P
p
.002 w
.44589 .30473 m .45517 .30173 L .45496 .28113 L p
1 g
F P
s
P
p
.002 w
.45496 .28113 m .43636 .28713 L .44589 .30473 L p
1 g
F P
s
P
p
.002 w
.42566 .58351 m .48265 .58598 L .47563 .5659 L p
1 g
F P
s
P
p
.002 w
.47563 .5659 m .41943 .56318 L .42566 .58351 L p
1 g
F P
s
P
p
.002 w
.36921 .54552 m .41943 .56318 L .41539 .5401 L p
1 g
F P
s
P
p
.002 w
.41539 .5401 m .36717 .52271 L .36921 .54552 L p
1 g
F P
s
P
p
.002 w
.38674 .31002 m .37785 .33388 L .40235 .32823 L p
1 g
F P
s
P
p
.002 w
.40235 .32823 m .40849 .31215 L .38674 .31002 L p
1 g
F P
s
P
p
.002 w
.35587 .34219 m .35673 .37291 L .37826 .35754 L p
1 g
F P
s
P
p
.002 w
.37826 .35754 m .37785 .33388 L .35587 .34219 L p
1 g
F P
s
P
p
.002 w
.55334 .27824 m .56826 .30413 L .59462 .30668 L p
1 g
F P
s
P
p
.002 w
.56826 .30413 m .55334 .27824 L .52891 .28497 L p
1 g
F P
s
P
p
.002 w
.59456 .54837 m .64003 .51166 L .63054 .49262 L p
1 g
F P
s
P
p
.002 w
.66262 .4479 m .63054 .49262 L .64003 .51166 L p
1 g
F P
s
P
p
.002 w
.63054 .49262 m .66262 .4479 L .64862 .42934 L p
1 g
F P
s
P
p
.002 w
.61914 .3125 m .62283 .35322 L .64476 .3664 L p
1 g
F P
s
P
p
.002 w
.62283 .35322 m .61914 .3125 L .59462 .30668 L p
1 g
F P
s
P
p
.002 w
.47389 .28058 m .49097 .28549 L .50939 .27041 L p
1 g
F P
s
P
p
.002 w
.52891 .28497 m .50939 .27041 L .49097 .28549 L p
1 g
F P
s
P
p
.002 w
.32381 .40885 m .34188 .44539 L .35382 .42224 L p
1 g
F P
s
P
p
.002 w
.35382 .42224 m .3384 .39013 L .32381 .40885 L p
1 g
F P
s
P
p
.002 w
.32975 .49168 m .36717 .52271 L .36855 .49817 L p
1 g
F P
s
P
p
.002 w
.36855 .49817 m .33374 .46871 L .32975 .49168 L p
1 g
F P
s
P
p
.002 w
.50939 .27041 m .52891 .28497 L .55334 .27824 L p
1 g
F P
s
P
p
.002 w
.66349 .38159 m .64862 .42934 L .66262 .4479 L p
1 g
F P
s
P
p
.002 w
.64862 .42934 m .66349 .38159 L .64476 .3664 L p
1 g
F P
s
P
p
.002 w
.49036 .60269 m .54765 .59056 L .54057 .57384 L p
1 g
F P
s
P
p
.002 w
.54057 .57384 m .48265 .58598 L .49036 .60269 L p
1 g
F P
s
P
p
.002 w
.59456 .54837 m .54057 .57384 L .54765 .59056 L p
1 g
F P
s
P
p
.002 w
.40414 .28874 m .38674 .31002 L .40849 .31215 L p
1 g
F P
s
P
p
.002 w
.40849 .31215 m .42025 .2979 L .40414 .28874 L p
1 g
F P
s
P
p
.002 w
.54765 .59056 m .6011 .56538 L .59456 .54837 L p
1 g
F P
s
P
p
.002 w
.64003 .51166 m .59456 .54837 L .6011 .56538 L p
1 g
F P
s
P
p
.002 w
.50939 .27041 m .48411 .26297 L .47389 .28058 L p
1 g
F P
s
P
p
.002 w
.45496 .28113 m .47389 .28058 L .48411 .26297 L p
1 g
F P
s
P
p
.002 w
.33701 .35307 m .3384 .39013 L .35673 .37291 L p
1 g
F P
s
P
p
.002 w
.35673 .37291 m .35587 .34219 L .33701 .35307 L p
1 g
F P
s
P
p
.002 w
.42814 .27264 m .40414 .28874 L .42025 .2979 L p
1 g
F P
s
P
p
.002 w
.42025 .2979 m .43636 .28713 L .42814 .27264 L p
1 g
F P
s
P
p
.002 w
.37477 .566 m .42566 .58351 L .41943 .56318 L p
1 g
F P
s
P
p
.002 w
.41943 .56318 m .36921 .54552 L .37477 .566 L p
1 g
F P
s
P
p
.002 w
.36725 .31097 m .35587 .34219 L .37785 .33388 L p
1 g
F P
s
P
p
.002 w
.37785 .33388 m .38674 .31002 L .36725 .31097 L p
1 g
F P
s
P
p
.002 w
.57701 .27529 m .59462 .30668 L .61914 .3125 L p
1 g
F P
s
P
p
.002 w
.59462 .30668 m .57701 .27529 L .55334 .27824 L p
1 g
F P
s
P
p
.002 w
.48411 .26297 m .45591 .26371 L .45496 .28113 L p
1 g
F P
s
P
p
.002 w
.43636 .28713 m .45496 .28113 L .45591 .26371 L p
1 g
F P
s
P
p
.002 w
.43407 .60049 m .49036 .60269 L .48265 .58598 L p
1 g
F P
s
P
p
.002 w
.48265 .58598 m .42566 .58351 L .43407 .60049 L p
1 g
F P
s
P
p
.002 w
.45591 .26371 m .42814 .27264 L .43636 .28713 L p
1 g
F P
s
P
p
.002 w
.64119 .32155 m .64476 .3664 L .66349 .38159 L p
1 g
F P
s
P
p
.002 w
.64476 .3664 m .64119 .32155 L .61914 .3125 L p
1 g
F P
s
P
p
.002 w
.31347 .42871 m .33374 .46871 L .34188 .44539 L p
1 g
F P
s
P
p
.002 w
.34188 .44539 m .32381 .40885 L .31347 .42871 L p
1 g
F P
s
P
p
.002 w
.48411 .26297 m .50939 .27041 L .52811 .25907 L p
1 g
F P
s
P
p
.002 w
.55334 .27824 m .52811 .25907 L .50939 .27041 L p
1 g
F P
s
P
p
.002 w
.52811 .25907 m .55334 .27824 L .57701 .27529 L p
1 g
F P
s
P
p
.002 w
.33018 .51371 m .36921 .54552 L .36717 .52271 L p
1 g
F P
s
P
p
.002 w
.36717 .52271 m .32975 .49168 L .33018 .51371 L p
1 g
F P
s
P
p
.002 w
.6011 .56538 m .64618 .52922 L .64003 .51166 L p
1 g
F P
s
P
p
.002 w
.67279 .46656 m .64003 .51166 L .64618 .52922 L p
1 g
F P
s
P
p
.002 w
.64003 .51166 m .67279 .46656 L .66262 .4479 L p
1 g
F P
s
P
p
.002 w
.67846 .39849 m .66262 .4479 L .67279 .46656 L p
1 g
F P
s
P
p
.002 w
.66262 .4479 m .67846 .39849 L .66349 .38159 L p
1 g
F P
s
P
p
.002 w
.38996 .283 m .36725 .31097 L .38674 .31002 L p
1 g
F P
s
P
p
.002 w
.38674 .31002 m .40414 .28874 L .38996 .283 L p
1 g
F P
s
P
p
.002 w
.32189 .36637 m .32381 .40885 L .3384 .39013 L p
1 g
F P
s
P
p
.002 w
.3384 .39013 m .33701 .35307 L .32189 .36637 L p
1 g
F P
s
P
p
.002 w
.49861 .61547 m .55374 .6037 L .54765 .59056 L p
1 g
F P
s
P
p
.002 w
.54765 .59056 m .49036 .60269 L .49861 .61547 L p
1 g
F P
s
P
p
.002 w
.6011 .56538 m .54765 .59056 L .55374 .6037 L p
1 g
F P
s
P
p
.002 w
.59935 .27636 m .61914 .3125 L .64119 .32155 L p
1 g
F P
s
P
p
.002 w
.61914 .3125 m .59935 .27636 L .57701 .27529 L p
1 g
F P
s
P
p
.002 w
.52811 .25907 m .4951 .24916 L .48411 .26297 L p
1 g
F P
s
P
p
.002 w
.45591 .26371 m .48411 .26297 L .4951 .24916 L p
1 g
F P
s
P
p
.002 w
.55374 .6037 m .60523 .57947 L .6011 .56538 L p
1 g
F P
s
P
p
.002 w
.64618 .52922 m .6011 .56538 L .60523 .57947 L p
1 g
F P
s
P
p
.002 w
.3506 .31515 m .33701 .35307 L .35587 .34219 L p
1 g
F P
s
P
p
.002 w
.35587 .34219 m .36725 .31097 L .3506 .31515 L p
1 g
F P
s
P
p
.002 w
.38389 .58353 m .43407 .60049 L .42566 .58351 L p
1 g
F P
s
P
p
.002 w
.42566 .58351 m .37477 .566 L .38389 .58353 L p
1 g
F P
s
P
p
.002 w
.30783 .44925 m .32975 .49168 L .33374 .46871 L p
1 g
F P
s
P
p
.002 w
.33374 .46871 m .31347 .42871 L .30783 .44925 L p
1 g
F P
s
P
p
.002 w
.66014 .33378 m .66349 .38159 L .67846 .39849 L p
1 g
F P
s
P
p
.002 w
.66349 .38159 m .66014 .33378 L .64119 .32155 L p
1 g
F P
s
P
p
.002 w
.42151 .26178 m .38996 .283 L .40414 .28874 L p
1 g
F P
s
P
p
.002 w
.40414 .28874 m .42814 .27264 L .42151 .26178 L p
1 g
F P
s
P
p
.002 w
.44456 .61352 m .49861 .61547 L .49036 .60269 L p
1 g
F P
s
P
p
.002 w
.49036 .60269 m .43407 .60049 L .44456 .61352 L p
1 g
F P
s
P
p
.002 w
.4951 .24916 m .45806 .25003 L .45591 .26371 L p
1 g
F P
s
P
p
.002 w
.42814 .27264 m .45591 .26371 L .45806 .25003 L p
1 g
F P
s
P
p
.002 w
.54669 .25189 m .57701 .27529 L .59935 .27636 L p
1 g
F P
s
P
p
.002 w
.57701 .27529 m .54669 .25189 L .52811 .25907 L p
1 g
F P
s
P
p
.002 w
.45806 .25003 m .42151 .26178 L .42814 .27264 L p
1 g
F P
s
P
p
.002 w
.4951 .24916 m .52811 .25907 L .54669 .25189 L p
1 g
F P
s
P
p
.002 w
.33524 .5342 m .37477 .566 L .36921 .54552 L p
1 g
F P
s
P
p
.002 w
.36921 .54552 m .33018 .51371 L .33524 .5342 L p
1 g
F P
s
P
p
.002 w
.60523 .57947 m .64867 .54479 L .64618 .52922 L p
1 g
F P
s
P
p
.002 w
.6787 .48489 m .64618 .52922 L .64867 .54479 L p
1 g
F P
s
P
p
.002 w
.64618 .52922 m .6787 .48489 L .67279 .46656 L p
1 g
F P
s
P
p
.002 w
.68913 .41679 m .67279 .46656 L .6787 .48489 L p
1 g
F P
s
P
p
.002 w
.67279 .46656 m .68913 .41679 L .67846 .39849 L p
1 g
F P
s
P
p
.002 w
.31109 .38189 m .31347 .42871 L .32381 .40885 L p
1 g
F P
s
P
p
.002 w
.32381 .40885 m .32189 .36637 L .31109 .38189 L p
1 g
F P
s
P
p
.002 w
.61973 .2816 m .64119 .32155 L .66014 .33378 L p
1 g
F P
s
P
p
.002 w
.64119 .32155 m .61973 .2816 L .59935 .27636 L p
1 g
F P
s
P
p
.002 w
.37819 .281 m .3506 .31515 L .36725 .31097 L p
1 g
F P
s
P
p
.002 w
.36725 .31097 m .38996 .283 L .37819 .281 L p
1 g
F P
s
P
p
.002 w
.33738 .32263 m .32189 .36637 L .33701 .35307 L p
1 g
F P
s
P
p
.002 w
.33701 .35307 m .3506 .31515 L .33738 .32263 L p
1 g
F P
s
P
p
.002 w
.30728 .46997 m .33018 .51371 L .32975 .49168 L p
1 g
F P
s
P
p
.002 w
.32975 .49168 m .30783 .44925 L .30728 .46997 L p
1 g
F P
s
P
p
.002 w
.67536 .349 m .67846 .39849 L .68913 .41679 L p
1 g
F P
s
P
p
.002 w
.67846 .39849 m .67536 .349 L .66014 .33378 L p
1 g
F P
s
P
p
.002 w
.50724 .62375 m .55864 .61272 L .55374 .6037 L p
1 g
F P
s
P
p
.002 w
.55374 .6037 m .49861 .61547 L .50724 .62375 L p
1 g
F P
s
P
p
.002 w
.60523 .57947 m .55374 .6037 L .55864 .61272 L p
1 g
F P
s
P
p
.002 w
.54669 .25189 m .50664 .23969 L .4951 .24916 L p
1 g
F P
s
P
p
.002 w
.45806 .25003 m .4951 .24916 L .50664 .23969 L p
1 g
F P
s
P
p
.002 w
.39651 .59748 m .44456 .61352 L .43407 .60049 L p
1 g
F P
s
P
p
.002 w
.43407 .60049 m .38389 .58353 L .39651 .59748 L p
1 g
F P
s
P
p
.002 w
.55864 .61272 m .60669 .59013 L .60523 .57947 L p
1 g
F P
s
P
p
.002 w
.64867 .54479 m .60523 .57947 L .60669 .59013 L p
1 g
F P
s
P
p
.002 w
.56468 .24927 m .59935 .27636 L .61973 .2816 L p
1 g
F P
s
P
p
.002 w
.59935 .27636 m .56468 .24927 L .54669 .25189 L p
1 g
F P
s
P
p
.002 w
.41672 .25503 m .37819 .281 L .38996 .283 L p
1 g
F P
s
P
p
.002 w
.38996 .283 m .42151 .26178 L .41672 .25503 L p
1 g
F P
s
P
p
.002 w
.34503 .55252 m .38389 .58353 L .37477 .566 L p
1 g
F P
s
P
p
.002 w
.37477 .566 m .33524 .5342 L .34503 .55252 L p
1 g
F P
s
P
p
.002 w
.50664 .23969 m .54669 .25189 L .56468 .24927 L p
1 g
F P
s
P
p
.002 w
.45697 .62205 m .50724 .62375 L .49861 .61547 L p
1 g
F P
s
P
p
.002 w
.49861 .61547 m .44456 .61352 L .45697 .62205 L p
1 g
F P
s
P
p
.002 w
.50664 .23969 m .46144 .24068 L .45806 .25003 L p
1 g
F P
s
P
p
.002 w
.42151 .26178 m .45806 .25003 L .46144 .24068 L p
1 g
F P
s
P
p
.002 w
.46144 .24068 m .41672 .25503 L .42151 .26178 L p
1 g
F P
s
P
p
.002 w
.30512 .39931 m .30783 .44925 L .31347 .42871 L p
1 g
F P
s
P
p
.002 w
.31347 .42871 m .31109 .38189 L .30512 .39931 L p
1 g
F P
s
P
p
.002 w
.64867 .54479 m .68 .50241 L .6787 .48489 L p
1 g
F P
s
P
p
.002 w
.69501 .43608 m .6787 .48489 L .68 .50241 L p
1 g
F P
s
P
p
.002 w
.6787 .48489 m .69501 .43608 L .68913 .41679 L p
1 g
F P
s
P
p
.002 w
.63754 .29108 m .66014 .33378 L .67536 .349 L p
1 g
F P
s
P
p
.002 w
.66014 .33378 m .63754 .29108 L .61973 .2816 L p
1 g
F P
s
P
p
.002 w
.60669 .59013 m .64722 .55789 L .64867 .54479 L p
1 g
F P
s
P
p
.002 w
.68 .50241 m .64867 .54479 L .64722 .55789 L p
1 g
F P
s
P
p
.002 w
.36927 .28304 m .33738 .32263 L .3506 .31515 L p
1 g
F P
s
P
p
.002 w
.3506 .31515 m .37819 .281 L .36927 .28304 L p
1 g
F P
s
P
p
.002 w
.3121 .49029 m .33524 .5342 L .33018 .51371 L p
1 g
F P
s
P
p
.002 w
.33018 .51371 m .30728 .46997 L .3121 .49029 L p
1 g
F P
s
P
p
.002 w
.32815 .3334 m .31109 .38189 L .32189 .36637 L p
1 g
F P
s
P
p
.002 w
.32189 .36637 m .33738 .32263 L .32815 .3334 L p
1 g
F P
s
P
p
.002 w
.68627 .36697 m .68913 .41679 L .69501 .43608 L p
1 g
F P
s
P
p
.002 w
.68913 .41679 m .68627 .36697 L .67536 .349 L p
1 g
F P
s
P
p
.002 w
.56468 .24927 m .51846 .23507 L .50664 .23969 L p
1 g
F P
s
P
p
.002 w
.46144 .24068 m .50664 .23969 L .51846 .23507 L p
1 g
F P
s
P
p
.002 w
.58156 .25153 m .61973 .2816 L .63754 .29108 L p
1 g
F P
s
P
p
.002 w
.61973 .2816 m .58156 .25153 L .56468 .24927 L p
1 g
F P
s
P
p
.002 w
.41248 .60728 m .45697 .62205 L .44456 .61352 L p
1 g
F P
s
P
p
.002 w
.44456 .61352 m .39651 .59748 L .41248 .60728 L p
1 g
F P
s
P
p
.002 w
.51602 .62706 m .56213 .61714 L .55864 .61272 L p
1 g
F P
s
P
p
.002 w
.55864 .61272 m .50724 .62375 L .51602 .62706 L p
1 g
F P
s
P
p
.002 w
.60669 .59013 m .55864 .61272 L .56213 .61714 L p
1 g
F P
s
P
p
.002 w
.56213 .61714 m .60528 .59686 L .60669 .59013 L p
1 g
F P
s
P
p
.002 w
.64722 .55789 m .60669 .59013 L .60528 .59686 L p
1 g
F P
s
P
p
.002 w
.35949 .56804 m .39651 .59748 L .38389 .58353 L p
1 g
F P
s
P
p
.002 w
.38389 .58353 m .34503 .55252 L .35949 .56804 L p
1 g
F P
s
P
p
.002 w
.51846 .23507 m .56468 .24927 L .58156 .25153 L p
1 g
F P
s
P
p
.002 w
.41403 .25285 m .36927 .28304 L .37819 .281 L p
1 g
F P
s
P
p
.002 w
.37819 .281 m .41672 .25503 L .41403 .25285 L p
1 g
F P
s
P
p
.002 w
.30443 .41826 m .30728 .46997 L .30783 .44925 L p
1 g
F P
s
P
p
.002 w
.30783 .44925 m .30512 .39931 L .30443 .41826 L p
1 g
F P
s
P
p
.002 w
.47107 .62557 m .51602 .62706 L .50724 .62375 L p
1 g
F P
s
P
p
.002 w
.50724 .62375 m .45697 .62205 L .47107 .62557 L p
1 g
F P
s
P
p
.002 w
.65215 .30477 m .67536 .349 L .68627 .36697 L p
1 g
F P
s
P
p
.002 w
.67536 .349 m .65215 .30477 L .63754 .29108 L p
1 g
F P
s
P
p
.002 w
.51846 .23507 m .46603 .23617 L .46144 .24068 L p
1 g
F P
s
P
p
.002 w
.41672 .25503 m .46144 .24068 L .46603 .23617 L p
1 g
F P
s
P
p
.002 w
.64722 .55789 m .67638 .51861 L .68 .50241 L p
1 g
F P
s
P
p
.002 w
.6957 .45589 m .68 .50241 L .67638 .51861 L p
1 g
F P
s
P
p
.002 w
.68 .50241 m .6957 .45589 L .69501 .43608 L p
1 g
F P
s
P
p
.002 w
.46603 .23617 m .41403 .25285 L .41672 .25503 L p
1 g
F P
s
P
p
.002 w
.32241 .50961 m .34503 .55252 L .33524 .5342 L p
1 g
F P
s
P
p
.002 w
.33524 .5342 m .3121 .49029 L .32241 .50961 L p
1 g
F P
s
P
p
.002 w
.60528 .59686 m .64162 .56799 L .64722 .55789 L p
1 g
F P
s
P
p
.002 w
.67638 .51861 m .64722 .55789 L .64162 .56799 L p
1 g
F P
s
P
p
.002 w
.32341 .34735 m .30512 .39931 L .31109 .38189 L p
1 g
F P
s
P
p
.002 w
.31109 .38189 m .32815 .3334 L .32341 .34735 L p
1 g
F P
s
P
p
.002 w
.69501 .43608 m .69235 .38733 L .68627 .36697 L p
1 g
F P
s
P
p
.002 w
.69235 .38733 m .69501 .43608 L .6957 .45589 L p
1 g
F P
s
P
p
.002 w
.36365 .28931 m .32815 .3334 L .33738 .32263 L p
1 g
F P
s
P
p
.002 w
.33738 .32263 m .36927 .28304 L .36365 .28931 L p
1 g
F P
s
P
p
.004 w
.70849 .41362 m
.77342 .40836 L
s
P
p
.002 w
.63754 .29108 m .5968 .25888 L .58156 .25153 L p
1 g
F P
s
P
p
.002 w
.5968 .25888 m .63754 .29108 L .65215 .30477 L p
1 g
F P
s
P
p
.002 w
.58156 .25153 m .53026 .23571 L .51846 .23507 L p
1 g
F P
s
P
p
.002 w
.46603 .23617 m .51846 .23507 L .53026 .23571 L p
1 g
F P
s
P
p
.002 w
.43152 .61242 m .47107 .62557 L .45697 .62205 L p
1 g
F P
s
P
p
.002 w
.45697 .62205 m .41248 .60728 L .43152 .61242 L p
1 g
F P
s
P
p
.002 w
.37846 .58015 m .41248 .60728 L .39651 .59748 L p
1 g
F P
s
P
p
.002 w
.39651 .59748 m .35949 .56804 L .37846 .58015 L p
1 g
F P
s
P
p
.002 w
.53026 .23571 m .58156 .25153 L .5968 .25888 L p
1 g
F P
s
P
p
.002 w
.60528 .59686 m .56213 .61714 L .56404 .61651 L p
1 g
F P
s
P
p
.002 w
.52473 .62497 m .56404 .61651 L .56213 .61714 L p
1 g
F P
s
P
p
.002 w
.56213 .61714 m .51602 .62706 L .52473 .62497 L p
1 g
F P
s
P
p
.002 w
.30933 .43823 m .3121 .49029 L .30728 .46997 L p
1 g
F P
s
P
p
.002 w
.30728 .46997 m .30443 .41826 L .30933 .43823 L p
1 g
F P
s
P
p
.002 w
.68627 .36697 m .66297 .32248 L .65215 .30477 L p
1 g
F P
s
P
p
.002 w
.66297 .32248 m .68627 .36697 L .69235 .38733 L p
1 g
F P
s
P
p
.002 w
.56404 .61651 m .60086 .59921 L .60528 .59686 L p
1 g
F P
s
P
p
.002 w
.64162 .56799 m .60528 .59686 L .60086 .59921 L p
1 g
F P
s
P
p
.002 w
.41366 .2556 m .36365 .28931 L .36927 .28304 L p
1 g
F P
s
P
p
.002 w
.36927 .28304 m .41403 .25285 L .41366 .2556 L p
1 g
F P
s
P
p
.002 w
.64162 .56799 m .66766 .53296 L .67638 .51861 L p
1 g
F P
s
P
p
.002 w
.67638 .51861 m .69091 .47569 L .6957 .45589 L p
1 g
F P
s
P
p
.002 w
.69091 .47569 m .67638 .51861 L .66766 .53296 L p
1 g
F P
s
P
p
.002 w
.48656 .62368 m .52473 .62497 L .51602 .62706 L p
1 g
F P
s
P
p
.002 w
.51602 .62706 m .47107 .62557 L .48656 .62368 L p
1 g
F P
s
P
p
.002 w
.33818 .52728 m .35949 .56804 L .34503 .55252 L p
1 g
F P
s
P
p
.002 w
.34503 .55252 m .32241 .50961 L .33818 .52728 L p
1 g
F P
s
P
p
.002 w
.53026 .23571 m .47178 .23695 L .46603 .23617 L p
1 g
F P
s
P
p
.002 w
.41403 .25285 m .46603 .23617 L .47178 .23695 L p
1 g
F P
s
P
p
.002 w
.69317 .4096 m .6957 .45589 L .69091 .47569 L p
1 g
F P
s
P
p
.002 w
.6957 .45589 m .69317 .4096 L .69235 .38733 L p
1 g
F P
s
P
p
.002 w
.32358 .36425 m .30443 .41826 L .30512 .39931 L p
1 g
F P
s
P
p
.002 w
.30512 .39931 m .32341 .34735 L .32358 .36425 L p
1 g
F P
s
P
p
.002 w
.47178 .23695 m .41366 .2556 L .41403 .25285 L p
1 g
F P
s
P
p
.002 w
.60086 .59921 m .63179 .57462 L .64162 .56799 L p
1 g
F P
s
P
p
.002 w
.66766 .53296 m .64162 .56799 L .63179 .57462 L p
1 g
F P
s
P
p
.002 w
.3617 .29991 m .32341 .34735 L .32815 .3334 L p
1 g
F P
s
P
p
.002 w
.32815 .3334 m .36365 .28931 L .3617 .29991 L p
1 g
F P
s
P
p
.002 w
.60986 .27139 m .65215 .30477 L .66297 .32248 L p
1 g
F P
s
P
p
.002 w
.65215 .30477 m .60986 .27139 L .5968 .25888 L p
1 g
F P
s
P
p
.002 w
.40155 .58832 m .43152 .61242 L .41248 .60728 L p
1 g
F P
s
P
p
.002 w
.41248 .60728 m .37846 .58015 L .40155 .58832 L p
1 g
F P
s
P
p
.002 w
.4532 .61248 m .48656 .62368 L .47107 .62557 L p
1 g
F P
s
P
p
.002 w
.47107 .62557 m .43152 .61242 L .4532 .61248 L p
1 g
F P
s
P
p
.002 w
.31995 .45867 m .32241 .50961 L .3121 .49029 L p
1 g
F P
s
P
p
.002 w
.3121 .49029 m .30933 .43823 L .31995 .45867 L p
1 g
F P
s
P
p
.002 w
.66947 .34391 m .69235 .38733 L .69317 .4096 L p
1 g
F P
s
P
p
.002 w
.69235 .38733 m .66947 .34391 L .66297 .32248 L p
1 g
F P
s
P
p
.002 w
.5968 .25888 m .54168 .24194 L .53026 .23571 L p
1 g
F P
s
P
p
.002 w
.47178 .23695 m .53026 .23571 L .54168 .24194 L p
1 g
F P
s
P
p
.002 w
.54168 .24194 m .5968 .25888 L .60986 .27139 L p
1 g
F P
s
P
p
.002 w
.5331 .61719 m .5642 .61052 L .56404 .61651 L p
1 g
F P
s
P
p
.002 w
.56404 .61651 m .52473 .62497 L .5331 .61719 L p
1 g
F P
s
P
p
.002 w
.60086 .59921 m .56404 .61651 L .5642 .61052 L p
1 g
F P
s
P
p
.004 w
.57514 .61285 m
.58464 .63592 L
s
P
p
.002 w
.35917 .54266 m .37846 .58015 L .35949 .56804 L p
1 g
F P
s
P
p
.002 w
.35949 .56804 m .33818 .52728 L .35917 .54266 L p
1 g
F P
s
P
p
.002 w
.5642 .61052 m .59334 .59682 L .60086 .59921 L p
1 g
F P
s
P
p
.002 w
.63179 .57462 m .60086 .59921 L .59334 .59682 L p
1 g
F P
s
P
p
.002 w
.63179 .57462 m .65381 .54492 L .66766 .53296 L p
1 g
F P
s
P
p
.002 w
.68048 .49487 m .66766 .53296 L .65381 .54492 L p
1 g
F P
s
P
p
.002 w
.66766 .53296 m .68048 .49487 L .69091 .47569 L p
1 g
F P
s
P
p
.002 w
.41577 .26353 m .3617 .29991 L .36365 .28931 L p
1 g
F P
s
P
p
.002 w
.36365 .28931 m .41366 .2556 L .41577 .26353 L p
1 g
F P
s
P
p
.002 w
.68844 .43319 m .69091 .47569 L .68048 .49487 L p
1 g
F P
s
P
p
.002 w
.69091 .47569 m .68844 .43319 L .69317 .4096 L p
1 g
F P
s
P
p
.002 w
.50303 .61611 m .5331 .61719 L .52473 .62497 L p
1 g
F P
s
P
p
.002 w
.52473 .62497 m .48656 .62368 L .50303 .61611 L p
1 g
F P
s
P
p
.002 w
.32893 .38373 m .30933 .43823 L .30443 .41826 L p
1 g
F P
s
P
p
.002 w
.30443 .41826 m .32358 .36425 L .32893 .38373 L p
1 g
F P
s
P
p
.002 w
.54168 .24194 m .4786 .24334 L .47178 .23695 L p
1 g
F P
s
P
p
.002 w
.41366 .2556 m .47178 .23695 L .4786 .24334 L p
1 g
F P
s
P
p
.002 w
.62021 .28899 m .66297 .32248 L .66947 .34391 L p
1 g
F P
s
P
p
.002 w
.66297 .32248 m .62021 .28899 L .60986 .27139 L p
1 g
F P
s
P
p
.002 w
.59334 .59682 m .61775 .57737 L .63179 .57462 L p
1 g
F P
s
P
p
.002 w
.65381 .54492 m .63179 .57462 L .61775 .57737 L p
1 g
F P
s
P
p
.002 w
.36373 .31478 m .32358 .36425 L .32341 .34735 L p
1 g
F P
s
P
p
.002 w
.32341 .34735 m .3617 .29991 L .36373 .31478 L p
1 g
F P
s
P
p
.002 w
.4786 .24334 m .41577 .26353 L .41366 .2556 L p
1 g
F P
s
P
p
.002 w
.33624 .47891 m .33818 .52728 L .32241 .50961 L p
1 g
F P
s
P
p
.002 w
.32241 .50961 m .31995 .45867 L .33624 .47891 L p
1 g
F P
s
P
p
.002 w
.42821 .59208 m .4532 .61248 L .43152 .61242 L p
1 g
F P
s
P
p
.002 w
.43152 .61242 m .40155 .58832 L .42821 .59208 L p
1 g
F P
s
P
p
.002 w
.67124 .36855 m .69317 .4096 L .68844 .43319 L p
1 g
F P
s
P
p
.004 w
.69279 .41489 m
.70849 .41362 L
s
P
p
.002 w
.69317 .4096 m .67124 .36855 L .66947 .34391 L p
1 g
F P
s
P
p
.002 w
.47697 .60721 m .50303 .61611 L .48656 .62368 L p
1 g
F P
s
P
p
.002 w
.48656 .62368 m .4532 .61248 L .47697 .60721 L p
1 g
F P
s
P
p
.002 w
.55235 .25389 m .60986 .27139 L .62021 .28899 L p
1 g
F P
s
P
p
.002 w
.60986 .27139 m .55235 .25389 L .54168 .24194 L p
1 g
F P
s
P
p
.002 w
.4786 .24334 m .54168 .24194 L .55235 .25389 L p
1 g
F P
s
P
p
.002 w
.3849 .55513 m .40155 .58832 L .37846 .58015 L p
1 g
F P
s
P
p
.002 w
.37846 .58015 m .35917 .54266 L .3849 .55513 L p
1 g
F P
s
P
p
.002 w
.61775 .57737 m .63498 .55398 L .65381 .54492 L p
1 g
F P
s
P
p
.002 w
.66446 .51281 m .65381 .54492 L .63498 .55398 L p
1 g
F P
s
P
p
.002 w
.65381 .54492 m .66446 .51281 L .68048 .49487 L p
1 g
F P
s
P
p
.002 w
.67805 .4574 m .68048 .49487 L .66446 .51281 L p
1 g
F P
s
P
p
.002 w
.68048 .49487 m .67805 .4574 L .68844 .43319 L p
1 g
F P
s
P
p
.002 w
.54085 .60361 m .56248 .599 L .5642 .61052 L p
1 g
F P
s
P
p
.002 w
.5642 .61052 m .5331 .61719 L .54085 .60361 L p
1 g
F P
s
P
p
.002 w
.59334 .59682 m .5642 .61052 L .56248 .599 L p
1 g
F P
s
P
p
.002 w
.33957 .40526 m .31995 .45867 L .30933 .43823 L p
1 g
F P
s
P
p
.002 w
.30933 .43823 m .32893 .38373 L .33957 .40526 L p
1 g
F P
s
P
p
.002 w
.56248 .599 m .58277 .58946 L .59334 .59682 L p
1 g
F P
s
P
p
.002 w
.61775 .57737 m .59334 .59682 L .58277 .58946 L p
1 g
F P
s
P
p
.002 w
.62737 .31135 m .66947 .34391 L .67124 .36855 L p
1 g
F P
s
P
p
.002 w
.66947 .34391 m .62737 .31135 L .62021 .28899 L p
1 g
F P
s
P
p
.002 w
.42045 .27673 m .36373 .31478 L .3617 .29991 L p
1 g
F P
s
P
p
.002 w
.3617 .29991 m .41577 .26353 L .42045 .27673 L p
1 g
F P
s
P
p
.002 w
.52002 .60279 m .54085 .60361 L .5331 .61719 L p
1 g
F P
s
P
p
.002 w
.5331 .61719 m .50303 .61611 L .52002 .60279 L p
1 g
F P
s
P
p
.002 w
.35787 .49825 m .35917 .54266 L .33818 .52728 L p
1 g
F P
s
P
p
.002 w
.33818 .52728 m .33624 .47891 L .35787 .49825 L p
1 g
F P
s
P
p
.002 w
.66801 .39574 m .68844 .43319 L .67805 .4574 L p
1 g
F P
s
P
p
.002 w
.68844 .43319 m .66801 .39574 L .67124 .36855 L p
1 g
F P
s
P
p
.004 w
.68437 .41557 m
.69279 .41489 L
s
P
p
.002 w
.3699 .33367 m .32893 .38373 L .32358 .36425 L p
1 g
F P
s
P
p
.002 w
.32358 .36425 m .36373 .31478 L .3699 .33367 L p
1 g
F P
s
P
p
.002 w
.55235 .25389 m .48633 .25552 L .4786 .24334 L p
1 g
F P
s
P
p
.002 w
.41577 .26353 m .4786 .24334 L .48633 .25552 L p
1 g
F P
s
P
p
.002 w
.58277 .58946 m .5997 .57591 L .61775 .57737 L p
1 g
F P
s
P
p
.002 w
.63498 .55398 m .61775 .57737 L .5997 .57591 L p
1 g
F P
s
P
p
.002 w
.4577 .59115 m .47697 .60721 L .4532 .61248 L p
1 g
F P
s
P
p
.002 w
.4532 .61248 m .42821 .59208 L .4577 .59115 L p
1 g
F P
s
P
p
.002 w
.48633 .25552 m .42045 .27673 L .41577 .26353 L p
1 g
F P
s
P
p
.002 w
.41467 .56416 m .42821 .59208 L .40155 .58832 L p
1 g
F P
s
P
p
.002 w
.40155 .58832 m .3849 .55513 L .41467 .56416 L p
1 g
F P
s
P
p
.002 w
.56188 .27153 m .62021 .28899 L .62737 .31135 L p
1 g
F P
s
P
p
.002 w
.62021 .28899 m .56188 .27153 L .55235 .25389 L p
1 g
F P
s
P
p
.002 w
.50213 .59654 m .52002 .60279 L .50303 .61611 L p
1 g
F P
s
P
p
.002 w
.50303 .61611 m .47697 .60721 L .50213 .59654 L p
1 g
F P
s
P
p
.002 w
.48633 .25552 m .55235 .25389 L .56188 .27153 L p
1 g
F P
s
P
p
.002 w
.63498 .55398 m .64311 .52886 L .66446 .51281 L p
1 g
F P
s
P
p
.002 w
.66212 .48147 m .66446 .51281 L .64311 .52886 L p
1 g
F P
s
P
p
.002 w
.66446 .51281 m .66212 .48147 L .67805 .4574 L p
1 g
F P
s
P
p
.002 w
.5997 .57591 m .61152 .55969 L .63498 .55398 L p
1 g
F P
s
P
p
.002 w
.64311 .52886 m .63498 .55398 L .61152 .55969 L p
1 g
F P
s
P
p
.002 w
.35539 .42821 m .33624 .47891 L .31995 .45867 L p
1 g
F P
s
P
p
.002 w
.31995 .45867 m .33957 .40526 L .35539 .42821 L p
1 g
F P
s
P
p
.002 w
.63095 .33796 m .67124 .36855 L .66801 .39574 L p
1 g
F P
s
P
p
.002 w
.67124 .36855 m .63095 .33796 L .62737 .31135 L p
1 g
F P
s
P
p
.002 w
.65966 .42465 m .67805 .4574 L .66212 .48147 L p
1 g
F P
s
P
p
.002 w
.67805 .4574 m .65966 .42465 L .66801 .39574 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.66175 .4174 L
s
P
p
.004 w
.67306 .41649 m
.67442 .41638 L
s
P
p
.004 w
.67442 .41638 m
.68437 .41557 L
s
P
p
.002 w
.3843 .51599 m .3849 .55513 L .35917 .54266 L p
1 g
F P
s
P
p
.002 w
.35917 .54266 m .35787 .49825 L .3843 .51599 L p
1 g
F P
s
P
p
.002 w
.54766 .58435 m .55883 .582 L .56248 .599 L p
1 g
F P
s
P
p
.002 w
.56248 .599 m .54085 .60361 L .54766 .58435 L p
1 g
F P
s
P
p
.002 w
.58277 .58946 m .56248 .599 L .55883 .582 L p
1 g
F P
s
P
p
.002 w
.55883 .582 m .56931 .57706 L .58277 .58946 L p
1 g
F P
s
P
p
.002 w
.5997 .57591 m .58277 .58946 L .56931 .57706 L p
1 g
F P
s
P
p
.002 w
.42771 .29506 m .3699 .33367 L .36373 .31478 L p
1 g
F P
s
P
p
.002 w
.36373 .31478 m .42045 .27673 L .42771 .29506 L p
1 g
F P
s
P
p
.002 w
.48909 .58537 m .50213 .59654 L .47697 .60721 L p
1 g
F P
s
P
p
.002 w
.47697 .60721 m .4577 .59115 L .48909 .58537 L p
1 g
F P
s
P
p
.002 w
.53696 .58388 m .54766 .58435 L .54085 .60361 L p
1 g
F P
s
P
p
.002 w
.54085 .60361 m .52002 .60279 L .53696 .58388 L p
1 g
F P
s
P
p
.002 w
.38023 .35615 m .33957 .40526 L .32893 .38373 L p
1 g
F P
s
P
p
.002 w
.32893 .38373 m .3699 .33367 L .38023 .35615 L p
1 g
F P
s
P
p
.002 w
.44755 .56933 m .4577 .59115 L .42821 .59208 L p
1 g
F P
s
P
p
.002 w
.42821 .59208 m .41467 .56416 L .44755 .56933 L p
1 g
F P
s
P
p
.002 w
.56931 .57706 m .57801 .57005 L .5997 .57591 L p
1 g
F P
s
P
p
.002 w
.61152 .55969 m .5997 .57591 L .57801 .57005 L p
1 g
F P
s
P
p
.002 w
.56188 .27153 m .49477 .27341 L .48633 .25552 L p
1 g
F P
s
P
p
.002 w
.42045 .27673 m .48633 .25552 L .49477 .27341 L p
1 g
F P
s
P
p
.002 w
.56988 .29456 m .62737 .31135 L .63095 .33796 L p
1 g
F P
s
P
p
.002 w
.62737 .31135 m .56988 .29456 L .56188 .27153 L p
1 g
F P
s
P
p
.002 w
.61152 .55969 m .61693 .5424 L .64311 .52886 L p
1 g
F P
s
P
p
.002 w
.64097 .50456 m .64311 .52886 L .61693 .5424 L p
1 g
F P
s
P
p
.002 w
.64311 .52886 m .64097 .50456 L .66212 .48147 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.52786 .58059 m .53696 .58388 L .52002 .60279 L p
1 g
F P
s
P
p
.002 w
.52002 .60279 m .50213 .59654 L .52786 .58059 L p
1 g
F P
s
P
p
.002 w
.49477 .27341 m .42771 .29506 L .42045 .27673 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.63067 .36807 m .66801 .39574 L .65966 .42465 L p
1 g
F P
s
P
p
.002 w
.66801 .39574 m .63067 .36807 L .63095 .33796 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37601 .4518 m .35787 .49825 L .33624 .47891 L p
1 g
F P
s
P
p
.002 w
.33624 .47891 m .35539 .42821 L .37601 .4518 L p
1 g
F P
s
P
p
.002 w
.57801 .57005 m .58401 .5617 L .61152 .55969 L p
1 g
F P
s
P
p
.002 w
.61693 .5424 m .61152 .55969 L .58401 .5617 L p
1 g
F P
s
P
p
.002 w
.49477 .27341 m .56188 .27153 L .56988 .29456 L p
1 g
F P
s
P
p
.002 w
.64633 .45434 m .66212 .48147 L .64097 .50456 L p
1 g
F P
s
P
p
.002 w
.66212 .48147 m .64633 .45434 L .65966 .42465 L p
1 g
F P
s
P
p
.002 w
.4147 .53142 m .41467 .56416 L .3849 .55513 L p
1 g
F P
s
P
p
.002 w
.3849 .55513 m .3843 .51599 L .4147 .53142 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.54145 .53109 L
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48909 .58537 m .4577 .59115 L p
.47504 .57658 L 1 g
F P
s
P
p
.002 w
.48694 .58051 m .48909 .58537 L p
.47504 .57658 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.4577 .59115 m .44755 .56933 L .45354 .56951 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46834 .57438 L p
1 g
F P
s
P
p
.48921 .57862 m .46834 .57438 L .47856 .57775 L 1 g
F
P
p
.002 w
.45354 .56951 m .46038 .56971 L p
.46834 .57438 L 1 g
F P
s
P
p
.4577 .59115 m .45354 .56951 L .47504 .57658 L 1 g
F
P
p
.002 w
.46038 .56971 m .44755 .56933 L p
.45491 .56596 L 1 g
F P
s
P
p
.002 w
.46834 .57438 m .46872 .57265 L p
.45832 .5685 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56313 L p
1 g
F P
s
P
p
.002 w
.44755 .56933 m .44771 .56103 L p
.45078 .56313 L 1 g
F P
s
P
p
.45366 .56653 m .45078 .56313 L .45491 .56596 L 1 g
F
P
p
.44755 .56933 m .45078 .56313 L .45366 .56653 L 1 g
F
P
p
.002 w
.45078 .56313 m .45146 .56129 L p
.44472 .55544 L 1 g
F P
s
P
p
.002 w
.44774 .55954 m .44755 .56933 L p
.43989 .54887 L 1 g
F P
s
P
p
.44472 .55544 m .44301 .55395 L .44774 .55954 L 1 g
F
P
p
.44472 .55544 m .44774 .55954 L .45078 .56313 L 1 g
F
P
p
.002 w
.44755 .56933 m .41467 .56416 L p
.43989 .54887 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43853 .54702 L p
1 g
F P
s
P
p
.41467 .56416 m .43177 .53783 L .43853 .54702 L 1 g
F
P
p
.43933 .54921 m .43853 .54702 L .43989 .54887 L 1 g
F
P
p
.41467 .56416 m .43853 .54702 L .43933 .54921 L 1 g
F
P
p
.002 w
.43853 .54702 m .43925 .54566 L p
.43534 .53792 L 1 g
F P
s
P
p
.4147 .53142 m .43217 .52609 L .43277 .52834 L 1 g
F
P
p
.002 w
.43571 .5393 m .43212 .53796 L p
.43277 .52834 L 1 g
F P
s
P
p
.002 w
.43212 .53796 m .4147 .53142 L p
.43277 .52834 L 1 g
F P
s
P
p
.002 w
.43277 .52834 m .43346 .52734 L p
.43325 .52134 L 1 g
F P
s
P
p
.43534 .53792 m .43571 .5393 L .43853 .54702 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.45146 .56129 m .43853 .54702 L .44262 .55258 L 1 g
F
P
p
.43989 .54887 m .43853 .54702 L .44804 .54393 L 1 g
F
P
p
.002 w
.43177 .53783 m .43571 .5393 L p
.43853 .54702 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43207 .52936 L p
1 g
F P
s
P
p
.43925 .54566 m .43207 .52936 L .43485 .53695 L 1 g
F
P
p
.002 w
.43571 .5393 m .44804 .54393 L p
.43853 .54702 L 1 g
F P
s
P
p
.002 w
.43207 .52936 m .43146 .53025 L p
.43485 .53695 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.43277 .52834 m .45954 .51773 L .43571 .5393 L 1 g
F
P
p
.43217 .52609 m .43294 .52585 L .43277 .52834 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43408 .50917 L p
1 g
F P
s
P
p
.43346 .52734 m .43408 .50917 L .43325 .52134 L 1 g
F
P
p
.43294 .52585 m .45954 .51773 L .43277 .52834 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.4147 .53142 m .42902 .49744 L .43703 .50277 L p
1 g
F P
s
P
p
.002 w
.43408 .50917 m .43485 .50826 L p
.43829 .50023 L 1 g
F P
s
P
p
.002 w
.43703 .50277 m .42902 .49744 L p
.44004 .49668 L 1 g
F P
s
P
p
.43829 .50023 m .43941 .49761 L .43703 .50277 L 1 g
F
P
p
.43829 .50023 m .43703 .50277 L .43408 .50917 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44276 .49117 L p
1 g
F P
s
P
p
.002 w
.42902 .49744 m .45314 .47016 L p
.44276 .49117 L 1 g
F P
s
P
p
.43685 .4969 m .44276 .49117 L .44004 .49668 L 1 g
F
P
p
.42902 .49744 m .44276 .49117 L .43685 .4969 L 1 g
F
P
p
.002 w
.44276 .49117 m .44166 .49233 L p
.43829 .50023 L 1 g
F P
s
P
p
.43485 .50826 m .44276 .49117 L .43829 .50023 L 1 g
F
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44276 .49117 m .44339 .4905 L p
.44866 .48545 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.44004 .49668 m .44333 .49062 L .48106 .49383 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45772 .47667 L p
1 g
F P
s
P
p
.44339 .4905 m .45772 .47667 L .44866 .48545 L 1 g
F
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45772 .47667 m .45826 .47608 L p
.4673 .47212 L 1 g
F P
s
P
p
.47342 .46911 m .51021 .47519 L .4634 .47403 L 1 g
F
P
p
.4673 .47212 m .47139 .47032 L .4634 .47403 L 1 g
F
P
p
.4673 .47212 m .4634 .47403 L .45772 .47667 L 1 g
F
P
p
.002 w
.51021 .47519 m .48106 .49383 L .4634 .47403 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.44333 .49062 m .45772 .47667 L .48106 .49383 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47764 .46704 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.47342 .46911 m .47764 .46704 L .51021 .47519 L 1 g
F
P
p
.002 w
.47764 .46704 m .47786 .46667 L p
.48583 .46586 L 1 g
F P
s
P
p
.47764 .46704 m .5 .46382 L .51021 .47519 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52243 .46715 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54232 .47671 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.52726 .46953 m .54232 .47671 L .54835 .49908 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56607 .50936 L p
1 g
F P
s
P
p
.002 w
.57098 .49749 m .56742 .51221 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.56081 .49821 m .56509 .4979 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.56509 .4979 m .57098 .49749 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.56607 .50936 m .56515 .50826 L p
.56693 .51983 L 1 g
F P
s
P
p
.002 w
.56661 .51558 m .57098 .49749 L p
.56833 .52613 L 1 g
F P
s
P
p
.56833 .52613 m .56783 .53148 L .56764 .52894 L 1 g
F
P
p
.56833 .52613 m .56764 .52894 L .56661 .51558 L 1 g
F
P
p
.56654 .52734 m .56439 .53911 L .56463 .53842 L 1 g
F
P
p
.002 w
.57316 .53259 m .56089 .54935 L p
.5616 .54727 L 1 g
F P
s
P
p
.002 w
.56705 .53132 m .57231 .53242 L p
.5616 .54727 L 1 g
F P
s
P
p
.002 w
.57231 .53242 m .57316 .53259 L p
.5616 .54727 L 1 g
F P
s
P
p
.002 w
.5616 .54727 m .56075 .54566 L p
.55418 .55757 L 1 g
F P
s
P
p
.002 w
.56764 .52894 m .56654 .52734 L p
.56463 .53842 L 1 g
F P
s
P
p
.002 w
.57316 .53259 m .58097 .53745 L .55883 .55529 L p
1 g
F P
s
P
p
.002 w
.55883 .55529 m .55327 .55978 L .56089 .54935 L p
1 g
F P
s
P
p
.002 w
.56089 .54935 m .57316 .53259 L p
.55883 .55529 L 1 g
F P
s
P
p
.56463 .53842 m .56456 .53878 L .56705 .53132 L 1 g
F
P
p
.56456 .53878 m .56304 .54761 L .5668 .53233 L 1 g
F
P
p
.56456 .53878 m .5668 .53233 L .56705 .53132 L 1 g
F
P
p
.56463 .53842 m .56705 .53132 L .56764 .52894 L 1 g
F
P
p
.002 w
.53696 .58388 m .53213 .58214 L p
.55086 .56232 L 1 g
F P
s
P
p
.002 w
.55209 .56152 m .53696 .58388 L p
.55086 .56232 L 1 g
F P
s
P
p
.002 w
.5493 .56334 m .54854 .56129 L p
.54009 .56934 L 1 g
F P
s
P
p
.002 w
.52786 .58059 m .52571 .5787 L p
.53174 .57477 L 1 g
F P
s
P
p
.002 w
.54737 .56461 m .53758 .57263 L p
.53174 .57477 L 1 g
F P
s
P
p
.002 w
.53758 .57263 m .52786 .58059 L p
.53174 .57477 L 1 g
F P
s
P
p
.002 w
.53174 .57477 m .53128 .57265 L p
.51974 .57857 L 1 g
F P
s
P
p
.002 w
.52786 .58059 m .50213 .59654 L p
.51756 .57908 L 1 g
F P
s
P
p
.002 w
.52435 .57749 m .52786 .58059 L p
.51756 .57908 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48909 .58537 m .50278 .58089 L p
.51049 .58064 L 1 g
F P
s
P
p
.002 w
.50213 .59654 m .48943 .58566 L p
.51756 .57908 L 1 g
F P
s
P
p
.002 w
.51094 .58063 m .51079 .57862 L p
.49936 .58091 L 1 g
F P
s
P
p
.002 w
.50278 .58089 m .48909 .58537 L p
.49618 .58092 L 1 g
F P
s
P
p
.49936 .58091 m .4988 .58102 L .50278 .58089 L 1 g
F
P
p
.49936 .58091 m .50278 .58089 L .51094 .58063 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48904 .58096 L p
1 g
F P
s
P
p
.002 w
.48909 .58537 m .48715 .58097 L p
.48904 .58096 L 1 g
F P
s
P
p
.49431 .58209 m .48904 .58096 L .49618 .58092 L 1 g
F
P
p
.48909 .58537 m .48904 .58096 L .49431 .58209 L 1 g
F
P
p
.48921 .57862 m .47856 .57775 L .48694 .58051 L 1 g
F
P
p
.002 w
.48904 .58096 m .48921 .57862 L p
.48694 .58051 L 1 g
F P
s
P
p
.51079 .57862 m .48904 .58096 L .49936 .58091 L 1 g
F
P
p
.48904 .58096 m .48245 .57035 L .49618 .58092 L 1 g
F
P
p
.002 w
.48715 .58097 m .48694 .58051 L p
.48904 .58096 L 1 g
F P
s
P
p
.002 w
.48694 .58051 m .48245 .57035 L p
.48904 .58096 L 1 g
F P
s
P
p
.48694 .58051 m .4678 .57686 L .48902 .58119 L 1 g
F
P
p
.47856 .57775 m .47134 .57715 L .48694 .58051 L 1 g
F
P
p
.47134 .57715 m .4678 .57686 L .48694 .58051 L 1 g
F
P
p
.002 w
.48902 .58119 m .48904 .58096 L p
.48694 .58051 L 1 g
F P
s
P
p
.002 w
.48904 .58096 m .48889 .583 L p
.49936 .58091 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48245 .57035 m .51812 .56714 L p
.49618 .58092 L 1 g
F P
s
P
p
.002 w
.51812 .56714 m .52133 .57482 L .50278 .58089 L p
1 g
F P
s
P
p
.49618 .58092 m .51812 .56714 L .50278 .58089 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51107 .58238 L p
1 g
F P
s
P
p
.53128 .57265 m .51107 .58238 L .51549 .58075 L 1 g
F
P
p
.54009 .56934 m .54737 .56461 L .5493 .56334 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.53174 .57477 m .52133 .57482 L .54737 .56461 L 1 g
F
P
p
.002 w
.52571 .5787 m .52435 .57749 L p
.53174 .57477 L 1 g
F P
s
P
p
.51974 .57857 m .52435 .57749 L .53174 .57477 L 1 g
F
P
p
.002 w
.52435 .57749 m .52133 .57482 L p
.53174 .57477 L 1 g
F P
s
P
p
.002 w
.51107 .58238 m .51111 .583 L p
.51549 .58075 L 1 g
F P
s
P
p
.002 w
.48943 .58566 m .48909 .58537 L p
.51756 .57908 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58063 L p
1 g
F P
s
P
p
.4988 .58102 m .48889 .583 L .51094 .58063 L 1 g
F
P
p
.51756 .57908 m .51049 .58064 L .52133 .57482 L 1 g
F
P
p
.002 w
.50278 .58089 m .52133 .57482 L p
.51049 .58064 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53195 .57572 L p
1 g
F P
s
P
p
.002 w
.53195 .57572 m .53174 .57477 L p
.52574 .57717 L 1 g
F P
s
P
p
.52574 .57717 m .51111 .583 L .53195 .57572 L 1 g
F
P
p
.51974 .57857 m .51549 .58075 L .52435 .57749 L 1 g
F
P
p
.002 w
.52133 .57482 m .52435 .57749 L p
.51756 .57908 L 1 g
F P
s
P
p
.51549 .58075 m .51111 .583 L .53174 .57477 L 1 g
F
P
p
.54009 .56934 m .53999 .56944 L .54737 .56461 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5493 .56334 L p
1 g
F P
s
P
p
.002 w
.55201 .56037 m .55327 .55978 L .55046 .56207 L p
1 g
F P
s
P
p
.002 w
.55046 .56207 m .55327 .55978 L p
.53213 .58214 L 1 g
F P
s
P
p
.55125 .56121 m .55046 .56207 L .54955 .564 L 1 g
F
P
p
.002 w
.5493 .56334 m .54931 .56335 L p
.55046 .56207 L 1 g
F P
s
P
p
.002 w
.54931 .56335 m .54955 .564 L p
.55046 .56207 L 1 g
F P
s
P
p
.56075 .54566 m .5493 .56334 L .55125 .56121 L 1 g
F
P
p
.56075 .54566 m .55123 .56124 L .55418 .55757 L 1 g
F
P
p
.002 w
.55237 .55996 m .55327 .55978 L .55201 .56037 L p
1 g
F P
s
P
p
.55123 .56124 m .55237 .55996 L .55418 .55757 L 1 g
F
P
p
.002 w
.55255 .55975 m .55327 .55978 L .55237 .55996 L p
1 g
F P
s
P
p
.55237 .55996 m .55247 .55985 L .55249 .55982 L 1 g
F
P
p
.55237 .55996 m .55249 .55982 L .55418 .55757 L 1 g
F
P
p
.55247 .55985 m .55271 .55956 L .55418 .55757 L 1 g
F
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.51812 .56714 m .51863 .55836 L .55255 .55975 L p
1 g
F P
s
P
p
.002 w
.55237 .55996 m .51812 .56714 L p
.55255 .55975 L 1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.51863 .55836 m .52285 .54945 L .55269 .55958 L p
1 g
F P
s
P
p
.002 w
.55269 .55958 m .55327 .55978 L .55255 .55975 L p
1 g
F P
s
P
p
.002 w
.55255 .55975 m .51863 .55836 L p
.55269 .55958 L 1 g
F P
s
P
p
.55247 .55985 m .55263 .55967 L .55271 .55956 L 1 g
F
P
p
.002 w
.55282 .55942 m .55327 .55978 L .55269 .55958 L p
1 g
F P
s
P
p
.55263 .55967 m .5527 .55959 L .55287 .55935 L 1 g
F
P
p
.55263 .55967 m .55287 .55935 L .55418 .55757 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.53035 .5414 m .54032 .53512 L .55297 .55922 L p
1 g
F P
s
P
p
.002 w
.55297 .55922 m .55327 .55978 L .55282 .55942 L p
1 g
F P
s
P
p
.002 w
.55282 .55942 m .53035 .5414 L p
.55297 .55922 L 1 g
F P
s
P
p
.5527 .55959 m .55316 .55897 L .55418 .55757 L 1 g
F
P
p
.002 w
.54032 .53512 m .55163 .53134 L .55322 .5589 L p
1 g
F P
s
P
p
.002 w
.55322 .5589 m .55327 .55978 L .55297 .55922 L p
1 g
F P
s
P
p
.002 w
.55297 .55922 m .54032 .53512 L p
.55322 .5589 L 1 g
F P
s
P
p
.5527 .55959 m .55276 .55952 L .55316 .55897 L 1 g
F
P
p
.55276 .55952 m .55283 .55944 L .55384 .55804 L 1 g
F
P
p
.55276 .55952 m .55384 .55804 L .55418 .55757 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55163 .53134 m .563 .53047 L .55384 .55804 L p
1 g
F P
s
P
p
.002 w
.55384 .55804 m .55327 .55978 L .55322 .5589 L p
1 g
F P
s
P
p
.002 w
.55322 .5589 m .55163 .53134 L p
.55384 .55804 L 1 g
F P
s
P
p
.002 w
.52285 .54945 m .53035 .5414 L .55282 .55942 L p
1 g
F P
s
P
p
.002 w
.55269 .55958 m .52285 .54945 L p
.55282 .55942 L 1 g
F P
s
P
p
.55256 .55975 m .54955 .564 L .55283 .55944 L 1 g
F
P
p
.55123 .56124 m .5508 .56194 L .55256 .55975 L 1 g
F
P
p
.5508 .56194 m .54955 .564 L .55256 .55975 L 1 g
F
P
p
.002 w
.52133 .57482 m .51812 .56714 L .55237 .55996 L p
1 g
F P
s
P
p
.002 w
.55201 .56037 m .52133 .57482 L p
.55237 .55996 L 1 g
F P
s
P
p
.002 w
.52133 .57482 m .55201 .56037 L p
.54737 .56461 L 1 g
F P
s
P
p
.002 w
.55046 .56207 m .54737 .56461 L p
.55201 .56037 L 1 g
F P
s
P
p
.002 w
.53213 .58214 m .52786 .58059 L .55046 .56207 L p
1 g
F P
s
P
p
.002 w
.54766 .58435 m .53696 .58388 L .55209 .56152 L p
1 g
F P
s
P
p
.002 w
.55209 .56152 m .55327 .55978 L .55301 .5609 L p
1 g
F P
s
P
p
.002 w
.55301 .5609 m .54766 .58435 L p
.55209 .56152 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54931 .56337 L p
1 g
F P
s
P
p
.002 w
.54931 .56337 m .5493 .56334 L p
.549 .56358 L 1 g
F P
s
P
p
.549 .56358 m .5322 .57686 L .54931 .56337 L 1 g
F
P
p
.53999 .56944 m .5322 .57686 L .5493 .56334 L 1 g
F
P
p
.002 w
.55327 .55978 m .55209 .56152 L p
.55086 .56232 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55327 .55978 m .563 .53047 L .56705 .53132 L p
1 g
F P
s
P
p
.002 w
.54955 .564 m .54998 .56518 L p
.55418 .55757 L 1 g
F P
s
P
p
.002 w
.56089 .54935 m .55327 .55978 L p
.55465 .55692 L 1 g
F P
s
P
p
.56705 .53132 m .5616 .54727 L .55465 .55692 L 1 g
F
P
p
.5616 .54727 m .56089 .54935 L .55465 .55692 L 1 g
F
P
p
.002 w
.55883 .582 m .54766 .58435 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.56931 .57706 m .55883 .582 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.57801 .57005 m .56931 .57706 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.58401 .5617 m .57801 .57005 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.58666 .55286 m .58401 .5617 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.58563 .54447 m .58666 .55286 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.58097 .53745 m .58563 .54447 L .55327 .55978 L closepath p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5616 .54727 L p
1 g
F P
s
P
p
.55418 .55757 m .54998 .56518 L .5616 .54727 L 1 g
F
P
p
.002 w
.56257 .5491 m .56304 .54761 L p
.56463 .53842 L 1 g
F P
s
P
p
.56439 .53911 m .56257 .5491 L .56463 .53842 L 1 g
F
P
p
.002 w
.57316 .53259 m .56783 .53148 L p
.56833 .52613 L 1 g
F P
s
P
p
.57098 .49749 m .57187 .51176 L .56833 .52613 L 1 g
F
P
p
.57187 .51176 m .57316 .53259 L .56833 .52613 L 1 g
F
P
p
.002 w
.56854 .53025 m .56304 .54761 L p
.5644 .55256 L 1 g
F P
s
P
p
.002 w
.56304 .54761 m .56257 .5491 L .56264 .54923 L p
1 g
F P
s
P
p
.002 w
.56264 .54923 m .5644 .55256 L p
.56304 .54761 L 1 g
F P
s
P
p
.56693 .51983 m .56661 .51558 L .56607 .50936 L 1 g
F
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56777 .52913 L p
1 g
F P
s
P
p
.56515 .50826 m .56777 .52913 L .56702 .52037 L 1 g
F
P
p
.55661 .4905 m .56607 .50936 L .56243 .50164 L 1 g
F
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55739 .49133 m .55661 .4905 L p
.56435 .5053 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.002 w
.56424 .49796 m .56081 .49821 L p
.55739 .49133 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55739 .49133 L p
1 g
F P
s
P
p
.56435 .5053 m .56713 .51061 L .55739 .49133 L 1 g
F
P
p
.54174 .47608 m .55739 .49133 L .55275 .48684 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56081 .49821 m .54835 .49908 L p
.54617 .48045 L 1 g
F P
s
P
p
.54174 .47608 m .55275 .48684 L .54982 .484 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55739 .49133 m .56081 .49821 L .54617 .48045 L 1 g
F
P
p
.002 w
.54835 .49908 m .54571 .48001 L p
.54617 .48045 L 1 g
F P
s
P
p
.002 w
.54571 .48001 m .54835 .49908 L p
.54232 .47671 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .5424 .4768 L p
1 g
F P
s
P
p
.54174 .47608 m .54982 .484 L .54571 .48001 L 1 g
F
P
p
.002 w
.54232 .47671 m .54174 .47608 L p
.54571 .48001 L 1 g
F P
s
P
p
.002 w
.54351 .46414 m .54546 .47821 L p
.54232 .47671 L 1 g
F P
s
P
p
.52214 .46667 m .54232 .47671 L .53249 .47203 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.51021 .47519 m .52726 .46953 L p
.54835 .49908 L 1 g
F P
s
P
p
.002 w
.51021 .47519 m .50512 .46469 L p
.52243 .46715 L 1 g
F P
s
P
p
.002 w
.52243 .46715 m .52214 .46667 L p
.53641 .47406 L 1 g
F P
s
P
p
.002 w
.53084 .46835 m .52726 .46953 L p
.52243 .46715 L 1 g
F P
s
P
p
.002 w
.52726 .46953 m .51021 .47519 L p
.52243 .46715 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52243 .46715 L p
1 g
F P
s
P
p
.53641 .47406 m .54302 .47747 L .52243 .46715 L 1 g
F
P
p
.002 w
.52726 .46953 m .53298 .46763 L p
.54232 .47671 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53298 .46763 m .54351 .46414 L p
.54232 .47671 L 1 g
F P
s
P
p
.002 w
.5424 .4768 m .54232 .47671 L p
.54571 .48001 L 1 g
F P
s
P
p
.54982 .484 m .55834 .49233 L .5424 .4768 L 1 g
F
P
p
.54351 .46414 m .54437 .46519 L .54617 .48045 L 1 g
F
P
p
.002 w
.54571 .48001 m .54351 .46414 L p
.54617 .48045 L 1 g
F P
s
P
p
.54437 .46519 m .55739 .49133 L .54617 .48045 L 1 g
F
P
p
.54982 .484 m .5578 .49177 L .55164 .48577 L 1 g
F
P
p
.55275 .48684 m .5578 .49177 L .54982 .484 L 1 g
F
P
p
.002 w
.55739 .49133 m .5578 .49177 L p
.55275 .48684 L 1 g
F P
s
P
p
.002 w
.57098 .49749 m .56424 .49796 L p
.54437 .46519 L 1 g
F P
s
P
p
.54437 .46519 m .56424 .49796 L .55739 .49133 L 1 g
F
P
p
.56081 .49821 m .56607 .50936 L .563 .53047 L 1 g
F
P
p
.002 w
.56742 .51221 m .56661 .51558 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.56661 .51558 m .563 .53047 L p
.56607 .50936 L 1 g
F P
s
P
p
.002 w
.56777 .52913 m .56854 .53025 L p
.56702 .52037 L 1 g
F P
s
P
p
.002 w
.56783 .53148 m .563 .53047 L .56661 .51558 L p
1 g
F P
s
P
p
.002 w
.56304 .54761 m .56854 .53025 L .56764 .52894 L p
1 g
F P
s
P
p
.56693 .51983 m .56702 .52037 L .56661 .51558 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56607 .50936 L p
1 g
F P
s
P
p
.56702 .52037 m .56854 .53025 L .56607 .50936 L 1 g
F
P
p
.002 w
.56607 .50936 m .56713 .51061 L p
.56243 .50164 L 1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.54835 .49908 m .56081 .49821 L p
.563 .53047 L 1 g
F P
s
P
p
.002 w
.54546 .47821 m .54571 .48001 L p
.54232 .47671 L 1 g
F P
s
P
p
.002 w
.5578 .49177 m .55834 .49233 L p
.55164 .48577 L 1 g
F P
s
P
p
.002 w
.54232 .47671 m .54302 .47747 L p
.53249 .47203 L 1 g
F P
s
P
p
.002 w
.52243 .46715 m .52274 .46765 L p
.51244 .46573 L 1 g
F P
s
P
p
.5 .4634 m .52243 .46715 L .51244 .46573 L 1 g
F
P
p
.002 w
.54351 .46414 m .53084 .46835 L p
.49415 .44206 L 1 g
F P
s
P
p
.5 .4634 m .52274 .46765 L .51786 .46683 L 1 g
F
P
p
.002 w
.50512 .46469 m .51021 .47519 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .4634 L p
.51786 .46683 L 1 g
F P
s
P
p
.51786 .46683 m .52282 .46778 L .5 .46382 L 1 g
F
P
p
.002 w
.50076 .45568 m .5044 .46319 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46382 L p
1 g
F P
s
P
p
.002 w
.5 .46382 m .5 .46442 L p
.48583 .46586 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46382 L .48583 .46586 L 1 g
F
P
p
.47764 .46704 m .48822 .46184 L .5 .46382 L 1 g
F
P
p
.48822 .46184 m .50076 .45568 L .5 .46382 L 1 g
F
P
p
.002 w
.50512 .46469 m .49415 .44206 L p
.53084 .46835 L 1 g
F P
s
P
p
.002 w
.5044 .46319 m .50512 .46469 L p
.5 .46382 L 1 g
F P
s
P
p
.002 w
.52274 .46765 m .52282 .46778 L p
.51786 .46683 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47764 .46704 L p
1 g
F P
s
P
p
.48583 .46586 m .5 .46442 L .47764 .46704 L 1 g
F
P
p
.002 w
.47764 .46704 m .47731 .46757 L p
.46891 .47132 L 1 g
F P
s
P
p
.45826 .47608 m .47764 .46704 L .46891 .47132 L 1 g
F
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.45653 .46632 m .49415 .44206 L .50076 .45568 L p
1 g
F P
s
P
p
.45653 .46632 m .50076 .45568 L .47342 .46911 L 1 g
F
P
p
.45826 .47608 m .47731 .46757 L .47139 .47032 L 1 g
F
P
p
.002 w
.46203 .47249 m .4634 .47403 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.4634 .47403 m .48106 .49383 L p
.45772 .47667 L 1 g
F P
s
P
p
.002 w
.47731 .46757 m .47718 .46778 L p
.47139 .47032 L 1 g
F P
s
P
p
.002 w
.4634 .47403 m .45653 .46632 L p
.47342 .46911 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45772 .47667 L p
1 g
F P
s
P
p
.47139 .47032 m .47718 .46778 L .45772 .47667 L 1 g
F
P
p
.002 w
.45653 .46632 m .46203 .47249 L p
.45772 .47667 L 1 g
F P
s
P
p
.44333 .49062 m .44861 .4809 L .45772 .47667 L 1 g
F
P
p
.44861 .4809 m .45653 .46632 L .45772 .47667 L 1 g
F
P
p
.002 w
.45772 .47667 m .45698 .47747 L p
.44866 .48545 L 1 g
F P
s
P
p
.002 w
.45314 .47016 m .45653 .46632 L p
.44004 .49668 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44276 .49117 L p
1 g
F P
s
P
p
.44866 .48545 m .45698 .47747 L .44276 .49117 L 1 g
F
P
p
.002 w
.48106 .49383 m .45954 .51773 L .43703 .50277 L p
1 g
F P
s
P
p
.44004 .49668 m .48106 .49383 L .43703 .50277 L 1 g
F
P
p
.002 w
.43703 .50277 m .45954 .51773 L p
.42533 .52817 L 1 g
F P
s
P
p
.4147 .53142 m .43703 .50277 L .42533 .52817 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43408 .50917 L p
1 g
F P
s
P
p
.43941 .49761 m .44166 .49233 L .43408 .50917 L 1 g
F
P
p
.002 w
.43408 .50917 m .43287 .51061 L p
.43325 .52134 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43277 .52834 L p
1 g
F P
s
P
p
.43325 .52134 m .43287 .51061 L .43277 .52834 L 1 g
F
P
p
.43534 .53792 m .43485 .53695 L .43571 .5393 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45954 .51773 m .44804 .54393 L .43571 .5393 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43853 .54702 L p
1 g
F P
s
P
p
.43485 .53695 m .43146 .53025 L .43853 .54702 L 1 g
F
P
p
.002 w
.43853 .54702 m .438 .54802 L p
.44262 .55258 L 1 g
F P
s
P
p
.002 w
.41467 .56416 m .4147 .53142 L .43177 .53783 L p
1 g
F P
s
P
p
.45146 .56129 m .438 .54802 L .44301 .55395 L 1 g
F
P
p
.46872 .57265 m .45078 .56313 L .45903 .56878 L 1 g
F
P
p
.45078 .56313 m .44804 .54393 L .45491 .56596 L 1 g
F
P
p
.002 w
.44771 .56103 m .44774 .55954 L p
.45078 .56313 L 1 g
F P
s
P
p
.002 w
.44774 .55954 m .44804 .54393 L p
.45078 .56313 L 1 g
F P
s
P
p
.002 w
.438 .54802 m .43743 .5491 L p
.44301 .55395 L 1 g
F P
s
P
p
.002 w
.44804 .54393 m .44774 .55954 L p
.43989 .54887 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56313 L p
1 g
F P
s
P
p
.44301 .55395 m .43743 .5491 L .45078 .56313 L 1 g
F
P
p
.002 w
.45078 .56313 m .45002 .56518 L p
.45903 .56878 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44804 .54393 m .48312 .55303 L p
.45491 .56596 L 1 g
F P
s
P
p
.002 w
.48312 .55303 m .48245 .57035 L .46038 .56971 L p
1 g
F P
s
P
p
.45491 .56596 m .48312 .55303 L .46038 .56971 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46819 .57506 L p
1 g
F P
s
P
p
.002 w
.46819 .57506 m .46834 .57438 L p
.46409 .57224 L 1 g
F P
s
P
p
.46409 .57224 m .45002 .56518 L .46819 .57506 L 1 g
F
P
p
.45832 .5685 m .45002 .56518 L .46834 .57438 L 1 g
F
P
p
.47504 .57658 m .46834 .57438 L .48245 .57035 L 1 g
F
P
p
.002 w
.46038 .56971 m .48245 .57035 L p
.46834 .57438 L 1 g
F P
s
P
p
.002 w
.46834 .57438 m .4678 .57686 L p
.47856 .57775 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58119 L p
1 g
F P
s
P
p
.002 w
.48245 .57035 m .48694 .58051 L p
.47504 .57658 L 1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.39454 .38157 m .35539 .42821 L .33957 .40526 L p
1 g
F P
s
P
p
.002 w
.33957 .40526 m .38023 .35615 L .39454 .38157 L p
1 g
F P
s
P
p
.002 w
.43742 .31815 m .38023 .35615 L .3699 .33367 L p
1 g
F P
s
P
p
.002 w
.3699 .33367 m .42771 .29506 L .43742 .31815 L p
1 g
F P
s
P
p
.002 w
.58401 .5617 m .58666 .55286 L .61693 .5424 L p
1 g
F P
s
P
p
.002 w
.6152 .52583 m .61693 .5424 L .58666 .55286 L p
1 g
F P
s
P
p
.002 w
.61693 .5424 m .6152 .52583 L .64097 .50456 L p
1 g
F P
s
P
p
.002 w
.57598 .3224 m .63095 .33796 L .63067 .36807 L p
1 g
F P
s
P
p
.002 w
.63095 .33796 m .57598 .3224 L .56988 .29456 L p
1 g
F P
s
P
p
.002 w
.62639 .4007 m .65966 .42465 L .64633 .45434 L p
1 g
F P
s
P
p
.002 w
.65966 .42465 m .62639 .4007 L .63067 .36807 L p
1 g
F P
s
P
p
.002 w
.62836 .48374 m .64097 .50456 L .6152 .52583 L p
1 g
F P
s
P
p
.002 w
.64097 .50456 m .62836 .48374 L .64633 .45434 L p
1 g
F P
s
P
p
.002 w
.40084 .47517 m .3843 .51599 L .35787 .49825 L p
1 g
F P
s
P
p
.002 w
.35787 .49825 m .37601 .4518 L .40084 .47517 L p
1 g
F P
s
P
p
.002 w
.56988 .29456 m .50366 .29669 L .49477 .27341 L p
1 g
F P
s
P
p
.002 w
.42771 .29506 m .49477 .27341 L .50366 .29669 L p
1 g
F P
s
P
p
.002 w
.50366 .29669 m .43742 .31815 L .42771 .29506 L p
1 g
F P
s
P
p
.002 w
.50366 .29669 m .56988 .29456 L .57598 .3224 L p
1 g
F P
s
P
p
.002 w
.58666 .55286 m .58563 .54447 L .6152 .52583 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.60631 .5118 m .6152 .52583 L .58563 .54447 L p
1 g
F P
s
P
p
.002 w
.6152 .52583 m .60631 .5118 L .62836 .48374 L p
1 g
F P
s
P
p
.002 w
.61816 .43473 m .64633 .45434 L .62836 .48374 L p
1 g
F P
s
P
p
.002 w
.64633 .45434 m .61816 .43473 L .62639 .4007 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.57989 .35424 m .63067 .36807 L .62639 .4007 L p
1 g
F P
s
P
p
.002 w
.63067 .36807 m .57989 .35424 L .57598 .3224 L p
1 g
F P
s
P
p
.002 w
.41244 .40908 m .37601 .4518 L .35539 .42821 L p
1 g
F P
s
P
p
.002 w
.35539 .42821 m .39454 .38157 L .41244 .40908 L p
1 g
F P
s
P
p
.002 w
.42902 .49744 m .4147 .53142 L .3843 .51599 L p
1 g
F P
s
P
p
.002 w
.3843 .51599 m .40084 .47517 L .42902 .49744 L p
1 g
F P
s
P
p
.002 w
.58563 .54447 m .58097 .53745 L .60631 .5118 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.44935 .34538 m .39454 .38157 L .38023 .35615 L p
1 g
F P
s
P
p
.002 w
.38023 .35615 m .43742 .31815 L .44935 .34538 L p
1 g
F P
s
P
p
.002 w
.51863 .55836 m .51812 .56714 L .48245 .57035 L p
1 g
F P
s
P
p
.002 w
.48245 .57035 m .48312 .55303 L .51863 .55836 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.60624 .46891 m .62836 .48374 L .60631 .5118 L p
1 g
F P
s
P
p
.002 w
.62836 .48374 m .60624 .46891 L .61816 .43473 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.58097 .53745 m .57316 .53259 L .59105 .50194 L p
1 g
F P
s
P
p
.002 w
.59105 .50194 m .60631 .5118 L .58097 .53745 L p
1 g
F P
s
P
p
.002 w
.57598 .3224 m .51269 .32478 L .50366 .29669 L p
1 g
F P
s
P
p
.002 w
.43742 .31815 m .50366 .29669 L .51269 .32478 L p
1 g
F P
s
P
p
.002 w
.60631 .5118 m .59105 .50194 L .60624 .46891 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.51269 .32478 m .57598 .3224 L .57989 .35424 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.58139 .38899 m .62639 .4007 L .61816 .43473 L p
1 g
F P
s
P
p
.002 w
.62639 .4007 m .58139 .38899 L .57989 .35424 L p
1 g
F P
s
P
p
.002 w
.52285 .54945 m .51863 .55836 L .48312 .55303 L p
1 g
F P
s
P
p
.002 w
.51269 .32478 m .44935 .34538 L .43742 .31815 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43336 .4377 m .40084 .47517 L .37601 .4518 L p
1 g
F P
s
P
p
.002 w
.37601 .4518 m .41244 .40908 L .43336 .4377 L p
1 g
F P
s
P
p
.002 w
.57098 .49749 m .59105 .50194 L .57316 .53259 L p
1 g
F P
s
P
p
.002 w
.49122 .53529 m .48312 .55303 L .44804 .54393 L p
1 g
F P
s
P
p
.002 w
.44804 .54393 m .45954 .51773 L .49122 .53529 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.48312 .55303 m .49122 .53529 L .52285 .54945 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.53035 .5414 m .52285 .54945 L .49122 .53529 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58037 .42538 m .61816 .43473 L .60624 .46891 L p
1 g
F P
s
P
p
.002 w
.61816 .43473 m .58037 .42538 L .58139 .38899 L p
1 g
F P
s
P
p
.002 w
.563 .53047 m .55163 .53134 L .54835 .49908 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.46312 .37587 m .41244 .40908 L .39454 .38157 L p
1 g
F P
s
P
p
.002 w
.39454 .38157 m .44935 .34538 L .46312 .37587 L p
1 g
F P
s
P
p
.002 w
.59105 .50194 m .57098 .49749 L .57686 .46202 L p
1 g
F P
s
P
p
.002 w
.57686 .46202 m .60624 .46891 L .59105 .50194 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.54032 .53512 m .53035 .5414 L .50599 .51917 L p
1 g
F P
s
P
p
.002 w
.49122 .53529 m .50599 .51917 L .53035 .5414 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.55163 .53134 m .54032 .53512 L .5258 .5066 L p
1 g
F P
s
P
p
.002 w
.5258 .5066 m .54835 .49908 L .55163 .53134 L p
1 g
F P
s
P
p
.002 w
.60624 .46891 m .57686 .46202 L .58037 .42538 L p
1 g
F P
s
P
p
.002 w
.50599 .51917 m .5258 .5066 L .54032 .53512 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.52154 .35678 m .57989 .35424 L .58139 .38899 L p
1 g
F P
s
P
p
.002 w
.57989 .35424 m .52154 .35678 L .51269 .32478 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.45653 .46632 m .42902 .49744 L .40084 .47517 L p
1 g
F P
s
P
p
.002 w
.40084 .47517 m .43336 .4377 L .45653 .46632 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.44935 .34538 m .51269 .32478 L .52154 .35678 L p
1 g
F P
s
P
p
.002 w
.50599 .51917 m .49122 .53529 L .45954 .51773 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.52154 .35678 m .46312 .37587 L .44935 .34538 L p
1 g
F P
s
P
p
.002 w
.54351 .46414 m .57686 .46202 L .57098 .49749 L p
1 g
F P
s
P
p
.002 w
.45954 .51773 m .48106 .49383 L .50599 .51917 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.52983 .39157 m .58139 .38899 L .58037 .42538 L p
1 g
F P
s
P
p
.002 w
.58139 .38899 m .52983 .39157 L .52154 .35678 L p
1 g
F P
s
P
p
.002 w
.47825 .40852 m .43336 .4377 L .41244 .40908 L p
1 g
F P
s
P
p
.002 w
.41244 .40908 m .46312 .37587 L .47825 .40852 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.5258 .5066 m .50599 .51917 L .48106 .49383 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.54835 .49908 m .5258 .5066 L .51021 .47519 L p
1 g
F P
s
P
p
.002 w
.57686 .46202 m .54351 .46414 L .53726 .42783 L p
1 g
F P
s
P
p
.002 w
.53726 .42783 m .58037 .42538 L .57686 .46202 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.58037 .42538 m .53726 .42783 L .52983 .39157 L p
1 g
F P
s
P
p
.002 w
.48106 .49383 m .51021 .47519 L .5258 .5066 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.46312 .37587 m .52154 .35678 L .52983 .39157 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49415 .44206 m .45653 .46632 L .43336 .4377 L p
1 g
F P
s
P
p
.002 w
.43336 .4377 m .47825 .40852 L .49415 .44206 L p
1 g
F P
s
P
p
.002 w
.52983 .39157 m .47825 .40852 L .46312 .37587 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.49415 .44206 m .53726 .42783 L .54351 .46414 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.47825 .40852 m .52983 .39157 L .53726 .42783 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.004 w
.57127 .60346 m
.57514 .61285 L
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53726 .42783 m .49415 .44206 L .47825 .40852 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .77342 .40836 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58464 .63592 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.64031)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.64031)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45074 .4706 m .49823 .47034 L .49463 .44219 L p
1 g
F P
s
P
p
.002 w
.49463 .44219 m .45302 .4423 L .45074 .4706 L p
1 g
F P
s
P
p
.002 w
.53527 .4322 m .49463 .44219 L .49823 .47034 L p
1 g
F P
s
P
p
.002 w
.45302 .4423 m .49463 .44219 L .49117 .41383 L p
1 g
F P
s
P
p
.002 w
.49463 .44219 m .53527 .4322 L .52509 .40544 L p
1 g
F P
s
P
p
.002 w
.52509 .40544 m .49117 .41383 L .49463 .44219 L p
1 g
F P
s
P
p
.002 w
.49117 .41383 m .45643 .41382 L .45302 .4423 L p
1 g
F P
s
P
p
.002 w
.45643 .41382 m .49117 .41383 L .48791 .38576 L p
1 g
F P
s
P
p
.002 w
.49117 .41383 m .52509 .40544 L .51427 .3792 L p
1 g
F P
s
P
p
.002 w
.51427 .3792 m .48791 .38576 L .49117 .41383 L p
1 g
F P
s
P
p
.002 w
.49823 .47034 m .54462 .459 L .53527 .4322 L p
1 g
F P
s
P
p
.002 w
.57126 .41317 m .53527 .4322 L .54462 .459 L p
1 g
F P
s
P
p
.002 w
.53527 .4322 m .57126 .41317 L .55503 .38938 L p
1 g
F P
s
P
p
.002 w
.55503 .38938 m .52509 .40544 L .53527 .4322 L p
1 g
F P
s
P
p
.002 w
.52509 .40544 m .55503 .38938 L .53745 .3666 L p
1 g
F P
s
P
p
.002 w
.53745 .3666 m .51427 .3792 L .52509 .40544 L p
1 g
F P
s
P
p
.002 w
.44964 .4982 m .5019 .49776 L .49823 .47034 L p
1 g
F P
s
P
p
.002 w
.49823 .47034 m .45074 .4706 L .44964 .4982 L p
1 g
F P
s
P
p
.002 w
.54462 .459 m .49823 .47034 L .5019 .49776 L p
1 g
F P
s
P
p
.002 w
.48791 .38576 m .46091 .38567 L .45643 .41382 L p
1 g
F P
s
P
p
.002 w
.46091 .38567 m .48791 .38576 L .48491 .3585 L p
1 g
F P
s
P
p
.002 w
.48791 .38576 m .51427 .3792 L .50301 .35397 L p
1 g
F P
s
P
p
.002 w
.50301 .35397 m .48491 .3585 L .48791 .38576 L p
1 g
F P
s
P
p
.002 w
.41421 .43239 m .45302 .4423 L .45643 .41382 L p
1 g
F P
s
P
p
.002 w
.45643 .41382 m .42413 .40532 L .41421 .43239 L p
1 g
F P
s
P
p
.002 w
.42413 .40532 m .45643 .41382 L .46091 .38567 L p
1 g
F P
s
P
p
.002 w
.40634 .45961 m .45074 .4706 L .45302 .4423 L p
1 g
F P
s
P
p
.002 w
.45302 .4423 m .41421 .43239 L .40634 .45961 L p
1 g
F P
s
P
p
.002 w
.5019 .49776 m .55297 .48536 L .54462 .459 L p
1 g
F P
s
P
p
.002 w
.58584 .43751 m .54462 .459 L .55297 .48536 L p
1 g
F P
s
P
p
.002 w
.54462 .459 m .58584 .43751 L .57126 .41317 L p
1 g
F P
s
P
p
.002 w
.51427 .3792 m .53745 .3666 L .51885 .34524 L p
1 g
F P
s
P
p
.002 w
.51885 .34524 m .50301 .35397 L .51427 .3792 L p
1 g
F P
s
P
p
.002 w
.46091 .38567 m .43589 .37889 L .42413 .40532 L p
1 g
F P
s
P
p
.002 w
.43589 .37889 m .46091 .38567 L .46638 .35838 L p
1 g
F P
s
P
p
.002 w
.48491 .3585 m .46638 .35838 L .46091 .38567 L p
1 g
F P
s
P
p
.002 w
.40068 .48645 m .44964 .4982 L .45074 .4706 L p
1 g
F P
s
P
p
.002 w
.45074 .4706 m .40634 .45961 L .40068 .48645 L p
1 g
F P
s
P
p
.002 w
.44976 .52456 m .50558 .52394 L .5019 .49776 L p
1 g
F P
s
P
p
.002 w
.5019 .49776 m .44964 .4982 L .44976 .52456 L p
1 g
F P
s
P
p
.002 w
.55297 .48536 m .5019 .49776 L .50558 .52394 L p
1 g
F P
s
P
p
.002 w
.57804 .36705 m .55503 .38938 L .57126 .41317 L p
1 g
F P
s
P
p
.002 w
.55503 .38938 m .57804 .36705 L .55511 .3491 L p
1 g
F P
s
P
p
.002 w
.55511 .3491 m .53745 .3666 L .55503 .38938 L p
1 g
F P
s
P
p
.002 w
.59915 .38664 m .57126 .41317 L .58584 .43751 L p
1 g
F P
s
P
p
.002 w
.57126 .41317 m .59915 .38664 L .57804 .36705 L p
1 g
F P
s
P
p
.002 w
.46638 .35838 m .48491 .3585 L .48224 .33256 L p
1 g
F P
s
P
p
.002 w
.48491 .3585 m .50301 .35397 L .49149 .33023 L p
1 g
F P
s
P
p
.002 w
.49149 .33023 m .48224 .33256 L .48491 .3585 L p
1 g
F P
s
P
p
.002 w
.53745 .3666 m .55511 .3491 L .5308 .33315 L p
1 g
F P
s
P
p
.002 w
.5308 .33315 m .51885 .34524 L .53745 .3666 L p
1 g
F P
s
P
p
.002 w
.50558 .52394 m .56015 .51077 L .55297 .48536 L p
1 g
F P
s
P
p
.002 w
.59847 .46196 m .55297 .48536 L .56015 .51077 L p
1 g
F P
s
P
p
.002 w
.55297 .48536 m .59847 .46196 L .58584 .43751 L p
1 g
F P
s
P
p
.002 w
.50301 .35397 m .51885 .34524 L .49956 .32573 L p
1 g
F P
s
P
p
.002 w
.49956 .32573 m .49149 .33023 L .50301 .35397 L p
1 g
F P
s
P
p
.002 w
.46638 .35838 m .44928 .35362 L .43589 .37889 L p
1 g
F P
s
P
p
.002 w
.44928 .35362 m .46638 .35838 L .47276 .33248 L p
1 g
F P
s
P
p
.002 w
.48224 .33256 m .47276 .33248 L .46638 .35838 L p
1 g
F P
s
P
p
.002 w
.38194 .4131 m .41421 .43239 L .42413 .40532 L p
1 g
F P
s
P
p
.002 w
.42413 .40532 m .39744 .38894 L .38194 .4131 L p
1 g
F P
s
P
p
.002 w
.39744 .38894 m .42413 .40532 L .43589 .37889 L p
1 g
F P
s
P
p
.002 w
.43589 .37889 m .41537 .36596 L .39744 .38894 L p
1 g
F P
s
P
p
.002 w
.41537 .36596 m .43589 .37889 L .44928 .35362 L p
1 g
F P
s
P
p
.002 w
.39741 .51236 m .44976 .52456 L .44964 .4982 L p
1 g
F P
s
P
p
.002 w
.44964 .4982 m .40068 .48645 L .39741 .51236 L p
1 g
F P
s
P
p
.002 w
.36921 .43798 m .40634 .45961 L .41421 .43239 L p
1 g
F P
s
P
p
.002 w
.41421 .43239 m .38194 .4131 L .36921 .43798 L p
1 g
F P
s
P
p
.002 w
.61801 .40752 m .58584 .43751 L .59847 .46196 L p
1 g
F P
s
P
p
.002 w
.58584 .43751 m .61801 .40752 L .59915 .38664 L p
1 g
F P
s
P
p
.002 w
.51885 .34524 m .5308 .33315 L .50559 .31951 L p
1 g
F P
s
P
p
.002 w
.50559 .31951 m .49956 .32573 L .51885 .34524 L p
1 g
F P
s
P
p
.002 w
.44928 .35362 m .43536 .34462 L .41537 .36596 L p
1 g
F P
s
P
p
.002 w
.43536 .34462 m .44928 .35362 L .46405 .32998 L p
1 g
F P
s
P
p
.002 w
.47276 .33248 m .46405 .32998 L .44928 .35362 L p
1 g
F P
s
P
p
.002 w
.45114 .54915 m .5092 .54835 L .50558 .52394 L p
1 g
F P
s
P
p
.002 w
.50558 .52394 m .44976 .52456 L .45114 .54915 L p
1 g
F P
s
P
p
.002 w
.56015 .51077 m .50558 .52394 L .5092 .54835 L p
1 g
F P
s
P
p
.002 w
.35958 .46309 m .40068 .48645 L .40634 .45961 L p
1 g
F P
s
P
p
.002 w
.40634 .45961 m .36921 .43798 L .35958 .46309 L p
1 g
F P
s
P
p
.002 w
.56532 .32835 m .55511 .3491 L .57804 .36705 L p
1 g
F P
s
P
p
.002 w
.55511 .3491 m .56532 .32835 L .53756 .31889 L p
1 g
F P
s
P
p
.002 w
.53756 .31889 m .5308 .33315 L .55511 .3491 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .47276 .33248 L .48224 .33256 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .48224 .33256 L .49149 .33023 L closepath p
1 g
F P
s
P
p
.002 w
.5092 .54835 m .56598 .53472 L .56015 .51077 L p
1 g
F P
s
P
p
.002 w
.60887 .48604 m .56015 .51077 L .56598 .53472 L p
1 g
F P
s
P
p
.002 w
.56015 .51077 m .60887 .48604 L .59847 .46196 L p
1 g
F P
s
P
p
.002 w
.59163 .34041 m .57804 .36705 L .59915 .38664 L p
1 g
F P
s
P
p
.002 w
.57804 .36705 m .59163 .34041 L .56532 .32835 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .49149 .33023 L .49956 .32573 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .46405 .32998 L .47276 .33248 L closepath p
1 g
F P
s
P
p
.002 w
.5308 .33315 m .53756 .31889 L .50891 .31223 L p
1 g
F P
s
P
p
.002 w
.50891 .31223 m .50559 .31951 L .5308 .33315 L p
1 g
F P
s
P
p
.002 w
.6342 .4293 m .59847 .46196 L .60887 .48604 L p
1 g
F P
s
P
p
.002 w
.59847 .46196 m .6342 .4293 L .61801 .40752 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .49956 .32573 L .50559 .31951 L closepath p
1 g
F P
s
P
p
.002 w
.37925 .36601 m .39744 .38894 L .41537 .36596 L p
1 g
F P
s
P
p
.002 w
.41537 .36596 m .40158 .34802 L .37925 .36601 L p
1 g
F P
s
P
p
.002 w
.40158 .34802 m .41537 .36596 L .43536 .34462 L p
1 g
F P
s
P
p
.002 w
.39667 .5368 m .45114 .54915 L .44976 .52456 L p
1 g
F P
s
P
p
.002 w
.44976 .52456 m .39741 .51236 L .39667 .5368 L p
1 g
F P
s
P
p
.002 w
.46405 .32998 m .45702 .32532 L .43536 .34462 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .45702 .32532 L .46405 .32998 L closepath p
1 g
F P
s
P
p
.002 w
.43536 .34462 m .42615 .33224 L .40158 .34802 L p
1 g
F P
s
P
p
.002 w
.42615 .33224 m .43536 .34462 L .45702 .32532 L p
1 g
F P
s
P
p
.002 w
.61592 .35488 m .59915 .38664 L .61801 .40752 L p
1 g
F P
s
P
p
.002 w
.59915 .38664 m .61592 .35488 L .59163 .34041 L p
1 g
F P
s
P
p
.002 w
.35969 .38589 m .38194 .4131 L .39744 .38894 L p
1 g
F P
s
P
p
.002 w
.39744 .38894 m .37925 .36601 L .35969 .38589 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .50559 .31951 L .50891 .31223 L closepath p
1 g
F P
s
P
p
.002 w
.45702 .32532 m .45245 .31898 L .42615 .33224 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .45245 .31898 L .45702 .32532 L closepath p
1 g
F P
s
P
p
.002 w
.35333 .4879 m .39741 .51236 L .40068 .48645 L p
1 g
F P
s
P
p
.002 w
.40068 .48645 m .35958 .46309 L .35333 .4879 L p
1 g
F P
s
P
p
.002 w
.5383 .30392 m .53756 .31889 L .56532 .32835 L p
1 g
F P
s
P
p
.002 w
.53756 .31889 m .5383 .30392 L .50916 .30464 L p
1 g
F P
s
P
p
.002 w
.50916 .30464 m .50891 .31223 L .53756 .31889 L p
1 g
F P
s
P
p
.002 w
.4538 .57138 m .51268 .57044 L .5092 .54835 L p
1 g
F P
s
P
p
.002 w
.5092 .54835 m .45114 .54915 L .4538 .57138 L p
1 g
F P
s
P
p
.002 w
.56598 .53472 m .5092 .54835 L .51268 .57044 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .50891 .31223 L .50916 .30464 L closepath p
1 g
F P
s
P
p
.002 w
.34336 .40726 m .36921 .43798 L .38194 .4131 L p
1 g
F P
s
P
p
.002 w
.38194 .4131 m .35969 .38589 L .34336 .40726 L p
1 g
F P
s
P
p
.002 w
.63765 .3715 m .61801 .40752 L .6342 .4293 L p
1 g
F P
s
P
p
.002 w
.61801 .40752 m .63765 .3715 L .61592 .35488 L p
1 g
F P
s
P
p
.002 w
.42273 .31772 m .42615 .33224 L .45245 .31898 L p
1 g
F P
s
P
p
.002 w
.45245 .31898 m .45085 .3116 L .42273 .31772 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .45085 .3116 L .45245 .31898 L closepath p
1 g
F P
s
P
p
.002 w
.56677 .3064 m .56532 .32835 L .59163 .34041 L p
1 g
F P
s
P
p
.002 w
.56532 .32835 m .56677 .3064 L .5383 .30392 L p
1 g
F P
s
P
p
.002 w
.56598 .53472 m .61675 .50927 L .60887 .48604 L p
1 g
F P
s
P
p
.002 w
.6473 .45154 m .60887 .48604 L .61675 .50927 L p
1 g
F P
s
P
p
.002 w
.60887 .48604 m .6473 .45154 L .6342 .4293 L p
1 g
F P
s
P
p
.002 w
.39621 .32679 m .40158 .34802 L .42615 .33224 L p
1 g
F P
s
P
p
.002 w
.42615 .33224 m .42273 .31772 L .39621 .32679 L p
1 g
F P
s
P
p
.002 w
.51268 .57044 m .57029 .55668 L .56598 .53472 L p
1 g
F P
s
P
p
.002 w
.61675 .50927 m .56598 .53472 L .57029 .55668 L p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .50625 .29757 L .50047 .2918 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .50047 .2918 L .49243 .28798 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .49243 .28798 L .483 .28657 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .483 .28657 L .47325 .28773 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .47325 .28773 L .46427 .29133 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .46427 .29133 L .45707 .29696 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .45707 .29696 L .45243 .30398 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .45243 .30398 L .45085 .3116 L closepath p
1 g
F P
s
P
p
.002 w
.47995 .30848 m .50916 .30464 L .50625 .29757 L closepath p
1 g
F P
s
P
p
.002 w
.50625 .29757 m .50916 .30464 L .5383 .30392 L p
1 g
F P
s
P
p
.002 w
.39856 .55919 m .4538 .57138 L .45114 .54915 L p
1 g
F P
s
P
p
.002 w
.45114 .54915 m .39667 .5368 L .39856 .55919 L p
1 g
F P
s
P
p
.002 w
.37188 .33866 m .37925 .36601 L .40158 .34802 L p
1 g
F P
s
P
p
.002 w
.40158 .34802 m .39621 .32679 L .37188 .33866 L p
1 g
F P
s
P
p
.002 w
.59396 .31205 m .59163 .34041 L .61592 .35488 L p
1 g
F P
s
P
p
.002 w
.59163 .34041 m .59396 .31205 L .56677 .3064 L p
1 g
F P
s
P
p
.002 w
.42565 .3026 m .42273 .31772 L .45085 .3116 L p
1 g
F P
s
P
p
.002 w
.45085 .3116 m .45243 .30398 L .42565 .3026 L p
1 g
F P
s
P
p
.002 w
.33072 .4297 m .35958 .46309 L .36921 .43798 L p
1 g
F P
s
P
p
.002 w
.36921 .43798 m .34336 .40726 L .33072 .4297 L p
1 g
F P
s
P
p
.002 w
.35071 .51185 m .39667 .5368 L .39741 .51236 L p
1 g
F P
s
P
p
.002 w
.39741 .51236 m .35333 .4879 L .35071 .51185 L p
1 g
F P
s
P
p
.002 w
.53277 .28985 m .5383 .30392 L .56677 .3064 L p
1 g
F P
s
P
p
.002 w
.5383 .30392 m .53277 .28985 L .50625 .29757 L p
1 g
F P
s
P
p
.002 w
.50047 .2918 m .50625 .29757 L .53277 .28985 L p
1 g
F P
s
P
p
.002 w
.65628 .38996 m .6342 .4293 L .6473 .45154 L p
1 g
F P
s
P
p
.002 w
.6342 .4293 m .65628 .38996 L .63765 .3715 L p
1 g
F P
s
P
p
.002 w
.43472 .28856 m .42565 .3026 L .45243 .30398 L p
1 g
F P
s
P
p
.002 w
.45243 .30398 m .45707 .29696 L .43472 .28856 L p
1 g
F P
s
P
p
.002 w
.40019 .30448 m .39621 .32679 L .42273 .31772 L p
1 g
F P
s
P
p
.002 w
.42273 .31772 m .42565 .3026 L .40019 .30448 L p
1 g
F P
s
P
p
.002 w
.35034 .35316 m .35969 .38589 L .37925 .36601 L p
1 g
F P
s
P
p
.002 w
.37925 .36601 m .37188 .33866 L .35034 .35316 L p
1 g
F P
s
P
p
.002 w
.61924 .32086 m .61592 .35488 L .63765 .3715 L p
1 g
F P
s
P
p
.002 w
.61592 .35488 m .61924 .32086 L .59396 .31205 L p
1 g
F P
s
P
p
.002 w
.53277 .28985 m .52144 .27827 L .50047 .2918 L p
1 g
F P
s
P
p
.002 w
.49243 .28798 m .50047 .2918 L .52144 .27827 L p
1 g
F P
s
P
p
.002 w
.44904 .27723 m .43472 .28856 L .45707 .29696 L p
1 g
F P
s
P
p
.002 w
.45707 .29696 m .46427 .29133 L .44904 .27723 L p
1 g
F P
s
P
p
.002 w
.45773 .59069 m .51595 .58964 L .51268 .57044 L p
1 g
F P
s
P
p
.002 w
.51268 .57044 m .4538 .57138 L .45773 .59069 L p
1 g
F P
s
P
p
.002 w
.57029 .55668 m .51268 .57044 L .51595 .58964 L p
1 g
F P
s
P
p
.002 w
.57029 .55668 m .62187 .53111 L .61675 .50927 L p
1 g
F P
s
P
p
.002 w
.65694 .47378 m .61675 .50927 L .62187 .53111 L p
1 g
F P
s
P
p
.002 w
.61675 .50927 m .65694 .47378 L .6473 .45154 L p
1 g
F P
s
P
p
.002 w
.55896 .28559 m .56677 .3064 L .59396 .31205 L p
1 g
F P
s
P
p
.002 w
.56677 .3064 m .55896 .28559 L .53277 .28985 L p
1 g
F P
s
P
p
.002 w
.52144 .27827 m .50546 .27055 L .49243 .28798 L p
1 g
F P
s
P
p
.002 w
.483 .28657 m .49243 .28798 L .50546 .27055 L p
1 g
F P
s
P
p
.002 w
.46702 .26997 m .44904 .27723 L .46427 .29133 L p
1 g
F P
s
P
p
.002 w
.46427 .29133 m .47325 .28773 L .46702 .26997 L p
1 g
F P
s
P
p
.002 w
.32221 .45273 m .35333 .4879 L .35958 .46309 L p
1 g
F P
s
P
p
.002 w
.35958 .46309 m .33072 .4297 L .32221 .45273 L p
1 g
F P
s
P
p
.002 w
.52144 .27827 m .53277 .28985 L .55896 .28559 L p
1 g
F P
s
P
p
.002 w
.51595 .58964 m .57294 .57609 L .57029 .55668 L p
1 g
F P
s
P
p
.002 w
.62187 .53111 m .57029 .55668 L .57294 .57609 L p
1 g
F P
s
P
p
.002 w
.50546 .27055 m .48659 .26765 L .483 .28657 L p
1 g
F P
s
P
p
.002 w
.47325 .28773 m .483 .28657 L .48659 .26765 L p
1 g
F P
s
P
p
.002 w
.48659 .26765 m .46702 .26997 L .47325 .28773 L p
1 g
F P
s
P
p
.002 w
.37668 .30968 m .37188 .33866 L .39621 .32679 L p
1 g
F P
s
P
p
.002 w
.39621 .32679 m .40019 .30448 L .37668 .30968 L p
1 g
F P
s
P
p
.002 w
.33219 .37004 m .34336 .40726 L .35969 .38589 L p
1 g
F P
s
P
p
.002 w
.35969 .38589 m .35034 .35316 L .33219 .37004 L p
1 g
F P
s
P
p
.002 w
.41342 .2836 m .40019 .30448 L .42565 .3026 L p
1 g
F P
s
P
p
.002 w
.42565 .3026 m .43472 .28856 L .41342 .2836 L p
1 g
F P
s
P
p
.002 w
.35195 .53435 m .39856 .55919 L .39667 .5368 L p
1 g
F P
s
P
p
.002 w
.39667 .5368 m .35071 .51185 L .35195 .53435 L p
1 g
F P
s
P
p
.002 w
.40316 .57891 m .45773 .59069 L .4538 .57138 L p
1 g
F P
s
P
p
.002 w
.4538 .57138 m .39856 .55919 L .40316 .57891 L p
1 g
F P
s
P
p
.002 w
.6713 .40991 m .6473 .45154 L .65694 .47378 L p
1 g
F P
s
P
p
.002 w
.6473 .45154 m .6713 .40991 L .65628 .38996 L p
1 g
F P
s
P
p
.002 w
.64199 .33271 m .63765 .3715 L .65628 .38996 L p
1 g
F P
s
P
p
.002 w
.63765 .3715 m .64199 .33271 L .61924 .32086 L p
1 g
F P
s
P
p
.002 w
.58422 .28497 m .59396 .31205 L .61924 .32086 L p
1 g
F P
s
P
p
.002 w
.59396 .31205 m .58422 .28497 L .55896 .28559 L p
1 g
F P
s
P
p
.002 w
.55896 .28559 m .54242 .26831 L .52144 .27827 L p
1 g
F P
s
P
p
.002 w
.50546 .27055 m .52144 .27827 L .54242 .26831 L p
1 g
F P
s
P
p
.002 w
.43462 .26665 m .41342 .2836 L .43472 .28856 L p
1 g
F P
s
P
p
.002 w
.43472 .28856 m .44904 .27723 L .43462 .26665 L p
1 g
F P
s
P
p
.002 w
.54242 .26831 m .55896 .28559 L .58422 .28497 L p
1 g
F P
s
P
p
.002 w
.31819 .47582 m .35071 .51185 L .35333 .4879 L p
1 g
F P
s
P
p
.002 w
.35333 .4879 m .32221 .45273 L .31819 .47582 L p
1 g
F P
s
P
p
.002 w
.35574 .31821 m .35034 .35316 L .37188 .33866 L p
1 g
F P
s
P
p
.002 w
.37188 .33866 m .37668 .30968 L .35574 .31821 L p
1 g
F P
s
P
p
.002 w
.57294 .57609 m .62398 .55103 L .62187 .53111 L p
1 g
F P
s
P
p
.002 w
.66276 .49553 m .62187 .53111 L .62398 .55103 L p
1 g
F P
s
P
p
.002 w
.62187 .53111 m .66276 .49553 L .65694 .47378 L p
1 g
F P
s
P
p
.002 w
.318 .389 m .33072 .4297 L .34336 .40726 L p
1 g
F P
s
P
p
.002 w
.34336 .40726 m .33219 .37004 L .318 .389 L p
1 g
F P
s
P
p
.002 w
.46292 .60648 m .51892 .60538 L .51595 .58964 L p
1 g
F P
s
P
p
.002 w
.51595 .58964 m .45773 .59069 L .46292 .60648 L p
1 g
F P
s
P
p
.002 w
.57294 .57609 m .51595 .58964 L .51892 .60538 L p
1 g
F P
s
P
p
.002 w
.54242 .26831 m .51877 .25671 L .50546 .27055 L p
1 g
F P
s
P
p
.002 w
.48659 .26765 m .50546 .27055 L .51877 .25671 L p
1 g
F P
s
P
p
.002 w
.3937 .28235 m .37668 .30968 L .40019 .30448 L p
1 g
F P
s
P
p
.002 w
.40019 .30448 m .41342 .2836 L .3937 .28235 L p
1 g
F P
s
P
p
.002 w
.66158 .34744 m .65628 .38996 L .6713 .40991 L p
1 g
F P
s
P
p
.002 w
.65628 .38996 m .66158 .34744 L .64199 .33271 L p
1 g
F P
s
P
p
.002 w
.46143 .25576 m .43462 .26665 L .44904 .27723 L p
1 g
F P
s
P
p
.002 w
.44904 .27723 m .46702 .26997 L .46143 .25576 L p
1 g
F P
s
P
p
.002 w
.60793 .28815 m .61924 .32086 L .64199 .33271 L p
1 g
F P
s
P
p
.002 w
.61924 .32086 m .60793 .28815 L .58422 .28497 L p
1 g
F P
s
P
p
.002 w
.68221 .43095 m .65694 .47378 L .66276 .49553 L p
1 g
F P
s
P
p
.002 w
.65694 .47378 m .68221 .43095 L .6713 .40991 L p
1 g
F P
s
P
p
.002 w
.51892 .60538 m .57378 .59238 L .57294 .57609 L p
1 g
F P
s
P
p
.002 w
.62398 .55103 m .57294 .57609 L .57378 .59238 L p
1 g
F P
s
P
p
.002 w
.51877 .25671 m .49066 .25231 L .48659 .26765 L p
1 g
F P
s
P
p
.002 w
.46702 .26997 m .48659 .26765 L .49066 .25231 L p
1 g
F P
s
P
p
.002 w
.35719 .55479 m .40316 .57891 L .39856 .55919 L p
1 g
F P
s
P
p
.002 w
.39856 .55919 m .35195 .53435 L .35719 .55479 L p
1 g
F P
s
P
p
.002 w
.49066 .25231 m .46143 .25576 L .46702 .26997 L p
1 g
F P
s
P
p
.002 w
.4105 .59537 m .46292 .60648 L .45773 .59069 L p
1 g
F P
s
P
p
.002 w
.45773 .59069 m .40316 .57891 L .4105 .59537 L p
1 g
F P
s
P
p
.002 w
.58422 .28497 m .56291 .26231 L .54242 .26831 L p
1 g
F P
s
P
p
.002 w
.51877 .25671 m .54242 .26831 L .56291 .26231 L p
1 g
F P
s
P
p
.002 w
.56291 .26231 m .58422 .28497 L .60793 .28815 L p
1 g
F P
s
P
p
.002 w
.33801 .33003 m .33219 .37004 L .35034 .35316 L p
1 g
F P
s
P
p
.002 w
.35034 .35316 m .35574 .31821 L .33801 .33003 L p
1 g
F P
s
P
p
.002 w
.30829 .40965 m .32221 .45273 L .33072 .4297 L p
1 g
F P
s
P
p
.002 w
.33072 .4297 m .318 .389 L .30829 .40965 L p
1 g
F P
s
P
p
.002 w
.31896 .49838 m .35195 .53435 L .35071 .51185 L p
1 g
F P
s
P
p
.002 w
.35071 .51185 m .31819 .47582 L .31896 .49838 L p
1 g
F P
s
P
p
.002 w
.42139 .26003 m .3937 .28235 L .41342 .2836 L p
1 g
F P
s
P
p
.002 w
.41342 .2836 m .43462 .26665 L .42139 .26003 L p
1 g
F P
s
P
p
.002 w
.62948 .29521 m .64199 .33271 L .66158 .34744 L p
1 g
F P
s
P
p
.002 w
.64199 .33271 m .62948 .29521 L .60793 .28815 L p
1 g
F P
s
P
p
.002 w
.67741 .36481 m .6713 .40991 L .68221 .43095 L p
1 g
F P
s
P
p
.002 w
.6713 .40991 m .67741 .36481 L .66158 .34744 L p
1 g
F P
s
P
p
.002 w
.37614 .28503 m .35574 .31821 L .37668 .30968 L p
1 g
F P
s
P
p
.002 w
.37668 .30968 m .3937 .28235 L .37614 .28503 L p
1 g
F P
s
P
p
.002 w
.57378 .59238 m .62288 .56846 L .62398 .55103 L p
1 g
F P
s
P
p
.002 w
.66445 .51624 m .62398 .55103 L .62288 .56846 L p
1 g
F P
s
P
p
.002 w
.62398 .55103 m .66445 .51624 L .66276 .49553 L p
1 g
F P
s
P
p
.002 w
.56291 .26231 m .53207 .24699 L .51877 .25671 L p
1 g
F P
s
P
p
.002 w
.49066 .25231 m .51877 .25671 L .53207 .24699 L p
1 g
F P
s
P
p
.002 w
.68858 .45261 m .66276 .49553 L .66445 .51624 L p
1 g
F P
s
P
p
.002 w
.66276 .49553 m .68858 .45261 L .68221 .43095 L p
1 g
F P
s
P
p
.002 w
.46929 .61818 m .5215 .61709 L .51892 .60538 L p
1 g
F P
s
P
p
.002 w
.51892 .60538 m .46292 .60648 L .46929 .61818 L p
1 g
F P
s
P
p
.002 w
.57378 .59238 m .51892 .60538 L .5215 .61709 L p
1 g
F P
s
P
p
.002 w
.45665 .24566 m .42139 .26003 L .43462 .26665 L p
1 g
F P
s
P
p
.002 w
.43462 .26665 m .46143 .25576 L .45665 .24566 L p
1 g
F P
s
P
p
.002 w
.36648 .57255 m .4105 .59537 L .40316 .57891 L p
1 g
F P
s
P
p
.002 w
.40316 .57891 m .35719 .55479 L .36648 .57255 L p
1 g
F P
s
P
p
.002 w
.5215 .61709 m .57267 .60499 L .57378 .59238 L p
1 g
F P
s
P
p
.002 w
.62288 .56846 m .57378 .59238 L .57267 .60499 L p
1 g
F P
s
P
p
.002 w
.3241 .34498 m .318 .389 L .33219 .37004 L p
1 g
F P
s
P
p
.002 w
.33219 .37004 m .33801 .33003 L .3241 .34498 L p
1 g
F P
s
P
p
.002 w
.53207 .24699 m .49515 .24113 L .49066 .25231 L p
1 g
F P
s
P
p
.002 w
.46143 .25576 m .49066 .25231 L .49515 .24113 L p
1 g
F P
s
P
p
.002 w
.58242 .2606 m .60793 .28815 L .62948 .29521 L p
1 g
F P
s
P
p
.002 w
.60793 .28815 m .58242 .2606 L .56291 .26231 L p
1 g
F P
s
P
p
.002 w
.49515 .24113 m .45665 .24566 L .46143 .25576 L p
1 g
F P
s
P
p
.002 w
.30352 .43152 m .31819 .47582 L .32221 .45273 L p
1 g
F P
s
P
p
.002 w
.32221 .45273 m .30829 .40965 L .30352 .43152 L p
1 g
F P
s
P
p
.002 w
.53207 .24699 m .56291 .26231 L .58242 .2606 L p
1 g
F P
s
P
p
.002 w
.42055 .60798 m .46929 .61818 L .46292 .60648 L p
1 g
F P
s
P
p
.002 w
.46292 .60648 m .4105 .59537 L .42055 .60798 L p
1 g
F P
s
P
p
.002 w
.32472 .5198 m .35719 .55479 L .35195 .53435 L p
1 g
F P
s
P
p
.002 w
.35195 .53435 m .31896 .49838 L .32472 .5198 L p
1 g
F P
s
P
p
.002 w
.6482 .30615 m .66158 .34744 L .67741 .36481 L p
1 g
F P
s
P
p
.002 w
.66158 .34744 m .6482 .30615 L .62948 .29521 L p
1 g
F P
s
P
p
.002 w
.68891 .38449 m .68221 .43095 L .68858 .45261 L p
1 g
F P
s
P
p
.002 w
.68221 .43095 m .68891 .38449 L .67741 .36481 L p
1 g
F P
s
P
p
.002 w
.40977 .25779 m .37614 .28503 L .3937 .28235 L p
1 g
F P
s
P
p
.002 w
.3937 .28235 m .42139 .26003 L .40977 .25779 L p
1 g
F P
s
P
p
.002 w
.3613 .29179 m .33801 .33003 L .35574 .31821 L p
1 g
F P
s
P
p
.002 w
.35574 .31821 m .37614 .28503 L .3613 .29179 L p
1 g
F P
s
P
p
.002 w
.57267 .60499 m .61843 .58284 L .62288 .56846 L p
1 g
F P
s
P
p
.002 w
.66176 .53535 m .62288 .56846 L .61843 .58284 L p
1 g
F P
s
P
p
.002 w
.62288 .56846 m .66176 .53535 L .66445 .51624 L p
1 g
F P
s
P
p
.002 w
.69001 .47435 m .66445 .51624 L .66176 .53535 L p
1 g
F P
s
P
p
.002 w
.66445 .51624 m .69001 .47435 L .68858 .45261 L p
1 g
F P
s
P
p
.002 w
.58242 .2606 m .54502 .24186 L .53207 .24699 L p
1 g
F P
s
P
p
.002 w
.49515 .24113 m .53207 .24699 L .54502 .24186 L p
1 g
F P
s
P
p
.002 w
.31458 .36282 m .30829 .40965 L .318 .389 L p
1 g
F P
s
P
p
.002 w
.318 .389 m .3241 .34498 L .31458 .36282 L p
1 g
F P
s
P
p
.002 w
.60038 .26345 m .62948 .29521 L .6482 .30615 L p
1 g
F P
s
P
p
.002 w
.62948 .29521 m .60038 .26345 L .58242 .2606 L p
1 g
F P
s
P
p
.002 w
.30408 .45406 m .31896 .49838 L .31819 .47582 L p
1 g
F P
s
P
p
.002 w
.31819 .47582 m .30352 .43152 L .30408 .45406 L p
1 g
F P
s
P
p
.002 w
.3798 .58699 m .42055 .60798 L .4105 .59537 L p
1 g
F P
s
P
p
.002 w
.4105 .59537 m .36648 .57255 L .3798 .58699 L p
1 g
F P
s
P
p
.002 w
.45284 .24018 m .40977 .25779 L .42139 .26003 L p
1 g
F P
s
P
p
.002 w
.42139 .26003 m .45665 .24566 L .45284 .24018 L p
1 g
F P
s
P
p
.002 w
.47678 .62523 m .52361 .62422 L .5215 .61709 L p
1 g
F P
s
P
p
.002 w
.5215 .61709 m .46929 .61818 L .47678 .62523 L p
1 g
F P
s
P
p
.002 w
.57267 .60499 m .5215 .61709 L .52361 .62422 L p
1 g
F P
s
P
p
.002 w
.54502 .24186 m .58242 .2606 L .60038 .26345 L p
1 g
F P
s
P
p
.002 w
.52361 .62422 m .56954 .61338 L .57267 .60499 L p
1 g
F P
s
P
p
.002 w
.61843 .58284 m .57267 .60499 L .56954 .61338 L p
1 g
F P
s
P
p
.002 w
.66347 .32087 m .67741 .36481 L .68891 .38449 L p
1 g
F P
s
P
p
.002 w
.67741 .36481 m .66347 .32087 L .6482 .30615 L p
1 g
F P
s
P
p
.002 w
.33556 .53943 m .36648 .57255 L .35719 .55479 L p
1 g
F P
s
P
p
.002 w
.35719 .55479 m .32472 .5198 L .33556 .53943 L p
1 g
F P
s
P
p
.002 w
.54502 .24186 m .49995 .23465 L .49515 .24113 L p
1 g
F P
s
P
p
.002 w
.45665 .24566 m .49515 .24113 L .49995 .23465 L p
1 g
F P
s
P
p
.002 w
.69557 .40606 m .68858 .45261 L .69001 .47435 L p
1 g
F P
s
P
p
.002 w
.68858 .45261 m .69557 .40606 L .68891 .38449 L p
1 g
F P
s
P
p
.002 w
.49995 .23465 m .45284 .24018 L .45665 .24566 L p
1 g
F P
s
P
p
.002 w
.43319 .61617 m .47678 .62523 L .46929 .61818 L p
1 g
F P
s
P
p
.002 w
.46929 .61818 m .42055 .60798 L .43319 .61617 L p
1 g
F P
s
P
p
.002 w
.34975 .30268 m .3241 .34498 L .33801 .33003 L p
1 g
F P
s
P
p
.002 w
.33801 .33003 m .3613 .29179 L .34975 .30268 L p
1 g
F P
s
P
p
.002 w
.40016 .26023 m .3613 .29179 L .37614 .28503 L p
1 g
F P
s
P
p
.002 w
.37614 .28503 m .40977 .25779 L .40016 .26023 L p
1 g
F P
s
P
p
.002 w
.61843 .58284 m .65453 .55227 L .66176 .53535 L p
1 g
F P
s
P
p
.002 w
.68624 .4956 m .66176 .53535 L .65453 .55227 L p
1 g
F P
s
P
p
.002 w
.66176 .53535 m .68624 .4956 L .69001 .47435 L p
1 g
F P
s
P
p
.002 w
.30997 .3832 m .30352 .43152 L .30829 .40965 L p
1 g
F P
s
P
p
.002 w
.30829 .40965 m .31458 .36282 L .30997 .3832 L p
1 g
F P
s
P
p
.002 w
.56954 .61338 m .61053 .59359 L .61843 .58284 L p
1 g
F P
s
P
p
.002 w
.65453 .55227 m .61843 .58284 L .61053 .59359 L p
1 g
F P
s
P
p
.002 w
.3102 .47666 m .32472 .5198 L .31896 .49838 L p
1 g
F P
s
P
p
.002 w
.31896 .49838 m .30408 .45406 L .3102 .47666 L p
1 g
F P
s
P
p
.002 w
.61624 .27102 m .6482 .30615 L .66347 .32087 L p
1 g
F P
s
P
p
.002 w
.6482 .30615 m .61624 .27102 L .60038 .26345 L p
1 g
F P
s
P
p
.002 w
.60038 .26345 m .55725 .24173 L .54502 .24186 L p
1 g
F P
s
P
p
.002 w
.49995 .23465 m .54502 .24186 L .55725 .24173 L p
1 g
F P
s
P
p
.002 w
.68891 .38449 m .67468 .33915 L .66347 .32087 L p
1 g
F P
s
P
p
.002 w
.67468 .33915 m .68891 .38449 L .69557 .40606 L p
1 g
F P
s
P
p
.002 w
.39697 .59755 m .43319 .61617 L .42055 .60798 L p
1 g
F P
s
P
p
.002 w
.42055 .60798 m .3798 .58699 L .39697 .59755 L p
1 g
F P
s
P
p
.002 w
.45019 .23977 m .40016 .26023 L .40977 .25779 L p
1 g
F P
s
P
p
.002 w
.40977 .25779 m .45284 .24018 L .45019 .23977 L p
1 g
F P
s
P
p
.002 w
.55725 .24173 m .60038 .26345 L .61624 .27102 L p
1 g
F P
s
P
p
.002 w
.35141 .5566 m .3798 .58699 L .36648 .57255 L p
1 g
F P
s
P
p
.002 w
.36648 .57255 m .33556 .53943 L .35141 .5566 L p
1 g
F P
s
P
p
.002 w
.69001 .47435 m .69697 .429 L .69557 .40606 L p
1 g
F P
s
P
p
.002 w
.69697 .429 m .69001 .47435 L .68624 .4956 L p
1 g
F P
s
P
p
.002 w
.48523 .62714 m .52515 .62627 L .52361 .62422 L p
1 g
F P
s
P
p
.002 w
.52361 .62422 m .47678 .62523 L .48523 .62714 L p
1 g
F P
s
P
p
.002 w
.56954 .61338 m .52361 .62422 L .52515 .62627 L p
1 g
F P
s
P
p
.002 w
.34203 .31762 m .31458 .36282 L .3241 .34498 L p
1 g
F P
s
P
p
.002 w
.3241 .34498 m .34975 .30268 L .34203 .31762 L p
1 g
F P
s
P
p
.002 w
.52515 .62627 m .56434 .61703 L .56954 .61338 L p
1 g
F P
s
P
p
.002 w
.61053 .59359 m .56954 .61338 L .56434 .61703 L p
1 g
F P
s
P
p
.004 w
.53413 .63822 m
.53841 .66422 L
s
P
p
.004 w
.69811 .50425 m
.7755 .53306 L
s
P
p
.002 w
.55725 .24173 m .50497 .23334 L .49995 .23465 L p
1 g
F P
s
P
p
.002 w
.45284 .24018 m .49995 .23465 L .50497 .23334 L p
1 g
F P
s
P
p
.002 w
.50497 .23334 m .45019 .23977 L .45284 .24018 L p
1 g
F P
s
P
p
.002 w
.44821 .61945 m .48523 .62714 L .47678 .62523 L p
1 g
F P
s
P
p
.002 w
.47678 .62523 m .43319 .61617 L .44821 .61945 L p
1 g
F P
s
P
p
.002 w
.39297 .26761 m .34975 .30268 L .3613 .29179 L p
1 g
F P
s
P
p
.002 w
.3613 .29179 m .40016 .26023 L .39297 .26761 L p
1 g
F P
s
P
p
.002 w
.31065 .40562 m .30408 .45406 L .30352 .43152 L p
1 g
F P
s
P
p
.002 w
.30352 .43152 m .30997 .3832 L .31065 .40562 L p
1 g
F P
s
P
p
.002 w
.32195 .49863 m .33556 .53943 L .32472 .5198 L p
1 g
F P
s
P
p
.002 w
.32472 .5198 m .3102 .47666 L .32195 .49863 L p
1 g
F P
s
P
p
.002 w
.61053 .59359 m .64272 .56641 L .65453 .55227 L p
1 g
F P
s
P
p
.002 w
.65453 .55227 m .67711 .51572 L .68624 .4956 L p
1 g
F P
s
P
p
.002 w
.67711 .51572 m .65453 .55227 L .64272 .56641 L p
1 g
F P
s
P
p
.002 w
.66347 .32087 m .6294 .28338 L .61624 .27102 L p
1 g
F P
s
P
p
.002 w
.6294 .28338 m .66347 .32087 L .67468 .33915 L p
1 g
F P
s
P
p
.002 w
.56434 .61703 m .59921 .60021 L .61053 .59359 L p
1 g
F P
s
P
p
.002 w
.64272 .56641 m .61053 .59359 L .59921 .60021 L p
1 g
F P
s
P
p
.002 w
.68131 .36063 m .69557 .40606 L .69697 .429 L p
1 g
F P
s
P
p
.002 w
.69557 .40606 m .68131 .36063 L .67468 .33915 L p
1 g
F P
s
P
p
.002 w
.61624 .27102 m .56838 .24692 L .55725 .24173 L p
1 g
F P
s
P
p
.002 w
.50497 .23334 m .55725 .24173 L .56838 .24692 L p
1 g
F P
s
P
p
.002 w
.69281 .4527 m .68624 .4956 L .67711 .51572 L p
1 g
F P
s
P
p
.002 w
.68624 .4956 m .69281 .4527 L .69697 .429 L p
1 g
F P
s
P
p
.002 w
.41768 .60369 m .44821 .61945 L .43319 .61617 L p
1 g
F P
s
P
p
.002 w
.43319 .61617 m .39697 .59755 L .41768 .60369 L p
1 g
F P
s
P
p
.002 w
.37202 .57067 m .39697 .59755 L .3798 .58699 L p
1 g
F P
s
P
p
.002 w
.3798 .58699 m .35141 .5566 L .37202 .57067 L p
1 g
F P
s
P
p
.002 w
.56838 .24692 m .61624 .27102 L .6294 .28338 L p
1 g
F P
s
P
p
.002 w
.33858 .3364 m .30997 .3832 L .31458 .36282 L p
1 g
F P
s
P
p
.002 w
.31458 .36282 m .34203 .31762 L .33858 .3364 L p
1 g
F P
s
P
p
.002 w
.44884 .2448 m .39297 .26761 L .40016 .26023 L p
1 g
F P
s
P
p
.002 w
.40016 .26023 m .45019 .23977 L .44884 .2448 L p
1 g
F P
s
P
p
.002 w
.49446 .62353 m .52605 .62285 L .52515 .62627 L p
1 g
F P
s
P
p
.002 w
.52515 .62627 m .48523 .62714 L .49446 .62353 L p
1 g
F P
s
P
p
.002 w
.56434 .61703 m .52515 .62627 L .52605 .62285 L p
1 g
F P
s
P
p
.002 w
.31686 .42949 m .3102 .47666 L .30408 .45406 L p
1 g
F P
s
P
p
.002 w
.30408 .45406 m .31065 .40562 L .31686 .42949 L p
1 g
F P
s
P
p
.002 w
.52605 .62285 m .55707 .61553 L .56434 .61703 L p
1 g
F P
s
P
p
.002 w
.59921 .60021 m .56434 .61703 L .55707 .61553 L p
1 g
F P
s
P
p
.002 w
.38858 .28001 m .34203 .31762 L .34975 .30268 L p
1 g
F P
s
P
p
.002 w
.34975 .30268 m .39297 .26761 L .38858 .28001 L p
1 g
F P
s
P
p
.002 w
.33922 .51925 m .35141 .5566 L .33556 .53943 L p
1 g
F P
s
P
p
.002 w
.33556 .53943 m .32195 .49863 L .33922 .51925 L p
1 g
F P
s
P
p
.002 w
.56838 .24692 m .51007 .2376 L .50497 .23334 L p
1 g
F P
s
P
p
.002 w
.45019 .23977 m .50497 .23334 L .51007 .2376 L p
1 g
F P
s
P
p
.002 w
.4653 .61743 m .49446 .62353 L .48523 .62714 L p
1 g
F P
s
P
p
.002 w
.48523 .62714 m .44821 .61945 L .4653 .61743 L p
1 g
F P
s
P
p
.002 w
.51007 .2376 m .44884 .2448 L .45019 .23977 L p
1 g
F P
s
P
p
.002 w
.63934 .30042 m .67468 .33915 L .68131 .36063 L p
1 g
F P
s
P
p
.002 w
.67468 .33915 m .63934 .30042 L .6294 .28338 L p
1 g
F P
s
P
p
.002 w
.59921 .60021 m .62641 .57719 L .64272 .56641 L p
1 g
F P
s
P
p
.002 w
.66264 .53407 m .64272 .56641 L .62641 .57719 L p
1 g
F P
s
P
p
.002 w
.64272 .56641 m .66264 .53407 L .67711 .51572 L p
1 g
F P
s
P
p
.002 w
.68292 .38482 m .69697 .429 L .69281 .4527 L p
1 g
F P
s
P
p
.002 w
.69697 .429 m .68292 .38482 L .68131 .36063 L p
1 g
F P
s
P
p
.002 w
.55707 .61553 m .58458 .60223 L .59921 .60021 L p
1 g
F P
s
P
p
.002 w
.62641 .57719 m .59921 .60021 L .58458 .60223 L p
1 g
F P
s
P
p
.002 w
.68296 .47647 m .67711 .51572 L .66264 .53407 L p
1 g
F P
s
P
p
.002 w
.67711 .51572 m .68296 .47647 L .69281 .4527 L p
1 g
F P
s
P
p
.004 w
.68814 .50054 m
.69811 .50425 L
s
P
p
.004 w
.68495 .49935 m
.68814 .50054 L
s
P
p
.002 w
.39695 .58106 m .41768 .60369 L .39697 .59755 L p
1 g
F P
s
P
p
.002 w
.39697 .59755 m .37202 .57067 L .39695 .58106 L p
1 g
F P
s
P
p
.002 w
.578 .2576 m .6294 .28338 L .63934 .30042 L p
1 g
F P
s
P
p
.002 w
.6294 .28338 m .578 .2576 L .56838 .24692 L p
1 g
F P
s
P
p
.002 w
.51007 .2376 m .56838 .24692 L .578 .2576 L p
1 g
F P
s
P
p
.002 w
.44147 .605 m .4653 .61743 L .44821 .61945 L p
1 g
F P
s
P
p
.002 w
.44821 .61945 m .41768 .60369 L .44147 .605 L p
1 g
F P
s
P
p
.002 w
.33976 .35861 m .31065 .40562 L .30997 .3832 L p
1 g
F P
s
P
p
.002 w
.30997 .3832 m .33858 .3364 L .33976 .35861 L p
1 g
F P
s
P
p
.002 w
.32867 .45408 m .32195 .49863 L .3102 .47666 L p
1 g
F P
s
P
p
.002 w
.3102 .47666 m .31686 .42949 L .32867 .45408 L p
1 g
F P
s
P
p
.002 w
.44892 .25546 m .38858 .28001 L .39297 .26761 L p
1 g
F P
s
P
p
.002 w
.39297 .26761 m .44884 .2448 L .44892 .25546 L p
1 g
F P
s
P
p
.002 w
.36167 .53779 m .37202 .57067 L .35141 .5566 L p
1 g
F P
s
P
p
.002 w
.35141 .5566 m .33922 .51925 L .36167 .53779 L p
1 g
F P
s
P
p
.002 w
.64556 .32185 m .68131 .36063 L .68292 .38482 L p
1 g
F P
s
P
p
.002 w
.68131 .36063 m .64556 .32185 L .63934 .30042 L p
1 g
F P
s
P
p
.002 w
.38729 .29734 m .33858 .3364 L .34203 .31762 L p
1 g
F P
s
P
p
.002 w
.34203 .31762 m .38858 .28001 L .38729 .29734 L p
1 g
F P
s
P
p
.002 w
.50424 .61415 m .52623 .6137 L .52605 .62285 L p
1 g
F P
s
P
p
.002 w
.52605 .62285 m .49446 .62353 L .50424 .61415 L p
1 g
F P
s
P
p
.002 w
.55707 .61553 m .52605 .62285 L .52623 .6137 L p
1 g
F P
s
P
p
.002 w
.67923 .41106 m .69281 .4527 L .68296 .47647 L p
1 g
F P
s
P
p
.002 w
.69281 .4527 m .67923 .41106 L .68292 .38482 L p
1 g
F P
s
P
p
.002 w
.58458 .60223 m .60587 .58411 L .62641 .57719 L p
1 g
F P
s
P
p
.002 w
.643 .54998 m .62641 .57719 L .60587 .58411 L p
1 g
F P
s
P
p
.002 w
.62641 .57719 m .643 .54998 L .66264 .53407 L p
1 g
F P
s
P
p
.002 w
.52623 .6137 m .54784 .60859 L .55707 .61553 L p
1 g
F P
s
P
p
.002 w
.58458 .60223 m .55707 .61553 L .54784 .60859 L p
1 g
F P
s
P
p
.002 w
.578 .2576 m .51509 .24766 L .51007 .2376 L p
1 g
F P
s
P
p
.002 w
.44884 .2448 m .51007 .2376 L .51509 .24766 L p
1 g
F P
s
P
p
.002 w
.48405 .60987 m .50424 .61415 L .49446 .62353 L p
1 g
F P
s
P
p
.002 w
.49446 .62353 m .4653 .61743 L .48405 .60987 L p
1 g
F P
s
P
p
.002 w
.6675 .49955 m .66264 .53407 L .643 .54998 L p
1 g
F P
s
P
p
.002 w
.66264 .53407 m .6675 .49955 L .68296 .47647 L p
1 g
F P
s
P
p
.004 w
.67688 .49635 m
.67823 .49685 L
s
P
p
.004 w
.67823 .49685 m
.68495 .49935 L
s
P
p
.004 w
.5 .43051 m
.67109 .49419 L
s
P
p
.002 w
.51509 .24766 m .44892 .25546 L .44884 .2448 L p
1 g
F P
s
P
p
.002 w
.42557 .58727 m .44147 .605 L .41768 .60369 L p
1 g
F P
s
P
p
.002 w
.41768 .60369 m .39695 .58106 L .42557 .58727 L p
1 g
F P
s
P
p
.002 w
.54784 .60859 m .56692 .59931 L .58458 .60223 L p
1 g
F P
s
P
p
.002 w
.60587 .58411 m .58458 .60223 L .56692 .59931 L p
1 g
F P
s
P
p
.002 w
.34577 .38368 m .31686 .42949 L .31065 .40562 L p
1 g
F P
s
P
p
.002 w
.31065 .40562 m .33976 .35861 L .34577 .38368 L p
1 g
F P
s
P
p
.002 w
.34588 .47859 m .33922 .51925 L .32195 .49863 L p
1 g
F P
s
P
p
.002 w
.32195 .49863 m .32867 .45408 L .34588 .47859 L p
1 g
F P
s
P
p
.002 w
.58571 .27377 m .63934 .30042 L .64556 .32185 L p
1 g
F P
s
P
p
.002 w
.63934 .30042 m .58571 .27377 L .578 .2576 L p
1 g
F P
s
P
p
.002 w
.46771 .6012 m .48405 .60987 L .4653 .61743 L p
1 g
F P
s
P
p
.002 w
.4653 .61743 m .44147 .605 L .46771 .6012 L p
1 g
F P
s
P
p
.002 w
.38873 .55355 m .39695 .58106 L .37202 .57067 L p
1 g
F P
s
P
p
.002 w
.37202 .57067 m .36167 .53779 L .38873 .55355 L p
1 g
F P
s
P
p
.002 w
.51509 .24766 m .578 .2576 L .58571 .27377 L p
1 g
F P
s
P
p
.002 w
.67014 .43858 m .68296 .47647 L .6675 .49955 L p
1 g
F P
s
P
p
.002 w
.68296 .47647 m .67014 .43858 L .67923 .41106 L p
1 g
F P
s
P
p
.002 w
.64766 .34718 m .68292 .38482 L .67923 .41106 L p
1 g
F P
s
P
p
.002 w
.68292 .38482 m .64766 .34718 L .64556 .32185 L p
1 g
F P
s
P
p
.002 w
.45053 .27175 m .38729 .29734 L .38858 .28001 L p
1 g
F P
s
P
p
.002 w
.38858 .28001 m .44892 .25546 L .45053 .27175 L p
1 g
F P
s
P
p
.002 w
.38933 .31929 m .33976 .35861 L .33858 .3364 L p
1 g
F P
s
P
p
.002 w
.33858 .3364 m .38729 .29734 L .38933 .31929 L p
1 g
F P
s
P
p
.002 w
.56692 .59931 m .58154 .58674 L .60587 .58411 L p
1 g
F P
s
P
p
.002 w
.61861 .56284 m .60587 .58411 L .58154 .58674 L p
1 g
F P
s
P
p
.002 w
.60587 .58411 m .61861 .56284 L .643 .54998 L p
1 g
F P
s
P
p
.002 w
.64672 .52116 m .643 .54998 L .61861 .56284 L p
1 g
F P
s
P
p
.002 w
.643 .54998 m .64672 .52116 L .6675 .49955 L p
1 g
F P
s
P
p
.002 w
.51429 .59896 m .52564 .59874 L .52623 .6137 L p
1 g
F P
s
P
p
.002 w
.52623 .6137 m .50424 .61415 L .51429 .59896 L p
1 g
F P
s
P
p
.002 w
.54784 .60859 m .52623 .6137 L .52564 .59874 L p
1 g
F P
s
P
p
.002 w
.52564 .59874 m .53681 .5961 L .54784 .60859 L p
1 g
F P
s
P
p
.002 w
.56692 .59931 m .54784 .60859 L .53681 .5961 L p
1 g
F P
s
P
p
.002 w
.45702 .58895 m .46771 .6012 L .44147 .605 L p
1 g
F P
s
P
p
.002 w
.44147 .605 m .42557 .58727 L .45702 .58895 L p
1 g
F P
s
P
p
.002 w
.50391 .59671 m .51429 .59896 L .50424 .61415 L p
1 g
F P
s
P
p
.002 w
.50424 .61415 m .48405 .60987 L .50391 .59671 L p
1 g
F P
s
P
p
.002 w
.3681 .50217 m .36167 .53779 L .33922 .51925 L p
1 g
F P
s
P
p
.002 w
.33922 .51925 m .34588 .47859 L .3681 .50217 L p
1 g
F P
s
P
p
.002 w
.58571 .27377 m .51987 .26355 L .51509 .24766 L p
1 g
F P
s
P
p
.002 w
.44892 .25546 m .51509 .24766 L .51987 .26355 L p
1 g
F P
s
P
p
.002 w
.3566 .41087 m .32867 .45408 L .31686 .42949 L p
1 g
F P
s
P
p
.002 w
.31686 .42949 m .34577 .38368 L .3566 .41087 L p
1 g
F P
s
P
p
.002 w
.41959 .56589 m .42557 .58727 L .39695 .58106 L p
1 g
F P
s
P
p
.002 w
.39695 .58106 m .38873 .55355 L .41959 .56589 L p
1 g
F P
s
P
p
.002 w
.51987 .26355 m .45053 .27175 L .44892 .25546 L p
1 g
F P
s
P
p
.002 w
.59114 .2952 m .64556 .32185 L .64766 .34718 L p
1 g
F P
s
P
p
.002 w
.64556 .32185 m .59114 .2952 L .58571 .27377 L p
1 g
F P
s
P
p
.002 w
.53681 .5961 m .54662 .59128 L .56692 .59931 L p
1 g
F P
s
P
p
.002 w
.58154 .58674 m .56692 .59931 L .54662 .59128 L p
1 g
F P
s
P
p
.002 w
.65575 .46647 m .6675 .49955 L .64672 .52116 L p
1 g
F P
s
P
p
.002 w
.6675 .49955 m .65575 .46647 L .67014 .43858 L p
1 g
F P
s
P
p
.002 w
.6454 .37574 m .67923 .41106 L .67014 .43858 L p
1 g
F P
s
P
p
.002 w
.67923 .41106 m .6454 .37574 L .64766 .34718 L p
1 g
F P
s
P
p
.002 w
.49562 .59221 m .50391 .59671 L .48405 .60987 L p
1 g
F P
s
P
p
.002 w
.48405 .60987 m .46771 .6012 L .49562 .59221 L p
1 g
F P
s
P
p
.002 w
.51987 .26355 m .58571 .27377 L .59114 .2952 L p
1 g
F P
s
P
p
.002 w
.58154 .58674 m .5901 .57209 L .61861 .56284 L p
1 g
F P
s
P
p
.002 w
.62115 .5405 m .61861 .56284 L .5901 .57209 L p
1 g
F P
s
P
p
.002 w
.61861 .56284 m .62115 .5405 L .64672 .52116 L p
1 g
F P
s
P
p
.002 w
.54662 .59128 m .55406 .58479 L .58154 .58674 L p
1 g
F P
s
P
p
.002 w
.5901 .57209 m .58154 .58674 L .55406 .58479 L p
1 g
F P
s
P
p
.002 w
.39481 .34533 m .34577 .38368 L .33976 .35861 L p
1 g
F P
s
P
p
.002 w
.33976 .35861 m .38933 .31929 L .39481 .34533 L p
1 g
F P
s
P
p
.002 w
.39466 .52393 m .38873 .55355 L .36167 .53779 L p
1 g
F P
s
P
p
.002 w
.36167 .53779 m .3681 .50217 L .39466 .52393 L p
1 g
F P
s
P
p
.002 w
.45369 .29346 m .38933 .31929 L .38729 .29734 L p
1 g
F P
s
P
p
.002 w
.38729 .29734 m .45053 .27175 L .45369 .29346 L p
1 g
F P
s
P
p
.002 w
.4903 .58591 m .49562 .59221 L .46771 .6012 L p
1 g
F P
s
P
p
.002 w
.46771 .6012 m .45702 .58895 L .4903 .58591 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51892 .54561 L
s
P
p
.002 w
.45326 .57431 m .45702 .58895 L .42557 .58727 L p
1 g
F P
s
P
p
.002 w
.42557 .58727 m .41959 .56589 L .45326 .57431 L p
1 g
F P
s
P
p
.002 w
.37206 .43926 m .34588 .47859 L .32867 .45408 L p
1 g
F P
s
P
p
.002 w
.32867 .45408 m .3566 .41087 L .37206 .43926 L p
1 g
F P
s
P
p
.002 w
.63642 .49376 m .64672 .52116 L .62115 .5405 L p
1 g
F P
s
P
p
.002 w
.64672 .52116 m .63642 .49376 L .65575 .46647 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.63867 .40661 m .67014 .43858 L .65575 .46647 L p
1 g
F P
s
P
p
.002 w
.67014 .43858 m .63867 .40661 L .6454 .37574 L p
1 g
F P
s
P
p
.002 w
.52564 .59874 m .51429 .59896 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.53681 .5961 m .52564 .59874 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.54662 .59128 m .53681 .5961 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.59399 .32142 m .64766 .34718 L .6454 .37574 L p
1 g
F P
s
P
p
.002 w
.64766 .34718 m .59399 .32142 L .59114 .2952 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.51429 .59896 m .50391 .59671 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.59114 .2952 m .52423 .28507 L .51987 .26355 L p
1 g
F P
s
P
p
.002 w
.45053 .27175 m .51987 .26355 L .52423 .28507 L p
1 g
F P
s
P
p
.002 w
.55406 .58479 m .55831 .57729 L .5901 .57209 L p
1 g
F P
s
P
p
.002 w
.59154 .55685 m .5901 .57209 L .55831 .57729 L p
1 g
F P
s
P
p
.002 w
.5901 .57209 m .59154 .55685 L .62115 .5405 L p
1 g
F P
s
P
p
.002 w
.55406 .58479 m .54662 .59128 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52423 .28507 m .45369 .29346 L .45053 .27175 L p
1 g
F P
s
P
p
.002 w
.50391 .59671 m .49562 .59221 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.42467 .54305 m .41959 .56589 L .38873 .55355 L p
1 g
F P
s
P
p
.002 w
.38873 .55355 m .39466 .52393 L .42467 .54305 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.4903 .58591 m .45702 .58895 L p
.48457 .57979 L 1 g
F P
s
P
p
.002 w
.48921 .58123 m .4903 .58591 L p
.48552 .5808 L 1 g
F P
s
P
p
.48457 .57979 m .48902 .58118 L .48552 .5808 L 1 g
F
P
p
.48902 .58118 m .48921 .58123 L .48552 .5808 L 1 g
F
P
p
.002 w
.49562 .59221 m .4903 .58591 L .51332 .58065 L p
1 g
F P
s
P
p
.002 w
.51332 .58065 m .52426 .57814 L .51954 .58046 L p
1 g
F P
s
P
p
.002 w
.51954 .58046 m .49562 .59221 L p
.51332 .58065 L 1 g
F P
s
P
p
.002 w
.51094 .5807 m .51079 .57862 L p
.49903 .58097 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57458 L p
1 g
F P
s
P
p
.48921 .57862 m .4683 .57458 L .46924 .57489 L 1 g
F
P
p
.45326 .57431 m .46424 .57324 L .4683 .57458 L 1 g
F
P
p
.002 w
.47529 .5769 m .47132 .57643 L p
.4683 .57458 L 1 g
F P
s
P
p
.002 w
.47132 .57643 m .45326 .57431 L p
.4683 .57458 L 1 g
F P
s
P
p
.002 w
.4683 .57458 m .46872 .57265 L p
.45841 .56853 L 1 g
F P
s
P
p
.48921 .57862 m .46924 .57489 L .47781 .57768 L 1 g
F
P
p
.46924 .57489 m .46827 .57471 L .47529 .5769 L 1 g
F
P
p
.46924 .57489 m .47529 .5769 L .47781 .57768 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.46424 .57324 m .49068 .57065 L .47529 .5769 L 1 g
F
P
p
.002 w
.45702 .58895 m .45326 .57431 L .47529 .5769 L p
1 g
F P
s
P
p
.002 w
.45326 .57431 m .41959 .56589 L p
.44752 .56062 L 1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.44752 .56062 m .45077 .56314 L .45326 .57431 L 1 g
F
P
p
.002 w
.45517 .56655 m .45477 .56818 L p
.45077 .56314 L 1 g
F P
s
P
p
.002 w
.45477 .56818 m .45326 .57431 L p
.45077 .56314 L 1 g
F P
s
P
p
.002 w
.45077 .56314 m .45146 .56129 L p
.44454 .55528 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45077 .56314 L p
1 g
F P
s
P
p
.002 w
.45326 .57431 m .45517 .56655 L p
.46585 .57308 L 1 g
F P
s
P
p
.46872 .57265 m .45077 .56314 L .457 .56797 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45707 .55882 m .49068 .57065 L p
.46585 .57308 L 1 g
F P
s
P
p
.002 w
.45517 .56655 m .45707 .55882 L p
.46585 .57308 L 1 g
F P
s
P
p
.457 .56797 m .45517 .56655 L .45002 .56518 L 1 g
F
P
p
.002 w
.45077 .56314 m .45056 .56372 L p
.45517 .56655 L 1 g
F P
s
P
p
.002 w
.45056 .56372 m .45002 .56518 L p
.45517 .56655 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43844 .54719 L p
1 g
F P
s
P
p
.45146 .56129 m .43844 .54719 L .43951 .54868 L 1 g
F
P
p
.42467 .54305 m .4357 .54334 L .43844 .54719 L 1 g
F
P
p
.002 w
.44124 .55112 m .43944 .55024 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.43944 .55024 m .42467 .54305 L p
.43844 .54719 L 1 g
F P
s
P
p
.002 w
.43844 .54719 m .43925 .54566 L p
.43553 .5383 L 1 g
F P
s
P
p
.45146 .56129 m .43951 .54868 L .44454 .55528 L 1 g
F
P
p
.43951 .54868 m .43831 .54742 L .44124 .55112 L 1 g
F
P
p
.43951 .54868 m .44124 .55112 L .44454 .55528 L 1 g
F
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.42467 .54305 m .39466 .52393 L p
.4308 .52189 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43256 .52866 L p
1 g
F P
s
P
p
.43925 .54566 m .43256 .52866 L .43291 .53004 L 1 g
F
P
p
.4308 .52189 m .43256 .52866 L .42467 .54305 L 1 g
F
P
p
.002 w
.43327 .53141 m .4323 .53272 L p
.43256 .52866 L 1 g
F P
s
P
p
.002 w
.4323 .53272 m .42467 .54305 L p
.43256 .52866 L 1 g
F P
s
P
p
.002 w
.43256 .52866 m .43346 .52734 L p
.43317 .51893 L 1 g
F P
s
P
p
.43925 .54566 m .43291 .53004 L .43553 .5383 L 1 g
F
P
p
.43291 .53004 m .43243 .52884 L .43327 .53141 L 1 g
F
P
p
.43291 .53004 m .43327 .53141 L .43553 .5383 L 1 g
F
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43402 .50924 L p
1 g
F P
s
P
p
.43346 .52734 m .43402 .50924 L .43372 .51194 L 1 g
F
P
p
.41486 .49556 m .43523 .49865 L .43402 .50924 L 1 g
F
P
p
.002 w
.43347 .51411 m .43225 .5129 L p
.43402 .50924 L 1 g
F P
s
P
p
.002 w
.43225 .5129 m .41486 .49556 L p
.43402 .50924 L 1 g
F P
s
P
p
.002 w
.43402 .50924 m .43485 .50826 L p
.43745 .50219 L 1 g
F P
s
P
p
.43346 .52734 m .43372 .51194 L .43317 .51893 L 1 g
F
P
p
.43372 .51194 m .43376 .50956 L .43347 .51411 L 1 g
F
P
p
.43372 .51194 m .43347 .51411 L .43317 .51893 L 1 g
F
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44283 .4911 L p
1 g
F P
s
P
p
.43523 .49865 m .43889 .4992 L .43402 .50924 L 1 g
F
P
p
.43485 .50826 m .44283 .4911 L .43745 .50219 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45305 .48122 m .4662 .50335 L p
.43505 .49862 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45773 .47666 L p
1 g
F P
s
P
p
.002 w
.49828 .49142 m .4662 .50335 L .45305 .48122 L p
1 g
F P
s
P
p
.45773 .47666 m .49828 .49142 L .45305 .48122 L 1 g
F
P
p
.002 w
.45773 .47666 m .45826 .47608 L p
.46578 .47278 L 1 g
F P
s
P
p
.45831 .4761 m .45864 .47622 L .45773 .47666 L 1 g
F
P
p
.45864 .47622 m .49828 .49142 L .45773 .47666 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.44755 .47197 m .48903 .45633 L .49026 .46099 L p
1 g
F P
s
P
p
.45864 .47622 m .47761 .46708 L .49828 .49142 L 1 g
F
P
p
.002 w
.49138 .46523 m .49828 .49142 L p
.47761 .46708 L 1 g
F P
s
P
p
.002 w
.53306 .4871 m .49828 .49142 L .49138 .46523 L p
1 g
F P
s
P
p
.49977 .46384 m .53306 .4871 L .49138 .46523 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48903 .45633 m .53412 .45077 L .53391 .45817 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50922 L p
1 g
F P
s
P
p
.56624 .4909 m .57051 .51896 L .56595 .50922 L 1 g
F
P
p
.002 w
.56222 .50123 m .56472 .49482 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.56472 .49482 m .56624 .4909 L p
.56595 .50922 L 1 g
F P
s
P
p
.002 w
.56595 .50922 m .56515 .50826 L p
.56677 .51879 L 1 g
F P
s
P
p
.55661 .4905 m .56595 .50922 L .56225 .50129 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56157 .54721 L p
1 g
F P
s
P
p
.002 w
.564 .54024 m .57236 .53113 L p
.57005 .53544 L 1 g
F P
s
P
p
.57005 .53544 m .55747 .55899 L .56157 .54721 L 1 g
F
P
p
.57005 .53544 m .56157 .54721 L .564 .54024 L 1 g
F
P
p
.002 w
.56157 .54721 m .56075 .54566 L p
.55444 .55711 L 1 g
F P
s
P
p
.56654 .52734 m .56157 .54721 L .564 .54024 L 1 g
F
P
p
.002 w
.56758 .52924 m .56767 .52927 L p
.564 .54024 L 1 g
F P
s
P
p
.002 w
.56767 .52927 m .57236 .53113 L .56791 .53598 L p
1 g
F P
s
P
p
.002 w
.56791 .53598 m .564 .54024 L p
.56767 .52927 L 1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56764 .52895 L p
1 g
F P
s
P
p
.56515 .50826 m .56764 .52895 L .56761 .52854 L 1 g
F
P
p
.002 w
.57236 .53113 m .56767 .52927 L p
.56764 .52895 L 1 g
F P
s
P
p
.5663 .51326 m .56927 .52204 L .56764 .52895 L 1 g
F
P
p
.56927 .52204 m .57236 .53113 L .56764 .52895 L 1 g
F
P
p
.002 w
.56257 .5491 m .56383 .54511 L p
.56654 .52734 L 1 g
F P
s
P
p
.002 w
.56764 .52895 m .56654 .52734 L p
.56383 .54511 L 1 g
F P
s
P
p
.56677 .51879 m .56766 .52897 L .56746 .52326 L 1 g
F
P
p
.56515 .50826 m .56761 .52854 L .56677 .51879 L 1 g
F
P
p
.56761 .52854 m .56766 .52897 L .56677 .51879 L 1 g
F
P
p
.56654 .52734 m .564 .54024 L .56442 .53893 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56767 .52927 m .5535 .52367 L p
.5663 .51326 L 1 g
F P
s
P
p
.002 w
.56383 .54511 m .56854 .53025 L .56764 .52895 L p
1 g
F P
s
P
p
.002 w
.55668 .48981 m .56624 .4909 L .5637 .49744 L p
1 g
F P
s
P
p
.002 w
.5637 .49744 m .56222 .50123 L p
.55746 .4914 L 1 g
F P
s
P
p
.55668 .48981 m .5637 .49744 L .55746 .4914 L 1 g
F
P
p
.002 w
.55746 .4914 m .55661 .4905 L p
.56227 .50132 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55746 .4914 L p
1 g
F P
s
P
p
.54174 .47608 m .55746 .4914 L .55659 .49057 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.53306 .4871 m .55569 .48969 L p
.5535 .52367 L 1 g
F P
s
P
p
.55569 .48969 m .55661 .49058 L .5535 .52367 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55746 .4914 L p
1 g
F P
s
P
p
.56227 .50132 m .56713 .51061 L .55746 .4914 L 1 g
F
P
p
.54174 .47608 m .55659 .49057 L .5493 .48348 L 1 g
F
P
p
.55659 .49057 m .55754 .49148 L .55569 .48969 L 1 g
F
P
p
.55659 .49057 m .55569 .48969 L .5493 .48348 L 1 g
F
P
p
.002 w
.56222 .50123 m .5535 .52367 L p
.55661 .49058 L 1 g
F P
s
P
p
.55668 .48981 m .55746 .4914 L .55661 .49058 L 1 g
F
P
p
.55746 .4914 m .56222 .50123 L .55661 .49058 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55569 .48969 m .55668 .48981 L p
.55661 .49058 L 1 g
F P
s
P
p
.002 w
.55569 .48969 m .53306 .4871 L p
.54422 .47855 L 1 g
F P
s
P
p
.002 w
.55754 .49148 m .55834 .49233 L p
.55143 .48557 L 1 g
F P
s
P
p
.5493 .48348 m .55569 .48969 L .55143 .48557 L 1 g
F
P
p
.55569 .48969 m .55754 .49148 L .55143 .48557 L 1 g
F
P
p
.002 w
.55746 .4914 m .55754 .49148 L p
.55659 .49057 L 1 g
F P
s
P
p
.002 w
.5535 .52367 m .56222 .50123 L p
.5663 .51326 L 1 g
F P
s
P
p
.002 w
.56764 .52895 m .56766 .52897 L p
.56761 .52854 L 1 g
F P
s
P
p
.002 w
.56766 .52897 m .56854 .53025 L p
.56746 .52326 L 1 g
F P
s
P
p
.56442 .53893 m .564 .54024 L .56439 .53911 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.5535 .52367 m .56758 .52924 L p
.54887 .55673 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.564 .54024 m .54887 .55673 L p
.56758 .52924 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .5493 .56333 L p
1 g
F P
s
P
p
.002 w
.55562 .56244 m .54554 .56749 L p
.5493 .56333 L 1 g
F P
s
P
p
.002 w
.5525 .5598 m .55346 .56062 L p
.5493 .56333 L 1 g
F P
s
P
p
.002 w
.55346 .56062 m .55562 .56244 L p
.5493 .56333 L 1 g
F P
s
P
p
.002 w
.5493 .56333 m .54854 .56129 L p
.54009 .56935 L 1 g
F P
s
P
p
.56075 .54566 m .5493 .56333 L .55113 .56131 L 1 g
F
P
p
.56075 .54566 m .54952 .56393 L .55444 .55711 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53174 .57478 L p
1 g
F P
s
P
p
.002 w
.55887 .56956 m .52797 .57722 L p
.53064 .57549 L 1 g
F P
s
P
p
.54854 .56129 m .53174 .57478 L .53433 .5731 L 1 g
F
P
p
.002 w
.54554 .56749 m .53433 .5731 L p
.5493 .56333 L 1 g
F P
s
P
p
.54009 .56935 m .53433 .5731 L .54 .56943 L 1 g
F
P
p
.54854 .56129 m .53433 .5731 L .54009 .56935 L 1 g
F
P
p
.53128 .57265 m .51947 .57871 L .53154 .57486 L 1 g
F
P
p
.002 w
.53174 .57478 m .53128 .57265 L p
.53154 .57486 L 1 g
F P
s
P
p
.002 w
.55696 .56539 m .55887 .56956 L p
.52877 .57589 L 1 g
F P
s
P
p
.51947 .57871 m .5218 .57817 L .53175 .57479 L 1 g
F
P
p
.002 w
.52303 .57787 m .52426 .57814 L .5218 .57817 L p
1 g
F P
s
P
p
.5218 .57817 m .5226 .57798 L .52266 .57796 L 1 g
F
P
p
.5218 .57817 m .52266 .57796 L .53175 .57479 L 1 g
F
P
p
.5226 .57798 m .52312 .57785 L .53175 .57479 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52426 .57814 m .51332 .58065 L p
.51177 .58051 L 1 g
F P
s
P
p
.002 w
.5218 .57817 m .52426 .57814 L p
.51177 .58051 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .5807 L p
1 g
F P
s
P
p
.002 w
.51332 .58065 m .4903 .58591 L .49021 .58554 L p
1 g
F P
s
P
p
.49021 .58554 m .51094 .5807 L .51332 .58065 L 1 g
F
P
p
.53128 .57265 m .51094 .5807 L .51947 .57871 L 1 g
F
P
p
.002 w
.48902 .58118 m .48921 .57862 L p
.47781 .57768 L 1 g
F P
s
P
p
.002 w
.49021 .58554 m .4892 .58119 L p
.51094 .5807 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48902 .58118 L p
1 g
F P
s
P
p
.002 w
.4892 .58119 m .48921 .58123 L p
.48902 .58118 L 1 g
F P
s
P
p
.002 w
.48902 .58118 m .48889 .583 L p
.4949 .5818 L 1 g
F P
s
P
p
.51079 .57862 m .48902 .58118 L .4949 .5818 L 1 g
F
P
p
.002 w
.48857 .57846 m .4892 .58119 L p
.48457 .57979 L 1 g
F P
s
P
p
.48457 .57979 m .4892 .58119 L .48902 .58118 L 1 g
F
P
p
.002 w
.4892 .58119 m .48857 .57846 L p
.51332 .58065 L 1 g
F P
s
P
p
.002 w
.51094 .5807 m .51111 .583 L p
.51947 .57871 L 1 g
F P
s
P
p
.002 w
.48857 .57846 m .49068 .57065 L .52303 .57787 L p
1 g
F P
s
P
p
.002 w
.5218 .57817 m .48857 .57846 L p
.52303 .57787 L 1 g
F P
s
P
p
.52303 .57788 m .52344 .57776 L .53175 .57479 L 1 g
F
P
p
.52331 .57781 m .52371 .57769 L .53175 .57479 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.49068 .57065 m .49645 .56334 L .52351 .57775 L p
1 g
F P
s
P
p
.002 w
.52351 .57775 m .52426 .57814 L .52303 .57787 L p
1 g
F P
s
P
p
.002 w
.52303 .57787 m .49068 .57065 L p
.52351 .57775 L 1 g
F P
s
P
p
.5226 .57798 m .52303 .57788 L .52312 .57785 L 1 g
F
P
p
.52303 .57788 m .52331 .57781 L .52344 .57776 L 1 g
F
P
p
.52352 .57777 m .524 .57761 L .53175 .57479 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.49645 .56334 m .50529 .55737 L .52382 .57766 L p
1 g
F P
s
P
p
.002 w
.52382 .57766 m .52426 .57814 L .52351 .57775 L p
1 g
F P
s
P
p
.002 w
.52351 .57775 m .49645 .56334 L p
.52382 .57766 L 1 g
F P
s
P
p
.52368 .57773 m .52442 .57747 L .53175 .57479 L 1 g
F
P
p
.002 w
.50529 .55737 m .51622 .55341 L .52408 .57758 L p
1 g
F P
s
P
p
.002 w
.52408 .57758 m .52426 .57814 L .52382 .57766 L p
1 g
F P
s
P
p
.002 w
.52382 .57766 m .50529 .55737 L p
.52408 .57758 L 1 g
F P
s
P
p
.52331 .57781 m .52352 .57777 L .52371 .57769 L 1 g
F
P
p
.52352 .57777 m .52368 .57773 L .524 .57761 L 1 g
F
P
p
.002 w
.51622 .55341 m .52801 .55192 L .52435 .5775 L p
1 g
F P
s
P
p
.002 w
.52435 .5775 m .52426 .57814 L .52408 .57758 L p
1 g
F P
s
P
p
.002 w
.52408 .57758 m .51622 .55341 L p
.52435 .5775 L 1 g
F P
s
P
p
.52383 .57769 m .52545 .57711 L .53175 .57479 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.52801 .55192 m .53931 .55308 L .52473 .57737 L p
1 g
F P
s
P
p
.002 w
.52473 .57737 m .52426 .57814 L .52435 .5775 L p
1 g
F P
s
P
p
.002 w
.52435 .5775 m .52801 .55192 L p
.52473 .57737 L 1 g
F P
s
P
p
.52368 .57773 m .52383 .57769 L .52442 .57747 L 1 g
F
P
p
.52383 .57769 m .52396 .57766 L .52545 .57711 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53931 .55308 m .54887 .55673 L .52545 .57711 L p
1 g
F P
s
P
p
.002 w
.52545 .57711 m .52426 .57814 L .52473 .57737 L p
1 g
F P
s
P
p
.002 w
.52473 .57737 m .53931 .55308 L p
.52545 .57711 L 1 g
F P
s
P
p
.5525 .5598 m .5493 .56333 L .52877 .57589 L 1 g
F
P
p
.002 w
.53433 .5731 m .52877 .57589 L p
.5493 .56333 L 1 g
F P
s
P
p
.002 w
.55562 .56244 m .55696 .56539 L p
.53174 .57478 L 1 g
F P
s
P
p
.002 w
.52877 .57589 m .53433 .5731 L p
.53174 .57478 L 1 g
F P
s
P
p
.002 w
.53433 .5731 m .55562 .56244 L p
.53174 .57478 L 1 g
F P
s
P
p
.002 w
.55887 .56956 m .55831 .57729 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54932 .56339 L p
1 g
F P
s
P
p
.002 w
.54932 .56339 m .5493 .56333 L p
.54883 .56371 L 1 g
F P
s
P
p
.54883 .56371 m .5322 .57686 L .54932 .56339 L 1 g
F
P
p
.002 w
.53174 .57478 m .5322 .57686 L p
.54 .56943 L 1 g
F P
s
P
p
.002 w
.52426 .57814 m .52877 .57589 L p
.53064 .57549 L 1 g
F P
s
P
p
.002 w
.52797 .57722 m .52426 .57814 L p
.53064 .57549 L 1 g
F P
s
P
p
.002 w
.53175 .57479 m .53174 .57478 L p
.53154 .57486 L 1 g
F P
s
P
p
.51947 .57871 m .51526 .58087 L .52396 .57766 L 1 g
F
P
p
.002 w
.48857 .57846 m .5218 .57817 L p
.51177 .58051 L 1 g
F P
s
P
p
.002 w
.52877 .57589 m .52426 .57814 L p
.52638 .57677 L 1 g
F P
s
P
p
.5525 .5598 m .52877 .57589 L .52638 .57677 L 1 g
F
P
p
.002 w
.52426 .57814 m .54887 .55673 L .5525 .5598 L p
1 g
F P
s
P
p
.002 w
.55831 .57729 m .55406 .58479 L .52426 .57814 L closepath p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53175 .57479 L p
1 g
F P
s
P
p
.51526 .58087 m .51111 .583 L .53175 .57479 L 1 g
F
P
p
.54009 .56935 m .5322 .57686 L .5493 .56333 L 1 g
F
P
p
.002 w
.5493 .56333 m .54952 .56393 L p
.55113 .56131 L 1 g
F P
s
P
p
.002 w
.54887 .55673 m .564 .54024 L p
.56115 .5478 L 1 g
F P
s
P
p
.002 w
.55562 .56244 m .5525 .5598 L p
.56115 .5478 L 1 g
F P
s
P
p
.002 w
.5525 .5598 m .54887 .55673 L p
.56115 .5478 L 1 g
F P
s
P
p
.002 w
.54952 .56393 m .54998 .56518 L p
.55444 .55711 L 1 g
F P
s
P
p
.55747 .55899 m .55562 .56244 L .564 .54024 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56157 .54721 L p
1 g
F P
s
P
p
.55444 .55711 m .54998 .56518 L .56157 .54721 L 1 g
F
P
p
.002 w
.56157 .54721 m .56257 .5491 L p
.56439 .53911 L 1 g
F P
s
P
p
.57051 .51896 m .57236 .53113 L .56222 .50123 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50922 L p
1 g
F P
s
P
p
.56677 .51879 m .56854 .53025 L .56595 .50922 L 1 g
F
P
p
.002 w
.56595 .50922 m .56713 .51061 L p
.56225 .50129 L 1 g
F P
s
P
p
.002 w
.53306 .4871 m .53349 .47253 L p
.54422 .47855 L 1 g
F P
s
P
p
.002 w
.54223 .47661 m .54174 .47608 L p
.5493 .48348 L 1 g
F P
s
P
p
.56233 .48601 m .56624 .4909 L .53349 .47253 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54223 .47661 L p
1 g
F P
s
P
p
.5493 .48348 m .55834 .49233 L .54223 .47661 L 1 g
F
P
p
.53412 .45077 m .56233 .48601 L .54223 .47661 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54223 .47661 L p
1 g
F P
s
P
p
.52214 .46667 m .54223 .47661 L .53662 .47399 L 1 g
F
P
p
.52214 .46667 m .54259 .47701 L .53286 .47222 L 1 g
F
P
p
.002 w
.53349 .47253 m .53361 .46824 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.53361 .46824 m .53412 .45077 L p
.54223 .47661 L 1 g
F P
s
P
p
.002 w
.56624 .4909 m .55569 .48969 L p
.54422 .47855 L 1 g
F P
s
P
p
.002 w
.54223 .47661 m .54259 .47701 L p
.53662 .47399 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.53349 .47253 m .53306 .4871 L p
.51531 .46603 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46705 L p
1 g
F P
s
P
p
.5 .4634 m .52237 .46705 L .50852 .46504 L 1 g
F
P
p
.51179 .46184 m .52237 .46705 L .51531 .46603 L 1 g
F
P
p
.52237 .46705 m .53349 .47253 L .51531 .46603 L 1 g
F
P
p
.49977 .46384 m .5 .4638 L .53306 .4871 L 1 g
F
P
p
.002 w
.5 .4638 m .5 .4634 L p
.50852 .46504 L 1 g
F P
s
P
p
.5 .4638 m .51179 .46184 L .51531 .46603 L 1 g
F
P
p
.5 .4638 m .51531 .46603 L .53306 .4871 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4638 L p
1 g
F P
s
P
p
.50852 .46504 m .52282 .46778 L .5 .4638 L 1 g
F
P
p
.002 w
.52237 .46705 m .52282 .46778 L p
.50852 .46504 L 1 g
F P
s
P
p
.002 w
.54259 .47701 m .54302 .47747 L p
.53286 .47222 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.53391 .45817 m .53349 .47253 L p
.51179 .46184 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .4638 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .4638 L .4944 .46473 L 1 g
F
P
p
.48903 .45633 m .53391 .45817 L .49977 .46384 L 1 g
F
P
p
.002 w
.5 .4638 m .5 .46407 L p
.4944 .46473 L 1 g
F P
s
P
p
.002 w
.5 .46407 m .5 .46442 L p
.48941 .46549 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46407 L .48941 .46549 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47761 .46708 L p
1 g
F P
s
P
p
.45826 .47608 m .47761 .46708 L .46578 .47278 L 1 g
F
P
p
.44755 .47197 m .45448 .47019 L .45864 .47622 L 1 g
F
P
p
.002 w
.47761 .46708 m .47786 .46667 L p
.48941 .46549 L 1 g
F P
s
P
p
.45448 .47019 m .49026 .46099 L .47761 .46708 L 1 g
F
P
p
.45448 .47019 m .47761 .46708 L .45864 .47622 L 1 g
F
P
p
.002 w
.49138 .46523 m .48903 .45633 L p
.49977 .46384 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47732 .46757 L p
1 g
F P
s
P
p
.002 w
.47732 .46757 m .47761 .46708 L p
.48686 .46598 L 1 g
F P
s
P
p
.48686 .46598 m .5 .46442 L .47732 .46757 L 1 g
F
P
p
.48941 .46549 m .5 .46442 L .47761 .46708 L 1 g
F
P
p
.002 w
.49026 .46099 m .49138 .46523 L p
.47761 .46708 L 1 g
F P
s
P
p
.002 w
.47761 .46708 m .47718 .46778 L p
.46578 .47278 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45773 .47666 L p
1 g
F P
s
P
p
.46578 .47278 m .47718 .46778 L .45773 .47666 L 1 g
F
P
p
.002 w
.45773 .47666 m .45698 .47747 L p
.45122 .483 L 1 g
F P
s
P
p
.44339 .4905 m .45773 .47666 L .45122 .483 L 1 g
F
P
p
.002 w
.45305 .48122 m .44755 .47197 L p
.45831 .4761 L 1 g
F P
s
P
p
.002 w
.41486 .49556 m .44755 .47197 L .45305 .48122 L p
1 g
F P
s
P
p
.002 w
.44283 .4911 m .44339 .4905 L p
.44969 .48446 L 1 g
F P
s
P
p
.41486 .49556 m .45305 .48122 L .43505 .49862 L 1 g
F
P
p
.002 w
.44283 .4911 m .44166 .49233 L p
.43745 .50219 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44283 .4911 L p
1 g
F P
s
P
p
.44969 .48446 m .45698 .47747 L .44283 .4911 L 1 g
F
P
p
.43402 .50924 m .4662 .50335 L .43347 .51411 L 1 g
F
P
p
.43889 .4992 m .4662 .50335 L .43402 .50924 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43402 .50924 L p
1 g
F P
s
P
p
.43745 .50219 m .44166 .49233 L .43402 .50924 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.4662 .50335 m .44071 .52133 L .43347 .51411 L p
1 g
F P
s
P
p
.002 w
.43402 .50924 m .43376 .50956 L p
.43372 .51194 L 1 g
F P
s
P
p
.002 w
.39466 .52393 m .41486 .49556 L .44071 .52133 L p
1 g
F P
s
P
p
.002 w
.43376 .50956 m .43287 .51061 L p
.43317 .51893 L 1 g
F P
s
P
p
.002 w
.44071 .52133 m .43327 .53141 L p
.43256 .52866 L 1 g
F P
s
P
p
.4308 .52189 m .43299 .52176 L .43256 .52866 L 1 g
F
P
p
.43299 .52176 m .44071 .52133 L .43256 .52866 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43256 .52866 L p
1 g
F P
s
P
p
.43317 .51893 m .43287 .51061 L .43256 .52866 L 1 g
F
P
p
.002 w
.43256 .52866 m .43243 .52884 L p
.43291 .53004 L 1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.42467 .54305 m .44071 .52133 L .46825 .5442 L p
1 g
F P
s
P
p
.002 w
.43243 .52884 m .43146 .53025 L p
.43553 .5383 L 1 g
F P
s
P
p
.43844 .54719 m .46825 .5442 L .44124 .55112 L 1 g
F
P
p
.4357 .54334 m .43719 .54338 L .43844 .54719 L 1 g
F
P
p
.43719 .54338 m .46825 .5442 L .43844 .54719 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43844 .54719 L p
1 g
F P
s
P
p
.43553 .5383 m .43146 .53025 L .43844 .54719 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46825 .5442 m .45707 .55882 L .44124 .55112 L p
1 g
F P
s
P
p
.002 w
.43844 .54719 m .43831 .54742 L p
.43951 .54868 L 1 g
F P
s
P
p
.002 w
.41959 .56589 m .42467 .54305 L .45707 .55882 L p
1 g
F P
s
P
p
.002 w
.43831 .54742 m .43743 .5491 L p
.44454 .55528 L 1 g
F P
s
P
p
.002 w
.45707 .55882 m .45517 .56655 L p
.45077 .56314 L 1 g
F P
s
P
p
.44752 .56062 m .44861 .56042 L .45077 .56314 L 1 g
F
P
p
.44861 .56042 m .45707 .55882 L .45077 .56314 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45077 .56314 L p
1 g
F P
s
P
p
.44454 .55528 m .43743 .5491 L .45077 .56314 L 1 g
F
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4679 .57641 L p
1 g
F P
s
P
p
.002 w
.4679 .57641 m .4683 .57458 L p
.46008 .57036 L 1 g
F P
s
P
p
.46008 .57036 m .45002 .56518 L .4679 .57641 L 1 g
F
P
p
.45841 .56853 m .45002 .56518 L .4683 .57458 L 1 g
F
P
p
.002 w
.49068 .57065 m .48857 .57846 L .47529 .5769 L p
1 g
F P
s
P
p
.002 w
.4683 .57458 m .46827 .57471 L p
.46924 .57489 L 1 g
F P
s
P
p
.45702 .58895 m .47529 .5769 L .48457 .57979 L 1 g
F
P
p
.002 w
.46827 .57471 m .4678 .57686 L p
.47781 .57768 L 1 g
F P
s
P
p
.002 w
.47529 .5769 m .48857 .57846 L p
.48457 .57979 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51094 .5807 L p
.49849 .58108 L 1 g
F P
s
P
p
.49903 .58097 m .49849 .58108 L .51094 .5807 L 1 g
F
P
p
.002 w
.51111 .583 m .51095 .58071 L p
.4949 .5818 L 1 g
F P
s
P
p
.49849 .58108 m .4949 .5818 L .51095 .58071 L 1 g
F
P
p
.002 w
.48889 .583 m .50623 .583 L p
.4949 .5818 L 1 g
F P
s
P
p
.002 w
.50623 .583 m .51111 .583 L p
.4949 .5818 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48902 .58118 L p
1 g
F P
s
P
p
.47781 .57768 m .4678 .57686 L .48902 .58118 L 1 g
F
P
p
.002 w
.61273 .51948 m .62115 .5405 L .59154 .55685 L p
1 g
F P
s
P
p
.002 w
.62115 .5405 m .61273 .51948 L .63642 .49376 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52423 .28507 m .59114 .2952 L .59399 .32142 L p
1 g
F P
s
P
p
.002 w
.3917 .46785 m .3681 .50217 L .34588 .47859 L p
1 g
F P
s
P
p
.002 w
.34588 .47859 m .37206 .43926 L .3917 .46785 L p
1 g
F P
s
P
p
.002 w
.40366 .37469 m .3566 .41087 L .34577 .38368 L p
1 g
F P
s
P
p
.002 w
.34577 .38368 m .39481 .34533 L .40366 .37469 L p
1 g
F P
s
P
p
.002 w
.62759 .43877 m .65575 .46647 L .63642 .49376 L p
1 g
F P
s
P
p
.002 w
.65575 .46647 m .62759 .43877 L .63867 .40661 L p
1 g
F P
s
P
p
.002 w
.55831 .57729 m .55887 .56956 L .59154 .55685 L p
1 g
F P
s
P
p
.002 w
.45837 .32007 m .39481 .34533 L .38933 .31929 L p
1 g
F P
s
P
p
.002 w
.38933 .31929 m .45369 .29346 L .45837 .32007 L p
1 g
F P
s
P
p
.002 w
.58547 .54265 m .59154 .55685 L .55887 .56956 L p
1 g
F P
s
P
p
.002 w
.59154 .55685 m .58547 .54265 L .61273 .51948 L p
1 g
F P
s
P
p
.002 w
.59404 .35169 m .6454 .37574 L .63867 .40661 L p
1 g
F P
s
P
p
.002 w
.6454 .37574 m .59404 .35169 L .59399 .32142 L p
1 g
F P
s
P
p
.002 w
.55887 .56956 m .55562 .56244 L .58547 .54265 L p
1 g
F P
s
P
p
.002 w
.61247 .47103 m .63642 .49376 L .61273 .51948 L p
1 g
F P
s
P
p
.002 w
.63642 .49376 m .61247 .47103 L .62759 .43877 L p
1 g
F P
s
P
p
.002 w
.41486 .49556 m .39466 .52393 L .3681 .50217 L p
1 g
F P
s
P
p
.002 w
.3681 .50217 m .3917 .46785 L .41486 .49556 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.59399 .32142 m .52799 .31174 L .52423 .28507 L p
1 g
F P
s
P
p
.002 w
.45369 .29346 m .52423 .28507 L .52799 .31174 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41569 .40638 m .37206 .43926 L .3566 .41087 L p
1 g
F P
s
P
p
.002 w
.3566 .41087 m .40366 .37469 L .41569 .40638 L p
1 g
F P
s
P
p
.002 w
.52799 .31174 m .45837 .32007 L .45369 .29346 L p
1 g
F P
s
P
p
.002 w
.52799 .31174 m .59399 .32142 L .59404 .35169 L p
1 g
F P
s
P
p
.002 w
.59383 .50221 m .61273 .51948 L .58547 .54265 L p
1 g
F P
s
P
p
.002 w
.61273 .51948 m .59383 .50221 L .61247 .47103 L p
1 g
F P
s
P
p
.002 w
.57236 .53113 m .58547 .54265 L .55562 .56244 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.58547 .54265 m .57236 .53113 L .59383 .50221 L p
1 g
F P
s
P
p
.002 w
.59118 .38501 m .63867 .40661 L .62759 .43877 L p
1 g
F P
s
P
p
.002 w
.63867 .40661 m .59118 .38501 L .59404 .35169 L p
1 g
F P
s
P
p
.002 w
.49645 .56334 m .49068 .57065 L .45707 .55882 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46447 .3508 m .40366 .37469 L .39481 .34533 L p
1 g
F P
s
P
p
.002 w
.39481 .34533 m .45837 .32007 L .46447 .3508 L p
1 g
F P
s
P
p
.002 w
.54887 .55673 m .53931 .55308 L .5535 .52367 L p
1 g
F P
s
P
p
.002 w
.45707 .55882 m .46825 .5442 L .49645 .56334 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50529 .55737 m .49645 .56334 L .46825 .5442 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.53931 .55308 m .52801 .55192 L .53099 .52123 L p
1 g
F P
s
P
p
.002 w
.53099 .52123 m .5535 .52367 L .53931 .55308 L p
1 g
F P
s
P
p
.002 w
.4305 .43922 m .3917 .46785 L .37206 .43926 L p
1 g
F P
s
P
p
.002 w
.37206 .43926 m .41569 .40638 L .4305 .43922 L p
1 g
F P
s
P
p
.002 w
.58546 .42022 m .62759 .43877 L .61247 .47103 L p
1 g
F P
s
P
p
.002 w
.62759 .43877 m .58546 .42022 L .59118 .38501 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.51622 .55341 m .50529 .55737 L .4857 .53216 L p
1 g
F P
s
P
p
.002 w
.46825 .5442 m .4857 .53216 L .50529 .55737 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.52801 .55192 m .51622 .55341 L .50746 .52418 L p
1 g
F P
s
P
p
.002 w
.50746 .52418 m .53099 .52123 L .52801 .55192 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4857 .53216 m .50746 .52418 L .51622 .55341 L p
1 g
F P
s
P
p
.002 w
.56624 .4909 m .59383 .50221 L .57236 .53113 L p
1 g
F P
s
P
p
.002 w
.53097 .3428 m .59404 .35169 L .59118 .38501 L p
1 g
F P
s
P
p
.002 w
.59404 .35169 m .53097 .3428 L .52799 .31174 L p
1 g
F P
s
P
p
.002 w
.45837 .32007 m .52799 .31174 L .53097 .3428 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57704 .45597 m .61247 .47103 L .59383 .50221 L p
1 g
F P
s
P
p
.002 w
.61247 .47103 m .57704 .45597 L .58546 .42022 L p
1 g
F P
s
P
p
.002 w
.59383 .50221 m .56624 .4909 L .57704 .45597 L p
1 g
F P
s
P
p
.002 w
.4857 .53216 m .46825 .5442 L .44071 .52133 L p
1 g
F P
s
P
p
.002 w
.53097 .3428 m .46447 .3508 L .45837 .32007 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.44755 .47197 m .41486 .49556 L .3917 .46785 L p
1 g
F P
s
P
p
.002 w
.3917 .46785 m .4305 .43922 L .44755 .47197 L p
1 g
F P
s
P
p
.002 w
.4718 .38462 m .41569 .40638 L .40366 .37469 L p
1 g
F P
s
P
p
.002 w
.40366 .37469 m .46447 .3508 L .4718 .38462 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.44071 .52133 m .4662 .50335 L .4857 .53216 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.5535 .52367 m .53099 .52123 L .53306 .4871 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50746 .52418 m .4857 .53216 L .4662 .50335 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53305 .37719 m .59118 .38501 L .58546 .42022 L p
1 g
F P
s
P
p
.002 w
.59118 .38501 m .53305 .37719 L .53097 .3428 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.53099 .52123 m .50746 .52418 L .49828 .49142 L p
1 g
F P
s
P
p
.002 w
.49828 .49142 m .53306 .4871 L .53099 .52123 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.4662 .50335 m .49828 .49142 L .50746 .52418 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.46447 .3508 m .53097 .3428 L .53305 .37719 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.53412 .45077 m .57704 .45597 L .56624 .4909 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.48009 .42026 m .4305 .43922 L .41569 .40638 L p
1 g
F P
s
P
p
.002 w
.41569 .40638 m .4718 .38462 L .48009 .42026 L p
1 g
F P
s
P
p
.002 w
.53305 .37719 m .4718 .38462 L .46447 .3508 L p
1 g
F P
s
P
p
.002 w
.53412 .41365 m .58546 .42022 L .57704 .45597 L p
1 g
F P
s
P
p
.002 w
.58546 .42022 m .53412 .41365 L .53305 .37719 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.004 w
.53241 .62771 m
.53413 .63822 L
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57704 .45597 m .53412 .45077 L .53412 .41365 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.48903 .45633 m .44755 .47197 L .4305 .43922 L p
1 g
F P
s
P
p
.002 w
.4305 .43922 m .48009 .42026 L .48903 .45633 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.4718 .38462 m .53305 .37719 L .53412 .41365 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53412 .41365 m .48009 .42026 L .4718 .38462 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.53412 .45077 m .48903 .45633 L .48009 .42026 L p
1 g
F P
s
P
p
.002 w
.48009 .42026 m .53412 .41365 L .53412 .45077 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .7755 .53306 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .53841 .66422 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.645736)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.645736)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.44806 .45795 m .49466 .46756 L .49711 .43926 L p
1 g
F P
s
P
p
.002 w
.49711 .43926 m .45629 .43074 L .44806 .45795 L p
1 g
F P
s
P
p
.002 w
.53887 .438 m .49711 .43926 L .49466 .46756 L p
1 g
F P
s
P
p
.002 w
.45629 .43074 m .49711 .43926 L .49962 .41081 L p
1 g
F P
s
P
p
.002 w
.49711 .43926 m .53887 .438 L .53449 .40969 L p
1 g
F P
s
P
p
.002 w
.53449 .40969 m .49962 .41081 L .49711 .43926 L p
1 g
F P
s
P
p
.002 w
.49962 .41081 m .46555 .40361 L .45629 .43074 L p
1 g
F P
s
P
p
.002 w
.46555 .40361 m .49962 .41081 L .50215 .38271 L p
1 g
F P
s
P
p
.002 w
.49962 .41081 m .53449 .40969 L .52927 .38178 L p
1 g
F P
s
P
p
.002 w
.52927 .38178 m .50215 .38271 L .49962 .41081 L p
1 g
F P
s
P
p
.002 w
.44102 .48474 m .49233 .49519 L .49466 .46756 L p
1 g
F P
s
P
p
.002 w
.49466 .46756 m .44806 .45795 L .44102 .48474 L p
1 g
F P
s
P
p
.002 w
.54231 .46621 m .49466 .46756 L .49233 .49519 L p
1 g
F P
s
P
p
.002 w
.49466 .46756 m .54231 .46621 L .53887 .438 L p
1 g
F P
s
P
p
.002 w
.5778 .42699 m .53887 .438 L .54231 .46621 L p
1 g
F P
s
P
p
.002 w
.53887 .438 m .5778 .42699 L .56692 .40029 L p
1 g
F P
s
P
p
.002 w
.56692 .40029 m .53449 .40969 L .53887 .438 L p
1 g
F P
s
P
p
.002 w
.53449 .40969 m .56692 .40029 L .5544 .37432 L p
1 g
F P
s
P
p
.002 w
.5544 .37432 m .52927 .38178 L .53449 .40969 L p
1 g
F P
s
P
p
.002 w
.42011 .41311 m .45629 .43074 L .46555 .40361 L p
1 g
F P
s
P
p
.002 w
.46555 .40361 m .43547 .38869 L .42011 .41311 L p
1 g
F P
s
P
p
.002 w
.43547 .38869 m .46555 .40361 L .47568 .37705 L p
1 g
F P
s
P
p
.002 w
.50215 .38271 m .47568 .37705 L .46555 .40361 L p
1 g
F P
s
P
p
.002 w
.40661 .4381 m .44806 .45795 L .45629 .43074 L p
1 g
F P
s
P
p
.002 w
.45629 .43074 m .42011 .41311 L .40661 .4381 L p
1 g
F P
s
P
p
.002 w
.47568 .37705 m .50215 .38271 L .50466 .35548 L p
1 g
F P
s
P
p
.002 w
.50215 .38271 m .52927 .38178 L .52328 .35481 L p
1 g
F P
s
P
p
.002 w
.52328 .35481 m .50466 .35548 L .50215 .38271 L p
1 g
F P
s
P
p
.002 w
.49233 .49519 m .54476 .49381 L .54231 .46621 L p
1 g
F P
s
P
p
.002 w
.58684 .45392 m .54231 .46621 L .54476 .49381 L p
1 g
F P
s
P
p
.002 w
.54231 .46621 m .58684 .45392 L .5778 .42699 L p
1 g
F P
s
P
p
.002 w
.52927 .38178 m .5544 .37432 L .54047 .34958 L p
1 g
F P
s
P
p
.002 w
.54047 .34958 m .52328 .35481 L .52927 .38178 L p
1 g
F P
s
P
p
.002 w
.47568 .37705 m .4524 .3653 L .43547 .38869 L p
1 g
F P
s
P
p
.002 w
.4524 .3653 m .47568 .37705 L .48649 .35155 L p
1 g
F P
s
P
p
.002 w
.50466 .35548 m .48649 .35155 L .47568 .37705 L p
1 g
F P
s
P
p
.002 w
.39527 .4632 m .44102 .48474 L .44806 .45795 L p
1 g
F P
s
P
p
.002 w
.44806 .45795 m .40661 .4381 L .39527 .4632 L p
1 g
F P
s
P
p
.002 w
.43533 .5106 m .49014 .52164 L .49233 .49519 L p
1 g
F P
s
P
p
.002 w
.49233 .49519 m .44102 .48474 L .43533 .5106 L p
1 g
F P
s
P
p
.002 w
.54476 .49381 m .49233 .49519 L .49014 .52164 L p
1 g
F P
s
P
p
.002 w
.59374 .38333 m .56692 .40029 L .5778 .42699 L p
1 g
F P
s
P
p
.002 w
.56692 .40029 m .59374 .38333 L .57504 .36095 L p
1 g
F P
s
P
p
.002 w
.57504 .36095 m .5544 .37432 L .56692 .40029 L p
1 g
F P
s
P
p
.002 w
.48649 .35155 m .50466 .35548 L .50709 .32963 L p
1 g
F P
s
P
p
.002 w
.50466 .35548 m .52328 .35481 L .51662 .32927 L p
1 g
F P
s
P
p
.002 w
.51662 .32927 m .50709 .32963 L .50466 .35548 L p
1 g
F P
s
P
p
.002 w
.39208 .38774 m .42011 .41311 L .43547 .38869 L p
1 g
F P
s
P
p
.002 w
.43547 .38869 m .41236 .3673 L .39208 .38774 L p
1 g
F P
s
P
p
.002 w
.41236 .3673 m .43547 .38869 L .4524 .3653 L p
1 g
F P
s
P
p
.002 w
.49014 .52164 m .54614 .52027 L .54476 .49381 L p
1 g
F P
s
P
p
.002 w
.59384 .48059 m .54476 .49381 L .54614 .52027 L p
1 g
F P
s
P
p
.002 w
.54476 .49381 m .59384 .48059 L .58684 .45392 L p
1 g
F P
s
P
p
.002 w
.61021 .40698 m .5778 .42699 L .58684 .45392 L p
1 g
F P
s
P
p
.002 w
.5778 .42699 m .61021 .40698 L .59374 .38333 L p
1 g
F P
s
P
p
.002 w
.5544 .37432 m .57504 .36095 L .55448 .34029 L p
1 g
F P
s
P
p
.002 w
.55448 .34029 m .54047 .34958 L .5544 .37432 L p
1 g
F P
s
P
p
.002 w
.52328 .35481 m .54047 .34958 L .52539 .32655 L p
1 g
F P
s
P
p
.002 w
.52539 .32655 m .51662 .32927 L .52328 .35481 L p
1 g
F P
s
P
p
.002 w
.48649 .35155 m .47059 .34339 L .4524 .3653 L p
1 g
F P
s
P
p
.002 w
.47059 .34339 m .48649 .35155 L .4978 .3276 L p
1 g
F P
s
P
p
.002 w
.50709 .32963 m .4978 .3276 L .48649 .35155 L p
1 g
F P
s
P
p
.002 w
.38634 .48792 m .43533 .5106 L .44102 .48474 L p
1 g
F P
s
P
p
.002 w
.44102 .48474 m .39527 .4632 L .38634 .48792 L p
1 g
F P
s
P
p
.002 w
.4524 .3653 m .43469 .34852 L .41236 .3673 L p
1 g
F P
s
P
p
.002 w
.43469 .34852 m .4524 .3653 L .47059 .34339 L p
1 g
F P
s
P
p
.002 w
.37427 .40948 m .40661 .4381 L .42011 .41311 L p
1 g
F P
s
P
p
.002 w
.42011 .41311 m .39208 .38774 L .37427 .40948 L p
1 g
F P
s
P
p
.002 w
.62411 .43147 m .58684 .45392 L .59384 .48059 L p
1 g
F P
s
P
p
.002 w
.58684 .45392 m .62411 .43147 L .61021 .40698 L p
1 g
F P
s
P
p
.002 w
.54047 .34958 m .55448 .34029 L .53247 .32175 L p
1 g
F P
s
P
p
.002 w
.53247 .32175 m .52539 .32655 L .54047 .34958 L p
1 g
F P
s
P
p
.002 w
.43114 .53501 m .48816 .54637 L .49014 .52164 L p
1 g
F P
s
P
p
.002 w
.49014 .52164 m .43533 .5106 L .43114 .53501 L p
1 g
F P
s
P
p
.002 w
.54614 .52027 m .49014 .52164 L .48816 .54637 L p
1 g
F P
s
P
p
.002 w
.47059 .34339 m .45862 .33178 L .43469 .34852 L p
1 g
F P
s
P
p
.002 w
.45862 .33178 m .47059 .34339 L .48971 .32339 L p
1 g
F P
s
P
p
.002 w
.4978 .3276 m .48971 .32339 L .47059 .34339 L p
1 g
F P
s
P
p
.002 w
.35936 .43209 m .39527 .4632 L .40661 .4381 L p
1 g
F P
s
P
p
.002 w
.40661 .4381 m .37427 .40948 L .35936 .43209 L p
1 g
F P
s
P
p
.002 w
.48816 .54637 m .5464 .54504 L .54614 .52027 L p
1 g
F P
s
P
p
.002 w
.59862 .50646 m .54614 .52027 L .5464 .54504 L p
1 g
F P
s
P
p
.002 w
.54614 .52027 m .59862 .50646 L .59384 .48059 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .4978 .3276 L .50709 .32963 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .50709 .32963 L .51662 .32927 L closepath p
1 g
F P
s
P
p
.002 w
.58897 .34286 m .57504 .36095 L .59374 .38333 L p
1 g
F P
s
P
p
.002 w
.57504 .36095 m .58897 .34286 L .5638 .32781 L p
1 g
F P
s
P
p
.002 w
.5638 .32781 m .55448 .34029 L .57504 .36095 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .51662 .32927 L .52539 .32655 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .48971 .32339 L .4978 .3276 L closepath p
1 g
F P
s
P
p
.002 w
.38009 .51174 m .43114 .53501 L .43533 .5106 L p
1 g
F P
s
P
p
.002 w
.43533 .5106 m .38634 .48792 L .38009 .51174 L p
1 g
F P
s
P
p
.002 w
.39878 .34132 m .41236 .3673 L .43469 .34852 L p
1 g
F P
s
P
p
.002 w
.43469 .34852 m .42449 .32827 L .39878 .34132 L p
1 g
F P
s
P
p
.002 w
.42449 .32827 m .43469 .34852 L .45862 .33178 L p
1 g
F P
s
P
p
.002 w
.6121 .36022 m .59374 .38333 L .61021 .40698 L p
1 g
F P
s
P
p
.002 w
.59374 .38333 m .6121 .36022 L .58897 .34286 L p
1 g
F P
s
P
p
.002 w
.55448 .34029 m .5638 .32781 L .5371 .31534 L p
1 g
F P
s
P
p
.002 w
.5371 .31534 m .53247 .32175 L .55448 .34029 L p
1 g
F P
s
P
p
.002 w
.6351 .4563 m .59384 .48059 L .59862 .50646 L p
1 g
F P
s
P
p
.002 w
.59384 .48059 m .6351 .4563 L .62411 .43147 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .52539 .32655 L .53247 .32175 L closepath p
1 g
F P
s
P
p
.002 w
.45862 .33178 m .45188 .31787 L .42449 .32827 L p
1 g
F P
s
P
p
.002 w
.45188 .31787 m .45862 .33178 L .48368 .31741 L p
1 g
F P
s
P
p
.002 w
.48971 .32339 m .48368 .31741 L .45862 .33178 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .48368 .31741 L .48971 .32339 L closepath p
1 g
F P
s
P
p
.002 w
.37531 .35679 m .39208 .38774 L .41236 .3673 L p
1 g
F P
s
P
p
.002 w
.41236 .3673 m .39878 .34132 L .37531 .35679 L p
1 g
F P
s
P
p
.002 w
.34772 .45512 m .38634 .48792 L .39527 .4632 L p
1 g
F P
s
P
p
.002 w
.39527 .4632 m .35936 .43209 L .34772 .45512 L p
1 g
F P
s
P
p
.002 w
.63266 .37955 m .61021 .40698 L .62411 .43147 L p
1 g
F P
s
P
p
.002 w
.61021 .40698 m .63266 .37955 L .6121 .36022 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .53247 .32175 L .5371 .31534 L closepath p
1 g
F P
s
P
p
.002 w
.48368 .31741 m .48037 .3103 L .45188 .31787 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .48037 .3103 L .48368 .31741 L closepath p
1 g
F P
s
P
p
.002 w
.35462 .3744 m .37427 .40948 L .39208 .38774 L p
1 g
F P
s
P
p
.002 w
.39208 .38774 m .37531 .35679 L .35462 .3744 L p
1 g
F P
s
P
p
.002 w
.42857 .55742 m .48642 .56883 L .48816 .54637 L p
1 g
F P
s
P
p
.002 w
.48816 .54637 m .43114 .53501 L .42857 .55742 L p
1 g
F P
s
P
p
.002 w
.5464 .54504 m .48816 .54637 L .48642 .56883 L p
1 g
F P
s
P
p
.002 w
.56732 .31339 m .5638 .32781 L .58897 .34286 L p
1 g
F P
s
P
p
.002 w
.5638 .32781 m .56732 .31339 L .53875 .30801 L p
1 g
F P
s
P
p
.002 w
.53875 .30801 m .5371 .31534 L .5638 .32781 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .5371 .31534 L .53875 .30801 L closepath p
1 g
F P
s
P
p
.002 w
.45122 .30306 m .45188 .31787 L .48037 .3103 L p
1 g
F P
s
P
p
.002 w
.48037 .3103 m .48017 .3028 L .45122 .30306 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .48017 .3028 L .48037 .3103 L closepath p
1 g
F P
s
P
p
.002 w
.42316 .30655 m .42449 .32827 L .45188 .31787 L p
1 g
F P
s
P
p
.002 w
.45188 .31787 m .45122 .30306 L .42316 .30655 L p
1 g
F P
s
P
p
.002 w
.48642 .56883 m .54549 .56758 L .5464 .54504 L p
1 g
F P
s
P
p
.002 w
.60102 .531 m .5464 .54504 L .54549 .56758 L p
1 g
F P
s
P
p
.002 w
.5464 .54504 m .60102 .531 L .59862 .50646 L p
1 g
F P
s
P
p
.002 w
.65019 .40049 m .62411 .43147 L .6351 .4563 L p
1 g
F P
s
P
p
.002 w
.62411 .43147 m .65019 .40049 L .63266 .37955 L p
1 g
F P
s
P
p
.002 w
.64287 .48098 m .59862 .50646 L .60102 .531 L p
1 g
F P
s
P
p
.002 w
.59862 .50646 m .64287 .48098 L .6351 .4563 L p
1 g
F P
s
P
p
.002 w
.5945 .32178 m .58897 .34286 L .6121 .36022 L p
1 g
F P
s
P
p
.002 w
.58897 .34286 m .5945 .32178 L .56732 .31339 L p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .53875 .30801 L .53721 .30053 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .53721 .30053 L .53261 .29372 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .53261 .29372 L .52541 .28836 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .52541 .28836 L .51641 .28505 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .51641 .28505 L .50661 .28417 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .50661 .28417 L .49712 .28584 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .49712 .28584 L .489 .28984 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .489 .28984 L .48315 .29571 L closepath p
1 g
F P
s
P
p
.002 w
.50941 .30572 m .48315 .29571 L .48017 .3028 L closepath p
1 g
F P
s
P
p
.002 w
.37674 .53412 m .42857 .55742 L .43114 .53501 L p
1 g
F P
s
P
p
.002 w
.43114 .53501 m .38009 .51174 L .37674 .53412 L p
1 g
F P
s
P
p
.002 w
.3966 .31326 m .39878 .34132 L .42449 .32827 L p
1 g
F P
s
P
p
.002 w
.42449 .32827 m .42316 .30655 L .3966 .31326 L p
1 g
F P
s
P
p
.002 w
.33972 .47808 m .38009 .51174 L .38634 .48792 L p
1 g
F P
s
P
p
.002 w
.38634 .48792 m .34772 .45512 L .33972 .47808 L p
1 g
F P
s
P
p
.002 w
.33725 .39383 m .35936 .43209 L .37427 .40948 L p
1 g
F P
s
P
p
.002 w
.37427 .40948 m .35462 .3744 L .33725 .39383 L p
1 g
F P
s
P
p
.002 w
.53721 .30053 m .53875 .30801 L .56732 .31339 L p
1 g
F P
s
P
p
.002 w
.45689 .28896 m .45122 .30306 L .48017 .3028 L p
1 g
F P
s
P
p
.002 w
.48017 .3028 m .48315 .29571 L .45689 .28896 L p
1 g
F P
s
P
p
.002 w
.61969 .33308 m .6121 .36022 L .63266 .37955 L p
1 g
F P
s
P
p
.002 w
.6121 .36022 m .61969 .33308 L .5945 .32178 L p
1 g
F P
s
P
p
.002 w
.37218 .32314 m .37531 .35679 L .39878 .34132 L p
1 g
F P
s
P
p
.002 w
.39878 .34132 m .3966 .31326 L .37218 .32314 L p
1 g
F P
s
P
p
.002 w
.56451 .29855 m .56732 .31339 L .5945 .32178 L p
1 g
F P
s
P
p
.002 w
.56732 .31339 m .56451 .29855 L .53721 .30053 L p
1 g
F P
s
P
p
.002 w
.53261 .29372 m .53721 .30053 L .56451 .29855 L p
1 g
F P
s
P
p
.002 w
.46839 .27717 m .45689 .28896 L .48315 .29571 L p
1 g
F P
s
P
p
.002 w
.48315 .29571 m .489 .28984 L .46839 .27717 L p
1 g
F P
s
P
p
.002 w
.43119 .2857 m .42316 .30655 L .45122 .30306 L p
1 g
F P
s
P
p
.002 w
.45122 .30306 m .45689 .28896 L .43119 .2857 L p
1 g
F P
s
P
p
.002 w
.6642 .42264 m .6351 .4563 L .64287 .48098 L p
1 g
F P
s
P
p
.002 w
.6351 .4563 m .6642 .42264 L .65019 .40049 L p
1 g
F P
s
P
p
.002 w
.42776 .57727 m .48498 .58845 L .48642 .56883 L p
1 g
F P
s
P
p
.002 w
.48642 .56883 m .42857 .55742 L .42776 .57727 L p
1 g
F P
s
P
p
.002 w
.54549 .56758 m .48642 .56883 L .48498 .58845 L p
1 g
F P
s
P
p
.002 w
.56451 .29855 m .55552 .28494 L .53261 .29372 L p
1 g
F P
s
P
p
.002 w
.52541 .28836 m .53261 .29372 L .55552 .28494 L p
1 g
F P
s
P
p
.002 w
.32371 .41469 m .34772 .45512 L .35936 .43209 L p
1 g
F P
s
P
p
.002 w
.35936 .43209 m .33725 .39383 L .32371 .41469 L p
1 g
F P
s
P
p
.002 w
.48455 .26908 m .46839 .27717 L .489 .28984 L p
1 g
F P
s
P
p
.002 w
.489 .28984 m .49712 .28584 L .48455 .26908 L p
1 g
F P
s
P
p
.002 w
.64229 .3471 m .63266 .37955 L .65019 .40049 L p
1 g
F P
s
P
p
.002 w
.63266 .37955 m .64229 .3471 L .61969 .33308 L p
1 g
F P
s
P
p
.002 w
.54549 .56758 m .60089 .55362 L .60102 .531 L p
1 g
F P
s
P
p
.002 w
.64716 .50496 m .60102 .531 L .60089 .55362 L p
1 g
F P
s
P
p
.002 w
.60102 .531 m .64716 .50496 L .64287 .48098 L p
1 g
F P
s
P
p
.002 w
.5907 .29991 m .5945 .32178 L .61969 .33308 L p
1 g
F P
s
P
p
.002 w
.5945 .32178 m .5907 .29991 L .56451 .29855 L p
1 g
F P
s
P
p
.002 w
.55552 .28494 m .54123 .27414 L .52541 .28836 L p
1 g
F P
s
P
p
.002 w
.51641 .28505 m .52541 .28836 L .54123 .27414 L p
1 g
F P
s
P
p
.002 w
.48498 .58845 m .54338 .58729 L .54549 .56758 L p
1 g
F P
s
P
p
.002 w
.60089 .55362 m .54549 .56758 L .54338 .58729 L p
1 g
F P
s
P
p
.002 w
.50356 .26569 m .48455 .26908 L .49712 .28584 L p
1 g
F P
s
P
p
.002 w
.49712 .28584 m .50661 .28417 L .50356 .26569 L p
1 g
F P
s
P
p
.002 w
.3357 .50045 m .37674 .53412 L .38009 .51174 L p
1 g
F P
s
P
p
.002 w
.38009 .51174 m .33972 .47808 L .3357 .50045 L p
1 g
F P
s
P
p
.002 w
.35051 .33605 m .35462 .3744 L .37531 .35679 L p
1 g
F P
s
P
p
.002 w
.37531 .35679 m .37218 .32314 L .35051 .33605 L p
1 g
F P
s
P
p
.002 w
.3765 .5545 m .42776 .57727 L .42857 .55742 L p
1 g
F P
s
P
p
.002 w
.42857 .55742 m .37674 .53412 L .3765 .5545 L p
1 g
F P
s
P
p
.002 w
.40664 .28611 m .3966 .31326 L .42316 .30655 L p
1 g
F P
s
P
p
.002 w
.42316 .30655 m .43119 .2857 L .40664 .28611 L p
1 g
F P
s
P
p
.002 w
.54123 .27414 m .52322 .26745 L .51641 .28505 L p
1 g
F P
s
P
p
.002 w
.50661 .28417 m .51641 .28505 L .52322 .26745 L p
1 g
F P
s
P
p
.002 w
.52322 .26745 m .50356 .26569 L .50661 .28417 L p
1 g
F P
s
P
p
.002 w
.55552 .28494 m .56451 .29855 L .5907 .29991 L p
1 g
F P
s
P
p
.002 w
.44801 .26811 m .43119 .2857 L .45689 .28896 L p
1 g
F P
s
P
p
.002 w
.45689 .28896 m .46839 .27717 L .44801 .26811 L p
1 g
F P
s
P
p
.002 w
.67428 .44552 m .64287 .48098 L .64716 .50496 L p
1 g
F P
s
P
p
.002 w
.64287 .48098 m .67428 .44552 L .6642 .42264 L p
1 g
F P
s
P
p
.002 w
.6617 .36363 m .65019 .40049 L .6642 .42264 L p
1 g
F P
s
P
p
.002 w
.65019 .40049 m .6617 .36363 L .64229 .3471 L p
1 g
F P
s
P
p
.002 w
.31448 .43654 m .33972 .47808 L .34772 .45512 L p
1 g
F P
s
P
p
.002 w
.34772 .45512 m .32371 .41469 L .31448 .43654 L p
1 g
F P
s
P
p
.002 w
.61515 .30468 m .61969 .33308 L .64229 .3471 L p
1 g
F P
s
P
p
.002 w
.61969 .33308 m .61515 .30468 L .5907 .29991 L p
1 g
F P
s
P
p
.002 w
.5907 .29991 m .57763 .27968 L .55552 .28494 L p
1 g
F P
s
P
p
.002 w
.54123 .27414 m .55552 .28494 L .57763 .27968 L p
1 g
F P
s
P
p
.002 w
.33222 .35182 m .33725 .39383 L .35462 .3744 L p
1 g
F P
s
P
p
.002 w
.35462 .3744 m .35051 .33605 L .33222 .35182 L p
1 g
F P
s
P
p
.002 w
.38387 .29034 m .37218 .32314 L .3966 .31326 L p
1 g
F P
s
P
p
.002 w
.3966 .31326 m .40664 .28611 L .38387 .29034 L p
1 g
F P
s
P
p
.002 w
.47195 .25597 m .44801 .26811 L .46839 .27717 L p
1 g
F P
s
P
p
.002 w
.46839 .27717 m .48455 .26908 L .47195 .25597 L p
1 g
F P
s
P
p
.002 w
.42881 .59398 m .48387 .60466 L .48498 .58845 L p
1 g
F P
s
P
p
.002 w
.48498 .58845 m .42776 .57727 L .42881 .59398 L p
1 g
F P
s
P
p
.002 w
.54338 .58729 m .48498 .58845 L .48387 .60466 L p
1 g
F P
s
P
p
.002 w
.57763 .27968 m .5907 .29991 L .61515 .30468 L p
1 g
F P
s
P
p
.002 w
.54338 .58729 m .59814 .57375 L .60089 .55362 L p
1 g
F P
s
P
p
.002 w
.64772 .52767 m .60089 .55362 L .59814 .57375 L p
1 g
F P
s
P
p
.002 w
.60089 .55362 m .64772 .52767 L .64716 .50496 L p
1 g
F P
s
P
p
.002 w
.42835 .26304 m .40664 .28611 L .43119 .2857 L p
1 g
F P
s
P
p
.002 w
.43119 .2857 m .44801 .26811 L .42835 .26304 L p
1 g
F P
s
P
p
.002 w
.33593 .52166 m .3765 .5545 L .37674 .53412 L p
1 g
F P
s
P
p
.002 w
.37674 .53412 m .3357 .50045 L .33593 .52166 L p
1 g
F P
s
P
p
.002 w
.57763 .27968 m .55651 .26352 L .54123 .27414 L p
1 g
F P
s
P
p
.002 w
.52322 .26745 m .54123 .27414 L .55651 .26352 L p
1 g
F P
s
P
p
.002 w
.5003 .25085 m .47195 .25597 L .48455 .26908 L p
1 g
F P
s
P
p
.002 w
.48455 .26908 m .50356 .26569 L .5003 .25085 L p
1 g
F P
s
P
p
.002 w
.48387 .60466 m .54007 .60361 L .54338 .58729 L p
1 g
F P
s
P
p
.002 w
.59814 .57375 m .54338 .58729 L .54007 .60361 L p
1 g
F P
s
P
p
.002 w
.37953 .57231 m .42881 .59398 L .42776 .57727 L p
1 g
F P
s
P
p
.002 w
.42776 .57727 m .3765 .5545 L .37953 .57231 L p
1 g
F P
s
P
p
.002 w
.67734 .38235 m .6642 .42264 L .67428 .44552 L p
1 g
F P
s
P
p
.002 w
.6642 .42264 m .67734 .38235 L .6617 .36363 L p
1 g
F P
s
P
p
.002 w
.55651 .26352 m .52968 .25348 L .52322 .26745 L p
1 g
F P
s
P
p
.002 w
.50356 .26569 m .52322 .26745 L .52968 .25348 L p
1 g
F P
s
P
p
.002 w
.52968 .25348 m .5003 .25085 L .50356 .26569 L p
1 g
F P
s
P
p
.002 w
.68001 .46862 m .64716 .50496 L .64772 .52767 L p
1 g
F P
s
P
p
.002 w
.64716 .50496 m .68001 .46862 L .67428 .44552 L p
1 g
F P
s
P
p
.002 w
.63725 .31289 m .64229 .3471 L .6617 .36363 L p
1 g
F P
s
P
p
.002 w
.64229 .3471 m .63725 .31289 L .61515 .30468 L p
1 g
F P
s
P
p
.002 w
.31792 .37016 m .32371 .41469 L .33725 .39383 L p
1 g
F P
s
P
p
.002 w
.33725 .39383 m .33222 .35182 L .31792 .37016 L p
1 g
F P
s
P
p
.002 w
.3635 .29845 m .35051 .33605 L .37218 .32314 L p
1 g
F P
s
P
p
.002 w
.37218 .32314 m .38387 .29034 L .3635 .29845 L p
1 g
F P
s
P
p
.002 w
.30996 .45889 m .3357 .50045 L .33972 .47808 L p
1 g
F P
s
P
p
.002 w
.33972 .47808 m .31448 .43654 L .30996 .45889 L p
1 g
F P
s
P
p
.002 w
.61515 .30468 m .59838 .27822 L .57763 .27968 L p
1 g
F P
s
P
p
.002 w
.55651 .26352 m .57763 .27968 L .59838 .27822 L p
1 g
F P
s
P
p
.002 w
.45963 .24701 m .42835 .26304 L .44801 .26811 L p
1 g
F P
s
P
p
.002 w
.44801 .26811 m .47195 .25597 L .45963 .24701 L p
1 g
F P
s
P
p
.002 w
.59838 .27822 m .61515 .30468 L .63725 .31289 L p
1 g
F P
s
P
p
.002 w
.40993 .26229 m .38387 .29034 L .40664 .28611 L p
1 g
F P
s
P
p
.002 w
.40664 .28611 m .42835 .26304 L .40993 .26229 L p
1 g
F P
s
P
p
.002 w
.54007 .60361 m .59269 .59078 L .59814 .57375 L p
1 g
F P
s
P
p
.002 w
.64437 .54851 m .59814 .57375 L .59269 .59078 L p
1 g
F P
s
P
p
.002 w
.59814 .57375 m .64437 .54851 L .64772 .52767 L p
1 g
F P
s
P
p
.002 w
.43181 .60697 m .48316 .61688 L .48387 .60466 L p
1 g
F P
s
P
p
.002 w
.48387 .60466 m .42881 .59398 L .43181 .60697 L p
1 g
F P
s
P
p
.002 w
.54007 .60361 m .48387 .60466 L .48316 .61688 L p
1 g
F P
s
P
p
.002 w
.68868 .4029 m .67428 .44552 L .68001 .46862 L p
1 g
F P
s
P
p
.002 w
.67428 .44552 m .68868 .4029 L .67734 .38235 L p
1 g
F P
s
P
p
.002 w
.65634 .32449 m .6617 .36363 L .67734 .38235 L p
1 g
F P
s
P
p
.002 w
.6617 .36363 m .65634 .32449 L .63725 .31289 L p
1 g
F P
s
P
p
.002 w
.3406 .54111 m .37953 .57231 L .3765 .5545 L p
1 g
F P
s
P
p
.002 w
.3765 .5545 m .33593 .52166 L .3406 .54111 L p
1 g
F P
s
P
p
.002 w
.59838 .27822 m .57085 .25696 L .55651 .26352 L p
1 g
F P
s
P
p
.002 w
.52968 .25348 m .55651 .26352 L .57085 .25696 L p
1 g
F P
s
P
p
.002 w
.4969 .24023 m .45963 .24701 L .47195 .25597 L p
1 g
F P
s
P
p
.002 w
.47195 .25597 m .5003 .25085 L .4969 .24023 L p
1 g
F P
s
P
p
.002 w
.68109 .49139 m .64772 .52767 L .64437 .54851 L p
1 g
F P
s
P
p
.002 w
.64772 .52767 m .68109 .49139 L .68001 .46862 L p
1 g
F P
s
P
p
.002 w
.34619 .31042 m .33222 .35182 L .35051 .33605 L p
1 g
F P
s
P
p
.002 w
.35051 .33605 m .3635 .29845 L .34619 .31042 L p
1 g
F P
s
P
p
.002 w
.30815 .39071 m .31448 .43654 L .32371 .41469 L p
1 g
F P
s
P
p
.002 w
.32371 .41469 m .31792 .37016 L .30815 .39071 L p
1 g
F P
s
P
p
.002 w
.48316 .61688 m .53556 .61594 L .54007 .60361 L p
1 g
F P
s
P
p
.002 w
.59269 .59078 m .54007 .60361 L .53556 .61594 L p
1 g
F P
s
P
p
.002 w
.38594 .58694 m .43181 .60697 L .42881 .59398 L p
1 g
F P
s
P
p
.002 w
.42881 .59398 m .37953 .57231 L .38594 .58694 L p
1 g
F P
s
P
p
.002 w
.31049 .48116 m .33593 .52166 L .3357 .50045 L p
1 g
F P
s
P
p
.002 w
.3357 .50045 m .30996 .45889 L .31049 .48116 L p
1 g
F P
s
P
p
.002 w
.57085 .25696 m .53559 .24369 L .52968 .25348 L p
1 g
F P
s
P
p
.002 w
.5003 .25085 m .52968 .25348 L .53559 .24369 L p
1 g
F P
s
P
p
.002 w
.53559 .24369 m .4969 .24023 L .5003 .25085 L p
1 g
F P
s
P
p
.002 w
.61721 .2808 m .63725 .31289 L .65634 .32449 L p
1 g
F P
s
P
p
.002 w
.63725 .31289 m .61721 .2808 L .59838 .27822 L p
1 g
F P
s
P
p
.002 w
.57085 .25696 m .59838 .27822 L .61721 .2808 L p
1 g
F P
s
P
p
.002 w
.39328 .26611 m .3635 .29845 L .38387 .29034 L p
1 g
F P
s
P
p
.002 w
.38387 .29034 m .40993 .26229 L .39328 .26611 L p
1 g
F P
s
P
p
.002 w
.44791 .24269 m .40993 .26229 L .42835 .26304 L p
1 g
F P
s
P
p
.002 w
.42835 .26304 m .45963 .24701 L .44791 .24269 L p
1 g
F P
s
P
p
.002 w
.67181 .33934 m .67734 .38235 L .68868 .4029 L p
1 g
F P
s
P
p
.002 w
.67734 .38235 m .67181 .33934 L .65634 .32449 L p
1 g
F P
s
P
p
.002 w
.69522 .42482 m .68001 .46862 L .68109 .49139 L p
1 g
F P
s
P
p
.002 w
.68001 .46862 m .69522 .42482 L .68868 .4029 L p
1 g
F P
s
P
p
.002 w
.53556 .61594 m .58454 .60413 L .59269 .59078 L p
1 g
F P
s
P
p
.002 w
.63701 .56687 m .59269 .59078 L .58454 .60413 L p
1 g
F P
s
P
p
.002 w
.59269 .59078 m .63701 .56687 L .64437 .54851 L p
1 g
F P
s
P
p
.002 w
.33254 .32612 m .31792 .37016 L .33222 .35182 L p
1 g
F P
s
P
p
.002 w
.33222 .35182 m .34619 .31042 L .33254 .32612 L p
1 g
F P
s
P
p
.002 w
.30339 .41302 m .30996 .45889 L .31448 .43654 L p
1 g
F P
s
P
p
.002 w
.31448 .43654 m .30815 .39071 L .30339 .41302 L p
1 g
F P
s
P
p
.002 w
.34984 .5582 m .38594 .58694 L .37953 .57231 L p
1 g
F P
s
P
p
.002 w
.37953 .57231 m .3406 .54111 L .34984 .5582 L p
1 g
F P
s
P
p
.002 w
.67726 .51321 m .64437 .54851 L .63701 .56687 L p
1 g
F P
s
P
p
.002 w
.64437 .54851 m .67726 .51321 L .68109 .49139 L p
1 g
F P
s
P
p
.002 w
.43679 .61569 m .48286 .62455 L .48316 .61688 L p
1 g
F P
s
P
p
.002 w
.48316 .61688 m .43181 .60697 L .43679 .61569 L p
1 g
F P
s
P
p
.002 w
.53556 .61594 m .48316 .61688 L .48286 .62455 L p
1 g
F P
s
P
p
.002 w
.61721 .2808 m .58383 .25485 L .57085 .25696 L p
1 g
F P
s
P
p
.002 w
.53559 .24369 m .57085 .25696 L .58383 .25485 L p
1 g
F P
s
P
p
.002 w
.31631 .50275 m .3406 .54111 L .33593 .52166 L p
1 g
F P
s
P
p
.002 w
.33593 .52166 m .31049 .48116 L .31631 .50275 L p
1 g
F P
s
P
p
.002 w
.49344 .23436 m .44791 .24269 L .45963 .24701 L p
1 g
F P
s
P
p
.002 w
.45963 .24701 m .4969 .24023 L .49344 .23436 L p
1 g
F P
s
P
p
.002 w
.48286 .62455 m .52989 .62373 L .53556 .61594 L p
1 g
F P
s
P
p
.002 w
.58454 .60413 m .53556 .61594 L .52989 .62373 L p
1 g
F P
s
P
p
.002 w
.63354 .28754 m .65634 .32449 L .67181 .33934 L p
1 g
F P
s
P
p
.002 w
.65634 .32449 m .63354 .28754 L .61721 .2808 L p
1 g
F P
s
P
p
.002 w
.39573 .59784 m .43679 .61569 L .43181 .60697 L p
1 g
F P
s
P
p
.002 w
.43181 .60697 m .38594 .58694 L .39573 .59784 L p
1 g
F P
s
P
p
.002 w
.37897 .27465 m .34619 .31042 L .3635 .29845 L p
1 g
F P
s
P
p
.002 w
.3635 .29845 m .39328 .26611 L .37897 .27465 L p
1 g
F P
s
P
p
.002 w
.58383 .25485 m .61721 .2808 L .63354 .28754 L p
1 g
F P
s
P
p
.002 w
.58383 .25485 m .54079 .2386 L .53559 .24369 L p
1 g
F P
s
P
p
.002 w
.4969 .24023 m .53559 .24369 L .54079 .2386 L p
1 g
F P
s
P
p
.002 w
.54079 .2386 m .49344 .23436 L .4969 .24023 L p
1 g
F P
s
P
p
.002 w
.68305 .35721 m .68868 .4029 L .69522 .42482 L p
1 g
F P
s
P
p
.002 w
.68868 .4029 m .68305 .35721 L .67181 .33934 L p
1 g
F P
s
P
p
.002 w
.43714 .2434 m .39328 .26611 L .40993 .26229 L p
1 g
F P
s
P
p
.002 w
.40993 .26229 m .44791 .24269 L .43714 .2434 L p
1 g
F P
s
P
p
.002 w
.69657 .44759 m .68109 .49139 L .67726 .51321 L p
1 g
F P
s
P
p
.002 w
.68109 .49139 m .69657 .44759 L .69522 .42482 L p
1 g
F P
s
P
p
.002 w
.32314 .3453 m .30815 .39071 L .31792 .37016 L p
1 g
F P
s
P
p
.002 w
.31792 .37016 m .33254 .32612 L .32314 .3453 L p
1 g
F P
s
P
p
.002 w
.30402 .43652 m .31049 .48116 L .30996 .45889 L p
1 g
F P
s
P
p
.002 w
.30996 .45889 m .30339 .41302 L .30402 .43652 L p
1 g
F P
s
P
p
.002 w
.52989 .62373 m .57373 .61323 L .58454 .60413 L p
1 g
F P
s
P
p
.002 w
.62562 .58213 m .58454 .60413 L .57373 .61323 L p
1 g
F P
s
P
p
.002 w
.58454 .60413 m .62562 .58213 L .63701 .56687 L p
1 g
F P
s
P
p
.002 w
.6684 .53345 m .63701 .56687 L .62562 .58213 L p
1 g
F P
s
P
p
.002 w
.63701 .56687 m .6684 .53345 L .67726 .51321 L p
1 g
F P
s
P
p
.002 w
.36362 .57232 m .39573 .59784 L .38594 .58694 L p
1 g
F P
s
P
p
.002 w
.38594 .58694 m .34984 .5582 L .36362 .57232 L p
1 g
F P
s
P
p
.002 w
.32751 .52299 m .34984 .5582 L .3406 .54111 L p
1 g
F P
s
P
p
.002 w
.3406 .54111 m .31631 .50275 L .32751 .52299 L p
1 g
F P
s
P
p
.002 w
.64676 .29852 m .67181 .33934 L .68305 .35721 L p
1 g
F P
s
P
p
.002 w
.67181 .33934 m .64676 .29852 L .63354 .28754 L p
1 g
F P
s
P
p
.002 w
.63354 .28754 m .59502 .25752 L .58383 .25485 L p
1 g
F P
s
P
p
.002 w
.54079 .2386 m .58383 .25485 L .59502 .25752 L p
1 g
F P
s
P
p
.002 w
.44374 .61963 m .48303 .62717 L .48286 .62455 L p
1 g
F P
s
P
p
.002 w
.48286 .62455 m .43679 .61569 L .44374 .61963 L p
1 g
F P
s
P
p
.002 w
.52989 .62373 m .48286 .62455 L .48303 .62717 L p
1 g
F P
s
P
p
.002 w
.49001 .23371 m .43714 .2434 L .44791 .24269 L p
1 g
F P
s
P
p
.002 w
.44791 .24269 m .49344 .23436 L .49001 .23371 L p
1 g
F P
s
P
p
.002 w
.36755 .28794 m .33254 .32612 L .34619 .31042 L p
1 g
F P
s
P
p
.002 w
.34619 .31042 m .37897 .27465 L .36755 .28794 L p
1 g
F P
s
P
p
.002 w
.69522 .42482 m .68953 .37773 L .68305 .35721 L p
1 g
F P
s
P
p
.002 w
.68953 .37773 m .69522 .42482 L .69657 .44759 L p
1 g
F P
s
P
p
.002 w
.48303 .62717 m .52314 .62648 L .52989 .62373 L p
1 g
F P
s
P
p
.002 w
.57373 .61323 m .52989 .62373 L .52314 .62648 L p
1 g
F P
s
P
p
.002 w
.67726 .51321 m .69244 .4706 L .69657 .44759 L p
1 g
F P
s
P
p
.002 w
.69244 .4706 m .67726 .51321 L .6684 .53345 L p
1 g
F P
s
P
p
.002 w
.59502 .25752 m .63354 .28754 L .64676 .29852 L p
1 g
F P
s
P
p
.004 w
.48203 .66889 m
.48403 .64241 L
s
P
p
.004 w
.66153 .58772 m
.71454 .63931 L
s
P
p
.002 w
.40886 .60446 m .44374 .61963 L .43679 .61569 L p
1 g
F P
s
P
p
.002 w
.43679 .61569 m .39573 .59784 L .40886 .60446 L p
1 g
F P
s
P
p
.002 w
.31848 .36755 m .30339 .41302 L .30815 .39071 L p
1 g
F P
s
P
p
.002 w
.30815 .39071 m .32314 .3453 L .31848 .36755 L p
1 g
F P
s
P
p
.002 w
.42771 .24944 m .37897 .27465 L .39328 .26611 L p
1 g
F P
s
P
p
.002 w
.39328 .26611 m .43714 .2434 L .42771 .24944 L p
1 g
F P
s
P
p
.002 w
.31028 .46057 m .31631 .50275 L .31049 .48116 L p
1 g
F P
s
P
p
.002 w
.31049 .48116 m .30402 .43652 L .31028 .46057 L p
1 g
F P
s
P
p
.002 w
.59502 .25752 m .54507 .23864 L .54079 .2386 L p
1 g
F P
s
P
p
.002 w
.49344 .23436 m .54079 .2386 L .54507 .23864 L p
1 g
F P
s
P
p
.002 w
.54507 .23864 m .49001 .23371 L .49344 .23436 L p
1 g
F P
s
P
p
.002 w
.57373 .61323 m .61031 .5937 L .62562 .58213 L p
1 g
F P
s
P
p
.002 w
.62562 .58213 m .65451 .55145 L .6684 .53345 L p
1 g
F P
s
P
p
.002 w
.65451 .55145 m .62562 .58213 L .61031 .5937 L p
1 g
F P
s
P
p
.002 w
.52314 .62648 m .56042 .61756 L .57373 .61323 L p
1 g
F P
s
P
p
.002 w
.61031 .5937 m .57373 .61323 L .56042 .61756 L p
1 g
F P
s
P
p
.002 w
.34399 .54121 m .36362 .57232 L .34984 .5582 L p
1 g
F P
s
P
p
.002 w
.34984 .5582 m .32751 .52299 L .34399 .54121 L p
1 g
F P
s
P
p
.002 w
.38177 .58289 m .40886 .60446 L .39573 .59784 L p
1 g
F P
s
P
p
.002 w
.39573 .59784 m .36362 .57232 L .38177 .58289 L p
1 g
F P
s
P
p
.002 w
.68305 .35721 m .65633 .31365 L .64676 .29852 L p
1 g
F P
s
P
p
.002 w
.65633 .31365 m .68305 .35721 L .68953 .37773 L p
1 g
F P
s
P
p
.002 w
.69083 .40043 m .69657 .44759 L .69244 .4706 L p
1 g
F P
s
P
p
.002 w
.69657 .44759 m .69083 .40043 L .68953 .37773 L p
1 g
F P
s
P
p
.002 w
.35953 .30584 m .32314 .3453 L .33254 .32612 L p
1 g
F P
s
P
p
.002 w
.33254 .32612 m .36755 .28794 L .35953 .30584 L p
1 g
F P
s
P
p
.002 w
.6827 .49318 m .6684 .53345 L .65451 .55145 L p
1 g
F P
s
P
p
.002 w
.6684 .53345 m .6827 .49318 L .69244 .4706 L p
1 g
F P
s
P
p
.002 w
.64676 .29852 m .604 .26519 L .59502 .25752 L p
1 g
F P
s
P
p
.002 w
.54507 .23864 m .59502 .25752 L .604 .26519 L p
1 g
F P
s
P
p
.002 w
.31894 .39233 m .30402 .43652 L .30339 .41302 L p
1 g
F P
s
P
p
.002 w
.30339 .41302 m .31848 .36755 L .31894 .39233 L p
1 g
F P
s
P
p
.002 w
.48672 .23867 m .42771 .24944 L .43714 .2434 L p
1 g
F P
s
P
p
.002 w
.43714 .2434 m .49001 .23371 L .48672 .23867 L p
1 g
F P
s
P
p
.002 w
.4526 .61835 m .48369 .62432 L .48303 .62717 L p
1 g
F P
s
P
p
.002 w
.48303 .62717 m .44374 .61963 L .4526 .61835 L p
1 g
F P
s
P
p
.002 w
.52314 .62648 m .48303 .62717 L .48369 .62432 L p
1 g
F P
s
P
p
.002 w
.604 .26519 m .64676 .29852 L .65633 .31365 L p
1 g
F P
s
P
p
.002 w
.32221 .48445 m .32751 .52299 L .31631 .50275 L p
1 g
F P
s
P
p
.002 w
.31631 .50275 m .31028 .46057 L .32221 .48445 L p
1 g
F P
s
P
p
.002 w
.48369 .62432 m .51544 .62377 L .52314 .62648 L p
1 g
F P
s
P
p
.002 w
.56042 .61756 m .52314 .62648 L .51544 .62377 L p
1 g
F P
s
P
p
.002 w
.41997 .26096 m .36755 .28794 L .37897 .27465 L p
1 g
F P
s
P
p
.002 w
.37897 .27465 m .42771 .24944 L .41997 .26096 L p
1 g
F P
s
P
p
.002 w
.42511 .60636 m .4526 .61835 L .44374 .61963 L p
1 g
F P
s
P
p
.002 w
.44374 .61963 m .40886 .60446 L .42511 .60636 L p
1 g
F P
s
P
p
.002 w
.604 .26519 m .54826 .24417 L .54507 .23864 L p
1 g
F P
s
P
p
.002 w
.49001 .23371 m .54507 .23864 L .54826 .24417 L p
1 g
F P
s
P
p
.002 w
.54826 .24417 m .48672 .23867 L .49001 .23371 L p
1 g
F P
s
P
p
.002 w
.56042 .61756 m .5913 .60103 L .61031 .5937 L p
1 g
F P
s
P
p
.002 w
.63576 .56657 m .61031 .5937 L .5913 .60103 L p
1 g
F P
s
P
p
.002 w
.61031 .5937 m .63576 .56657 L .65451 .55145 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.63797 .56479 L
s
P
p
.004 w
.63944 .56622 m
.64048 .56723 L
s
P
p
.004 w
.64048 .56723 m
.64614 .57274 L
s
P
p
.004 w
.64614 .57274 m
.66153 .58772 L
s
P
p
.002 w
.66175 .3327 m .68953 .37773 L .69083 .40043 L p
1 g
F P
s
P
p
.002 w
.68953 .37773 m .66175 .3327 L .65633 .31365 L p
1 g
F P
s
P
p
.002 w
.36549 .55675 m .38177 .58289 L .36362 .57232 L p
1 g
F P
s
P
p
.002 w
.36362 .57232 m .34399 .54121 L .36549 .55675 L p
1 g
F P
s
P
p
.002 w
.68665 .42473 m .69244 .4706 L .6827 .49318 L p
1 g
F P
s
P
p
.002 w
.69244 .4706 m .68665 .42473 L .69083 .40043 L p
1 g
F P
s
P
p
.002 w
.51544 .62377 m .54484 .61671 L .56042 .61756 L p
1 g
F P
s
P
p
.002 w
.5913 .60103 m .56042 .61756 L .54484 .61671 L p
1 g
F P
s
P
p
.002 w
.40397 .58939 m .42511 .60636 L .40886 .60446 L p
1 g
F P
s
P
p
.002 w
.40886 .60446 m .38177 .58289 L .40397 .58939 L p
1 g
F P
s
P
p
.002 w
.35536 .32803 m .31848 .36755 L .32314 .3453 L p
1 g
F P
s
P
p
.002 w
.32314 .3453 m .35953 .30584 L .35536 .32803 L p
1 g
F P
s
P
p
.002 w
.66739 .51461 m .65451 .55145 L .63576 .56657 L p
1 g
F P
s
P
p
.002 w
.65451 .55145 m .66739 .51461 L .6827 .49318 L p
1 g
F P
s
P
p
.002 w
.32474 .41895 m .31028 .46057 L .30402 .43652 L p
1 g
F P
s
P
p
.002 w
.30402 .43652 m .31894 .39233 L .32474 .41895 L p
1 g
F P
s
P
p
.002 w
.33968 .50737 m .34399 .54121 L .32751 .52299 L p
1 g
F P
s
P
p
.002 w
.32751 .52299 m .32221 .48445 L .33968 .50737 L p
1 g
F P
s
P
p
.002 w
.65633 .31365 m .61034 .27795 L .604 .26519 L p
1 g
F P
s
P
p
.002 w
.54826 .24417 m .604 .26519 L .61034 .27795 L p
1 g
F P
s
P
p
.002 w
.61034 .27795 m .65633 .31365 L .66175 .3327 L p
1 g
F P
s
P
p
.002 w
.48367 .24943 m .41997 .26096 L .42771 .24944 L p
1 g
F P
s
P
p
.002 w
.42771 .24944 m .48672 .23867 L .48367 .24943 L p
1 g
F P
s
P
p
.002 w
.41428 .27793 m .35953 .30584 L .36755 .28794 L p
1 g
F P
s
P
p
.002 w
.36755 .28794 m .41997 .26096 L .41428 .27793 L p
1 g
F P
s
P
p
.002 w
.46321 .61156 m .48486 .61574 L .48369 .62432 L p
1 g
F P
s
P
p
.002 w
.48369 .62432 m .4526 .61835 L .46321 .61156 L p
1 g
F P
s
P
p
.002 w
.51544 .62377 m .48369 .62432 L .48486 .61574 L p
1 g
F P
s
P
p
.002 w
.48486 .61574 m .50697 .61534 L .51544 .62377 L p
1 g
F P
s
P
p
.002 w
.54484 .61671 m .51544 .62377 L .50697 .61534 L p
1 g
F P
s
P
p
.002 w
.44417 .6032 m .46321 .61156 L .4526 .61835 L p
1 g
F P
s
P
p
.002 w
.4526 .61835 m .42511 .60636 L .44417 .6032 L p
1 g
F P
s
P
p
.002 w
.54484 .61671 m .56899 .60368 L .5913 .60103 L p
1 g
F P
s
P
p
.002 w
.61251 .57819 m .5913 .60103 L .56899 .60368 L p
1 g
F P
s
P
p
.002 w
.5913 .60103 m .61251 .57819 L .63576 .56657 L p
1 g
F P
s
P
p
.002 w
.66262 .35528 m .69083 .40043 L .68665 .42473 L p
1 g
F P
s
P
p
.002 w
.69083 .40043 m .66262 .35528 L .66175 .3327 L p
1 g
F P
s
P
p
.002 w
.67687 .44991 m .6827 .49318 L .66739 .51461 L p
1 g
F P
s
P
p
.002 w
.6827 .49318 m .67687 .44991 L .68665 .42473 L p
1 g
F P
s
P
p
.002 w
.39152 .56898 m .40397 .58939 L .38177 .58289 L p
1 g
F P
s
P
p
.002 w
.38177 .58289 m .36549 .55675 L .39152 .56898 L p
1 g
F P
s
P
p
.002 w
.61034 .27795 m .55017 .25538 L .54826 .24417 L p
1 g
F P
s
P
p
.002 w
.48672 .23867 m .54826 .24417 L .55017 .25538 L p
1 g
F P
s
P
p
.002 w
.55017 .25538 m .48367 .24943 L .48672 .23867 L p
1 g
F P
s
P
p
.002 w
.64677 .53414 m .63576 .56657 L .61251 .57819 L p
1 g
F P
s
P
p
.002 w
.63576 .56657 m .64677 .53414 L .66739 .51461 L p
1 g
F P
s
P
p
.002 w
.35536 .35398 m .31894 .39233 L .31848 .36755 L p
1 g
F P
s
P
p
.002 w
.31848 .36755 m .35536 .32803 L .35536 .35398 L p
1 g
F P
s
P
p
.002 w
.33591 .4466 m .32221 .48445 L .31028 .46057 L p
1 g
F P
s
P
p
.002 w
.31028 .46057 m .32474 .41895 L .33591 .4466 L p
1 g
F P
s
P
p
.002 w
.50697 .61534 m .52735 .61039 L .54484 .61671 L p
1 g
F P
s
P
p
.002 w
.56899 .60368 m .54484 .61671 L .52735 .61039 L p
1 g
F P
s
P
p
.002 w
.36229 .52852 m .36549 .55675 L .34399 .54121 L p
1 g
F P
s
P
p
.002 w
.34399 .54121 m .33968 .50737 L .36229 .52852 L p
1 g
F P
s
P
p
.002 w
.42968 .59143 m .44417 .6032 L .42511 .60636 L p
1 g
F P
s
P
p
.002 w
.42511 .60636 m .40397 .58939 L .42968 .59143 L p
1 g
F P
s
P
p
.002 w
.61369 .2957 m .66175 .3327 L .66262 .35528 L p
1 g
F P
s
P
p
.002 w
.66175 .3327 m .61369 .2957 L .61034 .27795 L p
1 g
F P
s
P
p
.002 w
.55017 .25538 m .61034 .27795 L .61369 .2957 L p
1 g
F P
s
P
p
.002 w
.41096 .30008 m .35536 .32803 L .35953 .30584 L p
1 g
F P
s
P
p
.002 w
.35953 .30584 m .41428 .27793 L .41096 .30008 L p
1 g
F P
s
P
p
.002 w
.48098 .26602 m .41428 .27793 L .41997 .26096 L p
1 g
F P
s
P
p
.002 w
.41997 .26096 m .48367 .24943 L .48098 .26602 L p
1 g
F P
s
P
p
.002 w
.66158 .47515 m .66739 .51461 L .64677 .53414 L p
1 g
F P
s
P
p
.002 w
.66739 .51461 m .66158 .47515 L .67687 .44991 L p
1 g
F P
s
P
p
.002 w
.65868 .38081 m .68665 .42473 L .67687 .44991 L p
1 g
F P
s
P
p
.002 w
.68665 .42473 m .65868 .38081 L .66262 .35528 L p
1 g
F P
s
P
p
.002 w
.52735 .61039 m .54395 .60132 L .56899 .60368 L p
1 g
F P
s
P
p
.002 w
.58532 .58579 m .56899 .60368 L .54395 .60132 L p
1 g
F P
s
P
p
.002 w
.56899 .60368 m .58532 .58579 L .61251 .57819 L p
1 g
F P
s
P
p
.002 w
.47533 .59914 m .48652 .60131 L .48486 .61574 L p
1 g
F P
s
P
p
.002 w
.48486 .61574 m .46321 .61156 L .47533 .59914 L p
1 g
F P
s
P
p
.002 w
.50697 .61534 m .48486 .61574 L .48652 .60131 L p
1 g
F P
s
P
p
.002 w
.35224 .47434 m .33968 .50737 L .32221 .48445 L p
1 g
F P
s
P
p
.002 w
.32221 .48445 m .33591 .4466 L .35224 .47434 L p
1 g
F P
s
P
p
.002 w
.62134 .55106 m .61251 .57819 L .58532 .58579 L p
1 g
F P
s
P
p
.002 w
.61251 .57819 m .62134 .55106 L .64677 .53414 L p
1 g
F P
s
P
p
.002 w
.42136 .57738 m .42968 .59143 L .40397 .58939 L p
1 g
F P
s
P
p
.002 w
.40397 .58939 m .39152 .56898 L .42136 .57738 L p
1 g
F P
s
P
p
.002 w
.35972 .38295 m .32474 .41895 L .31894 .39233 L p
1 g
F P
s
P
p
.002 w
.31894 .39233 m .35536 .35398 L .35972 .38295 L p
1 g
F P
s
P
p
.002 w
.48652 .60131 m .49794 .6011 L .50697 .61534 L p
1 g
F P
s
P
p
.002 w
.52735 .61039 m .50697 .61534 L .49794 .6011 L p
1 g
F P
s
P
p
.002 w
.46555 .5948 m .47533 .59914 L .46321 .61156 L p
1 g
F P
s
P
p
.002 w
.46321 .61156 m .44417 .6032 L .46555 .5948 L p
1 g
F P
s
P
p
.002 w
.38943 .54713 m .39152 .56898 L .36549 .55675 L p
1 g
F P
s
P
p
.002 w
.36549 .55675 m .36229 .52852 L .38943 .54713 L p
1 g
F P
s
P
p
.002 w
.61369 .2957 m .55068 .27224 L .55017 .25538 L p
1 g
F P
s
P
p
.002 w
.48367 .24943 m .55017 .25538 L .55068 .27224 L p
1 g
F P
s
P
p
.002 w
.49794 .6011 m .50843 .59851 L .52735 .61039 L p
1 g
F P
s
P
p
.002 w
.54395 .60132 m .52735 .61039 L .50843 .59851 L p
1 g
F P
s
P
p
.002 w
.55068 .27224 m .48098 .26602 L .48367 .24943 L p
1 g
F P
s
P
p
.002 w
.4582 .58872 m .46555 .5948 L .44417 .6032 L p
1 g
F P
s
P
p
.002 w
.44417 .6032 m .42968 .59143 L .4582 .58872 L p
1 g
F P
s
P
p
.002 w
.64113 .4996 m .64677 .53414 L .62134 .55106 L p
1 g
F P
s
P
p
.002 w
.64677 .53414 m .64113 .4996 L .66158 .47515 L p
1 g
F P
s
P
p
.002 w
.61377 .31812 m .66262 .35528 L .65868 .38081 L p
1 g
F P
s
P
p
.002 w
.66262 .35528 m .61377 .31812 L .61369 .2957 L p
1 g
F P
s
P
p
.002 w
.64986 .40855 m .67687 .44991 L .66158 .47515 L p
1 g
F P
s
P
p
.002 w
.67687 .44991 m .64986 .40855 L .65868 .38081 L p
1 g
F P
s
P
p
.002 w
.3733 .50119 m .36229 .52852 L .33968 .50737 L p
1 g
F P
s
P
p
.002 w
.33968 .50737 m .35224 .47434 L .3733 .50119 L p
1 g
F P
s
P
p
.002 w
.41023 .32691 m .35536 .35398 L .35536 .32803 L p
1 g
F P
s
P
p
.002 w
.35536 .32803 m .41096 .30008 L .41023 .32691 L p
1 g
F P
s
P
p
.002 w
.54395 .60132 m .55496 .58896 L .58532 .58579 L p
1 g
F P
s
P
p
.002 w
.5918 .56471 m .58532 .58579 L .55496 .58896 L p
1 g
F P
s
P
p
.002 w
.58532 .58579 m .5918 .56471 L .62134 .55106 L p
1 g
F P
s
P
p
.002 w
.50843 .59851 m .51688 .5938 L .54395 .60132 L p
1 g
F P
s
P
p
.002 w
.55496 .58896 m .54395 .60132 L .51688 .5938 L p
1 g
F P
s
P
p
.002 w
.55068 .27224 m .61369 .2957 L .61377 .31812 L p
1 g
F P
s
P
p
.002 w
.42024 .56248 m .42136 .57738 L .39152 .56898 L p
1 g
F P
s
P
p
.002 w
.39152 .56898 m .38943 .54713 L .42024 .56248 L p
1 g
F P
s
P
p
.002 w
.36846 .41401 m .33591 .4466 L .32474 .41895 L p
1 g
F P
s
P
p
.002 w
.32474 .41895 m .35972 .38295 L .36846 .41401 L p
1 g
F P
s
P
p
.002 w
.45409 .58153 m .4582 .58872 L .42968 .59143 L p
1 g
F P
s
P
p
.002 w
.42968 .59143 m .42136 .57738 L .45409 .58153 L p
1 g
F P
s
P
p
.002 w
.47877 .2882 m .41096 .30008 L .41428 .27793 L p
1 g
F P
s
P
p
.002 w
.41428 .27793 m .48098 .26602 L .47877 .2882 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.004 w
.4911 .54856 m
.5 .43051 L
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.48652 .60131 m .47533 .59914 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.49794 .6011 m .48652 .60131 L .48864 .58123 L p
1 g
F P
s
P
p
.002 w
.48866 .58123 m .49794 .6011 L p
.48864 .58123 L 1 g
F P
s
P
p
.002 w
.50843 .59851 m .49794 .6011 L .48866 .58123 L p
1 g
F P
s
P
p
.002 w
.48866 .58123 m .48864 .58119 L .48868 .58123 L p
1 g
F P
s
P
p
.002 w
.48868 .58123 m .50843 .59851 L p
.48866 .58123 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48902 .58122 L p
1 g
F P
s
P
p
.51079 .57862 m .48902 .58122 L .48913 .58122 L 1 g
F
P
p
.002 w
.52237 .58745 m .48883 .58122 L p
.48902 .58122 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51095 .58071 L p
1 g
F P
s
P
p
.002 w
.52421 .5804 m .52241 .58731 L p
.5 .58322 L 1 g
F P
s
P
p
.52421 .5804 m .5 .58322 L .51095 .58071 L 1 g
F
P
p
.53128 .57265 m .51095 .58071 L .51194 .58048 L 1 g
F
P
p
.002 w
.52367 .57771 m .52429 .5801 L .51194 .58048 L p
1 g
F P
s
P
p
.51951 .57869 m .51194 .58048 L .51932 .57878 L 1 g
F
P
p
.53128 .57265 m .51194 .58048 L .51951 .57869 L 1 g
F
P
p
.002 w
.48864 .58119 m .48873 .58117 L p
.48878 .58118 L 1 g
F P
s
P
p
.002 w
.45409 .58153 m .45371 .57398 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.45371 .57398 m .45539 .57051 L p
.46835 .57467 L 1 g
F P
s
P
p
.002 w
.47446 .57826 m .45371 .57398 L p
.46835 .57467 L 1 g
F P
s
P
p
.002 w
.46829 .57463 m .46872 .57265 L p
.45685 .56791 L 1 g
F P
s
P
p
.002 w
.48902 .58122 m .48921 .57862 L p
.47998 .57838 L 1 g
F P
s
P
p
.47998 .57838 m .48352 .57951 L .48902 .58122 L 1 g
F
P
p
.47986 .57837 m .48598 .58031 L .48902 .58122 L 1 g
F
P
p
.002 w
.48864 .58119 m .47446 .57826 L p
.46835 .57467 L 1 g
F P
s
P
p
.002 w
.48834 .58105 m .48864 .58119 L p
.45539 .57051 L 1 g
F P
s
P
p
.47952 .57836 m .48697 .58064 L .48902 .58122 L 1 g
F
P
p
.47893 .57835 m .48753 .58082 L .48902 .58122 L 1 g
F
P
p
.47808 .57832 m .4879 .58095 L .48902 .58122 L 1 g
F
P
p
.002 w
.4678 .57686 m .4723 .57817 L p
.48921 .57862 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45072 .56328 L p
1 g
F P
s
P
p
.46872 .57265 m .45072 .56328 L .45408 .56583 L 1 g
F
P
p
.002 w
.42024 .56248 m .4267 .54833 L .44867 .56172 L p
1 g
F P
s
P
p
.42024 .56248 m .44867 .56172 L .45072 .56328 L 1 g
F
P
p
.45327 .56643 m .45072 .56328 L .45516 .56665 L 1 g
F
P
p
.42024 .56248 m .45072 .56328 L .45327 .56643 L 1 g
F
P
p
.002 w
.45072 .56328 m .45146 .56129 L p
.44454 .55528 L 1 g
F P
s
P
p
.002 w
.45023 .56267 m .4267 .54833 L p
.44363 .55409 L 1 g
F P
s
P
p
.44454 .55528 m .44353 .5544 L .45023 .56267 L 1 g
F
P
p
.44454 .55528 m .45023 .56267 L .45072 .56328 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.4641 .56105 m .45715 .56689 L .45023 .56267 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43839 .54728 L p
1 g
F P
s
P
p
.002 w
.4267 .54833 m .43418 .54181 L p
.43839 .54728 L 1 g
F P
s
P
p
.44052 .55303 m .43839 .54728 L .44363 .55409 L 1 g
F
P
p
.4267 .54833 m .43839 .54728 L .44052 .55303 L 1 g
F
P
p
.002 w
.43839 .54728 m .43925 .54566 L p
.43488 .53701 L 1 g
F P
s
P
p
.002 w
.4267 .54833 m .3984 .52616 L p
.43433 .53509 L 1 g
F P
s
P
p
.002 w
.43584 .54037 m .4267 .54833 L p
.43433 .53509 L 1 g
F P
s
P
p
.002 w
.3984 .52616 m .41792 .50853 L .43169 .52584 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.3984 .52616 m .43169 .52584 L .43251 .52872 L 1 g
F
P
p
.43224 .53457 m .43251 .52872 L .43433 .53509 L 1 g
F
P
p
.3984 .52616 m .43251 .52872 L .43224 .53457 L 1 g
F
P
p
.002 w
.43251 .52872 m .43346 .52734 L p
.43319 .51961 L 1 g
F P
s
P
p
.002 w
.4326 .52697 m .41792 .50853 L p
.43348 .51604 L 1 g
F P
s
P
p
.43319 .51961 m .43308 .51648 L .4326 .52697 L 1 g
F
P
p
.43319 .51961 m .4326 .52697 L .43251 .52872 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43245 .52882 L p
1 g
F P
s
P
p
.002 w
.43245 .52882 m .43146 .53025 L p
.43415 .53558 L 1 g
F P
s
P
p
.43925 .54566 m .43245 .52882 L .43415 .53558 L 1 g
F
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43403 .50923 L p
1 g
F P
s
P
p
.002 w
.41792 .50853 m .43467 .50136 L p
.43403 .50923 L 1 g
F P
s
P
p
.43133 .515 m .43403 .50923 L .43348 .51604 L 1 g
F
P
p
.41792 .50853 m .43403 .50923 L .43133 .515 L 1 g
F
P
p
.002 w
.43403 .50923 m .43485 .50826 L p
.43862 .49945 L 1 g
F P
s
P
p
.002 w
.43849 .49972 m .41792 .50853 L p
.44101 .49453 L 1 g
F P
s
P
p
.43862 .49945 m .43867 .49933 L .43849 .49972 L 1 g
F
P
p
.43862 .49945 m .43849 .49972 L .43403 .50923 L 1 g
F
P
p
.002 w
.41792 .50853 m .39806 .478 L p
.44101 .49453 L 1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43346 .52734 m .43403 .50923 L .43319 .51961 L 1 g
F
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43403 .50923 m .44607 .49647 L .43348 .51604 L 1 g
F
P
p
.002 w
.43467 .50136 m .43849 .49972 L p
.43403 .50923 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44253 .49142 L p
1 g
F P
s
P
p
.39806 .478 m .44359 .48924 L .44253 .49142 L 1 g
F
P
p
.43979 .49406 m .44253 .49142 L .44101 .49453 L 1 g
F
P
p
.39806 .478 m .44253 .49142 L .43979 .49406 L 1 g
F
P
p
.002 w
.44253 .49142 m .44223 .49174 L p
.44061 .49536 L 1 g
F P
s
P
p
.43485 .50826 m .44253 .49142 L .44061 .49536 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44253 .49142 m .44339 .4905 L p
.44947 .48467 L 1 g
F P
s
P
p
.45732 .47705 m .47965 .49162 L .44389 .49011 L 1 g
F
P
p
.44947 .48467 m .45455 .47981 L .44389 .49011 L 1 g
F
P
p
.44947 .48467 m .44389 .49011 L .44253 .49142 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.47965 .49162 m .44607 .49647 L .44389 .49011 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44101 .49453 m .44253 .49142 L .44607 .49647 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45786 .47652 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.45732 .47705 m .45786 .47652 L .47965 .49162 L 1 g
F
P
p
.002 w
.45786 .47652 m .45826 .47608 L p
.46537 .47296 L 1 g
F P
s
P
p
.45786 .47652 m .47754 .4672 L .47965 .49162 L 1 g
F
P
p
.002 w
.47754 .4672 m .47786 .46667 L p
.48699 .46576 L 1 g
F P
s
P
p
.48734 .46571 m .51459 .49467 L .47833 .4671 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.47771 .45547 m .523 .45944 L .52281 .46023 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54655 .50525 m .51459 .49467 L .52118 .46706 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52247 .46722 L p
1 g
F P
s
P
p
.5 .4634 m .52247 .46722 L .52161 .46711 L 1 g
F
P
p
.52247 .46722 m .54655 .50525 L .52118 .46706 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54215 .47653 L p
1 g
F P
s
P
p
.52214 .46667 m .54215 .47653 L .53093 .47122 L 1 g
F
P
p
.52845 .47005 m .54655 .50525 L .52247 .46722 L 1 g
F
P
p
.002 w
.52247 .46722 m .52214 .46667 L p
.53093 .47122 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.523 .45944 m .5254 .46025 L p
.54655 .50525 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56591 .50917 L p
1 g
F P
s
P
p
.55661 .4905 m .56591 .50917 L .56094 .49878 L 1 g
F
P
p
.5687 .50224 m .5717 .52195 L .56608 .51074 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5675 .52873 L p
1 g
F P
s
P
p
.5717 .52195 m .56757 .5316 L .5675 .52873 L 1 g
F
P
p
.002 w
.56742 .52571 m .56891 .5244 L p
.5675 .52873 L 1 g
F P
s
P
p
.002 w
.56891 .5244 m .5717 .52195 L p
.5675 .52873 L 1 g
F P
s
P
p
.002 w
.5675 .52873 m .56654 .52734 L p
.56475 .53711 L 1 g
F P
s
P
p
.56515 .50826 m .5675 .52873 L .56742 .52571 L 1 g
F
P
p
.002 w
.56695 .5188 m .5717 .52195 L .56742 .52571 L p
1 g
F P
s
P
p
.56727 .52352 m .56742 .52571 L .56738 .52433 L 1 g
F
P
p
.56515 .50826 m .56742 .52571 L .56727 .52352 L 1 g
F
P
p
.56515 .50826 m .56812 .52964 L .56737 .52263 L 1 g
F
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.5687 .50224 m .56631 .51 L .56476 .49843 L 1 g
F
P
p
.56631 .51 m .56608 .51074 L .56591 .50917 L 1 g
F
P
p
.56631 .51 m .56591 .50917 L .56476 .49843 L 1 g
F
P
p
.002 w
.55735 .49128 m .55661 .4905 L p
.56094 .49878 L 1 g
F P
s
P
p
.002 w
.56591 .50917 m .56515 .50826 L p
.56737 .52263 L 1 g
F P
s
P
p
.002 w
.5717 .52195 m .54655 .50525 L .55539 .48939 L p
1 g
F P
s
P
p
.002 w
.5717 .52195 m .58725 .5426 L .56811 .55285 L p
1 g
F P
s
P
p
.002 w
.56811 .55285 m .55562 .55954 L p
.56008 .54912 L 1 g
F P
s
P
p
.56773 .53807 m .56811 .55285 L .56073 .54942 L 1 g
F
P
p
.5615 .54707 m .56073 .54942 L .56008 .54912 L 1 g
F
P
p
.56773 .53807 m .56073 .54942 L .5615 .54707 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5615 .54707 L p
1 g
F P
s
P
p
.56654 .52734 m .5615 .54707 L .56475 .53711 L 1 g
F
P
p
.002 w
.5615 .54707 m .56075 .54566 L p
.55408 .55776 L 1 g
F P
s
P
p
.002 w
.55416 .55766 m .55562 .55954 L .55101 .56134 L p
1 g
F P
s
P
p
.55408 .55776 m .55402 .55787 L .55416 .55766 L 1 g
F
P
p
.55408 .55776 m .55416 .55766 L .5615 .54707 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.56757 .5316 m .56008 .54912 L .56742 .52571 L 1 g
F
P
p
.56008 .54912 m .55562 .55954 L .55842 .55151 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54927 .56325 L p
1 g
F P
s
P
p
.55562 .55954 m .53547 .57831 L .54821 .56441 L 1 g
F
P
p
.56075 .54566 m .54927 .56325 L .55197 .5603 L 1 g
F
P
p
.002 w
.52429 .5801 m .52416 .57961 L p
.53233 .57446 L 1 g
F P
s
P
p
.002 w
.52416 .57961 m .52367 .57771 L p
.53172 .57468 L 1 g
F P
s
P
p
.53233 .57446 m .52416 .57961 L .53172 .57468 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57468 L p
1 g
F P
s
P
p
.54854 .56129 m .53172 .57468 L .54047 .56898 L 1 g
F
P
p
.002 w
.52429 .5801 m .52421 .5804 L p
.51101 .58069 L 1 g
F P
s
P
p
.47698 .5783 m .48819 .58104 L .48902 .58122 L 1 g
F
P
p
.47566 .57826 m .48843 .5811 L .48902 .58122 L 1 g
F
P
p
.002 w
.48856 .58112 m .48864 .58119 L .48834 .58105 L p
1 g
F P
s
P
p
.47426 .57822 m .48864 .58115 L .48902 .58122 L 1 g
F
P
p
.47304 .57819 m .48883 .58118 L .48902 .58122 L 1 g
F
P
p
.51095 .58071 m .5 .58322 L .48902 .58122 L 1 g
F
P
p
.002 w
.52241 .58731 m .52237 .58745 L p
.48902 .58122 L 1 g
F P
s
P
p
.49894 .58099 m .48902 .58123 L .49716 .58134 L 1 g
F
P
p
.51079 .57862 m .48913 .58122 L .49894 .58099 L 1 g
F
P
p
.48913 .58122 m .48902 .58123 L .49894 .58099 L 1 g
F
P
p
.002 w
.51104 .582 m .51079 .57862 L p
.49642 .58149 L 1 g
F P
s
P
p
.002 w
.48864 .58119 m .51194 .58048 L p
.51101 .58069 L 1 g
F P
s
P
p
.002 w
.51194 .58048 m .52429 .5801 L p
.51101 .58069 L 1 g
F P
s
P
p
.002 w
.53172 .57468 m .53128 .57265 L p
.51932 .57878 L 1 g
F P
s
P
p
.002 w
.48883 .58122 m .48864 .58119 L p
.52421 .5804 L 1 g
F P
s
P
p
.51932 .57878 m .51531 .58084 L .52313 .57791 L 1 g
F
P
p
.51932 .57878 m .52313 .57791 L .53172 .57468 L 1 g
F
P
p
.002 w
.54927 .56325 m .54854 .56129 L p
.54047 .56898 L 1 g
F P
s
P
p
.002 w
.52235 .57255 m .55101 .56134 L p
.53567 .57211 L 1 g
F P
s
P
p
.53567 .57211 m .53233 .57446 L .53213 .57442 L 1 g
F
P
p
.53567 .57211 m .53213 .57442 L .52235 .57255 L 1 g
F
P
p
.002 w
.55101 .56134 m .55562 .55954 L p
.54821 .56441 L 1 g
F P
s
P
p
.54821 .56441 m .52429 .5801 L .55101 .56134 L 1 g
F
P
p
.002 w
.55562 .55954 m .55908 .57453 L .53547 .57831 L p
1 g
F P
s
P
p
.002 w
.53547 .57831 m .52429 .5801 L p
.54821 .56441 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54927 .56325 L p
1 g
F P
s
P
p
.54047 .56898 m .5322 .57686 L .54927 .56325 L 1 g
F
P
p
.002 w
.52367 .57771 m .52235 .57255 L p
.53233 .57446 L 1 g
F P
s
P
p
.002 w
.53172 .57468 m .5322 .57686 L p
.54047 .56898 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57468 L p
1 g
F P
s
P
p
.51531 .58084 m .51111 .583 L .53172 .57468 L 1 g
F
P
p
.002 w
.54962 .56421 m .54998 .56518 L p
.55375 .55836 L 1 g
F P
s
P
p
.55402 .55787 m .55346 .55867 L .55375 .55836 L 1 g
F
P
p
.55346 .55867 m .54962 .56421 L .55375 .55836 L 1 g
F
P
p
.002 w
.54927 .56325 m .54962 .56421 L p
.55197 .5603 L 1 g
F P
s
P
p
.56075 .54566 m .54962 .56421 L .55402 .55787 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56008 .54912 m .55842 .55151 L .56742 .52571 L 1 g
F
P
p
.002 w
.54476 .54565 m .55416 .55766 L p
.52235 .57255 L 1 g
F P
s
P
p
.002 w
.55101 .56134 m .52235 .57255 L p
.55416 .55766 L 1 g
F P
s
P
p
.56757 .5316 m .56773 .53807 L .56008 .54912 L 1 g
F
P
p
.002 w
.5615 .54707 m .56257 .5491 L p
.56475 .53711 L 1 g
F P
s
P
p
.002 w
.55562 .55954 m .54476 .54565 L .56742 .52571 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5615 .54707 L p
1 g
F P
s
P
p
.55402 .55787 m .54998 .56518 L .5615 .54707 L 1 g
F
P
p
.5717 .52195 m .56811 .55285 L .56757 .5316 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56703 .5105 L p
1 g
F P
s
P
p
.002 w
.56703 .5105 m .56591 .50917 L p
.56728 .5201 L 1 g
F P
s
P
p
.56728 .5201 m .56854 .53025 L .56703 .5105 L 1 g
F
P
p
.56737 .52263 m .56854 .53025 L .56591 .50917 L 1 g
F
P
p
.56476 .49843 m .56608 .51074 L .55539 .48939 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55735 .49128 L p
1 g
F P
s
P
p
.56094 .49878 m .56713 .51061 L .55735 .49128 L 1 g
F
P
p
.002 w
.54655 .50525 m .56695 .5188 L p
.54476 .54565 L 1 g
F P
s
P
p
.002 w
.56742 .52571 m .54476 .54565 L p
.56695 .5188 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5675 .52873 L p
1 g
F P
s
P
p
.56475 .53711 m .56257 .5491 L .5675 .52873 L 1 g
F
P
p
.002 w
.5675 .52873 m .56812 .52964 L p
.56738 .52433 L 1 g
F P
s
P
p
.002 w
.56812 .52964 m .56854 .53025 L p
.56737 .52263 L 1 g
F P
s
P
p
.002 w
.56591 .50917 m .56713 .51061 L p
.56094 .49878 L 1 g
F P
s
P
p
.56431 .47339 m .5687 .50224 L .55735 .49128 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55735 .49128 L p
1 g
F P
s
P
p
.54174 .47608 m .55735 .49128 L .55604 .49002 L 1 g
F
P
p
.54174 .47608 m .55751 .49145 L .54848 .48268 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55539 .48939 m .55595 .48838 L p
.55735 .49128 L 1 g
F P
s
P
p
.002 w
.55595 .48838 m .56431 .47339 L p
.55735 .49128 L 1 g
F P
s
P
p
.002 w
.55735 .49128 m .55751 .49145 L p
.55604 .49002 L 1 g
F P
s
P
p
.002 w
.55539 .48939 m .54655 .50525 L p
.5254 .46025 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.5254 .46025 m .56431 .47339 L .55539 .48939 L p
1 g
F P
s
P
p
.002 w
.55751 .49145 m .55834 .49233 L p
.54848 .48268 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52247 .46722 L p
1 g
F P
s
P
p
.53093 .47122 m .54302 .47747 L .52247 .46722 L 1 g
F
P
p
.523 .45944 m .52731 .46782 L .52247 .46722 L 1 g
F
P
p
.5 .4634 m .52161 .46711 L .50972 .46527 L 1 g
F
P
p
.52161 .46711 m .5225 .46726 L .52118 .46706 L 1 g
F
P
p
.52161 .46711 m .52118 .46706 L .50972 .46527 L 1 g
F
P
p
.002 w
.52118 .46706 m .52128 .46665 L p
.52247 .46722 L 1 g
F P
s
P
p
.002 w
.52128 .46665 m .523 .45944 L p
.52247 .46722 L 1 g
F P
s
P
p
.52731 .46782 m .52845 .47005 L .52247 .46722 L 1 g
F
P
p
.002 w
.54215 .47653 m .54302 .47747 L p
.53093 .47122 L 1 g
F P
s
P
p
.002 w
.52247 .46722 m .5225 .46726 L p
.52161 .46711 L 1 g
F P
s
P
p
.002 w
.52118 .46706 m .51459 .49467 L p
.5 .46375 L 1 g
F P
s
P
p
.002 w
.5225 .46726 m .52282 .46778 L p
.50972 .46527 L 1 g
F P
s
P
p
.48734 .46571 m .5 .46375 L .51459 .49467 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46375 L p
1 g
F P
s
P
p
.002 w
.5 .46375 m .5 .4634 L p
.50972 .46527 L 1 g
F P
s
P
p
.50972 .46527 m .52282 .46778 L .5 .46375 L 1 g
F
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.47771 .45547 m .52281 .46023 L .5 .46375 L 1 g
F
P
p
.47786 .46667 m .48739 .4657 L .48699 .46576 L 1 g
F
P
p
.483 .4611 m .5 .46375 L .48734 .46571 L 1 g
F
P
p
.47771 .45547 m .5 .46375 L .483 .4611 L 1 g
F
P
p
.002 w
.52281 .46023 m .52118 .46706 L p
.5 .46375 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .49895 .46457 L p
.48699 .46576 L 1 g
F P
s
P
p
.48739 .4657 m .5 .46442 L .48699 .46576 L 1 g
F
P
p
.48699 .46576 m .49895 .46457 L .47833 .4671 L 1 g
F
P
p
.48699 .46576 m .47833 .4671 L .47754 .4672 L 1 g
F
P
p
.002 w
.51459 .49467 m .47965 .49162 L .47833 .4671 L p
1 g
F P
s
P
p
.002 w
.47833 .4671 m .47771 .45547 L p
.48734 .46571 L 1 g
F P
s
P
p
.002 w
.47832 .46683 m .47833 .4671 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.47833 .4671 m .47965 .49162 L p
.47754 .4672 L 1 g
F P
s
P
p
.002 w
.49895 .46457 m .47718 .46778 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47754 .4672 L p
1 g
F P
s
P
p
.002 w
.47754 .4672 m .47718 .46778 L p
.46537 .47296 L 1 g
F P
s
P
p
.45826 .47608 m .47754 .4672 L .46537 .47296 L 1 g
F
P
p
.43424 .46199 m .4778 .45713 L .45786 .47652 L 1 g
F
P
p
.45708 .47689 m .45786 .47652 L .45732 .47705 L 1 g
F
P
p
.43424 .46199 m .45786 .47652 L .45708 .47689 L 1 g
F
P
p
.002 w
.4778 .45713 m .47832 .46683 L p
.45786 .47652 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45786 .47652 L p
1 g
F P
s
P
p
.46537 .47296 m .47718 .46778 L .45786 .47652 L 1 g
F
P
p
.002 w
.45786 .47652 m .45712 .47732 L p
.45014 .48403 L 1 g
F P
s
P
p
.44339 .4905 m .45786 .47652 L .45014 .48403 L 1 g
F
P
p
.002 w
.43424 .46199 m .47771 .45547 L .4778 .45713 L p
1 g
F P
s
P
p
.44339 .4905 m .45712 .47732 L .45455 .47981 L 1 g
F
P
p
.002 w
.44359 .48924 m .44389 .49011 L p
.44253 .49142 L 1 g
F P
s
P
p
.002 w
.44389 .49011 m .44607 .49647 L p
.44253 .49142 L 1 g
F P
s
P
p
.002 w
.45712 .47732 m .45698 .47747 L p
.45455 .47981 L 1 g
F P
s
P
p
.002 w
.44389 .49011 m .43424 .46199 L p
.45732 .47705 L 1 g
F P
s
P
p
.002 w
.44223 .49174 m .44166 .49233 L p
.43867 .49933 L 1 g
F P
s
P
p
.43485 .50826 m .44223 .49174 L .43867 .49933 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44253 .49142 L p
1 g
F P
s
P
p
.45455 .47981 m .45698 .47747 L .44253 .49142 L 1 g
F
P
p
.002 w
.39806 .478 m .43424 .46199 L .44359 .48924 L p
1 g
F P
s
P
p
.002 w
.43849 .49972 m .44607 .49647 L p
.43403 .50923 L 1 g
F P
s
P
p
.002 w
.44607 .49647 m .43849 .49972 L p
.44101 .49453 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43403 .50923 L p
1 g
F P
s
P
p
.43867 .49933 m .44166 .49233 L .43403 .50923 L 1 g
F
P
p
.002 w
.43403 .50923 m .43287 .51061 L p
.43319 .51961 L 1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44607 .49647 m .45944 .52857 L p
.43348 .51604 L 1 g
F P
s
P
p
.002 w
.45944 .52857 m .44022 .53655 L .4326 .52697 L p
1 g
F P
s
P
p
.43348 .51604 m .45944 .52857 L .4326 .52697 L 1 g
F
P
p
.002 w
.43169 .52584 m .44022 .53655 L p
.43433 .53509 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52872 L p
1 g
F P
s
P
p
.43308 .51648 m .43287 .51061 L .43251 .52872 L 1 g
F
P
p
.45146 .56129 m .43839 .54728 L .44454 .55528 L 1 g
F
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.43839 .54728 m .44022 .53655 L .44363 .55409 L 1 g
F
P
p
.002 w
.43418 .54181 m .43584 .54037 L p
.43839 .54728 L 1 g
F P
s
P
p
.43488 .53701 m .43584 .54037 L .43839 .54728 L 1 g
F
P
p
.002 w
.43584 .54037 m .44022 .53655 L p
.43839 .54728 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43801 .548 L p
1 g
F P
s
P
p
.002 w
.43801 .548 m .43839 .54728 L p
.43644 .54248 L 1 g
F P
s
P
p
.43644 .54248 m .43146 .53025 L .43801 .548 L 1 g
F
P
p
.43488 .53701 m .43382 .53491 L .43584 .54037 L 1 g
F
P
p
.002 w
.44022 .53655 m .43584 .54037 L p
.43433 .53509 L 1 g
F P
s
P
p
.43382 .53491 m .43146 .53025 L .43839 .54728 L 1 g
F
P
p
.002 w
.43839 .54728 m .43743 .5491 L p
.44454 .55528 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44022 .53655 m .4641 .56105 L p
.44363 .55409 L 1 g
F P
s
P
p
.44363 .55409 m .4641 .56105 L .45023 .56267 L 1 g
F
P
p
.46872 .57265 m .45408 .56583 L .45685 .56791 L 1 g
F
P
p
.002 w
.45371 .57398 m .42024 .56248 L p
.45516 .56665 L 1 g
F P
s
P
p
.002 w
.4567 .56782 m .45371 .57398 L p
.45516 .56665 L 1 g
F P
s
P
p
.45408 .56583 m .45041 .56412 L .4567 .56782 L 1 g
F
P
p
.45408 .56583 m .4567 .56782 L .45685 .56791 L 1 g
F
P
p
.002 w
.44867 .56172 m .45715 .56689 L p
.45516 .56665 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45072 .56328 L p
1 g
F P
s
P
p
.44353 .5544 m .43743 .5491 L .45072 .56328 L 1 g
F
P
p
.002 w
.45539 .57051 m .4567 .56782 L p
.46829 .57463 L 1 g
F P
s
P
p
.002 w
.45041 .56412 m .45002 .56518 L p
.45678 .56788 L 1 g
F P
s
P
p
.45685 .56791 m .4567 .56782 L .45678 .56788 L 1 g
F
P
p
.4567 .56782 m .45041 .56412 L .45678 .56788 L 1 g
F
P
p
.002 w
.45072 .56328 m .45041 .56412 L p
.45408 .56583 L 1 g
F P
s
P
p
.002 w
.45715 .56689 m .4567 .56782 L p
.45516 .56665 L 1 g
F P
s
P
p
.002 w
.45715 .56689 m .48834 .58105 L p
.46829 .57463 L 1 g
F P
s
P
p
.002 w
.4567 .56782 m .45715 .56689 L p
.46829 .57463 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57463 L p
1 g
F P
s
P
p
.45685 .56791 m .45002 .56518 L .46829 .57463 L 1 g
F
P
p
.47998 .57838 m .47986 .57837 L .48352 .57951 L 1 g
F
P
p
.47986 .57837 m .47952 .57836 L .48598 .58031 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45715 .56689 m .4641 .56105 L .48856 .58112 L p
1 g
F P
s
P
p
.002 w
.48834 .58105 m .45715 .56689 L p
.48856 .58112 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.4641 .56105 m .47382 .55712 L .48861 .58114 L p
1 g
F P
s
P
p
.002 w
.48861 .58114 m .48864 .58119 L .48856 .58112 L p
1 g
F P
s
P
p
.002 w
.48856 .58112 m .4641 .56105 L p
.48861 .58114 L 1 g
F P
s
P
p
.47952 .57836 m .47893 .57835 L .48697 .58064 L 1 g
F
P
p
.47893 .57835 m .47808 .57832 L .48753 .58082 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47382 .55712 m .48524 .55558 L .48864 .58115 L p
1 g
F P
s
P
p
.002 w
.48864 .58115 m .48864 .58119 L .48861 .58114 L p
1 g
F P
s
P
p
.002 w
.48861 .58114 m .47382 .55712 L p
.48864 .58115 L 1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48524 .55558 m .49708 .55661 L .48866 .58115 L p
1 g
F P
s
P
p
.002 w
.48866 .58115 m .48864 .58119 L .48864 .58115 L p
1 g
F P
s
P
p
.002 w
.48864 .58115 m .48524 .55558 L p
.48866 .58115 L 1 g
F P
s
P
p
.47808 .57832 m .47698 .5783 L .4879 .58095 L 1 g
F
P
p
.47698 .5783 m .47566 .57826 L .48819 .58104 L 1 g
F
P
p
.002 w
.49708 .55661 m .50798 .56009 L .48868 .58116 L p
1 g
F P
s
P
p
.002 w
.48868 .58116 m .48864 .58119 L .48866 .58115 L p
1 g
F P
s
P
p
.002 w
.48866 .58115 m .49708 .55661 L p
.48868 .58116 L 1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.50798 .56009 m .51672 .56562 L .4887 .58116 L p
1 g
F P
s
P
p
.002 w
.4887 .58116 m .48864 .58119 L .48868 .58116 L p
1 g
F P
s
P
p
.002 w
.48868 .58116 m .50798 .56009 L p
.4887 .58116 L 1 g
F P
s
P
p
.47566 .57826 m .47426 .57822 L .48843 .5811 L 1 g
F
P
p
.47426 .57822 m .47304 .57819 L .48864 .58115 L 1 g
F
P
p
.002 w
.51672 .56562 m .52235 .57255 L .48873 .58117 L p
1 g
F P
s
P
p
.002 w
.48873 .58117 m .48864 .58119 L .4887 .58116 L p
1 g
F P
s
P
p
.002 w
.4887 .58116 m .51672 .56562 L p
.48873 .58117 L 1 g
F P
s
P
p
.002 w
.51194 .58048 m .48883 .58118 L p
.52367 .57771 L 1 g
F P
s
P
p
.002 w
.48883 .58118 m .48864 .58119 L p
.48878 .58118 L 1 g
F P
s
P
p
.52367 .57771 m .48883 .58118 L .48878 .58118 L 1 g
F
P
p
.47304 .57819 m .4723 .57817 L .48883 .58118 L 1 g
F
P
p
.002 w
.48864 .58123 m .48864 .58119 L .48866 .58123 L p
1 g
F P
s
P
p
.002 w
.47533 .59914 m .46555 .5948 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.51688 .5938 m .50843 .59851 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.46555 .5948 m .4582 .58872 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.52237 .58745 m .51688 .5938 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.4582 .58872 m .45409 .58153 L .48864 .58119 L closepath p
1 g
F P
s
P
p
.002 w
.4723 .57817 m .48889 .583 L .48902 .58122 L p
1 g
F P
s
P
p
.002 w
.48902 .58122 m .48902 .58122 L p
.48883 .58118 L 1 g
F P
s
P
p
.48883 .58118 m .4723 .57817 L .48902 .58122 L 1 g
F
P
p
.002 w
.52235 .57255 m .52367 .57771 L p
.48878 .58118 L 1 g
F P
s
P
p
.002 w
.48873 .58117 m .52235 .57255 L p
.48878 .58118 L 1 g
F P
s
P
p
.002 w
.51095 .58071 m .51111 .583 L p
.51932 .57878 L 1 g
F P
s
P
p
.002 w
.48902 .58122 m .48902 .58123 L p
.48913 .58122 L 1 g
F P
s
P
p
.002 w
.48902 .58123 m .48889 .583 L p
.49716 .58134 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51104 .582 L p
1 g
F P
s
P
p
.49642 .58149 m .48889 .583 L .51104 .582 L 1 g
F
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.61608 .52237 m .62134 .55106 L .5918 .56471 L p
1 g
F P
s
P
p
.002 w
.62134 .55106 m .61608 .52237 L .64113 .4996 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.3984 .52616 m .38943 .54713 L .36229 .52852 L p
1 g
F P
s
P
p
.002 w
.36229 .52852 m .3733 .50119 L .3984 .52616 L p
1 g
F P
s
P
p
.002 w
.51688 .5938 m .52237 .58745 L .55496 .58896 L p
1 g
F P
s
P
p
.002 w
.55908 .57453 m .55496 .58896 L .52237 .58745 L p
1 g
F P
s
P
p
.002 w
.55496 .58896 m .55908 .57453 L .5918 .56471 L p
1 g
F P
s
P
p
.002 w
.63629 .43758 m .66158 .47515 L .64113 .4996 L p
1 g
F P
s
P
p
.002 w
.66158 .47515 m .63629 .43758 L .64986 .40855 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.45371 .57398 m .45409 .58153 L .42136 .57738 L p
1 g
F P
s
P
p
.002 w
.42136 .57738 m .42024 .56248 L .45371 .57398 L p
1 g
F P
s
P
p
.002 w
.61039 .34467 m .65868 .38081 L .64986 .40855 L p
1 g
F P
s
P
p
.002 w
.65868 .38081 m .61039 .34467 L .61377 .31812 L p
1 g
F P
s
P
p
.002 w
.61377 .31812 m .54966 .29451 L .55068 .27224 L p
1 g
F P
s
P
p
.002 w
.48098 .26602 m .55068 .27224 L .54966 .29451 L p
1 g
F P
s
P
p
.002 w
.54966 .29451 m .47877 .2882 L .48098 .26602 L p
1 g
F P
s
P
p
.002 w
.38137 .44609 m .35224 .47434 L .33591 .4466 L p
1 g
F P
s
P
p
.002 w
.33591 .4466 m .36846 .41401 L .38137 .44609 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.41224 .35762 m .35972 .38295 L .35536 .35398 L p
1 g
F P
s
P
p
.002 w
.35536 .35398 m .41023 .32691 L .41224 .35762 L p
1 g
F P
s
P
p
.002 w
.58725 .5426 m .5918 .56471 L .55908 .57453 L p
1 g
F P
s
P
p
.002 w
.5918 .56471 m .58725 .5426 L .61608 .52237 L p
1 g
F P
s
P
p
.002 w
.4267 .54833 m .42024 .56248 L .38943 .54713 L p
1 g
F P
s
P
p
.002 w
.38943 .54713 m .3984 .52616 L .4267 .54833 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.54966 .29451 m .61377 .31812 L .61039 .34467 L p
1 g
F P
s
P
p
.002 w
.52237 .58745 m .52429 .5801 L .55908 .57453 L p
1 g
F P
s
P
p
.002 w
.47714 .31545 m .41023 .32691 L .41096 .30008 L p
1 g
F P
s
P
p
.002 w
.41096 .30008 m .47877 .2882 L .47714 .31545 L p
1 g
F P
s
P
p
.002 w
.61832 .46687 m .64113 .4996 L .61608 .52237 L p
1 g
F P
s
P
p
.002 w
.64113 .4996 m .61832 .46687 L .63629 .43758 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.55908 .57453 m .55562 .55954 L .58725 .5426 L p
1 g
F P
s
P
p
.002 w
.39806 .478 m .3733 .50119 L .35224 .47434 L p
1 g
F P
s
P
p
.002 w
.35224 .47434 m .38137 .44609 L .39806 .478 L p
1 g
F P
s
P
p
.002 w
.60353 .37455 m .64986 .40855 L .63629 .43758 L p
1 g
F P
s
P
p
.002 w
.64986 .40855 m .60353 .37455 L .61039 .34467 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.41702 .39121 m .36846 .41401 L .35972 .38295 L p
1 g
F P
s
P
p
.002 w
.35972 .38295 m .41224 .35762 L .41702 .39121 L p
1 g
F P
s
P
p
.002 w
.59653 .49536 m .61608 .52237 L .58725 .5426 L p
1 g
F P
s
P
p
.002 w
.61608 .52237 m .59653 .49536 L .61832 .46687 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.41792 .50853 m .3984 .52616 L .3733 .50119 L p
1 g
F P
s
P
p
.002 w
.3733 .50119 m .39806 .478 L .41792 .50853 L p
1 g
F P
s
P
p
.002 w
.61039 .34467 m .5471 .32167 L .54966 .29451 L p
1 g
F P
s
P
p
.002 w
.47877 .2882 m .54966 .29451 L .5471 .32167 L p
1 g
F P
s
P
p
.002 w
.5471 .32167 m .47714 .31545 L .47877 .2882 L p
1 g
F P
s
P
p
.002 w
.52235 .57255 m .51672 .56562 L .54476 .54565 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.58725 .5426 m .5717 .52195 L .59653 .49536 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.5471 .32167 m .61039 .34467 L .60353 .37455 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.47617 .34698 m .41224 .35762 L .41023 .32691 L p
1 g
F P
s
P
p
.002 w
.41023 .32691 m .47714 .31545 L .47617 .34698 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.59334 .40676 m .63629 .43758 L .61832 .46687 L p
1 g
F P
s
P
p
.002 w
.63629 .43758 m .59334 .40676 L .60353 .37455 L p
1 g
F P
s
P
p
.002 w
.51672 .56562 m .50798 .56009 L .52753 .5345 L p
1 g
F P
s
P
p
.002 w
.52753 .5345 m .54476 .54565 L .51672 .56562 L p
1 g
F P
s
P
p
.002 w
.47382 .55712 m .4641 .56105 L .44022 .53655 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.42443 .42644 m .38137 .44609 L .36846 .41401 L p
1 g
F P
s
P
p
.002 w
.36846 .41401 m .41702 .39121 L .42443 .42644 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.50798 .56009 m .49708 .55661 L .50583 .52746 L p
1 g
F P
s
P
p
.002 w
.50583 .52746 m .52753 .5345 L .50798 .56009 L p
1 g
F P
s
P
p
.002 w
.48524 .55558 m .47382 .55712 L .45944 .52857 L p
1 g
F P
s
P
p
.002 w
.44022 .53655 m .45944 .52857 L .47382 .55712 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.49708 .55661 m .48524 .55558 L .4822 .5254 L p
1 g
F P
s
P
p
.002 w
.4822 .5254 m .50583 .52746 L .49708 .55661 L p
1 g
F P
s
P
p
.002 w
.45944 .52857 m .4822 .5254 L .48524 .55558 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58011 .44013 m .61832 .46687 L .59653 .49536 L p
1 g
F P
s
P
p
.002 w
.61832 .46687 m .58011 .44013 L .59334 .40676 L p
1 g
F P
s
P
p
.002 w
.54476 .54565 m .52753 .5345 L .54655 .50525 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.43424 .46199 m .39806 .478 L .38137 .44609 L p
1 g
F P
s
P
p
.002 w
.38137 .44609 m .42443 .42644 L .43424 .46199 L p
1 g
F P
s
P
p
.002 w
.60353 .37455 m .543 .3529 L .5471 .32167 L p
1 g
F P
s
P
p
.002 w
.47714 .31545 m .5471 .32167 L .543 .3529 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.543 .3529 m .60353 .37455 L .59334 .40676 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.543 .3529 m .47617 .34698 L .47714 .31545 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.56431 .47339 m .59653 .49536 L .5717 .52195 L p
1 g
F P
s
P
p
.002 w
.59653 .49536 m .56431 .47339 L .58011 .44013 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.47593 .3817 m .41702 .39121 L .41224 .35762 L p
1 g
F P
s
P
p
.002 w
.41224 .35762 m .47617 .34698 L .47593 .3817 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.52753 .5345 m .50583 .52746 L .51459 .49467 L p
1 g
F P
s
P
p
.002 w
.51459 .49467 m .54655 .50525 L .52753 .5345 L p
1 g
F P
s
P
p
.002 w
.4822 .5254 m .45944 .52857 L .44607 .49647 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50583 .52746 m .4822 .5254 L .47965 .49162 L p
1 g
F P
s
P
p
.002 w
.47965 .49162 m .51459 .49467 L .50583 .52746 L p
1 g
F P
s
P
p
.002 w
.44607 .49647 m .47965 .49162 L .4822 .5254 L p
1 g
F P
s
P
p
.002 w
.53749 .38714 m .59334 .40676 L .58011 .44013 L p
1 g
F P
s
P
p
.002 w
.59334 .40676 m .53749 .38714 L .543 .3529 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.004 w
.48403 .64241 m
.48477 .63261 L
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.47645 .41834 m .42443 .42644 L .41702 .39121 L p
1 g
F P
s
P
p
.002 w
.41702 .39121 m .47593 .3817 L .47645 .41834 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47617 .34698 m .543 .3529 L .53749 .38714 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53749 .38714 m .47593 .3817 L .47617 .34698 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.53073 .42312 m .58011 .44013 L .56431 .47339 L p
1 g
F P
s
P
p
.002 w
.58011 .44013 m .53073 .42312 L .53749 .38714 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56431 .47339 m .523 .45944 L .53073 .42312 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.47771 .45547 m .43424 .46199 L .42443 .42644 L p
1 g
F P
s
P
p
.002 w
.42443 .42644 m .47645 .41834 L .47771 .45547 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.47593 .3817 m .53749 .38714 L .53073 .42312 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.53073 .42312 m .47645 .41834 L .47593 .3817 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.523 .45944 m .47771 .45547 L .47645 .41834 L p
1 g
F P
s
P
p
.002 w
.47645 .41834 m .53073 .42312 L .523 .45944 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .71454 .63931 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .48203 .66889 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.651163)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.651163)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45916 .4306 m .49742 .44748 L .50567 .42013 L p
1 g
F P
s
P
p
.002 w
.50567 .42013 m .47378 .40598 L .45916 .4306 L p
1 g
F P
s
P
p
.002 w
.54 .42594 m .50567 .42013 L .49742 .44748 L p
1 g
F P
s
P
p
.002 w
.47378 .40598 m .50567 .42013 L .51381 .39296 L p
1 g
F P
s
P
p
.002 w
.50567 .42013 m .54 .42594 L .54049 .39741 L p
1 g
F P
s
P
p
.002 w
.54049 .39741 m .51381 .39296 L .50567 .42013 L p
1 g
F P
s
P
p
.002 w
.44547 .45532 m .4892 .47452 L .49742 .44748 L p
1 g
F P
s
P
p
.002 w
.49742 .44748 m .45916 .4306 L .44547 .45532 L p
1 g
F P
s
P
p
.002 w
.53855 .45455 m .49742 .44748 L .4892 .47452 L p
1 g
F P
s
P
p
.002 w
.49742 .44748 m .53855 .45455 L .54 .42594 L p
1 g
F P
s
P
p
.002 w
.42729 .40537 m .45916 .4306 L .47378 .40598 L p
1 g
F P
s
P
p
.002 w
.47378 .40598 m .44733 .38479 L .42729 .40537 L p
1 g
F P
s
P
p
.002 w
.44733 .38479 m .47378 .40598 L .48905 .38192 L p
1 g
F P
s
P
p
.002 w
.51381 .39296 m .48905 .38192 L .47378 .40598 L p
1 g
F P
s
P
p
.002 w
.48905 .38192 m .51381 .39296 L .52169 .36646 L p
1 g
F P
s
P
p
.002 w
.51381 .39296 m .54049 .39741 L .54 .36947 L p
1 g
F P
s
P
p
.002 w
.54 .36947 m .52169 .36646 L .51381 .39296 L p
1 g
F P
s
P
p
.002 w
.57355 .42282 m .54 .42594 L .53855 .45455 L p
1 g
F P
s
P
p
.002 w
.54 .42594 m .57355 .42282 L .5665 .39482 L p
1 g
F P
s
P
p
.002 w
.5665 .39482 m .54049 .39741 L .54 .42594 L p
1 g
F P
s
P
p
.002 w
.40888 .42672 m .44547 .45532 L .45916 .4306 L p
1 g
F P
s
P
p
.002 w
.45916 .4306 m .42729 .40537 L .40888 .42672 L p
1 g
F P
s
P
p
.002 w
.43297 .47971 m .48115 .50077 L .4892 .47452 L p
1 g
F P
s
P
p
.002 w
.4892 .47452 m .44547 .45532 L .43297 .47971 L p
1 g
F P
s
P
p
.002 w
.53615 .48271 m .4892 .47452 L .48115 .50077 L p
1 g
F P
s
P
p
.002 w
.4892 .47452 m .53615 .48271 L .53855 .45455 L p
1 g
F P
s
P
p
.002 w
.57882 .45106 m .53855 .45455 L .53615 .48271 L p
1 g
F P
s
P
p
.002 w
.53855 .45455 m .57882 .45106 L .57355 .42282 L p
1 g
F P
s
P
p
.002 w
.48905 .38192 m .46863 .36535 L .44733 .38479 L p
1 g
F P
s
P
p
.002 w
.46863 .36535 m .48905 .38192 L .50471 .35886 L p
1 g
F P
s
P
p
.002 w
.52169 .36646 m .50471 .35886 L .48905 .38192 L p
1 g
F P
s
P
p
.002 w
.54049 .39741 m .5665 .39482 L .5578 .36758 L p
1 g
F P
s
P
p
.002 w
.5578 .36758 m .54 .36947 L .54049 .39741 L p
1 g
F P
s
P
p
.002 w
.39249 .44844 m .43297 .47971 L .44547 .45532 L p
1 g
F P
s
P
p
.002 w
.44547 .45532 m .40888 .42672 L .39249 .44844 L p
1 g
F P
s
P
p
.002 w
.48115 .50077 m .53284 .5099 L .53615 .48271 L p
1 g
F P
s
P
p
.002 w
.58219 .47902 m .53615 .48271 L .53284 .5099 L p
1 g
F P
s
P
p
.002 w
.53615 .48271 m .58219 .47902 L .57882 .45106 L p
1 g
F P
s
P
p
.002 w
.50471 .35886 m .52169 .36646 L .52915 .34113 L p
1 g
F P
s
P
p
.002 w
.52169 .36646 m .54 .36947 L .53851 .34265 L p
1 g
F P
s
P
p
.002 w
.53851 .34265 m .52915 .34113 L .52169 .36646 L p
1 g
F P
s
P
p
.002 w
.40495 .37395 m .42729 .40537 L .44733 .38479 L p
1 g
F P
s
P
p
.002 w
.44733 .38479 m .429 .35844 L .40495 .37395 L p
1 g
F P
s
P
p
.002 w
.429 .35844 m .44733 .38479 L .46863 .36535 L p
1 g
F P
s
P
p
.002 w
.50471 .35886 m .49079 .34742 L .46863 .36535 L p
1 g
F P
s
P
p
.002 w
.49079 .34742 m .50471 .35886 L .52048 .33723 L p
1 g
F P
s
P
p
.002 w
.52915 .34113 m .52048 .33723 L .50471 .35886 L p
1 g
F P
s
P
p
.002 w
.46863 .36535 m .45464 .3448 L .429 .35844 L p
1 g
F P
s
P
p
.002 w
.45464 .3448 m .46863 .36535 L .49079 .34742 L p
1 g
F P
s
P
p
.002 w
.42191 .50329 m .47344 .52571 L .48115 .50077 L p
1 g
F P
s
P
p
.002 w
.48115 .50077 m .43297 .47971 L .42191 .50329 L p
1 g
F P
s
P
p
.002 w
.53284 .5099 m .48115 .50077 L .47344 .52571 L p
1 g
F P
s
P
p
.002 w
.54 .36947 m .5578 .36758 L .54759 .34163 L p
1 g
F P
s
P
p
.002 w
.54759 .34163 m .53851 .34265 L .54 .36947 L p
1 g
F P
s
P
p
.002 w
.60307 .41084 m .57355 .42282 L .57882 .45106 L p
1 g
F P
s
P
p
.002 w
.57355 .42282 m .60307 .41084 L .58926 .3853 L p
1 g
F P
s
P
p
.002 w
.58926 .3853 m .5665 .39482 L .57355 .42282 L p
1 g
F P
s
P
p
.002 w
.5665 .39482 m .58926 .3853 L .57327 .36091 L p
1 g
F P
s
P
p
.002 w
.57327 .36091 m .5578 .36758 L .5665 .39482 L p
1 g
F P
s
P
p
.002 w
.38299 .39105 m .40888 .42672 L .42729 .40537 L p
1 g
F P
s
P
p
.002 w
.42729 .40537 m .40495 .37395 L .38299 .39105 L p
1 g
F P
s
P
p
.002 w
.61442 .43706 m .57882 .45106 L .58219 .47902 L p
1 g
F P
s
P
p
.002 w
.57882 .45106 m .61442 .43706 L .60307 .41084 L p
1 g
F P
s
P
p
.002 w
.37848 .47011 m .42191 .50329 L .43297 .47971 L p
1 g
F P
s
P
p
.002 w
.43297 .47971 m .39249 .44844 L .37848 .47011 L p
1 g
F P
s
P
p
.002 w
.49079 .34742 m .48137 .33328 L .45464 .3448 L p
1 g
F P
s
P
p
.002 w
.48137 .33328 m .49079 .34742 L .5134 .33135 L p
1 g
F P
s
P
p
.002 w
.52048 .33723 m .5134 .33135 L .49079 .34742 L p
1 g
F P
s
P
p
.002 w
.5578 .36758 m .57327 .36091 L .55543 .33816 L p
1 g
F P
s
P
p
.002 w
.55543 .33816 m .54759 .34163 L .5578 .36758 L p
1 g
F P
s
P
p
.002 w
.47344 .52571 m .52866 .53559 L .53284 .5099 L p
1 g
F P
s
P
p
.002 w
.58357 .50616 m .53284 .5099 L .52866 .53559 L p
1 g
F P
s
P
p
.002 w
.53284 .5099 m .58357 .50616 L .58219 .47902 L p
1 g
F P
s
P
p
.002 w
.3636 .40942 m .39249 .44844 L .40888 .42672 L p
1 g
F P
s
P
p
.002 w
.40888 .42672 m .38299 .39105 L .3636 .40942 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .52048 .33723 L .52915 .34113 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .52915 .34113 L .53851 .34265 L closepath p
1 g
F P
s
P
p
.002 w
.62305 .46343 m .58219 .47902 L .58357 .50616 L p
1 g
F P
s
P
p
.002 w
.58219 .47902 m .62305 .46343 L .61442 .43706 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .5134 .33135 L .52048 .33723 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .53851 .34265 L .54759 .34163 L closepath p
1 g
F P
s
P
p
.002 w
.42087 .32937 m .429 .35844 L .45464 .3448 L p
1 g
F P
s
P
p
.002 w
.45464 .3448 m .44866 .32224 L .42087 .32937 L p
1 g
F P
s
P
p
.002 w
.44866 .32224 m .45464 .3448 L .48137 .33328 L p
1 g
F P
s
P
p
.002 w
.41255 .52558 m .46622 .54883 L .47344 .52571 L p
1 g
F P
s
P
p
.002 w
.47344 .52571 m .42191 .50329 L .41255 .52558 L p
1 g
F P
s
P
p
.002 w
.52866 .53559 m .47344 .52571 L .46622 .54883 L p
1 g
F P
s
P
p
.002 w
.48137 .33328 m .47751 .31784 L .44866 .32224 L p
1 g
F P
s
P
p
.002 w
.47751 .31784 m .48137 .33328 L .50868 .32411 L p
1 g
F P
s
P
p
.002 w
.5134 .33135 m .50868 .32411 L .48137 .33328 L p
1 g
F P
s
P
p
.002 w
.60634 .36964 m .58926 .3853 L .60307 .41084 L p
1 g
F P
s
P
p
.002 w
.58926 .3853 m .60634 .36964 L .58477 .35007 L p
1 g
F P
s
P
p
.002 w
.58477 .35007 m .57327 .36091 L .58926 .3853 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .50868 .32411 L .5134 .33135 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .54759 .34163 L .55543 .33816 L closepath p
1 g
F P
s
P
p
.002 w
.57327 .36091 m .58477 .35007 L .56118 .33258 L p
1 g
F P
s
P
p
.002 w
.56118 .33258 m .55543 .33816 L .57327 .36091 L p
1 g
F P
s
P
p
.002 w
.39471 .33915 m .40495 .37395 L .429 .35844 L p
1 g
F P
s
P
p
.002 w
.429 .35844 m .42087 .32937 L .39471 .33915 L p
1 g
F P
s
P
p
.002 w
.62544 .39091 m .60307 .41084 L .61442 .43706 L p
1 g
F P
s
P
p
.002 w
.60307 .41084 m .62544 .39091 L .60634 .36964 L p
1 g
F P
s
P
p
.002 w
.3672 .4913 m .41255 .52558 L .42191 .50329 L p
1 g
F P
s
P
p
.002 w
.42191 .50329 m .37848 .47011 L .3672 .4913 L p
1 g
F P
s
P
p
.002 w
.50868 .32411 m .50683 .31625 L .47751 .31784 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .50683 .31625 L .50868 .32411 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .55543 .33816 L .56118 .33258 L closepath p
1 g
F P
s
P
p
.002 w
.46622 .54883 m .52367 .55923 L .52866 .53559 L p
1 g
F P
s
P
p
.002 w
.58289 .53191 m .52866 .53559 L .52367 .55923 L p
1 g
F P
s
P
p
.002 w
.52866 .53559 m .58289 .53191 L .58357 .50616 L p
1 g
F P
s
P
p
.002 w
.34727 .42873 m .37848 .47011 L .39249 .44844 L p
1 g
F P
s
P
p
.002 w
.39249 .44844 m .3636 .40942 L .34727 .42873 L p
1 g
F P
s
P
p
.002 w
.37078 .35141 m .38299 .39105 L .40495 .37395 L p
1 g
F P
s
P
p
.002 w
.40495 .37395 m .39471 .33915 L .37078 .35141 L p
1 g
F P
s
P
p
.002 w
.62873 .48943 m .58357 .50616 L .58289 .53191 L p
1 g
F P
s
P
p
.002 w
.58357 .50616 m .62873 .48943 L .62305 .46343 L p
1 g
F P
s
P
p
.002 w
.47975 .30272 m .47751 .31784 L .50683 .31625 L p
1 g
F P
s
P
p
.002 w
.50683 .31625 m .50809 .30861 L .47975 .30272 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .50809 .30861 L .50683 .31625 L closepath p
1 g
F P
s
P
p
.002 w
.64164 .41347 m .61442 .43706 L .62305 .46343 L p
1 g
F P
s
P
p
.002 w
.61442 .43706 m .64164 .41347 L .62544 .39091 L p
1 g
F P
s
P
p
.002 w
.4516 .29998 m .44866 .32224 L .47751 .31784 L p
1 g
F P
s
P
p
.002 w
.47751 .31784 m .47975 .30272 L .4516 .29998 L p
1 g
F P
s
P
p
.002 w
.5642 .32546 m .56118 .33258 L .58477 .35007 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .56118 .33258 L .5642 .32546 L closepath p
1 g
F P
s
P
p
.002 w
.59096 .33613 m .58477 .35007 L .60634 .36964 L p
1 g
F P
s
P
p
.002 w
.58477 .35007 m .59096 .33613 L .5642 .32546 L p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .5642 .32546 L .56413 .31758 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .56413 .31758 L .56094 .30977 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .56094 .30977 L .55495 .30292 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .55495 .30292 L .54681 .2978 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .54681 .2978 L .53743 .29498 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .53743 .29498 L .52787 .29479 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .52787 .29479 L .51919 .29724 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .51919 .29724 L .51235 .30203 L closepath p
1 g
F P
s
P
p
.002 w
.53604 .31749 m .51235 .30203 L .50809 .30861 L closepath p
1 g
F P
s
P
p
.002 w
.42424 .30051 m .42087 .32937 L .44866 .32224 L p
1 g
F P
s
P
p
.002 w
.44866 .32224 m .4516 .29998 L .42424 .30051 L p
1 g
F P
s
P
p
.002 w
.48799 .28957 m .47975 .30272 L .50809 .30861 L p
1 g
F P
s
P
p
.002 w
.50809 .30861 m .51235 .30203 L .48799 .28957 L p
1 g
F P
s
P
p
.002 w
.61576 .3493 m .60634 .36964 L .62544 .39091 L p
1 g
F P
s
P
p
.002 w
.60634 .36964 m .61576 .3493 L .59096 .33613 L p
1 g
F P
s
P
p
.002 w
.40515 .54609 m .45966 .5696 L .46622 .54883 L p
1 g
F P
s
P
p
.002 w
.46622 .54883 m .41255 .52558 L .40515 .54609 L p
1 g
F P
s
P
p
.002 w
.52367 .55923 m .46622 .54883 L .45966 .5696 L p
1 g
F P
s
P
p
.002 w
.56413 .31758 m .5642 .32546 L .59096 .33613 L p
1 g
F P
s
P
p
.002 w
.34966 .36597 m .3636 .40942 L .38299 .39105 L p
1 g
F P
s
P
p
.002 w
.38299 .39105 m .37078 .35141 L .34966 .36597 L p
1 g
F P
s
P
p
.002 w
.65452 .43687 m .62305 .46343 L .62873 .48943 L p
1 g
F P
s
P
p
.002 w
.62305 .46343 m .65452 .43687 L .64164 .41347 L p
1 g
F P
s
P
p
.002 w
.33446 .44859 m .3672 .4913 L .37848 .47011 L p
1 g
F P
s
P
p
.002 w
.37848 .47011 m .34727 .42873 L .33446 .44859 L p
1 g
F P
s
P
p
.002 w
.39828 .30439 m .39471 .33915 L .42087 .32937 L p
1 g
F P
s
P
p
.002 w
.42087 .32937 m .42424 .30051 L .39828 .30439 L p
1 g
F P
s
P
p
.002 w
.50146 .27992 m .48799 .28957 L .51235 .30203 L p
1 g
F P
s
P
p
.002 w
.51235 .30203 m .51919 .29724 L .50146 .27992 L p
1 g
F P
s
P
p
.002 w
.35902 .51153 m .40515 .54609 L .41255 .52558 L p
1 g
F P
s
P
p
.002 w
.41255 .52558 m .3672 .4913 L .35902 .51153 L p
1 g
F P
s
P
p
.002 w
.46346 .28047 m .4516 .29998 L .47975 .30272 L p
1 g
F P
s
P
p
.002 w
.47975 .30272 m .48799 .28957 L .46346 .28047 L p
1 g
F P
s
P
p
.002 w
.59096 .33613 m .59104 .32051 L .56413 .31758 L p
1 g
F P
s
P
p
.002 w
.56094 .30977 m .56413 .31758 L .59104 .32051 L p
1 g
F P
s
P
p
.002 w
.45966 .5696 m .51794 .58026 L .52367 .55923 L p
1 g
F P
s
P
p
.002 w
.58008 .55571 m .52367 .55923 L .51794 .58026 L p
1 g
F P
s
P
p
.002 w
.52367 .55923 m .58008 .55571 L .58289 .53191 L p
1 g
F P
s
P
p
.002 w
.63126 .5145 m .58289 .53191 L .58008 .55571 L p
1 g
F P
s
P
p
.002 w
.58289 .53191 m .63126 .5145 L .62873 .48943 L p
1 g
F P
s
P
p
.002 w
.59104 .32051 m .59096 .33613 L .61576 .3493 L p
1 g
F P
s
P
p
.002 w
.63802 .36476 m .62544 .39091 L .64164 .41347 L p
1 g
F P
s
P
p
.002 w
.62544 .39091 m .63802 .36476 L .61576 .3493 L p
1 g
F P
s
P
p
.002 w
.51875 .27492 m .50146 .27992 L .51919 .29724 L p
1 g
F P
s
P
p
.002 w
.51919 .29724 m .52787 .29479 L .51875 .27492 L p
1 g
F P
s
P
p
.002 w
.59104 .32051 m .58486 .30494 L .56094 .30977 L p
1 g
F P
s
P
p
.002 w
.55495 .30292 m .56094 .30977 L .58486 .30494 L p
1 g
F P
s
P
p
.002 w
.33191 .38259 m .34727 .42873 L .3636 .40942 L p
1 g
F P
s
P
p
.002 w
.3636 .40942 m .34966 .36597 L .33191 .38259 L p
1 g
F P
s
P
p
.002 w
.5379 .27524 m .51875 .27492 L .52787 .29479 L p
1 g
F P
s
P
p
.002 w
.52787 .29479 m .53743 .29498 L .5379 .27524 L p
1 g
F P
s
P
p
.002 w
.58486 .30494 m .57299 .29119 L .55495 .30292 L p
1 g
F P
s
P
p
.002 w
.54681 .2978 m .55495 .30292 L .57299 .29119 L p
1 g
F P
s
P
p
.002 w
.43929 .27502 m .42424 .30051 L .4516 .29998 L p
1 g
F P
s
P
p
.002 w
.4516 .29998 m .46346 .28047 L .43929 .27502 L p
1 g
F P
s
P
p
.002 w
.37434 .31164 m .37078 .35141 L .39471 .33915 L p
1 g
F P
s
P
p
.002 w
.39471 .33915 m .39828 .30439 L .37434 .31164 L p
1 g
F P
s
P
p
.002 w
.55672 .28088 m .5379 .27524 L .53743 .29498 L p
1 g
F P
s
P
p
.002 w
.53743 .29498 m .54681 .2978 L .55672 .28088 L p
1 g
F P
s
P
p
.002 w
.57299 .29119 m .55672 .28088 L .54681 .2978 L p
1 g
F P
s
P
p
.002 w
.61619 .32632 m .61576 .3493 L .63802 .36476 L p
1 g
F P
s
P
p
.002 w
.61576 .3493 m .61619 .32632 L .59104 .32051 L p
1 g
F P
s
P
p
.002 w
.48323 .26601 m .46346 .28047 L .48799 .28957 L p
1 g
F P
s
P
p
.002 w
.48799 .28957 m .50146 .27992 L .48323 .26601 L p
1 g
F P
s
P
p
.002 w
.6637 .46062 m .62873 .48943 L .63126 .5145 L p
1 g
F P
s
P
p
.002 w
.62873 .48943 m .6637 .46062 L .65452 .43687 L p
1 g
F P
s
P
p
.002 w
.65721 .38223 m .64164 .41347 L .65452 .43687 L p
1 g
F P
s
P
p
.002 w
.64164 .41347 m .65721 .38223 L .63802 .36476 L p
1 g
F P
s
P
p
.002 w
.58486 .30494 m .59104 .32051 L .61619 .32632 L p
1 g
F P
s
P
p
.002 w
.39996 .56427 m .45392 .58748 L .45966 .5696 L p
1 g
F P
s
P
p
.002 w
.45966 .5696 m .40515 .54609 L .39996 .56427 L p
1 g
F P
s
P
p
.002 w
.51794 .58026 m .45966 .5696 L .45392 .58748 L p
1 g
F P
s
P
p
.002 w
.3256 .46855 m .35902 .51153 L .3672 .4913 L p
1 g
F P
s
P
p
.002 w
.3672 .4913 m .33446 .44859 L .3256 .46855 L p
1 g
F P
s
P
p
.002 w
.51794 .58026 m .57514 .57697 L .58008 .55571 L p
1 g
F P
s
P
p
.002 w
.63045 .53805 m .58008 .55571 L .57514 .57697 L p
1 g
F P
s
P
p
.002 w
.58008 .55571 m .63045 .53805 L .63126 .5145 L p
1 g
F P
s
P
p
.002 w
.35425 .53031 m .39996 .56427 L .40515 .54609 L p
1 g
F P
s
P
p
.002 w
.40515 .54609 m .35902 .51153 L .35425 .53031 L p
1 g
F P
s
P
p
.002 w
.41605 .27349 m .39828 .30439 L .42424 .30051 L p
1 g
F P
s
P
p
.002 w
.42424 .30051 m .43929 .27502 L .41605 .27349 L p
1 g
F P
s
P
p
.002 w
.50885 .25844 m .48323 .26601 L .50146 .27992 L p
1 g
F P
s
P
p
.002 w
.50146 .27992 m .51875 .27492 L .50885 .25844 L p
1 g
F P
s
P
p
.002 w
.45392 .58748 m .51156 .59811 L .51794 .58026 L p
1 g
F P
s
P
p
.002 w
.57514 .57697 m .51794 .58026 L .51156 .59811 L p
1 g
F P
s
P
p
.002 w
.35307 .32222 m .34966 .36597 L .37078 .35141 L p
1 g
F P
s
P
p
.002 w
.37078 .35141 m .37434 .31164 L .35307 .32222 L p
1 g
F P
s
P
p
.002 w
.61619 .32632 m .60726 .30322 L .58486 .30494 L p
1 g
F P
s
P
p
.002 w
.57299 .29119 m .58486 .30494 L .60726 .30322 L p
1 g
F P
s
P
p
.002 w
.31811 .40094 m .33446 .44859 L .34727 .42873 L p
1 g
F P
s
P
p
.002 w
.34727 .42873 m .33191 .38259 L .31811 .40094 L p
1 g
F P
s
P
p
.002 w
.63895 .33496 m .63802 .36476 L .65721 .38223 L p
1 g
F P
s
P
p
.002 w
.63802 .36476 m .63895 .33496 L .61619 .32632 L p
1 g
F P
s
P
p
.002 w
.46486 .25597 m .43929 .27502 L .46346 .28047 L p
1 g
F P
s
P
p
.002 w
.46346 .28047 m .48323 .26601 L .46486 .25597 L p
1 g
F P
s
P
p
.002 w
.67276 .4014 m .65452 .43687 L .6637 .46062 L p
1 g
F P
s
P
p
.002 w
.65452 .43687 m .67276 .4014 L .65721 .38223 L p
1 g
F P
s
P
p
.002 w
.66884 .48421 m .63126 .5145 L .63045 .53805 L p
1 g
F P
s
P
p
.002 w
.63126 .5145 m .66884 .48421 L .6637 .46062 L p
1 g
F P
s
P
p
.002 w
.60726 .30322 m .61619 .32632 L .63895 .33496 L p
1 g
F P
s
P
p
.002 w
.53741 .25884 m .50885 .25844 L .51875 .27492 L p
1 g
F P
s
P
p
.002 w
.51875 .27492 m .5379 .27524 L .53741 .25884 L p
1 g
F P
s
P
p
.002 w
.60726 .30322 m .58974 .2827 L .57299 .29119 L p
1 g
F P
s
P
p
.002 w
.55672 .28088 m .57299 .29119 L .58974 .2827 L p
1 g
F P
s
P
p
.002 w
.5655 .26726 m .53741 .25884 L .5379 .27524 L p
1 g
F P
s
P
p
.002 w
.5379 .27524 m .55672 .28088 L .5655 .26726 L p
1 g
F P
s
P
p
.002 w
.58974 .2827 m .5655 .26726 L .55672 .28088 L p
1 g
F P
s
P
p
.002 w
.39434 .27609 m .37434 .31164 L .39828 .30439 L p
1 g
F P
s
P
p
.002 w
.39828 .30439 m .41605 .27349 L .39434 .27609 L p
1 g
F P
s
P
p
.002 w
.32111 .48816 m .35425 .53031 L .35902 .51153 L p
1 g
F P
s
P
p
.002 w
.35902 .51153 m .3256 .46855 L .32111 .48816 L p
1 g
F P
s
P
p
.002 w
.3972 .57961 m .44917 .60189 L .45392 .58748 L p
1 g
F P
s
P
p
.002 w
.45392 .58748 m .39996 .56427 L .3972 .57961 L p
1 g
F P
s
P
p
.002 w
.51156 .59811 m .45392 .58748 L .44917 .60189 L p
1 g
F P
s
P
p
.002 w
.3351 .33602 m .33191 .38259 L .34966 .36597 L p
1 g
F P
s
P
p
.002 w
.34966 .36597 m .35307 .32222 L .3351 .33602 L p
1 g
F P
s
P
p
.002 w
.65871 .34635 m .65721 .38223 L .67276 .4014 L p
1 g
F P
s
P
p
.002 w
.65721 .38223 m .65871 .34635 L .63895 .33496 L p
1 g
F P
s
P
p
.002 w
.51156 .59811 m .56807 .59509 L .57514 .57697 L p
1 g
F P
s
P
p
.002 w
.62619 .55947 m .57514 .57697 L .56807 .59509 L p
1 g
F P
s
P
p
.002 w
.57514 .57697 m .62619 .55947 L .63045 .53805 L p
1 g
F P
s
P
p
.002 w
.49835 .24592 m .46486 .25597 L .48323 .26601 L p
1 g
F P
s
P
p
.002 w
.48323 .26601 m .50885 .25844 L .49835 .24592 L p
1 g
F P
s
P
p
.002 w
.68418 .42187 m .6637 .46062 L .66884 .48421 L p
1 g
F P
s
P
p
.002 w
.6637 .46062 m .68418 .42187 L .67276 .4014 L p
1 g
F P
s
P
p
.002 w
.63895 .33496 m .62756 .30477 L .60726 .30322 L p
1 g
F P
s
P
p
.002 w
.58974 .2827 m .60726 .30322 L .62756 .30477 L p
1 g
F P
s
P
p
.002 w
.30877 .42066 m .3256 .46855 L .33446 .44859 L p
1 g
F P
s
P
p
.002 w
.33446 .44859 m .31811 .40094 L .30877 .42066 L p
1 g
F P
s
P
p
.002 w
.44681 .25025 m .41605 .27349 L .43929 .27502 L p
1 g
F P
s
P
p
.002 w
.43929 .27502 m .46486 .25597 L .44681 .25025 L p
1 g
F P
s
P
p
.002 w
.35319 .5471 m .3972 .57961 L .39996 .56427 L p
1 g
F P
s
P
p
.002 w
.39996 .56427 m .35425 .53031 L .35319 .5471 L p
1 g
F P
s
P
p
.002 w
.44917 .60189 m .50464 .6122 L .51156 .59811 L p
1 g
F P
s
P
p
.002 w
.56807 .59509 m .51156 .59811 L .50464 .6122 L p
1 g
F P
s
P
p
.002 w
.62756 .30477 m .63895 .33496 L .65871 .34635 L p
1 g
F P
s
P
p
.002 w
.66965 .50705 m .63045 .53805 L .62619 .55947 L p
1 g
F P
s
P
p
.002 w
.63045 .53805 m .66965 .50705 L .66884 .48421 L p
1 g
F P
s
P
p
.002 w
.53589 .24637 m .49835 .24592 L .50885 .25844 L p
1 g
F P
s
P
p
.002 w
.50885 .25844 m .53741 .25884 L .53589 .24637 L p
1 g
F P
s
P
p
.002 w
.62756 .30477 m .60472 .2778 L .58974 .2827 L p
1 g
F P
s
P
p
.002 w
.5655 .26726 m .58974 .2827 L .60472 .2778 L p
1 g
F P
s
P
p
.002 w
.37477 .28295 m .35307 .32222 L .37434 .31164 L p
1 g
F P
s
P
p
.002 w
.37434 .31164 m .39434 .27609 L .37477 .28295 L p
1 g
F P
s
P
p
.002 w
.32104 .35282 m .31811 .40094 L .33191 .38259 L p
1 g
F P
s
P
p
.002 w
.33191 .38259 m .3351 .33602 L .32104 .35282 L p
1 g
F P
s
P
p
.002 w
.67486 .36035 m .67276 .4014 L .68418 .42187 L p
1 g
F P
s
P
p
.002 w
.67276 .4014 m .67486 .36035 L .65871 .34635 L p
1 g
F P
s
P
p
.002 w
.57288 .25746 m .53589 .24637 L .53741 .25884 L p
1 g
F P
s
P
p
.002 w
.53741 .25884 m .5655 .26726 L .57288 .25746 L p
1 g
F P
s
P
p
.002 w
.60472 .2778 m .57288 .25746 L .5655 .26726 L p
1 g
F P
s
P
p
.002 w
.3213 .5069 m .35319 .5471 L .35425 .53031 L p
1 g
F P
s
P
p
.002 w
.35425 .53031 m .32111 .48816 L .3213 .5069 L p
1 g
F P
s
P
p
.002 w
.691 .44319 m .66884 .48421 L .66965 .50705 L p
1 g
F P
s
P
p
.002 w
.66884 .48421 m .691 .44319 L .68418 .42187 L p
1 g
F P
s
P
p
.002 w
.48749 .23789 m .44681 .25025 L .46486 .25597 L p
1 g
F P
s
P
p
.002 w
.46486 .25597 m .49835 .24592 L .48749 .23789 L p
1 g
F P
s
P
p
.002 w
.42955 .24921 m .39434 .27609 L .41605 .27349 L p
1 g
F P
s
P
p
.002 w
.41605 .27349 m .44681 .25025 L .42955 .24921 L p
1 g
F P
s
P
p
.002 w
.50464 .6122 m .55892 .60948 L .56807 .59509 L p
1 g
F P
s
P
p
.002 w
.61842 .57816 m .56807 .59509 L .55892 .60948 L p
1 g
F P
s
P
p
.002 w
.56807 .59509 m .61842 .57816 L .62619 .55947 L p
1 g
F P
s
P
p
.002 w
.30434 .4413 m .32111 .48816 L .3256 .46855 L p
1 g
F P
s
P
p
.002 w
.3256 .46855 m .30877 .42066 L .30434 .4413 L p
1 g
F P
s
P
p
.002 w
.3971 .59155 m .44559 .61231 L .44917 .60189 L p
1 g
F P
s
P
p
.002 w
.44917 .60189 m .3972 .57961 L .3971 .59155 L p
1 g
F P
s
P
p
.002 w
.50464 .6122 m .44917 .60189 L .44559 .61231 L p
1 g
F P
s
P
p
.002 w
.65871 .34635 m .64516 .30974 L .62756 .30477 L p
1 g
F P
s
P
p
.002 w
.60472 .2778 m .62756 .30477 L .64516 .30974 L p
1 g
F P
s
P
p
.002 w
.64516 .30974 m .65871 .34635 L .67486 .36035 L p
1 g
F P
s
P
p
.002 w
.6659 .52854 m .62619 .55947 L .61842 .57816 L p
1 g
F P
s
P
p
.002 w
.62619 .55947 m .6659 .52854 L .66965 .50705 L p
1 g
F P
s
P
p
.002 w
.35608 .56139 m .3971 .59155 L .3972 .57961 L p
1 g
F P
s
P
p
.002 w
.3972 .57961 m .35319 .5471 L .35608 .56139 L p
1 g
F P
s
P
p
.002 w
.44559 .61231 m .49732 .62197 L .50464 .6122 L p
1 g
F P
s
P
p
.002 w
.55892 .60948 m .50464 .6122 L .49732 .62197 L p
1 g
F P
s
P
p
.002 w
.35797 .29411 m .3351 .33602 L .35307 .32222 L p
1 g
F P
s
P
p
.002 w
.35307 .32222 m .37477 .28295 L .35797 .29411 L p
1 g
F P
s
P
p
.002 w
.31147 .37232 m .30877 .42066 L .31811 .40094 L p
1 g
F P
s
P
p
.002 w
.31811 .40094 m .32104 .35282 L .31147 .37232 L p
1 g
F P
s
P
p
.002 w
.6868 .37671 m .68418 .42187 L .691 .44319 L p
1 g
F P
s
P
p
.002 w
.68418 .42187 m .6868 .37671 L .67486 .36035 L p
1 g
F P
s
P
p
.002 w
.53334 .23838 m .48749 .23789 L .49835 .24592 L p
1 g
F P
s
P
p
.002 w
.49835 .24592 m .53589 .24637 L .53334 .23838 L p
1 g
F P
s
P
p
.002 w
.64516 .30974 m .61746 .27684 L .60472 .2778 L p
1 g
F P
s
P
p
.002 w
.57288 .25746 m .60472 .2778 L .61746 .27684 L p
1 g
F P
s
P
p
.002 w
.69282 .46485 m .66965 .50705 L .6659 .52854 L p
1 g
F P
s
P
p
.002 w
.66965 .50705 m .69282 .46485 L .691 .44319 L p
1 g
F P
s
P
p
.002 w
.41357 .25314 m .37477 .28295 L .39434 .27609 L p
1 g
F P
s
P
p
.002 w
.39434 .27609 m .42955 .24921 L .41357 .25314 L p
1 g
F P
s
P
p
.002 w
.32643 .52421 m .35608 .56139 L .35319 .5471 L p
1 g
F P
s
P
p
.002 w
.35319 .5471 m .3213 .5069 L .32643 .52421 L p
1 g
F P
s
P
p
.002 w
.5786 .25194 m .53334 .23838 L .53589 .24637 L p
1 g
F P
s
P
p
.002 w
.53589 .24637 m .57288 .25746 L .5786 .25194 L p
1 g
F P
s
P
p
.002 w
.61746 .27684 m .5786 .25194 L .57288 .25746 L p
1 g
F P
s
P
p
.002 w
.47652 .23483 m .42955 .24921 L .44681 .25025 L p
1 g
F P
s
P
p
.002 w
.44681 .25025 m .48749 .23789 L .47652 .23483 L p
1 g
F P
s
P
p
.002 w
.3052 .46234 m .3213 .5069 L .32111 .48816 L p
1 g
F P
s
P
p
.002 w
.32111 .48816 m .30434 .4413 L .3052 .46234 L p
1 g
F P
s
P
p
.002 w
.65947 .31818 m .67486 .36035 L .6868 .37671 L p
1 g
F P
s
P
p
.002 w
.67486 .36035 m .65947 .31818 L .64516 .30974 L p
1 g
F P
s
P
p
.002 w
.49732 .62197 m .54783 .61955 L .55892 .60948 L p
1 g
F P
s
P
p
.002 w
.60715 .59348 m .55892 .60948 L .54783 .61955 L p
1 g
F P
s
P
p
.002 w
.55892 .60948 m .60715 .59348 L .61842 .57816 L p
1 g
F P
s
P
p
.002 w
.61746 .27684 m .64516 .30974 L .65947 .31818 L p
1 g
F P
s
P
p
.002 w
.65749 .54805 m .61842 .57816 L .60715 .59348 L p
1 g
F P
s
P
p
.002 w
.61842 .57816 m .65749 .54805 L .6659 .52854 L p
1 g
F P
s
P
p
.002 w
.39982 .59959 m .44335 .6182 L .44559 .61231 L p
1 g
F P
s
P
p
.002 w
.44559 .61231 m .3971 .59155 L .39982 .59959 L p
1 g
F P
s
P
p
.002 w
.49732 .62197 m .44559 .61231 L .44335 .6182 L p
1 g
F P
s
P
p
.002 w
.34456 .30947 m .32104 .35282 L .3351 .33602 L p
1 g
F P
s
P
p
.002 w
.3351 .33602 m .35797 .29411 L .34456 .30947 L p
1 g
F P
s
P
p
.002 w
.36306 .57262 m .39982 .59959 L .3971 .59155 L p
1 g
F P
s
P
p
.002 w
.3971 .59155 m .35608 .56139 L .36306 .57262 L p
1 g
F P
s
P
p
.002 w
.694 .39514 m .691 .44319 L .69282 .46485 L p
1 g
F P
s
P
p
.002 w
.691 .44319 m .694 .39514 L .6868 .37671 L p
1 g
F P
s
P
p
.002 w
.44335 .6182 m .48977 .62689 L .49732 .62197 L p
1 g
F P
s
P
p
.002 w
.54783 .61955 m .49732 .62197 L .48977 .62689 L p
1 g
F P
s
P
p
.002 w
.30689 .3941 m .30434 .4413 L .30877 .42066 L p
1 g
F P
s
P
p
.002 w
.30877 .42066 m .31147 .37232 L .30689 .3941 L p
1 g
F P
s
P
p
.002 w
.68935 .48627 m .6659 .52854 L .65749 .54805 L p
1 g
F P
s
P
p
.002 w
.6659 .52854 m .68935 .48627 L .69282 .46485 L p
1 g
F P
s
P
p
.002 w
.52975 .23538 m .47652 .23483 L .48749 .23789 L p
1 g
F P
s
P
p
.002 w
.48749 .23789 m .53334 .23838 L .52975 .23538 L p
1 g
F P
s
P
p
.002 w
.65947 .31818 m .6275 .28008 L .61746 .27684 L p
1 g
F P
s
P
p
.002 w
.5786 .25194 m .61746 .27684 L .6275 .28008 L p
1 g
F P
s
P
p
.002 w
.39942 .26222 m .35797 .29411 L .37477 .28295 L p
1 g
F P
s
P
p
.002 w
.37477 .28295 m .41357 .25314 L .39942 .26222 L p
1 g
F P
s
P
p
.002 w
.31159 .48319 m .32643 .52421 L .3213 .5069 L p
1 g
F P
s
P
p
.002 w
.3213 .5069 m .3052 .46234 L .31159 .48319 L p
1 g
F P
s
P
p
.002 w
.66991 .33006 m .6868 .37671 L .694 .39514 L p
1 g
F P
s
P
p
.002 w
.6868 .37671 m .66991 .33006 L .65947 .31818 L p
1 g
F P
s
P
p
.002 w
.46576 .23716 m .41357 .25314 L .42955 .24921 L p
1 g
F P
s
P
p
.002 w
.42955 .24921 m .47652 .23483 L .46576 .23716 L p
1 g
F P
s
P
p
.002 w
.33664 .53953 m .36306 .57262 L .35608 .56139 L p
1 g
F P
s
P
p
.002 w
.35608 .56139 m .32643 .52421 L .33664 .53953 L p
1 g
F P
s
P
p
.002 w
.48977 .62689 m .53496 .62477 L .54783 .61955 L p
1 g
F P
s
P
p
.002 w
.59251 .60484 m .54783 .61955 L .53496 .62477 L p
1 g
F P
s
P
p
.002 w
.54783 .61955 m .59251 .60484 L .60715 .59348 L p
1 g
F P
s
P
p
.002 w
.58238 .25115 m .52975 .23538 L .53334 .23838 L p
1 g
F P
s
P
p
.002 w
.53334 .23838 m .5786 .25194 L .58238 .25115 L p
1 g
F P
s
P
p
.002 w
.6444 .56494 m .60715 .59348 L .59251 .60484 L p
1 g
F P
s
P
p
.002 w
.60715 .59348 m .6444 .56494 L .65749 .54805 L p
1 g
F P
s
P
p
.002 w
.6275 .28008 m .65947 .31818 L .66991 .33006 L p
1 g
F P
s
P
p
.002 w
.33511 .32881 m .31147 .37232 L .32104 .35282 L p
1 g
F P
s
P
p
.002 w
.32104 .35282 m .34456 .30947 L .33511 .32881 L p
1 g
F P
s
P
p
.002 w
.6275 .28008 m .58238 .25115 L .5786 .25194 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.57215 .6118 L
s
P
p
.004 w
.57218 .61188 m
.57268 .61314 L
s
P
p
.004 w
.57268 .61314 m
.57556 .62039 L
s
P
p
.004 w
.57556 .62039 m
.57777 .62594 L
s
P
p
.004 w
.57777 .62594 m
.61018 .70736 L
s
P
p
.002 w
.69282 .46485 m .69601 .4152 L .694 .39514 L p
1 g
F P
s
P
p
.002 w
.69601 .4152 m .69282 .46485 L .68935 .48627 L p
1 g
F P
s
P
p
.002 w
.30767 .41762 m .3052 .46234 L .30434 .4413 L p
1 g
F P
s
P
p
.002 w
.30434 .4413 m .30689 .3941 L .30767 .41762 L p
1 g
F P
s
P
p
.002 w
.40546 .60324 m .44259 .61911 L .44335 .6182 L p
1 g
F P
s
P
p
.002 w
.44335 .6182 m .39982 .59959 L .40546 .60324 L p
1 g
F P
s
P
p
.002 w
.48977 .62689 m .44335 .6182 L .44259 .61911 L p
1 g
F P
s
P
p
.002 w
.65749 .54805 m .68042 .50683 L .68935 .48627 L p
1 g
F P
s
P
p
.002 w
.68042 .50683 m .65749 .54805 L .6444 .56494 L p
1 g
F P
s
P
p
.002 w
.3742 .5803 m .40546 .60324 L .39982 .59959 L p
1 g
F P
s
P
p
.002 w
.39982 .59959 m .36306 .57262 L .3742 .5803 L p
1 g
F P
s
P
p
.002 w
.44259 .61911 m .48217 .62653 L .48977 .62689 L p
1 g
F P
s
P
p
.002 w
.53496 .62477 m .48977 .62689 L .48217 .62653 L p
1 g
F P
s
P
p
.002 w
.38762 .27648 m .34456 .30947 L .35797 .29411 L p
1 g
F P
s
P
p
.002 w
.35797 .29411 m .39942 .26222 L .38762 .27648 L p
1 g
F P
s
P
p
.002 w
.52515 .23779 m .46576 .23716 L .47652 .23483 L p
1 g
F P
s
P
p
.002 w
.47652 .23483 m .52975 .23538 L .52515 .23779 L p
1 g
F P
s
P
p
.002 w
.66991 .33006 m .63437 .2877 L .6275 .28008 L p
1 g
F P
s
P
p
.002 w
.58238 .25115 m .6275 .28008 L .63437 .2877 L p
1 g
F P
s
P
p
.002 w
.694 .39514 m .67595 .34524 L .66991 .33006 L p
1 g
F P
s
P
p
.002 w
.67595 .34524 m .694 .39514 L .69601 .4152 L p
1 g
F P
s
P
p
.002 w
.32359 .50321 m .33664 .53953 L .32643 .52421 L p
1 g
F P
s
P
p
.002 w
.32643 .52421 m .31159 .48319 L .32359 .50321 L p
1 g
F P
s
P
p
.002 w
.33012 .35173 m .30689 .3941 L .31147 .37232 L p
1 g
F P
s
P
p
.002 w
.31147 .37232 m .33511 .32881 L .33012 .35173 L p
1 g
F P
s
P
p
.002 w
.45553 .24513 m .39942 .26222 L .41357 .25314 L p
1 g
F P
s
P
p
.002 w
.41357 .25314 m .46576 .23716 L .45553 .24513 L p
1 g
F P
s
P
p
.002 w
.3519 .55228 m .3742 .5803 L .36306 .57262 L p
1 g
F P
s
P
p
.002 w
.36306 .57262 m .33664 .53953 L .3519 .55228 L p
1 g
F P
s
P
p
.002 w
.53496 .62477 m .57473 .6117 L .59251 .60484 L p
1 g
F P
s
P
p
.002 w
.59251 .60484 m .62678 .57859 L .6444 .56494 L p
1 g
F P
s
P
p
.002 w
.62678 .57859 m .59251 .60484 L .57473 .6117 L p
1 g
F P
s
P
p
.002 w
.63437 .2877 m .66991 .33006 L .67595 .34524 L p
1 g
F P
s
P
p
.002 w
.48217 .62653 m .52059 .62472 L .53496 .62477 L p
1 g
F P
s
P
p
.002 w
.57473 .6117 m .53496 .62477 L .52059 .62472 L p
1 g
F P
s
P
p
.002 w
.6925 .4364 m .68935 .48627 L .68042 .50683 L p
1 g
F P
s
P
p
.002 w
.68935 .48627 m .6925 .4364 L .69601 .4152 L p
1 g
F P
s
P
p
.002 w
.31404 .44224 m .31159 .48319 L .3052 .46234 L p
1 g
F P
s
P
p
.002 w
.3052 .46234 m .30767 .41762 L .31404 .44224 L p
1 g
F P
s
P
p
.002 w
.58398 .25542 m .52515 .23779 L .52975 .23538 L p
1 g
F P
s
P
p
.002 w
.52975 .23538 m .58238 .25115 L .58398 .25542 L p
1 g
F P
s
P
p
.002 w
.63437 .2877 m .58398 .25542 L .58238 .25115 L p
1 g
F P
s
P
p
.002 w
.66604 .52586 m .6444 .56494 L .62678 .57859 L p
1 g
F P
s
P
p
.002 w
.6444 .56494 m .66604 .52586 L .68042 .50683 L p
1 g
F P
s
P
p
.002 w
.41405 .6021 m .44344 .61468 L .44259 .61911 L p
1 g
F P
s
P
p
.002 w
.44259 .61911 m .40546 .60324 L .41405 .6021 L p
1 g
F P
s
P
p
.002 w
.48217 .62653 m .44259 .61911 L .44344 .61468 L p
1 g
F P
s
P
p
.002 w
.37867 .29575 m .33511 .32881 L .34456 .30947 L p
1 g
F P
s
P
p
.002 w
.34456 .30947 m .38762 .27648 L .37867 .29575 L p
1 g
F P
s
P
p
.002 w
.38941 .58397 m .41405 .6021 L .40546 .60324 L p
1 g
F P
s
P
p
.002 w
.40546 .60324 m .3742 .5803 L .38941 .58397 L p
1 g
F P
s
P
p
.002 w
.44344 .61468 m .47476 .62053 L .48217 .62653 L p
1 g
F P
s
P
p
.002 w
.52059 .62472 m .48217 .62653 L .47476 .62053 L p
1 g
F P
s
P
p
.002 w
.67716 .36345 m .69601 .4152 L .6925 .4364 L p
1 g
F P
s
P
p
.002 w
.69601 .4152 m .67716 .36345 L .67595 .34524 L p
1 g
F P
s
P
p
.002 w
.32995 .37766 m .30767 .41762 L .30689 .3941 L p
1 g
F P
s
P
p
.002 w
.30689 .3941 m .33012 .35173 L .32995 .37766 L p
1 g
F P
s
P
p
.002 w
.34111 .52174 m .3519 .55228 L .33664 .53953 L p
1 g
F P
s
P
p
.002 w
.33664 .53953 m .32359 .50321 L .34111 .52174 L p
1 g
F P
s
P
p
.002 w
.51962 .2459 m .45553 .24513 L .46576 .23716 L p
1 g
F P
s
P
p
.002 w
.46576 .23716 m .52515 .23779 L .51962 .2459 L p
1 g
F P
s
P
p
.002 w
.67595 .34524 m .63767 .29974 L .63437 .2877 L p
1 g
F P
s
P
p
.002 w
.58398 .25542 m .63437 .2877 L .63767 .29974 L p
1 g
F P
s
P
p
.002 w
.44618 .25884 m .38762 .27648 L .39942 .26222 L p
1 g
F P
s
P
p
.002 w
.39942 .26222 m .45553 .24513 L .44618 .25884 L p
1 g
F P
s
P
p
.002 w
.52059 .62472 m .55417 .61361 L .57473 .6117 L p
1 g
F P
s
P
p
.002 w
.60495 .58841 m .57473 .6117 L .55417 .61361 L p
1 g
F P
s
P
p
.002 w
.57473 .6117 m .60495 .58841 L .62678 .57859 L p
1 g
F P
s
P
p
.002 w
.68328 .45814 m .68042 .50683 L .66604 .52586 L p
1 g
F P
s
P
p
.002 w
.68042 .50683 m .68328 .45814 L .6925 .4364 L p
1 g
F P
s
P
p
.002 w
.32605 .46721 m .32359 .50321 L .31159 .48319 L p
1 g
F P
s
P
p
.002 w
.31159 .48319 m .31404 .44224 L .32605 .46721 L p
1 g
F P
s
P
p
.002 w
.372 .56194 m .38941 .58397 L .3742 .5803 L p
1 g
F P
s
P
p
.002 w
.3742 .5803 m .3519 .55228 L .372 .56194 L p
1 g
F P
s
P
p
.002 w
.63767 .29974 m .67595 .34524 L .67716 .36345 L p
1 g
F P
s
P
p
.002 w
.47476 .62053 m .50505 .61906 L .52059 .62472 L p
1 g
F P
s
P
p
.002 w
.55417 .61361 m .52059 .62472 L .50505 .61906 L p
1 g
F P
s
P
p
.002 w
.6464 .5427 m .62678 .57859 L .60495 .58841 L p
1 g
F P
s
P
p
.002 w
.62678 .57859 m .6464 .5427 L .66604 .52586 L p
1 g
F P
s
P
p
.002 w
.58322 .26496 m .51962 .2459 L .52515 .23779 L p
1 g
F P
s
P
p
.002 w
.52515 .23779 m .58398 .25542 L .58322 .26496 L p
1 g
F P
s
P
p
.002 w
.63767 .29974 m .58322 .26496 L .58398 .25542 L p
1 g
F P
s
P
p
.002 w
.37302 .31966 m .33012 .35173 L .33511 .32881 L p
1 g
F P
s
P
p
.002 w
.33511 .32881 m .37867 .29575 L .37302 .31966 L p
1 g
F P
s
P
p
.002 w
.33483 .40588 m .31404 .44224 L .30767 .41762 L p
1 g
F P
s
P
p
.002 w
.30767 .41762 m .32995 .37766 L .33483 .40588 L p
1 g
F P
s
P
p
.002 w
.42551 .59591 m .44597 .60468 L .44344 .61468 L p
1 g
F P
s
P
p
.002 w
.44344 .61468 m .41405 .6021 L .42551 .59591 L p
1 g
F P
s
P
p
.002 w
.47476 .62053 m .44344 .61468 L .44597 .60468 L p
1 g
F P
s
P
p
.002 w
.67322 .38429 m .6925 .4364 L .68328 .45814 L p
1 g
F P
s
P
p
.002 w
.6925 .4364 m .67322 .38429 L .67716 .36345 L p
1 g
F P
s
P
p
.002 w
.40844 .58329 m .42551 .59591 L .41405 .6021 L p
1 g
F P
s
P
p
.002 w
.41405 .6021 m .38941 .58397 L .40844 .58329 L p
1 g
F P
s
P
p
.002 w
.3638 .53809 m .372 .56194 L .3519 .55228 L p
1 g
F P
s
P
p
.002 w
.3519 .55228 m .34111 .52174 L .3638 .53809 L p
1 g
F P
s
P
p
.002 w
.44597 .60468 m .46777 .60874 L .47476 .62053 L p
1 g
F P
s
P
p
.002 w
.50505 .61906 m .47476 .62053 L .46777 .60874 L p
1 g
F P
s
P
p
.002 w
.66838 .47972 m .66604 .52586 L .6464 .5427 L p
1 g
F P
s
P
p
.002 w
.66604 .52586 m .66838 .47972 L .68328 .45814 L p
1 g
F P
s
P
p
.002 w
.50505 .61906 m .53132 .61026 L .55417 .61361 L p
1 g
F P
s
P
p
.002 w
.5794 .59393 m .55417 .61361 L .53132 .61026 L p
1 g
F P
s
P
p
.002 w
.55417 .61361 m .5794 .59393 L .60495 .58841 L p
1 g
F P
s
P
p
.002 w
.34352 .4917 m .34111 .52174 L .32359 .50321 L p
1 g
F P
s
P
p
.002 w
.32359 .50321 m .32605 .46721 L .34352 .4917 L p
1 g
F P
s
P
p
.002 w
.4381 .27818 m .37867 .29575 L .38762 .27648 L p
1 g
F P
s
P
p
.002 w
.38762 .27648 m .44618 .25884 L .4381 .27818 L p
1 g
F P
s
P
p
.002 w
.51329 .25979 m .44618 .25884 L .45553 .24513 L p
1 g
F P
s
P
p
.002 w
.45553 .24513 m .51962 .2459 L .51329 .25979 L p
1 g
F P
s
P
p
.002 w
.67716 .36345 m .63706 .31611 L .63767 .29974 L p
1 g
F P
s
P
p
.002 w
.58322 .26496 m .63767 .29974 L .63706 .31611 L p
1 g
F P
s
P
p
.002 w
.62191 .55669 m .60495 .58841 L .5794 .59393 L p
1 g
F P
s
P
p
.002 w
.60495 .58841 m .62191 .55669 L .6464 .5427 L p
1 g
F P
s
P
p
.002 w
.63706 .31611 m .67716 .36345 L .67322 .38429 L p
1 g
F P
s
P
p
.002 w
.39653 .56802 m .40844 .58329 L .38941 .58397 L p
1 g
F P
s
P
p
.002 w
.38941 .58397 m .372 .56194 L .39653 .56802 L p
1 g
F P
s
P
p
.002 w
.46777 .60874 m .48878 .60766 L .50505 .61906 L p
1 g
F P
s
P
p
.002 w
.53132 .61026 m .50505 .61906 L .48878 .60766 L p
1 g
F P
s
P
p
.002 w
.37102 .3476 m .32995 .37766 L .33012 .35173 L p
1 g
F P
s
P
p
.002 w
.33012 .35173 m .37302 .31966 L .37102 .3476 L p
1 g
F P
s
P
p
.002 w
.34479 .43549 m .32605 .46721 L .31404 .44224 L p
1 g
F P
s
P
p
.002 w
.31404 .44224 m .33483 .40588 L .34479 .43549 L p
1 g
F P
s
P
p
.002 w
.57997 .27979 m .51329 .25979 L .51962 .2459 L p
1 g
F P
s
P
p
.002 w
.51962 .2459 m .58322 .26496 L .57997 .27979 L p
1 g
F P
s
P
p
.002 w
.664 .4072 m .68328 .45814 L .66838 .47972 L p
1 g
F P
s
P
p
.002 w
.68328 .45814 m .664 .4072 L .67322 .38429 L p
1 g
F P
s
P
p
.002 w
.63706 .31611 m .57997 .27979 L .58322 .26496 L p
1 g
F P
s
P
p
.002 w
.64807 .50042 m .6464 .5427 L .62191 .55669 L p
1 g
F P
s
P
p
.002 w
.6464 .5427 m .64807 .50042 L .66838 .47972 L p
1 g
F P
s
P
p
.002 w
.3911 .55163 m .39653 .56802 L .372 .56194 L p
1 g
F P
s
P
p
.002 w
.372 .56194 m .3638 .53809 L .3911 .55163 L p
1 g
F P
s
P
p
.002 w
.36602 .51485 m .3638 .53809 L .34111 .52174 L p
1 g
F P
s
P
p
.002 w
.34111 .52174 m .34352 .4917 L .36602 .51485 L p
1 g
F P
s
P
p
.002 w
.48878 .60766 m .50684 .60147 L .53132 .61026 L p
1 g
F P
s
P
p
.002 w
.55081 .59476 m .53132 .61026 L .50684 .60147 L p
1 g
F P
s
P
p
.002 w
.53132 .61026 m .55081 .59476 L .5794 .59393 L p
1 g
F P
s
P
p
.002 w
.43964 .58455 m .45021 .58909 L .44597 .60468 L p
1 g
F P
s
P
p
.002 w
.44597 .60468 m .42551 .59591 L .43964 .58455 L p
1 g
F P
s
P
p
.002 w
.46777 .60874 m .44597 .60468 L .45021 .58909 L p
1 g
F P
s
P
p
.002 w
.59322 .56727 m .5794 .59393 L .55081 .59476 L p
1 g
F P
s
P
p
.002 w
.5794 .59393 m .59322 .56727 L .62191 .55669 L p
1 g
F P
s
P
p
.002 w
.43088 .57802 m .43964 .58455 L .42551 .59591 L p
1 g
F P
s
P
p
.002 w
.42551 .59591 m .40844 .58329 L .43088 .57802 L p
1 g
F P
s
P
p
.002 w
.43161 .30277 m .37302 .31966 L .37867 .29575 L p
1 g
F P
s
P
p
.002 w
.37867 .29575 m .4381 .27818 L .43161 .30277 L p
1 g
F P
s
P
p
.002 w
.45021 .58909 m .46147 .59117 L .46777 .60874 L p
1 g
F P
s
P
p
.002 w
.48878 .60766 m .46777 .60874 L .46147 .59117 L p
1 g
F P
s
P
p
.002 w
.50631 .27936 m .4381 .27818 L .44618 .25884 L p
1 g
F P
s
P
p
.002 w
.44618 .25884 m .51329 .25979 L .50631 .27936 L p
1 g
F P
s
P
p
.002 w
.63234 .3365 m .67322 .38429 L .664 .4072 L p
1 g
F P
s
P
p
.002 w
.67322 .38429 m .63234 .3365 L .63706 .31611 L p
1 g
F P
s
P
p
.002 w
.57997 .27979 m .63706 .31611 L .63234 .3365 L p
1 g
F P
s
P
p
.002 w
.42485 .57016 m .43088 .57802 L .40844 .58329 L p
1 g
F P
s
P
p
.002 w
.40844 .58329 m .39653 .56802 L .42485 .57016 L p
1 g
F P
s
P
p
.002 w
.3729 .37874 m .33483 .40588 L .32995 .37766 L p
1 g
F P
s
P
p
.002 w
.32995 .37766 m .37102 .3476 L .3729 .37874 L p
1 g
F P
s
P
p
.002 w
.35961 .46548 m .34352 .4917 L .32605 .46721 L p
1 g
F P
s
P
p
.002 w
.32605 .46721 m .34479 .43549 L .35961 .46548 L p
1 g
F P
s
P
p
.002 w
.46147 .59117 m .47228 .59057 L .48878 .60766 L p
1 g
F P
s
P
p
.002 w
.50684 .60147 m .48878 .60766 L .47228 .59057 L p
1 g
F P
s
P
p
.002 w
.62284 .51949 m .62191 .55669 L .59322 .56727 L p
1 g
F P
s
P
p
.002 w
.62191 .55669 m .62284 .51949 L .64807 .50042 L p
1 g
F P
s
P
p
.002 w
.64957 .43148 m .66838 .47972 L .64807 .50042 L p
1 g
F P
s
P
p
.002 w
.66838 .47972 m .64957 .43148 L .664 .4072 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.3929 .53581 m .3911 .55163 L .3638 .53809 L p
1 g
F P
s
P
p
.002 w
.3638 .53809 m .36602 .51485 L .3929 .53581 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.004 w
.46582 .53768 m
.5 .43051 L
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.42221 .56179 m .42485 .57016 L .39653 .56802 L p
1 g
F P
s
P
p
.002 w
.39653 .56802 m .3911 .55163 L .42221 .56179 L p
1 g
F P
s
P
p
.002 w
.56117 .57394 m .55081 .59476 L .52004 .59071 L p
1 g
F P
s
P
p
.002 w
.50684 .60147 m .52004 .59071 L .55081 .59476 L p
1 g
F P
s
P
p
.002 w
.55081 .59476 m .56117 .57394 L .59322 .56727 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.57418 .29973 m .50631 .27936 L .51329 .25979 L p
1 g
F P
s
P
p
.002 w
.51329 .25979 m .57997 .27979 L .57418 .29973 L p
1 g
F P
s
P
p
.002 w
.47228 .59057 m .48148 .58733 L .50684 .60147 L p
1 g
F P
s
P
p
.002 w
.52004 .59071 m .50684 .60147 L .48148 .58733 L p
1 g
F P
s
P
p
.002 w
.63234 .3365 m .57418 .29973 L .57997 .27979 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.42703 .33197 m .37102 .3476 L .37302 .31966 L p
1 g
F P
s
P
p
.002 w
.37302 .31966 m .43161 .30277 L .42703 .33197 L p
1 g
F P
s
P
p
.002 w
.37889 .49478 m .36602 .51485 L .34352 .4917 L p
1 g
F P
s
P
p
.002 w
.34352 .4917 m .35961 .46548 L .37889 .49478 L p
1 g
F P
s
P
p
.002 w
.3787 .41205 m .34479 .43549 L .33483 .40588 L p
1 g
F P
s
P
p
.002 w
.33483 .40588 m .3729 .37874 L .3787 .41205 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.45021 .58909 m .43964 .58455 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.46147 .59117 m .45021 .58909 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.62345 .36042 m .664 .4072 L .64957 .43148 L p
1 g
F P
s
P
p
.002 w
.664 .4072 m .62345 .36042 L .63234 .3365 L p
1 g
F P
s
P
p
.002 w
.59345 .53618 m .59322 .56727 L .56117 .57394 L p
1 g
F P
s
P
p
.002 w
.59322 .56727 m .59345 .53618 L .62284 .51949 L p
1 g
F P
s
P
p
.002 w
.43964 .58455 m .43088 .57802 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.47228 .59057 m .46147 .59117 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.49891 .3042 m .43161 .30277 L .4381 .27818 L p
1 g
F P
s
P
p
.002 w
.4381 .27818 m .50631 .27936 L .49891 .3042 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.63024 .45632 m .64807 .50042 L .62284 .51949 L p
1 g
F P
s
P
p
.002 w
.64807 .50042 m .63024 .45632 L .64957 .43148 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.43088 .57802 m .42485 .57016 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.42329 .5538 m .42221 .56179 L .3911 .55163 L p
1 g
F P
s
P
p
.002 w
.3911 .55163 m .3929 .53581 L .42329 .5538 L p
1 g
F P
s
P
p
.002 w
.48148 .58733 m .47228 .59057 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.57418 .29973 m .63234 .3365 L .62345 .36042 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48148 .58733 m .46207 .57264 L p
.46907 .57509 L 1 g
F P
s
P
p
.002 w
.46829 .57464 m .46872 .57265 L p
.45692 .56794 L 1 g
F P
s
P
p
.002 w
.45713 .56807 m .45611 .56813 L .45683 .56788 L p
1 g
F P
s
P
p
.45692 .56794 m .4569 .56793 L .45703 .56801 L 1 g
F
P
p
.45692 .56794 m .45703 .56801 L .46829 .57464 L 1 g
F
P
p
.4569 .56793 m .45752 .5683 L .46829 .57464 L 1 g
F
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.42329 .5538 m .42803 .54706 L .45226 .56524 L p
1 g
F P
s
P
p
.002 w
.45226 .56524 m .45611 .56813 L .45373 .56709 L p
1 g
F P
s
P
p
.002 w
.45373 .56709 m .42329 .5538 L p
.45226 .56524 L 1 g
F P
s
P
p
.002 w
.45072 .56328 m .45146 .56129 L p
.44424 .55502 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45072 .56328 L p
1 g
F P
s
P
p
.002 w
.45611 .56813 m .45226 .56524 L p
.45104 .56352 L 1 g
F P
s
P
p
.002 w
.45471 .56633 m .45611 .56813 L p
.45104 .56352 L 1 g
F P
s
P
p
.002 w
.42803 .54706 m .43483 .54302 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.45226 .56524 m .44225 .55773 L p
.4383 .54745 L 1 g
F P
s
P
p
.002 w
.44225 .55773 m .42803 .54706 L p
.4383 .54745 L 1 g
F P
s
P
p
.41749 .51272 m .43199 .52657 L .43256 .5288 L 1 g
F
P
p
.002 w
.4321 .53614 m .41749 .51272 L p
.43256 .5288 L 1 g
F P
s
P
p
.002 w
.43257 .52864 m .43346 .52734 L p
.43317 .51894 L 1 g
F P
s
P
p
.002 w
.4383 .54745 m .43925 .54566 L p
.43486 .53698 L 1 g
F P
s
P
p
.43486 .53698 m .43627 .54211 L .4383 .54745 L 1 g
F
P
p
.002 w
.43597 .54234 m .4321 .53614 L p
.43256 .5288 L 1 g
F P
s
P
p
.002 w
.43632 .54226 m .43597 .54234 L p
.43199 .52657 L 1 g
F P
s
P
p
.43271 .53272 m .4367 .54327 L .4383 .54745 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43257 .52864 L p
1 g
F P
s
P
p
.002 w
.43257 .52864 m .43146 .53025 L p
.43486 .53698 L 1 g
F P
s
P
p
.43925 .54566 m .43257 .52864 L .43486 .53698 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43375 .50957 L p
1 g
F P
s
P
p
.43346 .52734 m .43375 .50957 L .43317 .51894 L 1 g
F
P
p
.42973 .51836 m .43785 .50823 L .43199 .52657 L 1 g
F
P
p
.002 w
.42757 .5105 m .43397 .50908 L p
.42973 .51836 L 1 g
F P
s
P
p
.002 w
.43397 .50908 m .43785 .50823 L p
.42973 .51836 L 1 g
F P
s
P
p
.002 w
.41749 .51272 m .40139 .48032 L p
.43531 .50629 L 1 g
F P
s
P
p
.43124 .47338 m .44388 .48884 L .4427 .49124 L 1 g
F
P
p
.002 w
.43687 .50305 m .43588 .49784 L p
.4427 .49124 L 1 g
F P
s
P
p
.002 w
.43588 .49784 m .43124 .47338 L p
.4427 .49124 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44237 .49159 L p
1 g
F P
s
P
p
.002 w
.44237 .49159 m .44166 .49233 L p
.43882 .49898 L 1 g
F P
s
P
p
.43485 .50826 m .44237 .49159 L .43882 .49898 L 1 g
F
P
p
.002 w
.40139 .48032 m .43124 .47338 L .43687 .50305 L p
1 g
F P
s
P
p
.43485 .50826 m .43845 .49984 L .43808 .50058 L 1 g
F
P
p
.40139 .48032 m .43687 .50305 L .43531 .50629 L 1 g
F
P
p
.002 w
.43397 .50908 m .41749 .51272 L p
.43531 .50629 L 1 g
F P
s
P
p
.002 w
.43375 .50957 m .43485 .50826 L p
.44084 .49405 L 1 g
F P
s
P
p
.002 w
.43687 .50305 m .43785 .50823 L p
.43531 .50629 L 1 g
F P
s
P
p
.002 w
.4427 .49124 m .44339 .4905 L p
.44939 .48475 L 1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.4427 .49124 m .46075 .50947 L .43687 .50305 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45763 .47677 L p
1 g
F P
s
P
p
.44339 .4905 m .45763 .47677 L .44939 .48475 L 1 g
F
P
p
.44388 .48884 m .44445 .48954 L .4427 .49124 L 1 g
F
P
p
.44445 .48954 m .46075 .50947 L .4427 .49124 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.46503 .47502 m .46075 .50947 L p
.44048 .48468 L 1 g
F P
s
P
p
.002 w
.49866 .48518 m .46503 .47502 L .46531 .47318 L p
1 g
F P
s
P
p
.002 w
.45763 .47677 m .45826 .47608 L p
.4687 .4715 L 1 g
F P
s
P
p
.4687 .4715 m .4661 .47279 L .45763 .47677 L 1 g
F
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.47761 .46708 m .49866 .48518 L .46531 .47318 L 1 g
F
P
p
.002 w
.47761 .46708 m .47786 .46667 L p
.4861 .46583 L 1 g
F P
s
P
p
.48683 .46573 m .49866 .48518 L .47761 .46708 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46378 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46378 L .4861 .46583 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52237 .46706 L p
1 g
F P
s
P
p
.51802 .46647 m .52799 .50262 L .50794 .4651 L 1 g
F
P
p
.5 .4634 m .52237 .46706 L .51314 .46581 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56598 .50925 L p
1 g
F P
s
P
p
.002 w
.57932 .50404 m .5675 .51239 L p
.56591 .50855 L 1 g
F P
s
P
p
.002 w
.55185 .4747 m .56358 .48723 L p
.56591 .50855 L 1 g
F P
s
P
p
.002 w
.56358 .48723 m .57932 .50404 L p
.56591 .50855 L 1 g
F P
s
P
p
.002 w
.56598 .50925 m .56515 .50826 L p
.56667 .5181 L 1 g
F P
s
P
p
.57932 .50404 m .56747 .53349 L .5672 .5283 L 1 g
F
P
p
.002 w
.56641 .51316 m .57276 .50867 L p
.5672 .5283 L 1 g
F P
s
P
p
.002 w
.57276 .50867 m .57932 .50404 L p
.5672 .5283 L 1 g
F P
s
P
p
.002 w
.5672 .5283 m .56654 .52734 L p
.56486 .53655 L 1 g
F P
s
P
p
.56667 .5181 m .56641 .51316 L .56598 .50925 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56174 .54753 L p
1 g
F P
s
P
p
.56747 .53349 m .56195 .5472 L .56205 .54646 L 1 g
F
P
p
.56747 .53349 m .56205 .54646 L .5672 .5283 L 1 g
F
P
p
.56654 .52734 m .56174 .54753 L .56486 .53655 L 1 g
F
P
p
.002 w
.56174 .54753 m .56075 .54566 L p
.55679 .55387 L 1 g
F P
s
P
p
.002 w
.56117 .57394 m .53812 .57558 L p
.54992 .56224 L 1 g
F P
s
P
p
.002 w
.56088 .54985 m .56094 .5546 L p
.54992 .56224 L 1 g
F P
s
P
p
.002 w
.56094 .5546 m .56117 .57394 L p
.54992 .56224 L 1 g
F P
s
P
p
.002 w
.5491 .56281 m .54854 .56129 L p
.54118 .5683 L 1 g
F P
s
P
p
.55679 .55387 m .56003 .5501 L .56174 .54753 L 1 g
F
P
p
.002 w
.56063 .54931 m .56088 .54985 L .56003 .5501 L p
1 g
F P
s
P
p
.56003 .5501 m .56041 .54967 L .56063 .54931 L 1 g
F
P
p
.56003 .5501 m .56063 .54931 L .56174 .54753 L 1 g
F
P
p
.56088 .54985 m .53812 .57558 L .55895 .55135 L 1 g
F
P
p
.002 w
.54998 .56518 m .55352 .56066 L p
.55679 .55387 L 1 g
F P
s
P
p
.56075 .54566 m .5552 .55572 L .55679 .55387 L 1 g
F
P
p
.5552 .55572 m .54998 .56518 L .55679 .55387 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58055 L p
1 g
F P
s
P
p
.51093 .58055 m .52177 .58706 L .5 .58315 L 1 g
F
P
p
.002 w
.52662 .57683 m .52505 .58015 L p
.51093 .58055 L 1 g
F P
s
P
p
.002 w
.52505 .58015 m .52177 .58706 L p
.51093 .58055 L 1 g
F P
s
P
p
.002 w
.51093 .58055 m .51079 .57862 L p
.49948 .58088 L 1 g
F P
s
P
p
.53128 .57265 m .51093 .58055 L .52013 .57837 L 1 g
F
P
p
.49348 .58105 m .5 .58315 L .49046 .58144 L 1 g
F
P
p
.51079 .57862 m .48902 .58118 L .49948 .58088 L 1 g
F
P
p
.002 w
.53176 .57484 m .53128 .57265 L p
.51683 .58028 L 1 g
F P
s
P
p
.002 w
.52004 .59071 m .52579 .57858 L p
.56117 .57394 L 1 g
F P
s
P
p
.002 w
.52579 .57858 m .52662 .57683 L p
.52908 .57662 L 1 g
F P
s
P
p
.56117 .57394 m .52579 .57858 L .52908 .57662 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53176 .57484 L p
1 g
F P
s
P
p
.54854 .56129 m .53176 .57484 L .53332 .57375 L 1 g
F
P
p
.5491 .56281 m .54246 .57054 L .53268 .5742 L 1 g
F
P
p
.54246 .57054 m .52983 .57617 L .53176 .57484 L 1 g
F
P
p
.51683 .58028 m .52814 .57629 L .53176 .57484 L 1 g
F
P
p
.002 w
.52814 .57629 m .52683 .57639 L p
.54246 .57054 L 1 g
F P
s
P
p
.54118 .5683 m .53179 .575 L .53808 .57126 L 1 g
F
P
p
.54854 .56129 m .53332 .57375 L .54118 .5683 L 1 g
F
P
p
.53332 .57375 m .53179 .575 L .54118 .5683 L 1 g
F
P
p
.002 w
.53812 .57558 m .52983 .57617 L p
.54246 .57054 L 1 g
F P
s
P
p
.002 w
.52983 .57617 m .52814 .57629 L p
.53176 .57484 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.55895 .55135 m .5491 .56281 L .52683 .57639 L 1 g
F
P
p
.5491 .56281 m .53268 .5742 L .52683 .57639 L 1 g
F
P
p
.002 w
.53176 .57484 m .53179 .575 L p
.53332 .57375 L 1 g
F P
s
P
p
.002 w
.52814 .57629 m .56117 .57394 L p
.52662 .57683 L 1 g
F P
s
P
p
.002 w
.53179 .575 m .5322 .57686 L p
.53808 .57126 L 1 g
F P
s
P
p
.51683 .58028 m .51238 .58263 L .52814 .57629 L 1 g
F
P
p
.002 w
.52662 .57683 m .52683 .57639 L .52814 .57629 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .51238 .58263 L p
.53128 .57265 L 1 g
F P
s
P
p
.002 w
.51238 .58263 m .5322 .57686 L .53176 .57484 L p
1 g
F P
s
P
p
.52662 .57683 m .51093 .58055 L .49348 .58105 L 1 g
F
P
p
.51093 .58055 m .5 .58315 L .49348 .58105 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48902 .58118 L p
1 g
F P
s
P
p
.002 w
.52683 .57639 m .52662 .57683 L p
.49046 .58144 L 1 g
F P
s
P
p
.002 w
.52004 .59071 m .4881 .58177 L p
.49046 .58144 L 1 g
F P
s
P
p
.002 w
.52177 .58706 m .52004 .59071 L p
.49046 .58144 L 1 g
F P
s
P
p
.002 w
.48148 .58733 m .4881 .58177 L .52004 .59071 L p
1 g
F P
s
P
p
.002 w
.48079 .57865 m .4881 .58177 L p
.46207 .57264 L 1 g
F P
s
P
p
.002 w
.48902 .58118 m .48921 .57862 L p
.47997 .57839 L 1 g
F P
s
P
p
.002 w
.48841 .58107 m .4881 .58177 L .48079 .57865 L p
1 g
F P
s
P
p
.002 w
.4881 .58177 m .48496 .58441 L p
.46907 .57509 L 1 g
F P
s
P
p
.002 w
.48496 .58441 m .48148 .58733 L p
.46907 .57509 L 1 g
F P
s
P
p
.47997 .57839 m .47239 .5782 L .48841 .58107 L 1 g
F
P
p
.47997 .57839 m .48841 .58107 L .48902 .58118 L 1 g
F
P
p
.46872 .57265 m .45072 .56328 L .45471 .56633 L 1 g
F
P
p
.46872 .57265 m .45471 .56633 L .45576 .56713 L 1 g
F
P
p
.002 w
.45616 .56742 m .45611 .56813 L .45576 .56713 L p
1 g
F P
s
P
p
.456 .5673 m .45576 .56713 L .45599 .5673 L 1 g
F
P
p
.46872 .57265 m .45576 .56713 L .456 .5673 L 1 g
F
P
p
.46872 .57265 m .45599 .5673 L .45618 .56743 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.44626 .54018 m .45776 .54086 L .45616 .56742 L p
1 g
F P
s
P
p
.002 w
.45576 .56713 m .44626 .54018 L p
.45616 .56742 L 1 g
F P
s
P
p
.46872 .57265 m .45615 .56742 L .45688 .56792 L 1 g
F
P
p
.002 w
.45776 .54086 m .46917 .54432 L .4564 .5676 L p
1 g
F P
s
P
p
.002 w
.4564 .5676 m .45611 .56813 L .45616 .56742 L p
1 g
F P
s
P
p
.002 w
.45616 .56742 m .45776 .54086 L p
.4564 .5676 L 1 g
F P
s
P
p
.45618 .56743 m .45599 .5673 L .45615 .56742 L 1 g
F
P
p
.002 w
.45661 .56774 m .45611 .56813 L .4564 .5676 L p
1 g
F P
s
P
p
.45688 .56792 m .45615 .56742 L .45673 .56786 L 1 g
F
P
p
.002 w
.46917 .54432 m .4792 .55016 L .45661 .56774 L p
1 g
F P
s
P
p
.002 w
.4564 .5676 m .46917 .54432 L p
.45661 .56774 L 1 g
F P
s
P
p
.002 w
.4792 .55016 m .48673 .55771 L .45683 .56788 L p
1 g
F P
s
P
p
.002 w
.45683 .56788 m .45611 .56813 L .45661 .56774 L p
1 g
F P
s
P
p
.002 w
.45661 .56774 m .4792 .55016 L p
.45683 .56788 L 1 g
F P
s
P
p
.45673 .56786 m .45629 .56752 L .45668 .56784 L 1 g
F
P
p
.002 w
.45576 .56713 m .45611 .56813 L .45471 .56633 L p
1 g
F P
s
P
p
.45629 .56752 m .45471 .56633 L .45615 .56744 L 1 g
F
P
p
.45629 .56752 m .45615 .56744 L .45668 .56784 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.44626 .54018 m .45576 .56713 L p
.4367 .54327 L 1 g
F P
s
P
p
.002 w
.45471 .56633 m .4367 .54327 L p
.45576 .56713 L 1 g
F P
s
P
p
.45684 .5679 m .46007 .56982 L .46829 .57464 L 1 g
F
P
p
.48921 .57862 m .47777 .57768 L .47998 .57839 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.49139 .57444 m .48841 .58107 L p
.46007 .56982 L 1 g
F P
s
P
p
.002 w
.48079 .57865 m .46007 .56982 L p
.48841 .58107 L 1 g
F P
s
P
p
.002 w
.4881 .58177 m .49139 .57444 L .52683 .57639 L p
1 g
F P
s
P
p
.002 w
.48902 .58118 m .48889 .583 L p
.49948 .58088 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58055 L p
1 g
F P
s
P
p
.49948 .58088 m .48889 .583 L .51093 .58055 L 1 g
F
P
p
.002 w
.51093 .58055 m .51111 .583 L p
.52013 .57837 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.52683 .57639 m .52629 .55996 L .56003 .5501 L p
1 g
F P
s
P
p
.002 w
.56003 .5501 m .56088 .54985 L p
.55895 .55135 L 1 g
F P
s
P
p
.55895 .55135 m .52683 .57639 L .56003 .5501 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54951 .52511 m .56063 .54931 L p
.52629 .55996 L 1 g
F P
s
P
p
.002 w
.56003 .5501 m .52629 .55996 L p
.56063 .54931 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .5491 .56281 L p
1 g
F P
s
P
p
.54118 .5683 m .5322 .57686 L .5491 .56281 L 1 g
F
P
p
.55679 .55387 m .55352 .56066 L .56041 .54967 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56195 .5472 m .56107 .54861 L .56641 .51316 L 1 g
F
P
p
.002 w
.59345 .53618 m .56088 .54985 L p
.56195 .5472 L 1 g
F P
s
P
p
.002 w
.57932 .50404 m .58331 .51311 L p
.56195 .5472 L 1 g
F P
s
P
p
.002 w
.58331 .51311 m .59345 .53618 L p
.56195 .5472 L 1 g
F P
s
P
p
.002 w
.56117 .57394 m .56088 .54985 L .59345 .53618 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .55352 .56066 L p
.55144 .56909 L 1 g
F P
s
P
p
.002 w
.55352 .56066 m .54998 .56518 L .55025 .56588 L p
1 g
F P
s
P
p
.002 w
.55025 .56588 m .55144 .56909 L p
.55352 .56066 L 1 g
F P
s
P
p
.002 w
.56174 .54753 m .56257 .5491 L p
.56486 .53655 L 1 g
F P
s
P
p
.5672 .5283 m .56205 .54646 L .56641 .51316 L 1 g
F
P
p
.56195 .5472 m .56088 .54985 L .56107 .54861 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56088 .54985 m .54951 .52511 L .56641 .51316 L p
1 g
F P
s
P
p
.002 w
.55352 .56066 m .56257 .5491 L .56174 .54753 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5672 .5283 L p
1 g
F P
s
P
p
.56486 .53655 m .56257 .5491 L .5672 .5283 L 1 g
F
P
p
.56667 .5181 m .56764 .52442 L .56641 .51316 L 1 g
F
P
p
.55661 .4905 m .56598 .50925 L .56058 .49809 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.5675 .51239 m .54951 .52511 L p
.55135 .48547 L 1 g
F P
s
P
p
.55185 .4747 m .55966 .49351 L .55162 .4796 L 1 g
F
P
p
.55966 .49351 m .5675 .51239 L .55721 .49114 L 1 g
F
P
p
.55966 .49351 m .55721 .49114 L .55162 .4796 L 1 g
F
P
p
.002 w
.55809 .49208 m .55661 .4905 L p
.55674 .49075 L 1 g
F P
s
P
p
.55674 .49075 m .56713 .51061 L .55809 .49208 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55809 .49208 L p
1 g
F P
s
P
p
.55721 .49114 m .5675 .51239 L .55135 .48547 L 1 g
F
P
p
.54174 .47608 m .55071 .48485 L .54985 .48402 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55721 .49114 L p
1 g
F P
s
P
p
.002 w
.54951 .52511 m .52799 .50262 L .54658 .48086 L p
1 g
F P
s
P
p
.54174 .47608 m .55721 .49114 L .55071 .48485 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.55135 .48547 m .54951 .52511 L .54658 .48086 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54658 .48086 m .52799 .50262 L p
.53571 .47351 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54229 .47668 L p
1 g
F P
s
P
p
.52214 .46667 m .54229 .47668 L .53013 .47081 L 1 g
F
P
p
.5364 .47094 m .54229 .47668 L .53571 .47351 L 1 g
F
P
p
.54229 .47668 m .54658 .48086 L .53571 .47351 L 1 g
F
P
p
.51802 .46647 m .52433 .468 L .52799 .50262 L 1 g
F
P
p
.002 w
.52237 .46706 m .52214 .46667 L p
.53013 .47081 L 1 g
F P
s
P
p
.52433 .468 m .5364 .47094 L .53571 .47351 L 1 g
F
P
p
.52433 .468 m .53571 .47351 L .52799 .50262 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.54403 .47 m .55185 .4747 L p
.51802 .46647 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52237 .46706 L p
1 g
F P
s
P
p
.53013 .47081 m .54302 .47747 L .52237 .46706 L 1 g
F
P
p
.002 w
.54229 .47668 m .54302 .47747 L p
.53013 .47081 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54658 .48086 m .55185 .4747 L p
.55135 .48547 L 1 g
F P
s
P
p
.54985 .48402 m .55809 .49208 L .55435 .48843 L 1 g
F
P
p
.55071 .48485 m .55809 .49208 L .54985 .48402 L 1 g
F
P
p
.55162 .4796 m .55721 .49114 L .55135 .48547 L 1 g
F
P
p
.002 w
.55721 .49114 m .55809 .49208 L p
.55071 .48485 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56598 .50925 L p
1 g
F P
s
P
p
.56764 .52442 m .56854 .53025 L .56598 .50925 L 1 g
F
P
p
.002 w
.56598 .50925 m .56713 .51061 L p
.56058 .49809 L 1 g
F P
s
P
p
.002 w
.55809 .49208 m .55834 .49233 L p
.55435 .48843 L 1 g
F P
s
P
p
.002 w
.55185 .4747 m .54658 .48086 L p
.5364 .47094 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51401 .45195 m .54403 .47 L p
.51802 .46647 L 1 g
F P
s
P
p
.51103 .46552 m .52267 .46755 L .51471 .46623 L 1 g
F
P
p
.5 .4634 m .51314 .46581 L .51103 .46552 L 1 g
F
P
p
.51314 .46581 m .52267 .46755 L .51103 .46552 L 1 g
F
P
p
.002 w
.52237 .46706 m .52267 .46755 L p
.51314 .46581 L 1 g
F P
s
P
p
.002 w
.52799 .50262 m .49866 .48518 L .50794 .4651 L p
1 g
F P
s
P
p
.002 w
.50794 .4651 m .49866 .48518 L p
.48403 .46113 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.50794 .4651 m .51401 .45195 L p
.51802 .46647 L 1 g
F P
s
P
p
.002 w
.47046 .4388 m .51401 .45195 L .50794 .4651 L p
1 g
F P
s
P
p
.47046 .4388 m .50794 .4651 L .48403 .46113 L 1 g
F
P
p
.002 w
.52267 .46755 m .52282 .46778 L p
.51471 .46623 L 1 g
F P
s
P
p
.002 w
.5 .46378 m .5 .46442 L p
.4861 .46583 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47737 .46747 L p
1 g
F P
s
P
p
.002 w
.47737 .46747 m .47718 .46778 L p
.47087 .47055 L 1 g
F P
s
P
p
.45826 .47608 m .47737 .46747 L .47087 .47055 L 1 g
F
P
p
.47087 .47055 m .46531 .47318 L .46531 .47316 L 1 g
F
P
p
.46531 .47318 m .46176 .47486 L .46531 .47316 L 1 g
F
P
p
.46531 .47316 m .46176 .47486 L .45763 .47677 L 1 g
F
P
p
.002 w
.42673 .43693 m .47046 .4388 L .46531 .47318 L p
1 g
F P
s
P
p
.002 w
.46531 .47318 m .46503 .47502 L p
.46387 .47386 L 1 g
F P
s
P
p
.42673 .43693 m .46531 .47318 L .46387 .47386 L 1 g
F
P
p
.47046 .4388 m .48533 .46326 L .47761 .46708 L 1 g
F
P
p
.002 w
.46531 .47318 m .46596 .4688 L p
.47761 .46708 L 1 g
F P
s
P
p
.002 w
.46596 .4688 m .47046 .4388 L p
.47761 .46708 L 1 g
F P
s
P
p
.48533 .46326 m .48683 .46573 L .47761 .46708 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .47761 .46708 L p
1 g
F P
s
P
p
.4861 .46583 m .5 .46442 L .47761 .46708 L 1 g
F
P
p
.4687 .4715 m .47087 .47055 L .4661 .47279 L 1 g
F
P
p
.002 w
.46503 .47502 m .46176 .47486 L p
.46387 .47386 L 1 g
F P
s
P
p
.47087 .47055 m .47564 .46846 L .46176 .47486 L 1 g
F
P
p
.002 w
.43124 .47338 m .42673 .43693 L p
.46387 .47386 L 1 g
F P
s
P
p
.002 w
.46176 .47486 m .43124 .47338 L p
.46387 .47386 L 1 g
F P
s
P
p
.002 w
.43124 .47338 m .46176 .47486 L p
.44048 .48468 L 1 g
F P
s
P
p
.002 w
.46176 .47486 m .46503 .47502 L p
.44048 .48468 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45763 .47677 L p
1 g
F P
s
P
p
.47564 .46846 m .47718 .46778 L .45763 .47677 L 1 g
F
P
p
.002 w
.45763 .47677 m .45698 .47747 L p
.44939 .48475 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .4427 .49124 L p
1 g
F P
s
P
p
.44939 .48475 m .45698 .47747 L .4427 .49124 L 1 g
F
P
p
.43808 .50058 m .43882 .49898 L .43833 .5 L 1 g
F
P
p
.43845 .49984 m .43882 .49898 L .43808 .50058 L 1 g
F
P
p
.002 w
.46075 .50947 m .43785 .50823 L .43687 .50305 L p
1 g
F P
s
P
p
.002 w
.43785 .50823 m .43397 .50908 L p
.43531 .50629 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .44084 .49405 L p
.43833 .5 L 1 g
F P
s
P
p
.43882 .49898 m .44166 .49233 L .43833 .5 L 1 g
F
P
p
.002 w
.44084 .49405 m .43287 .51061 L .43375 .50957 L p
1 g
F P
s
P
p
.002 w
.43375 .50957 m .43287 .51061 L p
.43317 .51894 L 1 g
F P
s
P
p
.002 w
.43785 .50823 m .44626 .54018 L p
.43266 .5272 L 1 g
F P
s
P
p
.43199 .52657 m .43286 .52384 L .43266 .5272 L 1 g
F
P
p
.43286 .52384 m .43785 .50823 L .43266 .5272 L 1 g
F
P
p
.002 w
.41749 .51272 m .42757 .5105 L p
.43199 .52657 L 1 g
F P
s
P
p
.002 w
.44626 .54018 m .43632 .54226 L p
.43199 .52657 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43257 .52864 L p
1 g
F P
s
P
p
.43317 .51894 m .43287 .51061 L .43257 .52864 L 1 g
F
P
p
.43486 .53698 m .43271 .53272 L .43627 .54211 L 1 g
F
P
p
.43271 .53272 m .43245 .53221 L .4367 .54327 L 1 g
F
P
p
.002 w
.4367 .54327 m .43597 .54234 L .43632 .54226 L p
1 g
F P
s
P
p
.002 w
.43632 .54226 m .44626 .54018 L p
.4367 .54327 L 1 g
F P
s
P
p
.002 w
.43597 .54234 m .45471 .56633 L p
.45104 .56352 L 1 g
F P
s
P
p
.002 w
.43483 .54302 m .43597 .54234 L p
.45226 .56524 L 1 g
F P
s
P
p
.002 w
.43597 .54234 m .42803 .54706 L .40197 .52232 L p
1 g
F P
s
P
p
.002 w
.40197 .52232 m .41749 .51272 L .43597 .54234 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.43245 .53221 m .43146 .53025 L .4383 .54745 L 1 g
F
P
p
.002 w
.45072 .56328 m .45002 .56518 L p
.45668 .56784 L 1 g
F P
s
P
p
.002 w
.45071 .56329 m .45072 .56328 L p
.44391 .55473 L 1 g
F P
s
P
p
.44424 .55502 m .44391 .55473 L .45072 .56328 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45071 .56329 L p
1 g
F P
s
P
p
.44391 .55473 m .43743 .5491 L .45071 .56329 L 1 g
F
P
p
.002 w
.48673 .55771 m .49093 .56612 L .45713 .56807 L p
1 g
F P
s
P
p
.002 w
.45683 .56788 m .48673 .55771 L p
.45713 .56807 L 1 g
F P
s
P
p
.002 w
.49093 .56612 m .49139 .57444 L .4577 .56841 L p
1 g
F P
s
P
p
.002 w
.4577 .56841 m .45611 .56813 L .45713 .56807 L p
1 g
F P
s
P
p
.002 w
.45713 .56807 m .49093 .56612 L p
.4577 .56841 L 1 g
F P
s
P
p
.4569 .56793 m .45684 .5679 L .45752 .5683 L 1 g
F
P
p
.002 w
.46007 .56982 m .45611 .56813 L .4577 .56841 L p
1 g
F P
s
P
p
.45684 .5679 m .45675 .56787 L .46007 .56982 L 1 g
F
P
p
.002 w
.4577 .56841 m .49139 .57444 L p
.46007 .56982 L 1 g
F P
s
P
p
.002 w
.46207 .57264 m .45611 .56813 L .48079 .57865 L p
1 g
F P
s
P
p
.002 w
.42485 .57016 m .42221 .56179 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.42221 .56179 m .42329 .5538 L .45611 .56813 L closepath p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46829 .57464 L p
1 g
F P
s
P
p
.45675 .56787 m .45002 .56518 L .46829 .57464 L 1 g
F
P
p
.002 w
.4678 .57686 m .47239 .5782 L p
.47998 .57839 L 1 g
F P
s
P
p
.47777 .57768 m .4678 .57686 L .47998 .57839 L 1 g
F
P
p
.002 w
.47239 .5782 m .48889 .583 L .48902 .58118 L p
1 g
F P
s
P
p
.002 w
.40197 .52232 m .3929 .53581 L .36602 .51485 L p
1 g
F P
s
P
p
.002 w
.36602 .51485 m .37889 .49478 L .40197 .52232 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.3883 .44634 m .35961 .46548 L .34479 .43549 L p
1 g
F P
s
P
p
.002 w
.34479 .43549 m .3787 .41205 L .3883 .44634 L p
1 g
F P
s
P
p
.002 w
.42461 .36485 m .3729 .37874 L .37102 .3476 L p
1 g
F P
s
P
p
.002 w
.37102 .3476 m .42703 .33197 L .42461 .36485 L p
1 g
F P
s
P
p
.002 w
.60656 .48081 m .62284 .51949 L .59345 .53618 L p
1 g
F P
s
P
p
.002 w
.62284 .51949 m .60656 .48081 L .63024 .45632 L p
1 g
F P
s
P
p
.002 w
.56593 .32433 m .49891 .3042 L .50631 .27936 L p
1 g
F P
s
P
p
.002 w
.50631 .27936 m .57418 .29973 L .56593 .32433 L p
1 g
F P
s
P
p
.002 w
.62345 .36042 m .56593 .32433 L .57418 .29973 L p
1 g
F P
s
P
p
.002 w
.42803 .54706 m .42329 .5538 L .3929 .53581 L p
1 g
F P
s
P
p
.002 w
.3929 .53581 m .40197 .52232 L .42803 .54706 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61053 .38716 m .64957 .43148 L .63024 .45632 L p
1 g
F P
s
P
p
.002 w
.64957 .43148 m .61053 .38716 L .62345 .36042 L p
1 g
F P
s
P
p
.002 w
.52629 .55996 m .52683 .57639 L .49139 .57444 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.49134 .33364 m .42703 .33197 L .43161 .30277 L p
1 g
F P
s
P
p
.002 w
.43161 .30277 m .49891 .3042 L .49134 .33364 L p
1 g
F P
s
P
p
.002 w
.40139 .48032 m .37889 .49478 L .35961 .46548 L p
1 g
F P
s
P
p
.002 w
.35961 .46548 m .3883 .44634 L .40139 .48032 L p
1 g
F P
s
P
p
.002 w
.49139 .57444 m .49093 .56612 L .52629 .55996 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.56593 .32433 m .62345 .36042 L .61053 .38716 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.59345 .53618 m .57932 .50404 L .60656 .48081 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.4245 .40028 m .3787 .41205 L .3729 .37874 L p
1 g
F P
s
P
p
.002 w
.3729 .37874 m .42461 .36485 L .4245 .40028 L p
1 g
F P
s
P
p
.002 w
.41749 .51272 m .40197 .52232 L .37889 .49478 L p
1 g
F P
s
P
p
.002 w
.37889 .49478 m .40139 .48032 L .41749 .51272 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.49093 .56612 m .48673 .55771 L .51825 .54321 L p
1 g
F P
s
P
p
.002 w
.51825 .54321 m .52629 .55996 L .49093 .56612 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5939 .41584 m .63024 .45632 L .60656 .48081 L p
1 g
F P
s
P
p
.002 w
.63024 .45632 m .5939 .41584 L .61053 .38716 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.52629 .55996 m .51825 .54321 L .54951 .52511 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.48673 .55771 m .4792 .55016 L .50346 .52808 L p
1 g
F P
s
P
p
.002 w
.50346 .52808 m .51825 .54321 L .48673 .55771 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.55541 .3529 m .49134 .33364 L .49891 .3042 L p
1 g
F P
s
P
p
.002 w
.49891 .3042 m .56593 .32433 L .55541 .3529 L p
1 g
F P
s
P
p
.002 w
.61053 .38716 m .55541 .3529 L .56593 .32433 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42673 .43693 m .3883 .44634 L .3787 .41205 L p
1 g
F P
s
P
p
.002 w
.3787 .41205 m .4245 .40028 L .42673 .43693 L p
1 g
F P
s
P
p
.002 w
.48388 .36671 m .42461 .36485 L .42703 .33197 L p
1 g
F P
s
P
p
.002 w
.42703 .33197 m .49134 .33364 L .48388 .36671 L p
1 g
F P
s
P
p
.002 w
.45776 .54086 m .44626 .54018 L .43785 .50823 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.4792 .55016 m .46917 .54432 L .48352 .51636 L p
1 g
F P
s
P
p
.002 w
.48352 .51636 m .50346 .52808 L .4792 .55016 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.55541 .3529 m .61053 .38716 L .5939 .41584 L p
1 g
F P
s
P
p
.002 w
.46917 .54432 m .45776 .54086 L .46075 .50947 L p
1 g
F P
s
P
p
.002 w
.43785 .50823 m .46075 .50947 L .45776 .54086 L p
1 g
F P
s
P
p
.002 w
.46075 .50947 m .48352 .51636 L .46917 .54432 L p
1 g
F P
s
P
p
.002 w
.5741 .44539 m .60656 .48081 L .57932 .50404 L p
1 g
F P
s
P
p
.002 w
.60656 .48081 m .5741 .44539 L .5939 .41584 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51825 .54321 m .50346 .52808 L .52799 .50262 L p
1 g
F P
s
P
p
.002 w
.52799 .50262 m .54951 .52511 L .51825 .54321 L p
1 g
F P
s
P
p
.002 w
.43124 .47338 m .40139 .48032 L .3883 .44634 L p
1 g
F P
s
P
p
.002 w
.3883 .44634 m .42673 .43693 L .43124 .47338 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.57932 .50404 m .55185 .4747 L .5741 .44539 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.47682 .40222 m .4245 .40028 L .42461 .36485 L p
1 g
F P
s
P
p
.002 w
.42461 .36485 m .48388 .36671 L .47682 .40222 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.50346 .52808 m .48352 .51636 L .49866 .48518 L p
1 g
F P
s
P
p
.002 w
.49866 .48518 m .52799 .50262 L .50346 .52808 L p
1 g
F P
s
P
p
.002 w
.54295 .38449 m .48388 .36671 L .49134 .33364 L p
1 g
F P
s
P
p
.002 w
.49134 .33364 m .55541 .3529 L .54295 .38449 L p
1 g
F P
s
P
p
.002 w
.5939 .41584 m .54295 .38449 L .55541 .3529 L p
1 g
F P
s
P
p
.002 w
.54295 .38449 m .5939 .41584 L .5741 .44539 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.48352 .51636 m .46075 .50947 L .46503 .47502 L p
1 g
F P
s
P
p
.002 w
.46503 .47502 m .49866 .48518 L .48352 .51636 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.004 w
.43038 .64882 m
.43817 .6244 L
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.004 w
.43817 .6244 m
.44133 .61449 L
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.47046 .4388 m .42673 .43693 L .4245 .40028 L p
1 g
F P
s
P
p
.002 w
.4245 .40028 m .47682 .40222 L .47046 .4388 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.52897 .41793 m .5741 .44539 L .55185 .4747 L p
1 g
F P
s
P
p
.002 w
.5741 .44539 m .52897 .41793 L .54295 .38449 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.55185 .4747 m .51401 .45195 L .52897 .41793 L p
1 g
F P
s
P
p
.002 w
.52897 .41793 m .47682 .40222 L .48388 .36671 L p
1 g
F P
s
P
p
.002 w
.48388 .36671 m .54295 .38449 L .52897 .41793 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51401 .45195 m .47046 .4388 L .47682 .40222 L p
1 g
F P
s
P
p
.002 w
.47682 .40222 m .52897 .41793 L .51401 .45195 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .61018 .70736 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .43038 .64882 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.656589)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.656589)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.45492 .4392 m .48931 .46322 L .50246 .438 L p
1 g
F P
s
P
p
.002 w
.50246 .438 m .47384 .41795 L .45492 .4392 L p
1 g
F P
s
P
p
.002 w
.53523 .44971 m .50246 .438 L .48931 .46322 L p
1 g
F P
s
P
p
.002 w
.47384 .41795 m .50246 .438 L .51554 .41262 L p
1 g
F P
s
P
p
.002 w
.50246 .438 m .53523 .44971 L .54097 .42164 L p
1 g
F P
s
P
p
.002 w
.54097 .42164 m .51554 .41262 L .50246 .438 L p
1 g
F P
s
P
p
.002 w
.51554 .41262 m .49337 .39705 L .47384 .41795 L p
1 g
F P
s
P
p
.002 w
.49337 .39705 m .51554 .41262 L .52831 .38754 L p
1 g
F P
s
P
p
.002 w
.51554 .41262 m .54097 .42164 L .54574 .39368 L p
1 g
F P
s
P
p
.002 w
.54574 .39368 m .52831 .38754 L .51554 .41262 L p
1 g
F P
s
P
p
.002 w
.42867 .40751 m .45492 .4392 L .47384 .41795 L p
1 g
F P
s
P
p
.002 w
.47384 .41795 m .45212 .39147 L .42867 .40751 L p
1 g
F P
s
P
p
.002 w
.45212 .39147 m .47384 .41795 L .49337 .39705 L p
1 g
F P
s
P
p
.002 w
.49337 .39705 m .47664 .37644 L .45212 .39147 L p
1 g
F P
s
P
p
.002 w
.47664 .37644 m .49337 .39705 L .51314 .37686 L p
1 g
F P
s
P
p
.002 w
.52831 .38754 m .51314 .37686 L .49337 .39705 L p
1 g
F P
s
P
p
.002 w
.43693 .46041 m .47631 .48785 L .48931 .46322 L p
1 g
F P
s
P
p
.002 w
.48931 .46322 m .45492 .4392 L .43693 .46041 L p
1 g
F P
s
P
p
.002 w
.52862 .47738 m .48931 .46322 L .47631 .48785 L p
1 g
F P
s
P
p
.002 w
.48931 .46322 m .52862 .47738 L .53523 .44971 L p
1 g
F P
s
P
p
.002 w
.56903 .4519 m .53523 .44971 L .52862 .47738 L p
1 g
F P
s
P
p
.002 w
.53523 .44971 m .56903 .4519 L .56716 .42317 L p
1 g
F P
s
P
p
.002 w
.56716 .42317 m .54097 .42164 L .53523 .44971 L p
1 g
F P
s
P
p
.002 w
.54097 .42164 m .56716 .42317 L .56366 .39462 L p
1 g
F P
s
P
p
.002 w
.56366 .39462 m .54574 .39368 L .54097 .42164 L p
1 g
F P
s
P
p
.002 w
.40672 .42428 m .43693 .46041 L .45492 .4392 L p
1 g
F P
s
P
p
.002 w
.45492 .4392 m .42867 .40751 L .40672 .42428 L p
1 g
F P
s
P
p
.002 w
.51314 .37686 m .52831 .38754 L .54054 .36323 L p
1 g
F P
s
P
p
.002 w
.52831 .38754 m .54574 .39368 L .54944 .36634 L p
1 g
F P
s
P
p
.002 w
.54944 .36634 m .54054 .36323 L .52831 .38754 L p
1 g
F P
s
P
p
.002 w
.47631 .48785 m .52125 .50416 L .52862 .47738 L p
1 g
F P
s
P
p
.002 w
.56923 .48026 m .52862 .47738 L .52125 .50416 L p
1 g
F P
s
P
p
.002 w
.52862 .47738 m .56923 .48026 L .56903 .4519 L p
1 g
F P
s
P
p
.002 w
.51314 .37686 m .50176 .36271 L .47664 .37644 L p
1 g
F P
s
P
p
.002 w
.50176 .36271 m .51314 .37686 L .5328 .35777 L p
1 g
F P
s
P
p
.002 w
.54054 .36323 m .5328 .35777 L .51314 .37686 L p
1 g
F P
s
P
p
.002 w
.54574 .39368 m .56366 .39462 L .55857 .36677 L p
1 g
F P
s
P
p
.002 w
.55857 .36677 m .54944 .36634 L .54574 .39368 L p
1 g
F P
s
P
p
.002 w
.43954 .36099 m .45212 .39147 L .47664 .37644 L p
1 g
F P
s
P
p
.002 w
.47664 .37644 m .4671 .35278 L .43954 .36099 L p
1 g
F P
s
P
p
.002 w
.4671 .35278 m .47664 .37644 L .50176 .36271 L p
1 g
F P
s
P
p
.002 w
.41323 .37099 m .42867 .40751 L .45212 .39147 L p
1 g
F P
s
P
p
.002 w
.45212 .39147 m .43954 .36099 L .41323 .37099 L p
1 g
F P
s
P
p
.002 w
.42024 .48119 m .46372 .5114 L .47631 .48785 L p
1 g
F P
s
P
p
.002 w
.47631 .48785 m .43693 .46041 L .42024 .48119 L p
1 g
F P
s
P
p
.002 w
.52125 .50416 m .47631 .48785 L .46372 .5114 L p
1 g
F P
s
P
p
.002 w
.59149 .41694 m .56716 .42317 L .56903 .4519 L p
1 g
F P
s
P
p
.002 w
.56716 .42317 m .59149 .41694 L .58022 .39021 L p
1 g
F P
s
P
p
.002 w
.58022 .39021 m .56366 .39462 L .56716 .42317 L p
1 g
F P
s
P
p
.002 w
.50176 .36271 m .49538 .3465 L .4671 .35278 L p
1 g
F P
s
P
p
.002 w
.49538 .3465 m .50176 .36271 L .52703 .35053 L p
1 g
F P
s
P
p
.002 w
.5328 .35777 m .52703 .35053 L .50176 .36271 L p
1 g
F P
s
P
p
.002 w
.38673 .44148 m .42024 .48119 L .43693 .46041 L p
1 g
F P
s
P
p
.002 w
.43693 .46041 m .40672 .42428 L .38673 .44148 L p
1 g
F P
s
P
p
.002 w
.60057 .44414 m .56903 .4519 L .56923 .48026 L p
1 g
F P
s
P
p
.002 w
.56903 .4519 m .60057 .44414 L .59149 .41694 L p
1 g
F P
s
P
p
.002 w
.56366 .39462 m .58022 .39021 L .56696 .36445 L p
1 g
F P
s
P
p
.002 w
.56696 .36445 m .55857 .36677 L .56366 .39462 L p
1 g
F P
s
P
p
.002 w
.38871 .38261 m .40672 .42428 L .42867 .40751 L p
1 g
F P
s
P
p
.002 w
.42867 .40751 m .41323 .37099 L .38871 .38261 L p
1 g
F P
s
P
p
.002 w
.46372 .5114 m .51326 .52951 L .52125 .50416 L p
1 g
F P
s
P
p
.002 w
.56771 .50773 m .52125 .50416 L .51326 .52951 L p
1 g
F P
s
P
p
.002 w
.52125 .50416 m .56771 .50773 L .56923 .48026 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .5328 .35777 L .54054 .36323 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .54054 .36323 L .54944 .36634 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .52703 .35053 L .5328 .35777 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .54944 .36634 L .55857 .36677 L closepath p
1 g
F P
s
P
p
.002 w
.46589 .32843 m .4671 .35278 L .49538 .3465 L p
1 g
F P
s
P
p
.002 w
.49538 .3465 m .49475 .32989 L .46589 .32843 L p
1 g
F P
s
P
p
.002 w
.49475 .32989 m .49538 .3465 L .52386 .34226 L p
1 g
F P
s
P
p
.002 w
.52703 .35053 m .52386 .34226 L .49538 .3465 L p
1 g
F P
s
P
p
.002 w
.43761 .32948 m .43954 .36099 L .4671 .35278 L p
1 g
F P
s
P
p
.002 w
.4671 .35278 m .46589 .32843 L .43761 .32948 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .52386 .34226 L .52703 .35053 L closepath p
1 g
F P
s
P
p
.002 w
.60726 .47128 m .56923 .48026 L .56771 .50773 L p
1 g
F P
s
P
p
.002 w
.56923 .48026 m .60726 .47128 L .60057 .44414 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .55857 .36677 L .56696 .36445 L closepath p
1 g
F P
s
P
p
.002 w
.40519 .50113 m .45178 .53342 L .46372 .5114 L p
1 g
F P
s
P
p
.002 w
.46372 .5114 m .42024 .48119 L .40519 .50113 L p
1 g
F P
s
P
p
.002 w
.51326 .52951 m .46372 .5114 L .45178 .53342 L p
1 g
F P
s
P
p
.002 w
.59367 .38082 m .58022 .39021 L .59149 .41694 L p
1 g
F P
s
P
p
.002 w
.58022 .39021 m .59367 .38082 L .57372 .35961 L p
1 g
F P
s
P
p
.002 w
.57372 .35961 m .56696 .36445 L .58022 .39021 L p
1 g
F P
s
P
p
.002 w
.52386 .34226 m .52363 .33383 L .49475 .32989 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .52363 .33383 L .52386 .34226 L closepath p
1 g
F P
s
P
p
.002 w
.4105 .33309 m .41323 .37099 L .43954 .36099 L p
1 g
F P
s
P
p
.002 w
.43954 .36099 m .43761 .32948 L .4105 .33309 L p
1 g
F P
s
P
p
.002 w
.61141 .4034 m .59149 .41694 L .60057 .44414 L p
1 g
F P
s
P
p
.002 w
.59149 .41694 m .61141 .4034 L .59367 .38082 L p
1 g
F P
s
P
p
.002 w
.36651 .39566 m .38673 .44148 L .40672 .42428 L p
1 g
F P
s
P
p
.002 w
.40672 .42428 m .38871 .38261 L .36651 .39566 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .56696 .36445 L .57372 .35961 L closepath p
1 g
F P
s
P
p
.002 w
.36914 .45878 m .40519 .50113 L .42024 .48119 L p
1 g
F P
s
P
p
.002 w
.42024 .48119 m .38673 .44148 L .36914 .45878 L p
1 g
F P
s
P
p
.002 w
.50003 .31465 m .49475 .32989 L .52363 .33383 L p
1 g
F P
s
P
p
.002 w
.52363 .33383 m .52641 .32615 L .50003 .31465 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .52641 .32615 L .52363 .33383 L closepath p
1 g
F P
s
P
p
.002 w
.45178 .53342 m .50476 .55293 L .51326 .52951 L p
1 g
F P
s
P
p
.002 w
.56449 .53374 m .51326 .52951 L .50476 .55293 L p
1 g
F P
s
P
p
.002 w
.51326 .52951 m .56449 .53374 L .56771 .50773 L p
1 g
F P
s
P
p
.002 w
.47336 .30591 m .46589 .32843 L .49475 .32989 L p
1 g
F P
s
P
p
.002 w
.49475 .32989 m .50003 .31465 L .47336 .30591 L p
1 g
F P
s
P
p
.002 w
.62658 .42691 m .60057 .44414 L .60726 .47128 L p
1 g
F P
s
P
p
.002 w
.60057 .44414 m .62658 .42691 L .61141 .4034 L p
1 g
F P
s
P
p
.002 w
.5781 .35274 m .57372 .35961 L .59367 .38082 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .57372 .35961 L .5781 .35274 L closepath p
1 g
F P
s
P
p
.002 w
.61136 .49783 m .56771 .50773 L .56449 .53374 L p
1 g
F P
s
P
p
.002 w
.56771 .50773 m .61136 .49783 L .60726 .47128 L p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .5781 .35274 L .5796 .34457 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .5796 .34457 L .57802 .33599 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .57802 .33599 L .5735 .32794 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .5735 .32794 L .56655 .32132 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .56655 .32132 L .55792 .31689 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .55792 .31689 L .54858 .31513 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .54858 .31513 L .53958 .31624 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .53958 .31624 L .53191 .32006 L closepath p
1 g
F P
s
P
p
.002 w
.55198 .34016 m .53191 .32006 L .52641 .32615 L closepath p
1 g
F P
s
P
p
.002 w
.38513 .33922 m .38871 .38261 L .41323 .37099 L p
1 g
F P
s
P
p
.002 w
.41323 .37099 m .4105 .33309 L .38513 .33922 L p
1 g
F P
s
P
p
.002 w
.60251 .36736 m .59367 .38082 L .61141 .4034 L p
1 g
F P
s
P
p
.002 w
.59367 .38082 m .60251 .36736 L .5781 .35274 L p
1 g
F P
s
P
p
.002 w
.44694 .30018 m .43761 .32948 L .46589 .32843 L p
1 g
F P
s
P
p
.002 w
.46589 .32843 m .47336 .30591 L .44694 .30018 L p
1 g
F P
s
P
p
.002 w
.51079 .30245 m .50003 .31465 L .52641 .32615 L p
1 g
F P
s
P
p
.002 w
.52641 .32615 m .53191 .32006 L .51079 .30245 L p
1 g
F P
s
P
p
.002 w
.5796 .34457 m .5781 .35274 L .60251 .36736 L p
1 g
F P
s
P
p
.002 w
.39215 .5198 m .44074 .55342 L .45178 .53342 L p
1 g
F P
s
P
p
.002 w
.45178 .53342 m .40519 .50113 L .39215 .5198 L p
1 g
F P
s
P
p
.002 w
.50476 .55293 m .45178 .53342 L .44074 .55342 L p
1 g
F P
s
P
p
.002 w
.34717 .40991 m .36914 .45878 L .38673 .44148 L p
1 g
F P
s
P
p
.002 w
.38673 .44148 m .36651 .39566 L .34717 .40991 L p
1 g
F P
s
P
p
.002 w
.62467 .38376 m .61141 .4034 L .62658 .42691 L p
1 g
F P
s
P
p
.002 w
.61141 .4034 m .62467 .38376 L .60251 .36736 L p
1 g
F P
s
P
p
.002 w
.6388 .45089 m .60726 .47128 L .61136 .49783 L p
1 g
F P
s
P
p
.002 w
.60726 .47128 m .6388 .45089 L .62658 .42691 L p
1 g
F P
s
P
p
.002 w
.52594 .29471 m .51079 .30245 L .53191 .32006 L p
1 g
F P
s
P
p
.002 w
.53191 .32006 m .53958 .31624 L .52594 .29471 L p
1 g
F P
s
P
p
.002 w
.489 .28775 m .47336 .30591 L .50003 .31465 L p
1 g
F P
s
P
p
.002 w
.50003 .31465 m .51079 .30245 L .489 .28775 L p
1 g
F P
s
P
p
.002 w
.60251 .36736 m .60566 .35121 L .5796 .34457 L p
1 g
F P
s
P
p
.002 w
.57802 .33599 m .5796 .34457 L .60566 .35121 L p
1 g
F P
s
P
p
.002 w
.35441 .47582 m .39215 .5198 L .40519 .50113 L p
1 g
F P
s
P
p
.002 w
.40519 .50113 m .36914 .45878 L .35441 .47582 L p
1 g
F P
s
P
p
.002 w
.42133 .29765 m .4105 .33309 L .43761 .32948 L p
1 g
F P
s
P
p
.002 w
.43761 .32948 m .44694 .30018 L .42133 .29765 L p
1 g
F P
s
P
p
.002 w
.60566 .35121 m .60251 .36736 L .62467 .38376 L p
1 g
F P
s
P
p
.002 w
.54387 .2924 m .52594 .29471 L .53958 .31624 L p
1 g
F P
s
P
p
.002 w
.53958 .31624 m .54858 .31513 L .54387 .2924 L p
1 g
F P
s
P
p
.002 w
.36211 .34785 m .36651 .39566 L .38871 .38261 L p
1 g
F P
s
P
p
.002 w
.38871 .38261 m .38513 .33922 L .36211 .34785 L p
1 g
F P
s
P
p
.002 w
.50476 .55293 m .55957 .55773 L .56449 .53374 L p
1 g
F P
s
P
p
.002 w
.61273 .52323 m .56449 .53374 L .55957 .55773 L p
1 g
F P
s
P
p
.002 w
.56449 .53374 m .61273 .52323 L .61136 .49783 L p
1 g
F P
s
P
p
.002 w
.44074 .55342 m .49593 .57386 L .50476 .55293 L p
1 g
F P
s
P
p
.002 w
.55957 .55773 m .50476 .55293 L .49593 .57386 L p
1 g
F P
s
P
p
.002 w
.60566 .35121 m .60266 .33411 L .57802 .33599 L p
1 g
F P
s
P
p
.002 w
.5735 .32794 m .57802 .33599 L .60266 .33411 L p
1 g
F P
s
P
p
.002 w
.56256 .29585 m .54387 .2924 L .54858 .31513 L p
1 g
F P
s
P
p
.002 w
.54858 .31513 m .55792 .31689 L .56256 .29585 L p
1 g
F P
s
P
p
.002 w
.60266 .33411 m .59374 .31799 L .5735 .32794 L p
1 g
F P
s
P
p
.002 w
.56655 .32132 m .5735 .32794 L .59374 .31799 L p
1 g
F P
s
P
p
.002 w
.64408 .40165 m .62658 .42691 L .6388 .45089 L p
1 g
F P
s
P
p
.002 w
.62658 .42691 m .64408 .40165 L .62467 .38376 L p
1 g
F P
s
P
p
.002 w
.46699 .27636 m .44694 .30018 L .47336 .30591 L p
1 g
F P
s
P
p
.002 w
.47336 .30591 m .489 .28775 L .46699 .27636 L p
1 g
F P
s
P
p
.002 w
.57985 .30472 m .56256 .29585 L .55792 .31689 L p
1 g
F P
s
P
p
.002 w
.55792 .31689 m .56655 .32132 L .57985 .30472 L p
1 g
F P
s
P
p
.002 w
.59374 .31799 m .57985 .30472 L .56655 .32132 L p
1 g
F P
s
P
p
.002 w
.5113 .27611 m .489 .28775 L .51079 .30245 L p
1 g
F P
s
P
p
.002 w
.51079 .30245 m .52594 .29471 L .5113 .27611 L p
1 g
F P
s
P
p
.002 w
.64775 .47486 m .61136 .49783 L .61273 .52323 L p
1 g
F P
s
P
p
.002 w
.61136 .49783 m .64775 .47486 L .6388 .45089 L p
1 g
F P
s
P
p
.002 w
.62467 .38376 m .62959 .35999 L .60566 .35121 L p
1 g
F P
s
P
p
.002 w
.60266 .33411 m .60566 .35121 L .62959 .35999 L p
1 g
F P
s
P
p
.002 w
.39711 .29848 m .38513 .33922 L .4105 .33309 L p
1 g
F P
s
P
p
.002 w
.4105 .33309 m .42133 .29765 L .39711 .29848 L p
1 g
F P
s
P
p
.002 w
.62959 .35999 m .62467 .38376 L .64408 .40165 L p
1 g
F P
s
P
p
.002 w
.33123 .4251 m .35441 .47582 L .36914 .45878 L p
1 g
F P
s
P
p
.002 w
.36914 .45878 m .34717 .40991 L .33123 .4251 L p
1 g
F P
s
P
p
.002 w
.38146 .53677 m .43088 .57089 L .44074 .55342 L p
1 g
F P
s
P
p
.002 w
.44074 .55342 m .39215 .5198 L .38146 .53677 L p
1 g
F P
s
P
p
.002 w
.49593 .57386 m .44074 .55342 L .43088 .57089 L p
1 g
F P
s
P
p
.002 w
.34204 .35886 m .34717 .40991 L .36651 .39566 L p
1 g
F P
s
P
p
.002 w
.36651 .39566 m .36211 .34785 L .34204 .35886 L p
1 g
F P
s
P
p
.002 w
.53789 .27252 m .5113 .27611 L .52594 .29471 L p
1 g
F P
s
P
p
.002 w
.52594 .29471 m .54387 .2924 L .53789 .27252 L p
1 g
F P
s
P
p
.002 w
.34298 .49223 m .38146 .53677 L .39215 .5198 L p
1 g
F P
s
P
p
.002 w
.39215 .5198 m .35441 .47582 L .34298 .49223 L p
1 g
F P
s
P
p
.002 w
.66024 .42068 m .6388 .45089 L .64775 .47486 L p
1 g
F P
s
P
p
.002 w
.6388 .45089 m .66024 .42068 L .64408 .40165 L p
1 g
F P
s
P
p
.002 w
.49593 .57386 m .553 .57913 L .55957 .55773 L p
1 g
F P
s
P
p
.002 w
.61124 .54689 m .55957 .55773 L .553 .57913 L p
1 g
F P
s
P
p
.002 w
.55957 .55773 m .61124 .54689 L .61273 .52323 L p
1 g
F P
s
P
p
.002 w
.44525 .26866 m .42133 .29765 L .44694 .30018 L p
1 g
F P
s
P
p
.002 w
.44694 .30018 m .46699 .27636 L .44525 .26866 L p
1 g
F P
s
P
p
.002 w
.62959 .35999 m .62535 .33465 L .60266 .33411 L p
1 g
F P
s
P
p
.002 w
.59374 .31799 m .60266 .33411 L .62535 .33465 L p
1 g
F P
s
P
p
.002 w
.49594 .26096 m .46699 .27636 L .489 .28775 L p
1 g
F P
s
P
p
.002 w
.489 .28775 m .5113 .27611 L .49594 .26096 L p
1 g
F P
s
P
p
.002 w
.43088 .57089 m .48693 .59176 L .49593 .57386 L p
1 g
F P
s
P
p
.002 w
.553 .57913 m .49593 .57386 L .48693 .59176 L p
1 g
F P
s
P
p
.002 w
.56574 .27759 m .53789 .27252 L .54387 .2924 L p
1 g
F P
s
P
p
.002 w
.54387 .2924 m .56256 .29585 L .56574 .27759 L p
1 g
F P
s
P
p
.002 w
.6531 .49828 m .61273 .52323 L .61124 .54689 L p
1 g
F P
s
P
p
.002 w
.61273 .52323 m .6531 .49828 L .64775 .47486 L p
1 g
F P
s
P
p
.002 w
.62535 .33465 m .6122 .31063 L .59374 .31799 L p
1 g
F P
s
P
p
.002 w
.57985 .30472 m .59374 .31799 L .6122 .31063 L p
1 g
F P
s
P
p
.002 w
.3749 .30281 m .36211 .34785 L .38513 .33922 L p
1 g
F P
s
P
p
.002 w
.38513 .33922 m .39711 .29848 L .3749 .30281 L p
1 g
F P
s
P
p
.002 w
.65079 .37081 m .64408 .40165 L .66024 .42068 L p
1 g
F P
s
P
p
.002 w
.64408 .40165 m .65079 .37081 L .62959 .35999 L p
1 g
F P
s
P
p
.002 w
.62535 .33465 m .62959 .35999 L .65079 .37081 L p
1 g
F P
s
P
p
.002 w
.59153 .29081 m .56574 .27759 L .56256 .29585 L p
1 g
F P
s
P
p
.002 w
.56256 .29585 m .57985 .30472 L .59153 .29081 L p
1 g
F P
s
P
p
.002 w
.6122 .31063 m .59153 .29081 L .57985 .30472 L p
1 g
F P
s
P
p
.002 w
.31922 .44093 m .34298 .49223 L .35441 .47582 L p
1 g
F P
s
P
p
.002 w
.35441 .47582 m .33123 .4251 L .31922 .44093 L p
1 g
F P
s
P
p
.002 w
.32553 .3721 m .33123 .4251 L .34717 .40991 L p
1 g
F P
s
P
p
.002 w
.34717 .40991 m .34204 .35886 L .32553 .3721 L p
1 g
F P
s
P
p
.002 w
.67267 .44048 m .64775 .47486 L .6531 .49828 L p
1 g
F P
s
P
p
.002 w
.64775 .47486 m .67267 .44048 L .66024 .42068 L p
1 g
F P
s
P
p
.002 w
.42427 .26499 m .39711 .29848 L .42133 .29765 L p
1 g
F P
s
P
p
.002 w
.42133 .29765 m .44525 .26866 L .42427 .26499 L p
1 g
F P
s
P
p
.002 w
.53072 .2561 m .49594 .26096 L .5113 .27611 L p
1 g
F P
s
P
p
.002 w
.5113 .27611 m .53789 .27252 L .53072 .2561 L p
1 g
F P
s
P
p
.002 w
.37348 .55156 m .42246 .58533 L .43088 .57089 L p
1 g
F P
s
P
p
.002 w
.43088 .57089 m .38146 .53677 L .37348 .55156 L p
1 g
F P
s
P
p
.002 w
.48693 .59176 m .43088 .57089 L .42246 .58533 L p
1 g
F P
s
P
p
.002 w
.48018 .24977 m .44525 .26866 L .46699 .27636 L p
1 g
F P
s
P
p
.002 w
.46699 .27636 m .49594 .26096 L .48018 .24977 L p
1 g
F P
s
P
p
.002 w
.48693 .59176 m .54483 .59735 L .553 .57913 L p
1 g
F P
s
P
p
.002 w
.60682 .56821 m .553 .57913 L .54483 .59735 L p
1 g
F P
s
P
p
.002 w
.553 .57913 m .60682 .56821 L .61124 .54689 L p
1 g
F P
s
P
p
.002 w
.65079 .37081 m .64548 .33769 L .62535 .33465 L p
1 g
F P
s
P
p
.002 w
.6122 .31063 m .62535 .33465 L .64548 .33769 L p
1 g
F P
s
P
p
.002 w
.33529 .50759 m .37348 .55156 L .38146 .53677 L p
1 g
F P
s
P
p
.002 w
.38146 .53677 m .34298 .49223 L .33529 .50759 L p
1 g
F P
s
P
p
.002 w
.66868 .3835 m .66024 .42068 L .67267 .44048 L p
1 g
F P
s
P
p
.002 w
.66024 .42068 m .66868 .3835 L .65079 .37081 L p
1 g
F P
s
P
p
.002 w
.35533 .31066 m .34204 .35886 L .36211 .34785 L p
1 g
F P
s
P
p
.002 w
.36211 .34785 m .3749 .30281 L .35533 .31066 L p
1 g
F P
s
P
p
.002 w
.6546 .5206 m .61124 .54689 L .60682 .56821 L p
1 g
F P
s
P
p
.002 w
.61124 .54689 m .6546 .5206 L .6531 .49828 L p
1 g
F P
s
P
p
.002 w
.42246 .58533 m .47795 .60608 L .48693 .59176 L p
1 g
F P
s
P
p
.002 w
.54483 .59735 m .48693 .59176 L .47795 .60608 L p
1 g
F P
s
P
p
.002 w
.64548 .33769 m .65079 .37081 L .66868 .3835 L p
1 g
F P
s
P
p
.002 w
.5673 .26267 m .53072 .2561 L .53789 .27252 L p
1 g
F P
s
P
p
.002 w
.53789 .27252 m .56574 .27759 L .5673 .26267 L p
1 g
F P
s
P
p
.002 w
.64548 .33769 m .62837 .30615 L .6122 .31063 L p
1 g
F P
s
P
p
.002 w
.59153 .29081 m .6122 .31063 L .62837 .30615 L p
1 g
F P
s
P
p
.002 w
.60124 .28006 m .5673 .26267 L .56574 .27759 L p
1 g
F P
s
P
p
.002 w
.56574 .27759 m .59153 .29081 L .60124 .28006 L p
1 g
F P
s
P
p
.002 w
.62837 .30615 m .60124 .28006 L .59153 .29081 L p
1 g
F P
s
P
p
.002 w
.40462 .26563 m .3749 .30281 L .39711 .29848 L p
1 g
F P
s
P
p
.002 w
.39711 .29848 m .42427 .26499 L .40462 .26563 L p
1 g
F P
s
P
p
.002 w
.68092 .46062 m .6531 .49828 L .6546 .5206 L p
1 g
F P
s
P
p
.002 w
.6531 .49828 m .68092 .46062 L .67267 .44048 L p
1 g
F P
s
P
p
.002 w
.31162 .45704 m .33529 .50759 L .34298 .49223 L p
1 g
F P
s
P
p
.002 w
.34298 .49223 m .31922 .44093 L .31162 .45704 L p
1 g
F P
s
P
p
.002 w
.31314 .38737 m .31922 .44093 L .33123 .4251 L p
1 g
F P
s
P
p
.002 w
.33123 .4251 m .32553 .3721 L .31314 .38737 L p
1 g
F P
s
P
p
.002 w
.52246 .2437 m .48018 .24977 L .49594 .26096 L p
1 g
F P
s
P
p
.002 w
.49594 .26096 m .53072 .2561 L .52246 .2437 L p
1 g
F P
s
P
p
.002 w
.46437 .24303 m .42427 .26499 L .44525 .26866 L p
1 g
F P
s
P
p
.002 w
.44525 .26866 m .48018 .24977 L .46437 .24303 L p
1 g
F P
s
P
p
.002 w
.66868 .3835 m .66247 .3433 L .64548 .33769 L p
1 g
F P
s
P
p
.002 w
.62837 .30615 m .64548 .33769 L .66247 .3433 L p
1 g
F P
s
P
p
.002 w
.47795 .60608 m .53519 .61179 L .54483 .59735 L p
1 g
F P
s
P
p
.002 w
.59942 .58659 m .54483 .59735 L .53519 .61179 L p
1 g
F P
s
P
p
.002 w
.54483 .59735 m .59942 .58659 L .60682 .56821 L p
1 g
F P
s
P
p
.002 w
.68268 .39784 m .67267 .44048 L .68092 .46062 L p
1 g
F P
s
P
p
.002 w
.67267 .44048 m .68268 .39784 L .66868 .3835 L p
1 g
F P
s
P
p
.002 w
.36856 .56371 m .41578 .59622 L .42246 .58533 L p
1 g
F P
s
P
p
.002 w
.42246 .58533 m .37348 .55156 L .36856 .56371 L p
1 g
F P
s
P
p
.002 w
.47795 .60608 m .42246 .58533 L .41578 .59622 L p
1 g
F P
s
P
p
.002 w
.339 .32204 m .32553 .3721 L .34204 .35886 L p
1 g
F P
s
P
p
.002 w
.34204 .35886 m .35533 .31066 L .339 .32204 L p
1 g
F P
s
P
p
.002 w
.65202 .54124 m .60682 .56821 L .59942 .58659 L p
1 g
F P
s
P
p
.002 w
.60682 .56821 m .65202 .54124 L .6546 .5206 L p
1 g
F P
s
P
p
.002 w
.33172 .52147 m .36856 .56371 L .37348 .55156 L p
1 g
F P
s
P
p
.002 w
.37348 .55156 m .33529 .50759 L .33172 .52147 L p
1 g
F P
s
P
p
.002 w
.66247 .3433 m .66868 .3835 L .68268 .39784 L p
1 g
F P
s
P
p
.002 w
.41578 .59622 m .46921 .61627 L .47795 .60608 L p
1 g
F P
s
P
p
.002 w
.53519 .61179 m .47795 .60608 L .46921 .61627 L p
1 g
F P
s
P
p
.002 w
.56713 .25165 m .52246 .2437 L .53072 .2561 L p
1 g
F P
s
P
p
.002 w
.53072 .2561 m .5673 .26267 L .56713 .25165 L p
1 g
F P
s
P
p
.002 w
.66247 .3433 m .64174 .30482 L .62837 .30615 L p
1 g
F P
s
P
p
.002 w
.60124 .28006 m .62837 .30615 L .64174 .30482 L p
1 g
F P
s
P
p
.002 w
.38688 .27079 m .35533 .31066 L .3749 .30281 L p
1 g
F P
s
P
p
.002 w
.3749 .30281 m .40462 .26563 L .38688 .27079 L p
1 g
F P
s
P
p
.002 w
.68457 .4806 m .6546 .5206 L .65202 .54124 L p
1 g
F P
s
P
p
.002 w
.6546 .5206 m .68457 .4806 L .68092 .46062 L p
1 g
F P
s
P
p
.002 w
.60864 .2729 m .56713 .25165 L .5673 .26267 L p
1 g
F P
s
P
p
.002 w
.5673 .26267 m .60124 .28006 L .60864 .2729 L p
1 g
F P
s
P
p
.002 w
.30544 .40436 m .31162 .45704 L .31922 .44093 L p
1 g
F P
s
P
p
.002 w
.31922 .44093 m .31314 .38737 L .30544 .40436 L p
1 g
F P
s
P
p
.002 w
.64174 .30482 m .60864 .2729 L .60124 .28006 L p
1 g
F P
s
P
p
.002 w
.51325 .23589 m .46437 .24303 L .48018 .24977 L p
1 g
F P
s
P
p
.002 w
.48018 .24977 m .52246 .2437 L .51325 .23589 L p
1 g
F P
s
P
p
.002 w
.30888 .47304 m .33172 .52147 L .33529 .50759 L p
1 g
F P
s
P
p
.002 w
.33529 .50759 m .31162 .45704 L .30888 .47304 L p
1 g
F P
s
P
p
.002 w
.44894 .24116 m .40462 .26563 L .42427 .26499 L p
1 g
F P
s
P
p
.002 w
.42427 .26499 m .46437 .24303 L .44894 .24116 L p
1 g
F P
s
P
p
.002 w
.69224 .41358 m .68092 .46062 L .68457 .4806 L p
1 g
F P
s
P
p
.002 w
.68092 .46062 m .69224 .41358 L .68268 .39784 L p
1 g
F P
s
P
p
.002 w
.32655 .3368 m .31314 .38737 L .32553 .3721 L p
1 g
F P
s
P
p
.002 w
.32553 .3721 m .339 .32204 L .32655 .3368 L p
1 g
F P
s
P
p
.002 w
.68268 .39784 m .67572 .35147 L .66247 .3433 L p
1 g
F P
s
P
p
.002 w
.64174 .30482 m .66247 .3433 L .67572 .35147 L p
1 g
F P
s
P
p
.002 w
.46921 .61627 m .52424 .6219 L .53519 .61179 L p
1 g
F P
s
P
p
.002 w
.58907 .60141 m .53519 .61179 L .52424 .6219 L p
1 g
F P
s
P
p
.002 w
.53519 .61179 m .58907 .60141 L .59942 .58659 L p
1 g
F P
s
P
p
.002 w
.64523 .55958 m .59942 .58659 L .58907 .60141 L p
1 g
F P
s
P
p
.002 w
.59942 .58659 m .64523 .55958 L .65202 .54124 L p
1 g
F P
s
P
p
.002 w
.67572 .35147 m .68268 .39784 L .69224 .41358 L p
1 g
F P
s
P
p
.002 w
.36701 .57275 m .4111 .60308 L .41578 .59622 L p
1 g
F P
s
P
p
.002 w
.41578 .59622 m .36856 .56371 L .36701 .57275 L p
1 g
F P
s
P
p
.002 w
.46921 .61627 m .41578 .59622 L .4111 .60308 L p
1 g
F P
s
P
p
.002 w
.33262 .53342 m .36701 .57275 L .36856 .56371 L p
1 g
F P
s
P
p
.002 w
.36856 .56371 m .33172 .52147 L .33262 .53342 L p
1 g
F P
s
P
p
.002 w
.37162 .28058 m .339 .32204 L .35533 .31066 L p
1 g
F P
s
P
p
.002 w
.35533 .31066 m .38688 .27079 L .37162 .28058 L p
1 g
F P
s
P
p
.002 w
.68332 .49992 m .65202 .54124 L .64523 .55958 L p
1 g
F P
s
P
p
.002 w
.65202 .54124 m .68332 .49992 L .68457 .4806 L p
1 g
F P
s
P
p
.002 w
.56511 .24507 m .51325 .23589 L .52246 .2437 L p
1 g
F P
s
P
p
.002 w
.52246 .2437 m .56713 .25165 L .56511 .24507 L p
1 g
F P
s
P
p
.002 w
.4111 .60308 m .46095 .62183 L .46921 .61627 L p
1 g
F P
s
P
p
.002 w
.52424 .6219 m .46921 .61627 L .46095 .62183 L p
1 g
F P
s
P
p
.002 w
.67572 .35147 m .6518 .30687 L .64174 .30482 L p
1 g
F P
s
P
p
.002 w
.60864 .2729 m .64174 .30482 L .6518 .30687 L p
1 g
F P
s
P
p
.002 w
.30287 .4227 m .30888 .47304 L .31162 .45704 L p
1 g
F P
s
P
p
.002 w
.31162 .45704 m .30544 .40436 L .30287 .4227 L p
1 g
F P
s
P
p
.002 w
.43433 .24449 m .38688 .27079 L .40462 .26563 L p
1 g
F P
s
P
p
.002 w
.40462 .26563 m .44894 .24116 L .43433 .24449 L p
1 g
F P
s
P
p
.002 w
.50329 .23315 m .44894 .24116 L .46437 .24303 L p
1 g
F P
s
P
p
.002 w
.46437 .24303 m .51325 .23589 L .50329 .23315 L p
1 g
F P
s
P
p
.002 w
.61336 .26977 m .56511 .24507 L .56713 .25165 L p
1 g
F P
s
P
p
.002 w
.56713 .25165 m .60864 .2729 L .61336 .26977 L p
1 g
F P
s
P
p
.002 w
.69687 .43036 m .68457 .4806 L .68332 .49992 L p
1 g
F P
s
P
p
.002 w
.68457 .4806 m .69687 .43036 L .69224 .41358 L p
1 g
F P
s
P
p
.002 w
.31135 .48847 m .33262 .53342 L .33172 .52147 L p
1 g
F P
s
P
p
.002 w
.33172 .52147 m .30888 .47304 L .31135 .48847 L p
1 g
F P
s
P
p
.002 w
.6518 .30687 m .61336 .26977 L .60864 .2729 L p
1 g
F P
s
P
p
.002 w
.31851 .35473 m .30544 .40436 L .31314 .38737 L p
1 g
F P
s
P
p
.002 w
.31314 .38737 m .32655 .3368 L .31851 .35473 L p
1 g
F P
s
P
p
.002 w
.69224 .41358 m .68465 .36213 L .67572 .35147 L p
1 g
F P
s
P
p
.002 w
.6518 .30687 m .67572 .35147 L .68465 .36213 L p
1 g
F P
s
P
p
.002 w
.52424 .6219 m .57589 .61209 L .58907 .60141 L p
1 g
F P
s
P
p
.002 w
.63419 .57502 m .58907 .60141 L .57589 .61209 L p
1 g
F P
s
P
p
.002 w
.58907 .60141 m .63419 .57502 L .64523 .55958 L p
1 g
F P
s
P
p
.002 w
.46095 .62183 m .51218 .62714 L .52424 .6219 L p
1 g
F P
s
P
p
.002 w
.57589 .61209 m .52424 .6219 L .51218 .62714 L p
1 g
F P
s
P
p
.002 w
.68465 .36213 m .69224 .41358 L .69687 .43036 L p
1 g
F P
s
P
p
.002 w
.36907 .57823 m .40867 .60547 L .4111 .60308 L p
1 g
F P
s
P
p
.002 w
.4111 .60308 m .36701 .57275 L .36907 .57823 L p
1 g
F P
s
P
p
.002 w
.46095 .62183 m .4111 .60308 L .40867 .60547 L p
1 g
F P
s
P
p
.002 w
.35944 .29497 m .32655 .3368 L .339 .32204 L p
1 g
F P
s
P
p
.002 w
.339 .32204 m .37162 .28058 L .35944 .29497 L p
1 g
F P
s
P
p
.002 w
.67691 .518 m .64523 .55958 L .63419 .57502 L p
1 g
F P
s
P
p
.002 w
.64523 .55958 m .67691 .518 L .68332 .49992 L p
1 g
F P
s
P
p
.002 w
.33824 .543 m .36907 .57823 L .36701 .57275 L p
1 g
F P
s
P
p
.002 w
.36701 .57275 m .33262 .53342 L .33824 .543 L p
1 g
F P
s
P
p
.002 w
.56117 .24339 m .50329 .23315 L .51325 .23589 L p
1 g
F P
s
P
p
.002 w
.51325 .23589 m .56511 .24507 L .56117 .24339 L p
1 g
F P
s
P
p
.002 w
.40867 .60547 m .45341 .6223 L .46095 .62183 L p
1 g
F P
s
P
p
.002 w
.51218 .62714 m .46095 .62183 L .45341 .6223 L p
1 g
F P
s
P
p
.002 w
.421 .25324 m .37162 .28058 L .38688 .27079 L p
1 g
F P
s
P
p
.002 w
.38688 .27079 m .43433 .24449 L .421 .25324 L p
1 g
F P
s
P
p
.002 w
.68465 .36213 m .65805 .31245 L .6518 .30687 L p
1 g
F P
s
P
p
.002 w
.61336 .26977 m .6518 .30687 L .65805 .31245 L p
1 g
F P
s
P
p
.002 w
.30581 .44193 m .31135 .48847 L .30888 .47304 L p
1 g
F P
s
P
p
.002 w
.30888 .47304 m .30287 .4227 L .30581 .44193 L p
1 g
F P
s
P
p
.002 w
.68332 .49992 m .69616 .44778 L .69687 .43036 L p
1 g
F P
s
P
p
.002 w
.69616 .44778 m .68332 .49992 L .67691 .518 L p
1 g
F P
s
P
p
.002 w
.49281 .23589 m .43433 .24449 L .44894 .24116 L p
1 g
F P
s
P
p
.002 w
.44894 .24116 m .50329 .23315 L .49281 .23589 L p
1 g
F P
s
P
p
.002 w
.31537 .37545 m .30287 .4227 L .30544 .40436 L p
1 g
F P
s
P
p
.002 w
.30544 .40436 m .31851 .35473 L .31537 .37545 L p
1 g
F P
s
P
p
.002 w
.31926 .50286 m .33824 .543 L .33262 .53342 L p
1 g
F P
s
P
p
.002 w
.33262 .53342 m .31135 .48847 L .31926 .50286 L p
1 g
F P
s
P
p
.002 w
.65805 .31245 m .61512 .271 L .61336 .26977 L p
1 g
F P
s
P
p
.002 w
.61512 .271 m .56117 .24339 L .56511 .24507 L p
1 g
F P
s
P
p
.002 w
.56511 .24507 m .61336 .26977 L .61512 .271 L p
1 g
F P
s
P
p
.002 w
.51218 .62714 m .56009 .61809 L .57589 .61209 L p
1 g
F P
s
P
p
.002 w
.57589 .61209 m .61898 .58695 L .63419 .57502 L p
1 g
F P
s
P
p
.002 w
.61898 .58695 m .57589 .61209 L .56009 .61809 L p
1 g
F P
s
P
p
.002 w
.69687 .43036 m .68877 .37515 L .68465 .36213 L p
1 g
F P
s
P
p
.002 w
.68877 .37515 m .69687 .43036 L .69616 .44778 L p
1 g
F P
s
P
p
.002 w
.65805 .31245 m .68465 .36213 L .68877 .37515 L p
1 g
F P
s
P
p
.002 w
.45341 .6223 m .49928 .62707 L .51218 .62714 L p
1 g
F P
s
P
p
.004 w
.48603 .72748 m
.49077 .62668 L
s
P
p
.004 w
.49077 .62668 m
.49079 .62619 L
s
P
p
.002 w
.56009 .61809 m .51218 .62714 L .49928 .62707 L p
1 g
F P
s
P
p
.004 w
.49084 .62526 m
.5 .43051 L
s
P
p
.002 w
.35086 .31379 m .31851 .35473 L .32655 .3368 L p
1 g
F P
s
P
p
.002 w
.32655 .3368 m .35944 .29497 L .35086 .31379 L p
1 g
F P
s
P
p
.002 w
.63419 .57502 m .66527 .53425 L .67691 .518 L p
1 g
F P
s
P
p
.002 w
.66527 .53425 m .63419 .57502 L .61898 .58695 L p
1 g
F P
s
P
p
.002 w
.37494 .57976 m .40872 .603 L .40867 .60547 L p
1 g
F P
s
P
p
.002 w
.40867 .60547 m .36907 .57823 L .37494 .57976 L p
1 g
F P
s
P
p
.002 w
.45341 .6223 m .40867 .60547 L .40872 .603 L p
1 g
F P
s
P
p
.002 w
.34872 .54976 m .37494 .57976 L .36907 .57823 L p
1 g
F P
s
P
p
.002 w
.36907 .57823 m .33824 .543 L .34872 .54976 L p
1 g
F P
s
P
p
.002 w
.55531 .24699 m .49281 .23589 L .50329 .23315 L p
1 g
F P
s
P
p
.002 w
.50329 .23315 m .56117 .24339 L .55531 .24699 L p
1 g
F P
s
P
p
.002 w
.40945 .26746 m .35944 .29497 L .37162 .28058 L p
1 g
F P
s
P
p
.002 w
.37162 .28058 m .421 .25324 L .40945 .26746 L p
1 g
F P
s
P
p
.002 w
.40872 .603 m .44688 .61735 L .45341 .6223 L p
1 g
F P
s
P
p
.002 w
.49928 .62707 m .45341 .6223 L .44688 .61735 L p
1 g
F P
s
P
p
.002 w
.68983 .46536 m .67691 .518 L .66527 .53425 L p
1 g
F P
s
P
p
.002 w
.67691 .518 m .68983 .46536 L .69616 .44778 L p
1 g
F P
s
P
p
.002 w
.31445 .46151 m .31926 .50286 L .31135 .48847 L p
1 g
F P
s
P
p
.002 w
.31135 .48847 m .30581 .44193 L .31445 .46151 L p
1 g
F P
s
P
p
.002 w
.31749 .39847 m .30581 .44193 L .30287 .4227 L p
1 g
F P
s
P
p
.002 w
.30287 .4227 m .31537 .37545 L .31749 .39847 L p
1 g
F P
s
P
p
.002 w
.68877 .37515 m .66008 .32163 L .65805 .31245 L p
1 g
F P
s
P
p
.002 w
.61512 .271 m .65805 .31245 L .66008 .32163 L p
1 g
F P
s
P
p
.002 w
.48211 .24438 m .421 .25324 L .43433 .24449 L p
1 g
F P
s
P
p
.002 w
.43433 .24449 m .49281 .23589 L .48211 .24438 L p
1 g
F P
s
P
p
.002 w
.3327 .51571 m .34872 .54976 L .33824 .543 L p
1 g
F P
s
P
p
.002 w
.33824 .543 m .31926 .50286 L .3327 .51571 L p
1 g
F P
s
P
p
.002 w
.49928 .62707 m .54197 .61897 L .56009 .61809 L p
1 g
F P
s
P
p
.002 w
.59983 .59483 m .56009 .61809 L .54197 .61897 L p
1 g
F P
s
P
p
.002 w
.56009 .61809 m .59983 .59483 L .61898 .58695 L p
1 g
F P
s
P
p
.002 w
.68766 .39027 m .69616 .44778 L .68983 .46536 L p
1 g
F P
s
P
p
.002 w
.69616 .44778 m .68766 .39027 L .68877 .37515 L p
1 g
F P
s
P
p
.002 w
.61365 .27686 m .55531 .24699 L .56117 .24339 L p
1 g
F P
s
P
p
.002 w
.56117 .24339 m .61512 .271 L .61365 .27686 L p
1 g
F P
s
P
p
.002 w
.66008 .32163 m .68877 .37515 L .68766 .39027 L p
1 g
F P
s
P
p
.002 w
.66008 .32163 m .61365 .27686 L .61512 .271 L p
1 g
F P
s
P
p
.002 w
.34635 .33666 m .31537 .37545 L .31851 .35473 L p
1 g
F P
s
P
p
.002 w
.31851 .35473 m .35086 .31379 L .34635 .33666 L p
1 g
F P
s
P
p
.002 w
.44688 .61735 m .48587 .62137 L .49928 .62707 L p
1 g
F P
s
P
p
.002 w
.54197 .61897 m .49928 .62707 L .48587 .62137 L p
1 g
F P
s
P
p
.002 w
.64847 .54808 m .61898 .58695 L .59983 .59483 L p
1 g
F P
s
P
p
.002 w
.61898 .58695 m .64847 .54808 L .66527 .53425 L p
1 g
F P
s
P
p
.002 w
.40014 .287 m .35086 .31379 L .35944 .29497 L p
1 g
F P
s
P
p
.002 w
.35944 .29497 m .40945 .26746 L .40014 .287 L p
1 g
F P
s
P
p
.002 w
.38469 .57704 m .41141 .59544 L .40872 .603 L p
1 g
F P
s
P
p
.002 w
.40872 .603 m .37494 .57976 L .38469 .57704 L p
1 g
F P
s
P
p
.002 w
.44688 .61735 m .40872 .603 L .41141 .59544 L p
1 g
F P
s
P
p
.002 w
.67776 .48256 m .66527 .53425 L .64847 .54808 L p
1 g
F P
s
P
p
.002 w
.66527 .53425 m .67776 .48256 L .68983 .46536 L p
1 g
F P
s
P
p
.002 w
.54758 .25611 m .48211 .24438 L .49281 .23589 L p
1 g
F P
s
P
p
.002 w
.49281 .23589 m .55531 .24699 L .54758 .25611 L p
1 g
F P
s
P
p
.002 w
.36402 .55332 m .38469 .57704 L .37494 .57976 L p
1 g
F P
s
P
p
.002 w
.37494 .57976 m .34872 .54976 L .36402 .55332 L p
1 g
F P
s
P
p
.002 w
.32882 .48084 m .3327 .51571 L .31926 .50286 L p
1 g
F P
s
P
p
.002 w
.31926 .50286 m .31445 .46151 L .32882 .48084 L p
1 g
F P
s
P
p
.002 w
.32504 .42315 m .31445 .46151 L .30581 .44193 L p
1 g
F P
s
P
p
.002 w
.30581 .44193 m .31749 .39847 L .32504 .42315 L p
1 g
F P
s
P
p
.002 w
.41141 .59544 m .4416 .60677 L .44688 .61735 L p
1 g
F P
s
P
p
.002 w
.48587 .62137 m .44688 .61735 L .4416 .60677 L p
1 g
F P
s
P
p
.002 w
.4715 .25869 m .40945 .26746 L .421 .25324 L p
1 g
F P
s
P
p
.002 w
.421 .25324 m .48211 .24438 L .4715 .25869 L p
1 g
F P
s
P
p
.002 w
.68766 .39027 m .65754 .33436 L .66008 .32163 L p
1 g
F P
s
P
p
.002 w
.61365 .27686 m .66008 .32163 L .65754 .33436 L p
1 g
F P
s
P
p
.002 w
.48587 .62137 m .52197 .61441 L .54197 .61897 L p
1 g
F P
s
P
p
.002 w
.57713 .59821 m .54197 .61897 L .52197 .61441 L p
1 g
F P
s
P
p
.002 w
.54197 .61897 m .57713 .59821 L .59983 .59483 L p
1 g
F P
s
P
p
.002 w
.68103 .40716 m .68983 .46536 L .67776 .48256 L p
1 g
F P
s
P
p
.002 w
.68983 .46536 m .68103 .40716 L .68766 .39027 L p
1 g
F P
s
P
p
.002 w
.34626 .36302 m .31749 .39847 L .31537 .37545 L p
1 g
F P
s
P
p
.002 w
.31537 .37545 m .34635 .33666 L .34626 .36302 L p
1 g
F P
s
P
p
.002 w
.35154 .52651 m .36402 .55332 L .34872 .54976 L p
1 g
F P
s
P
p
.002 w
.34872 .54976 m .3327 .51571 L .35154 .52651 L p
1 g
F P
s
P
p
.002 w
.62677 .55892 m .59983 .59483 L .57713 .59821 L p
1 g
F P
s
P
p
.002 w
.59983 .59483 m .62677 .55892 L .64847 .54808 L p
1 g
F P
s
P
p
.002 w
.65754 .33436 m .68766 .39027 L .68103 .40716 L p
1 g
F P
s
P
p
.002 w
.6088 .28748 m .54758 .25611 L .55531 .24699 L p
1 g
F P
s
P
p
.002 w
.55531 .24699 m .61365 .27686 L .6088 .28748 L p
1 g
F P
s
P
p
.002 w
.4416 .60677 m .47235 .60987 L .48587 .62137 L p
1 g
F P
s
P
p
.002 w
.52197 .61441 m .48587 .62137 L .47235 .60987 L p
1 g
F P
s
P
p
.002 w
.65754 .33436 m .6088 .28748 L .61365 .27686 L p
1 g
F P
s
P
p
.002 w
.39352 .31147 m .34635 .33666 L .35086 .31379 L p
1 g
F P
s
P
p
.002 w
.35086 .31379 m .40014 .287 L .39352 .31147 L p
1 g
F P
s
P
p
.002 w
.66005 .49881 m .64847 .54808 L .62677 .55892 L p
1 g
F P
s
P
p
.002 w
.64847 .54808 m .66005 .49881 L .67776 .48256 L p
1 g
F P
s
P
p
.002 w
.33802 .44873 m .32882 .48084 L .31445 .46151 L p
1 g
F P
s
P
p
.002 w
.31445 .46151 m .32504 .42315 L .33802 .44873 L p
1 g
F P
s
P
p
.002 w
.34871 .49925 m .35154 .52651 L .3327 .51571 L p
1 g
F P
s
P
p
.002 w
.3327 .51571 m .32882 .48084 L .34871 .49925 L p
1 g
F P
s
P
p
.002 w
.39825 .56988 m .41683 .5827 L .41141 .59544 L p
1 g
F P
s
P
p
.002 w
.41141 .59544 m .38469 .57704 L .39825 .56988 L p
1 g
F P
s
P
p
.004 w
.3974 .60888 m
.40902 .58868 L
s
P
p
.002 w
.4416 .60677 m .41141 .59544 L .41683 .5827 L p
1 g
F P
s
P
p
.002 w
.53812 .2708 m .4715 .25869 L .48211 .24438 L p
1 g
F P
s
P
p
.002 w
.48211 .24438 m .54758 .25611 L .53812 .2708 L p
1 g
F P
s
P
p
.002 w
.46137 .27867 m .40014 .287 L .40945 .26746 L p
1 g
F P
s
P
p
.002 w
.40945 .26746 m .4715 .25869 L .46137 .27867 L p
1 g
F P
s
P
p
.002 w
.38394 .55338 m .39825 .56988 L .38469 .57704 L p
1 g
F P
s
P
p
.002 w
.38469 .57704 m .36402 .55332 L .38394 .55338 L p
1 g
F P
s
P
p
.002 w
.41683 .5827 m .43784 .59055 L .4416 .60677 L p
1 g
F P
s
P
p
.002 w
.47235 .60987 m .4416 .60677 L .43784 .59055 L p
1 g
F P
s
P
p
.002 w
.35079 .39211 m .32504 .42315 L .31749 .39847 L p
1 g
F P
s
P
p
.002 w
.31749 .39847 m .34626 .36302 L .35079 .39211 L p
1 g
F P
s
P
p
.002 w
.66879 .42535 m .67776 .48256 L .66005 .49881 L p
1 g
F P
s
P
p
.002 w
.67776 .48256 m .66879 .42535 L .68103 .40716 L p
1 g
F P
s
P
p
.002 w
.55144 .59676 m .52197 .61441 L .50064 .60428 L p
1 g
F P
s
P
p
.002 w
.47235 .60987 m .50064 .60428 L .52197 .61441 L p
1 g
F P
s
P
p
.002 w
.52197 .61441 m .55144 .59676 L .57713 .59821 L p
1 g
F P
s
P
p
.002 w
.60067 .56629 m .57713 .59821 L .55144 .59676 L p
1 g
F P
s
P
p
.002 w
.57713 .59821 m .60067 .56629 L .62677 .55892 L p
1 g
F P
s
P
p
.002 w
.68103 .40716 m .65023 .35045 L .65754 .33436 L p
1 g
F P
s
P
p
.002 w
.6088 .28748 m .65754 .33436 L .65023 .35045 L p
1 g
F P
s
P
p
.002 w
.37542 .53481 m .38394 .55338 L .36402 .55332 L p
1 g
F P
s
P
p
.002 w
.36402 .55332 m .35154 .52651 L .37542 .53481 L p
1 g
F P
s
P
p
.002 w
.65023 .35045 m .68103 .40716 L .66879 .42535 L p
1 g
F P
s
P
p
.002 w
.43784 .59055 m .45916 .59263 L .47235 .60987 L p
1 g
F P
s
P
p
.002 w
.50064 .60428 m .47235 .60987 L .45916 .59263 L p
1 g
F P
s
P
p
.002 w
.6005 .30279 m .53812 .2708 L .54758 .25611 L p
1 g
F P
s
P
p
.002 w
.54758 .25611 m .6088 .28748 L .6005 .30279 L p
1 g
F P
s
P
p
.002 w
.63702 .5135 m .62677 .55892 L .60067 .56629 L p
1 g
F P
s
P
p
.002 w
.62677 .55892 m .63702 .5135 L .66005 .49881 L p
1 g
F P
s
P
p
.002 w
.38994 .34024 m .34626 .36302 L .34635 .33666 L p
1 g
F P
s
P
p
.002 w
.34635 .33666 m .39352 .31147 L .38994 .34024 L p
1 g
F P
s
P
p
.002 w
.65023 .35045 m .6005 .30279 L .6088 .28748 L p
1 g
F P
s
P
p
.002 w
.35618 .47435 m .34871 .49925 L .32882 .48084 L p
1 g
F P
s
P
p
.002 w
.32882 .48084 m .33802 .44873 L .35618 .47435 L p
1 g
F P
s
P
p
.002 w
.37366 .51606 m .37542 .53481 L .35154 .52651 L p
1 g
F P
s
P
p
.002 w
.35154 .52651 m .34871 .49925 L .37366 .51606 L p
1 g
F P
s
P
p
.002 w
.35994 .42301 m .33802 .44873 L .32504 .42315 L p
1 g
F P
s
P
p
.002 w
.32504 .42315 m .35079 .39211 L .35994 .42301 L p
1 g
F P
s
P
p
.002 w
.45209 .30391 m .39352 .31147 L .40014 .287 L p
1 g
F P
s
P
p
.002 w
.40014 .287 m .46137 .27867 L .45209 .30391 L p
1 g
F P
s
P
p
.002 w
.52717 .29085 m .46137 .27867 L .4715 .25869 L p
1 g
F P
s
P
p
.002 w
.4715 .25869 m .53812 .2708 L .52717 .29085 L p
1 g
F P
s
P
p
.002 w
.50064 .60428 m .52351 .5903 L .55144 .59676 L p
1 g
F P
s
P
p
.002 w
.57088 .56977 m .55144 .59676 L .52351 .5903 L p
1 g
F P
s
P
p
.002 w
.55144 .59676 m .57088 .56977 L .60067 .56629 L p
1 g
F P
s
P
p
.002 w
.65108 .44429 m .66005 .49881 L .63702 .5135 L p
1 g
F P
s
P
p
.002 w
.66005 .49881 m .65108 .44429 L .66879 .42535 L p
1 g
F P
s
P
p
.002 w
.52351 .5903 m .50064 .60428 L .47864 .58863 L p
1 g
F P
s
P
p
.002 w
.45916 .59263 m .47864 .58863 L .50064 .60428 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.41538 .55826 m .42496 .56488 L .41683 .5827 L p
1 g
F P
s
P
p
.002 w
.41683 .5827 m .39825 .56988 L .41538 .55826 L p
1 g
F P
s
P
p
.002 w
.43784 .59055 m .41683 .5827 L .42496 .56488 L p
1 g
F P
s
P
p
.002 w
.40804 .54974 m .41538 .55826 L .39825 .56988 L p
1 g
F P
s
P
p
.002 w
.39825 .56988 m .38394 .55338 L .40804 .54974 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.42496 .56488 m .4358 .56892 L .43784 .59055 L p
1 g
F P
s
P
p
.002 w
.45916 .59263 m .43784 .59055 L .4358 .56892 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.66879 .42535 m .63814 .36953 L .65023 .35045 L p
1 g
F P
s
P
p
.002 w
.6005 .30279 m .65023 .35045 L .63814 .36953 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.60926 .52606 m .60067 .56629 L .57088 .56977 L p
1 g
F P
s
P
p
.002 w
.60067 .56629 m .60926 .52606 L .63702 .5135 L p
1 g
F P
s
P
p
.002 w
.40375 .54019 m .40804 .54974 L .38394 .55338 L p
1 g
F P
s
P
p
.002 w
.38394 .55338 m .37542 .53481 L .40375 .54019 L p
1 g
F P
s
P
p
.002 w
.63814 .36953 m .66879 .42535 L .65108 .44429 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.38964 .37243 m .35079 .39211 L .34626 .36302 L p
1 g
F P
s
P
p
.002 w
.34626 .36302 m .38994 .34024 L .38964 .37243 L p
1 g
F P
s
P
p
.002 w
.4358 .56892 m .44677 .56993 L .45916 .59263 L p
1 g
F P
s
P
p
.002 w
.47864 .58863 m .45916 .59263 L .44677 .56993 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.37902 .49911 m .37366 .51606 L .34871 .49925 L p
1 g
F P
s
P
p
.002 w
.34871 .49925 m .35618 .47435 L .37902 .49911 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.004 w
.45013 .5172 m
.5 .43051 L
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.58885 .32253 m .52717 .29085 L .53812 .2708 L p
1 g
F P
s
P
p
.002 w
.53812 .2708 m .6005 .30279 L .58885 .32253 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.37352 .45464 m .35618 .47435 L .33802 .44873 L p
1 g
F P
s
P
p
.002 w
.33802 .44873 m .35994 .42301 L .37352 .45464 L p
1 g
F P
s
P
p
.002 w
.63814 .36953 m .58885 .32253 L .6005 .30279 L p
1 g
F P
s
P
p
.002 w
.40297 .53063 m .40375 .54019 L .37542 .53481 L p
1 g
F P
s
P
p
.002 w
.37542 .53481 m .37366 .51606 L .40297 .53063 L p
1 g
F P
s
P
p
.48921 .57862 m .47857 .57775 L .48011 .57822 L 1 g
F
P
p
.002 w
.49023 .58136 m .47864 .58863 L .46863 .57912 L p
1 g
F P
s
P
p
.002 w
.46863 .57912 m .46167 .57251 L p
.4683 .57456 L 1 g
F P
s
P
p
.002 w
.4683 .57456 m .46872 .57265 L p
.45671 .56785 L 1 g
F P
s
P
p
.002 w
.45687 .56795 m .47864 .58863 L p
.45665 .56782 L 1 g
F P
s
P
p
.45671 .56785 m .45669 .56785 L .45687 .56795 L 1 g
F
P
p
.45671 .56785 m .45687 .56795 L .4683 .57456 L 1 g
F
P
p
.002 w
.44677 .56993 m .45665 .56782 L p
.47864 .58863 L 1 g
F P
s
P
p
.46872 .57265 m .45425 .56598 L .45669 .56785 L 1 g
F
P
p
.002 w
.44677 .56993 m .44114 .55594 L p
.45072 .56328 L 1 g
F P
s
P
p
.002 w
.45665 .56782 m .45462 .56825 L p
.45072 .56328 L 1 g
F P
s
P
p
.002 w
.45462 .56825 m .44677 .56993 L p
.45072 .56328 L 1 g
F P
s
P
p
.002 w
.45072 .56328 m .45146 .56129 L p
.44424 .55502 L 1 g
F P
s
P
p
.45425 .56598 m .45668 .56784 L .45669 .56785 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45038 .56419 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4383 .54745 L p
1 g
F P
s
P
p
.45146 .56129 m .4383 .54745 L .44424 .55502 L 1 g
F
P
p
.43695 .54391 m .43713 .54439 L .43566 .54235 L 1 g
F
P
p
.002 w
.44114 .55594 m .43709 .54591 L p
.45072 .56328 L 1 g
F P
s
P
p
.002 w
.4383 .54745 m .43925 .54566 L p
.43481 .53687 L 1 g
F P
s
P
p
.002 w
.43514 .53808 m .43566 .54235 L p
.43245 .52991 L 1 g
F P
s
P
p
.42759 .51106 m .43252 .5287 L .43245 .52991 L 1 g
F
P
p
.43252 .5287 m .43514 .53808 L .43245 .52991 L 1 g
F
P
p
.002 w
.43566 .54235 m .42106 .51152 L .42759 .51106 L p
1 g
F P
s
P
p
.002 w
.43252 .5287 m .43346 .52734 L p
.43314 .51808 L 1 g
F P
s
P
p
.002 w
.43183 .51076 m .43355 .51115 L p
.43305 .51964 L 1 g
F P
s
P
p
.43314 .51808 m .433 .52042 L .43252 .5287 L 1 g
F
P
p
.43481 .53687 m .43482 .53691 L .4383 .54745 L 1 g
F
P
p
.4348 .53686 m .43493 .53733 L .4383 .54745 L 1 g
F
P
p
.43473 .53672 m .43501 .53769 L .4383 .54745 L 1 g
F
P
p
.002 w
.43599 .54108 m .43566 .54235 L .43514 .53808 L p
1 g
F P
s
P
p
.43459 .53644 m .43508 .53807 L .4383 .54745 L 1 g
F
P
p
.43436 .536 m .43517 .53856 L .4383 .54745 L 1 g
F
P
p
.43405 .53538 m .43535 .53927 L .4383 .54745 L 1 g
F
P
p
.002 w
.43617 .5417 m .43566 .54235 L .43599 .54108 L p
1 g
F P
s
P
p
.43366 .5346 m .43566 .54032 L .4383 .54745 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.42759 .51106 m .43183 .51076 L .433 .52042 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43373 .5096 L p
1 g
F P
s
P
p
.43575 .49227 m .43373 .5096 L .43183 .51076 L 1 g
F
P
p
.002 w
.43355 .51115 m .43303 .51103 L p
.43373 .5096 L 1 g
F P
s
P
p
.002 w
.43303 .51103 m .43183 .51076 L p
.43373 .5096 L 1 g
F P
s
P
p
.002 w
.43373 .5096 m .43485 .50826 L p
.43828 .50024 L 1 g
F P
s
P
p
.43346 .52734 m .43373 .5096 L .43361 .51065 L 1 g
F
P
p
.43346 .52734 m .43361 .50973 L .43314 .51804 L 1 g
F
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44317 .51329 m .43355 .51115 L p
.43373 .5096 L 1 g
F P
s
P
p
.43575 .49227 m .43844 .49991 L .43373 .5096 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44262 .49132 L p
1 g
F P
s
P
p
.43485 .50826 m .44262 .49132 L .43828 .50024 L 1 g
F
P
p
.43844 .49991 m .44317 .51329 L .43373 .5096 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.45235 .48191 m .44317 .51329 L p
.43725 .49652 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.45261 .48102 m .46367 .44672 L p
.46811 .46655 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.47382 .49203 m .45304 .48124 L p
.45763 .47677 L 1 g
F P
s
P
p
.46915 .4712 m .47382 .49203 L .45763 .47677 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.46915 .4712 m .48493 .46613 L .47382 .49203 L 1 g
F
P
p
.002 w
.49343 .46499 m .47382 .49203 L p
.48493 .46613 L 1 g
F P
s
P
p
.002 w
.47759 .46711 m .47786 .46667 L p
.49037 .4654 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49493 .46291 m .51633 .43259 L p
.51846 .46071 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52236 .46705 L p
1 g
F P
s
P
p
.5189 .46656 m .52039 .48633 L .5 .46392 L 1 g
F
P
p
.5 .4634 m .52236 .46705 L .50986 .4653 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54224 .47662 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54224 .47662 m .53705 .51406 L .53591 .47368 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.002 w
.57025 .49891 m .57709 .53331 L p
.56595 .50921 L 1 g
F P
s
P
p
.56574 .50621 m .56595 .50921 L .56507 .5073 L 1 g
F
P
p
.57025 .49891 m .56595 .50921 L .56574 .50621 L 1 g
F
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56647 .51685 L 1 g
F P
s
P
p
.55661 .4905 m .56595 .50921 L .56276 .50232 L 1 g
F
P
p
.54909 .46296 m .55973 .49358 L .54721 .47094 L 1 g
F
P
p
.55973 .49358 m .56276 .50232 L .55723 .49116 L 1 g
F
P
p
.55973 .49358 m .55723 .49116 L .54721 .47094 L 1 g
F
P
p
.55661 .4905 m .56276 .50232 L .5623 .50138 L 1 g
F
P
p
.002 w
.54224 .47662 m .54174 .47608 L p
.54805 .48226 L 1 g
F P
s
P
p
.002 w
.54909 .46296 m .57025 .49891 L .56276 .50232 L p
1 g
F P
s
P
p
.002 w
.56276 .50232 m .57025 .49891 L p
.56507 .5073 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55796 .49194 L p
1 g
F P
s
P
p
.002 w
.55796 .49194 m .55661 .4905 L p
.56257 .5019 L 1 g
F P
s
P
p
.56257 .5019 m .56713 .51061 L .55796 .49194 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.54315 .54275 m .53705 .51406 L .56276 .50232 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56507 .5073 m .54315 .54275 L .56276 .50232 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55723 .49116 L p
1 g
F P
s
P
p
.002 w
.56276 .50232 m .53705 .51406 L p
.54519 .47949 L 1 g
F P
s
P
p
.54174 .47608 m .55723 .49116 L .54805 .48226 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54721 .47094 m .55723 .49116 L .54519 .47949 L 1 g
F
P
p
.55723 .49116 m .56276 .50232 L .54519 .47949 L 1 g
F
P
p
.54519 .47949 m .53705 .51406 L .54224 .47662 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54224 .47662 L p
1 g
F P
s
P
p
.54805 .48226 m .55834 .49233 L .54224 .47662 L 1 g
F
P
p
.5623 .50138 m .56276 .50232 L .56257 .5019 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56727 .52841 L p
1 g
F P
s
P
p
.56596 .50933 m .56996 .51847 L .56678 .52135 L 1 g
F
P
p
.002 w
.57762 .53595 m .56453 .53854 L p
.56996 .51847 L 1 g
F P
s
P
p
.56515 .50826 m .56727 .52841 L .56647 .51685 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56139 .54686 L p
1 g
F P
s
P
p
.57762 .53595 m .55985 .55095 L .56139 .54686 L 1 g
F
P
p
.002 w
.56453 .53854 m .56838 .53778 L p
.56139 .54686 L 1 g
F P
s
P
p
.002 w
.56838 .53778 m .57762 .53595 L p
.56139 .54686 L 1 g
F P
s
P
p
.002 w
.56139 .54686 m .56075 .54566 L p
.55679 .55284 L 1 g
F P
s
P
p
.56654 .52734 m .56139 .54686 L .56341 .54152 L 1 g
F
P
p
.56654 .52734 m .56198 .54798 L .56442 .53896 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53172 .57465 L p
1 g
F P
s
P
p
.002 w
.52351 .5903 m .51154 .58563 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53613 .57224 m .53511 .5737 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53511 .5737 m .52351 .5903 L p
.53172 .57465 L 1 g
F P
s
P
p
.002 w
.53172 .57465 m .53128 .57265 L p
.52226 .57728 L 1 g
F P
s
P
p
.54854 .56129 m .53172 .57465 L .53613 .57224 L 1 g
F
P
p
.002 w
.54105 .56916 m .57088 .56977 L p
.53613 .57224 L 1 g
F P
s
P
p
.53881 .57056 m .53613 .57224 L .53827 .57108 L 1 g
F
P
p
.54854 .56129 m .53613 .57224 L .53881 .57056 L 1 g
F
P
p
.002 w
.52351 .5903 m .53613 .57224 L p
.57088 .56977 L 1 g
F P
s
P
p
.002 w
.57656 .54125 m .57088 .56977 L .54419 .56922 L p
1 g
F P
s
P
p
.002 w
.54419 .56922 m .54105 .56916 L p
.54911 .56282 L 1 g
F P
s
P
p
.57656 .54125 m .54419 .56922 L .54911 .56282 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56282 L p
1 g
F P
s
P
p
.56075 .54566 m .54911 .56282 L .55679 .55284 L 1 g
F
P
p
.002 w
.54911 .56282 m .54854 .56129 L p
.53667 .5726 L 1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.57762 .53595 m .57656 .54125 L p
.53832 .56911 L 1 g
F P
s
P
p
.002 w
.54105 .56916 m .53832 .56911 L p
.57656 .54125 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56654 .52734 L p
1 g
F P
s
P
p
.56139 .54686 m .53832 .56911 L .56453 .53854 L 1 g
F
P
p
.55985 .55095 m .55529 .55479 L .56139 .54686 L 1 g
F
P
p
.55529 .55479 m .53832 .56911 L .56139 .54686 L 1 g
F
P
p
.002 w
.54911 .56282 m .54998 .56518 L p
.55679 .55284 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56282 L p
1 g
F P
s
P
p
.53667 .5726 m .5322 .57686 L .54911 .56282 L 1 g
F
P
p
.002 w
.53613 .57224 m .53832 .56911 L .54105 .56916 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48903 .58099 L p
1 g
F P
s
P
p
.51079 .57862 m .48903 .58099 L .4906 .58113 L 1 g
F
P
p
.002 w
.49995 .5811 m .50994 .585 L p
.4906 .58113 L 1 g
F P
s
P
p
.49617 .58112 m .4906 .58113 L .49415 .58146 L 1 g
F
P
p
.51079 .57862 m .4906 .58113 L .49617 .58112 L 1 g
F
P
p
.002 w
.49023 .58136 m .4906 .58113 L p
.50994 .585 L 1 g
F P
s
P
p
.51079 .57862 m .49415 .58146 L .49767 .58124 L 1 g
F
P
p
.002 w
.51154 .58563 m .50351 .58249 L p
.52237 .57973 L 1 g
F P
s
P
p
.002 w
.50351 .58249 m .49995 .5811 L p
.51093 .58043 L 1 g
F P
s
P
p
.52237 .57973 m .50351 .58249 L .51093 .58043 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58043 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58043 L .52226 .57728 L 1 g
F
P
p
.002 w
.47864 .58863 m .49023 .58136 L p
.52351 .5903 L 1 g
F P
s
P
p
.002 w
.50994 .585 m .52351 .5903 L p
.49023 .58136 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51093 .58043 L p
1 g
F P
s
P
p
.002 w
.51093 .58043 m .51079 .57862 L p
.49767 .58124 L 1 g
F P
s
P
p
.49767 .58124 m .48889 .583 L .51093 .58043 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.53613 .57224 m .52237 .57973 L .49421 .57886 L 1 g
F
P
p
.002 w
.49995 .5811 m .49421 .57886 L p
.52237 .57973 L 1 g
F P
s
P
p
.002 w
.51093 .58043 m .51111 .583 L p
.52226 .57728 L 1 g
F P
s
P
p
.002 w
.4906 .58113 m .49421 .57886 L .49995 .5811 L p
1 g
F P
s
P
p
.49767 .58124 m .49415 .58146 L .49582 .58161 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57465 L p
1 g
F P
s
P
p
.52226 .57728 m .51111 .583 L .53172 .57465 L 1 g
F
P
p
.002 w
.53172 .57465 m .5322 .57686 L p
.53827 .57108 L 1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53832 .56911 m .53613 .57224 L p
.49421 .57886 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56139 .54686 L p
1 g
F P
s
P
p
.55679 .55284 m .54998 .56518 L .56139 .54686 L 1 g
F
P
p
.002 w
.56139 .54686 m .56198 .54798 L p
.56341 .54152 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53832 .56911 m .54315 .54275 L .56453 .53854 L p
1 g
F P
s
P
p
.002 w
.56453 .53854 m .54315 .54275 L p
.56996 .51847 L 1 g
F P
s
P
p
.002 w
.56727 .52841 m .56854 .53025 L p
.56647 .51685 L 1 g
F P
s
P
p
.56507 .5073 m .56596 .50933 L .54315 .54275 L 1 g
F
P
p
.56596 .50933 m .56678 .52135 L .54315 .54275 L 1 g
F
P
p
.002 w
.56198 .54798 m .56257 .5491 L p
.56442 .53896 L 1 g
F P
s
P
p
.002 w
.57709 .53331 m .57762 .53595 L p
.56507 .5073 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56647 .51685 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.56257 .5019 L 1 g
F P
s
P
p
.54551 .47814 m .54519 .47949 L .54224 .47662 L 1 g
F
P
p
.002 w
.55723 .49116 m .55834 .49233 L p
.54805 .48226 L 1 g
F P
s
P
p
.002 w
.54224 .47662 m .54251 .47692 L p
.53813 .47471 L 1 g
F P
s
P
p
.52214 .46667 m .54224 .47662 L .53813 .47471 L 1 g
F
P
p
.002 w
.53705 .51406 m .52039 .48633 L .53591 .47368 L p
1 g
F P
s
P
p
.52214 .46667 m .54251 .47692 L .53173 .47163 L 1 g
F
P
p
.002 w
.53591 .47368 m .54909 .46296 L p
.54551 .47814 L 1 g
F P
s
P
p
.002 w
.51633 .43259 m .54909 .46296 L .53591 .47368 L p
1 g
F P
s
P
p
.002 w
.53591 .47368 m .52039 .48633 L p
.5189 .46656 L 1 g
F P
s
P
p
.52236 .46705 m .53591 .47368 L .5189 .46656 L 1 g
F
P
p
.002 w
.52039 .48633 m .49665 .4645 L p
.5 .46392 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46392 L p
1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .4634 L p
.50986 .4653 L 1 g
F P
s
P
p
.50986 .4653 m .52282 .46778 L .5 .46392 L 1 g
F
P
p
.5188 .4653 m .52236 .46705 L .5189 .46656 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52214 .46667 L p
1 g
F P
s
P
p
.51633 .43259 m .53591 .47368 L .5188 .4653 L 1 g
F
P
p
.002 w
.54251 .47692 m .54302 .47747 L p
.53173 .47163 L 1 g
F P
s
P
p
.002 w
.52236 .46705 m .52282 .46778 L p
.50986 .4653 L 1 g
F P
s
P
p
.51846 .46071 m .5189 .46656 L .5 .46392 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46392 L p
1 g
F P
s
P
p
.47786 .46667 m .5 .46392 L .49855 .46417 L 1 g
F
P
p
.47786 .46667 m .5 .46399 L .49685 .46447 L 1 g
F
P
p
.49477 .46478 m .49117 .50786 L .49343 .46499 L 1 g
F
P
p
.47786 .46667 m .49685 .46447 L .49037 .4654 L 1 g
F
P
p
.002 w
.52039 .48633 m .49117 .50786 L p
.49477 .46478 L 1 g
F P
s
P
p
.002 w
.49665 .4645 m .52039 .48633 L p
.49477 .46478 L 1 g
F P
s
P
p
.49685 .46447 m .5 .4641 L .49343 .46499 L 1 g
F
P
p
.49685 .46447 m .49343 .46499 L .49037 .4654 L 1 g
F
P
p
.002 w
.49493 .46291 m .49665 .4645 L p
.49477 .46478 L 1 g
F P
s
P
p
.002 w
.49665 .4645 m .49493 .46291 L p
.51846 .46071 L 1 g
F P
s
P
p
.002 w
.5 .46392 m .5 .46399 L p
.49855 .46417 L 1 g
F P
s
P
p
.002 w
.5 .46399 m .5 .4641 L p
.49685 .46447 L 1 g
F P
s
P
p
.002 w
.49117 .50786 m .47382 .49203 L .49343 .46499 L p
1 g
F P
s
P
p
.002 w
.49343 .46499 m .49493 .46291 L p
.49477 .46478 L 1 g
F P
s
P
p
.002 w
.49075 .46075 m .49493 .46291 L p
.48493 .46613 L 1 g
F P
s
P
p
.47759 .46711 m .48493 .46613 L .46915 .4712 L 1 g
F
P
p
.49075 .46075 m .48493 .46613 L .47759 .46711 L 1 g
F
P
p
.002 w
.5 .4641 m .5 .46442 L p
.49037 .4654 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47759 .46711 L p
1 g
F P
s
P
p
.49037 .4654 m .5 .46442 L .47759 .46711 L 1 g
F
P
p
.002 w
.49493 .46291 m .49343 .46499 L p
.48493 .46613 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47759 .46711 L p
1 g
F P
s
P
p
.45826 .47608 m .47759 .46711 L .46677 .47235 L 1 g
F
P
p
.002 w
.46367 .44672 m .49075 .46075 L p
.46915 .4712 L 1 g
F P
s
P
p
.002 w
.47759 .46711 m .47718 .46778 L p
.46677 .47235 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45763 .47677 L p
1 g
F P
s
P
p
.002 w
.45763 .47677 m .45826 .47608 L p
.46677 .47235 L 1 g
F P
s
P
p
.46677 .47235 m .47718 .46778 L .45763 .47677 L 1 g
F
P
p
.46811 .46655 m .46915 .4712 L .45763 .47677 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45763 .47677 L p
1 g
F P
s
P
p
.44339 .4905 m .45763 .47677 L .45521 .47913 L 1 g
F
P
p
.44339 .4905 m .4574 .47702 L .45187 .48237 L 1 g
F
P
p
.002 w
.45304 .48124 m .45261 .48102 L p
.46811 .46655 L 1 g
F P
s
P
p
.002 w
.45763 .47677 m .4574 .47702 L p
.45521 .47913 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.45382 .51883 m .44317 .51329 L .45235 .48191 L p
1 g
F P
s
P
p
.45263 .48164 m .45382 .51883 L .45235 .48191 L 1 g
F
P
p
.002 w
.47382 .49203 m .45382 .51883 L p
.45263 .48164 L 1 g
F P
s
P
p
.002 w
.45261 .48102 m .45304 .48124 L p
.45263 .48164 L 1 g
F P
s
P
p
.002 w
.45304 .48124 m .47382 .49203 L p
.45263 .48164 L 1 g
F P
s
P
p
.002 w
.44262 .49132 m .44166 .49233 L p
.43828 .50024 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44246 .49149 L p
1 g
F P
s
P
p
.002 w
.44246 .49149 m .44262 .49132 L p
.44588 .48818 L 1 g
F P
s
P
p
.44588 .48818 m .45698 .47747 L .44246 .49149 L 1 g
F
P
p
.002 w
.4574 .47702 m .45698 .47747 L p
.45187 .48237 L 1 g
F P
s
P
p
.002 w
.45235 .48191 m .45261 .48102 L p
.45263 .48164 L 1 g
F P
s
P
p
.002 w
.43004 .47612 m .45261 .48102 L .45235 .48191 L p
1 g
F P
s
P
p
.002 w
.44262 .49132 m .44339 .4905 L p
.45178 .48246 L 1 g
F P
s
P
p
.43004 .47612 m .45235 .48191 L .43725 .49652 L 1 g
F
P
p
.45178 .48246 m .45698 .47747 L .44262 .49132 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43373 .5096 L p
1 g
F P
s
P
p
.43828 .50024 m .44166 .49233 L .43373 .5096 L 1 g
F
P
p
.002 w
.43373 .5096 m .43361 .50973 L p
.43361 .51065 L 1 g
F P
s
P
p
.002 w
.43183 .51076 m .43004 .47612 L p
.43575 .49227 L 1 g
F P
s
P
p
.002 w
.433 .52042 m .43514 .53808 L p
.43252 .5287 L 1 g
F P
s
P
p
.42759 .51106 m .433 .52042 L .43252 .5287 L 1 g
F
P
p
.002 w
.43361 .50973 m .43287 .51061 L p
.43314 .51804 L 1 g
F P
s
P
p
.002 w
.43514 .53808 m .433 .52042 L p
.43599 .54108 L 1 g
F P
s
P
p
.002 w
.433 .52042 m .43183 .51076 L p
.43305 .51964 L 1 g
F P
s
P
p
.43305 .51964 m .43599 .54108 L .433 .52042 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43251 .52873 L p
1 g
F P
s
P
p
.002 w
.43251 .52873 m .43252 .5287 L p
.43253 .52835 L 1 g
F P
s
P
p
.43253 .52835 m .43287 .51061 L .43251 .52873 L 1 g
F
P
p
.43314 .51808 m .43314 .51804 L .433 .52042 L 1 g
F
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44317 .51329 m .43599 .54108 L p
.43305 .51964 L 1 g
F P
s
P
p
.002 w
.43355 .51115 m .44317 .51329 L p
.43305 .51964 L 1 g
F P
s
P
p
.43314 .51804 m .43287 .51061 L .43252 .5287 L 1 g
F
P
p
.43481 .53687 m .4348 .53686 L .43482 .53691 L 1 g
F
P
p
.4348 .53686 m .43473 .53672 L .43493 .53733 L 1 g
F
P
p
.43473 .53672 m .43459 .53644 L .43501 .53769 L 1 g
F
P
p
.43321 .53371 m .43617 .54181 L .4383 .54745 L 1 g
F
P
p
.002 w
.44317 .51329 m .45382 .51883 L .43617 .5417 L p
1 g
F P
s
P
p
.002 w
.43599 .54108 m .44317 .51329 L p
.43617 .5417 L 1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45382 .51883 m .46257 .52676 L .43626 .54201 L p
1 g
F P
s
P
p
.002 w
.43626 .54201 m .43566 .54235 L .43617 .5417 L p
1 g
F P
s
P
p
.002 w
.43617 .5417 m .45382 .51883 L p
.43626 .54201 L 1 g
F P
s
P
p
.43459 .53644 m .43436 .536 L .43508 .53807 L 1 g
F
P
p
.43436 .536 m .43405 .53538 L .43517 .53856 L 1 g
F
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.46257 .52676 m .46845 .53617 L .43633 .54223 L p
1 g
F P
s
P
p
.002 w
.43633 .54223 m .43566 .54235 L .43626 .54201 L p
1 g
F P
s
P
p
.002 w
.43626 .54201 m .46257 .52676 L p
.43633 .54223 L 1 g
F P
s
P
p
.002 w
.4364 .54243 m .43566 .54235 L .43633 .54223 L p
1 g
F P
s
P
p
.43277 .53285 m .43694 .5439 L .4383 .54745 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46845 .53617 m .47083 .54602 L .4364 .54243 L p
1 g
F P
s
P
p
.002 w
.43633 .54223 m .46845 .53617 L p
.4364 .54243 L 1 g
F P
s
P
p
.43405 .53538 m .43366 .5346 L .43535 .53927 L 1 g
F
P
p
.43366 .5346 m .43321 .53371 L .43566 .54032 L 1 g
F
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47083 .54602 m .46947 .5552 L .43648 .54266 L p
1 g
F P
s
P
p
.002 w
.43648 .54266 m .43566 .54235 L .4364 .54243 L p
1 g
F P
s
P
p
.002 w
.4364 .54243 m .47083 .54602 L p
.43648 .54266 L 1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46947 .5552 m .46457 .56272 L .43661 .54302 L p
1 g
F P
s
P
p
.002 w
.43661 .54302 m .43566 .54235 L .43648 .54266 L p
1 g
F P
s
P
p
.002 w
.43648 .54266 m .46947 .5552 L p
.43661 .54302 L 1 g
F P
s
P
p
.43321 .53371 m .43277 .53285 L .43617 .54181 L 1 g
F
P
p
.43277 .53285 m .43247 .53226 L .43694 .5439 L 1 g
F
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.46457 .56272 m .45672 .5678 L .43694 .5439 L p
1 g
F P
s
P
p
.002 w
.43694 .5439 m .43566 .54235 L .43661 .54302 L p
1 g
F P
s
P
p
.002 w
.43661 .54302 m .46457 .56272 L p
.43694 .5439 L 1 g
F P
s
P
p
.002 w
.43709 .54591 m .43566 .54235 L p
.45072 .56328 L 1 g
F P
s
P
p
.002 w
.43566 .54235 m .45672 .5678 L .45665 .56782 L p
1 g
F P
s
P
p
.002 w
.42496 .56488 m .41538 .55826 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.4358 .56892 m .42496 .56488 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.41538 .55826 m .40804 .54974 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.44677 .56993 m .4358 .56892 L .43567 .54407 L p
1 g
F P
s
P
p
.002 w
.43567 .54407 m .43566 .54235 L .43709 .54591 L p
1 g
F P
s
P
p
.002 w
.43709 .54591 m .44677 .56993 L p
.43567 .54407 L 1 g
F P
s
P
p
.002 w
.4383 .54745 m .4383 .54746 L p
.44424 .55502 L 1 g
F P
s
P
p
.002 w
.4383 .54746 m .43743 .5491 L p
.444 .55481 L 1 g
F P
s
P
p
.44424 .55502 m .4383 .54746 L .444 .55481 L 1 g
F
P
p
.002 w
.40804 .54974 m .40375 .54019 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.40375 .54019 m .40297 .53063 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.40297 .53063 m .40583 .52206 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.40583 .52206 m .41208 .51544 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.41208 .51544 m .42106 .51152 L .43566 .54235 L closepath p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4383 .54745 L p
1 g
F P
s
P
p
.43247 .53226 m .43146 .53025 L .4383 .54745 L 1 g
F
P
p
.45665 .56782 m .45072 .56328 L .43713 .54439 L 1 g
F
P
p
.45665 .56782 m .43713 .54439 L .43695 .54391 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45072 .56328 L p
1 g
F P
s
P
p
.44424 .55502 m .43743 .5491 L .45072 .56328 L 1 g
F
P
p
.45425 .56598 m .45038 .56419 L .45668 .56784 L 1 g
F
P
p
.48903 .58099 m .4776 .57994 L .4683 .57456 L 1 g
F
P
p
.4776 .57994 m .46863 .57912 L .4683 .57456 L 1 g
F
P
p
.49023 .58136 m .46863 .57912 L .48903 .58099 L 1 g
F
P
p
.002 w
.48902 .58114 m .48903 .58099 L p
.47114 .57783 L 1 g
F P
s
P
p
.002 w
.48903 .58099 m .48921 .57862 L p
.48011 .57822 L 1 g
F P
s
P
p
.48011 .57822 m .47114 .57783 L .48903 .58099 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4678 .57686 L p
1 g
F P
s
P
p
.49023 .58136 m .4683 .57456 L .45672 .5678 L 1 g
F
P
p
.002 w
.46167 .57251 m .45687 .56795 L p
.4683 .57456 L 1 g
F P
s
P
p
.002 w
.45687 .56795 m .45672 .5678 L p
.4683 .57456 L 1 g
F P
s
P
p
.002 w
.45038 .56419 m .45002 .56518 L p
.45669 .56785 L 1 g
F P
s
P
p
.002 w
.45665 .56782 m .45672 .5678 L .45687 .56795 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4683 .57456 L p
1 g
F P
s
P
p
.45669 .56785 m .45002 .56518 L .4683 .57456 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49421 .57886 m .49023 .58136 L p
.45672 .5678 L 1 g
F P
s
P
p
.002 w
.48903 .58099 m .48889 .583 L p
.49582 .58161 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .47114 .57783 L p
.48011 .57822 L 1 g
F P
s
P
p
.47857 .57775 m .4678 .57686 L .48011 .57822 L 1 g
F
P
p
.002 w
.47114 .57783 m .48889 .583 L .48902 .58114 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.62828 .46333 m .63702 .5135 L .60926 .52606 L p
1 g
F P
s
P
p
.002 w
.63702 .5135 m .62828 .46333 L .65108 .44429 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.44404 .3337 m .38994 .34024 L .39352 .31147 L p
1 g
F P
s
P
p
.002 w
.39352 .31147 m .45209 .30391 L .44404 .3337 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.51503 .31583 m .45209 .30391 L .46137 .27867 L p
1 g
F P
s
P
p
.002 w
.46137 .27867 m .52717 .29085 L .51503 .31583 L p
1 g
F P
s
P
p
.002 w
.57088 .56977 m .57762 .53595 L .60926 .52606 L p
1 g
F P
s
P
p
.002 w
.39273 .40694 m .35994 .42301 L .35079 .39211 L p
1 g
F P
s
P
p
.002 w
.35079 .39211 m .38964 .37243 L .39273 .40694 L p
1 g
F P
s
P
p
.002 w
.40583 .52206 m .40297 .53063 L .37366 .51606 L p
1 g
F P
s
P
p
.002 w
.37366 .51606 m .37902 .49911 L .40583 .52206 L p
1 g
F P
s
P
p
.002 w
.62144 .39108 m .65108 .44429 L .62828 .46333 L p
1 g
F P
s
P
p
.002 w
.65108 .44429 m .62144 .39108 L .63814 .36953 L p
1 g
F P
s
P
p
.002 w
.58885 .32253 m .63814 .36953 L .62144 .39108 L p
1 g
F P
s
P
p
.002 w
.3911 .48583 m .37902 .49911 L .35618 .47435 L p
1 g
F P
s
P
p
.002 w
.35618 .47435 m .37352 .45464 L .3911 .48583 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.45672 .5678 m .46457 .56272 L .49421 .57886 L p
1 g
F P
s
P
p
.002 w
.50411 .56421 m .49421 .57886 L .46457 .56272 L p
1 g
F P
s
P
p
.002 w
.49421 .57886 m .50411 .56421 L .53832 .56911 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.60103 .48177 m .60926 .52606 L .57762 .53595 L p
1 g
F P
s
P
p
.002 w
.60926 .52606 m .60103 .48177 L .62828 .46333 L p
1 g
F P
s
P
p
.002 w
.54315 .54275 m .53832 .56911 L .50411 .56421 L p
1 g
F P
s
P
p
.002 w
.43757 .36708 m .38964 .37243 L .38994 .34024 L p
1 g
F P
s
P
p
.002 w
.38994 .34024 m .44404 .3337 L .43757 .36708 L p
1 g
F P
s
P
p
.002 w
.57411 .3462 m .51503 .31583 L .52717 .29085 L p
1 g
F P
s
P
p
.002 w
.52717 .29085 m .58885 .32253 L .57411 .3462 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.39917 .44252 m .37352 .45464 L .35994 .42301 L p
1 g
F P
s
P
p
.002 w
.35994 .42301 m .39273 .40694 L .39917 .44252 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62144 .39108 m .57411 .3462 L .58885 .32253 L p
1 g
F P
s
P
p
.002 w
.41208 .51544 m .40583 .52206 L .37902 .49911 L p
1 g
F P
s
P
p
.002 w
.37902 .49911 m .3911 .48583 L .41208 .51544 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.46457 .56272 m .46947 .5552 L .50411 .56421 L p
1 g
F P
s
P
p
.002 w
.50213 .34499 m .44404 .3337 L .45209 .30391 L p
1 g
F P
s
P
p
.002 w
.45209 .30391 m .51503 .31583 L .50213 .34499 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50711 .54616 m .50411 .56421 L .46947 .5552 L p
1 g
F P
s
P
p
.002 w
.50411 .56421 m .50711 .54616 L .54315 .54275 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.60056 .4144 m .62828 .46333 L .60103 .48177 L p
1 g
F P
s
P
p
.002 w
.62828 .46333 m .60056 .4144 L .62144 .39108 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.57762 .53595 m .57025 .49891 L .60103 .48177 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.40873 .47783 m .3911 .48583 L .37352 .45464 L p
1 g
F P
s
P
p
.002 w
.37352 .45464 m .39917 .44252 L .40873 .47783 L p
1 g
F P
s
P
p
.002 w
.46947 .5552 m .47083 .54602 L .50711 .54616 L p
1 g
F P
s
P
p
.002 w
.57411 .3462 m .62144 .39108 L .60056 .4144 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.43296 .40287 m .39273 .40694 L .38964 .37243 L p
1 g
F P
s
P
p
.002 w
.38964 .37243 m .43757 .36708 L .43296 .40287 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.42106 .51152 m .41208 .51544 L .3911 .48583 L p
1 g
F P
s
P
p
.002 w
.3911 .48583 m .40873 .47783 L .42106 .51152 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.53705 .51406 m .54315 .54275 L .50711 .54616 L p
1 g
F P
s
P
p
.002 w
.47083 .54602 m .46845 .53617 L .50268 .52664 L p
1 g
F P
s
P
p
.002 w
.50268 .52664 m .50711 .54616 L .47083 .54602 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.50711 .54616 m .50268 .52664 L .53705 .51406 L p
1 g
F P
s
P
p
.002 w
.55669 .37309 m .50213 .34499 L .51503 .31583 L p
1 g
F P
s
P
p
.002 w
.51503 .31583 m .57411 .3462 L .55669 .37309 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.57616 .43866 m .60103 .48177 L .57025 .49891 L p
1 g
F P
s
P
p
.002 w
.60103 .48177 m .57616 .43866 L .60056 .4144 L p
1 g
F P
s
P
p
.002 w
.43183 .51076 m .42106 .51152 L .40873 .47783 L p
1 g
F P
s
P
p
.002 w
.60056 .4144 m .55669 .37309 L .57411 .3462 L p
1 g
F P
s
P
p
.002 w
.48892 .37734 m .43757 .36708 L .44404 .3337 L p
1 g
F P
s
P
p
.002 w
.44404 .3337 m .50213 .34499 L .48892 .37734 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.46845 .53617 m .46257 .52676 L .49117 .50786 L p
1 g
F P
s
P
p
.002 w
.49117 .50786 m .50268 .52664 L .46845 .53617 L p
1 g
F P
s
P
p
.002 w
.43041 .43969 m .39917 .44252 L .39273 .40694 L p
1 g
F P
s
P
p
.002 w
.39273 .40694 m .43296 .40287 L .43041 .43969 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.40873 .47783 m .43004 .47612 L .43183 .51076 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.46257 .52676 m .45382 .51883 L .47382 .49203 L p
1 g
F P
s
P
p
.002 w
.47382 .49203 m .49117 .50786 L .46257 .52676 L p
1 g
F P
s
P
p
.002 w
.43004 .47612 m .40873 .47783 L .39917 .44252 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.55669 .37309 m .60056 .4144 L .57616 .43866 L p
1 g
F P
s
P
p
.002 w
.39917 .44252 m .43041 .43969 L .43004 .47612 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57025 .49891 m .54909 .46296 L .57616 .43866 L p
1 g
F P
s
P
p
.002 w
.50268 .52664 m .49117 .50786 L .52039 .48633 L p
1 g
F P
s
P
p
.002 w
.52039 .48633 m .53705 .51406 L .50268 .52664 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47593 .4117 m .43296 .40287 L .43757 .36708 L p
1 g
F P
s
P
p
.002 w
.43757 .36708 m .48892 .37734 L .47593 .4117 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53719 .40226 m .48892 .37734 L .50213 .34499 L p
1 g
F P
s
P
p
.002 w
.50213 .34499 m .55669 .37309 L .53719 .40226 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.45261 .48102 m .43004 .47612 L .43041 .43969 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57616 .43866 m .53719 .40226 L .55669 .37309 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.53719 .40226 m .57616 .43866 L .54909 .46296 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.46367 .44672 m .43041 .43969 L .43296 .40287 L p
1 g
F P
s
P
p
.002 w
.43296 .40287 m .47593 .4117 L .46367 .44672 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.43041 .43969 m .46367 .44672 L .45261 .48102 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54909 .46296 m .51633 .43259 L .53719 .40226 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51633 .43259 m .47593 .4117 L .48892 .37734 L p
1 g
F P
s
P
p
.002 w
.48892 .37734 m .53719 .40226 L .51633 .43259 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.49493 .46291 m .46367 .44672 L .47593 .4117 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47593 .4117 m .51633 .43259 L .49493 .46291 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.004 w
.40902 .58868 m
.41395 .58009 L
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .48603 .72748 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .3974 .60888 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.662016)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.662016)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46197 .433 m .48692 .45757 L .50383 .43463 L p
1 g
F P
s
P
p
.002 w
.50383 .43463 m .48455 .41561 L .46197 .433 L p
1 g
F P
s
P
p
.002 w
.5277 .44724 m .50383 .43463 L .48692 .45757 L p
1 g
F P
s
P
p
.002 w
.48455 .41561 m .50383 .43463 L .52065 .41159 L p
1 g
F P
s
P
p
.002 w
.50383 .43463 m .5277 .44724 L .53697 .42017 L p
1 g
F P
s
P
p
.002 w
.53697 .42017 m .52065 .41159 L .50383 .43463 L p
1 g
F P
s
P
p
.002 w
.44537 .40262 m .46197 .433 L .48455 .41561 L p
1 g
F P
s
P
p
.002 w
.48455 .41561 m .47181 .39207 L .44537 .40262 L p
1 g
F P
s
P
p
.002 w
.47181 .39207 m .48455 .41561 L .50749 .39859 L p
1 g
F P
s
P
p
.002 w
.52065 .41159 m .50749 .39859 L .48455 .41561 L p
1 g
F P
s
P
p
.002 w
.50749 .39859 m .52065 .41159 L .53706 .38888 L p
1 g
F P
s
P
p
.002 w
.52065 .41159 m .53697 .42017 L .54538 .39323 L p
1 g
F P
s
P
p
.002 w
.54538 .39323 m .53706 .38888 L .52065 .41159 L p
1 g
F P
s
P
p
.002 w
.44016 .45045 m .47022 .48 L .48692 .45757 L p
1 g
F P
s
P
p
.002 w
.48692 .45757 m .46197 .433 L .44016 .45045 L p
1 g
F P
s
P
p
.002 w
.51775 .47395 m .48692 .45757 L .47022 .48 L p
1 g
F P
s
P
p
.002 w
.48692 .45757 m .51775 .47395 L .5277 .44724 L p
1 g
F P
s
P
p
.002 w
.55378 .45215 m .5277 .44724 L .51775 .47395 L p
1 g
F P
s
P
p
.002 w
.5277 .44724 m .55378 .45215 L .55478 .42343 L p
1 g
F P
s
P
p
.002 w
.55478 .42343 m .53697 .42017 L .5277 .44724 L p
1 g
F P
s
P
p
.002 w
.50749 .39859 m .49885 .38249 L .47181 .39207 L p
1 g
F P
s
P
p
.002 w
.49885 .38249 m .50749 .39859 L .53037 .38225 L p
1 g
F P
s
P
p
.002 w
.53706 .38888 m .53037 .38225 L .50749 .39859 L p
1 g
F P
s
P
p
.002 w
.42003 .41394 m .44016 .45045 L .46197 .433 L p
1 g
F P
s
P
p
.002 w
.46197 .433 m .44537 .40262 L .42003 .41394 L p
1 g
F P
s
P
p
.002 w
.53697 .42017 m .55478 .42343 L .55444 .39484 L p
1 g
F P
s
P
p
.002 w
.55444 .39484 m .54538 .39323 L .53697 .42017 L p
1 g
F P
s
P
p
.002 w
.47022 .48 m .5073 .4998 L .51775 .47395 L p
1 g
F P
s
P
p
.002 w
.55147 .48045 m .51775 .47395 L .5073 .4998 L p
1 g
F P
s
P
p
.002 w
.51775 .47395 m .55147 .48045 L .55378 .45215 L p
1 g
F P
s
P
p
.002 w
.43888 .36938 m .44537 .40262 L .47181 .39207 L p
1 g
F P
s
P
p
.002 w
.47181 .39207 m .46696 .36637 L .43888 .36938 L p
1 g
F P
s
P
p
.002 w
.46696 .36637 m .47181 .39207 L .49885 .38249 L p
1 g
F P
s
P
p
.002 w
.49885 .38249 m .49566 .36495 L .46696 .36637 L p
1 g
F P
s
P
p
.002 w
.49566 .36495 m .49885 .38249 L .526 .37404 L p
1 g
F P
s
P
p
.002 w
.53037 .38225 m .526 .37404 L .49885 .38249 L p
1 g
F P
s
P
p
.002 w
.57223 .42098 m .55478 .42343 L .55378 .45215 L p
1 g
F P
s
P
p
.002 w
.55478 .42343 m .57223 .42098 L .56329 .39353 L p
1 g
F P
s
P
p
.002 w
.56329 .39353 m .55444 .39484 L .55478 .42343 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .53037 .38225 L .53706 .38888 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .53706 .38888 L .54538 .39323 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .526 .37404 L .53037 .38225 L closepath p
1 g
F P
s
P
p
.002 w
.41952 .46765 m .45403 .50151 L .47022 .48 L p
1 g
F P
s
P
p
.002 w
.47022 .48 m .44016 .45045 L .41952 .46765 L p
1 g
F P
s
P
p
.002 w
.5073 .4998 m .47022 .48 L .45403 .50151 L p
1 g
F P
s
P
p
.002 w
.57943 .44873 m .55378 .45215 L .55147 .48045 L p
1 g
F P
s
P
p
.002 w
.55378 .45215 m .57943 .44873 L .57223 .42098 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .54538 .39323 L .55444 .39484 L closepath p
1 g
F P
s
P
p
.002 w
.41196 .37392 m .42003 .41394 L .44537 .40262 L p
1 g
F P
s
P
p
.002 w
.44537 .40262 m .43888 .36938 L .41196 .37392 L p
1 g
F P
s
P
p
.002 w
.526 .37404 m .52444 .36512 L .49566 .36495 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .52444 .36512 L .526 .37404 L closepath p
1 g
F P
s
P
p
.002 w
.39628 .42584 m .41952 .46765 L .44016 .45045 L p
1 g
F P
s
P
p
.002 w
.44016 .45045 m .42003 .41394 L .39628 .42584 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .55444 .39484 L .56329 .39353 L closepath p
1 g
F P
s
P
p
.002 w
.47065 .34112 m .46696 .36637 L .49566 .36495 L p
1 g
F P
s
P
p
.002 w
.49566 .36495 m .49831 .34779 L .47065 .34112 L p
1 g
F P
s
P
p
.002 w
.49831 .34779 m .49566 .36495 L .52444 .36512 L p
1 g
F P
s
P
p
.002 w
.45403 .50151 m .49651 .5243 L .5073 .4998 L p
1 g
F P
s
P
p
.002 w
.54787 .50783 m .5073 .4998 L .49651 .5243 L p
1 g
F P
s
P
p
.002 w
.5073 .4998 m .54787 .50783 L .55147 .48045 L p
1 g
F P
s
P
p
.002 w
.52444 .36512 m .52586 .35644 L .49831 .34779 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .52586 .35644 L .52444 .36512 L closepath p
1 g
F P
s
P
p
.002 w
.58474 .47627 m .55147 .48045 L .54787 .50783 L p
1 g
F P
s
P
p
.002 w
.55147 .48045 m .58474 .47627 L .57943 .44873 L p
1 g
F P
s
P
p
.002 w
.44339 .33659 m .43888 .36938 L .46696 .36637 L p
1 g
F P
s
P
p
.002 w
.46696 .36637 m .47065 .34112 L .44339 .33659 L p
1 g
F P
s
P
p
.002 w
.58749 .41299 m .57223 .42098 L .57943 .44873 L p
1 g
F P
s
P
p
.002 w
.57223 .42098 m .58749 .41299 L .57098 .38941 L p
1 g
F P
s
P
p
.002 w
.57098 .38941 m .56329 .39353 L .57223 .42098 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .56329 .39353 L .57098 .38941 L closepath p
1 g
F P
s
P
p
.002 w
.50662 .33285 m .49831 .34779 L .52586 .35644 L p
1 g
F P
s
P
p
.002 w
.52586 .35644 m .53014 .34892 L .50662 .33285 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .53014 .34892 L .52586 .35644 L closepath p
1 g
F P
s
P
p
.002 w
.60197 .43719 m .57943 .44873 L .58474 .47627 L p
1 g
F P
s
P
p
.002 w
.57943 .44873 m .60197 .43719 L .58749 .41299 L p
1 g
F P
s
P
p
.002 w
.38675 .37996 m .39628 .42584 L .42003 .41394 L p
1 g
F P
s
P
p
.002 w
.42003 .41394 m .41196 .37392 L .38675 .37996 L p
1 g
F P
s
P
p
.002 w
.57667 .38291 m .57098 .38941 L .58749 .41299 L p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .57098 .38941 L .57667 .38291 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .57667 .38291 L .57972 .37472 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .57972 .37472 L .57978 .36571 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .57978 .36571 L .57681 .35688 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .57681 .35688 L .57114 .34921 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .53683 .3434 L .53014 .34892 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .57114 .34921 L .56339 .34355 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .56339 .34355 L .55442 .34054 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .55442 .34054 L .54523 .34049 L closepath p
1 g
F P
s
P
p
.002 w
.55278 .3669 m .54523 .34049 L .53683 .3434 L closepath p
1 g
F P
s
P
p
.002 w
.48267 .319 m .47065 .34112 L .49831 .34779 L p
1 g
F P
s
P
p
.002 w
.49831 .34779 m .50662 .33285 L .48267 .319 L p
1 g
F P
s
P
p
.002 w
.40048 .48426 m .43867 .52168 L .45403 .50151 L p
1 g
F P
s
P
p
.002 w
.45403 .50151 m .41952 .46765 L .40048 .48426 L p
1 g
F P
s
P
p
.002 w
.49651 .5243 m .45403 .50151 L .43867 .52168 L p
1 g
F P
s
P
p
.002 w
.41709 .33433 m .41196 .37392 L .43888 .36938 L p
1 g
F P
s
P
p
.002 w
.43888 .36938 m .44339 .33659 L .41709 .33433 L p
1 g
F P
s
P
p
.002 w
.51978 .32178 m .50662 .33285 L .53014 .34892 L p
1 g
F P
s
P
p
.002 w
.53014 .34892 m .53683 .3434 L .51978 .32178 L p
1 g
F P
s
P
p
.002 w
.37463 .43811 m .40048 .48426 L .41952 .46765 L p
1 g
F P
s
P
p
.002 w
.41952 .46765 m .39628 .42584 L .37463 .43811 L p
1 g
F P
s
P
p
.002 w
.59887 .40024 m .58749 .41299 L .60197 .43719 L p
1 g
F P
s
P
p
.002 w
.58749 .41299 m .59887 .40024 L .57667 .38291 L p
1 g
F P
s
P
p
.002 w
.57972 .37472 m .57667 .38291 L .59887 .40024 L p
1 g
F P
s
P
p
.002 w
.58802 .50307 m .54787 .50783 L .54303 .53373 L p
1 g
F P
s
P
p
.002 w
.49651 .5243 m .54303 .53373 L .54787 .50783 L p
1 g
F P
s
P
p
.002 w
.54787 .50783 m .58802 .50307 L .58474 .47627 L p
1 g
F P
s
P
p
.002 w
.43867 .52168 m .48561 .54696 L .49651 .5243 L p
1 g
F P
s
P
p
.002 w
.54303 .53373 m .49651 .5243 L .48561 .54696 L p
1 g
F P
s
P
p
.002 w
.45875 .30772 m .44339 .33659 L .47065 .34112 L p
1 g
F P
s
P
p
.002 w
.47065 .34112 m .48267 .319 L .45875 .30772 L p
1 g
F P
s
P
p
.002 w
.53643 .31587 m .51978 .32178 L .53683 .3434 L p
1 g
F P
s
P
p
.002 w
.53683 .3434 m .54523 .34049 L .53643 .31587 L p
1 g
F P
s
P
p
.002 w
.61412 .46155 m .58474 .47627 L .58802 .50307 L p
1 g
F P
s
P
p
.002 w
.58474 .47627 m .61412 .46155 L .60197 .43719 L p
1 g
F P
s
P
p
.002 w
.59887 .40024 m .60506 .38403 L .57972 .37472 L p
1 g
F P
s
P
p
.002 w
.57978 .36571 m .57972 .37472 L .60506 .38403 L p
1 g
F P
s
P
p
.002 w
.50195 .30249 m .48267 .319 L .50662 .33285 L p
1 g
F P
s
P
p
.002 w
.50662 .33285 m .51978 .32178 L .50195 .30249 L p
1 g
F P
s
P
p
.002 w
.55474 .31586 m .53643 .31587 L .54523 .34049 L p
1 g
F P
s
P
p
.002 w
.54523 .34049 m .55442 .34054 L .55474 .31586 L p
1 g
F P
s
P
p
.002 w
.61892 .41855 m .60197 .43719 L .61412 .46155 L p
1 g
F P
s
P
p
.002 w
.60197 .43719 m .61892 .41855 L .59887 .40024 L p
1 g
F P
s
P
p
.002 w
.60506 .38403 m .6053 .36611 L .57978 .36571 L p
1 g
F P
s
P
p
.002 w
.57681 .35688 m .57978 .36571 L .6053 .36611 L p
1 g
F P
s
P
p
.002 w
.60506 .38403 m .59887 .40024 L .61892 .41855 L p
1 g
F P
s
P
p
.002 w
.3638 .38742 m .37463 .43811 L .39628 .42584 L p
1 g
F P
s
P
p
.002 w
.39628 .42584 m .38675 .37996 L .3638 .38742 L p
1 g
F P
s
P
p
.002 w
.3923 .33444 m .38675 .37996 L .41196 .37392 L p
1 g
F P
s
P
p
.002 w
.41196 .37392 m .41709 .33433 L .3923 .33444 L p
1 g
F P
s
P
p
.002 w
.57267 .32183 m .55474 .31586 L .55442 .34054 L p
1 g
F P
s
P
p
.002 w
.55442 .34054 m .56339 .34355 L .57267 .32183 L p
1 g
F P
s
P
p
.002 w
.6053 .36611 m .59947 .34848 L .57681 .35688 L p
1 g
F P
s
P
p
.002 w
.57114 .34921 m .57681 .35688 L .59947 .34848 L p
1 g
F P
s
P
p
.002 w
.58817 .33313 m .57267 .32183 L .56339 .34355 L p
1 g
F P
s
P
p
.002 w
.56339 .34355 m .57114 .34921 L .58817 .33313 L p
1 g
F P
s
P
p
.002 w
.59947 .34848 m .58817 .33313 L .57114 .34921 L p
1 g
F P
s
P
p
.002 w
.43535 .29929 m .41709 .33433 L .44339 .33659 L p
1 g
F P
s
P
p
.002 w
.44339 .33659 m .45875 .30772 L .43535 .29929 L p
1 g
F P
s
P
p
.002 w
.38347 .49993 m .42447 .54005 L .43867 .52168 L p
1 g
F P
s
P
p
.002 w
.43867 .52168 m .40048 .48426 L .38347 .49993 L p
1 g
F P
s
P
p
.002 w
.48561 .54696 m .43867 .52168 L .42447 .54005 L p
1 g
F P
s
P
p
.002 w
.52651 .29358 m .50195 .30249 L .51978 .32178 L p
1 g
F P
s
P
p
.002 w
.51978 .32178 m .53643 .31587 L .52651 .29358 L p
1 g
F P
s
P
p
.002 w
.58917 .52857 m .54303 .53373 L .53701 .55761 L p
1 g
F P
s
P
p
.002 w
.48561 .54696 m .53701 .55761 L .54303 .53373 L p
1 g
F P
s
P
p
.002 w
.54303 .53373 m .58917 .52857 L .58802 .50307 L p
1 g
F P
s
P
p
.002 w
.48366 .28602 m .45875 .30772 L .48267 .319 L p
1 g
F P
s
P
p
.002 w
.48267 .319 m .50195 .30249 L .48366 .28602 L p
1 g
F P
s
P
p
.002 w
.35557 .4505 m .38347 .49993 L .40048 .48426 L p
1 g
F P
s
P
p
.002 w
.40048 .48426 m .37463 .43811 L .35557 .4505 L p
1 g
F P
s
P
p
.002 w
.62364 .48559 m .58802 .50307 L .58917 .52857 L p
1 g
F P
s
P
p
.002 w
.58802 .50307 m .62364 .48559 L .61412 .46155 L p
1 g
F P
s
P
p
.002 w
.61892 .41855 m .62827 .39469 L .60506 .38403 L p
1 g
F P
s
P
p
.002 w
.6053 .36611 m .60506 .38403 L .62827 .39469 L p
1 g
F P
s
P
p
.002 w
.42447 .54005 m .47478 .56727 L .48561 .54696 L p
1 g
F P
s
P
p
.002 w
.53701 .55761 m .48561 .54696 L .47478 .56727 L p
1 g
F P
s
P
p
.002 w
.63637 .43752 m .61412 .46155 L .62364 .48559 L p
1 g
F P
s
P
p
.002 w
.61412 .46155 m .63637 .43752 L .61892 .41855 L p
1 g
F P
s
P
p
.002 w
.62827 .39469 m .61892 .41855 L .63637 .43752 L p
1 g
F P
s
P
p
.002 w
.55368 .29343 m .52651 .29358 L .53643 .31587 L p
1 g
F P
s
P
p
.002 w
.53643 .31587 m .55474 .31586 L .55368 .29343 L p
1 g
F P
s
P
p
.002 w
.62827 .39469 m .62879 .36815 L .6053 .36611 L p
1 g
F P
s
P
p
.002 w
.59947 .34848 m .6053 .36611 L .62879 .36815 L p
1 g
F P
s
P
p
.002 w
.36961 .33702 m .3638 .38742 L .38675 .37996 L p
1 g
F P
s
P
p
.002 w
.38675 .37996 m .3923 .33444 L .36961 .33702 L p
1 g
F P
s
P
p
.002 w
.3437 .39619 m .35557 .4505 L .37463 .43811 L p
1 g
F P
s
P
p
.002 w
.37463 .43811 m .3638 .38742 L .3437 .39619 L p
1 g
F P
s
P
p
.002 w
.41298 .294 m .3923 .33444 L .41709 .33433 L p
1 g
F P
s
P
p
.002 w
.41709 .33433 m .43535 .29929 L .41298 .294 L p
1 g
F P
s
P
p
.002 w
.58037 .30224 m .55368 .29343 L .55474 .31586 L p
1 g
F P
s
P
p
.002 w
.55474 .31586 m .57267 .32183 L .58037 .30224 L p
1 g
F P
s
P
p
.002 w
.51564 .27417 m .48366 .28602 L .50195 .30249 L p
1 g
F P
s
P
p
.002 w
.50195 .30249 m .52651 .29358 L .51564 .27417 L p
1 g
F P
s
P
p
.002 w
.62879 .36815 m .62023 .34192 L .59947 .34848 L p
1 g
F P
s
P
p
.002 w
.58817 .33313 m .59947 .34848 L .62023 .34192 L p
1 g
F P
s
P
p
.002 w
.46529 .2728 m .43535 .29929 L .45875 .30772 L p
1 g
F P
s
P
p
.002 w
.45875 .30772 m .48366 .28602 L .46529 .2728 L p
1 g
F P
s
P
p
.002 w
.60346 .31905 m .58037 .30224 L .57267 .32183 L p
1 g
F P
s
P
p
.002 w
.57267 .32183 m .58817 .33313 L .60346 .31905 L p
1 g
F P
s
P
p
.002 w
.62023 .34192 m .60346 .31905 L .58817 .33313 L p
1 g
F P
s
P
p
.002 w
.58807 .55222 m .53701 .55761 L .52989 .57891 L p
1 g
F P
s
P
p
.002 w
.47478 .56727 m .52989 .57891 L .53701 .55761 L p
1 g
F P
s
P
p
.002 w
.53701 .55761 m .58807 .55222 L .58917 .52857 L p
1 g
F P
s
P
p
.002 w
.63024 .50881 m .58917 .52857 L .58807 .55222 L p
1 g
F P
s
P
p
.002 w
.58917 .52857 m .63024 .50881 L .62364 .48559 L p
1 g
F P
s
P
p
.002 w
.36891 .5143 m .41177 .55619 L .42447 .54005 L p
1 g
F P
s
P
p
.002 w
.42447 .54005 m .38347 .49993 L .36891 .5143 L p
1 g
F P
s
P
p
.002 w
.47478 .56727 m .42447 .54005 L .41177 .55619 L p
1 g
F P
s
P
p
.002 w
.63637 .43752 m .6488 .40653 L .62827 .39469 L p
1 g
F P
s
P
p
.002 w
.62879 .36815 m .62827 .39469 L .6488 .40653 L p
1 g
F P
s
P
p
.002 w
.65078 .45677 m .62364 .48559 L .63024 .50881 L p
1 g
F P
s
P
p
.002 w
.62364 .48559 m .65078 .45677 L .63637 .43752 L p
1 g
F P
s
P
p
.002 w
.33965 .46276 m .36891 .5143 L .38347 .49993 L p
1 g
F P
s
P
p
.002 w
.38347 .49993 m .35557 .4505 L .33965 .46276 L p
1 g
F P
s
P
p
.002 w
.6488 .40653 m .63637 .43752 L .65078 .45677 L p
1 g
F P
s
P
p
.002 w
.41177 .55619 m .46428 .58469 L .47478 .56727 L p
1 g
F P
s
P
p
.002 w
.52989 .57891 m .47478 .56727 L .46428 .58469 L p
1 g
F P
s
P
p
.002 w
.5512 .27383 m .51564 .27417 L .52651 .29358 L p
1 g
F P
s
P
p
.002 w
.52651 .29358 m .55368 .29343 L .5512 .27383 L p
1 g
F P
s
P
p
.002 w
.34961 .34212 m .3437 .39619 L .3638 .38742 L p
1 g
F P
s
P
p
.002 w
.3638 .38742 m .36961 .33702 L .34961 .34212 L p
1 g
F P
s
P
p
.002 w
.6488 .40653 m .64967 .37185 L .62879 .36815 L p
1 g
F P
s
P
p
.002 w
.62023 .34192 m .62879 .36815 L .64967 .37185 L p
1 g
F P
s
P
p
.002 w
.3922 .29212 m .36961 .33702 L .3923 .33444 L p
1 g
F P
s
P
p
.002 w
.3923 .33444 m .41298 .294 L .3922 .29212 L p
1 g
F P
s
P
p
.002 w
.50401 .2582 m .46529 .2728 L .48366 .28602 L p
1 g
F P
s
P
p
.002 w
.48366 .28602 m .51564 .27417 L .50401 .2582 L p
1 g
F P
s
P
p
.002 w
.32702 .40614 m .33965 .46276 L .35557 .4505 L p
1 g
F P
s
P
p
.002 w
.35557 .4505 m .3437 .39619 L .32702 .40614 L p
1 g
F P
s
P
p
.002 w
.44726 .26328 m .41298 .294 L .43535 .29929 L p
1 g
F P
s
P
p
.002 w
.43535 .29929 m .46529 .2728 L .44726 .26328 L p
1 g
F P
s
P
p
.002 w
.58625 .2853 m .5512 .27383 L .55368 .29343 L p
1 g
F P
s
P
p
.002 w
.55368 .29343 m .58037 .30224 L .58625 .2853 L p
1 g
F P
s
P
p
.002 w
.64967 .37185 m .63857 .33744 L .62023 .34192 L p
1 g
F P
s
P
p
.002 w
.60346 .31905 m .62023 .34192 L .63857 .33744 L p
1 g
F P
s
P
p
.002 w
.52989 .57891 m .58468 .57341 L .58807 .55222 L p
1 g
F P
s
P
p
.002 w
.63366 .53067 m .58807 .55222 L .58468 .57341 L p
1 g
F P
s
P
p
.002 w
.58807 .55222 m .63366 .53067 L .63024 .50881 L p
1 g
F P
s
P
p
.002 w
.65078 .45677 m .66608 .41933 L .6488 .40653 L p
1 g
F P
s
P
p
.002 w
.64967 .37185 m .6488 .40653 L .66608 .41933 L p
1 g
F P
s
P
p
.002 w
.61659 .30738 m .58625 .2853 L .58037 .30224 L p
1 g
F P
s
P
p
.002 w
.58037 .30224 m .60346 .31905 L .61659 .30738 L p
1 g
F P
s
P
p
.002 w
.58468 .57341 m .52989 .57891 L .52177 .59704 L p
1 g
F P
s
P
p
.002 w
.46428 .58469 m .52177 .59704 L .52989 .57891 L p
1 g
F P
s
P
p
.002 w
.66169 .4759 m .63024 .50881 L .63366 .53067 L p
1 g
F P
s
P
p
.002 w
.63024 .50881 m .66169 .4759 L .65078 .45677 L p
1 g
F P
s
P
p
.002 w
.63857 .33744 m .61659 .30738 L .60346 .31905 L p
1 g
F P
s
P
p
.002 w
.66608 .41933 m .65078 .45677 L .66169 .4759 L p
1 g
F P
s
P
p
.002 w
.35725 .527 m .40091 .56962 L .41177 .55619 L p
1 g
F P
s
P
p
.002 w
.41177 .55619 m .36891 .5143 L .35725 .527 L p
1 g
F P
s
P
p
.002 w
.46428 .58469 m .41177 .55619 L .40091 .56962 L p
1 g
F P
s
P
p
.002 w
.32736 .47461 m .35725 .527 L .36891 .5143 L p
1 g
F P
s
P
p
.002 w
.36891 .5143 m .33965 .46276 L .32736 .47461 L p
1 g
F P
s
P
p
.002 w
.5473 .25763 m .50401 .2582 L .51564 .27417 L p
1 g
F P
s
P
p
.002 w
.51564 .27417 m .5512 .27383 L .5473 .25763 L p
1 g
F P
s
P
p
.002 w
.40091 .56962 m .45434 .59871 L .46428 .58469 L p
1 g
F P
s
P
p
.002 w
.52177 .59704 m .46428 .58469 L .45434 .59871 L p
1 g
F P
s
P
p
.002 w
.33291 .34973 m .32702 .40614 L .3437 .39619 L p
1 g
F P
s
P
p
.002 w
.3437 .39619 m .34961 .34212 L .33291 .34973 L p
1 g
F P
s
P
p
.002 w
.37356 .29384 m .34961 .34212 L .36961 .33702 L p
1 g
F P
s
P
p
.002 w
.36961 .33702 m .3922 .29212 L .37356 .29384 L p
1 g
F P
s
P
p
.002 w
.66608 .41933 m .66734 .37721 L .64967 .37185 L p
1 g
F P
s
P
p
.002 w
.63857 .33744 m .64967 .37185 L .66734 .37721 L p
1 g
F P
s
P
p
.002 w
.49187 .24622 m .44726 .26328 L .46529 .2728 L p
1 g
F P
s
P
p
.002 w
.46529 .2728 m .50401 .2582 L .49187 .24622 L p
1 g
F P
s
P
p
.002 w
.42999 .25787 m .3922 .29212 L .41298 .294 L p
1 g
F P
s
P
p
.002 w
.41298 .294 m .44726 .26328 L .42999 .25787 L p
1 g
F P
s
P
p
.002 w
.31433 .4171 m .32736 .47461 L .33965 .46276 L p
1 g
F P
s
P
p
.002 w
.33965 .46276 m .32702 .40614 L .31433 .4171 L p
1 g
F P
s
P
p
.002 w
.59008 .27155 m .5473 .25763 L .5512 .27383 L p
1 g
F P
s
P
p
.002 w
.5512 .27383 m .58625 .2853 L .59008 .27155 L p
1 g
F P
s
P
p
.002 w
.52177 .59704 m .57895 .59157 L .58468 .57341 L p
1 g
F P
s
P
p
.002 w
.63369 .5506 m .58468 .57341 L .57895 .59157 L p
1 g
F P
s
P
p
.002 w
.58468 .57341 m .63369 .5506 L .63366 .53067 L p
1 g
F P
s
P
p
.002 w
.66169 .4759 m .67958 .43285 L .66608 .41933 L p
1 g
F P
s
P
p
.002 w
.66734 .37721 m .66608 .41933 L .67958 .43285 L p
1 g
F P
s
P
p
.002 w
.66734 .37721 m .65394 .33524 L .63857 .33744 L p
1 g
F P
s
P
p
.002 w
.61659 .30738 m .63857 .33744 L .65394 .33524 L p
1 g
F P
s
P
p
.002 w
.66871 .49444 m .63366 .53067 L .63369 .5506 L p
1 g
F P
s
P
p
.002 w
.63366 .53067 m .66871 .49444 L .66169 .4759 L p
1 g
F P
s
P
p
.002 w
.67958 .43285 m .66169 .4759 L .66871 .49444 L p
1 g
F P
s
P
p
.002 w
.57895 .59157 m .52177 .59704 L .51278 .61143 L p
1 g
F P
s
P
p
.002 w
.45434 .59871 m .51278 .61143 L .52177 .59704 L p
1 g
F P
s
P
p
.002 w
.62714 .29851 m .59008 .27155 L .58625 .2853 L p
1 g
F P
s
P
p
.002 w
.58625 .2853 m .61659 .30738 L .62714 .29851 L p
1 g
F P
s
P
p
.002 w
.65394 .33524 m .62714 .29851 L .61659 .30738 L p
1 g
F P
s
P
p
.002 w
.34893 .53762 m .39226 .57989 L .40091 .56962 L p
1 g
F P
s
P
p
.002 w
.40091 .56962 m .35725 .527 L .34893 .53762 L p
1 g
F P
s
P
p
.002 w
.45434 .59871 m .40091 .56962 L .39226 .57989 L p
1 g
F P
s
P
p
.002 w
.31921 .48574 m .34893 .53762 L .35725 .527 L p
1 g
F P
s
P
p
.002 w
.35725 .527 m .32736 .47461 L .31921 .48574 L p
1 g
F P
s
P
p
.002 w
.54198 .24543 m .49187 .24622 L .50401 .2582 L p
1 g
F P
s
P
p
.002 w
.50401 .2582 m .5473 .25763 L .54198 .24543 L p
1 g
F P
s
P
p
.002 w
.39226 .57989 m .44523 .60879 L .45434 .59871 L p
1 g
F P
s
P
p
.002 w
.51278 .61143 m .45434 .59871 L .44523 .60879 L p
1 g
F P
s
P
p
.002 w
.35766 .29932 m .33291 .34973 L .34961 .34212 L p
1 g
F P
s
P
p
.002 w
.34961 .34212 m .37356 .29384 L .35766 .29932 L p
1 g
F P
s
P
p
.002 w
.3201 .35981 m .31433 .4171 L .32702 .40614 L p
1 g
F P
s
P
p
.002 w
.32702 .40614 m .33291 .34973 L .3201 .35981 L p
1 g
F P
s
P
p
.002 w
.47948 .23876 m .42999 .25787 L .44726 .26328 L p
1 g
F P
s
P
p
.002 w
.44726 .26328 m .49187 .24622 L .47948 .23876 L p
1 g
F P
s
P
p
.002 w
.41398 .25693 m .37356 .29384 L .3922 .29212 L p
1 g
F P
s
P
p
.002 w
.3922 .29212 m .42999 .25787 L .41398 .25693 L p
1 g
F P
s
P
p
.002 w
.67958 .43285 m .68123 .38418 L .66734 .37721 L p
1 g
F P
s
P
p
.002 w
.65394 .33524 m .66734 .37721 L .68123 .38418 L p
1 g
F P
s
P
p
.002 w
.30617 .42884 m .31921 .48574 L .32736 .47461 L p
1 g
F P
s
P
p
.002 w
.32736 .47461 m .31433 .4171 L .30617 .42884 L p
1 g
F P
s
P
p
.002 w
.59164 .26152 m .54198 .24543 L .5473 .25763 L p
1 g
F P
s
P
p
.002 w
.5473 .25763 m .59008 .27155 L .59164 .26152 L p
1 g
F P
s
P
p
.002 w
.51278 .61143 m .5709 .60608 L .57895 .59157 L p
1 g
F P
s
P
p
.002 w
.63015 .56802 m .57895 .59157 L .5709 .60608 L p
1 g
F P
s
P
p
.002 w
.57895 .59157 m .63015 .56802 L .63369 .5506 L p
1 g
F P
s
P
p
.002 w
.66871 .49444 m .68878 .44679 L .67958 .43285 L p
1 g
F P
s
P
p
.002 w
.68123 .38418 m .67958 .43285 L .68878 .44679 L p
1 g
F P
s
P
p
.002 w
.67147 .51194 m .63369 .5506 L .63015 .56802 L p
1 g
F P
s
P
p
.002 w
.63369 .5506 m .67147 .51194 L .66871 .49444 L p
1 g
F P
s
P
p
.002 w
.68878 .44679 m .66871 .49444 L .67147 .51194 L p
1 g
F P
s
P
p
.002 w
.68123 .38418 m .66579 .33551 L .65394 .33524 L p
1 g
F P
s
P
p
.002 w
.62714 .29851 m .65394 .33524 L .66579 .33551 L p
1 g
F P
s
P
p
.002 w
.44523 .60879 m .50311 .62152 L .51278 .61143 L p
1 g
F P
s
P
p
.002 w
.5709 .60608 m .51278 .61143 L .50311 .62152 L p
1 g
F P
s
P
p
.002 w
.63471 .29283 m .59164 .26152 L .59008 .27155 L p
1 g
F P
s
P
p
.002 w
.59008 .27155 m .62714 .29851 L .63471 .29283 L p
1 g
F P
s
P
p
.002 w
.66579 .33551 m .63471 .29283 L .62714 .29851 L p
1 g
F P
s
P
p
.002 w
.34435 .54579 m .38616 .58656 L .39226 .57989 L p
1 g
F P
s
P
p
.002 w
.39226 .57989 m .34893 .53762 L .34435 .54579 L p
1 g
F P
s
P
p
.002 w
.44523 .60879 m .39226 .57989 L .38616 .58656 L p
1 g
F P
s
P
p
.002 w
.53528 .23778 m .47948 .23876 L .49187 .24622 L p
1 g
F P
s
P
p
.002 w
.49187 .24622 m .54198 .24543 L .53528 .23778 L p
1 g
F P
s
P
p
.002 w
.31565 .49582 m .34435 .54579 L .34893 .53762 L p
1 g
F P
s
P
p
.002 w
.34893 .53762 m .31921 .48574 L .31565 .49582 L p
1 g
F P
s
P
p
.002 w
.34508 .30863 m .3201 .35981 L .33291 .34973 L p
1 g
F P
s
P
p
.002 w
.33291 .34973 m .35766 .29932 L .34508 .30863 L p
1 g
F P
s
P
p
.002 w
.31175 .37224 m .30617 .42884 L .31433 .4171 L p
1 g
F P
s
P
p
.002 w
.31433 .4171 m .3201 .35981 L .31175 .37224 L p
1 g
F P
s
P
p
.002 w
.39971 .26074 m .35766 .29932 L .37356 .29384 L p
1 g
F P
s
P
p
.002 w
.37356 .29384 m .41398 .25693 L .39971 .26074 L p
1 g
F P
s
P
p
.002 w
.46715 .23627 m .41398 .25693 L .42999 .25787 L p
1 g
F P
s
P
p
.002 w
.42999 .25787 m .47948 .23876 L .46715 .23627 L p
1 g
F P
s
P
p
.002 w
.38616 .58656 m .43722 .61447 L .44523 .60879 L p
1 g
F P
s
P
p
.002 w
.50311 .62152 m .44523 .60879 L .43722 .61447 L p
1 g
F P
s
P
p
.002 w
.68878 .44679 m .69074 .39268 L .68123 .38418 L p
1 g
F P
s
P
p
.002 w
.66579 .33551 m .68123 .38418 L .69074 .39268 L p
1 g
F P
s
P
p
.002 w
.30304 .44111 m .31565 .49582 L .31921 .48574 L p
1 g
F P
s
P
p
.002 w
.31921 .48574 m .30617 .42884 L .30304 .44111 L p
1 g
F P
s
P
p
.002 w
.5709 .60608 m .62292 .58236 L .63015 .56802 L p
1 g
F P
s
P
p
.002 w
.66966 .52788 m .63015 .56802 L .62292 .58236 L p
1 g
F P
s
P
p
.002 w
.63015 .56802 m .66966 .52788 L .67147 .51194 L p
1 g
F P
s
P
p
.002 w
.50311 .62152 m .56061 .61637 L .5709 .60608 L p
1 g
F P
s
P
p
.002 w
.62292 .58236 m .5709 .60608 L .56061 .61637 L p
1 g
F P
s
P
p
.002 w
.67147 .51194 m .69318 .46084 L .68878 .44679 L p
1 g
F P
s
P
p
.002 w
.69074 .39268 m .68878 .44679 L .69318 .46084 L p
1 g
F P
s
P
p
.002 w
.59075 .25571 m .53528 .23778 L .54198 .24543 L p
1 g
F P
s
P
p
.002 w
.54198 .24543 m .59164 .26152 L .59075 .25571 L p
1 g
F P
s
P
p
.002 w
.69318 .46084 m .67147 .51194 L .66966 .52788 L p
1 g
F P
s
P
p
.002 w
.43722 .61447 m .49295 .62679 L .50311 .62152 L p
1 g
F P
s
P
p
.002 w
.56061 .61637 m .50311 .62152 L .49295 .62679 L p
1 g
F P
s
P
p
.002 w
.69074 .39268 m .6736 .3384 L .66579 .33551 L p
1 g
F P
s
P
p
.002 w
.63471 .29283 m .66579 .33551 L .6736 .3384 L p
1 g
F P
s
P
p
.002 w
.63889 .2907 m .59075 .25571 L .59164 .26152 L p
1 g
F P
s
P
p
.002 w
.59164 .26152 m .63471 .29283 L .63889 .2907 L p
1 g
F P
s
P
p
.002 w
.6736 .3384 m .63889 .2907 L .63471 .29283 L p
1 g
F P
s
P
p
.002 w
.52732 .23518 m .46715 .23627 L .47948 .23876 L p
1 g
F P
s
P
p
.002 w
.47948 .23876 m .53528 .23778 L .52732 .23518 L p
1 g
F P
s
P
p
.002 w
.34387 .55113 m .38294 .58921 L .38616 .58656 L p
1 g
F P
s
P
p
.002 w
.38616 .58656 m .34435 .54579 L .34387 .55113 L p
1 g
F P
s
P
p
.002 w
.43722 .61447 m .38616 .58656 L .38294 .58921 L p
1 g
F P
s
P
p
.002 w
.33635 .32173 m .31175 .37224 L .3201 .35981 L p
1 g
F P
s
P
p
.002 w
.3201 .35981 m .34508 .30863 L .33635 .32173 L p
1 g
F P
s
P
p
.002 w
.38769 .26948 m .34508 .30863 L .35766 .29932 L p
1 g
F P
s
P
p
.002 w
.35766 .29932 m .39971 .26074 L .38769 .26948 L p
1 g
F P
s
P
p
.002 w
.31707 .50452 m .34387 .55113 L .34435 .54579 L p
1 g
F P
s
P
p
.002 w
.34435 .54579 m .31565 .49582 L .31707 .50452 L p
1 g
F P
s
P
p
.002 w
.45523 .23913 m .39971 .26074 L .41398 .25693 L p
1 g
F P
s
P
p
.002 w
.41398 .25693 m .46715 .23627 L .45523 .23913 L p
1 g
F P
s
P
p
.002 w
.30836 .38679 m .30304 .44111 L .30617 .42884 L p
1 g
F P
s
P
p
.002 w
.30617 .42884 m .31175 .37224 L .30836 .38679 L p
1 g
F P
s
P
p
.002 w
.38294 .58921 m .43061 .61528 L .43722 .61447 L p
1 g
F P
s
P
p
.002 w
.49295 .62679 m .43722 .61447 L .43061 .61528 L p
1 g
F P
s
P
p
.002 w
.69318 .46084 m .69538 .40259 L .69074 .39268 L p
1 g
F P
s
P
p
.002 w
.6736 .3384 m .69074 .39268 L .69538 .40259 L p
1 g
F P
s
P
p
.002 w
.56061 .61637 m .612 .59304 L .62292 .58236 L p
1 g
F P
s
P
p
.002 w
.62292 .58236 m .66306 .54173 L .66966 .52788 L p
1 g
F P
s
P
p
.002 w
.66306 .54173 m .62292 .58236 L .612 .59304 L p
1 g
F P
s
P
p
.002 w
.49295 .62679 m .54821 .62191 L .56061 .61637 L p
1 g
F P
s
P
p
.002 w
.612 .59304 m .56061 .61637 L .54821 .62191 L p
1 g
F P
s
P
p
.002 w
.66966 .52788 m .69238 .4746 L .69318 .46084 L p
1 g
F P
s
P
p
.002 w
.69538 .40259 m .69318 .46084 L .69238 .4746 L p
1 g
F P
s
P
p
.002 w
.30533 .45358 m .31707 .50452 L .31565 .49582 L p
1 g
F P
s
P
p
.002 w
.31565 .49582 m .30304 .44111 L .30533 .45358 L p
1 g
F P
s
P
p
.002 w
.69238 .4746 m .66966 .52788 L .66306 .54173 L p
1 g
F P
s
P
p
.004 w
.36615 .69795 m
.4058 .61873 L
s
P
p
.002 w
.58727 .25456 m .52732 .23518 L .53528 .23778 L p
1 g
F P
s
P
p
.002 w
.53528 .23778 m .59075 .25571 L .58727 .25456 L p
1 g
F P
s
P
p
.002 w
.43061 .61528 m .48257 .6268 L .49295 .62679 L p
1 g
F P
s
P
p
.002 w
.54821 .62191 m .49295 .62679 L .48257 .6268 L p
1 g
F P
s
P
p
.002 w
.69538 .40259 m .67688 .34399 L .6736 .3384 L p
1 g
F P
s
P
p
.002 w
.63889 .2907 m .6736 .3384 L .67688 .34399 L p
1 g
F P
s
P
p
.002 w
.63935 .29241 m .58727 .25456 L .59075 .25571 L p
1 g
F P
s
P
p
.002 w
.59075 .25571 m .63889 .2907 L .63935 .29241 L p
1 g
F P
s
P
p
.002 w
.51824 .23803 m .45523 .23913 L .46715 .23627 L p
1 g
F P
s
P
p
.002 w
.46715 .23627 m .52732 .23518 L .51824 .23803 L p
1 g
F P
s
P
p
.002 w
.33197 .33845 m .30836 .38679 L .31175 .37224 L p
1 g
F P
s
P
p
.002 w
.31175 .37224 m .33635 .32173 L .33197 .33845 L p
1 g
F P
s
P
p
.002 w
.67688 .34399 m .63935 .29241 L .63889 .2907 L p
1 g
F P
s
P
p
.002 w
.37842 .28318 m .33635 .32173 L .34508 .30863 L p
1 g
F P
s
P
p
.002 w
.34508 .30863 m .38769 .26948 L .37842 .28318 L p
1 g
F P
s
P
p
.002 w
.44411 .2476 m .38769 .26948 L .39971 .26074 L p
1 g
F P
s
P
p
.002 w
.39971 .26074 m .45523 .23913 L .44411 .2476 L p
1 g
F P
s
P
p
.002 w
.34779 .5533 m .38287 .5875 L .38294 .58921 L p
1 g
F P
s
P
p
.002 w
.38294 .58921 m .34387 .55113 L .34779 .5533 L p
1 g
F P
s
P
p
.002 w
.43061 .61528 m .38294 .58921 L .38287 .5875 L p
1 g
F P
s
P
p
.002 w
.31032 .40316 m .30533 .45358 L .30304 .44111 L p
1 g
F P
s
P
p
.002 w
.30304 .44111 m .30836 .38679 L .31032 .40316 L p
1 g
F P
s
P
p
.002 w
.32376 .51148 m .34779 .5533 L .34387 .55113 L p
1 g
F P
s
P
p
.002 w
.34387 .55113 m .31707 .50452 L .32376 .51148 L p
1 g
F P
s
P
p
.002 w
.69238 .4746 m .69468 .4137 L .69538 .40259 L p
1 g
F P
s
P
p
.002 w
.67688 .34399 m .69538 .40259 L .69468 .4137 L p
1 g
F P
s
P
p
.002 w
.38287 .5875 m .42568 .61091 L .43061 .61528 L p
1 g
F P
s
P
p
.004 w
.41314 .60405 m
.5 .43051 L
s
P
p
.004 w
.41201 .60632 m
.41266 .60503 L
s
P
p
.004 w
.4058 .61873 m
.41201 .60632 L
s
P
p
.002 w
.48257 .6268 m .43061 .61528 L .42568 .61091 L p
1 g
F P
s
P
p
.002 w
.54821 .62191 m .59748 .59955 L .612 .59304 L p
1 g
F P
s
P
p
.002 w
.65157 .55297 m .612 .59304 L .59748 .59955 L p
1 g
F P
s
P
p
.002 w
.612 .59304 m .65157 .55297 L .66306 .54173 L p
1 g
F P
s
P
p
.002 w
.48257 .6268 m .53395 .62224 L .54821 .62191 L p
1 g
F P
s
P
p
.002 w
.59748 .59955 m .54821 .62191 L .53395 .62224 L p
1 g
F P
s
P
p
.002 w
.6861 .48767 m .66306 .54173 L .65157 .55297 L p
1 g
F P
s
P
p
.002 w
.66306 .54173 m .6861 .48767 L .69238 .4746 L p
1 g
F P
s
P
p
.002 w
.69468 .4137 m .69238 .4746 L .6861 .48767 L p
1 g
F P
s
P
p
.002 w
.3133 .4659 m .32376 .51148 L .31707 .50452 L p
1 g
F P
s
P
p
.002 w
.31707 .50452 m .30533 .45358 L .3133 .4659 L p
1 g
F P
s
P
p
.002 w
.58112 .25841 m .51824 .23803 L .52732 .23518 L p
1 g
F P
s
P
p
.002 w
.52732 .23518 m .58727 .25456 L .58112 .25841 L p
1 g
F P
s
P
p
.002 w
.53395 .62224 m .48257 .6268 L .47224 .6212 L p
1 g
F P
s
P
p
.002 w
.42568 .61091 m .47224 .6212 L .48257 .6268 L p
1 g
F P
s
P
p
.002 w
.69468 .4137 m .67525 .3523 L .67688 .34399 L p
1 g
F P
s
P
p
.002 w
.63935 .29241 m .67688 .34399 L .67525 .3523 L p
1 g
F P
s
P
p
.002 w
.33233 .35848 m .31032 .40316 L .30836 .38679 L p
1 g
F P
s
P
p
.002 w
.30836 .38679 m .33197 .33845 L .33233 .35848 L p
1 g
F P
s
P
p
.002 w
.50824 .24659 m .44411 .2476 L .45523 .23913 L p
1 g
F P
s
P
p
.002 w
.45523 .23913 m .51824 .23803 L .50824 .24659 L p
1 g
F P
s
P
p
.002 w
.37235 .3017 m .33197 .33845 L .33635 .32173 L p
1 g
F P
s
P
p
.002 w
.33635 .32173 m .37842 .28318 L .37235 .3017 L p
1 g
F P
s
P
p
.002 w
.63581 .29817 m .58112 .25841 L .58727 .25456 L p
1 g
F P
s
P
p
.002 w
.58727 .25456 m .63935 .29241 L .63581 .29817 L p
1 g
F P
s
P
p
.002 w
.43418 .26175 m .37842 .28318 L .38769 .26948 L p
1 g
F P
s
P
p
.002 w
.38769 .26948 m .44411 .2476 L .43418 .26175 L p
1 g
F P
s
P
p
.002 w
.67525 .3523 m .63581 .29817 L .63935 .29241 L p
1 g
F P
s
P
p
.002 w
.31789 .42096 m .3133 .4659 L .30533 .45358 L p
1 g
F P
s
P
p
.002 w
.30533 .45358 m .31032 .40316 L .31789 .42096 L p
1 g
F P
s
P
p
.002 w
.35626 .55202 m .38617 .58119 L .38287 .5875 L p
1 g
F P
s
P
p
.002 w
.38287 .5875 m .34779 .5533 L .35626 .55202 L p
1 g
F P
s
P
p
.002 w
.42568 .61091 m .38287 .5875 L .38617 .58119 L p
1 g
F P
s
P
p
.002 w
.33584 .51639 m .35626 .55202 L .34779 .5533 L p
1 g
F P
s
P
p
.002 w
.34779 .5533 m .32376 .51148 L .33584 .51639 L p
1 g
F P
s
P
p
.002 w
.6861 .48767 m .68833 .42576 L .69468 .4137 L p
1 g
F P
s
P
p
.002 w
.67525 .3523 m .69468 .4137 L .68833 .42576 L p
1 g
F P
s
P
p
.002 w
.53395 .62224 m .57959 .60142 L .59748 .59955 L p
1 g
F P
s
P
p
.002 w
.63527 .56111 m .59748 .59955 L .57959 .60142 L p
1 g
F P
s
P
p
.002 w
.59748 .59955 m .63527 .56111 L .65157 .55297 L p
1 g
F P
s
P
p
.002 w
.38617 .58119 m .42268 .60112 L .42568 .61091 L p
1 g
F P
s
P
p
.002 w
.47224 .6212 m .42568 .61091 L .42268 .60112 L p
1 g
F P
s
P
p
.002 w
.67419 .4996 m .65157 .55297 L .63527 .56111 L p
1 g
F P
s
P
p
.002 w
.65157 .55297 m .67419 .4996 L .6861 .48767 L p
1 g
F P
s
P
p
.002 w
.47224 .6212 m .51814 .61705 L .53395 .62224 L p
1 g
F P
s
P
p
.002 w
.57959 .60142 m .53395 .62224 L .51814 .61705 L p
1 g
F P
s
P
p
.002 w
.68833 .42576 m .6861 .48767 L .67419 .4996 L p
1 g
F P
s
P
p
.002 w
.32706 .47766 m .33584 .51639 L .32376 .51148 L p
1 g
F P
s
P
p
.002 w
.32376 .51148 m .3133 .4659 L .32706 .47766 L p
1 g
F P
s
P
p
.002 w
.57233 .26746 m .50824 .24659 L .51824 .23803 L p
1 g
F P
s
P
p
.002 w
.51824 .23803 m .58112 .25841 L .57233 .26746 L p
1 g
F P
s
P
p
.002 w
.51814 .61705 m .47224 .6212 L .4623 .60982 L p
1 g
F P
s
P
p
.002 w
.42268 .60112 m .4623 .60982 L .47224 .6212 L p
1 g
F P
s
P
p
.002 w
.68833 .42576 m .66843 .36325 L .67525 .3523 L p
1 g
F P
s
P
p
.002 w
.63581 .29817 m .67525 .3523 L .66843 .36325 L p
1 g
F P
s
P
p
.002 w
.33766 .38134 m .31789 .42096 L .31032 .40316 L p
1 g
F P
s
P
p
.002 w
.31032 .40316 m .33233 .35848 L .33766 .38134 L p
1 g
F P
s
P
p
.002 w
.36986 .3247 m .33233 .35848 L .33197 .33845 L p
1 g
F P
s
P
p
.002 w
.33197 .33845 m .37235 .3017 L .36986 .3247 L p
1 g
F P
s
P
p
.002 w
.4976 .26095 m .43418 .26175 L .44411 .2476 L p
1 g
F P
s
P
p
.002 w
.44411 .2476 m .50824 .24659 L .4976 .26095 L p
1 g
F P
s
P
p
.002 w
.42584 .28143 m .37235 .3017 L .37842 .28318 L p
1 g
F P
s
P
p
.002 w
.37842 .28318 m .43418 .26175 L .42584 .28143 L p
1 g
F P
s
P
p
.002 w
.62814 .30807 m .57233 .26746 L .58112 .25841 L p
1 g
F P
s
P
p
.002 w
.58112 .25841 m .63581 .29817 L .62814 .30807 L p
1 g
F P
s
P
p
.002 w
.33112 .43966 m .32706 .47766 L .3133 .4659 L p
1 g
F P
s
P
p
.002 w
.3133 .4659 m .31789 .42096 L .33112 .43966 L p
1 g
F P
s
P
p
.002 w
.66843 .36325 m .62814 .30807 L .63581 .29817 L p
1 g
F P
s
P
p
.002 w
.36933 .54711 m .39297 .57018 L .38617 .58119 L p
1 g
F P
s
P
p
.002 w
.38617 .58119 m .35626 .55202 L .36933 .54711 L p
1 g
F P
s
P
p
.002 w
.42268 .60112 m .38617 .58119 L .39297 .57018 L p
1 g
F P
s
P
p
.002 w
.51814 .61705 m .55871 .59835 L .57959 .60142 L p
1 g
F P
s
P
p
.002 w
.61441 .56571 m .57959 .60142 L .55871 .59835 L p
1 g
F P
s
P
p
.002 w
.57959 .60142 m .61441 .56571 L .63527 .56111 L p
1 g
F P
s
P
p
.002 w
.67419 .4996 m .6762 .43844 L .68833 .42576 L p
1 g
F P
s
P
p
.002 w
.66843 .36325 m .68833 .42576 L .6762 .43844 L p
1 g
F P
s
P
p
.002 w
.35326 .51895 m .36933 .54711 L .35626 .55202 L p
1 g
F P
s
P
p
.002 w
.35626 .55202 m .33584 .51639 L .35326 .51895 L p
1 g
F P
s
P
p
.002 w
.65671 .50995 m .63527 .56111 L .61441 .56571 L p
1 g
F P
s
P
p
.002 w
.63527 .56111 m .65671 .50995 L .67419 .4996 L p
1 g
F P
s
P
p
.002 w
.4623 .60982 m .5012 .60617 L .51814 .61705 L p
1 g
F P
s
P
p
.002 w
.55871 .59835 m .51814 .61705 L .5012 .60617 L p
1 g
F P
s
P
p
.002 w
.6762 .43844 m .67419 .4996 L .65671 .50995 L p
1 g
F P
s
P
p
.002 w
.39297 .57018 m .42183 .58591 L .42268 .60112 L p
1 g
F P
s
P
p
.002 w
.4623 .60982 m .42268 .60112 L .42183 .58591 L p
1 g
F P
s
P
p
.002 w
.34646 .48845 m .35326 .51895 L .33584 .51639 L p
1 g
F P
s
P
p
.002 w
.33584 .51639 m .32706 .47766 L .34646 .48845 L p
1 g
F P
s
P
p
.002 w
.56104 .28176 m .4976 .26095 L .50824 .24659 L p
1 g
F P
s
P
p
.002 w
.50824 .24659 m .57233 .26746 L .56104 .28176 L p
1 g
F P
s
P
p
.002 w
.42183 .58591 m .4531 .59268 L .4623 .60982 L p
1 g
F P
s
P
p
.002 w
.5012 .60617 m .4623 .60982 L .4531 .59268 L p
1 g
F P
s
P
p
.002 w
.37121 .35159 m .33766 .38134 L .33233 .35848 L p
1 g
F P
s
P
p
.002 w
.33233 .35848 m .36986 .3247 L .37121 .35159 L p
1 g
F P
s
P
p
.002 w
.34804 .40637 m .33112 .43966 L .31789 .42096 L p
1 g
F P
s
P
p
.002 w
.31789 .42096 m .33766 .38134 L .34804 .40637 L p
1 g
F P
s
P
p
.002 w
.6762 .43844 m .65633 .37663 L .66843 .36325 L p
1 g
F P
s
P
p
.002 w
.62814 .30807 m .66843 .36325 L .65633 .37663 L p
1 g
F P
s
P
p
.002 w
.41946 .30626 m .36986 .3247 L .37235 .3017 L p
1 g
F P
s
P
p
.002 w
.37235 .3017 m .42584 .28143 L .41946 .30626 L p
1 g
F P
s
P
p
.002 w
.48665 .28094 m .42584 .28143 L .43418 .26175 L p
1 g
F P
s
P
p
.002 w
.43418 .26175 m .4976 .26095 L .48665 .28094 L p
1 g
F P
s
P
p
.002 w
.34984 .45868 m .34646 .48845 L .32706 .47766 L p
1 g
F P
s
P
p
.002 w
.32706 .47766 m .33112 .43966 L .34984 .45868 L p
1 g
F P
s
P
p
.002 w
.61633 .32202 m .56104 .28176 L .57233 .26746 L p
1 g
F P
s
P
p
.002 w
.57233 .26746 m .62814 .30807 L .61633 .32202 L p
1 g
F P
s
P
p
.002 w
.5012 .60617 m .53539 .59018 L .55871 .59835 L p
1 g
F P
s
P
p
.002 w
.58944 .56643 m .55871 .59835 L .53539 .59018 L p
1 g
F P
s
P
p
.002 w
.55871 .59835 m .58944 .56643 L .61441 .56571 L p
1 g
F P
s
P
p
.002 w
.65633 .37663 m .61633 .32202 L .62814 .30807 L p
1 g
F P
s
P
p
.002 w
.63395 .51828 m .61441 .56571 L .58944 .56643 L p
1 g
F P
s
P
p
.002 w
.61441 .56571 m .63395 .51828 L .65671 .50995 L p
1 g
F P
s
P
p
.002 w
.65671 .50995 m .65836 .45134 L .6762 .43844 L p
1 g
F P
s
P
p
.002 w
.65633 .37663 m .6762 .43844 L .65836 .45134 L p
1 g
F P
s
P
p
.002 w
.38682 .53851 m .40324 .55455 L .39297 .57018 L p
1 g
F P
s
P
p
.002 w
.39297 .57018 m .36933 .54711 L .38682 .53851 L p
1 g
F P
s
P
p
.002 w
.42183 .58591 m .39297 .57018 L .40324 .55455 L p
1 g
F P
s
P
p
.002 w
.65836 .45134 m .65671 .50995 L .63395 .51828 L p
1 g
F P
s
P
p
.002 w
.4531 .59268 m .48365 .58967 L .5012 .60617 L p
1 g
F P
s
P
p
.002 w
.53539 .59018 m .5012 .60617 L .48365 .58967 L p
1 g
F P
s
P
p
.002 w
.37572 .51894 m .38682 .53851 L .36933 .54711 L p
1 g
F P
s
P
p
.002 w
.36933 .54711 m .35326 .51895 L .37572 .51894 L p
1 g
F P
s
P
p
.002 w
.40324 .55455 m .4233 .56545 L .42183 .58591 L p
1 g
F P
s
P
p
.002 w
.4531 .59268 m .42183 .58591 L .4233 .56545 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37113 .49783 m .37572 .51894 L .35326 .51895 L p
1 g
F P
s
P
p
.002 w
.35326 .51895 m .34646 .48845 L .37113 .49783 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.37652 .3816 m .34804 .40637 L .33766 .38134 L p
1 g
F P
s
P
p
.002 w
.33766 .38134 m .37121 .35159 L .37652 .3816 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54748 .30108 m .48665 .28094 L .4976 .26095 L p
1 g
F P
s
P
p
.002 w
.4976 .26095 m .56104 .28176 L .54748 .30108 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.36331 .43279 m .34984 .45868 L .33112 .43966 L p
1 g
F P
s
P
p
.002 w
.33112 .43966 m .34804 .40637 L .36331 .43279 L p
1 g
F P
s
P
p
.002 w
.48365 .58967 m .4531 .59268 L .44498 .57006 L p
1 g
F P
s
P
p
.002 w
.4233 .56545 m .44498 .57006 L .4531 .59268 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.41536 .33558 m .37121 .35159 L .36986 .3247 L p
1 g
F P
s
P
p
.002 w
.36986 .3247 m .41946 .30626 L .41536 .33558 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47577 .30612 m .41946 .30626 L .42584 .28143 L p
1 g
F P
s
P
p
.002 w
.42584 .28143 m .48665 .28094 L .47577 .30612 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.65836 .45134 m .63906 .39213 L .65633 .37663 L p
1 g
F P
s
P
p
.002 w
.61633 .32202 m .65633 .37663 L .63906 .39213 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.37362 .47734 m .37113 .49783 L .34646 .48845 L p
1 g
F P
s
P
p
.002 w
.34646 .48845 m .34984 .45868 L .37362 .47734 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.48365 .58967 m .50179 .58101 L p
.53539 .59018 L 1 g
F P
s
P
p
.002 w
.51704 .58049 m .53539 .59018 L p
.50525 .58195 L 1 g
F P
s
P
p
.50525 .58195 m .50179 .58101 L .51094 .5807 L 1 g
F
P
p
.50525 .58195 m .51094 .5807 L .51704 .58049 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .5807 L p
1 g
F P
s
P
p
.53128 .57265 m .51094 .5807 L .51552 .57969 L 1 g
F
P
p
.002 w
.56032 .56384 m .53539 .59018 L .51933 .5817 L p
1 g
F P
s
P
p
.002 w
.51933 .5817 m .51552 .57969 L p
.53158 .57401 L 1 g
F P
s
P
p
.56032 .56384 m .51933 .5817 L .53158 .57401 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53158 .57401 L p
1 g
F P
s
P
p
.54854 .56129 m .53158 .57401 L .54217 .56737 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.56106 .56307 m .56032 .56384 L p
.5388 .56948 L 1 g
F P
s
P
p
.53972 .5689 m .5388 .56948 L .51031 .57694 L 1 g
F
P
p
.56106 .56307 m .5388 .56948 L .53972 .5689 L 1 g
F
P
p
.53128 .57265 m .51552 .57969 L .52206 .57738 L 1 g
F
P
p
.002 w
.51094 .5807 m .51079 .57862 L p
.49938 .5809 L 1 g
F P
s
P
p
.002 w
.48365 .58967 m .47572 .57984 L p
.48907 .58044 L 1 g
F P
s
P
p
.002 w
.50179 .58101 m .49802 .58281 L p
.48907 .58044 L 1 g
F P
s
P
p
.002 w
.49802 .58281 m .48365 .58967 L p
.48907 .58044 L 1 g
F P
s
P
p
.002 w
.48907 .58044 m .48921 .57862 L p
.47908 .57779 L 1 g
F P
s
P
p
.49938 .5809 m .50179 .58101 L .51094 .5807 L 1 g
F
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4683 .57459 L p
1 g
F P
s
P
p
.48365 .58967 m .45264 .56926 L .4683 .57459 L 1 g
F
P
p
.002 w
.47271 .5761 m .47443 .57822 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.47443 .57822 m .48365 .58967 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.4683 .57459 m .46872 .57265 L p
.45774 .56827 L 1 g
F P
s
P
p
.002 w
.44498 .57006 m .44166 .55635 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.45828 .56866 m .45547 .56896 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.45547 .56896 m .44498 .57006 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.44446 .5552 L 1 g
F P
s
P
p
.45774 .56827 m .45828 .56866 L .4683 .57459 L 1 g
F
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45044 .56402 L p
1 g
F P
s
P
p
.46872 .57265 m .45044 .56402 L .45733 .5681 L 1 g
F
P
p
.48921 .57862 m .4683 .57459 L .4703 .57528 L 1 g
F
P
p
.48921 .57862 m .46823 .57491 L .47908 .57779 L 1 g
F
P
p
.002 w
.46606 .56785 m .47271 .5761 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.45264 .56926 m .45828 .56866 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.45828 .56866 m .46606 .56785 L p
.4683 .57459 L 1 g
F P
s
P
p
.002 w
.45044 .56402 m .45002 .56518 L p
.45733 .5681 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43831 .54743 L p
1 g
F P
s
P
p
.44498 .57006 m .43385 .54157 L .43831 .54743 L 1 g
F
P
p
.002 w
.44005 .5497 m .44157 .55596 L p
.43831 .54743 L 1 g
F P
s
P
p
.002 w
.44157 .55596 m .44498 .57006 L p
.43831 .54743 L 1 g
F P
s
P
p
.002 w
.43831 .54743 m .43925 .54566 L p
.43483 .53691 L 1 g
F P
s
P
p
.002 w
.42716 .54018 m .43085 .52273 L p
.43252 .5287 L 1 g
F P
s
P
p
.002 w
.43628 .54208 m .4318 .54115 L p
.43252 .5287 L 1 g
F P
s
P
p
.002 w
.4318 .54115 m .42716 .54018 L p
.43252 .5287 L 1 g
F P
s
P
p
.002 w
.43252 .5287 m .43346 .52734 L p
.43314 .51812 L 1 g
F P
s
P
p
.43483 .53691 m .43628 .54208 L .43831 .54743 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43166 .52996 L p
1 g
F P
s
P
p
.43925 .54566 m .43166 .52996 L .43271 .53272 L 1 g
F
P
p
.45146 .56129 m .43831 .54743 L .43869 .54792 L 1 g
F
P
p
.45146 .56129 m .43828 .54749 L .44446 .5552 L 1 g
F
P
p
.002 w
.43831 .5425 m .44005 .5497 L p
.43831 .54743 L 1 g
F P
s
P
p
.002 w
.43385 .54157 m .43628 .54208 L p
.43831 .54743 L 1 g
F P
s
P
p
.002 w
.43628 .54208 m .43831 .5425 L p
.43831 .54743 L 1 g
F P
s
P
p
.002 w
.43166 .52996 m .43146 .53025 L p
.43271 .53272 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43085 .52273 m .43337 .51082 L p
.43349 .51209 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4337 .50963 L p
1 g
F P
s
P
p
.002 w
.43363 .51026 m .43337 .51082 L p
.43345 .51014 L 1 g
F P
s
P
p
.43744 .47724 m .4337 .50963 L .43345 .51014 L 1 g
F
P
p
.4337 .50963 m .43363 .51026 L .43345 .51014 L 1 g
F
P
p
.002 w
.43337 .51082 m .43612 .47676 L .43744 .47724 L p
1 g
F P
s
P
p
.002 w
.4337 .50963 m .43485 .50826 L p
.43843 .49988 L 1 g
F P
s
P
p
.43843 .49988 m .43832 .50012 L .4337 .50963 L 1 g
F
P
p
.43346 .52734 m .4337 .50963 L .4337 .50964 L 1 g
F
P
p
.43346 .52734 m .4337 .50963 L .43369 .50969 L 1 g
F
P
p
.43346 .52734 m .4337 .50963 L .43369 .50973 L 1 g
F
P
p
.43346 .52734 m .43369 .50965 L .43367 .50978 L 1 g
F
P
p
.43346 .52734 m .43367 .50966 L .43366 .50982 L 1 g
F
P
p
.43346 .52734 m .43366 .50967 L .43365 .50985 L 1 g
F
P
p
.43346 .52734 m .43365 .50969 L .43364 .50986 L 1 g
F
P
p
.43346 .52734 m .43364 .5097 L .43363 .50984 L 1 g
F
P
p
.43346 .52734 m .43363 .50971 L .43363 .5098 L 1 g
F
P
p
.43346 .52734 m .43363 .50972 L .43314 .51812 L 1 g
F
P
p
.002 w
.43363 .51026 m .43832 .50012 L p
.43359 .51061 L 1 g
F P
s
P
p
.002 w
.43832 .50012 m .44219 .49174 L p
.43971 .49726 L 1 g
F P
s
P
p
.44227 .49166 m .43971 .49726 L .44219 .49174 L 1 g
F
P
p
.002 w
.44726 .48077 m .4476 .48101 L p
.43971 .49726 L 1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.44219 .49174 m .43832 .50012 L p
.43814 .49565 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44256 .49138 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .44166 .49233 L p
.43843 .49988 L 1 g
F P
s
P
p
.43485 .50826 m .44256 .49138 L .43843 .49988 L 1 g
F
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.44256 .49138 m .45701 .48794 L .43971 .49726 L 1 g
F
P
p
.002 w
.44256 .49138 m .44339 .4905 L p
.45082 .48338 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.44726 .48077 m .46302 .44868 L p
.45891 .47552 L 1 g
F P
s
P
p
.002 w
.45701 .48794 m .45083 .48339 L p
.45765 .47674 L 1 g
F P
s
P
p
.45881 .47619 m .45701 .48794 L .45765 .47674 L 1 g
F
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.46766 .47196 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47803 .46718 m .45701 .48794 L p
.47751 .46725 L 1 g
F P
s
P
p
.002 w
.46427 .49747 m .45701 .48794 L .47803 .46718 L p
1 g
F P
s
P
p
.48029 .46688 m .46427 .49747 L .47803 .46718 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49672 .48185 m .48491 .46625 L p
.5 .46381 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .51028 .46538 L 1 g
F
P
p
.50136 .46402 m .49672 .48185 L .5 .46381 L 1 g
F
P
p
.002 w
.5 .46381 m .5 .4634 L p
.51028 .46538 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.52946 .46452 m .56122 .44617 L p
.5476 .47911 L 1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56579 .50902 L p
1 g
F P
s
P
p
.57524 .48687 m .57449 .52738 L .56579 .50902 L 1 g
F
P
p
.56488 .4991 m .56579 .50902 L .56245 .50197 L 1 g
F
P
p
.57524 .48687 m .56579 .50902 L .56488 .4991 L 1 g
F
P
p
.002 w
.56579 .50902 m .56515 .50826 L p
.56656 .51742 L 1 g
F P
s
P
p
.55661 .4905 m .56579 .50902 L .56095 .4988 L 1 g
F
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56138 .54685 L p
1 g
F P
s
P
p
.57503 .52738 m .5735 .5302 L .56608 .533 L 1 g
F
P
p
.5735 .5302 m .55628 .56191 L .56138 .54685 L 1 g
F
P
p
.5735 .5302 m .56138 .54685 L .56608 .533 L 1 g
F
P
p
.002 w
.56138 .54685 m .56075 .54566 L p
.55606 .55417 L 1 g
F P
s
P
p
.56654 .52734 m .56138 .54685 L .56484 .53666 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54917 .56297 L p
1 g
F P
s
P
p
.002 w
.5513 .5607 m .56106 .56307 L p
.54492 .56748 L 1 g
F P
s
P
p
.002 w
.54917 .56297 m .54933 .56341 L p
.55058 .56147 L 1 g
F P
s
P
p
.56075 .54566 m .54917 .56297 L .55058 .56147 L 1 g
F
P
p
.56075 .54566 m .54933 .56341 L .55606 .55417 L 1 g
F
P
p
.002 w
.54917 .56297 m .54854 .56129 L p
.54217 .56737 L 1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.51031 .57694 m .53013 .55558 L .5513 .5607 L p
1 g
F P
s
P
p
.54492 .56748 m .51031 .57694 L .5513 .5607 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56752 .52876 L p
1 g
F P
s
P
p
.56515 .50826 m .56752 .52876 L .56749 .52787 L 1 g
F
P
p
.57503 .52738 m .5676 .53205 L .56752 .52876 L 1 g
F
P
p
.002 w
.56748 .52744 m .56797 .52743 L p
.56752 .52876 L 1 g
F P
s
P
p
.002 w
.56797 .52743 m .57503 .52738 L p
.56752 .52876 L 1 g
F P
s
P
p
.002 w
.56752 .52876 m .56654 .52734 L p
.56528 .53534 L 1 g
F P
s
P
p
.56515 .50826 m .56749 .52787 L .56656 .51742 L 1 g
F
P
p
.56749 .52787 m .56762 .52891 L .56748 .52744 L 1 g
F
P
p
.56749 .52787 m .56748 .52744 L .56656 .51742 L 1 g
F
P
p
.002 w
.56257 .5491 m .56368 .5456 L p
.56528 .53534 L 1 g
F P
s
P
p
.56654 .52734 m .56484 .53666 L .56528 .53534 L 1 g
F
P
p
.56484 .53666 m .56257 .5491 L .56528 .53534 L 1 g
F
P
p
.56752 .52876 m .53013 .55558 L .56748 .52744 L 1 g
F
P
p
.5676 .53205 m .56608 .533 L .56752 .52876 L 1 g
F
P
p
.56608 .533 m .53013 .55558 L .56752 .52876 L 1 g
F
P
p
.002 w
.56762 .52891 m .56752 .52876 L p
.56368 .5456 L 1 g
F P
s
P
p
.56528 .53534 m .56368 .5456 L .56752 .52876 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.53013 .55558 m .54072 .52764 L .56748 .52744 L p
1 g
F P
s
P
p
.002 w
.56752 .52876 m .56762 .52891 L p
.56749 .52787 L 1 g
F P
s
P
p
.56579 .50902 m .57014 .51821 L .56674 .5193 L 1 g
F
P
p
.002 w
.57449 .52738 m .56797 .52743 L p
.57014 .51821 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56797 .52743 m .54072 .52764 L p
.57014 .51821 L 1 g
F P
s
P
p
.002 w
.56762 .52891 m .56854 .53025 L p
.56656 .51742 L 1 g
F P
s
P
p
.56245 .50197 m .56579 .50902 L .54072 .52764 L 1 g
F
P
p
.56579 .50902 m .56674 .5193 L .54072 .52764 L 1 g
F
P
p
.002 w
.56368 .5456 m .56854 .53025 L .56762 .52891 L p
1 g
F P
s
P
p
.56608 .533 m .56138 .54685 L .53013 .55558 L 1 g
F
P
p
.002 w
.55628 .56191 m .5513 .5607 L p
.56138 .54685 L 1 g
F P
s
P
p
.002 w
.5513 .5607 m .53013 .55558 L p
.56138 .54685 L 1 g
F P
s
P
p
.002 w
.54933 .56341 m .54998 .56518 L p
.55606 .55417 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56138 .54685 L p
1 g
F P
s
P
p
.55606 .55417 m .54998 .56518 L .56138 .54685 L 1 g
F
P
p
.002 w
.56138 .54685 m .56257 .5491 L p
.56484 .53666 L 1 g
F P
s
P
p
.002 w
.57503 .52738 m .56106 .56307 L .55628 .56191 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56579 .50902 L p
1 g
F P
s
P
p
.56656 .51742 m .56854 .53025 L .56579 .50902 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55753 .49159 m .55763 .49156 L p
.55757 .49168 L 1 g
F P
s
P
p
.55661 .4905 m .56095 .4988 L .55753 .49159 L 1 g
F
P
p
.56122 .44617 m .55754 .49148 L .54924 .47515 L 1 g
F
P
p
.55754 .49148 m .55753 .49159 L .55741 .49135 L 1 g
F
P
p
.55754 .49148 m .55741 .49135 L .54924 .47515 L 1 g
F
P
p
.002 w
.56122 .44617 m .57524 .48687 L .55753 .49159 L p
1 g
F P
s
P
p
.002 w
.54222 .4766 m .54174 .47608 L p
.54863 .48283 L 1 g
F P
s
P
p
.002 w
.55741 .49135 m .55661 .4905 L p
.55753 .49159 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55741 .49135 L p
1 g
F P
s
P
p
.54174 .47608 m .55741 .49135 L .54863 .48283 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55753 .49159 m .54058 .4961 L p
.54924 .47515 L 1 g
F P
s
P
p
.56514 .4988 m .54072 .52764 L .55763 .49156 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55743 .49137 L p
1 g
F P
s
P
p
.56095 .4988 m .56713 .51061 L .55743 .49137 L 1 g
F
P
p
.5468 .48105 m .54058 .4961 L .54222 .4766 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54299 .47745 L p
1 g
F P
s
P
p
.002 w
.54299 .47745 m .54222 .4766 L p
.55078 .48496 L 1 g
F P
s
P
p
.55078 .48496 m .55834 .49233 L .54299 .47745 L 1 g
F
P
p
.54863 .48283 m .55834 .49233 L .54222 .4766 L 1 g
F
P
p
.002 w
.55743 .49137 m .55741 .49135 L p
.55753 .49159 L 1 g
F P
s
P
p
.002 w
.54072 .52764 m .54058 .4961 L .55753 .49159 L p
1 g
F P
s
P
p
.55757 .49168 m .54072 .52764 L .55753 .49159 L 1 g
F
P
p
.002 w
.55763 .49156 m .57524 .48687 L p
.56514 .4988 L 1 g
F P
s
P
p
.002 w
.55741 .49135 m .55743 .49137 L p
.54863 .48283 L 1 g
F P
s
P
p
.002 w
.55743 .49137 m .55834 .49233 L p
.55249 .48661 L 1 g
F P
s
P
p
.54863 .48283 m .55743 .49137 L .55249 .48661 L 1 g
F
P
p
.002 w
.56579 .50902 m .56713 .51061 L p
.56095 .4988 L 1 g
F P
s
P
p
.002 w
.57524 .48687 m .57503 .52738 L .57449 .52738 L p
1 g
F P
s
P
p
.002 w
.54058 .4961 m .53205 .47187 L p
.54222 .4766 L 1 g
F P
s
P
p
.5476 .47911 m .5468 .48105 L .54222 .4766 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54222 .4766 L p
1 g
F P
s
P
p
.52214 .46667 m .54222 .4766 L .53763 .47447 L 1 g
F
P
p
.52214 .46667 m .54252 .47693 L .53413 .47287 L 1 g
F
P
p
.002 w
.54058 .4961 m .50445 .50334 L p
.52647 .46917 L 1 g
F P
s
P
p
.002 w
.53205 .47187 m .54058 .4961 L p
.52647 .46917 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .54228 .47712 L p
.53366 .47265 L 1 g
F P
s
P
p
.52214 .46667 m .53413 .47287 L .53366 .47265 L 1 g
F
P
p
.53413 .47287 m .54302 .47747 L .53366 .47265 L 1 g
F
P
p
.002 w
.50445 .50334 m .49672 .48185 L .52344 .46771 L p
1 g
F P
s
P
p
.52647 .46917 m .50445 .50334 L .52344 .46771 L 1 g
F
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.54228 .47712 L 1 g
F P
s
P
p
.002 w
.52344 .46771 m .52946 .46452 L p
.52647 .46917 L 1 g
F P
s
P
p
.002 w
.50848 .43663 m .52946 .46452 L .52344 .46771 L p
1 g
F P
s
P
p
.002 w
.52344 .46771 m .49672 .48185 L p
.50305 .45753 L 1 g
F P
s
P
p
.50848 .43663 m .52344 .46771 L .50305 .45753 L 1 g
F
P
p
.002 w
.54228 .47712 m .52282 .46778 L .52248 .46723 L p
1 g
F P
s
P
p
.002 w
.53205 .47187 m .52946 .46452 L p
.5476 .47911 L 1 g
F P
s
P
p
.002 w
.54222 .4766 m .54252 .47693 L p
.53763 .47447 L 1 g
F P
s
P
p
.002 w
.54252 .47693 m .54302 .47747 L p
.53413 .47287 L 1 g
F P
s
P
p
.002 w
.52946 .46452 m .53205 .47187 L p
.52647 .46917 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46381 L p
1 g
F P
s
P
p
.51028 .46538 m .52282 .46778 L .5 .46381 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46381 L p
1 g
F P
s
P
p
.002 w
.5 .46381 m .5 .46442 L p
.48987 .46545 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46381 L .48987 .46545 L 1 g
F
P
p
.50848 .43663 m .50148 .46357 L .4975 .46343 L 1 g
F
P
p
.002 w
.48237 .46289 m .48389 .46136 L p
.4975 .46343 L 1 g
F P
s
P
p
.002 w
.48389 .46136 m .50848 .43663 L p
.4975 .46343 L 1 g
F P
s
P
p
.50148 .46357 m .50136 .46402 L .5 .46381 L 1 g
F
P
p
.002 w
.52248 .46723 m .52282 .46778 L p
.51028 .46538 L 1 g
F P
s
P
p
.002 w
.47751 .46725 m .47786 .46667 L p
.48987 .46545 L 1 g
F P
s
P
p
.48987 .46545 m .485 .46623 L .47751 .46725 L 1 g
F
P
p
.49366 .46506 m .47803 .46718 L .47751 .46725 L 1 g
F
P
p
.002 w
.48491 .46625 m .48237 .46289 L p
.50148 .46357 L 1 g
F P
s
P
p
.48987 .46545 m .49366 .46506 L .485 .46623 L 1 g
F
P
p
.002 w
.49672 .48185 m .46427 .49747 L p
.48029 .46688 L 1 g
F P
s
P
p
.002 w
.48491 .46625 m .49672 .48185 L p
.48029 .46688 L 1 g
F P
s
P
p
.49366 .46506 m .49904 .46451 L .47803 .46718 L 1 g
F
P
p
.002 w
.48237 .46289 m .48491 .46625 L p
.48029 .46688 L 1 g
F P
s
P
p
.002 w
.47803 .46718 m .48237 .46289 L p
.48029 .46688 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47751 .46725 L p
1 g
F P
s
P
p
.002 w
.47751 .46725 m .47751 .46725 L p
.47797 .46719 L 1 g
F P
s
P
p
.47797 .46719 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.49904 .46451 m .5 .46442 L .47751 .46725 L 1 g
F
P
p
.45881 .47619 m .47751 .46725 L .45701 .48794 L 1 g
F
P
p
.002 w
.47838 .46683 m .47803 .46718 L p
.47751 .46725 L 1 g
F P
s
P
p
.002 w
.46302 .44868 m .48237 .46289 L .47838 .46683 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46725 L p
1 g
F P
s
P
p
.45826 .47608 m .47751 .46725 L .46766 .47196 L 1 g
F
P
p
.46302 .44868 m .47838 .46683 L .45881 .47619 L 1 g
F
P
p
.002 w
.47751 .46725 m .47718 .46778 L p
.46766 .47196 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.46766 .47196 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.45891 .47552 m .45881 .47619 L .45765 .47674 L 1 g
F
P
p
.45082 .48338 m .45172 .48252 L .44256 .49138 L 1 g
F
P
p
.45172 .48252 m .45083 .48339 L .44256 .49138 L 1 g
F
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45083 .48339 m .44726 .48077 L p
.45891 .47552 L 1 g
F P
s
P
p
.45172 .48252 m .4524 .48187 L .45083 .48339 L 1 g
F
P
p
.002 w
.4476 .48101 m .45083 .48339 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.45083 .48339 m .45701 .48794 L p
.44256 .49138 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .44256 .49138 L p
.44262 .49132 L 1 g
F P
s
P
p
.44262 .49132 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.43744 .47724 m .44726 .48077 L .44219 .49174 L p
1 g
F P
s
P
p
.43744 .47724 m .44219 .49174 L .43814 .49565 L 1 g
F
P
p
.002 w
.43832 .50012 m .43363 .51026 L p
.4337 .50963 L 1 g
F P
s
P
p
.43744 .47724 m .43832 .50012 L .4337 .50963 L 1 g
F
P
p
.4524 .48187 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.44219 .49174 m .44726 .48077 L p
.44227 .49166 L 1 g
F P
s
P
p
.43971 .49726 m .43359 .51061 L .43832 .50012 L 1 g
F
P
p
.43843 .49988 m .44166 .49233 L .43372 .50959 L 1 g
F
P
p
.43832 .50012 m .43372 .50959 L .4337 .50963 L 1 g
F
P
p
.43843 .49988 m .43372 .50959 L .43832 .50012 L 1 g
F
P
p
.43843 .49988 m .43843 .49988 L .43832 .50012 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.45701 .48794 m .43359 .51061 L p
.43971 .49726 L 1 g
F P
s
P
p
.002 w
.40041 .5054 m .40178 .49495 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.40178 .49495 m .4067 .48601 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.4067 .48601 m .41467 .47957 L .43323 .51059 L p
1 g
F P
s
P
p
.002 w
.43323 .51059 m .43337 .51082 L .4332 .51066 L p
1 g
F P
s
P
p
.002 w
.4332 .51066 m .4067 .48601 L p
.43323 .51059 L 1 g
F P
s
P
p
.002 w
.42484 .47636 m .43612 .47676 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.41467 .47957 m .42484 .47636 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43369 .50965 L p
1 g
F P
s
P
p
.002 w
.43369 .50965 m .4337 .50963 L p
.43393 .50914 L 1 g
F P
s
P
p
.43393 .50914 m .44166 .49233 L .43369 .50965 L 1 g
F
P
p
.002 w
.4337 .50963 m .4337 .50963 L p
.4337 .50964 L 1 g
F P
s
P
p
.002 w
.43359 .51061 m .43337 .51082 L .43363 .51026 L p
1 g
F P
s
P
p
.002 w
.4337 .50963 m .4337 .50963 L p
.43369 .50969 L 1 g
F P
s
P
p
.002 w
.4337 .50963 m .43369 .50965 L p
.43369 .50973 L 1 g
F P
s
P
p
.002 w
.45701 .48794 m .46427 .49747 L .43358 .51073 L p
1 g
F P
s
P
p
.002 w
.43358 .51073 m .43337 .51082 L .43359 .51061 L p
1 g
F P
s
P
p
.002 w
.43359 .51061 m .45701 .48794 L p
.43358 .51073 L 1 g
F P
s
P
p
.002 w
.46427 .49747 m .46825 .5083 L .43357 .51081 L p
1 g
F P
s
P
p
.002 w
.43357 .51081 m .43337 .51082 L .43358 .51073 L p
1 g
F P
s
P
p
.002 w
.43358 .51073 m .46427 .49747 L p
.43357 .51081 L 1 g
F P
s
P
p
.002 w
.43369 .50965 m .43367 .50966 L p
.43367 .50978 L 1 g
F P
s
P
p
.002 w
.43367 .50966 m .43366 .50967 L p
.43366 .50982 L 1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.46825 .5083 m .46852 .51922 L .43356 .51087 L p
1 g
F P
s
P
p
.002 w
.43356 .51087 m .43337 .51082 L .43357 .51081 L p
1 g
F P
s
P
p
.002 w
.43357 .51081 m .46825 .5083 L p
.43356 .51087 L 1 g
F P
s
P
p
.002 w
.46852 .51922 m .46508 .52901 L .43356 .51093 L p
1 g
F P
s
P
p
.002 w
.43356 .51093 m .43337 .51082 L .43356 .51087 L p
1 g
F P
s
P
p
.002 w
.43356 .51087 m .46852 .51922 L p
.43356 .51093 L 1 g
F P
s
P
p
.002 w
.43366 .50967 m .43365 .50969 L p
.43365 .50985 L 1 g
F P
s
P
p
.002 w
.43365 .50969 m .43364 .5097 L p
.43364 .50986 L 1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.46508 .52901 m .45835 .53664 L .43355 .51101 L p
1 g
F P
s
P
p
.002 w
.43355 .51101 m .43337 .51082 L .43356 .51093 L p
1 g
F P
s
P
p
.002 w
.43356 .51093 m .46508 .52901 L p
.43355 .51101 L 1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.45835 .53664 m .44909 .54129 L .43354 .51116 L p
1 g
F P
s
P
p
.002 w
.43354 .51116 m .43337 .51082 L .43355 .51101 L p
1 g
F P
s
P
p
.002 w
.43355 .51101 m .45835 .53664 L p
.43354 .51116 L 1 g
F P
s
P
p
.002 w
.43364 .5097 m .43363 .50971 L p
.43363 .50984 L 1 g
F P
s
P
p
.002 w
.43363 .50971 m .43363 .50972 L p
.43363 .5098 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44909 .54129 m .43831 .5425 L .43351 .51172 L p
1 g
F P
s
P
p
.002 w
.43351 .51172 m .43337 .51082 L .43354 .51116 L p
1 g
F P
s
P
p
.002 w
.43354 .51116 m .44909 .54129 L p
.43351 .51172 L 1 g
F P
s
P
p
.43628 .54208 m .43252 .5287 L .43349 .51209 L 1 g
F
P
p
.43252 .5287 m .43085 .52273 L .43349 .51209 L 1 g
F
P
p
.002 w
.43337 .51082 m .43831 .5425 L .43628 .54208 L p
1 g
F P
s
P
p
.002 w
.41682 .53459 m .40837 .52632 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.42716 .54018 m .41682 .53459 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.40837 .52632 m .4027 .51624 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.4027 .51624 m .40041 .5054 L .43337 .51082 L closepath p
1 g
F P
s
P
p
.002 w
.43363 .50972 m .43287 .51061 L p
.43314 .51812 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43252 .5287 L p
1 g
F P
s
P
p
.43314 .51812 m .43287 .51061 L .43252 .5287 L 1 g
F
P
p
.43483 .53691 m .43271 .53272 L .43628 .54208 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43831 .54743 L p
1 g
F P
s
P
p
.43271 .53272 m .43146 .53025 L .43831 .54743 L 1 g
F
P
p
.002 w
.43831 .54743 m .43828 .54749 L p
.43869 .54792 L 1 g
F P
s
P
p
.002 w
.42716 .54018 m .43385 .54157 L p
.44498 .57006 L 1 g
F P
s
P
p
.45828 .56866 m .45078 .56311 L .43831 .5425 L 1 g
F
P
p
.002 w
.44166 .55635 m .44005 .5497 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.44005 .5497 m .43831 .5425 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.43828 .54749 m .43743 .5491 L p
.44446 .5552 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45078 .56311 L p
1 g
F P
s
P
p
.44446 .5552 m .43743 .5491 L .45078 .56311 L 1 g
F
P
p
.45774 .56827 m .45733 .5681 L .45828 .56866 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.46606 .56785 m .45828 .56866 L p
.43831 .5425 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4683 .57459 L p
1 g
F P
s
P
p
.45733 .5681 m .45002 .56518 L .4683 .57459 L 1 g
F
P
p
.002 w
.4683 .57459 m .46823 .57491 L p
.4703 .57528 L 1 g
F P
s
P
p
.002 w
.44498 .57006 m .45264 .56926 L p
.48365 .58967 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48889 .583 L p
1 g
F P
s
P
p
.50179 .58101 m .48907 .58044 L .46606 .56785 L 1 g
F
P
p
.002 w
.47572 .57984 m .47271 .5761 L p
.48907 .58044 L 1 g
F P
s
P
p
.002 w
.47271 .5761 m .46606 .56785 L p
.48907 .58044 L 1 g
F P
s
P
p
.002 w
.46823 .57491 m .4678 .57686 L p
.47908 .57779 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48907 .58044 L p
1 g
F P
s
P
p
.47908 .57779 m .4678 .57686 L .48907 .58044 L 1 g
F
P
p
.49938 .5809 m .49823 .58113 L .50179 .58101 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.51031 .57694 m .50179 .58101 L p
.46606 .56785 L 1 g
F P
s
P
p
.002 w
.50179 .58101 m .51031 .57694 L .51552 .57969 L p
1 g
F P
s
P
p
.002 w
.51552 .57969 m .51704 .58049 L p
.51094 .5807 L 1 g
F P
s
P
p
.51094 .5807 m .50179 .58101 L .51552 .57969 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53203 .57606 L p
1 g
F P
s
P
p
.002 w
.53203 .57606 m .53128 .57265 L p
.51907 .57891 L 1 g
F P
s
P
p
.51907 .57891 m .51111 .583 L .53203 .57606 L 1 g
F
P
p
.002 w
.51552 .57969 m .51031 .57694 L p
.56032 .56384 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54917 .56297 L p
1 g
F P
s
P
p
.54217 .56737 m .5322 .57686 L .54917 .56297 L 1 g
F
P
p
.002 w
.53158 .57401 m .5322 .57686 L p
.54217 .56737 L 1 g
F P
s
P
p
.52206 .57738 m .51552 .57969 L .51907 .57891 L 1 g
F
P
p
.002 w
.51094 .5807 m .51111 .583 L p
.51907 .57891 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .5807 L p
1 g
F P
s
P
p
.49823 .58113 m .48889 .583 L .51094 .5807 L 1 g
F
P
p
.002 w
.53539 .59018 m .56106 .56307 L .58944 .56643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.60645 .52419 m .58944 .56643 L .56106 .56307 L p
1 g
F P
s
P
p
.002 w
.58944 .56643 m .60645 .52419 L .63395 .51828 L p
1 g
F P
s
P
p
.004 w
.47663 .45868 m
.5 .43051 L
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.60056 .33977 m .54748 .30108 L .56104 .28176 L p
1 g
F P
s
P
p
.002 w
.56104 .28176 m .61633 .32202 L .60056 .33977 L p
1 g
F P
s
P
p
.002 w
.63513 .46403 m .63395 .51828 L .60645 .52419 L p
1 g
F P
s
P
p
.002 w
.63395 .51828 m .63513 .46403 L .65836 .45134 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.63906 .39213 m .65836 .45134 L .63513 .46403 L p
1 g
F P
s
P
p
.002 w
.63906 .39213 m .60056 .33977 L .61633 .32202 L p
1 g
F P
s
P
p
.002 w
.40837 .52632 m .41682 .53459 L .40324 .55455 L p
1 g
F P
s
P
p
.002 w
.40324 .55455 m .38682 .53851 L .40837 .52632 L p
1 g
F P
s
P
p
.002 w
.4233 .56545 m .40324 .55455 L .41682 .53459 L p
1 g
F P
s
P
p
.002 w
.4027 .51624 m .40837 .52632 L .38682 .53851 L p
1 g
F P
s
P
p
.002 w
.38682 .53851 m .37572 .51894 L .4027 .51624 L p
1 g
F P
s
P
p
.002 w
.41682 .53459 m .42716 .54018 L .4233 .56545 L p
1 g
F P
s
P
p
.002 w
.44498 .57006 m .4233 .56545 L .42716 .54018 L p
1 g
F P
s
P
p
.002 w
.38572 .41371 m .36331 .43279 L .34804 .40637 L p
1 g
F P
s
P
p
.002 w
.34804 .40637 m .37652 .3816 L .38572 .41371 L p
1 g
F P
s
P
p
.002 w
.38307 .45966 m .37362 .47734 L .34984 .45868 L p
1 g
F P
s
P
p
.002 w
.34984 .45868 m .36331 .43279 L .38307 .45966 L p
1 g
F P
s
P
p
.002 w
.40041 .5054 m .4027 .51624 L .37572 .51894 L p
1 g
F P
s
P
p
.002 w
.37572 .51894 m .37113 .49783 L .40041 .5054 L p
1 g
F P
s
P
p
.002 w
.41379 .36847 m .37652 .3816 L .37121 .35159 L p
1 g
F P
s
P
p
.002 w
.37121 .35159 m .41536 .33558 L .41379 .36847 L p
1 g
F P
s
P
p
.002 w
.53205 .32497 m .47577 .30612 L .48665 .28094 L p
1 g
F P
s
P
p
.002 w
.48665 .28094 m .54748 .30108 L .53205 .32497 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.46535 .33579 m .41536 .33558 L .41946 .30626 L p
1 g
F P
s
P
p
.002 w
.41946 .30626 m .47577 .30612 L .46535 .33579 L p
1 g
F P
s
P
p
.002 w
.46606 .56785 m .48432 .55892 L .51031 .57694 L p
1 g
F P
s
P
p
.002 w
.53013 .55558 m .51031 .57694 L .48432 .55892 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.56106 .56307 m .57503 .52738 L .60645 .52419 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40178 .49495 m .40041 .5054 L .37113 .49783 L p
1 g
F P
s
P
p
.002 w
.37113 .49783 m .37362 .47734 L .40178 .49495 L p
1 g
F P
s
P
p
.002 w
.63513 .46403 m .617 .40928 L .63906 .39213 L p
1 g
F P
s
P
p
.002 w
.60056 .33977 m .63906 .39213 L .617 .40928 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.60713 .47603 m .60645 .52419 L .57503 .52738 L p
1 g
F P
s
P
p
.002 w
.60645 .52419 m .60713 .47603 L .63513 .46403 L p
1 g
F P
s
P
p
.002 w
.43831 .5425 m .44909 .54129 L .46606 .56785 L p
1 g
F P
s
P
p
.002 w
.48432 .55892 m .46606 .56785 L .44909 .54129 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.617 .40928 m .63513 .46403 L .60713 .47603 L p
1 g
F P
s
P
p
.002 w
.58121 .36085 m .53205 .32497 L .54748 .30108 L p
1 g
F P
s
P
p
.002 w
.54748 .30108 m .60056 .33977 L .58121 .36085 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.39858 .44678 m .38307 .45966 L .36331 .43279 L p
1 g
F P
s
P
p
.002 w
.36331 .43279 m .38572 .41371 L .39858 .44678 L p
1 g
F P
s
P
p
.002 w
.617 .40928 m .58121 .36085 L .60056 .33977 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.4067 .48601 m .40178 .49495 L .37362 .47734 L p
1 g
F P
s
P
p
.002 w
.37362 .47734 m .38307 .45966 L .4067 .48601 L p
1 g
F P
s
P
p
.002 w
.41486 .40379 m .38572 .41371 L .37652 .3816 L p
1 g
F P
s
P
p
.002 w
.37652 .3816 m .41379 .36847 L .41486 .40379 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44909 .54129 m .45835 .53664 L .48432 .55892 L p
1 g
F P
s
P
p
.002 w
.49775 .54411 m .48432 .55892 L .45835 .53664 L p
1 g
F P
s
P
p
.002 w
.48432 .55892 m .49775 .54411 L .53013 .55558 L p
1 g
F P
s
P
p
.002 w
.54072 .52764 m .53013 .55558 L .49775 .54411 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.45582 .36896 m .41379 .36847 L .41536 .33558 L p
1 g
F P
s
P
p
.002 w
.41536 .33558 m .46535 .33579 L .45582 .36896 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51525 .35272 m .46535 .33579 L .47577 .30612 L p
1 g
F P
s
P
p
.002 w
.47577 .30612 m .53205 .32497 L .51525 .35272 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.57503 .52738 m .57524 .48687 L .60713 .47603 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.41467 .47957 m .4067 .48601 L .38307 .45966 L p
1 g
F P
s
P
p
.002 w
.38307 .45966 m .39858 .44678 L .41467 .47957 L p
1 g
F P
s
P
p
.002 w
.60713 .47603 m .59076 .42752 L .617 .40928 L p
1 g
F P
s
P
p
.002 w
.58121 .36085 m .617 .40928 L .59076 .42752 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59076 .42752 m .60713 .47603 L .57524 .48687 L p
1 g
F P
s
P
p
.002 w
.41859 .44022 m .39858 .44678 L .38572 .41371 L p
1 g
F P
s
P
p
.002 w
.38572 .41371 m .41486 .40379 L .41859 .44022 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.45835 .53664 m .46508 .52901 L .49775 .54411 L p
1 g
F P
s
P
p
.002 w
.50476 .5249 m .49775 .54411 L .46508 .52901 L p
1 g
F P
s
P
p
.002 w
.49775 .54411 m .50476 .5249 L .54072 .52764 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.55887 .38461 m .51525 .35272 L .53205 .32497 L p
1 g
F P
s
P
p
.002 w
.53205 .32497 m .58121 .36085 L .55887 .38461 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.59076 .42752 m .55887 .38461 L .58121 .36085 L p
1 g
F P
s
P
p
.002 w
.44756 .40443 m .41486 .40379 L .41379 .36847 L p
1 g
F P
s
P
p
.002 w
.41379 .36847 m .45582 .36896 L .44756 .40443 L p
1 g
F P
s
P
p
.002 w
.54058 .4961 m .54072 .52764 L .50476 .5249 L p
1 g
F P
s
P
p
.002 w
.46508 .52901 m .46852 .51922 L .50476 .5249 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42484 .47636 m .41467 .47957 L .39858 .44678 L p
1 g
F P
s
P
p
.002 w
.39858 .44678 m .41859 .44022 L .42484 .47636 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.49769 .38338 m .45582 .36896 L .46535 .33579 L p
1 g
F P
s
P
p
.002 w
.46535 .33579 m .51525 .35272 L .49769 .38338 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.50445 .50334 m .50476 .5249 L .46852 .51922 L p
1 g
F P
s
P
p
.002 w
.50476 .5249 m .50445 .50334 L .54058 .4961 L p
1 g
F P
s
P
p
.002 w
.46852 .51922 m .46825 .5083 L .50445 .50334 L p
1 g
F P
s
P
p
.002 w
.57524 .48687 m .56122 .44617 L .59076 .42752 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.55887 .38461 m .59076 .42752 L .56122 .44617 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.44091 .44084 m .41859 .44022 L .41486 .40379 L p
1 g
F P
s
P
p
.002 w
.41486 .40379 m .44756 .40443 L .44091 .44084 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.43612 .47676 m .42484 .47636 L .41859 .44022 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.46825 .5083 m .46427 .49747 L .49672 .48185 L p
1 g
F P
s
P
p
.002 w
.49672 .48185 m .50445 .50334 L .46825 .5083 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.41859 .44022 m .44091 .44084 L .43612 .47676 L p
1 g
F P
s
P
p
.002 w
.53432 .41019 m .49769 .38338 L .51525 .35272 L p
1 g
F P
s
P
p
.002 w
.51525 .35272 m .55887 .38461 L .53432 .41019 L p
1 g
F P
s
P
p
.002 w
.44726 .48077 m .43612 .47676 L .44091 .44084 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.48005 .41578 m .44756 .40443 L .45582 .36896 L p
1 g
F P
s
P
p
.002 w
.45582 .36896 m .49769 .38338 L .48005 .41578 L p
1 g
F P
s
P
p
.002 w
.56122 .44617 m .53432 .41019 L .55887 .38461 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.44091 .44084 m .46302 .44868 L .44726 .48077 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.53432 .41019 m .56122 .44617 L .52946 .46452 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.46302 .44868 m .44091 .44084 L .44756 .40443 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.44756 .40443 m .48005 .41578 L .46302 .44868 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.50848 .43663 m .48005 .41578 L .49769 .38338 L p
1 g
F P
s
P
p
.002 w
.49769 .38338 m .53432 .41019 L .50848 .43663 L p
1 g
F P
s
P
p
.002 w
.52946 .46452 m .50848 .43663 L .53432 .41019 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.48237 .46289 m .46302 .44868 L .48005 .41578 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.48005 .41578 m .50848 .43663 L .48237 .46289 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.004 w
.39304 .55944 m
.41014 .53882 L
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .36615 .69795 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39304 .55944 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.667442)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.667442)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46337 .42995 m .47985 .4515 L .49953 .43089 L p
1 g
F P
s
P
p
.002 w
.49953 .43089 m .48833 .4162 L .46337 .42995 L p
1 g
F P
s
P
p
.002 w
.51472 .4414 m .49953 .43089 L .47985 .4515 L p
1 g
F P
s
P
p
.002 w
.48833 .4162 m .49953 .43089 L .51922 .41027 L p
1 g
F P
s
P
p
.002 w
.49953 .43089 m .51472 .4414 L .52694 .4156 L p
1 g
F P
s
P
p
.002 w
.52694 .4156 m .51922 .41027 L .49953 .43089 L p
1 g
F P
s
P
p
.002 w
.5323 .44664 m .51472 .4414 L .50213 .46696 L p
1 g
F P
s
P
p
.002 w
.47985 .4515 m .50213 .46696 L .51472 .4414 L p
1 g
F P
s
P
p
.002 w
.51472 .4414 m .5323 .44664 L .53586 .41823 L p
1 g
F P
s
P
p
.002 w
.53586 .41823 m .52694 .4156 L .51472 .4414 L p
1 g
F P
s
P
p
.002 w
.45443 .40453 m .46337 .42995 L .48833 .4162 L p
1 g
F P
s
P
p
.002 w
.48833 .4162 m .48229 .39888 L .45443 .40453 L p
1 g
F P
s
P
p
.002 w
.48229 .39888 m .48833 .4162 L .51355 .40281 L p
1 g
F P
s
P
p
.002 w
.51922 .41027 m .51355 .40281 L .48833 .4162 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .51355 .40281 L .51922 .41027 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .51922 .41027 L .52694 .4156 L closepath p
1 g
F P
s
P
p
.002 w
.43913 .44381 m .46052 .47174 L .47985 .4515 L p
1 g
F P
s
P
p
.002 w
.47985 .4515 m .46337 .42995 L .43913 .44381 L p
1 g
F P
s
P
p
.002 w
.50213 .46696 m .47985 .4515 L .46052 .47174 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .52694 .4156 L .53586 .41823 L closepath p
1 g
F P
s
P
p
.002 w
.51355 .40281 m .51051 .39401 L .48229 .39888 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .51051 .39401 L .51355 .40281 L closepath p
1 g
F P
s
P
p
.002 w
.50213 .46696 m .52794 .47473 L .5323 .44664 L p
1 g
F P
s
P
p
.002 w
.55044 .44602 m .5323 .44664 L .52794 .47473 L p
1 g
F P
s
P
p
.002 w
.5323 .44664 m .55044 .44602 L .54506 .41787 L p
1 g
F P
s
P
p
.002 w
.54506 .41787 m .53586 .41823 L .5323 .44664 L p
1 g
F P
s
P
p
.002 w
.45399 .37783 m .45443 .40453 L .48229 .39888 L p
1 g
F P
s
P
p
.002 w
.48229 .39888 m .48208 .38073 L .45399 .37783 L p
1 g
F P
s
P
p
.002 w
.48208 .38073 m .48229 .39888 L .51051 .39401 L p
1 g
F P
s
P
p
.002 w
.52794 .47473 m .50213 .46696 L .4894 .49182 L p
1 g
F P
s
P
p
.002 w
.46052 .47174 m .4894 .49182 L .50213 .46696 L p
1 g
F P
s
P
p
.002 w
.42743 .41086 m .43913 .44381 L .46337 .42995 L p
1 g
F P
s
P
p
.002 w
.46337 .42995 m .45443 .40453 L .42743 .41086 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .53586 .41823 L .54506 .41787 L closepath p
1 g
F P
s
P
p
.002 w
.51051 .39401 m .51044 .38481 L .48208 .38073 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .51044 .38481 L .51051 .39401 L closepath p
1 g
F P
s
P
p
.002 w
.55353 .41455 m .54506 .41787 L .55044 .44602 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .54506 .41787 L .55353 .41455 L closepath p
1 g
F P
s
P
p
.002 w
.48777 .36367 m .48208 .38073 L .51044 .38481 L p
1 g
F P
s
P
p
.002 w
.51044 .38481 m .51337 .3762 L .48777 .36367 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .51337 .3762 L .51044 .38481 L closepath p
1 g
F P
s
P
p
.002 w
.4894 .49182 m .52286 .502 L .52794 .47473 L p
1 g
F P
s
P
p
.002 w
.55463 .47394 m .52794 .47473 L .52286 .502 L p
1 g
F P
s
P
p
.002 w
.52794 .47473 m .55463 .47394 L .55044 .44602 L p
1 g
F P
s
P
p
.002 w
.42671 .3762 m .42743 .41086 L .45443 .40453 L p
1 g
F P
s
P
p
.002 w
.45443 .40453 m .45399 .37783 L .42671 .3762 L p
1 g
F P
s
P
p
.002 w
.56722 .43955 m .55044 .44602 L .55463 .47394 L p
1 g
F P
s
P
p
.002 w
.55044 .44602 m .56722 .43955 L .55353 .41455 L p
1 g
F P
s
P
p
.002 w
.46223 .35266 m .45399 .37783 L .48208 .38073 L p
1 g
F P
s
P
p
.002 w
.48208 .38073 m .48777 .36367 L .46223 .35266 L p
1 g
F P
s
P
p
.002 w
.56036 .40861 m .55353 .41455 L .56722 .43955 L p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .55353 .41455 L .56036 .40861 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .56036 .40861 L .5648 .40068 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .5648 .40068 L .56635 .39161 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .56635 .39161 L .56483 .3824 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .51899 .3691 L .51337 .3762 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .56483 .3824 L .56039 .37405 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .56039 .37405 L .55352 .36748 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .55352 .36748 L .54498 .36343 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .54498 .36343 L .5357 .36234 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .5357 .36234 L .52671 .3643 L closepath p
1 g
F P
s
P
p
.002 w
.53857 .39001 m .52671 .3643 L .51899 .3691 L closepath p
1 g
F P
s
P
p
.002 w
.49881 .34955 m .48777 .36367 L .51337 .3762 L p
1 g
F P
s
P
p
.002 w
.51337 .3762 m .51899 .3691 L .49881 .34955 L p
1 g
F P
s
P
p
.002 w
.41606 .45753 m .44192 .49122 L .46052 .47174 L p
1 g
F P
s
P
p
.002 w
.46052 .47174 m .43913 .44381 L .41606 .45753 L p
1 g
F P
s
P
p
.002 w
.4894 .49182 m .46052 .47174 L .44192 .49122 L p
1 g
F P
s
P
p
.002 w
.52286 .502 m .4894 .49182 L .47676 .5155 L p
1 g
F P
s
P
p
.002 w
.44192 .49122 m .47676 .5155 L .4894 .49182 L p
1 g
F P
s
P
p
.002 w
.40181 .41777 m .41606 .45753 L .43913 .44381 L p
1 g
F P
s
P
p
.002 w
.43913 .44381 m .42743 .41086 L .40181 .41777 L p
1 g
F P
s
P
p
.002 w
.56722 .43955 m .58082 .42788 L .56036 .40861 L p
1 g
F P
s
P
p
.002 w
.5648 .40068 m .56036 .40861 L .58082 .42788 L p
1 g
F P
s
P
p
.002 w
.51407 .33994 m .49881 .34955 L .51899 .3691 L p
1 g
F P
s
P
p
.002 w
.51899 .3691 m .52671 .3643 L .51407 .33994 L p
1 g
F P
s
P
p
.002 w
.55463 .47394 m .57939 .46456 L .56722 .43955 L p
1 g
F P
s
P
p
.002 w
.58082 .42788 m .56722 .43955 L .57939 .46456 L p
1 g
F P
s
P
p
.002 w
.47839 .33174 m .46223 .35266 L .48777 .36367 L p
1 g
F P
s
P
p
.002 w
.48777 .36367 m .49881 .34955 L .47839 .33174 L p
1 g
F P
s
P
p
.002 w
.52286 .502 m .55752 .50112 L .55463 .47394 L p
1 g
F P
s
P
p
.002 w
.57939 .46456 m .55463 .47394 L .55752 .50112 L p
1 g
F P
s
P
p
.002 w
.43724 .34342 m .42671 .3762 L .45399 .37783 L p
1 g
F P
s
P
p
.002 w
.45399 .37783 m .46223 .35266 L .43724 .34342 L p
1 g
F P
s
P
p
.002 w
.58082 .42788 m .58972 .4122 L .5648 .40068 L p
1 g
F P
s
P
p
.002 w
.56635 .39161 m .5648 .40068 L .58972 .4122 L p
1 g
F P
s
P
p
.002 w
.53191 .33594 m .51407 .33994 L .52671 .3643 L p
1 g
F P
s
P
p
.002 w
.52671 .3643 m .5357 .36234 L .53191 .33594 L p
1 g
F P
s
P
p
.002 w
.47676 .5155 m .51715 .52791 L .52286 .502 L p
1 g
F P
s
P
p
.002 w
.55752 .50112 m .52286 .502 L .51715 .52791 L p
1 g
F P
s
P
p
.002 w
.40077 .37587 m .40181 .41777 L .42743 .41086 L p
1 g
F P
s
P
p
.002 w
.42743 .41086 m .42671 .3762 L .40077 .37587 L p
1 g
F P
s
P
p
.002 w
.58972 .4122 m .5929 .39419 L .56635 .39161 L p
1 g
F P
s
P
p
.002 w
.56483 .3824 m .56635 .39161 L .5929 .39419 L p
1 g
F P
s
P
p
.002 w
.55038 .33806 m .53191 .33594 L .5357 .36234 L p
1 g
F P
s
P
p
.002 w
.5357 .36234 m .54498 .36343 L .55038 .33806 L p
1 g
F P
s
P
p
.002 w
.5929 .39419 m .58994 .37584 L .56483 .3824 L p
1 g
F P
s
P
p
.002 w
.56039 .37405 m .56483 .3824 L .58994 .37584 L p
1 g
F P
s
P
p
.002 w
.56743 .3461 m .55038 .33806 L .54498 .36343 L p
1 g
F P
s
P
p
.002 w
.54498 .36343 m .55352 .36748 L .56743 .3461 L p
1 g
F P
s
P
p
.002 w
.57939 .46456 m .59956 .44746 L .58082 .42788 L p
1 g
F P
s
P
p
.002 w
.58972 .4122 m .58082 .42788 L .59956 .44746 L p
1 g
F P
s
P
p
.002 w
.50086 .31741 m .47839 .33174 L .49881 .34955 L p
1 g
F P
s
P
p
.002 w
.49881 .34955 m .51407 .33994 L .50086 .31741 L p
1 g
F P
s
P
p
.002 w
.58994 .37584 m .58112 .35918 L .56039 .37405 L p
1 g
F P
s
P
p
.002 w
.55352 .36748 m .56039 .37405 L .58112 .35918 L p
1 g
F P
s
P
p
.002 w
.58112 .35918 m .56743 .3461 L .55352 .36748 L p
1 g
F P
s
P
p
.002 w
.39462 .47085 m .4244 .50958 L .44192 .49122 L p
1 g
F P
s
P
p
.002 w
.44192 .49122 m .41606 .45753 L .39462 .47085 L p
1 g
F P
s
P
p
.002 w
.47676 .5155 m .44192 .49122 L .4244 .50958 L p
1 g
F P
s
P
p
.002 w
.55752 .50112 m .58979 .4891 L .57939 .46456 L p
1 g
F P
s
P
p
.002 w
.59956 .44746 m .57939 .46456 L .58979 .4891 L p
1 g
F P
s
P
p
.002 w
.45813 .31605 m .43724 .34342 L .46223 .35266 L p
1 g
F P
s
P
p
.002 w
.46223 .35266 m .47839 .33174 L .45813 .31605 L p
1 g
F P
s
P
p
.002 w
.51715 .52791 m .47676 .5155 L .46446 .53754 L p
1 g
F P
s
P
p
.002 w
.4244 .50958 m .46446 .53754 L .47676 .5155 L p
1 g
F P
s
P
p
.002 w
.37811 .42514 m .39462 .47085 L .41606 .45753 L p
1 g
F P
s
P
p
.002 w
.41606 .45753 m .40181 .41777 L .37811 .42514 L p
1 g
F P
s
P
p
.002 w
.51715 .52791 m .55905 .52703 L .55752 .50112 L p
1 g
F P
s
P
p
.002 w
.58979 .4891 m .55752 .50112 L .55905 .52703 L p
1 g
F P
s
P
p
.002 w
.41331 .33615 m .40077 .37587 L .42671 .3762 L p
1 g
F P
s
P
p
.002 w
.42671 .3762 m .43724 .34342 L .41331 .33615 L p
1 g
F P
s
P
p
.002 w
.59956 .44746 m .61285 .42437 L .58972 .4122 L p
1 g
F P
s
P
p
.002 w
.5929 .39419 m .58972 .4122 L .61285 .42437 L p
1 g
F P
s
P
p
.002 w
.52724 .31137 m .50086 .31741 L .51407 .33994 L p
1 g
F P
s
P
p
.002 w
.51407 .33994 m .53191 .33594 L .52724 .31137 L p
1 g
F P
s
P
p
.002 w
.46446 .53754 m .51089 .55193 L .51715 .52791 L p
1 g
F P
s
P
p
.002 w
.55905 .52703 m .51715 .52791 L .51089 .55193 L p
1 g
F P
s
P
p
.002 w
.37672 .37692 m .37811 .42514 L .40181 .41777 L p
1 g
F P
s
P
p
.002 w
.40181 .41777 m .40077 .37587 L .37672 .37692 L p
1 g
F P
s
P
p
.002 w
.61285 .42437 m .61767 .39773 L .5929 .39419 L p
1 g
F P
s
P
p
.002 w
.58994 .37584 m .5929 .39419 L .61767 .39773 L p
1 g
F P
s
P
p
.002 w
.55465 .31442 m .52724 .31137 L .53191 .33594 L p
1 g
F P
s
P
p
.002 w
.53191 .33594 m .55038 .33806 L .55465 .31442 L p
1 g
F P
s
P
p
.002 w
.58979 .4891 m .61617 .46699 L .59956 .44746 L p
1 g
F P
s
P
p
.002 w
.61285 .42437 m .59956 .44746 L .61617 .46699 L p
1 g
F P
s
P
p
.002 w
.48733 .2972 m .45813 .31605 L .47839 .33174 L p
1 g
F P
s
P
p
.002 w
.47839 .33174 m .50086 .31741 L .48733 .2972 L p
1 g
F P
s
P
p
.002 w
.61767 .39773 m .61337 .3705 L .58994 .37584 L p
1 g
F P
s
P
p
.002 w
.58112 .35918 m .58994 .37584 L .61337 .3705 L p
1 g
F P
s
P
p
.002 w
.57998 .32632 m .55465 .31442 L .55038 .33806 L p
1 g
F P
s
P
p
.002 w
.55038 .33806 m .56743 .3461 L .57998 .32632 L p
1 g
F P
s
P
p
.002 w
.55905 .52703 m .59815 .51268 L .58979 .4891 L p
1 g
F P
s
P
p
.002 w
.61617 .46699 m .58979 .4891 L .59815 .51268 L p
1 g
F P
s
P
p
.002 w
.43843 .30287 m .41331 .33615 L .43724 .34342 L p
1 g
F P
s
P
p
.002 w
.43724 .34342 m .45813 .31605 L .43843 .30287 L p
1 g
F P
s
P
p
.002 w
.61337 .3705 m .60032 .34575 L .58112 .35918 L p
1 g
F P
s
P
p
.002 w
.56743 .3461 m .58112 .35918 L .60032 .34575 L p
1 g
F P
s
P
p
.002 w
.60032 .34575 m .57998 .32632 L .56743 .3461 L p
1 g
F P
s
P
p
.002 w
.37529 .48349 m .40835 .5264 L .4244 .50958 L p
1 g
F P
s
P
p
.002 w
.4244 .50958 m .39462 .47085 L .37529 .48349 L p
1 g
F P
s
P
p
.002 w
.46446 .53754 m .4244 .50958 L .40835 .5264 L p
1 g
F P
s
P
p
.002 w
.51089 .55193 m .46446 .53754 L .45274 .55744 L p
1 g
F P
s
P
p
.002 w
.40835 .5264 m .45274 .55744 L .46446 .53754 L p
1 g
F P
s
P
p
.002 w
.35686 .43283 m .37529 .48349 L .39462 .47085 L p
1 g
F P
s
P
p
.002 w
.39462 .47085 m .37811 .42514 L .35686 .43283 L p
1 g
F P
s
P
p
.002 w
.61617 .46699 m .63366 .43696 L .61285 .42437 L p
1 g
F P
s
P
p
.002 w
.61767 .39773 m .61285 .42437 L .63366 .43696 L p
1 g
F P
s
P
p
.002 w
.52177 .28917 m .48733 .2972 L .50086 .31741 L p
1 g
F P
s
P
p
.002 w
.50086 .31741 m .52724 .31137 L .52177 .28917 L p
1 g
F P
s
P
p
.002 w
.51089 .55193 m .55912 .5511 L .55905 .52703 L p
1 g
F P
s
P
p
.002 w
.59815 .51268 m .55905 .52703 L .55912 .5511 L p
1 g
F P
s
P
p
.002 w
.39095 .33109 m .37672 .37692 L .40077 .37587 L p
1 g
F P
s
P
p
.002 w
.40077 .37587 m .41331 .33615 L .39095 .33109 L p
1 g
F P
s
P
p
.002 w
.59815 .51268 m .63025 .48607 L .61617 .46699 L p
1 g
F P
s
P
p
.002 w
.63366 .43696 m .61617 .46699 L .63025 .48607 L p
1 g
F P
s
P
p
.002 w
.47375 .27984 m .43843 .30287 L .45813 .31605 L p
1 g
F P
s
P
p
.002 w
.45813 .31605 m .48733 .2972 L .47375 .27984 L p
1 g
F P
s
P
p
.002 w
.45274 .55744 m .50419 .57352 L .51089 .55193 L p
1 g
F P
s
P
p
.002 w
.55912 .5511 m .51089 .55193 L .50419 .57352 L p
1 g
F P
s
P
p
.002 w
.35514 .37935 m .35686 .43283 L .37811 .42514 L p
1 g
F P
s
P
p
.002 w
.37811 .42514 m .37672 .37692 L .35514 .37935 L p
1 g
F P
s
P
p
.002 w
.63366 .43696 m .64011 .40219 L .61767 .39773 L p
1 g
F P
s
P
p
.002 w
.61337 .3705 m .61767 .39773 L .64011 .40219 L p
1 g
F P
s
P
p
.002 w
.55765 .29306 m .52177 .28917 L .52724 .31137 L p
1 g
F P
s
P
p
.002 w
.52724 .31137 m .55465 .31442 L .55765 .29306 L p
1 g
F P
s
P
p
.002 w
.55912 .5511 m .60425 .53479 L .59815 .51268 L p
1 g
F P
s
P
p
.002 w
.63025 .48607 m .59815 .51268 L .60425 .53479 L p
1 g
F P
s
P
p
.002 w
.41974 .29257 m .39095 .33109 L .41331 .33615 L p
1 g
F P
s
P
p
.002 w
.41331 .33615 m .43843 .30287 L .41974 .29257 L p
1 g
F P
s
P
p
.002 w
.64011 .40219 m .63458 .36653 L .61337 .3705 L p
1 g
F P
s
P
p
.002 w
.60032 .34575 m .61337 .3705 L .63458 .36653 L p
1 g
F P
s
P
p
.002 w
.59086 .3086 m .55765 .29306 L .55465 .31442 L p
1 g
F P
s
P
p
.002 w
.55465 .31442 m .57998 .32632 L .59086 .3086 L p
1 g
F P
s
P
p
.002 w
.63458 .36653 m .61754 .33407 L .60032 .34575 L p
1 g
F P
s
P
p
.002 w
.57998 .32632 m .60032 .34575 L .61754 .33407 L p
1 g
F P
s
P
p
.002 w
.61754 .33407 m .59086 .3086 L .57998 .32632 L p
1 g
F P
s
P
p
.002 w
.35856 .49515 m .39415 .54128 L .40835 .5264 L p
1 g
F P
s
P
p
.002 w
.40835 .5264 m .37529 .48349 L .35856 .49515 L p
1 g
F P
s
P
p
.002 w
.45274 .55744 m .40835 .5264 L .39415 .54128 L p
1 g
F P
s
P
p
.002 w
.63025 .48607 m .65164 .44974 L .63366 .43696 L p
1 g
F P
s
P
p
.002 w
.64011 .40219 m .63366 .43696 L .65164 .44974 L p
1 g
F P
s
P
p
.002 w
.51557 .26991 m .47375 .27984 L .48733 .2972 L p
1 g
F P
s
P
p
.002 w
.48733 .2972 m .52177 .28917 L .51557 .26991 L p
1 g
F P
s
P
p
.002 w
.50419 .57352 m .55769 .57279 L .55912 .5511 L p
1 g
F P
s
P
p
.002 w
.60425 .53479 m .55912 .5511 L .55769 .57279 L p
1 g
F P
s
P
p
.002 w
.37072 .32843 m .35514 .37935 L .37672 .37692 L p
1 g
F P
s
P
p
.002 w
.37672 .37692 m .39095 .33109 L .37072 .32843 L p
1 g
F P
s
P
p
.002 w
.50419 .57352 m .45274 .55744 L .44187 .57471 L p
1 g
F P
s
P
p
.002 w
.39415 .54128 m .44187 .57471 L .45274 .55744 L p
1 g
F P
s
P
p
.002 w
.33863 .44071 m .35856 .49515 L .37529 .48349 L p
1 g
F P
s
P
p
.002 w
.37529 .48349 m .35686 .43283 L .33863 .44071 L p
1 g
F P
s
P
p
.002 w
.60425 .53479 m .64141 .50427 L .63025 .48607 L p
1 g
F P
s
P
p
.002 w
.65164 .44974 m .63025 .48607 L .64141 .50427 L p
1 g
F P
s
P
p
.002 w
.46041 .26581 m .41974 .29257 L .43843 .30287 L p
1 g
F P
s
P
p
.002 w
.43843 .30287 m .47375 .27984 L .46041 .26581 L p
1 g
F P
s
P
p
.002 w
.65164 .44974 m .65964 .40751 L .64011 .40219 L p
1 g
F P
s
P
p
.002 w
.63458 .36653 m .64011 .40219 L .65964 .40751 L p
1 g
F P
s
P
p
.002 w
.55927 .27454 m .51557 .26991 L .52177 .28917 L p
1 g
F P
s
P
p
.002 w
.52177 .28917 m .55765 .29306 L .55927 .27454 L p
1 g
F P
s
P
p
.002 w
.44187 .57471 m .49717 .59211 L .50419 .57352 L p
1 g
F P
s
P
p
.002 w
.55769 .57279 m .50419 .57352 L .49717 .59211 L p
1 g
F P
s
P
p
.002 w
.3366 .3832 m .33863 .44071 L .35686 .43283 L p
1 g
F P
s
P
p
.002 w
.35686 .43283 m .35514 .37935 L .3366 .3832 L p
1 g
F P
s
P
p
.002 w
.55769 .57279 m .60785 .5549 L .60425 .53479 L p
1 g
F P
s
P
p
.002 w
.64141 .50427 m .60425 .53479 L .60785 .5549 L p
1 g
F P
s
P
p
.002 w
.40252 .28553 m .37072 .32843 L .39095 .33109 L p
1 g
F P
s
P
p
.002 w
.39095 .33109 m .41974 .29257 L .40252 .28553 L p
1 g
F P
s
P
p
.002 w
.65964 .40751 m .65302 .36408 L .63458 .36653 L p
1 g
F P
s
P
p
.002 w
.61754 .33407 m .63458 .36653 L .65302 .36408 L p
1 g
F P
s
P
p
.002 w
.59977 .29343 m .55927 .27454 L .55765 .29306 L p
1 g
F P
s
P
p
.002 w
.55765 .29306 m .59086 .3086 L .59977 .29343 L p
1 g
F P
s
P
p
.002 w
.65302 .36408 m .6323 .32449 L .61754 .33407 L p
1 g
F P
s
P
p
.002 w
.59086 .3086 m .61754 .33407 L .6323 .32449 L p
1 g
F P
s
P
p
.002 w
.6323 .32449 m .59977 .29343 L .59086 .3086 L p
1 g
F P
s
P
p
.002 w
.64141 .50427 m .66628 .46243 L .65164 .44974 L p
1 g
F P
s
P
p
.002 w
.65964 .40751 m .65164 .44974 L .66628 .46243 L p
1 g
F P
s
P
p
.002 w
.50875 .25418 m .46041 .26581 L .47375 .27984 L p
1 g
F P
s
P
p
.002 w
.47375 .27984 m .51557 .26991 L .50875 .25418 L p
1 g
F P
s
P
p
.002 w
.34492 .50554 m .3822 .55381 L .39415 .54128 L p
1 g
F P
s
P
p
.002 w
.39415 .54128 m .35856 .49515 L .34492 .50554 L p
1 g
F P
s
P
p
.002 w
.44187 .57471 m .39415 .54128 L .3822 .55381 L p
1 g
F P
s
P
p
.002 w
.49717 .59211 m .55472 .5915 L .55769 .57279 L p
1 g
F P
s
P
p
.002 w
.60785 .5549 m .55769 .57279 L .55472 .5915 L p
1 g
F P
s
P
p
.002 w
.35317 .32836 m .3366 .3832 L .35514 .37935 L p
1 g
F P
s
P
p
.002 w
.35514 .37935 m .37072 .32843 L .35317 .32836 L p
1 g
F P
s
P
p
.002 w
.3822 .55381 m .43213 .58883 L .44187 .57471 L p
1 g
F P
s
P
p
.002 w
.49717 .59211 m .44187 .57471 L .43213 .58883 L p
1 g
F P
s
P
p
.002 w
.32396 .44861 m .34492 .50554 L .35856 .49515 L p
1 g
F P
s
P
p
.002 w
.35856 .49515 m .33863 .44071 L .32396 .44861 L p
1 g
F P
s
P
p
.002 w
.60785 .5549 m .64925 .52117 L .64141 .50427 L p
1 g
F P
s
P
p
.002 w
.66628 .46243 m .64141 .50427 L .64925 .52117 L p
1 g
F P
s
P
p
.002 w
.44764 .25562 m .40252 .28553 L .41974 .29257 L p
1 g
F P
s
P
p
.002 w
.41974 .29257 m .46041 .26581 L .44764 .25562 L p
1 g
F P
s
P
p
.002 w
.66628 .46243 m .67569 .41362 L .65964 .40751 L p
1 g
F P
s
P
p
.002 w
.65302 .36408 m .65964 .40751 L .67569 .41362 L p
1 g
F P
s
P
p
.002 w
.55938 .25943 m .50875 .25418 L .51557 .26991 L p
1 g
F P
s
P
p
.002 w
.51557 .26991 m .55927 .27454 L .55938 .25943 L p
1 g
F P
s
P
p
.002 w
.43213 .58883 m .48998 .60714 L .49717 .59211 L p
1 g
F P
s
P
p
.002 w
.55472 .5915 m .49717 .59211 L .48998 .60714 L p
1 g
F P
s
P
p
.002 w
.32169 .38843 m .32396 .44861 L .33863 .44071 L p
1 g
F P
s
P
p
.002 w
.33863 .44071 m .3366 .3832 L .32169 .38843 L p
1 g
F P
s
P
p
.002 w
.55472 .5915 m .60874 .57244 L .60785 .5549 L p
1 g
F P
s
P
p
.002 w
.64925 .52117 m .60785 .5549 L .60874 .57244 L p
1 g
F P
s
P
p
.002 w
.38725 .28207 m .35317 .32836 L .37072 .32843 L p
1 g
F P
s
P
p
.002 w
.37072 .32843 m .40252 .28553 L .38725 .28207 L p
1 g
F P
s
P
p
.002 w
.67569 .41362 m .66812 .36329 L .65302 .36408 L p
1 g
F P
s
P
p
.002 w
.6323 .32449 m .65302 .36408 L .66812 .36329 L p
1 g
F P
s
P
p
.002 w
.60638 .2813 m .55938 .25943 L .55927 .27454 L p
1 g
F P
s
P
p
.002 w
.55927 .27454 m .59977 .29343 L .60638 .2813 L p
1 g
F P
s
P
p
.002 w
.64925 .52117 m .67707 .47474 L .66628 .46243 L p
1 g
F P
s
P
p
.002 w
.67569 .41362 m .66628 .46243 L .67707 .47474 L p
1 g
F P
s
P
p
.002 w
.50143 .24253 m .44764 .25562 L .46041 .26581 L p
1 g
F P
s
P
p
.002 w
.46041 .26581 m .50875 .25418 L .50143 .24253 L p
1 g
F P
s
P
p
.002 w
.66812 .36329 m .64413 .31735 L .6323 .32449 L p
1 g
F P
s
P
p
.002 w
.59977 .29343 m .6323 .32449 L .64413 .31735 L p
1 g
F P
s
P
p
.002 w
.64413 .31735 m .60638 .2813 L .59977 .29343 L p
1 g
F P
s
P
p
.002 w
.48998 .60714 m .5502 .60665 L .55472 .5915 L p
1 g
F P
s
P
p
.002 w
.60874 .57244 m .55472 .5915 L .5502 .60665 L p
1 g
F P
s
P
p
.002 w
.33887 .33101 m .32169 .38843 L .3366 .3832 L p
1 g
F P
s
P
p
.002 w
.3366 .3832 m .35317 .32836 L .33887 .33101 L p
1 g
F P
s
P
p
.002 w
.33486 .51435 m .37291 .56355 L .3822 .55381 L p
1 g
F P
s
P
p
.002 w
.3822 .55381 m .34492 .50554 L .33486 .51435 L p
1 g
F P
s
P
p
.002 w
.43213 .58883 m .3822 .55381 L .37291 .56355 L p
1 g
F P
s
P
p
.002 w
.48998 .60714 m .43213 .58883 L .42382 .59929 L p
1 g
F P
s
P
p
.002 w
.37291 .56355 m .42382 .59929 L .43213 .58883 L p
1 g
F P
s
P
p
.002 w
.31342 .45632 m .33486 .51435 L .34492 .50554 L p
1 g
F P
s
P
p
.002 w
.34492 .50554 m .32396 .44861 L .31342 .45632 L p
1 g
F P
s
P
p
.002 w
.60874 .57244 m .65342 .53628 L .64925 .52117 L p
1 g
F P
s
P
p
.002 w
.67707 .47474 m .64925 .52117 L .65342 .53628 L p
1 g
F P
s
P
p
.002 w
.43577 .24973 m .38725 .28207 L .40252 .28553 L p
1 g
F P
s
P
p
.002 w
.40252 .28553 m .44764 .25562 L .43577 .24973 L p
1 g
F P
s
P
p
.002 w
.67707 .47474 m .68768 .42041 L .67569 .41362 L p
1 g
F P
s
P
p
.002 w
.66812 .36329 m .67569 .41362 L .68768 .42041 L p
1 g
F P
s
P
p
.002 w
.55791 .24831 m .50143 .24253 L .50875 .25418 L p
1 g
F P
s
P
p
.002 w
.50875 .25418 m .55938 .25943 L .55791 .24831 L p
1 g
F P
s
P
p
.002 w
.42382 .59929 m .48277 .61805 L .48998 .60714 L p
1 g
F P
s
P
p
.002 w
.5502 .60665 m .48998 .60714 L .48277 .61805 L p
1 g
F P
s
P
p
.002 w
.31099 .395 m .31342 .45632 L .32396 .44861 L p
1 g
F P
s
P
p
.002 w
.32396 .44861 m .32169 .38843 L .31099 .395 L p
1 g
F P
s
P
p
.002 w
.5502 .60665 m .60677 .58685 L .60874 .57244 L p
1 g
F P
s
P
p
.002 w
.65342 .53628 m .60874 .57244 L .60677 .58685 L p
1 g
F P
s
P
p
.002 w
.37442 .2825 m .33887 .33101 L .35317 .32836 L p
1 g
F P
s
P
p
.002 w
.35317 .32836 m .38725 .28207 L .37442 .2825 L p
1 g
F P
s
P
p
.002 w
.68768 .42041 m .67932 .36427 L .66812 .36329 L p
1 g
F P
s
P
p
.002 w
.64413 .31735 m .66812 .36329 L .67932 .36427 L p
1 g
F P
s
P
p
.002 w
.6104 .27269 m .55791 .24831 L .55938 .25943 L p
1 g
F P
s
P
p
.002 w
.55938 .25943 m .60638 .2813 L .6104 .27269 L p
1 g
F P
s
P
p
.002 w
.65342 .53628 m .68351 .48634 L .67707 .47474 L p
1 g
F P
s
P
p
.002 w
.68768 .42041 m .67707 .47474 L .68351 .48634 L p
1 g
F P
s
P
p
.002 w
.49378 .23552 m .43577 .24973 L .44764 .25562 L p
1 g
F P
s
P
p
.002 w
.44764 .25562 m .50143 .24253 L .49378 .23552 L p
1 g
F P
s
P
p
.002 w
.48277 .61805 m .54415 .61765 L .5502 .60665 L p
1 g
F P
s
P
p
.002 w
.60677 .58685 m .5502 .60665 L .54415 .61765 L p
1 g
F P
s
P
p
.002 w
.3284 .33649 m .31099 .395 L .32169 .38843 L p
1 g
F P
s
P
p
.002 w
.32169 .38843 m .33887 .33101 L .3284 .33649 L p
1 g
F P
s
P
p
.002 w
.67932 .36427 m .65256 .31296 L .64413 .31735 L p
1 g
F P
s
P
p
.002 w
.60638 .2813 m .64413 .31735 L .65256 .31296 L p
1 g
F P
s
P
p
.002 w
.65256 .31296 m .6104 .27269 L .60638 .2813 L p
1 g
F P
s
P
p
.002 w
.32886 .52125 m .36666 .57012 L .37291 .56355 L p
1 g
F P
s
P
p
.002 w
.37291 .56355 m .33486 .51435 L .32886 .52125 L p
1 g
F P
s
P
p
.002 w
.42382 .59929 m .37291 .56355 L .36666 .57012 L p
1 g
F P
s
P
p
.002 w
.48277 .61805 m .42382 .59929 L .41722 .60563 L p
1 g
F P
s
P
p
.002 w
.36666 .57012 m .41722 .60563 L .42382 .59929 L p
1 g
F P
s
P
p
.002 w
.30752 .46366 m .32886 .52125 L .33486 .51435 L p
1 g
F P
s
P
p
.002 w
.33486 .51435 m .31342 .45632 L .30752 .46366 L p
1 g
F P
s
P
p
.002 w
.60677 .58685 m .6536 .54913 L .65342 .53628 L p
1 g
F P
s
P
p
.002 w
.68351 .48634 m .65342 .53628 L .6536 .54913 L p
1 g
F P
s
P
p
.002 w
.42517 .24856 m .37442 .2825 L .38725 .28207 L p
1 g
F P
s
P
p
.002 w
.38725 .28207 m .43577 .24973 L .42517 .24856 L p
1 g
F P
s
P
p
.002 w
.68351 .48634 m .69505 .42776 L .68768 .42041 L p
1 g
F P
s
P
p
.002 w
.67932 .36427 m .68768 .42041 L .69505 .42776 L p
1 g
F P
s
P
p
.002 w
.55478 .24172 m .49378 .23552 L .50143 .24253 L p
1 g
F P
s
P
p
.002 w
.50143 .24253 m .55791 .24831 L .55478 .24172 L p
1 g
F P
s
P
p
.002 w
.41722 .60563 m .47574 .6243 L .48277 .61805 L p
1 g
F P
s
P
p
.002 w
.54415 .61765 m .48277 .61805 L .47574 .6243 L p
1 g
F P
s
P
p
.002 w
.30505 .40283 m .30752 .46366 L .31342 .45632 L p
1 g
F P
s
P
p
.002 w
.31342 .45632 m .31099 .395 L .30505 .40283 L p
1 g
F P
s
P
p
.002 w
.54415 .61765 m .6018 .59759 L .60677 .58685 L p
1 g
F P
s
P
p
.002 w
.6536 .54913 m .60677 .58685 L .6018 .59759 L p
1 g
F P
s
P
p
.002 w
.36454 .28704 m .3284 .33649 L .33887 .33101 L p
1 g
F P
s
P
p
.002 w
.33887 .33101 m .37442 .2825 L .36454 .28704 L p
1 g
F P
s
P
p
.002 w
.69505 .42776 m .68607 .36711 L .67932 .36427 L p
1 g
F P
s
P
p
.002 w
.65256 .31296 m .67932 .36427 L .68607 .36711 L p
1 g
F P
s
P
p
.002 w
.61155 .26806 m .55478 .24172 L .55791 .24831 L p
1 g
F P
s
P
p
.002 w
.55791 .24831 m .6104 .27269 L .61155 .26806 L p
1 g
F P
s
P
p
.002 w
.6536 .54913 m .68519 .49689 L .68351 .48634 L p
1 g
F P
s
P
p
.002 w
.69505 .42776 m .68351 .48634 L .68519 .49689 L p
1 g
F P
s
P
p
.002 w
.48596 .23363 m .42517 .24856 L .43577 .24973 L p
1 g
F P
s
P
p
.002 w
.43577 .24973 m .49378 .23552 L .48596 .23363 L p
1 g
F P
s
P
p
.002 w
.47574 .6243 m .53663 .62397 L .54415 .61765 L p
1 g
F P
s
P
p
.002 w
.6018 .59759 m .54415 .61765 L .53663 .62397 L p
1 g
F P
s
P
p
.002 w
.32226 .34481 m .30505 .40283 L .31099 .395 L p
1 g
F P
s
P
p
.002 w
.31099 .395 m .3284 .33649 L .32226 .34481 L p
1 g
F P
s
P
p
.002 w
.68607 .36711 m .65716 .31162 L .65256 .31296 L p
1 g
F P
s
P
p
.002 w
.6104 .27269 m .65256 .31296 L .65716 .31162 L p
1 g
F P
s
P
p
.002 w
.65716 .31162 m .61155 .26806 L .6104 .27269 L p
1 g
F P
s
P
p
.002 w
.32732 .52595 m .36382 .57311 L .36666 .57012 L p
1 g
F P
s
P
p
.002 w
.36666 .57012 m .32886 .52125 L .32732 .52595 L p
1 g
F P
s
P
p
.002 w
.41722 .60563 m .36666 .57012 L .36382 .57311 L p
1 g
F P
s
P
p
.002 w
.36382 .57311 m .41262 .60741 L .41722 .60563 L p
1 g
F P
s
P
p
.002 w
.47574 .6243 m .41722 .60563 L .41262 .60741 L p
1 g
F P
s
P
p
.002 w
.30671 .47039 m .32732 .52595 L .32886 .52125 L p
1 g
F P
s
P
p
.002 w
.32886 .52125 m .30752 .46366 L .30671 .47039 L p
1 g
F P
s
P
p
.002 w
.6018 .59759 m .64954 .55923 L .6536 .54913 L p
1 g
F P
s
P
p
.002 w
.68519 .49689 m .6536 .54913 L .64954 .55923 L p
1 g
F P
s
P
p
.002 w
.41623 .25245 m .36454 .28704 L .37442 .2825 L p
1 g
F P
s
P
p
.002 w
.37442 .2825 m .42517 .24856 L .41623 .25245 L p
1 g
F P
s
P
p
.002 w
.68519 .49689 m .69732 .4355 L .69505 .42776 L p
1 g
F P
s
P
p
.002 w
.68607 .36711 m .69505 .42776 L .69732 .4355 L p
1 g
F P
s
P
p
.002 w
.54998 .24012 m .48596 .23363 L .49378 .23552 L p
1 g
F P
s
P
p
.002 w
.49378 .23552 m .55478 .24172 L .54998 .24012 L p
1 g
F P
s
P
p
.002 w
.41262 .60741 m .46907 .62543 L .47574 .6243 L p
1 g
F P
s
P
p
.002 w
.53663 .62397 m .47574 .6243 L .46907 .62543 L p
1 g
F P
s
P
p
.002 w
.30432 .41176 m .30671 .47039 L .30752 .46366 L p
1 g
F P
s
P
p
.002 w
.30752 .46366 m .30505 .40283 L .30432 .41176 L p
1 g
F P
s
P
p
.002 w
.53663 .62397 m .59379 .60413 L .6018 .59759 L p
1 g
F P
s
P
p
.002 w
.64954 .55923 m .6018 .59759 L .59379 .60413 L p
1 g
F P
s
P
p
.004 w
.27397 .6242 m
.28965 .61076 L
s
P
p
.002 w
.35806 .29583 m .32226 .34481 L .3284 .33649 L p
1 g
F P
s
P
p
.002 w
.3284 .33649 m .36454 .28704 L .35806 .29583 L p
1 g
F P
s
P
p
.002 w
.69732 .4355 m .68791 .37186 L .68607 .36711 L p
1 g
F P
s
P
p
.002 w
.65716 .31162 m .68607 .36711 L .68791 .37186 L p
1 g
F P
s
P
p
.002 w
.60961 .26779 m .54998 .24012 L .55478 .24172 L p
1 g
F P
s
P
p
.002 w
.55478 .24172 m .61155 .26806 L .60961 .26779 L p
1 g
F P
s
P
p
.002 w
.64954 .55923 m .68174 .50603 L .68519 .49689 L p
1 g
F P
s
P
p
.002 w
.69732 .4355 m .68519 .49689 L .68174 .50603 L p
1 g
F P
s
P
p
.002 w
.47821 .23724 m .41623 .25245 L .42517 .24856 L p
1 g
F P
s
P
p
.002 w
.42517 .24856 m .48596 .23363 L .47821 .23724 L p
1 g
F P
s
P
p
.002 w
.46907 .62543 m .52775 .62513 L .53663 .62397 L p
1 g
F P
s
P
p
.002 w
.59379 .60413 m .53663 .62397 L .52775 .62513 L p
1 g
F P
s
P
p
.002 w
.32091 .35593 m .30432 .41176 L .30505 .40283 L p
1 g
F P
s
P
p
.002 w
.30505 .40283 m .32226 .34481 L .32091 .35593 L p
1 g
F P
s
P
p
.002 w
.68791 .37186 m .65753 .31356 L .65716 .31162 L p
1 g
F P
s
P
p
.002 w
.61155 .26806 m .65716 .31162 L .65753 .31356 L p
1 g
F P
s
P
p
.002 w
.65753 .31356 m .60961 .26779 L .61155 .26806 L p
1 g
F P
s
P
p
.002 w
.33059 .52816 m .3647 .57222 L .36382 .57311 L p
1 g
F P
s
P
p
.002 w
.36382 .57311 m .32732 .52595 L .33059 .52816 L p
1 g
F P
s
P
p
.002 w
.41262 .60741 m .36382 .57311 L .3647 .57222 L p
1 g
F P
s
P
p
.002 w
.46907 .62543 m .41262 .60741 L .41029 .60426 L p
1 g
F P
s
P
p
.002 w
.3647 .57222 m .41029 .60426 L .41262 .60741 L p
1 g
F P
s
P
p
.002 w
.31137 .47629 m .33059 .52816 L .32732 .52595 L p
1 g
F P
s
P
p
.002 w
.32732 .52595 m .30671 .47039 L .31137 .47629 L p
1 g
F P
s
P
p
.002 w
.59379 .60413 m .64109 .56612 L .64954 .55923 L p
1 g
F P
s
P
p
.002 w
.68174 .50603 m .64954 .55923 L .64109 .56612 L p
1 g
F P
s
P
p
.002 w
.4093 .26159 m .35806 .29583 L .36454 .28704 L p
1 g
F P
s
P
p
.002 w
.36454 .28704 m .41623 .25245 L .4093 .26159 L p
1 g
F P
s
P
p
.002 w
.68174 .50603 m .69409 .44343 L .69732 .4355 L p
1 g
F P
s
P
p
.002 w
.68791 .37186 m .69732 .4355 L .69409 .44343 L p
1 g
F P
s
P
p
.002 w
.54354 .2439 m .47821 .23724 L .48596 .23363 L p
1 g
F P
s
P
p
.002 w
.48596 .23363 m .54998 .24012 L .54354 .2439 L p
1 g
F P
s
P
p
.002 w
.41029 .60426 m .46299 .62108 L .46907 .62543 L p
1 g
F P
s
P
p
.002 w
.52775 .62513 m .46907 .62543 L .46299 .62108 L p
1 g
F P
s
P
p
.002 w
.30918 .42162 m .31137 .47629 L .30671 .47039 L p
1 g
F P
s
P
p
.002 w
.30671 .47039 m .30432 .41176 L .30918 .42162 L p
1 g
F P
s
P
p
.002 w
.52775 .62513 m .58277 .606 L .59379 .60413 L p
1 g
F P
s
P
p
.002 w
.64109 .56612 m .59379 .60413 L .58277 .606 L p
1 g
F P
s
P
p
.002 w
.3554 .30886 m .32091 .35593 L .32226 .34481 L p
1 g
F P
s
P
p
.002 w
.32226 .34481 m .35806 .29583 L .3554 .30886 L p
1 g
F P
s
P
p
.002 w
.69409 .44343 m .68445 .37849 L .68791 .37186 L p
1 g
F P
s
P
p
.002 w
.65753 .31356 m .68791 .37186 L .68445 .37849 L p
1 g
F P
s
P
p
.002 w
.60444 .2722 m .54354 .2439 L .54998 .24012 L p
1 g
F P
s
P
p
.002 w
.54998 .24012 m .60961 .26779 L .60444 .2722 L p
1 g
F P
s
P
p
.002 w
.64109 .56612 m .67294 .51339 L .68174 .50603 L p
1 g
F P
s
P
p
.002 w
.69409 .44343 m .68174 .50603 L .67294 .51339 L p
1 g
F P
s
P
p
.002 w
.47075 .24661 m .4093 .26159 L .41623 .25245 L p
1 g
F P
s
P
p
.002 w
.41623 .25245 m .47821 .23724 L .47075 .24661 L p
1 g
F P
s
P
p
.002 w
.46299 .62108 m .51771 .62075 L .52775 .62513 L p
1 g
F P
s
P
p
.002 w
.58277 .606 m .52775 .62513 L .51771 .62075 L p
1 g
F P
s
P
p
.002 w
.3247 .36966 m .30918 .42162 L .30432 .41176 L p
1 g
F P
s
P
p
.002 w
.30432 .41176 m .32091 .35593 L .3247 .36966 L p
1 g
F P
s
P
p
.002 w
.68445 .37849 m .6534 .31896 L .65753 .31356 L p
1 g
F P
s
P
p
.002 w
.60961 .26779 m .65753 .31356 L .6534 .31896 L p
1 g
F P
s
P
p
.002 w
.6534 .31896 m .60444 .2722 L .60961 .26779 L p
1 g
F P
s
P
p
.002 w
.3389 .52764 m .36951 .56721 L .3647 .57222 L p
1 g
F P
s
P
p
.002 w
.3647 .57222 m .33059 .52816 L .3389 .52764 L p
1 g
F P
s
P
p
.004 w
.35794 .55225 m
.5 .43051 L
s
P
p
.004 w
.35296 .55651 m
.35407 .55557 L
s
P
p
.004 w
.34748 .56121 m
.35296 .55651 L
s
P
p
.002 w
.41029 .60426 m .3647 .57222 L .36951 .56721 L p
1 g
F P
s
P
p
.002 w
.58277 .606 m .62822 .5694 L .64109 .56612 L p
1 g
F P
s
P
p
.002 w
.67294 .51339 m .64109 .56612 L .62822 .5694 L p
1 g
F P
s
P
p
.002 w
.40473 .27605 m .3554 .30886 L .35806 .29583 L p
1 g
F P
s
P
p
.002 w
.35806 .29583 m .4093 .26159 L .40473 .27605 L p
1 g
F P
s
P
p
.002 w
.36951 .56721 m .41044 .59596 L .41029 .60426 L p
1 g
F P
s
P
p
.002 w
.46299 .62108 m .41029 .60426 L .41044 .59596 L p
1 g
F P
s
P
p
.002 w
.32169 .4811 m .3389 .52764 L .33059 .52816 L p
1 g
F P
s
P
p
.002 w
.33059 .52816 m .31137 .47629 L .32169 .4811 L p
1 g
F P
s
P
p
.002 w
.67294 .51339 m .6851 .45133 L .69409 .44343 L p
1 g
F P
s
P
p
.002 w
.68445 .37849 m .69409 .44343 L .6851 .45133 L p
1 g
F P
s
P
p
.002 w
.53555 .2533 m .47075 .24661 L .47821 .23724 L p
1 g
F P
s
P
p
.002 w
.47821 .23724 m .54354 .2439 L .53555 .2533 L p
1 g
F P
s
P
p
.002 w
.41044 .59596 m .45773 .61101 L .46299 .62108 L p
1 g
F P
s
P
p
.002 w
.51771 .62075 m .46299 .62108 L .45773 .61101 L p
1 g
F P
s
P
p
.002 w
.31982 .43214 m .32169 .4811 L .31137 .47629 L p
1 g
F P
s
P
p
.002 w
.31137 .47629 m .30918 .42162 L .31982 .43214 L p
1 g
F P
s
P
p
.002 w
.51771 .62075 m .5689 .60287 L .58277 .606 L p
1 g
F P
s
P
p
.002 w
.62822 .5694 m .58277 .606 L .5689 .60287 L p
1 g
F P
s
P
p
.002 w
.35689 .32598 m .3247 .36966 L .32091 .35593 L p
1 g
F P
s
P
p
.002 w
.32091 .35593 m .3554 .30886 L .35689 .32598 L p
1 g
F P
s
P
p
.002 w
.62822 .5694 m .65874 .51863 L .67294 .51339 L p
1 g
F P
s
P
p
.002 w
.6851 .45133 m .67294 .51339 L .65874 .51863 L p
1 g
F P
s
P
p
.002 w
.46386 .26178 m .40473 .27605 L .4093 .26159 L p
1 g
F P
s
P
p
.002 w
.4093 .26159 m .47075 .24661 L .46386 .26178 L p
1 g
F P
s
P
p
.002 w
.6851 .45133 m .67545 .38692 L .68445 .37849 L p
1 g
F P
s
P
p
.002 w
.6534 .31896 m .68445 .37849 L .67545 .38692 L p
1 g
F P
s
P
p
.002 w
.59597 .28144 m .53555 .2533 L .54354 .2439 L p
1 g
F P
s
P
p
.002 w
.54354 .2439 m .60444 .2722 L .59597 .28144 L p
1 g
F P
s
P
p
.002 w
.45773 .61101 m .50673 .61063 L .51771 .62075 L p
1 g
F P
s
P
p
.002 w
.5689 .60287 m .51771 .62075 L .50673 .61063 L p
1 g
F P
s
P
p
.002 w
.33382 .38573 m .31982 .43214 L .30918 .42162 L p
1 g
F P
s
P
p
.002 w
.30918 .42162 m .3247 .36966 L .33382 .38573 L p
1 g
F P
s
P
p
.002 w
.67545 .38692 m .64458 .32786 L .6534 .31896 L p
1 g
F P
s
P
p
.002 w
.60444 .2722 m .6534 .31896 L .64458 .32786 L p
1 g
F P
s
P
p
.002 w
.64458 .32786 m .59597 .28144 L .60444 .2722 L p
1 g
F P
s
P
p
.002 w
.5689 .60287 m .61107 .56872 L .62822 .5694 L p
1 g
F P
s
P
p
.002 w
.65874 .51863 m .62822 .5694 L .61107 .56872 L p
1 g
F P
s
P
p
.002 w
.3523 .52425 m .37836 .55796 L .36951 .56721 L p
1 g
F P
s
P
p
.002 w
.36951 .56721 m .3389 .52764 L .3523 .52425 L p
1 g
F P
s
P
p
.004 w
.28965 .61076 m
.34748 .56121 L
s
P
p
.002 w
.41044 .59596 m .36951 .56721 L .37836 .55796 L p
1 g
F P
s
P
p
.002 w
.40282 .29565 m .35689 .32598 L .3554 .30886 L p
1 g
F P
s
P
p
.002 w
.3554 .30886 m .40473 .27605 L .40282 .29565 L p
1 g
F P
s
P
p
.002 w
.37836 .55796 m .41324 .58244 L .41044 .59596 L p
1 g
F P
s
P
p
.002 w
.45773 .61101 m .41044 .59596 L .41324 .58244 L p
1 g
F P
s
P
p
.002 w
.33772 .48462 m .3523 .52425 L .3389 .52764 L p
1 g
F P
s
P
p
.002 w
.3389 .52764 m .32169 .4811 L .33772 .48462 L p
1 g
F P
s
P
p
.002 w
.65874 .51863 m .67028 .45893 L .6851 .45133 L p
1 g
F P
s
P
p
.002 w
.67545 .38692 m .6851 .45133 L .67028 .45893 L p
1 g
F P
s
P
p
.002 w
.52618 .26836 m .46386 .26178 L .47075 .24661 L p
1 g
F P
s
P
p
.002 w
.47075 .24661 m .53555 .2533 L .52618 .26836 L p
1 g
F P
s
P
p
.002 w
.50673 .61063 m .55245 .59452 L .5689 .60287 L p
1 g
F P
s
P
p
.002 w
.61107 .56872 m .5689 .60287 L .55245 .59452 L p
1 g
F P
s
P
p
.002 w
.3627 .34686 m .33382 .38573 L .3247 .36966 L p
1 g
F P
s
P
p
.002 w
.3247 .36966 m .35689 .32598 L .3627 .34686 L p
1 g
F P
s
P
p
.002 w
.41324 .58244 m .4535 .59518 L .45773 .61101 L p
1 g
F P
s
P
p
.002 w
.50673 .61063 m .45773 .61101 L .4535 .59518 L p
1 g
F P
s
P
p
.002 w
.33623 .44303 m .33772 .48462 L .32169 .4811 L p
1 g
F P
s
P
p
.002 w
.32169 .4811 m .31982 .43214 L .33623 .44303 L p
1 g
F P
s
P
p
.002 w
.61107 .56872 m .63926 .52146 L .65874 .51863 L p
1 g
F P
s
P
p
.002 w
.67028 .45893 m .65874 .51863 L .63926 .52146 L p
1 g
F P
s
P
p
.002 w
.4578 .28259 m .40282 .29565 L .40473 .27605 L p
1 g
F P
s
P
p
.002 w
.40473 .27605 m .46386 .26178 L .4578 .28259 L p
1 g
F P
s
P
p
.002 w
.67028 .45893 m .66086 .39699 L .67545 .38692 L p
1 g
F P
s
P
p
.002 w
.64458 .32786 m .67545 .38692 L .66086 .39699 L p
1 g
F P
s
P
p
.002 w
.5843 .29551 m .52618 .26836 L .53555 .2533 L p
1 g
F P
s
P
p
.002 w
.53555 .2533 m .59597 .28144 L .5843 .29551 L p
1 g
F P
s
P
p
.002 w
.4535 .59518 m .49512 .59476 L .50673 .61063 L p
1 g
F P
s
P
p
.002 w
.55245 .59452 m .50673 .61063 L .49512 .59476 L p
1 g
F P
s
P
p
.002 w
.34826 .40373 m .33623 .44303 L .31982 .43214 L p
1 g
F P
s
P
p
.002 w
.31982 .43214 m .33382 .38573 L .34826 .40373 L p
1 g
F P
s
P
p
.002 w
.66086 .39699 m .63108 .34019 L .64458 .32786 L p
1 g
F P
s
P
p
.002 w
.59597 .28144 m .64458 .32786 L .63108 .34019 L p
1 g
F P
s
P
p
.002 w
.55245 .59452 m .58997 .5639 L .61107 .56872 L p
1 g
F P
s
P
p
.002 w
.63926 .52146 m .61107 .56872 L .58997 .5639 L p
1 g
F P
s
P
p
.002 w
.63108 .34019 m .5843 .29551 L .59597 .28144 L p
1 g
F P
s
P
p
.002 w
.40378 .32 m .3627 .34686 L .35689 .32598 L p
1 g
F P
s
P
p
.002 w
.35689 .32598 m .40282 .29565 L .40378 .32 L p
1 g
F P
s
P
p
.002 w
.37066 .51791 m .3912 .54453 L .37836 .55796 L p
1 g
F P
s
P
p
.002 w
.37836 .55796 m .3523 .52425 L .37066 .51791 L p
1 g
F P
s
P
p
.002 w
.41324 .58244 m .37836 .55796 L .3912 .54453 L p
1 g
F P
s
P
p
.002 w
.4535 .59518 m .41324 .58244 L .41875 .56383 L p
1 g
F P
s
P
p
.002 w
.3912 .54453 m .41875 .56383 L .41324 .58244 L p
1 g
F P
s
P
p
.002 w
.35922 .48664 m .37066 .51791 L .3523 .52425 L p
1 g
F P
s
P
p
.002 w
.3523 .52425 m .33772 .48462 L .35922 .48664 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.63926 .52146 m .64979 .46596 L .67028 .45893 L p
1 g
F P
s
P
p
.002 w
.66086 .39699 m .67028 .45893 L .64979 .46596 L p
1 g
F P
s
P
p
.002 w
.51568 .28887 m .4578 .28259 L .46386 .26178 L p
1 g
F P
s
P
p
.002 w
.46386 .26178 m .52618 .26836 L .51568 .28887 L p
1 g
F P
s
P
p
.002 w
.49512 .59476 m .53383 .58094 L .55245 .59452 L p
1 g
F P
s
P
p
.002 w
.58997 .5639 m .55245 .59452 L .53383 .58094 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.37287 .37095 m .34826 .40373 L .33382 .38573 L p
1 g
F P
s
P
p
.002 w
.33382 .38573 m .3627 .34686 L .37287 .37095 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.41875 .56383 m .45051 .57382 L .4535 .59518 L p
1 g
F P
s
P
p
.002 w
.49512 .59476 m .4535 .59518 L .45051 .57382 L p
1 g
F P
s
P
p
.002 w
.35817 .4539 m .35922 .48664 L .33772 .48462 L p
1 g
F P
s
P
p
.002 w
.33772 .48462 m .33623 .44303 L .35817 .4539 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.58997 .5639 m .61491 .52164 L .63926 .52146 L p
1 g
F P
s
P
p
.002 w
.64979 .46596 m .63926 .52146 L .61491 .52164 L p
1 g
F P
s
P
p
.002 w
.45283 .30859 m .40378 .32 L .40282 .29565 L p
1 g
F P
s
P
p
.002 w
.40282 .29565 m .4578 .28259 L .45283 .30859 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.45051 .57382 m .46512 .57361 L p
.49512 .59476 L 1 g
F P
s
P
p
.49512 .59476 m .46512 .57361 L .4683 .57458 L 1 g
F
P
p
.002 w
.48731 .58066 m .49065 .58669 L p
.47764 .57964 L 1 g
F P
s
P
p
.002 w
.49065 .58669 m .49512 .59476 L p
.4746 .57932 L 1 g
F P
s
P
p
.4746 .57932 m .4683 .57458 L .47764 .57964 L 1 g
F
P
p
.4746 .57932 m .47764 .57964 L .49065 .58669 L 1 g
F
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53383 .58094 m .5193 .58613 L p
.50559 .58128 L 1 g
F P
s
P
p
.50931 .58039 m .50559 .58128 L .50267 .58024 L 1 g
F
P
p
.53383 .58094 m .50559 .58128 L .50931 .58039 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51089 .58001 L p
1 g
F P
s
P
p
.53128 .57265 m .51089 .58001 L .52218 .57732 L 1 g
F
P
p
.002 w
.51089 .58001 m .51079 .57862 L p
.50271 .58024 L 1 g
F P
s
P
p
.53383 .58094 m .50267 .58024 L .52501 .57962 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58061 L p
1 g
F P
s
P
p
.002 w
.5193 .58613 m .49512 .59476 L .48731 .58066 L p
1 g
F P
s
P
p
.5193 .58613 m .48731 .58066 L .48906 .58061 L 1 g
F
P
p
.51079 .57862 m .48906 .58061 L .50271 .58024 L 1 g
F
P
p
.48921 .57862 m .47887 .57777 L .48708 .58025 L 1 g
F
P
p
.002 w
.48906 .58061 m .48921 .57862 L p
.48708 .58025 L 1 g
F P
s
P
p
.002 w
.48708 .58025 m .48731 .58066 L p
.4683 .57458 L 1 g
F P
s
P
p
.47764 .57964 m .4683 .57458 L .48731 .58066 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46826 .57478 L p
1 g
F P
s
P
p
.002 w
.46826 .57478 m .4678 .57686 L p
.47562 .5775 L 1 g
F P
s
P
p
.48921 .57862 m .46826 .57478 L .47562 .5775 L 1 g
F
P
p
.002 w
.46649 .5736 m .46512 .57361 L p
.46414 .57202 L 1 g
F P
s
P
p
.002 w
.46512 .57361 m .45051 .57382 L .45017 .56808 L p
1 g
F P
s
P
p
.002 w
.45017 .56808 m .44983 .56245 L p
.45093 .56325 L 1 g
F P
s
P
p
.002 w
.45079 .56309 m .45146 .56129 L p
.44469 .55541 L 1 g
F P
s
P
p
.002 w
.4498 .56195 m .45051 .57382 L p
.44257 .55804 L 1 g
F P
s
P
p
.44257 .55804 m .43503 .54304 L .43837 .54732 L 1 g
F
P
p
.44257 .55804 m .43837 .54732 L .4498 .56195 L 1 g
F
P
p
.002 w
.42692 .54051 m .43503 .54304 L p
.45051 .57382 L 1 g
F P
s
P
p
.002 w
.43837 .54732 m .43925 .54566 L p
.43512 .53749 L 1 g
F P
s
P
p
.002 w
.42692 .54051 m .4321 .52722 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43692 .54363 m .43183 .54204 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43183 .54204 m .42692 .54051 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43253 .52869 m .43346 .52734 L p
.43314 .51828 L 1 g
F P
s
P
p
.002 w
.43269 .52571 m .42692 .54051 L p
.43363 .51035 L 1 g
F P
s
P
p
.43314 .51828 m .43312 .51759 L .43269 .52571 L 1 g
F
P
p
.43314 .51828 m .43269 .52571 L .43253 .52869 L 1 g
F
P
p
.43485 .50826 m .43841 .49994 L .43722 .5024 L 1 g
F
P
p
.002 w
.43342 .51021 m .42778 .50627 L .43494 .49877 L p
1 g
F P
s
P
p
.43371 .50961 m .43521 .49849 L .44256 .49138 L 1 g
F
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46049 .51634 m .4489 .51661 L .45039 .48381 L p
1 g
F P
s
P
p
.002 w
.47965 .50497 m .47112 .51232 L .45095 .48326 L p
1 g
F P
s
P
p
.002 w
.48695 .48364 m .48514 .49506 L .45136 .48287 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43371 .50961 L p
1 g
F P
s
P
p
.43346 .52734 m .43371 .50961 L .43339 .51242 L 1 g
F
P
p
.43346 .52734 m .43339 .51242 L .43312 .51759 L 1 g
F
P
p
.43512 .53749 m .43692 .54363 L .43837 .54732 L 1 g
F
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.44469 .55541 m .4498 .56195 L .45079 .56309 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43789 .54823 L p
1 g
F P
s
P
p
.45146 .56129 m .43789 .54823 L .44237 .55339 L 1 g
F
P
p
.002 w
.4683 .57458 m .46872 .57265 L p
.45969 .56904 L 1 g
F P
s
P
p
.45969 .56904 m .46649 .5736 L .4683 .57458 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.46512 .57361 m .45747 .57078 L .45093 .56325 L 1 g
F
P
p
.45747 .57078 m .45017 .56808 L .45093 .56325 L 1 g
F
P
p
.46512 .57361 m .44983 .56245 L .46414 .57202 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.46414 .57202 m .45079 .56309 L .44894 .54737 L 1 g
F
P
p
.002 w
.44983 .56245 m .4498 .56195 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.4498 .56195 m .44894 .54737 L p
.45079 .56309 L 1 g
F P
s
P
p
.002 w
.43789 .54823 m .43743 .5491 L p
.44237 .55339 L 1 g
F P
s
P
p
.002 w
.44894 .54737 m .4498 .56195 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.43503 .54304 m .43692 .54363 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4316 .53005 L p
1 g
F P
s
P
p
.43925 .54566 m .4316 .53005 L .43244 .53218 L 1 g
F
P
p
.002 w
.43692 .54363 m .44894 .54737 L p
.43837 .54732 L 1 g
F P
s
P
p
.002 w
.4316 .53005 m .43146 .53025 L p
.43244 .53218 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.43692 .54363 m .43253 .52869 L .4376 .51312 L 1 g
F
P
p
.002 w
.4321 .52722 m .43269 .52571 L p
.43253 .52869 L 1 g
F P
s
P
p
.002 w
.43269 .52571 m .4376 .51312 L p
.43253 .52869 L 1 g
F P
s
P
p
.43312 .51759 m .43339 .51242 L .43305 .51549 L 1 g
F
P
p
.002 w
.43494 .49877 m .43521 .49849 L p
.43371 .50961 L 1 g
F P
s
P
p
.43342 .51021 m .43494 .49877 L .43371 .50961 L 1 g
F
P
p
.002 w
.43367 .50966 m .43371 .50961 L p
.43926 .49732 L 1 g
F P
s
P
p
.002 w
.43371 .50961 m .43485 .50826 L p
.43722 .5024 L 1 g
F P
s
P
p
.43722 .5024 m .43926 .49732 L .43371 .50961 L 1 g
F
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.4376 .51312 m .43342 .51021 L p
.4486 .48554 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48488 .47198 m .45228 .48198 L p
.46139 .47497 L 1 g
F P
s
P
p
.4775 .46727 m .48488 .47198 L .46139 .47497 L 1 g
F
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.48992 .46544 L 1 g
F P
s
P
p
.002 w
.48488 .47198 m .48201 .46668 L p
.48955 .4655 L 1 g
F P
s
P
p
.48992 .46544 m .48201 .46668 L .4775 .46727 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.50866 .43902 m .51999 .46005 L .51628 .46131 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.52397 .48309 m .48695 .48364 L p
.51205 .46572 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .5225 .46726 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52397 .48309 m .52121 .4671 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54227 .47666 L p
1 g
F P
s
P
p
.52214 .46667 m .54227 .47666 L .53212 .47184 L 1 g
F
P
p
.53312 .47231 m .52397 .48309 L .5225 .46726 L 1 g
F
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56595 .50921 L p
1 g
F P
s
P
p
.59383 .4772 m .56925 .51615 L .56595 .50921 L 1 g
F
P
p
.56535 .50351 m .56595 .50921 L .56388 .50487 L 1 g
F
P
p
.59383 .4772 m .56595 .50921 L .56535 .50351 L 1 g
F
P
p
.002 w
.56595 .50921 m .56515 .50826 L p
.56676 .51872 L 1 g
F P
s
P
p
.002 w
.56663 .5157 m .58632 .51904 L p
.56719 .52809 L 1 g
F P
s
P
p
.56676 .51872 m .56731 .5223 L .56663 .5157 L 1 g
F
P
p
.56676 .51872 m .56663 .5157 L .56595 .50921 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .5672 .5283 L p
1 g
F P
s
P
p
.002 w
.58632 .51904 m .56818 .55017 L p
.5672 .5283 L 1 g
F P
s
P
p
.56727 .52805 m .5672 .5283 L .56719 .52809 L 1 g
F
P
p
.58632 .51904 m .5672 .5283 L .56727 .52805 L 1 g
F
P
p
.002 w
.5672 .5283 m .56654 .52734 L p
.56509 .53527 L 1 g
F P
s
P
p
.56515 .50826 m .5672 .5283 L .56685 .52065 L 1 g
F
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56152 .54711 L p
1 g
F P
s
P
p
.56717 .52839 m .56643 .53971 L .56369 .53991 L 1 g
F
P
p
.002 w
.56545 .55487 m .55857 .55155 L p
.56643 .53971 L 1 g
F P
s
P
p
.56654 .52734 m .56152 .54711 L .56509 .53527 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54906 .56267 L p
1 g
F P
s
P
p
.56545 .55487 m .53361 .58074 L .54906 .56267 L 1 g
F
P
p
.55913 .55578 m .54906 .56267 L .55436 .55647 L 1 g
F
P
p
.56545 .55487 m .54906 .56267 L .55913 .55578 L 1 g
F
P
p
.002 w
.54906 .56267 m .54854 .56129 L p
.54208 .56745 L 1 g
F P
s
P
p
.56075 .54566 m .54906 .56267 L .55494 .55579 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53169 .57455 L p
1 g
F P
s
P
p
.54906 .56267 m .54243 .57043 L .53909 .56949 L 1 g
F
P
p
.002 w
.53361 .58074 m .5283 .57586 L p
.54243 .57043 L 1 g
F P
s
P
p
.54854 .56129 m .53169 .57455 L .54208 .56745 L 1 g
F
P
p
.51734 .57847 m .50267 .58024 L .48327 .57337 L 1 g
F
P
p
.52501 .57962 m .51089 .58001 L .51734 .57847 L 1 g
F
P
p
.51089 .58001 m .50267 .58024 L .51734 .57847 L 1 g
F
P
p
.002 w
.53169 .57455 m .53128 .57265 L p
.52218 .57732 L 1 g
F P
s
P
p
.52218 .57732 m .5283 .57586 L .53169 .57455 L 1 g
F
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48327 .57337 m .51361 .56236 L .5283 .57586 L p
1 g
F P
s
P
p
.002 w
.5283 .57586 m .53383 .58094 L p
.51734 .57847 L 1 g
F P
s
P
p
.51734 .57847 m .48327 .57337 L .5283 .57586 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .5318 .57502 L p
1 g
F P
s
P
p
.002 w
.5318 .57502 m .53169 .57455 L p
.52881 .57574 L 1 g
F P
s
P
p
.52881 .57574 m .51111 .583 L .5318 .57502 L 1 g
F
P
p
.52218 .57732 m .51522 .58089 L .5283 .57586 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.5283 .57586 m .51361 .56236 L p
.54243 .57043 L 1 g
F P
s
P
p
.002 w
.53169 .57455 m .5322 .57686 L p
.54208 .56745 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.55436 .55647 m .54906 .56267 L .51361 .56236 L 1 g
F
P
p
.54906 .56267 m .53909 .56949 L .51361 .56236 L 1 g
F
P
p
.51522 .58089 m .51111 .583 L .53169 .57455 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54906 .56267 L p
1 g
F P
s
P
p
.54208 .56745 m .5322 .57686 L .54906 .56267 L 1 g
F
P
p
.56075 .54566 m .55494 .55579 L .55556 .55506 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55857 .55155 m .56545 .55487 L p
.55436 .55647 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.51361 .56236 m .53825 .54177 L .55857 .55155 L p
1 g
F P
s
P
p
.55436 .55647 m .51361 .56236 L .55857 .55155 L 1 g
F
P
p
.55556 .55506 m .54982 .56473 L .55227 .56103 L 1 g
F
P
p
.55494 .55579 m .54982 .56473 L .55556 .55506 L 1 g
F
P
p
.002 w
.54906 .56267 m .54982 .56473 L p
.55494 .55579 L 1 g
F P
s
P
p
.002 w
.56545 .55487 m .53383 .58094 L .53361 .58074 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55857 .55155 m .53825 .54177 L p
.56643 .53971 L 1 g
F P
s
P
p
.002 w
.56152 .54711 m .56257 .5491 L p
.56509 .53527 L 1 g
F P
s
P
p
.56719 .52809 m .56717 .52839 L .53825 .54177 L 1 g
F
P
p
.56717 .52839 m .56369 .53991 L .53825 .54177 L 1 g
F
P
p
.002 w
.54982 .56473 m .54998 .56518 L p
.55227 .56103 L 1 g
F P
s
P
p
.002 w
.56818 .55017 m .56545 .55487 L p
.56719 .52809 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .5672 .5283 L p
1 g
F P
s
P
p
.56509 .53527 m .56257 .5491 L .5672 .5283 L 1 g
F
P
p
.002 w
.5672 .5283 m .56807 .52957 L p
.56685 .52065 L 1 g
F P
s
P
p
.56515 .50826 m .56807 .52957 L .56731 .5223 L 1 g
F
P
p
.55661 .4905 m .56595 .50921 L .56147 .4998 L 1 g
F
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.56388 .50487 m .56595 .50921 L .55439 .51363 L 1 g
F
P
p
.002 w
.56925 .51615 m .56663 .5157 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.56663 .5157 m .55439 .51363 L p
.56595 .50921 L 1 g
F P
s
P
p
.002 w
.56807 .52957 m .56854 .53025 L p
.56731 .5223 L 1 g
F P
s
P
p
.002 w
.53825 .54177 m .55439 .51363 L .56663 .5157 L p
1 g
F P
s
P
p
.56719 .52809 m .53825 .54177 L .56663 .5157 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56595 .50921 L p
1 g
F P
s
P
p
.56731 .5223 m .56854 .53025 L .56595 .50921 L 1 g
F
P
p
.002 w
.56005 .48091 m .59383 .4772 L p
.56773 .50131 L 1 g
F P
s
P
p
.56773 .50131 m .56388 .50487 L .55813 .49205 L 1 g
F
P
p
.002 w
.55804 .49258 m .55813 .49205 L p
.56388 .50487 L 1 g
F P
s
P
p
.55661 .4905 m .56147 .4998 L .55804 .49258 L 1 g
F
P
p
.002 w
.55745 .49139 m .55661 .4905 L p
.55804 .49258 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55745 .49139 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.55414 .48818 m .55439 .51363 L .55186 .48598 L 1 g
F
P
p
.002 w
.56005 .48091 m .55813 .49205 L p
.5541 .48459 L 1 g
F P
s
P
p
.002 w
.55813 .49205 m .55804 .49258 L p
.55745 .49139 L 1 g
F P
s
P
p
.55813 .49205 m .55745 .49139 L .5541 .48459 L 1 g
F
P
p
.002 w
.55439 .51363 m .52024 .50555 L p
.55186 .48598 L 1 g
F P
s
P
p
.54174 .47608 m .55745 .49139 L .55278 .48686 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55804 .49258 m .55439 .51363 L p
.55414 .48818 L 1 g
F P
s
P
p
.55745 .49139 m .55414 .48818 L .5541 .48459 L 1 g
F
P
p
.55804 .49258 m .55414 .48818 L .55745 .49139 L 1 g
F
P
p
.002 w
.55749 .49144 m .55745 .49139 L p
.55804 .49258 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55749 .49144 L p
1 g
F P
s
P
p
.56147 .4998 m .56713 .51061 L .55749 .49144 L 1 g
F
P
p
.002 w
.54742 .48167 m .52397 .48309 L p
.53524 .46982 L 1 g
F P
s
P
p
.002 w
.54243 .47684 m .54174 .47608 L p
.55029 .48445 L 1 g
F P
s
P
p
.54174 .47608 m .55278 .48686 L .55029 .48445 L 1 g
F
P
p
.002 w
.52024 .50555 m .52397 .48309 L .56005 .48091 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54243 .47684 L p
1 g
F P
s
P
p
.55029 .48445 m .55834 .49233 L .54243 .47684 L 1 g
F
P
p
.55029 .48445 m .55789 .49185 L .55203 .48616 L 1 g
F
P
p
.55278 .48686 m .55789 .49185 L .55029 .48445 L 1 g
F
P
p
.002 w
.55745 .49139 m .55789 .49185 L p
.55278 .48686 L 1 g
F P
s
P
p
.5541 .48459 m .55414 .48818 L .55186 .48598 L 1 g
F
P
p
.002 w
.55439 .51363 m .55804 .49258 L p
.56388 .50487 L 1 g
F P
s
P
p
.002 w
.55813 .49205 m .56005 .48091 L p
.56773 .50131 L 1 g
F P
s
P
p
.002 w
.55789 .49185 m .55834 .49233 L p
.55313 .48723 L 1 g
F P
s
P
p
.55203 .48616 m .55385 .48793 L .55313 .48723 L 1 g
F
P
p
.55385 .48793 m .55789 .49185 L .55313 .48723 L 1 g
F
P
p
.002 w
.56595 .50921 m .56713 .51061 L p
.56147 .4998 L 1 g
F P
s
P
p
.002 w
.59383 .4772 m .58632 .51904 L .56925 .51615 L p
1 g
F P
s
P
p
.002 w
.5544 .44723 m .56005 .48091 L .54742 .48167 L p
1 g
F P
s
P
p
.5544 .44723 m .54742 .48167 L .53524 .46982 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5225 .46726 L p
1 g
F P
s
P
p
.002 w
.5225 .46726 m .52214 .46667 L p
.53212 .47184 L 1 g
F P
s
P
p
.53212 .47184 m .54302 .47747 L .5225 .46726 L 1 g
F
P
p
.53599 .46892 m .5225 .46726 L .51999 .46005 L 1 g
F
P
p
.5 .4634 m .5225 .46726 L .52179 .46718 L 1 g
F
P
p
.5 .4634 m .52252 .4673 L .5185 .4667 L 1 g
F
P
p
.002 w
.52121 .4671 m .52112 .46661 L p
.5225 .46726 L 1 g
F P
s
P
p
.002 w
.52112 .46661 m .51999 .46005 L p
.5225 .46726 L 1 g
F P
s
P
p
.53599 .46892 m .53312 .47231 L .5225 .46726 L 1 g
F
P
p
.002 w
.54227 .47666 m .54302 .47747 L p
.53212 .47184 L 1 g
F P
s
P
p
.002 w
.5225 .46726 m .52252 .4673 L p
.52179 .46718 L 1 g
F P
s
P
p
.002 w
.51999 .46005 m .5544 .44723 L p
.53599 .46892 L 1 g
F P
s
P
p
.002 w
.52121 .4671 m .52397 .48309 L p
.51205 .46572 L 1 g
F P
s
P
p
.51218 .46574 m .5226 .46742 L .51338 .46597 L 1 g
F
P
p
.5 .4634 m .5185 .4667 L .51218 .46574 L 1 g
F
P
p
.5185 .4667 m .5226 .46742 L .51218 .46574 L 1 g
F
P
p
.002 w
.48695 .48364 m .48488 .47198 L .50599 .46481 L p
1 g
F P
s
P
p
.51205 .46572 m .48695 .48364 L .50599 .46481 L 1 g
F
P
p
.002 w
.50599 .46481 m .48488 .47198 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46386 L p
1 g
F P
s
P
p
.002 w
.5 .46386 m .5 .4634 L p
.51338 .46597 L 1 g
F P
s
P
p
.51338 .46597 m .52282 .46778 L .5 .46386 L 1 g
F
P
p
.50866 .43902 m .51628 .46131 L .5 .46386 L 1 g
F
P
p
.48955 .4655 m .5 .46386 L .48488 .47198 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46436 L p
1 g
F P
s
P
p
.002 w
.5 .46436 m .5 .46442 L p
.49798 .46462 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46436 L .49798 .46462 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.002 w
.4775 .46727 m .47718 .46778 L p
.46805 .47179 L 1 g
F P
s
P
p
.45826 .47608 m .4775 .46727 L .46805 .47179 L 1 g
F
P
p
.002 w
.45566 .47869 m .45939 .47593 L p
.45228 .48198 L 1 g
F P
s
P
p
.45826 .47608 m .46805 .47179 L .45939 .47593 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45762 .47677 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45045 .48254 m .45276 .4791 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.45939 .47593 m .45566 .47869 L p
.45762 .47677 L 1 g
F P
s
P
p
.44339 .4905 m .45762 .47677 L .45759 .47681 L 1 g
F
P
p
.44339 .4905 m .45762 .47678 L .45733 .47706 L 1 g
F
P
p
.44339 .4905 m .4576 .4768 L .45399 .48031 L 1 g
F
P
p
.002 w
.45566 .47869 m .45045 .48254 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.45762 .47677 m .45762 .47678 L p
.45759 .47681 L 1 g
F P
s
P
p
.002 w
.45762 .47678 m .45762 .47677 L p
.45939 .47593 L 1 g
F P
s
P
p
.002 w
.45762 .47677 m .45826 .47608 L p
.45939 .47593 L 1 g
F P
s
P
p
.002 w
.47031 .45293 m .47912 .46135 L .45939 .47593 L p
1 g
F P
s
P
p
.002 w
.45276 .4791 m .47031 .45293 L p
.45939 .47593 L 1 g
F P
s
P
p
.002 w
.45939 .47593 m .47912 .46135 L p
.46139 .47497 L 1 g
F P
s
P
p
.46139 .47497 m .45228 .48198 L .45939 .47593 L 1 g
F
P
p
.002 w
.47912 .46135 m .48133 .46543 L p
.4775 .46727 L 1 g
F P
s
P
p
.47019 .46821 m .4775 .46727 L .46139 .47497 L 1 g
F
P
p
.47912 .46135 m .4775 .46727 L .47019 .46821 L 1 g
F
P
p
.49168 .46255 m .5 .46386 L .48955 .4655 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.50866 .43902 m .5 .46386 L .49168 .46255 L 1 g
F
P
p
.002 w
.50599 .46481 m .51999 .46005 L p
.51205 .46572 L 1 g
F P
s
P
p
.002 w
.51999 .46005 m .52121 .4671 L p
.51205 .46572 L 1 g
F P
s
P
p
.002 w
.52252 .4673 m .5226 .46742 L p
.5185 .4667 L 1 g
F P
s
P
p
.002 w
.5226 .46742 m .52282 .46778 L p
.51338 .46597 L 1 g
F P
s
P
p
.002 w
.51628 .46131 m .50599 .46481 L p
.5 .46386 L 1 g
F P
s
P
p
.002 w
.48201 .46668 m .48488 .47198 L p
.4775 .46727 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47742 .4674 L p
1 g
F P
s
P
p
.002 w
.47742 .4674 m .4775 .46727 L p
.48164 .46674 L 1 g
F P
s
P
p
.48164 .46674 m .5 .46442 L .47742 .4674 L 1 g
F
P
p
.48992 .46544 m .49798 .46462 L .48201 .46668 L 1 g
F
P
p
.002 w
.47912 .46135 m .50866 .43902 L p
.48955 .4655 L 1 g
F P
s
P
p
.002 w
.48201 .46668 m .47912 .46135 L p
.48955 .4655 L 1 g
F P
s
P
p
.002 w
.48133 .46543 m .48201 .46668 L p
.4775 .46727 L 1 g
F P
s
P
p
.49798 .46462 m .5 .46442 L .4775 .46727 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45762 .47678 L p
1 g
F P
s
P
p
.46805 .47179 m .47718 .46778 L .45762 .47678 L 1 g
F
P
p
.002 w
.45228 .48198 m .48488 .47198 L p
.45166 .48258 L 1 g
F P
s
P
p
.44339 .4905 m .45728 .47715 L .45253 .48174 L 1 g
F
P
p
.002 w
.45228 .48198 m .45045 .48254 L .45566 .47869 L p
1 g
F P
s
P
p
.002 w
.45762 .47678 m .4576 .4768 L p
.45733 .47706 L 1 g
F P
s
P
p
.002 w
.4576 .4768 m .45728 .47715 L p
.45399 .48031 L 1 g
F P
s
P
p
.002 w
.48488 .47198 m .48695 .48364 L .45166 .48258 L p
1 g
F P
s
P
p
.002 w
.45166 .48258 m .45045 .48254 L .45228 .48198 L p
1 g
F P
s
P
p
.002 w
.44256 .49138 m .44339 .4905 L p
.45188 .48236 L 1 g
F P
s
P
p
.45188 .48236 m .45181 .48244 L .44256 .49138 L 1 g
F
P
p
.45192 .48233 m .45175 .48249 L .44256 .49138 L 1 g
F
P
p
.45199 .48226 m .45166 .48258 L .44256 .49138 L 1 g
F
P
p
.002 w
.45166 .48258 m .48695 .48364 L p
.45136 .48287 L 1 g
F P
s
P
p
.002 w
.45136 .48287 m .48514 .49506 L p
.45115 .48308 L 1 g
F P
s
P
p
.4521 .48216 m .45146 .48278 L .44256 .49138 L 1 g
F
P
p
.002 w
.45045 .48254 m .44959 .48458 L p
.4486 .48554 L 1 g
F P
s
P
p
.002 w
.44959 .48458 m .4376 .51312 L p
.4486 .48554 L 1 g
F P
s
P
p
.002 w
.45728 .47715 m .45698 .47747 L p
.45253 .48174 L 1 g
F P
s
P
p
.002 w
.45136 .48287 m .45045 .48254 L .45166 .48258 L p
1 g
F P
s
P
p
.45188 .48236 m .45192 .48233 L .45181 .48244 L 1 g
F
P
p
.45192 .48233 m .45199 .48226 L .45175 .48249 L 1 g
F
P
p
.002 w
.48514 .49506 m .47965 .50497 L .45115 .48308 L p
1 g
F P
s
P
p
.002 w
.45115 .48308 m .45045 .48254 L .45136 .48287 L p
1 g
F P
s
P
p
.002 w
.45095 .48326 m .45045 .48254 L .45115 .48308 L p
1 g
F P
s
P
p
.002 w
.45115 .48308 m .47965 .50497 L p
.45095 .48326 L 1 g
F P
s
P
p
.45199 .48226 m .4521 .48216 L .45166 .48258 L 1 g
F
P
p
.4521 .48216 m .45224 .48202 L .45146 .48278 L 1 g
F
P
p
.002 w
.47112 .51232 m .46049 .51634 L .45073 .48348 L p
1 g
F P
s
P
p
.002 w
.45073 .48348 m .45045 .48254 L .45095 .48326 L p
1 g
F P
s
P
p
.002 w
.45095 .48326 m .47112 .51232 L p
.45073 .48348 L 1 g
F P
s
P
p
.002 w
.45039 .48381 m .45045 .48254 L .45073 .48348 L p
1 g
F P
s
P
p
.002 w
.45073 .48348 m .46049 .51634 L p
.45039 .48381 L 1 g
F P
s
P
p
.45224 .48202 m .45239 .48188 L .45097 .48325 L 1 g
F
P
p
.45224 .48202 m .45097 .48325 L .44256 .49138 L 1 g
F
P
p
.45239 .48188 m .45253 .48174 L .44959 .48458 L 1 g
F
P
p
.45239 .48188 m .44959 .48458 L .44256 .49138 L 1 g
F
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.4489 .51661 m .4376 .51312 L .44959 .48458 L p
1 g
F P
s
P
p
.002 w
.44959 .48458 m .45045 .48254 L .45039 .48381 L p
1 g
F P
s
P
p
.002 w
.45039 .48381 m .4489 .51661 L p
.44959 .48458 L 1 g
F P
s
P
p
.002 w
.44314 .49019 m .45045 .48254 L p
.43342 .51021 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44256 .49138 L p
1 g
F P
s
P
p
.45253 .48174 m .45698 .47747 L .44256 .49138 L 1 g
F
P
p
.002 w
.43521 .49849 m .44314 .49019 L p
.44256 .49138 L 1 g
F P
s
P
p
.42692 .54051 m .42734 .52362 L .43363 .51035 L 1 g
F
P
p
.002 w
.42778 .50627 m .43342 .51021 L p
.42734 .52362 L 1 g
F P
s
P
p
.002 w
.43342 .51021 m .43363 .51035 L p
.42734 .52362 L 1 g
F P
s
P
p
.002 w
.43371 .50961 m .43287 .51061 L p
.43305 .51549 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43926 .49732 L p
.43722 .5024 L 1 g
F P
s
P
p
.43841 .49994 m .44166 .49233 L .43722 .5024 L 1 g
F
P
p
.002 w
.43926 .49732 m .43287 .51061 L .43367 .50966 L p
1 g
F P
s
P
p
.002 w
.43363 .51035 m .4376 .51312 L .43269 .52571 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43253 .52869 L p
1 g
F P
s
P
p
.43312 .51759 m .43287 .51061 L .43253 .52869 L 1 g
F
P
p
.43512 .53749 m .43244 .53218 L .43692 .54363 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.44894 .54737 m .43692 .54363 L p
.4376 .51312 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43837 .54732 L p
1 g
F P
s
P
p
.43244 .53218 m .43146 .53025 L .43837 .54732 L 1 g
F
P
p
.44469 .55541 m .44237 .55339 L .4498 .56195 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45079 .56309 L p
1 g
F P
s
P
p
.44237 .55339 m .43743 .5491 L .45079 .56309 L 1 g
F
P
p
.45969 .56904 m .45362 .56662 L .46649 .5736 L 1 g
F
P
p
.002 w
.46512 .57361 m .48327 .57337 L .48708 .58025 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46826 .57478 L p
1 g
F P
s
P
p
.002 w
.46826 .57478 m .4683 .57458 L p
.46682 .57381 L 1 g
F P
s
P
p
.46682 .57381 m .45002 .56518 L .46826 .57478 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48327 .57337 m .46649 .5736 L p
.44894 .54737 L 1 g
F P
s
P
p
.46649 .5736 m .46414 .57202 L .44894 .54737 L 1 g
F
P
p
.002 w
.48708 .58025 m .48327 .57337 L p
.5193 .58613 L 1 g
F P
s
P
p
.002 w
.48906 .58061 m .48889 .583 L p
.50271 .58024 L 1 g
F P
s
P
p
.002 w
.48731 .58066 m .48708 .58025 L p
.48906 .58061 L 1 g
F P
s
P
p
.002 w
.51089 .58001 m .51111 .583 L p
.52218 .57732 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51089 .58001 L p
1 g
F P
s
P
p
.50271 .58024 m .48889 .583 L .51089 .58001 L 1 g
F
P
p
.002 w
.48904 .58085 m .48906 .58061 L p
.48708 .58025 L 1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51113 .58318 L p
1 g
F P
s
P
p
.002 w
.51113 .58318 m .51111 .583 L p
.5105 .58312 L 1 g
F P
s
P
p
.5105 .58312 m .48857 .5874 L .51113 .58318 L 1 g
F
P
p
.002 w
.48889 .583 m .48857 .5874 L p
.5105 .58312 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .50938 .583 L p
.5105 .58312 L 1 g
F P
s
P
p
.002 w
.50938 .583 m .48889 .583 L p
.5105 .58312 L 1 g
F P
s
P
p
.45362 .56662 m .45002 .56518 L .4683 .57458 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48904 .58085 L p
1 g
F P
s
P
p
.47887 .57777 m .4678 .57686 L .48904 .58085 L 1 g
F
P
p
.002 w
.64979 .46596 m .64087 .40844 L .66086 .39699 L p
1 g
F P
s
P
p
.002 w
.63108 .34019 m .66086 .39699 L .64087 .40844 L p
1 g
F P
s
P
p
.002 w
.56964 .31418 m .51568 .28887 L .52618 .26836 L p
1 g
F P
s
P
p
.002 w
.52618 .26836 m .5843 .29551 L .56964 .31418 L p
1 g
F P
s
P
p
.002 w
.36777 .42309 m .35817 .4539 L .33623 .44303 L p
1 g
F P
s
P
p
.002 w
.33623 .44303 m .34826 .40373 L .36777 .42309 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.004 w
.47467 .4571 m
.5 .43051 L
s
P
p
.002 w
.53383 .58094 m .56545 .55487 L .58997 .5639 L p
1 g
F P
s
P
p
.002 w
.61491 .52164 m .58997 .5639 L .56545 .55487 L p
1 g
F P
s
P
p
.002 w
.40772 .34846 m .37287 .37095 L .3627 .34686 L p
1 g
F P
s
P
p
.002 w
.3627 .34686 m .40378 .32 L .40772 .34846 L p
1 g
F P
s
P
p
.002 w
.64087 .40844 m .61312 .35571 L .63108 .34019 L p
1 g
F P
s
P
p
.002 w
.5843 .29551 m .63108 .34019 L .61312 .35571 L p
1 g
F P
s
P
p
.002 w
.61312 .35571 m .56964 .31418 L .5843 .29551 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.39359 .50868 m .40782 .52715 L .3912 .54453 L p
1 g
F P
s
P
p
.002 w
.3912 .54453 m .37066 .51791 L .39359 .50868 L p
1 g
F P
s
P
p
.002 w
.41875 .56383 m .3912 .54453 L .40782 .52715 L p
1 g
F P
s
P
p
.002 w
.45051 .57382 m .41875 .56383 L .42692 .54051 L p
1 g
F P
s
P
p
.002 w
.40782 .52715 m .42692 .54051 L .41875 .56383 L p
1 g
F P
s
P
p
.002 w
.38573 .48701 m .39359 .50868 L .37066 .51791 L p
1 g
F P
s
P
p
.002 w
.37066 .51791 m .35922 .48664 L .38573 .48701 L p
1 g
F P
s
P
p
.002 w
.38722 .39753 m .36777 .42309 L .34826 .40373 L p
1 g
F P
s
P
p
.002 w
.34826 .40373 m .37287 .37095 L .38722 .39753 L p
1 g
F P
s
P
p
.002 w
.61491 .52164 m .62407 .47214 L .64979 .46596 L p
1 g
F P
s
P
p
.002 w
.64087 .40844 m .64979 .46596 L .62407 .47214 L p
1 g
F P
s
P
p
.002 w
.50438 .31437 m .45283 .30859 L .4578 .28259 L p
1 g
F P
s
P
p
.002 w
.4578 .28259 m .51568 .28887 L .50438 .31437 L p
1 g
F P
s
P
p
.002 w
.3851 .46439 m .38573 .48701 L .35922 .48664 L p
1 g
F P
s
P
p
.002 w
.35922 .48664 m .35817 .4539 L .3851 .46439 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.56545 .55487 m .58632 .51904 L .61491 .52164 L p
1 g
F P
s
P
p
.002 w
.62407 .47214 m .61491 .52164 L .58632 .51904 L p
1 g
F P
s
P
p
.002 w
.44918 .33905 m .40772 .34846 L .40378 .32 L p
1 g
F P
s
P
p
.002 w
.40378 .32 m .45283 .30859 L .44918 .33905 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.44894 .54737 m .47157 .54696 L .48327 .57337 L p
1 g
F P
s
P
p
.002 w
.51361 .56236 m .48327 .57337 L .47157 .54696 L p
1 g
F P
s
P
p
.002 w
.39185 .44318 m .3851 .46439 L .35817 .4539 L p
1 g
F P
s
P
p
.002 w
.35817 .4539 m .36777 .42309 L .39185 .44318 L p
1 g
F P
s
P
p
.002 w
.62407 .47214 m .61594 .42092 L .64087 .40844 L p
1 g
F P
s
P
p
.002 w
.61312 .35571 m .64087 .40844 L .61594 .42092 L p
1 g
F P
s
P
p
.002 w
.55239 .33701 m .50438 .31437 L .51568 .28887 L p
1 g
F P
s
P
p
.002 w
.51568 .28887 m .56964 .31418 L .55239 .33701 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41459 .38012 m .38722 .39753 L .37287 .37095 L p
1 g
F P
s
P
p
.002 w
.37287 .37095 m .40772 .34846 L .41459 .38012 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.61594 .42092 m .59112 .374 L .61312 .35571 L p
1 g
F P
s
P
p
.002 w
.56964 .31418 m .61312 .35571 L .59112 .374 L p
1 g
F P
s
P
p
.002 w
.59112 .374 m .55239 .33701 L .56964 .31418 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.42048 .49678 m .42778 .50627 L .40782 .52715 L p
1 g
F P
s
P
p
.002 w
.40782 .52715 m .39359 .50868 L .42048 .49678 L p
1 g
F P
s
P
p
.002 w
.42692 .54051 m .40782 .52715 L .42778 .50627 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.47157 .54696 m .49245 .53925 L .51361 .56236 L p
1 g
F P
s
P
p
.002 w
.53825 .54177 m .51361 .56236 L .49245 .53925 L p
1 g
F P
s
P
p
.002 w
.40535 .42569 m .39185 .44318 L .36777 .42309 L p
1 g
F P
s
P
p
.002 w
.36777 .42309 m .38722 .39753 L .40535 .42569 L p
1 g
F P
s
P
p
.002 w
.41648 .48565 m .42048 .49678 L .39359 .50868 L p
1 g
F P
s
P
p
.002 w
.39359 .50868 m .38573 .48701 L .41648 .48565 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.58632 .51904 m .59383 .4772 L .62407 .47214 L p
1 g
F P
s
P
p
.002 w
.61594 .42092 m .62407 .47214 L .59383 .4772 L p
1 g
F P
s
P
p
.002 w
.49265 .34411 m .44918 .33905 L .45283 .30859 L p
1 g
F P
s
P
p
.002 w
.45283 .30859 m .50438 .31437 L .49265 .34411 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.4376 .51312 m .4489 .51661 L .44894 .54737 L p
1 g
F P
s
P
p
.002 w
.47157 .54696 m .44894 .54737 L .4489 .51661 L p
1 g
F P
s
P
p
.002 w
.41622 .47406 m .41648 .48565 L .38573 .48701 L p
1 g
F P
s
P
p
.002 w
.38573 .48701 m .3851 .46439 L .41622 .47406 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44703 .37297 m .41459 .38012 L .40772 .34846 L p
1 g
F P
s
P
p
.002 w
.40772 .34846 m .44918 .33905 L .44703 .37297 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.4489 .51661 m .46049 .51634 L .47157 .54696 L p
1 g
F P
s
P
p
.002 w
.49245 .53925 m .47157 .54696 L .46049 .51634 L p
1 g
F P
s
P
p
.002 w
.41974 .46325 m .41622 .47406 L .3851 .46439 L p
1 g
F P
s
P
p
.002 w
.3851 .46439 m .39185 .44318 L .41974 .46325 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.49245 .53925 m .5093 .52496 L .53825 .54177 L p
1 g
F P
s
P
p
.002 w
.55439 .51363 m .53825 .54177 L .5093 .52496 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.42425 .41388 m .40535 .42569 L .38722 .39753 L p
1 g
F P
s
P
p
.002 w
.38722 .39753 m .41459 .38012 L .42425 .41388 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59383 .4772 m .58679 .43401 L .61594 .42092 L p
1 g
F P
s
P
p
.002 w
.59112 .374 m .61594 .42092 L .58679 .43401 L p
1 g
F P
s
P
p
.002 w
.53311 .3633 m .49265 .34411 L .50438 .31437 L p
1 g
F P
s
P
p
.002 w
.50438 .31437 m .55239 .33701 L .53311 .3633 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.46049 .51634 m .47112 .51232 L .49245 .53925 L p
1 g
F P
s
P
p
.002 w
.5093 .52496 m .49245 .53925 L .47112 .51232 L p
1 g
F P
s
P
p
.002 w
.42669 .4544 m .41974 .46325 L .39185 .44318 L p
1 g
F P
s
P
p
.002 w
.39185 .44318 m .40535 .42569 L .42669 .4544 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.58679 .43401 m .56576 .39449 L .59112 .374 L p
1 g
F P
s
P
p
.002 w
.55239 .33701 m .59112 .374 L .56576 .39449 L p
1 g
F P
s
P
p
.002 w
.56576 .39449 m .53311 .3633 L .55239 .33701 L p
1 g
F P
s
P
p
.002 w
.58679 .43401 m .59383 .4772 L .56005 .48091 L p
1 g
F P
s
P
p
.002 w
.42778 .50627 m .42048 .49678 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.48095 .37707 m .44703 .37297 L .44918 .33905 L p
1 g
F P
s
P
p
.002 w
.44918 .33905 m .49265 .34411 L .48095 .37707 L p
1 g
F P
s
P
p
.002 w
.42048 .49678 m .41648 .48565 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.41648 .48565 m .41622 .47406 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.5093 .52496 m .52024 .50555 L .55439 .51363 L p
1 g
F P
s
P
p
.002 w
.44652 .40912 m .42425 .41388 L .41459 .38012 L p
1 g
F P
s
P
p
.002 w
.41459 .38012 m .44703 .37297 L .44652 .40912 L p
1 g
F P
s
P
p
.002 w
.47112 .51232 m .47965 .50497 L .5093 .52496 L p
1 g
F P
s
P
p
.002 w
.52024 .50555 m .5093 .52496 L .47965 .50497 L p
1 g
F P
s
P
p
.002 w
.43635 .44846 m .42669 .4544 L .40535 .42569 L p
1 g
F P
s
P
p
.002 w
.40535 .42569 m .42425 .41388 L .43635 .44846 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41622 .47406 m .41974 .46325 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.56005 .48091 m .5544 .44723 L .58679 .43401 L p
1 g
F P
s
P
p
.002 w
.56576 .39449 m .58679 .43401 L .5544 .44723 L p
1 g
F P
s
P
p
.002 w
.51246 .39212 m .48095 .37707 L .49265 .34411 L p
1 g
F P
s
P
p
.002 w
.49265 .34411 m .53311 .3633 L .51246 .39212 L p
1 g
F P
s
P
p
.002 w
.41974 .46325 m .42669 .4544 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.46972 .41205 m .44652 .40912 L .44703 .37297 L p
1 g
F P
s
P
p
.002 w
.44703 .37297 m .48095 .37707 L .46972 .41205 L p
1 g
F P
s
P
p
.002 w
.47965 .50497 m .48514 .49506 L .52024 .50555 L p
1 g
F P
s
P
p
.002 w
.52397 .48309 m .52024 .50555 L .48514 .49506 L p
1 g
F P
s
P
p
.002 w
.44767 .44613 m .43635 .44846 L .42425 .41388 L p
1 g
F P
s
P
p
.002 w
.42425 .41388 m .44652 .40912 L .44767 .44613 L p
1 g
F P
s
P
p
.002 w
.42669 .4544 m .43635 .44846 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.5544 .44723 m .53793 .41644 L .56576 .39449 L p
1 g
F P
s
P
p
.002 w
.53311 .3633 m .56576 .39449 L .53793 .41644 L p
1 g
F P
s
P
p
.002 w
.53793 .41644 m .51246 .39212 L .53311 .3633 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.45942 .44767 m .47031 .45293 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.44767 .44613 m .45942 .44767 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.43635 .44846 m .44767 .44613 L .45045 .48254 L closepath p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.48514 .49506 m .48695 .48364 L .52397 .48309 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.004 w
.44886 .48421 m
.45045 .48254 L
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.45942 .44767 m .44767 .44613 L .44652 .40912 L p
1 g
F P
s
P
p
.002 w
.44652 .40912 m .46972 .41205 L .45942 .44767 L p
1 g
F P
s
P
p
.002 w
.53793 .41644 m .5544 .44723 L .51999 .46005 L p
1 g
F P
s
P
p
.002 w
.49125 .42239 m .46972 .41205 L .48095 .37707 L p
1 g
F P
s
P
p
.002 w
.48095 .37707 m .51246 .39212 L .49125 .42239 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.47031 .45293 m .45942 .44767 L .46972 .41205 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51999 .46005 m .50866 .43902 L .53793 .41644 L p
1 g
F P
s
P
p
.002 w
.51246 .39212 m .53793 .41644 L .50866 .43902 L p
1 g
F P
s
P
p
.002 w
.50866 .43902 m .49125 .42239 L .51246 .39212 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.47912 .46135 m .47031 .45293 L .49125 .42239 L p
1 g
F P
s
P
p
.002 w
.49125 .42239 m .50866 .43902 L .47912 .46135 L p
1 g
F P
s
P
p
.002 w
.46972 .41205 m .49125 .42239 L .47031 .45293 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.004 w
.41998 .51453 m
.44886 .48421 L
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .27397 .6242 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .41998 .51453 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.672868)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.672868)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.46967 .43947 m .48362 .45161 L .49861 .42734 L p
1 g
F P
s
P
p
.002 w
.49861 .42734 m .49155 .42118 L .46967 .43947 L p
1 g
F P
s
P
p
.002 w
.50727 .43091 m .49861 .42734 L .48362 .45161 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .49155 .42118 L .49861 .42734 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .49861 .42734 L .50727 .43091 L closepath p
1 g
F P
s
P
p
.002 w
.48362 .45161 m .50073 .45867 L .50727 .43091 L p
1 g
F P
s
P
p
.002 w
.5166 .43152 m .50727 .43091 L .50073 .45867 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .50727 .43091 L .5166 .43152 L closepath p
1 g
F P
s
P
p
.002 w
.46036 .42352 m .46967 .43947 L .49155 .42118 L p
1 g
F P
s
P
p
.002 w
.49155 .42118 m .48685 .41311 L .46036 .42352 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .48685 .41311 L .49155 .42118 L closepath p
1 g
F P
s
P
p
.002 w
.50073 .45867 m .51918 .4599 L .5166 .43152 L p
1 g
F P
s
P
p
.002 w
.52561 .4291 m .5166 .43152 L .51918 .4599 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .5166 .43152 L .52561 .4291 L closepath p
1 g
F P
s
P
p
.002 w
.4567 .40547 m .46036 .42352 L .48685 .41311 L p
1 g
F P
s
P
p
.002 w
.48685 .41311 m .48503 .40398 L .4567 .40547 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .48503 .40398 L .48685 .41311 L closepath p
1 g
F P
s
P
p
.002 w
.51918 .4599 m .537 .45515 L .52561 .4291 L p
1 g
F P
s
P
p
.002 w
.53332 .42389 m .52561 .4291 L .537 .45515 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .52561 .4291 L .53332 .42389 L closepath p
1 g
F P
s
P
p
.002 w
.44838 .45765 m .46895 .47552 L .48362 .45161 L p
1 g
F P
s
P
p
.002 w
.48362 .45161 m .46967 .43947 L .44838 .45765 L p
1 g
F P
s
P
p
.002 w
.50073 .45867 m .48362 .45161 L .46895 .47552 L p
1 g
F P
s
P
p
.002 w
.46895 .47552 m .49414 .48592 L .50073 .45867 L p
1 g
F P
s
P
p
.002 w
.51918 .4599 m .50073 .45867 L .49414 .48592 L p
1 g
F P
s
P
p
.002 w
.45913 .38724 m .4567 .40547 L .48503 .40398 L p
1 g
F P
s
P
p
.002 w
.48503 .40398 m .48628 .39477 L .45913 .38724 L p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .48628 .39477 L .48503 .40398 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .53332 .42389 L .53889 .41647 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .53889 .41647 L .54172 .40761 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .54172 .40761 L .54148 .39829 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .54148 .39829 L .5382 .38951 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .5382 .38951 L .53223 .38224 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .53223 .38224 L .52421 .37727 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .52421 .37727 L .51503 .37515 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .51503 .37515 L .50568 .37611 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .50568 .37611 L .49719 .38003 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .49719 .38003 L .49049 .38649 L closepath p
1 g
F P
s
P
p
.002 w
.51363 .40313 m .49049 .38649 L .48628 .39477 L closepath p
1 g
F P
s
P
p
.002 w
.43462 .43418 m .44838 .45765 L .46967 .43947 L p
1 g
F P
s
P
p
.002 w
.46967 .43947 m .46036 .42352 L .43462 .43418 L p
1 g
F P
s
P
p
.002 w
.537 .45515 m .55228 .4449 L .53332 .42389 L p
1 g
F P
s
P
p
.002 w
.53889 .41647 m .53332 .42389 L .55228 .4449 L p
1 g
F P
s
P
p
.002 w
.49414 .48592 m .5213 .48777 L .51918 .4599 L p
1 g
F P
s
P
p
.002 w
.537 .45515 m .51918 .4599 L .5213 .48777 L p
1 g
F P
s
P
p
.002 w
.4674 .3708 m .45913 .38724 L .48628 .39477 L p
1 g
F P
s
P
p
.002 w
.48628 .39477 m .49049 .38649 L .4674 .3708 L p
1 g
F P
s
P
p
.002 w
.42917 .40759 m .43462 .43418 L .46036 .42352 L p
1 g
F P
s
P
p
.002 w
.46036 .42352 m .4567 .40547 L .42917 .40759 L p
1 g
F P
s
P
p
.002 w
.55228 .4449 m .56336 .43023 L .53889 .41647 L p
1 g
F P
s
P
p
.002 w
.54172 .40761 m .53889 .41647 L .56336 .43023 L p
1 g
F P
s
P
p
.002 w
.5213 .48777 m .54757 .48082 L .537 .45515 L p
1 g
F P
s
P
p
.002 w
.55228 .4449 m .537 .45515 L .54757 .48082 L p
1 g
F P
s
P
p
.002 w
.48067 .35795 m .4674 .3708 L .49049 .38649 L p
1 g
F P
s
P
p
.002 w
.49049 .38649 m .49719 .38003 L .48067 .35795 L p
1 g
F P
s
P
p
.002 w
.56336 .43023 m .56903 .41269 L .54172 .40761 L p
1 g
F P
s
P
p
.002 w
.54148 .39829 m .54172 .40761 L .56903 .41269 L p
1 g
F P
s
P
p
.002 w
.43266 .38068 m .42917 .40759 L .4567 .40547 L p
1 g
F P
s
P
p
.002 w
.4567 .40547 m .45913 .38724 L .43266 .38068 L p
1 g
F P
s
P
p
.002 w
.4975 .35011 m .48067 .35795 L .49719 .38003 L p
1 g
F P
s
P
p
.002 w
.49719 .38003 m .50568 .37611 L .4975 .35011 L p
1 g
F P
s
P
p
.002 w
.56903 .41269 m .56861 .39418 L .54148 .39829 L p
1 g
F P
s
P
p
.002 w
.5382 .38951 m .54148 .39829 L .56861 .39418 L p
1 g
F P
s
P
p
.002 w
.54757 .48082 m .57015 .46577 L .55228 .4449 L p
1 g
F P
s
P
p
.002 w
.56336 .43023 m .55228 .4449 L .57015 .46577 L p
1 g
F P
s
P
p
.002 w
.42809 .47539 m .45485 .49861 L .46895 .47552 L p
1 g
F P
s
P
p
.002 w
.46895 .47552 m .44838 .45765 L .42809 .47539 L p
1 g
F P
s
P
p
.002 w
.49414 .48592 m .46895 .47552 L .45485 .49861 L p
1 g
F P
s
P
p
.002 w
.51607 .34817 m .4975 .35011 L .50568 .37611 L p
1 g
F P
s
P
p
.002 w
.50568 .37611 m .51503 .37515 L .51607 .34817 L p
1 g
F P
s
P
p
.002 w
.45485 .49861 m .48761 .51215 L .49414 .48592 L p
1 g
F P
s
P
p
.002 w
.5213 .48777 m .49414 .48592 L .48761 .51215 L p
1 g
F P
s
P
p
.002 w
.56861 .39418 m .56213 .37673 L .5382 .38951 L p
1 g
F P
s
P
p
.002 w
.53223 .38224 m .5382 .38951 L .56213 .37673 L p
1 g
F P
s
P
p
.002 w
.53434 .35238 m .51607 .34817 L .51503 .37515 L p
1 g
F P
s
P
p
.002 w
.51503 .37515 m .52421 .37727 L .53434 .35238 L p
1 g
F P
s
P
p
.002 w
.56213 .37673 m .55028 .36226 L .53223 .38224 L p
1 g
F P
s
P
p
.002 w
.52421 .37727 m .53223 .38224 L .55028 .36226 L p
1 g
F P
s
P
p
.002 w
.41014 .4449 m .42809 .47539 L .44838 .45765 L p
1 g
F P
s
P
p
.002 w
.44838 .45765 m .43462 .43418 L .41014 .4449 L p
1 g
F P
s
P
p
.002 w
.55028 .36226 m .53434 .35238 L .52421 .37727 L p
1 g
F P
s
P
p
.002 w
.4448 .35636 m .43266 .38068 L .45913 .38724 L p
1 g
F P
s
P
p
.002 w
.45913 .38724 m .4674 .3708 L .4448 .35636 L p
1 g
F P
s
P
p
.002 w
.48761 .51215 m .52293 .51459 L .5213 .48777 L p
1 g
F P
s
P
p
.002 w
.54757 .48082 m .5213 .48777 L .52293 .51459 L p
1 g
F P
s
P
p
.002 w
.57015 .46577 m .58659 .44416 L .56336 .43023 L p
1 g
F P
s
P
p
.002 w
.56903 .41269 m .56336 .43023 L .58659 .44416 L p
1 g
F P
s
P
p
.002 w
.40295 .4103 m .41014 .4449 L .43462 .43418 L p
1 g
F P
s
P
p
.002 w
.43462 .43418 m .42917 .40759 L .40295 .4103 L p
1 g
F P
s
P
p
.002 w
.46436 .3373 m .4448 .35636 L .4674 .3708 L p
1 g
F P
s
P
p
.002 w
.4674 .3708 m .48067 .35795 L .46436 .3373 L p
1 g
F P
s
P
p
.002 w
.52293 .51459 m .55714 .50563 L .54757 .48082 L p
1 g
F P
s
P
p
.002 w
.57015 .46577 m .54757 .48082 L .55714 .50563 L p
1 g
F P
s
P
p
.002 w
.58659 .44416 m .59503 .41827 L .56903 .41269 L p
1 g
F P
s
P
p
.002 w
.56861 .39418 m .56903 .41269 L .59503 .41827 L p
1 g
F P
s
P
p
.002 w
.4074 .37524 m .40295 .4103 L .42917 .40759 L p
1 g
F P
s
P
p
.002 w
.42917 .40759 m .43266 .38068 L .4074 .37524 L p
1 g
F P
s
P
p
.002 w
.48924 .32564 m .46436 .3373 L .48067 .35795 L p
1 g
F P
s
P
p
.002 w
.48067 .35795 m .4975 .35011 L .48924 .32564 L p
1 g
F P
s
P
p
.002 w
.59503 .41827 m .5945 .3909 L .56861 .39418 L p
1 g
F P
s
P
p
.002 w
.56213 .37673 m .56861 .39418 L .5945 .3909 L p
1 g
F P
s
P
p
.002 w
.55714 .50563 m .58659 .48611 L .57015 .46577 L p
1 g
F P
s
P
p
.002 w
.58659 .44416 m .57015 .46577 L .58659 .48611 L p
1 g
F P
s
P
p
.002 w
.51674 .32273 m .48924 .32564 L .4975 .35011 L p
1 g
F P
s
P
p
.002 w
.4975 .35011 m .51607 .34817 L .51674 .32273 L p
1 g
F P
s
P
p
.002 w
.40919 .49237 m .44161 .52045 L .45485 .49861 L p
1 g
F P
s
P
p
.002 w
.45485 .49861 m .42809 .47539 L .40919 .49237 L p
1 g
F P
s
P
p
.002 w
.48761 .51215 m .45485 .49861 L .44161 .52045 L p
1 g
F P
s
P
p
.002 w
.5945 .3909 m .58496 .36505 L .56213 .37673 L p
1 g
F P
s
P
p
.002 w
.55028 .36226 m .56213 .37673 L .58496 .36505 L p
1 g
F P
s
P
p
.002 w
.44161 .52045 m .48126 .53685 L .48761 .51215 L p
1 g
F P
s
P
p
.002 w
.52293 .51459 m .48761 .51215 L .48126 .53685 L p
1 g
F P
s
P
p
.002 w
.42313 .34348 m .4074 .37524 L .43266 .38068 L p
1 g
F P
s
P
p
.002 w
.43266 .38068 m .4448 .35636 L .42313 .34348 L p
1 g
F P
s
P
p
.002 w
.54381 .32894 m .51674 .32273 L .51607 .34817 L p
1 g
F P
s
P
p
.002 w
.51607 .34817 m .53434 .35238 L .54381 .32894 L p
1 g
F P
s
P
p
.002 w
.38739 .45548 m .40919 .49237 L .42809 .47539 L p
1 g
F P
s
P
p
.002 w
.42809 .47539 m .41014 .4449 L .38739 .45548 L p
1 g
F P
s
P
p
.002 w
.58496 .36505 m .56742 .34359 L .55028 .36226 L p
1 g
F P
s
P
p
.002 w
.53434 .35238 m .55028 .36226 L .56742 .34359 L p
1 g
F P
s
P
p
.002 w
.56742 .34359 m .54381 .32894 L .53434 .35238 L p
1 g
F P
s
P
p
.002 w
.48126 .53685 m .52403 .53985 L .52293 .51459 L p
1 g
F P
s
P
p
.002 w
.55714 .50563 m .52293 .51459 L .52403 .53985 L p
1 g
F P
s
P
p
.002 w
.58659 .48611 m .60809 .45801 L .58659 .44416 L p
1 g
F P
s
P
p
.002 w
.59503 .41827 m .58659 .44416 L .60809 .45801 L p
1 g
F P
s
P
p
.002 w
.37859 .41358 m .38739 .45548 L .41014 .4449 L p
1 g
F P
s
P
p
.002 w
.41014 .4449 m .40295 .4103 L .37859 .41358 L p
1 g
F P
s
P
p
.002 w
.44859 .31853 m .42313 .34348 L .4448 .35636 L p
1 g
F P
s
P
p
.002 w
.4448 .35636 m .46436 .3373 L .44859 .31853 L p
1 g
F P
s
P
p
.002 w
.52403 .53985 m .56548 .52908 L .55714 .50563 L p
1 g
F P
s
P
p
.002 w
.58659 .48611 m .55714 .50563 L .56548 .52908 L p
1 g
F P
s
P
p
.002 w
.60809 .45801 m .61921 .42428 L .59503 .41827 L p
1 g
F P
s
P
p
.002 w
.5945 .3909 m .59503 .41827 L .61921 .42428 L p
1 g
F P
s
P
p
.002 w
.38386 .37105 m .37859 .41358 L .40295 .4103 L p
1 g
F P
s
P
p
.002 w
.40295 .4103 m .4074 .37524 L .38386 .37105 L p
1 g
F P
s
P
p
.002 w
.48106 .30323 m .44859 .31853 L .46436 .3373 L p
1 g
F P
s
P
p
.002 w
.46436 .3373 m .48924 .32564 L .48106 .30323 L p
1 g
F P
s
P
p
.002 w
.61921 .42428 m .6186 .38854 L .5945 .3909 L p
1 g
F P
s
P
p
.002 w
.58496 .36505 m .5945 .3909 L .6186 .38854 L p
1 g
F P
s
P
p
.002 w
.56548 .52908 m .60124 .50551 L .58659 .48611 L p
1 g
F P
s
P
p
.002 w
.60809 .45801 m .58659 .48611 L .60124 .50551 L p
1 g
F P
s
P
p
.002 w
.51701 .29937 m .48106 .30323 L .48924 .32564 L p
1 g
F P
s
P
p
.002 w
.48924 .32564 m .51674 .32273 L .51701 .29937 L p
1 g
F P
s
P
p
.002 w
.39211 .5082 m .42952 .54056 L .44161 .52045 L p
1 g
F P
s
P
p
.002 w
.44161 .52045 m .40919 .49237 L .39211 .5082 L p
1 g
F P
s
P
p
.002 w
.48126 .53685 m .44161 .52045 L .42952 .54056 L p
1 g
F P
s
P
p
.002 w
.6186 .38854 m .6062 .35472 L .58496 .36505 L p
1 g
F P
s
P
p
.002 w
.56742 .34359 m .58496 .36505 L .6062 .35472 L p
1 g
F P
s
P
p
.002 w
.40285 .33246 m .38386 .37105 L .4074 .37524 L p
1 g
F P
s
P
p
.002 w
.4074 .37524 m .42313 .34348 L .40285 .33246 L p
1 g
F P
s
P
p
.002 w
.42952 .54056 m .47523 .55948 L .48126 .53685 L p
1 g
F P
s
P
p
.002 w
.52403 .53985 m .48126 .53685 L .47523 .55948 L p
1 g
F P
s
P
p
.002 w
.55242 .30746 m .51701 .29937 L .51674 .32273 L p
1 g
F P
s
P
p
.002 w
.51674 .32273 m .54381 .32894 L .55242 .30746 L p
1 g
F P
s
P
p
.002 w
.3669 .46569 m .39211 .5082 L .40919 .49237 L p
1 g
F P
s
P
p
.002 w
.40919 .49237 m .38739 .45548 L .3669 .46569 L p
1 g
F P
s
P
p
.002 w
.6062 .35472 m .5833 .32664 L .56742 .34359 L p
1 g
F P
s
P
p
.002 w
.54381 .32894 m .56742 .34359 L .5833 .32664 L p
1 g
F P
s
P
p
.002 w
.5833 .32664 m .55242 .30746 L .54381 .32894 L p
1 g
F P
s
P
p
.002 w
.60124 .50551 m .6274 .47151 L .60809 .45801 L p
1 g
F P
s
P
p
.002 w
.61921 .42428 m .60809 .45801 L .6274 .47151 L p
1 g
F P
s
P
p
.002 w
.47523 .55948 m .52455 .563 L .52403 .53985 L p
1 g
F P
s
P
p
.002 w
.56548 .52908 m .52403 .53985 L .52455 .563 L p
1 g
F P
s
P
p
.002 w
.35664 .41737 m .3669 .46569 L .38739 .45548 L p
1 g
F P
s
P
p
.002 w
.38739 .45548 m .37859 .41358 L .35664 .41737 L p
1 g
F P
s
P
p
.002 w
.43369 .30208 m .40285 .33246 L .42313 .34348 L p
1 g
F P
s
P
p
.002 w
.42313 .34348 m .44859 .31853 L .43369 .30208 L p
1 g
F P
s
P
p
.002 w
.52455 .563 m .57239 .55065 L .56548 .52908 L p
1 g
F P
s
P
p
.002 w
.60124 .50551 m .56548 .52908 L .57239 .55065 L p
1 g
F P
s
P
p
.002 w
.6274 .47151 m .64101 .4306 L .61921 .42428 L p
1 g
F P
s
P
p
.002 w
.6186 .38854 m .61921 .42428 L .64101 .4306 L p
1 g
F P
s
P
p
.002 w
.36261 .36825 m .35664 .41737 L .37859 .41358 L p
1 g
F P
s
P
p
.002 w
.37859 .41358 m .38386 .37105 L .36261 .36825 L p
1 g
F P
s
P
p
.002 w
.47313 .2834 m .43369 .30208 L .44859 .31853 L p
1 g
F P
s
P
p
.002 w
.44859 .31853 m .48106 .30323 L .47313 .2834 L p
1 g
F P
s
P
p
.002 w
.64101 .4306 m .64037 .38717 L .6186 .38854 L p
1 g
F P
s
P
p
.002 w
.6062 .35472 m .6186 .38854 L .64037 .38717 L p
1 g
F P
s
P
p
.002 w
.57239 .55065 m .61372 .52355 L .60124 .50551 L p
1 g
F P
s
P
p
.002 w
.6274 .47151 m .60124 .50551 L .61372 .52355 L p
1 g
F P
s
P
p
.002 w
.51685 .27865 m .47313 .2834 L .48106 .30323 L p
1 g
F P
s
P
p
.002 w
.48106 .30323 m .51701 .29937 L .51685 .27865 L p
1 g
F P
s
P
p
.002 w
.64037 .38717 m .62537 .34603 L .6062 .35472 L p
1 g
F P
s
P
p
.002 w
.5833 .32664 m .6062 .35472 L .62537 .34603 L p
1 g
F P
s
P
p
.002 w
.38444 .32361 m .36261 .36825 L .38386 .37105 L p
1 g
F P
s
P
p
.002 w
.38386 .37105 m .40285 .33246 L .38444 .32361 L p
1 g
F P
s
P
p
.002 w
.37727 .52253 m .41886 .55846 L .42952 .54056 L p
1 g
F P
s
P
p
.002 w
.42952 .54056 m .39211 .5082 L .37727 .52253 L p
1 g
F P
s
P
p
.002 w
.47523 .55948 m .42952 .54056 L .41886 .55846 L p
1 g
F P
s
P
p
.002 w
.41886 .55846 m .46965 .57949 L .47523 .55948 L p
1 g
F P
s
P
p
.002 w
.52455 .563 m .47523 .55948 L .46965 .57949 L p
1 g
F P
s
P
p
.002 w
.55995 .28848 m .51685 .27865 L .51701 .29937 L p
1 g
F P
s
P
p
.002 w
.51701 .29937 m .55242 .30746 L .55995 .28848 L p
1 g
F P
s
P
p
.002 w
.34919 .47532 m .37727 .52253 L .39211 .5082 L p
1 g
F P
s
P
p
.002 w
.39211 .5082 m .3669 .46569 L .34919 .47532 L p
1 g
F P
s
P
p
.002 w
.62537 .34603 m .59753 .31183 L .5833 .32664 L p
1 g
F P
s
P
p
.002 w
.55242 .30746 m .5833 .32664 L .59753 .31183 L p
1 g
F P
s
P
p
.002 w
.59753 .31183 m .55995 .28848 L .55242 .30746 L p
1 g
F P
s
P
p
.002 w
.61372 .52355 m .64404 .48436 L .6274 .47151 L p
1 g
F P
s
P
p
.002 w
.64101 .4306 m .6274 .47151 L .64404 .48436 L p
1 g
F P
s
P
p
.002 w
.46965 .57949 m .52446 .58346 L .52455 .563 L p
1 g
F P
s
P
p
.002 w
.57239 .55065 m .52455 .563 L .52446 .58346 L p
1 g
F P
s
P
p
.002 w
.33768 .42161 m .34919 .47532 L .3669 .46569 L p
1 g
F P
s
P
p
.002 w
.3669 .46569 m .35664 .41737 L .33768 .42161 L p
1 g
F P
s
P
p
.002 w
.42002 .28841 m .38444 .32361 L .40285 .33246 L p
1 g
F P
s
P
p
.002 w
.40285 .33246 m .43369 .30208 L .42002 .28841 L p
1 g
F P
s
P
p
.002 w
.52446 .58346 m .57766 .56982 L .57239 .55065 L p
1 g
F P
s
P
p
.002 w
.61372 .52355 m .57239 .55065 L .57766 .56982 L p
1 g
F P
s
P
p
.002 w
.64404 .48436 m .65987 .43711 L .64101 .4306 L p
1 g
F P
s
P
p
.002 w
.64037 .38717 m .64101 .4306 L .65987 .43711 L p
1 g
F P
s
P
p
.002 w
.3442 .36697 m .33768 .42161 L .35664 .41737 L p
1 g
F P
s
P
p
.002 w
.35664 .41737 m .36261 .36825 L .3442 .36697 L p
1 g
F P
s
P
p
.002 w
.46563 .26672 m .42002 .28841 L .43369 .30208 L p
1 g
F P
s
P
p
.002 w
.43369 .30208 m .47313 .2834 L .46563 .26672 L p
1 g
F P
s
P
p
.002 w
.65987 .43711 m .65923 .38687 L .64037 .38717 L p
1 g
F P
s
P
p
.002 w
.62537 .34603 m .64037 .38717 L .65923 .38687 L p
1 g
F P
s
P
p
.002 w
.57766 .56982 m .62367 .53977 L .61372 .52355 L p
1 g
F P
s
P
p
.002 w
.64404 .48436 m .61372 .52355 L .62367 .53977 L p
1 g
F P
s
P
p
.002 w
.51625 .26116 m .46563 .26672 L .47313 .2834 L p
1 g
F P
s
P
p
.002 w
.47313 .2834 m .51685 .27865 L .51625 .26116 L p
1 g
F P
s
P
p
.002 w
.3684 .31724 m .3442 .36697 L .36261 .36825 L p
1 g
F P
s
P
p
.002 w
.36261 .36825 m .38444 .32361 L .3684 .31724 L p
1 g
F P
s
P
p
.002 w
.65923 .38687 m .64193 .33922 L .62537 .34603 L p
1 g
F P
s
P
p
.002 w
.59753 .31183 m .62537 .34603 L .64193 .33922 L p
1 g
F P
s
P
p
.002 w
.36509 .53497 m .40994 .57366 L .41886 .55846 L p
1 g
F P
s
P
p
.002 w
.41886 .55846 m .37727 .52253 L .36509 .53497 L p
1 g
F P
s
P
p
.002 w
.46965 .57949 m .41886 .55846 L .40994 .57366 L p
1 g
F P
s
P
p
.002 w
.40994 .57366 m .46467 .59634 L .46965 .57949 L p
1 g
F P
s
P
p
.002 w
.52446 .58346 m .46965 .57949 L .46467 .59634 L p
1 g
F P
s
P
p
.002 w
.56618 .27252 m .51625 .26116 L .51685 .27865 L p
1 g
F P
s
P
p
.002 w
.51685 .27865 m .55995 .28848 L .56618 .27252 L p
1 g
F P
s
P
p
.002 w
.33477 .48412 m .36509 .53497 L .37727 .52253 L p
1 g
F P
s
P
p
.002 w
.37727 .52253 m .34919 .47532 L .33477 .48412 L p
1 g
F P
s
P
p
.002 w
.64193 .33922 m .60973 .29958 L .59753 .31183 L p
1 g
F P
s
P
p
.002 w
.55995 .28848 m .59753 .31183 L .60973 .29958 L p
1 g
F P
s
P
p
.002 w
.62367 .53977 m .6575 .49624 L .64404 .48436 L p
1 g
F P
s
P
p
.002 w
.65987 .43711 m .64404 .48436 L .6575 .49624 L p
1 g
F P
s
P
p
.002 w
.60973 .29958 m .56618 .27252 L .55995 .28848 L p
1 g
F P
s
P
p
.002 w
.46467 .59634 m .52373 .60066 L .52446 .58346 L p
1 g
F P
s
P
p
.002 w
.57766 .56982 m .52446 .58346 L .52373 .60066 L p
1 g
F P
s
P
p
.002 w
.32228 .42625 m .33477 .48412 L .34919 .47532 L p
1 g
F P
s
P
p
.002 w
.34919 .47532 m .33768 .42161 L .32228 .42625 L p
1 g
F P
s
P
p
.002 w
.40796 .27797 m .3684 .31724 L .38444 .32361 L p
1 g
F P
s
P
p
.002 w
.38444 .32361 m .42002 .28841 L .40796 .27797 L p
1 g
F P
s
P
p
.002 w
.52373 .60066 m .58109 .58603 L .57766 .56982 L p
1 g
F P
s
P
p
.002 w
.62367 .53977 m .57766 .56982 L .58109 .58603 L p
1 g
F P
s
P
p
.002 w
.6575 .49624 m .67523 .44368 L .65987 .43711 L p
1 g
F P
s
P
p
.002 w
.65923 .38687 m .65987 .43711 L .67523 .44368 L p
1 g
F P
s
P
p
.002 w
.32922 .36732 m .32228 .42625 L .33768 .42161 L p
1 g
F P
s
P
p
.002 w
.33768 .42161 m .3442 .36697 L .32922 .36732 L p
1 g
F P
s
P
p
.002 w
.45875 .25372 m .40796 .27797 L .42002 .28841 L p
1 g
F P
s
P
p
.002 w
.42002 .28841 m .46563 .26672 L .45875 .25372 L p
1 g
F P
s
P
p
.002 w
.58109 .58603 m .63075 .55372 L .62367 .53977 L p
1 g
F P
s
P
p
.002 w
.6575 .49624 m .62367 .53977 L .63075 .55372 L p
1 g
F P
s
P
p
.002 w
.67523 .44368 m .67461 .38771 L .65923 .38687 L p
1 g
F P
s
P
p
.002 w
.64193 .33922 m .65923 .38687 L .67461 .38771 L p
1 g
F P
s
P
p
.002 w
.5152 .24747 m .45875 .25372 L .46563 .26672 L p
1 g
F P
s
P
p
.002 w
.46563 .26672 m .51625 .26116 L .5152 .24747 L p
1 g
F P
s
P
p
.002 w
.35523 .31363 m .32922 .36732 L .3442 .36697 L p
1 g
F P
s
P
p
.002 w
.3442 .36697 m .3684 .31724 L .35523 .31363 L p
1 g
F P
s
P
p
.002 w
.67461 .38771 m .65538 .33457 L .64193 .33922 L p
1 g
F P
s
P
p
.002 w
.60973 .29958 m .64193 .33922 L .65538 .33457 L p
1 g
F P
s
P
p
.002 w
.35602 .54512 m .40305 .58567 L .40994 .57366 L p
1 g
F P
s
P
p
.002 w
.40994 .57366 m .36509 .53497 L .35602 .54512 L p
1 g
F P
s
P
p
.002 w
.46467 .59634 m .40994 .57366 L .40305 .58567 L p
1 g
F P
s
P
p
.002 w
.40305 .58567 m .46043 .60945 L .46467 .59634 L p
1 g
F P
s
P
p
.002 w
.52373 .60066 m .46467 .59634 L .46043 .60945 L p
1 g
F P
s
P
p
.002 w
.57091 .26013 m .5152 .24747 L .51625 .26116 L p
1 g
F P
s
P
p
.002 w
.51625 .26116 m .56618 .27252 L .57091 .26013 L p
1 g
F P
s
P
p
.002 w
.32418 .49184 m .35602 .54512 L .36509 .53497 L p
1 g
F P
s
P
p
.002 w
.36509 .53497 m .33477 .48412 L .32418 .49184 L p
1 g
F P
s
P
p
.002 w
.63075 .55372 m .6673 .50684 L .6575 .49624 L p
1 g
F P
s
P
p
.002 w
.67523 .44368 m .6575 .49624 L .6673 .50684 L p
1 g
F P
s
P
p
.002 w
.65538 .33457 m .61949 .29032 L .60973 .29958 L p
1 g
F P
s
P
p
.002 w
.56618 .27252 m .60973 .29958 L .61949 .29032 L p
1 g
F P
s
P
p
.002 w
.61949 .29032 m .57091 .26013 L .56618 .27252 L p
1 g
F P
s
P
p
.002 w
.46043 .60945 m .52235 .61402 L .52373 .60066 L p
1 g
F P
s
P
p
.002 w
.58109 .58603 m .52373 .60066 L .52235 .61402 L p
1 g
F P
s
P
p
.002 w
.39787 .27118 m .35523 .31363 L .3684 .31724 L p
1 g
F P
s
P
p
.002 w
.3684 .31724 m .40796 .27797 L .39787 .27118 L p
1 g
F P
s
P
p
.002 w
.31101 .43118 m .32418 .49184 L .33477 .48412 L p
1 g
F P
s
P
p
.002 w
.33477 .48412 m .32228 .42625 L .31101 .43118 L p
1 g
F P
s
P
p
.002 w
.52235 .61402 m .5825 .59874 L .58109 .58603 L p
1 g
F P
s
P
p
.002 w
.63075 .55372 m .58109 .58603 L .5825 .59874 L p
1 g
F P
s
P
p
.002 w
.6673 .50684 m .68652 .45015 L .67523 .44368 L p
1 g
F P
s
P
p
.002 w
.67461 .38771 m .67523 .44368 L .68652 .45015 L p
1 g
F P
s
P
p
.002 w
.31822 .36938 m .31101 .43118 L .32228 .42625 L p
1 g
F P
s
P
p
.002 w
.32228 .42625 m .32922 .36732 L .31822 .36938 L p
1 g
F P
s
P
p
.002 w
.45269 .24494 m .39787 .27118 L .40796 .27797 L p
1 g
F P
s
P
p
.002 w
.40796 .27797 m .45875 .25372 L .45269 .24494 L p
1 g
F P
s
P
p
.002 w
.5825 .59874 m .63461 .56493 L .63075 .55372 L p
1 g
F P
s
P
p
.002 w
.6673 .50684 m .63075 .55372 L .63461 .56493 L p
1 g
F P
s
P
p
.002 w
.68652 .45015 m .68593 .38973 L .67461 .38771 L p
1 g
F P
s
P
p
.002 w
.65538 .33457 m .67461 .38771 L .68593 .38973 L p
1 g
F P
s
P
p
.002 w
.51369 .23815 m .45269 .24494 L .45875 .25372 L p
1 g
F P
s
P
p
.002 w
.45875 .25372 m .5152 .24747 L .51369 .23815 L p
1 g
F P
s
P
p
.002 w
.34544 .31304 m .31822 .36938 L .32922 .36732 L p
1 g
F P
s
P
p
.002 w
.32922 .36732 m .35523 .31363 L .34544 .31304 L p
1 g
F P
s
P
p
.002 w
.68593 .38973 m .6652 .3323 L .65538 .33457 L p
1 g
F P
s
P
p
.002 w
.61949 .29032 m .65538 .33457 L .6652 .3323 L p
1 g
F P
s
P
p
.002 w
.35046 .5526 m .39849 .59399 L .40305 .58567 L p
1 g
F P
s
P
p
.002 w
.40305 .58567 m .35602 .54512 L .35046 .5526 L p
1 g
F P
s
P
p
.002 w
.46043 .60945 m .40305 .58567 L .39849 .59399 L p
1 g
F P
s
P
p
.002 w
.39849 .59399 m .45708 .61828 L .46043 .60945 L p
1 g
F P
s
P
p
.002 w
.52235 .61402 m .46043 .60945 L .45708 .61828 L p
1 g
F P
s
P
p
.002 w
.57392 .25182 m .51369 .23815 L .5152 .24747 L p
1 g
F P
s
P
p
.002 w
.5152 .24747 m .57091 .26013 L .57392 .25182 L p
1 g
F P
s
P
p
.002 w
.63461 .56493 m .673 .51581 L .6673 .50684 L p
1 g
F P
s
P
p
.002 w
.68652 .45015 m .6673 .50684 L .673 .51581 L p
1 g
F P
s
P
p
.002 w
.31792 .49822 m .35046 .5526 L .35602 .54512 L p
1 g
F P
s
P
p
.002 w
.35602 .54512 m .32418 .49184 L .31792 .49822 L p
1 g
F P
s
P
p
.002 w
.6652 .3323 m .62643 .28447 L .61949 .29032 L p
1 g
F P
s
P
p
.002 w
.57091 .26013 m .61949 .29032 L .62643 .28447 L p
1 g
F P
s
P
p
.002 w
.62643 .28447 m .57392 .25182 L .57091 .26013 L p
1 g
F P
s
P
p
.002 w
.45708 .61828 m .5203 .62297 L .52235 .61402 L p
1 g
F P
s
P
p
.002 w
.5825 .59874 m .52235 .61402 L .5203 .62297 L p
1 g
F P
s
P
p
.002 w
.39014 .26846 m .34544 .31304 L .35523 .31363 L p
1 g
F P
s
P
p
.002 w
.35523 .31363 m .39787 .27118 L .39014 .26846 L p
1 g
F P
s
P
p
.002 w
.30443 .4363 m .31792 .49822 L .32418 .49184 L p
1 g
F P
s
P
p
.002 w
.32418 .49184 m .31101 .43118 L .30443 .4363 L p
1 g
F P
s
P
p
.002 w
.5203 .62297 m .58172 .60742 L .5825 .59874 L p
1 g
F P
s
P
p
.002 w
.63461 .56493 m .5825 .59874 L .58172 .60742 L p
1 g
F P
s
P
p
.002 w
.673 .51581 m .69322 .45637 L .68652 .45015 L p
1 g
F P
s
P
p
.002 w
.68593 .38973 m .68652 .45015 L .69322 .45637 L p
1 g
F P
s
P
p
.002 w
.31174 .3732 m .30443 .4363 L .31101 .43118 L p
1 g
F P
s
P
p
.002 w
.31101 .43118 m .31822 .36938 L .31174 .3732 L p
1 g
F P
s
P
p
.002 w
.44768 .24088 m .39014 .26846 L .39787 .27118 L p
1 g
F P
s
P
p
.002 w
.39787 .27118 m .45269 .24494 L .44768 .24088 L p
1 g
F P
s
P
p
.002 w
.58172 .60742 m .63494 .57294 L .63461 .56493 L p
1 g
F P
s
P
p
.002 w
.673 .51581 m .63461 .56493 L .63494 .57294 L p
1 g
F P
s
P
p
.002 w
.69322 .45637 m .69263 .39295 L .68593 .38973 L p
1 g
F P
s
P
p
.002 w
.6652 .3323 m .68593 .38973 L .69263 .39295 L p
1 g
F P
s
P
p
.002 w
.51174 .23373 m .44768 .24088 L .45269 .24494 L p
1 g
F P
s
P
p
.002 w
.45269 .24494 m .51369 .23815 L .51174 .23373 L p
1 g
F P
s
P
p
.002 w
.3395 .31567 m .31174 .3732 L .31822 .36938 L p
1 g
F P
s
P
p
.002 w
.31822 .36938 m .34544 .31304 L .3395 .31567 L p
1 g
F P
s
P
p
.002 w
.69263 .39295 m .6709 .33264 L .6652 .3323 L p
1 g
F P
s
P
p
.002 w
.62643 .28447 m .6652 .3323 L .6709 .33264 L p
1 g
F P
s
P
p
.002 w
.34878 .55704 m .39653 .59818 L .39849 .59399 L p
1 g
F P
s
P
p
.002 w
.39849 .59399 m .35046 .5526 L .34878 .55704 L p
1 g
F P
s
P
p
.002 w
.45708 .61828 m .39849 .59399 L .39653 .59818 L p
1 g
F P
s
P
p
.002 w
.39653 .59818 m .45477 .62232 L .45708 .61828 L p
1 g
F P
s
P
p
.002 w
.5203 .62297 m .45708 .61828 L .45477 .62232 L p
1 g
F P
s
P
p
.002 w
.57502 .24809 m .51174 .23373 L .51369 .23815 L p
1 g
F P
s
P
p
.002 w
.51369 .23815 m .57392 .25182 L .57502 .24809 L p
1 g
F P
s
P
p
.002 w
.63494 .57294 m .67417 .52281 L .673 .51581 L p
1 g
F P
s
P
p
.002 w
.69322 .45637 m .673 .51581 L .67417 .52281 L p
1 g
F P
s
P
p
.002 w
.31643 .503 m .34878 .55704 L .35046 .5526 L p
1 g
F P
s
P
p
.002 w
.35046 .5526 m .31792 .49822 L .31643 .503 L p
1 g
F P
s
P
p
.002 w
.6709 .33264 m .63019 .28239 L .62643 .28447 L p
1 g
F P
s
P
p
.002 w
.57392 .25182 m .62643 .28447 L .63019 .28239 L p
1 g
F P
s
P
p
.002 w
.63019 .28239 m .57502 .24809 L .57392 .25182 L p
1 g
F P
s
P
p
.002 w
.45477 .62232 m .5176 .62699 L .5203 .62297 L p
1 g
F P
s
P
p
.002 w
.58172 .60742 m .5203 .62297 L .5176 .62699 L p
1 g
F P
s
P
p
.002 w
.38514 .27014 m .3395 .31567 L .34544 .31304 L p
1 g
F P
s
P
p
.002 w
.34544 .31304 m .39014 .26846 L .38514 .27014 L p
1 g
F P
s
P
p
.002 w
.30301 .44148 m .31643 .503 L .31792 .49822 L p
1 g
F P
s
P
p
.002 w
.31792 .49822 m .30443 .4363 L .30301 .44148 L p
1 g
F P
s
P
p
.002 w
.5176 .62699 m .57864 .61156 L .58172 .60742 L p
1 g
F P
s
P
p
.002 w
.63494 .57294 m .58172 .60742 L .57864 .61156 L p
1 g
F P
s
P
p
.002 w
.67417 .52281 m .69484 .46213 L .69322 .45637 L p
1 g
F P
s
P
p
.002 w
.69263 .39295 m .69322 .45637 L .69484 .46213 L p
1 g
F P
s
P
p
.002 w
.31027 .37881 m .30301 .44148 L .30443 .4363 L p
1 g
F P
s
P
p
.002 w
.30443 .4363 m .31174 .3732 L .31027 .37881 L p
1 g
F P
s
P
p
.004 w
.2685 .50716 m
.30028 .49663 L
s
P
p
.004 w
.23075 .51966 m
.2685 .50716 L
s
P
p
.002 w
.44392 .24197 m .38514 .27014 L .39014 .26846 L p
1 g
F P
s
P
p
.002 w
.39014 .26846 m .44768 .24088 L .44392 .24197 L p
1 g
F P
s
P
p
.002 w
.57864 .61156 m .63152 .57731 L .63494 .57294 L p
1 g
F P
s
P
p
.002 w
.67417 .52281 m .63494 .57294 L .63152 .57731 L p
1 g
F P
s
P
p
.002 w
.69484 .46213 m .69425 .39736 L .69263 .39295 L p
1 g
F P
s
P
p
.002 w
.6709 .33264 m .69263 .39295 L .69425 .39736 L p
1 g
F P
s
P
p
.002 w
.50937 .23466 m .44392 .24197 L .44768 .24088 L p
1 g
F P
s
P
p
.002 w
.44768 .24088 m .51174 .23373 L .50937 .23466 L p
1 g
F P
s
P
p
.002 w
.33785 .32167 m .31027 .37881 L .31174 .3732 L p
1 g
F P
s
P
p
.002 w
.31174 .3732 m .3395 .31567 L .33785 .32167 L p
1 g
F P
s
P
p
.002 w
.69425 .39736 m .67205 .33575 L .6709 .33264 L p
1 g
F P
s
P
p
.002 w
.63019 .28239 m .6709 .33264 L .67205 .33575 L p
1 g
F P
s
P
p
.002 w
.35129 .55811 m .39739 .59783 L .39653 .59818 L p
1 g
F P
s
P
p
.002 w
.39653 .59818 m .34878 .55704 L .35129 .55811 L p
1 g
F P
s
P
p
.002 w
.45477 .62232 m .39653 .59818 L .39739 .59783 L p
1 g
F P
s
P
p
.002 w
.39739 .59783 m .45363 .62114 L .45477 .62232 L p
1 g
F P
s
P
p
.002 w
.5176 .62699 m .45477 .62232 L .45363 .62114 L p
1 g
F P
s
P
p
.002 w
.63152 .57731 m .67048 .52753 L .67417 .52281 L p
1 g
F P
s
P
p
.002 w
.69484 .46213 m .67417 .52281 L .67048 .52753 L p
1 g
F P
s
P
p
.002 w
.57404 .24933 m .50937 .23466 L .51174 .23373 L p
1 g
F P
s
P
p
.002 w
.51174 .23373 m .57502 .24809 L .57404 .24933 L p
1 g
F P
s
P
p
.002 w
.32007 .50595 m .35129 .55811 L .34878 .55704 L p
1 g
F P
s
P
p
.002 w
.34878 .55704 m .31643 .503 L .32007 .50595 L p
1 g
F P
s
P
p
.002 w
.67205 .33575 m .63044 .2844 L .63019 .28239 L p
1 g
F P
s
P
p
.002 w
.57502 .24809 m .63019 .28239 L .63044 .2844 L p
1 g
F P
s
P
p
.002 w
.63044 .2844 m .57404 .24933 L .57502 .24809 L p
1 g
F P
s
P
p
.002 w
.45363 .62114 m .51429 .62565 L .5176 .62699 L p
1 g
F P
s
P
p
.002 w
.57864 .61156 m .5176 .62699 L .51429 .62565 L p
1 g
F P
s
P
p
.002 w
.38319 .27646 m .33785 .32167 L .3395 .31567 L p
1 g
F P
s
P
p
.002 w
.3395 .31567 m .38514 .27014 L .38319 .27646 L p
1 g
F P
s
P
p
.002 w
.30714 .44658 m .32007 .50595 L .31643 .503 L p
1 g
F P
s
P
p
.002 w
.31643 .503 m .30301 .44148 L .30714 .44658 L p
1 g
F P
s
P
p
.002 w
.51429 .62565 m .5732 .61074 L .57864 .61156 L p
1 g
F P
s
P
p
.002 w
.63152 .57731 m .57864 .61156 L .5732 .61074 L p
1 g
F P
s
P
p
.002 w
.67048 .52753 m .691 .46725 L .69484 .46213 L p
1 g
F P
s
P
p
.002 w
.69425 .39736 m .69484 .46213 L .691 .46725 L p
1 g
F P
s
P
p
.002 w
.31417 .38614 m .30714 .44658 L .30301 .44148 L p
1 g
F P
s
P
p
.002 w
.30301 .44148 m .31027 .37881 L .31417 .38614 L p
1 g
F P
s
P
p
.002 w
.44159 .2485 m .38319 .27646 L .38514 .27014 L p
1 g
F P
s
P
p
.002 w
.38514 .27014 m .44392 .24197 L .44159 .2485 L p
1 g
F P
s
P
p
.002 w
.5732 .61074 m .62419 .57768 L .63152 .57731 L p
1 g
F P
s
P
p
.002 w
.67048 .52753 m .63152 .57731 L .62419 .57768 L p
1 g
F P
s
P
p
.002 w
.691 .46725 m .69039 .40292 L .69425 .39736 L p
1 g
F P
s
P
p
.002 w
.67205 .33575 m .69425 .39736 L .69039 .40292 L p
1 g
F P
s
P
p
.002 w
.50663 .24127 m .44159 .2485 L .44392 .24197 L p
1 g
F P
s
P
p
.002 w
.44392 .24197 m .50937 .23466 L .50663 .24127 L p
1 g
F P
s
P
p
.002 w
.3408 .33107 m .31417 .38614 L .31027 .37881 L p
1 g
F P
s
P
p
.002 w
.31027 .37881 m .33785 .32167 L .3408 .33107 L p
1 g
F P
s
P
p
.002 w
.69039 .40292 m .6683 .34172 L .67205 .33575 L p
1 g
F P
s
P
p
.002 w
.63044 .2844 m .67205 .33575 L .6683 .34172 L p
1 g
F P
s
P
p
.002 w
.35819 .55555 m .40124 .59265 L .39739 .59783 L p
1 g
F P
s
P
p
.002 w
.39739 .59783 m .35129 .55811 L .35819 .55555 L p
1 g
F P
s
P
p
.002 w
.45363 .62114 m .39739 .59783 L .40124 .59265 L p
1 g
F P
s
P
p
.002 w
.40124 .59265 m .45377 .61442 L .45363 .62114 L p
1 g
F P
s
P
p
.002 w
.51429 .62565 m .45363 .62114 L .45377 .61442 L p
1 g
F P
s
P
p
.002 w
.62419 .57768 m .66173 .52965 L .67048 .52753 L p
1 g
F P
s
P
p
.002 w
.691 .46725 m .67048 .52753 L .66173 .52965 L p
1 g
F P
s
P
p
.002 w
.5709 .25586 m .50663 .24127 L .50937 .23466 L p
1 g
F P
s
P
p
.002 w
.50937 .23466 m .57404 .24933 L .5709 .25586 L p
1 g
F P
s
P
p
.002 w
.32907 .50683 m .35819 .55555 L .35129 .55811 L p
1 g
F P
s
P
p
.002 w
.35129 .55811 m .32007 .50595 L .32907 .50683 L p
1 g
F P
s
P
p
.002 w
.6683 .34172 m .62694 .2907 L .63044 .2844 L p
1 g
F P
s
P
p
.002 w
.57404 .24933 m .63044 .2844 L .62694 .2907 L p
1 g
F P
s
P
p
.002 w
.62694 .2907 m .5709 .25586 L .57404 .24933 L p
1 g
F P
s
P
p
.002 w
.45377 .61442 m .51042 .61861 L .51429 .62565 L p
1 g
F P
s
P
p
.002 w
.5732 .61074 m .51429 .62565 L .51042 .61861 L p
1 g
F P
s
P
p
.002 w
.38456 .28754 m .3408 .33107 L .33785 .32167 L p
1 g
F P
s
P
p
.002 w
.33785 .32167 m .38319 .27646 L .38456 .28754 L p
1 g
F P
s
P
p
.002 w
.31705 .45144 m .32907 .50683 L .32007 .50595 L p
1 g
F P
s
P
p
.002 w
.32007 .50595 m .30714 .44658 L .31705 .45144 L p
1 g
F P
s
P
p
.004 w
.30028 .49663 m
.30773 .49417 L
s
P
p
.002 w
.51042 .61861 m .56539 .60466 L .5732 .61074 L p
1 g
F P
s
P
p
.002 w
.62419 .57768 m .5732 .61074 L .56539 .60466 L p
1 g
F P
s
P
p
.002 w
.66173 .52965 m .68146 .47153 L .691 .46725 L p
1 g
F P
s
P
p
.002 w
.69039 .40292 m .691 .46725 L .68146 .47153 L p
1 g
F P
s
P
p
.002 w
.32367 .39508 m .31705 .45144 L .30714 .44658 L p
1 g
F P
s
P
p
.002 w
.30714 .44658 m .31417 .38614 L .32367 .39508 L p
1 g
F P
s
P
p
.002 w
.44088 .26064 m .38456 .28754 L .38319 .27646 L p
1 g
F P
s
P
p
.002 w
.38319 .27646 m .44159 .2485 L .44088 .26064 L p
1 g
F P
s
P
p
.002 w
.56539 .60466 m .61293 .57378 L .62419 .57768 L p
1 g
F P
s
P
p
.002 w
.66173 .52965 m .62419 .57768 L .61293 .57378 L p
1 g
F P
s
P
p
.002 w
.68146 .47153 m .68081 .40952 L .69039 .40292 L p
1 g
F P
s
P
p
.002 w
.6683 .34172 m .69039 .40292 L .68081 .40952 L p
1 g
F P
s
P
p
.002 w
.50358 .25372 m .44088 .26064 L .44159 .2485 L p
1 g
F P
s
P
p
.002 w
.44159 .2485 m .50663 .24127 L .50358 .25372 L p
1 g
F P
s
P
p
.002 w
.34858 .3438 m .32367 .39508 L .31417 .38614 L p
1 g
F P
s
P
p
.002 w
.31417 .38614 m .3408 .33107 L .34858 .3438 L p
1 g
F P
s
P
p
.002 w
.68081 .40952 m .65946 .35054 L .6683 .34172 L p
1 g
F P
s
P
p
.002 w
.62694 .2907 m .6683 .34172 L .65946 .35054 L p
1 g
F P
s
P
p
.002 w
.36956 .5492 m .40816 .58249 L .40124 .59265 L p
1 g
F P
s
P
p
.002 w
.40124 .59265 m .35819 .55555 L .36956 .5492 L p
1 g
F P
s
P
p
.002 w
.45377 .61442 m .40124 .59265 L .40816 .58249 L p
1 g
F P
s
P
p
.002 w
.61293 .57378 m .64787 .52896 L .66173 .52965 L p
1 g
F P
s
P
p
.002 w
.68146 .47153 m .66173 .52965 L .64787 .52896 L p
1 g
F P
s
P
p
.002 w
.40816 .58249 m .45527 .60202 L .45377 .61442 L p
1 g
F P
s
P
p
.002 w
.51042 .61861 m .45377 .61442 L .45527 .60202 L p
1 g
F P
s
P
p
.002 w
.56552 .26781 m .50358 .25372 L .50663 .24127 L p
1 g
F P
s
P
p
.002 w
.50663 .24127 m .5709 .25586 L .56552 .26781 L p
1 g
F P
s
P
p
.002 w
.34349 .50551 m .36956 .5492 L .35819 .55555 L p
1 g
F P
s
P
p
.002 w
.35819 .55555 m .32907 .50683 L .34349 .50551 L p
1 g
F P
s
P
p
.002 w
.65946 .35054 m .61956 .30139 L .62694 .2907 L p
1 g
F P
s
P
p
.002 w
.5709 .25586 m .62694 .2907 L .61956 .30139 L p
1 g
F P
s
P
p
.002 w
.61956 .30139 m .56552 .26781 L .5709 .25586 L p
1 g
F P
s
P
p
.002 w
.45527 .60202 m .50608 .60575 L .51042 .61861 L p
1 g
F P
s
P
p
.002 w
.56539 .60466 m .51042 .61861 L .50608 .60575 L p
1 g
F P
s
P
p
.002 w
.3894 .30331 m .34858 .3438 L .3408 .33107 L p
1 g
F P
s
P
p
.002 w
.3408 .33107 m .38456 .28754 L .3894 .30331 L p
1 g
F P
s
P
p
.002 w
.33279 .45587 m .34349 .50551 L .32907 .50683 L p
1 g
F P
s
P
p
.004 w
.33883 .48387 m
.5 .43051 L
s
P
p
.002 w
.32907 .50683 m .31705 .45144 L .33279 .45587 L p
1 g
F P
s
P
p
.004 w
.32733 .48768 m
.32865 .48724 L
s
P
p
.004 w
.30773 .49417 m
.32071 .48987 L
s
P
p
.004 w
.32071 .48987 m
.32733 .48768 L
s
P
p
.002 w
.64787 .52896 m .66616 .47477 L .68146 .47153 L p
1 g
F P
s
P
p
.002 w
.68081 .40952 m .68146 .47153 L .66616 .47477 L p
1 g
F P
s
P
p
.002 w
.50608 .60575 m .55533 .59319 L .56539 .60466 L p
1 g
F P
s
P
p
.002 w
.61293 .57378 m .56539 .60466 L .55533 .59319 L p
1 g
F P
s
P
p
.002 w
.33881 .40543 m .33279 .45587 L .31705 .45144 L p
1 g
F P
s
P
p
.002 w
.31705 .45144 m .32367 .39508 L .33881 .40543 L p
1 g
F P
s
P
p
.002 w
.4419 .27834 m .3894 .30331 L .38456 .28754 L p
1 g
F P
s
P
p
.002 w
.38456 .28754 m .44088 .26064 L .4419 .27834 L p
1 g
F P
s
P
p
.002 w
.55533 .59319 m .59786 .56547 L .61293 .57378 L p
1 g
F P
s
P
p
.002 w
.64787 .52896 m .61293 .57378 L .59786 .56547 L p
1 g
F P
s
P
p
.002 w
.66616 .47477 m .66546 .41701 L .68081 .40952 L p
1 g
F P
s
P
p
.002 w
.65946 .35054 m .68081 .40952 L .66546 .41701 L p
1 g
F P
s
P
p
.002 w
.5003 .27196 m .4419 .27834 L .44088 .26064 L p
1 g
F P
s
P
p
.002 w
.44088 .26064 m .50358 .25372 L .5003 .27196 L p
1 g
F P
s
P
p
.002 w
.36119 .35961 m .33881 .40543 L .32367 .39508 L p
1 g
F P
s
P
p
.002 w
.32367 .39508 m .34858 .3438 L .36119 .35961 L p
1 g
F P
s
P
p
.002 w
.66546 .41701 m .64551 .36211 L .65946 .35054 L p
1 g
F P
s
P
p
.002 w
.61956 .30139 m .65946 .35054 L .64551 .36211 L p
1 g
F P
s
P
p
.002 w
.59786 .56547 m .62904 .52529 L .64787 .52896 L p
1 g
F P
s
P
p
.002 w
.66616 .47477 m .64787 .52896 L .62904 .52529 L p
1 g
F P
s
P
p
.002 w
.38528 .53905 m .4181 .56738 L .40816 .58249 L p
1 g
F P
s
P
p
.002 w
.40816 .58249 m .36956 .5492 L .38528 .53905 L p
1 g
F P
s
P
p
.002 w
.45527 .60202 m .40816 .58249 L .4181 .56738 L p
1 g
F P
s
P
p
.002 w
.4181 .56738 m .45818 .58398 L .45527 .60202 L p
1 g
F P
s
P
p
.002 w
.50608 .60575 m .45527 .60202 L .45818 .58398 L p
1 g
F P
s
P
p
.002 w
.55798 .28511 m .5003 .27196 L .50358 .25372 L p
1 g
F P
s
P
p
.002 w
.50358 .25372 m .56552 .26781 L .55798 .28511 L p
1 g
F P
s
P
p
.002 w
.36317 .50188 m .38528 .53905 L .36956 .5492 L p
1 g
F P
s
P
p
.002 w
.36956 .5492 m .34349 .50551 L .36317 .50188 L p
1 g
F P
s
P
p
.002 w
.64551 .36211 m .6083 .31637 L .61956 .30139 L p
1 g
F P
s
P
p
.002 w
.56552 .26781 m .61956 .30139 L .6083 .31637 L p
1 g
F P
s
P
p
.002 w
.6083 .31637 m .55798 .28511 L .56552 .26781 L p
1 g
F P
s
P
p
.002 w
.45818 .58398 m .50138 .58712 L .50608 .60575 L p
1 g
F P
s
P
p
.002 w
.55533 .59319 m .50608 .60575 L .50138 .58712 L p
1 g
F P
s
P
p
.002 w
.39776 .3235 m .36119 .35961 L .34858 .3438 L p
1 g
F P
s
P
p
.002 w
.34858 .3438 m .3894 .30331 L .39776 .3235 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.35416 .4597 m .36317 .50188 L .34349 .50551 L p
1 g
F P
s
P
p
.002 w
.34349 .50551 m .33279 .45587 L .35416 .4597 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.62904 .52529 m .64529 .4768 L .66616 .47477 L p
1 g
F P
s
P
p
.002 w
.66546 .41701 m .66616 .47477 L .64529 .4768 L p
1 g
F P
s
P
p
.002 w
.50138 .58712 m .54322 .57638 L .55533 .59319 L p
1 g
F P
s
P
p
.002 w
.59786 .56547 m .55533 .59319 L .54322 .57638 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.35938 .41691 m .35416 .4597 L .33279 .45587 L p
1 g
F P
s
P
p
.002 w
.33279 .45587 m .33881 .40543 L .35938 .41691 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.44471 .30129 m .39776 .3235 L .3894 .30331 L p
1 g
F P
s
P
p
.002 w
.3894 .30331 m .4419 .27834 L .44471 .30129 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.54322 .57638 m .57928 .55277 L .59786 .56547 L p
1 g
F P
s
P
p
.002 w
.62904 .52529 m .59786 .56547 L .57928 .55277 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.64529 .4768 m .64454 .42518 L .66546 .41701 L p
1 g
F P
s
P
p
.002 w
.64551 .36211 m .66546 .41701 L .64454 .42518 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.37846 .37812 m .35938 .41691 L .33881 .40543 L p
1 g
F P
s
P
p
.002 w
.33881 .40543 m .36119 .35961 L .37846 .37812 L p
1 g
F P
s
P
p
.002 w
.49689 .29567 m .44471 .30129 L .4419 .27834 L p
1 g
F P
s
P
p
.002 w
.4419 .27834 m .5003 .27196 L .49689 .29567 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.64454 .42518 m .62663 .37617 L .64551 .36211 L p
1 g
F P
s
P
p
.002 w
.6083 .31637 m .64551 .36211 L .62663 .37617 L p
1 g
F P
s
P
p
.002 w
.57928 .55277 m .60563 .51862 L .62904 .52529 L p
1 g
F P
s
P
p
.002 w
.64529 .4768 m .62904 .52529 L .60563 .51862 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.40505 .52523 m .43088 .54757 L .4181 .56738 L p
1 g
F P
s
P
p
.002 w
.4181 .56738 m .38528 .53905 L .40505 .52523 L p
1 g
F P
s
P
p
.002 w
.45818 .58398 m .4181 .56738 L .43088 .54757 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.45818 .58398 m .43192 .54896 L .45091 .56277 L 1 g
F
P
p
.002 w
.46075 .56993 m .46008 .57361 L p
.45091 .56277 L 1 g
F P
s
P
p
.002 w
.46008 .57361 m .45818 .58398 L p
.45091 .56277 L 1 g
F P
s
P
p
.002 w
.45091 .56277 m .45146 .56129 L p
.44464 .55537 L 1 g
F P
s
P
p
.46872 .57265 m .45934 .5689 L .46075 .56993 L 1 g
F
P
p
.002 w
.4901 .5863 m .45818 .58398 L .4604 .57187 L p
1 g
F P
s
P
p
.002 w
.4604 .57187 m .46075 .56993 L p
.46839 .57419 L 1 g
F P
s
P
p
.4901 .5863 m .4604 .57187 L .46839 .57419 L 1 g
F
P
p
.002 w
.48909 .58021 m .48921 .57862 L p
.48142 .57798 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.50138 .58712 m .4901 .5863 L p
.48307 .57977 L 1 g
F P
s
P
p
.50138 .58712 m .48307 .57977 L .48562 .57996 L 1 g
F
P
p
.50138 .58712 m .48562 .57996 L .49283 .5813 L 1 g
F
P
p
.48562 .57996 m .48101 .57786 L .48909 .58021 L 1 g
F
P
p
.48562 .57996 m .48909 .58021 L .49283 .5813 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48909 .58021 L p
1 g
F P
s
P
p
.51079 .57862 m .48909 .58021 L .49913 .58095 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46839 .57419 L p
1 g
F P
s
P
p
.48921 .57862 m .46839 .57419 L .48142 .57798 L 1 g
F
P
p
.49283 .5813 m .48101 .57786 L .46246 .56064 L 1 g
F
P
p
.51079 .57862 m .49913 .58095 L .50014 .58103 L 1 g
F
P
p
.002 w
.5338 .5788 m .50138 .58712 L .5006 .5833 L p
1 g
F P
s
P
p
.002 w
.5006 .5833 m .50014 .58103 L p
.51092 .58031 L 1 g
F P
s
P
p
.5338 .5788 m .5006 .5833 L .51092 .58031 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51092 .58031 L p
1 g
F P
s
P
p
.53128 .57265 m .51092 .58031 L .52338 .5767 L 1 g
F
P
p
.002 w
.51092 .58031 m .51079 .57862 L p
.50014 .58103 L 1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53164 .57431 m .53128 .57265 L p
.52338 .5767 L 1 g
F P
s
P
p
.002 w
.50014 .58103 m .49648 .56307 L p
.5266 .57577 L 1 g
F P
s
P
p
.5338 .5788 m .51092 .58031 L .5266 .57577 L 1 g
F
P
p
.51092 .58031 m .50014 .58103 L .5266 .57577 L 1 g
F
P
p
.002 w
.54322 .57638 m .5338 .5788 L p
.52801 .57636 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53164 .57431 L p
1 g
F P
s
P
p
.54854 .56129 m .53164 .57431 L .5392 .57004 L 1 g
F
P
p
.57928 .55277 m .5452 .56746 L .56124 .55342 L 1 g
F
P
p
.5452 .56746 m .5392 .57004 L .54904 .56262 L 1 g
F
P
p
.5452 .56746 m .54904 .56262 L .56124 .55342 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54904 .56262 L p
1 g
F P
s
P
p
.56075 .54566 m .54904 .56262 L .55676 .55289 L 1 g
F
P
p
.54854 .56129 m .5392 .57004 L .53996 .56947 L 1 g
F
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.57928 .55277 m .54322 .57638 L .5392 .57004 L p
1 g
F P
s
P
p
.54322 .57638 m .52801 .57636 L .53308 .5735 L 1 g
F
P
p
.002 w
.5392 .57004 m .54322 .57638 L p
.53308 .5735 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54961 .56416 L p
1 g
F P
s
P
p
.002 w
.54961 .56416 m .54854 .56129 L p
.53959 .56982 L 1 g
F P
s
P
p
.53959 .56982 m .5322 .57686 L .54961 .56416 L 1 g
F
P
p
.002 w
.49648 .56307 m .52939 .55456 L .5392 .57004 L p
1 g
F P
s
P
p
.53308 .5735 m .49648 .56307 L .5392 .57004 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.5392 .57004 m .52939 .55456 L p
.5562 .5536 L 1 g
F P
s
P
p
.56124 .55342 m .54904 .56262 L .5562 .5536 L 1 g
F
P
p
.54904 .56262 m .5392 .57004 L .5562 .5536 L 1 g
F
P
p
.002 w
.56145 .54698 m .56075 .54566 L p
.55676 .55289 L 1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56145 .54698 L p
1 g
F P
s
P
p
.56654 .52734 m .56145 .54698 L .56387 .54075 L 1 g
F
P
p
.60563 .51862 m .56387 .54075 L .56617 .53286 L 1 g
F
P
p
.56446 .53872 m .56387 .54075 L .56429 .53968 L 1 g
F
P
p
.56654 .52734 m .56387 .54075 L .56446 .53872 L 1 g
F
P
p
.002 w
.60563 .51862 m .57928 .55277 L .56387 .54075 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56387 .54075 m .57928 .55277 L p
.55892 .5535 L 1 g
F P
s
P
p
.002 w
.57828 .50904 m .60563 .51862 L p
.56756 .53236 L 1 g
F P
s
P
p
.56756 .53236 m .56617 .53286 L .56747 .53029 L 1 g
F
P
p
.56756 .53236 m .56747 .53029 L .57828 .50904 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56741 .5286 L p
1 g
F P
s
P
p
.56515 .50826 m .56741 .5286 L .5672 .5235 L 1 g
F
P
p
.002 w
.57828 .50904 m .5672 .5235 L p
.56614 .51077 L 1 g
F P
s
P
p
.56684 .51922 m .5672 .5235 L .56709 .52081 L 1 g
F
P
p
.56515 .50826 m .5672 .5235 L .56684 .51922 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56741 .5286 m .56654 .52734 L p
.56446 .53872 L 1 g
F P
s
P
p
.002 w
.55768 .53592 m .5672 .5235 L p
.56617 .53286 L 1 g
F P
s
P
p
.002 w
.5672 .5235 m .56992 .51995 L p
.56741 .5286 L 1 g
F P
s
P
p
.56617 .53286 m .5672 .5235 L .56741 .5286 L 1 g
F
P
p
.002 w
.56992 .51995 m .57828 .50904 L p
.56617 .53286 L 1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56601 .50929 L p
1 g
F P
s
P
p
.002 w
.563 .50289 m .56557 .50393 L p
.56379 .50456 L 1 g
F P
s
P
p
.002 w
.56557 .50393 m .57828 .50904 L p
.56614 .51077 L 1 g
F P
s
P
p
.55661 .4905 m .56601 .50929 L .563 .50289 L 1 g
F
P
p
.55795 .49187 m .563 .50289 L .55771 .49199 L 1 g
F
P
p
.58888 .47674 m .56611 .49975 L .55795 .49187 L 1 g
F
P
p
.56611 .49975 m .563 .50289 L .55795 .49187 L 1 g
F
P
p
.55661 .4905 m .563 .50289 L .56191 .50063 L 1 g
F
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.58888 .47674 m .57828 .50904 L .563 .50289 L p
1 g
F P
s
P
p
.002 w
.56601 .50929 m .56515 .50826 L p
.56684 .51922 L 1 g
F P
s
P
p
.56614 .51077 m .53374 .51537 L .56379 .50456 L 1 g
F
P
p
.56601 .50929 m .56379 .50456 L .56557 .50393 L 1 g
F
P
p
.56614 .51077 m .56379 .50456 L .56601 .50929 L 1 g
F
P
p
.55795 .49187 m .55771 .49199 L .55764 .49157 L 1 g
F
P
p
.54174 .47608 m .55156 .48569 L .55148 .48562 L 1 g
F
P
p
.002 w
.55148 .48562 m .54786 .4968 L p
.54259 .47698 L 1 g
F P
s
P
p
.002 w
.54233 .47672 m .54174 .47608 L p
.55148 .48562 L 1 g
F P
s
P
p
.002 w
.55739 .49132 m .55661 .4905 L p
.56191 .50063 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49132 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49132 L .55156 .48569 L 1 g
F
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.51547 .48229 m .51909 .47093 L .53308 .47233 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54233 .47672 L p
1 g
F P
s
P
p
.52214 .46667 m .54233 .47672 L .53311 .47235 L 1 g
F
P
p
.54279 .47694 m .51547 .48229 L .53308 .47233 L 1 g
F
P
p
.002 w
.54786 .4968 m .51547 .48229 L p
.54259 .47698 L 1 g
F P
s
P
p
.002 w
.53308 .47233 m .51909 .47093 L p
.52417 .46807 L 1 g
F P
s
P
p
.002 w
.5225 .46727 m .52214 .46667 L p
.53311 .47235 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.51875 .45895 m .5545 .451 L p
.52502 .46759 L 1 g
F P
s
P
p
.002 w
.51909 .47093 m .51897 .46682 L p
.52502 .46759 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .5225 .46727 L p
1 g
F P
s
P
p
.5 .4634 m .5225 .46727 L .51897 .46682 L 1 g
F
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51897 .46682 m .51909 .47093 L p
.49866 .46409 L 1 g
F P
s
P
p
.51897 .46682 m .49866 .46409 L .5 .46388 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.51909 .47093 m .48445 .46632 L p
.49866 .46409 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49023 .46541 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .49023 .46541 L 1 g
F
P
p
.002 w
.48232 .46603 m .49634 .46331 L p
.49866 .46409 L 1 g
F P
s
P
p
.002 w
.47472 .50067 m .46354 .49605 L .4819 .4667 L p
1 g
F P
s
P
p
.002 w
.49837 .49843 m .48676 .50149 L .48239 .46663 L p
1 g
F P
s
P
p
.002 w
.51547 .48229 m .5083 .49179 L .48285 .46657 L p
1 g
F P
s
P
p
.47786 .46667 m .49023 .46541 L .48445 .46632 L 1 g
F
P
p
.002 w
.48445 .46632 m .51909 .47093 L p
.48327 .4665 L 1 g
F P
s
P
p
.48365 .46644 m .48445 .46632 L .48366 .46644 L 1 g
F
P
p
.47786 .46667 m .48445 .46632 L .48365 .46644 L 1 g
F
P
p
.002 w
.51909 .47093 m .51547 .48229 L .48327 .4665 L p
1 g
F P
s
P
p
.002 w
.48327 .4665 m .48232 .46603 L .48445 .46632 L p
1 g
F P
s
P
p
.47786 .46667 m .48366 .46644 L .48326 .4665 L 1 g
F
P
p
.002 w
.48285 .46657 m .48232 .46603 L .48327 .4665 L p
1 g
F P
s
P
p
.002 w
.48327 .4665 m .51547 .48229 L p
.48285 .46657 L 1 g
F P
s
P
p
.48326 .4665 m .48366 .46644 L .48327 .4665 L 1 g
F
P
p
.48301 .46654 m .48327 .4665 L .48303 .46654 L 1 g
F
P
p
.47786 .46667 m .48327 .4665 L .48301 .46654 L 1 g
F
P
p
.002 w
.5083 .49179 m .49837 .49843 L .4826 .4666 L p
1 g
F P
s
P
p
.002 w
.4826 .4666 m .48232 .46603 L .48285 .46657 L p
1 g
F P
s
P
p
.002 w
.48285 .46657 m .5083 .49179 L p
.4826 .4666 L 1 g
F P
s
P
p
.47786 .46667 m .48303 .46654 L .48283 .46657 L 1 g
F
P
p
.002 w
.48239 .46663 m .48232 .46603 L .4826 .4666 L p
1 g
F P
s
P
p
.002 w
.4826 .4666 m .49837 .49843 L p
.48239 .46663 L 1 g
F P
s
P
p
.48283 .46657 m .48303 .46654 L .48285 .46657 L 1 g
F
P
p
.48269 .46659 m .48285 .46657 L .48271 .46659 L 1 g
F
P
p
.47786 .46667 m .48285 .46657 L .48269 .46659 L 1 g
F
P
p
.002 w
.48676 .50149 m .47472 .50067 L .48218 .46666 L p
1 g
F P
s
P
p
.002 w
.48218 .46666 m .48232 .46603 L .48239 .46663 L p
1 g
F P
s
P
p
.002 w
.48239 .46663 m .48676 .50149 L p
.48218 .46666 L 1 g
F P
s
P
p
.47786 .46667 m .48271 .46659 L .48258 .46661 L 1 g
F
P
p
.47786 .46667 m .4826 .46661 L .48139 .46677 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45441 .48812 m .45134 .48289 L p
.47946 .46702 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44831 .47774 m .44881 .47859 L p
.42834 .50809 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4426 .49134 L p
1 g
F P
s
P
p
.43485 .50826 m .4426 .49134 L .44173 .49313 L 1 g
F
P
p
.44339 .4905 m .45183 .48241 L .45134 .48289 L 1 g
F
P
p
.43459 .49909 m .4426 .49134 L .43807 .50063 L 1 g
F
P
p
.43485 .50826 m .44249 .49146 L .43842 .4999 L 1 g
F
P
p
.002 w
.4426 .49134 m .44339 .4905 L p
.45134 .48289 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.43807 .50063 m .42834 .50809 L p
.43459 .49909 L 1 g
F P
s
P
p
.002 w
.43268 .51184 m .42834 .50809 L .43442 .50343 L p
1 g
F P
s
P
p
.002 w
.43442 .50343 m .43807 .50063 L p
.4338 .50951 L 1 g
F P
s
P
p
.43268 .51184 m .43442 .50343 L .4338 .50951 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .4338 .50951 L p
1 g
F P
s
P
p
.43346 .52734 m .4338 .50951 L .43349 .51255 L 1 g
F
P
p
.002 w
.42834 .50809 m .43349 .51255 L p
.43238 .52752 L 1 g
F P
s
P
p
.43088 .54757 m .42877 .51477 L .43238 .52752 L 1 g
F
P
p
.42877 .51477 m .42834 .50809 L .43238 .52752 L 1 g
F
P
p
.43925 .54566 m .43529 .53782 L .43584 .53978 L 1 g
F
P
p
.002 w
.43969 .55121 m .43088 .54757 L .43446 .54196 L p
1 g
F P
s
P
p
.002 w
.43446 .54196 m .43584 .53978 L p
.43837 .54731 L 1 g
F P
s
P
p
.43969 .55121 m .43446 .54196 L .43837 .54731 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.46246 .56064 m .46075 .56993 L p
.45043 .5622 L 1 g
F P
s
P
p
.002 w
.43088 .54757 m .4419 .55213 L p
.45043 .5622 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43837 .54731 L p
1 g
F P
s
P
p
.002 w
.4419 .55213 m .43969 .55121 L p
.44006 .54962 L 1 g
F P
s
P
p
.45146 .56129 m .43837 .54731 L .44363 .55449 L 1 g
F
P
p
.002 w
.43837 .54731 m .43925 .54566 L p
.43584 .53978 L 1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43266 .52851 L p
1 g
F P
s
P
p
.43925 .54566 m .43266 .52851 L .43529 .53782 L 1 g
F
P
p
.002 w
.43349 .51255 m .44619 .52354 L .43584 .53978 L p
1 g
F P
s
P
p
.002 w
.43584 .53978 m .43173 .54624 L p
.43266 .52851 L 1 g
F P
s
P
p
.43346 .52734 m .43349 .51255 L .43316 .51883 L 1 g
F
P
p
.002 w
.43173 .54624 m .43088 .54757 L p
.43349 .51255 L 1 g
F P
s
P
p
.002 w
.43173 .52986 m .43346 .52734 L p
.43308 .51656 L 1 g
F P
s
P
p
.43266 .52851 m .43349 .51255 L .43584 .53978 L 1 g
F
P
p
.002 w
.43266 .52851 m .43146 .53025 L p
.43529 .53782 L 1 g
F P
s
P
p
.002 w
.43584 .53978 m .44619 .52354 L p
.44006 .54962 L 1 g
F P
s
P
p
.43969 .55121 m .43837 .54731 L .44006 .54962 L 1 g
F
P
p
.43837 .54731 m .43584 .53978 L .44006 .54962 L 1 g
F
P
p
.43192 .54896 m .43088 .54757 L .46075 .56993 L 1 g
F
P
p
.44464 .55537 m .44363 .55449 L .45091 .56277 L 1 g
F
P
p
.44363 .55449 m .43743 .5491 L .44619 .55799 L 1 g
F
P
p
.44363 .55449 m .44619 .55799 L .45091 .56277 L 1 g
F
P
p
.002 w
.43837 .54731 m .43743 .5491 L p
.44363 .55449 L 1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.46246 .56064 m .4419 .55213 L p
.44619 .52354 L 1 g
F P
s
P
p
.4419 .55213 m .44006 .54962 L .44619 .52354 L 1 g
F
P
p
.002 w
.4419 .55213 m .46246 .56064 L p
.45043 .5622 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .4505 .56387 L p
1 g
F P
s
P
p
.002 w
.4505 .56387 m .45091 .56277 L p
.44619 .55799 L 1 g
F P
s
P
p
.44619 .55799 m .43743 .5491 L .4505 .56387 L 1 g
F
P
p
.002 w
.43811 .54781 m .43837 .54731 L p
.43584 .53978 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43811 .54781 L p
1 g
F P
s
P
p
.43529 .53782 m .43146 .53025 L .43811 .54781 L 1 g
F
P
p
.43316 .51883 m .43349 .51255 L .43308 .51656 L 1 g
F
P
p
.002 w
.44619 .52354 m .43349 .51255 L p
.45441 .48812 L 1 g
F P
s
P
p
.002 w
.43349 .51255 m .43268 .51184 L p
.43368 .51075 L 1 g
F P
s
P
p
.43349 .51255 m .43368 .51075 L .45441 .48812 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .4338 .50951 L p
1 g
F P
s
P
p
.002 w
.4338 .50951 m .43485 .50826 L p
.43842 .4999 L 1 g
F P
s
P
p
.43842 .4999 m .44166 .49233 L .4338 .50951 L 1 g
F
P
p
.002 w
.43807 .50063 m .45441 .48812 L p
.43268 .51184 L 1 g
F P
s
P
p
.002 w
.4338 .50951 m .43287 .51061 L p
.43308 .51656 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43173 .52986 L p
1 g
F P
s
P
p
.43308 .51656 m .43287 .51061 L .43173 .52986 L 1 g
F
P
p
.002 w
.45441 .48812 m .43807 .50063 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.44881 .47859 m .45134 .48289 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.45134 .48289 m .45441 .48812 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.4426 .49134 m .44249 .49146 L p
.44173 .49313 L 1 g
F P
s
P
p
.002 w
.44249 .49146 m .44166 .49233 L p
.43842 .4999 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45134 .48289 m .45762 .47677 L .47946 .46702 L 1 g
F
P
p
.002 w
.45762 .47677 m .45826 .47608 L p
.46807 .47178 L 1 g
F P
s
P
p
.002 w
.47433 .46878 m .47946 .46702 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.45826 .47608 m .47786 .46667 L .4775 .46727 L p
1 g
F P
s
P
p
.47786 .46667 m .48139 .46677 L .47946 .46702 L 1 g
F
P
p
.002 w
.4775 .46727 m .47786 .46667 L p
.47946 .46702 L 1 g
F P
s
P
p
.002 w
.48008 .46603 m .48232 .46603 L .47946 .46702 L p
1 g
F P
s
P
p
.002 w
.47946 .46702 m .47433 .46878 L p
.4775 .46727 L 1 g
F P
s
P
p
.4775 .46727 m .48008 .46603 L .47946 .46702 L 1 g
F
P
p
.002 w
.47749 .46728 m .4775 .46727 L p
.47946 .46702 L 1 g
F P
s
P
p
.002 w
.48139 .46677 m .45441 .48812 L p
.47946 .46702 L 1 g
F P
s
P
p
.47946 .46702 m .48139 .46677 L .48084 .46684 L 1 g
F
P
p
.47946 .46702 m .48084 .46684 L .47749 .46728 L 1 g
F
P
p
.002 w
.4775 .46727 m .4775 .46727 L p
.47946 .46702 L 1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.44591 .46602 m .48008 .46603 L p
.47632 .46742 L 1 g
F P
s
P
p
.002 w
.44831 .47774 m .44697 .47117 L p
.47632 .46742 L 1 g
F P
s
P
p
.002 w
.44697 .47117 m .44591 .46602 L p
.47632 .46742 L 1 g
F P
s
P
p
.45826 .47608 m .4775 .46727 L .47743 .4673 L 1 g
F
P
p
.45826 .47608 m .4775 .46727 L .46807 .47178 L 1 g
F
P
p
.002 w
.47433 .46878 m .44831 .47774 L p
.48008 .46603 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .4775 .46727 L p
.47743 .4673 L 1 g
F P
s
P
p
.002 w
.4775 .46727 m .47718 .46778 L p
.46807 .47178 L 1 g
F P
s
P
p
.002 w
.44831 .47774 m .46118 .47331 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.45134 .48289 m .44991 .48046 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.44991 .48046 m .44831 .47774 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.46118 .47331 m .47433 .46878 L p
.45762 .47677 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45762 .47677 L p
1 g
F P
s
P
p
.46807 .47178 m .47718 .46778 L .45762 .47677 L 1 g
F
P
p
.45134 .48289 m .45698 .47747 L .44195 .49203 L 1 g
F
P
p
.45183 .48241 m .45221 .48205 L .45134 .48289 L 1 g
F
P
p
.45221 .48205 m .45698 .47747 L .45134 .48289 L 1 g
F
P
p
.002 w
.44195 .49203 m .4426 .49134 L p
.45134 .48289 L 1 g
F P
s
P
p
.43459 .49909 m .44881 .47859 L .4426 .49134 L 1 g
F
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44195 .49203 L p
1 g
F P
s
P
p
.002 w
.47946 .46702 m .48232 .46603 L .48139 .46677 L p
1 g
F P
s
P
p
.002 w
.4819 .4667 m .48232 .46603 L .48218 .46666 L p
1 g
F P
s
P
p
.002 w
.48218 .46666 m .47472 .50067 L p
.4819 .4667 L 1 g
F P
s
P
p
.48258 .46661 m .48271 .46659 L .4826 .46661 L 1 g
F
P
p
.002 w
.46354 .49605 m .45441 .48812 L .48139 .46677 L p
1 g
F P
s
P
p
.002 w
.4819 .4667 m .46354 .49605 L p
.48139 .46677 L 1 g
F P
s
P
p
.002 w
.4774 .46743 m .47749 .46728 L p
.4826 .46661 L 1 g
F P
s
P
p
.002 w
.48139 .46677 m .48232 .46603 L .4819 .4667 L p
1 g
F P
s
P
p
.002 w
.48445 .46632 m .48232 .46603 L p
.49866 .46409 L 1 g
F P
s
P
p
.5 .46388 m .49866 .46409 L .49634 .46331 L 1 g
F
P
p
.002 w
.5 .46442 m .47718 .46778 L .4774 .46743 L p
1 g
F P
s
P
p
.49023 .46541 m .5 .46442 L .4774 .46743 L 1 g
F
P
p
.51293 .46589 m .51897 .46682 L .5156 .4664 L 1 g
F
P
p
.5 .4634 m .51897 .46682 L .51293 .46589 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.49634 .46331 m .51875 .45895 L .51897 .46682 L p
1 g
F P
s
P
p
.002 w
.51897 .46682 m .51875 .45895 L p
.52502 .46759 L 1 g
F P
s
P
p
.002 w
.5225 .46727 m .52282 .46778 L p
.5156 .4664 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .5225 .46727 L p
1 g
F P
s
P
p
.53311 .47235 m .54302 .47747 L .5225 .46727 L 1 g
F
P
p
.002 w
.5545 .451 m .55507 .47454 L .53308 .47233 L p
1 g
F P
s
P
p
.5545 .451 m .53308 .47233 L .52417 .46807 L 1 g
F
P
p
.002 w
.53308 .47233 m .55507 .47454 L p
.54279 .47694 L 1 g
F P
s
P
p
.002 w
.54233 .47672 m .54302 .47747 L p
.53311 .47235 L 1 g
F P
s
P
p
.002 w
.54276 .4772 m .54233 .47672 L p
.55148 .48562 L 1 g
F P
s
P
p
.002 w
.55507 .47454 m .55148 .48562 L p
.54259 .47698 L 1 g
F P
s
P
p
.002 w
.54786 .4968 m .55273 .48175 L p
.55771 .49199 L 1 g
F P
s
P
p
.002 w
.55273 .48175 m .55507 .47454 L p
.55771 .49199 L 1 g
F P
s
P
p
.002 w
.55773 .49169 m .55739 .49132 L p
.56225 .50128 L 1 g
F P
s
P
p
.56191 .50063 m .56225 .50128 L .55739 .49132 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55773 .49169 L p
1 g
F P
s
P
p
.56225 .50128 m .56713 .51061 L .55773 .49169 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54276 .4772 L p
1 g
F P
s
P
p
.55156 .48569 m .55834 .49233 L .54276 .4772 L 1 g
F
P
p
.002 w
.55507 .47454 m .58888 .47674 L p
.55795 .49187 L 1 g
F P
s
P
p
.55795 .49187 m .55764 .49157 L .55507 .47454 L 1 g
F
P
p
.002 w
.55739 .49132 m .55834 .49233 L p
.55156 .48569 L 1 g
F P
s
P
p
.56191 .50063 m .563 .50289 L .56225 .50128 L 1 g
F
P
p
.002 w
.563 .50289 m .54786 .4968 L p
.55771 .49199 L 1 g
F P
s
P
p
.002 w
.56601 .50929 m .56713 .51061 L p
.56225 .50128 L 1 g
F P
s
P
p
.002 w
.53374 .51537 m .54786 .4968 L .563 .50289 L p
1 g
F P
s
P
p
.56379 .50456 m .53374 .51537 L .563 .50289 L 1 g
F
P
p
.002 w
.56664 .51004 m .56601 .50929 L p
.56709 .52081 L 1 g
F P
s
P
p
.56684 .51922 m .56709 .52081 L .56601 .50929 L 1 g
F
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56664 .51004 L p
1 g
F P
s
P
p
.56709 .52081 m .56854 .53025 L .56664 .51004 L 1 g
F
P
p
.002 w
.55768 .53592 m .53374 .51537 L p
.56614 .51077 L 1 g
F P
s
P
p
.002 w
.5672 .5235 m .55768 .53592 L p
.56614 .51077 L 1 g
F P
s
P
p
.002 w
.56741 .5286 m .56854 .53025 L p
.56709 .52081 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56741 .5286 L p
1 g
F P
s
P
p
.56446 .53872 m .56257 .5491 L .56741 .5286 L 1 g
F
P
p
.002 w
.56387 .54075 m .55768 .53592 L p
.56617 .53286 L 1 g
F P
s
P
p
.002 w
.52939 .55456 m .55768 .53592 L .56387 .54075 L p
1 g
F P
s
P
p
.55892 .5535 m .52939 .55456 L .56387 .54075 L 1 g
F
P
p
.002 w
.56145 .54698 m .56257 .5491 L p
.56429 .53968 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56145 .54698 L p
1 g
F P
s
P
p
.55676 .55289 m .54998 .56518 L .56145 .54698 L 1 g
F
P
p
.002 w
.54904 .56262 m .54998 .56518 L p
.55676 .55289 L 1 g
F P
s
P
p
.53996 .56947 m .5392 .57004 L .53959 .56982 L 1 g
F
P
p
.53308 .5735 m .52801 .57636 L .49648 .56307 L 1 g
F
P
p
.002 w
.53164 .57431 m .5322 .57686 L p
.53959 .56982 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53164 .57431 L p
1 g
F P
s
P
p
.52338 .5767 m .51111 .583 L .53164 .57431 L 1 g
F
P
p
.002 w
.51092 .58031 m .51111 .583 L p
.52338 .5767 L 1 g
F P
s
P
p
.002 w
.51103 .58183 m .51092 .58031 L p
.50014 .58103 L 1 g
F P
s
P
p
.002 w
.46246 .56064 m .49648 .56307 L .50138 .58712 L p
1 g
F P
s
P
p
.002 w
.48909 .58021 m .48889 .583 L p
.49913 .58095 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51103 .58183 L p
1 g
F P
s
P
p
.49913 .58095 m .48889 .583 L .51103 .58183 L 1 g
F
P
p
.48562 .57996 m .48307 .57977 L .48101 .57786 L 1 g
F
P
p
.002 w
.46839 .57419 m .46872 .57265 L p
.46075 .56993 L 1 g
F P
s
P
p
.002 w
.46075 .56993 m .46246 .56064 L p
.4901 .5863 L 1 g
F P
s
P
p
.002 w
.46839 .57419 m .4678 .57686 L p
.48142 .57798 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48909 .58021 L p
1 g
F P
s
P
p
.48142 .57798 m .4678 .57686 L .48909 .58021 L 1 g
F
P
p
.002 w
.46814 .57531 m .46839 .57419 L p
.46075 .56993 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46814 .57531 L p
1 g
F P
s
P
p
.45934 .5689 m .45002 .56518 L .46814 .57531 L 1 g
F
P
p
.002 w
.5484 .30745 m .49689 .29567 L .5003 .27196 L p
1 g
F P
s
P
p
.002 w
.5003 .27196 m .55798 .28511 L .5484 .30745 L p
1 g
F P
s
P
p
.002 w
.38769 .49595 m .40505 .52523 L .38528 .53905 L p
1 g
F P
s
P
p
.002 w
.38528 .53905 m .36317 .50188 L .38769 .49595 L p
1 g
F P
s
P
p
.002 w
.62663 .37617 m .59335 .33535 L .6083 .31637 L p
1 g
F P
s
P
p
.002 w
.55798 .28511 m .6083 .31637 L .59335 .33535 L p
1 g
F P
s
P
p
.002 w
.59335 .33535 m .5484 .30745 L .55798 .28511 L p
1 g
F P
s
P
p
.002 w
.40953 .34763 m .37846 .37812 L .36119 .35961 L p
1 g
F P
s
P
p
.002 w
.36119 .35961 m .39776 .3235 L .40953 .34763 L p
1 g
F P
s
P
p
.002 w
.38069 .46276 m .38769 .49595 L .36317 .50188 L p
1 g
F P
s
P
p
.002 w
.36317 .50188 m .35416 .4597 L .38069 .46276 L p
1 g
F P
s
P
p
.002 w
.60563 .51862 m .61928 .47749 L .64529 .4768 L p
1 g
F P
s
P
p
.002 w
.64454 .42518 m .64529 .4768 L .61928 .47749 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.38489 .42916 m .38069 .46276 L .35416 .4597 L p
1 g
F P
s
P
p
.002 w
.35416 .4597 m .35938 .41691 L .38489 .42916 L p
1 g
F P
s
P
p
.002 w
.44932 .32892 m .40953 .34763 L .39776 .3235 L p
1 g
F P
s
P
p
.002 w
.39776 .3235 m .44471 .30129 L .44932 .32892 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61928 .47749 m .61853 .43378 L .64454 .42518 L p
1 g
F P
s
P
p
.002 w
.62663 .37617 m .64454 .42518 L .61853 .43378 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.39997 .39878 m .38489 .42916 L .35938 .41691 L p
1 g
F P
s
P
p
.002 w
.35938 .41691 m .37846 .37812 L .39997 .39878 L p
1 g
F P
s
P
p
.002 w
.49347 .32425 m .44932 .32892 L .44471 .30129 L p
1 g
F P
s
P
p
.002 w
.44471 .30129 m .49689 .29567 L .49347 .32425 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.61853 .43378 m .60328 .39233 L .62663 .37617 L p
1 g
F P
s
P
p
.002 w
.59335 .33535 m .62663 .37617 L .60328 .39233 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.61928 .47749 m .60563 .51862 L .57828 .50904 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43088 .54757 m .40505 .52523 L .42834 .50809 L p
1 g
F P
s
P
p
.002 w
.44619 .52354 m .46802 .53258 L .46246 .56064 L p
1 g
F P
s
P
p
.002 w
.49648 .56307 m .46246 .56064 L .46802 .53258 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53704 .33424 m .49347 .32425 L .49689 .29567 L p
1 g
F P
s
P
p
.002 w
.49689 .29567 m .5484 .30745 L .53704 .33424 L p
1 g
F P
s
P
p
.002 w
.41639 .48783 m .42834 .50809 L .40505 .52523 L p
1 g
F P
s
P
p
.002 w
.40505 .52523 m .38769 .49595 L .41639 .48783 L p
1 g
F P
s
P
p
.002 w
.60328 .39233 m .57507 .35784 L .59335 .33535 L p
1 g
F P
s
P
p
.002 w
.5484 .30745 m .59335 .33535 L .57507 .35784 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46802 .53258 m .49154 .53423 L .49648 .56307 L p
1 g
F P
s
P
p
.002 w
.52939 .55456 m .49648 .56307 L .49154 .53423 L p
1 g
F P
s
P
p
.002 w
.4244 .37495 m .39997 .39878 L .37846 .37812 L p
1 g
F P
s
P
p
.002 w
.37846 .37812 m .40953 .34763 L .4244 .37495 L p
1 g
F P
s
P
p
.002 w
.57507 .35784 m .53704 .33424 L .5484 .30745 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41162 .46491 m .41639 .48783 L .38769 .49595 L p
1 g
F P
s
P
p
.002 w
.38769 .49595 m .38069 .46276 L .41162 .46491 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.57828 .50904 m .58888 .47674 L .61928 .47749 L p
1 g
F P
s
P
p
.002 w
.61853 .43378 m .61928 .47749 L .58888 .47674 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.49154 .53423 m .51426 .5283 L .52939 .55456 L p
1 g
F P
s
P
p
.002 w
.55768 .53592 m .52939 .55456 L .51426 .5283 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.4146 .44175 m .41162 .46491 L .38069 .46276 L p
1 g
F P
s
P
p
.002 w
.38069 .46276 m .38489 .42916 L .4146 .44175 L p
1 g
F P
s
P
p
.002 w
.45561 .36039 m .4244 .37495 L .40953 .34763 L p
1 g
F P
s
P
p
.002 w
.40953 .34763 m .44932 .32892 L .45561 .36039 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.51426 .5283 m .53374 .51537 L .55768 .53592 L p
1 g
F P
s
P
p
.002 w
.58888 .47674 m .58818 .44249 L .61853 .43378 L p
1 g
F P
s
P
p
.002 w
.60328 .39233 m .61853 .43378 L .58818 .44249 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.42506 .42087 m .4146 .44175 L .38489 .42916 L p
1 g
F P
s
P
p
.002 w
.38489 .42916 m .39997 .39878 L .42506 .42087 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49018 .35681 m .45561 .36039 L .44932 .32892 L p
1 g
F P
s
P
p
.002 w
.44932 .32892 m .49347 .32425 L .49018 .35681 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.58818 .44249 m .57615 .41007 L .60328 .39233 L p
1 g
F P
s
P
p
.002 w
.57507 .35784 m .60328 .39233 L .57615 .41007 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45441 .48812 m .46354 .49605 L .44619 .52354 L p
1 g
F P
s
P
p
.002 w
.46802 .53258 m .44619 .52354 L .46354 .49605 L p
1 g
F P
s
P
p
.002 w
.46354 .49605 m .47472 .50067 L .46802 .53258 L p
1 g
F P
s
P
p
.002 w
.49154 .53423 m .46802 .53258 L .47472 .50067 L p
1 g
F P
s
P
p
.002 w
.52427 .36466 m .49018 .35681 L .49347 .32425 L p
1 g
F P
s
P
p
.002 w
.49347 .32425 m .53704 .33424 L .52427 .36466 L p
1 g
F P
s
P
p
.002 w
.42834 .50809 m .41639 .48783 L .44831 .47774 L p
1 g
F P
s
P
p
.002 w
.44193 .40455 m .42506 .42087 L .39997 .39878 L p
1 g
F P
s
P
p
.002 w
.39997 .39878 m .4244 .37495 L .44193 .40455 L p
1 g
F P
s
P
p
.002 w
.57615 .41007 m .55403 .38311 L .57507 .35784 L p
1 g
F P
s
P
p
.002 w
.53704 .33424 m .57507 .35784 L .55403 .38311 L p
1 g
F P
s
P
p
.002 w
.47472 .50067 m .48676 .50149 L .49154 .53423 L p
1 g
F P
s
P
p
.002 w
.51426 .5283 m .49154 .53423 L .48676 .50149 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.55403 .38311 m .52427 .36466 L .53704 .33424 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.44591 .46602 m .44831 .47774 L .41639 .48783 L p
1 g
F P
s
P
p
.002 w
.41639 .48783 m .41162 .46491 L .44591 .46602 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.58818 .44249 m .58888 .47674 L .55507 .47454 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.48676 .50149 m .49837 .49843 L .51426 .5283 L p
1 g
F P
s
P
p
.002 w
.53374 .51537 m .51426 .5283 L .49837 .49843 L p
1 g
F P
s
P
p
.002 w
.44748 .45421 m .44591 .46602 L .41162 .46491 L p
1 g
F P
s
P
p
.002 w
.41162 .46491 m .4146 .44175 L .44748 .45421 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.4634 .39461 m .44193 .40455 L .4244 .37495 L p
1 g
F P
s
P
p
.002 w
.4244 .37495 m .45561 .36039 L .4634 .39461 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.49837 .49843 m .5083 .49179 L .53374 .51537 L p
1 g
F P
s
P
p
.002 w
.54786 .4968 m .53374 .51537 L .5083 .49179 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.55507 .47454 m .5545 .451 L .58818 .44249 L p
1 g
F P
s
P
p
.002 w
.57615 .41007 m .58818 .44249 L .5545 .451 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.45286 .44358 m .44748 .45421 L .4146 .44175 L p
1 g
F P
s
P
p
.002 w
.4146 .44175 m .42506 .42087 L .45286 .44358 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48715 .3922 m .4634 .39461 L .45561 .36039 L p
1 g
F P
s
P
p
.002 w
.45561 .36039 m .49018 .35681 L .48715 .3922 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.5083 .49179 m .51547 .48229 L .54786 .4968 L p
1 g
F P
s
P
p
.002 w
.5545 .451 m .54618 .42875 L .57615 .41007 L p
1 g
F P
s
P
p
.002 w
.55403 .38311 m .57615 .41007 L .54618 .42875 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.46148 .43531 m .45286 .44358 L .42506 .42087 L p
1 g
F P
s
P
p
.002 w
.42506 .42087 m .44193 .40455 L .46148 .43531 L p
1 g
F P
s
P
p
.002 w
.51053 .39762 m .48715 .3922 L .49018 .35681 L p
1 g
F P
s
P
p
.002 w
.49018 .35681 m .52427 .36466 L .51053 .39762 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54618 .42875 m .53096 .41027 L .55403 .38311 L p
1 g
F P
s
P
p
.002 w
.52427 .36466 m .55403 .38311 L .53096 .41027 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.53096 .41027 m .51053 .39762 L .52427 .36466 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.44591 .46602 m .44748 .45421 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.47242 .43029 m .46148 .43531 L .44193 .40455 L p
1 g
F P
s
P
p
.002 w
.44193 .40455 m .4634 .39461 L .47242 .43029 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54618 .42875 m .5545 .451 L .51875 .45895 L p
1 g
F P
s
P
p
.002 w
.44748 .45421 m .45286 .44358 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.48449 .42909 m .47242 .43029 L .4634 .39461 L p
1 g
F P
s
P
p
.002 w
.4634 .39461 m .48715 .3922 L .48449 .42909 L p
1 g
F P
s
P
p
.002 w
.45286 .44358 m .46148 .43531 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.51875 .45895 m .51449 .44765 L .54618 .42875 L p
1 g
F P
s
P
p
.002 w
.53096 .41027 m .54618 .42875 L .51449 .44765 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.49636 .43186 m .48449 .42909 L .48715 .3922 L p
1 g
F P
s
P
p
.002 w
.48715 .3922 m .51053 .39762 L .49636 .43186 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.51449 .44765 m .51875 .45895 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.50674 .43828 m .51449 .44765 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.49636 .43186 m .50674 .43828 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.004 w
.49863 .43326 m
.5 .43051 L
s
P
p
.002 w
.48449 .42909 m .49636 .43186 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.47242 .43029 m .48449 .42909 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.46148 .43531 m .47242 .43029 L .48232 .46603 L closepath p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.51449 .44765 m .50674 .43828 L .53096 .41027 L p
1 g
F P
s
P
p
.002 w
.51053 .39762 m .53096 .41027 L .50674 .43828 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.50674 .43828 m .49636 .43186 L .51053 .39762 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.004 w
.47134 .48808 m
.48232 .46603 L
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .23075 .51966 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .47134 .48808 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.678295)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.678295)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50287 .45689 m .51926 .44829 L .50213 .42548 L p
1 g
F P
s
P
p
.002 w
.50213 .42548 m .49383 .42983 L .50287 .45689 L p
1 g
F P
s
P
p
.002 w
.50859 .41871 m .50213 .42548 L .51926 .44829 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .49383 .42983 L .50213 .42548 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .50213 .42548 L .50859 .41871 L closepath p
1 g
F P
s
P
p
.002 w
.48462 .45981 m .50287 .45689 L .49383 .42983 L p
1 g
F P
s
P
p
.002 w
.49383 .42983 m .48459 .4313 L .48462 .45981 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .48459 .4313 L .49383 .42983 L closepath p
1 g
F P
s
P
p
.002 w
.51926 .44829 m .53205 .43493 L .50859 .41871 L p
1 g
F P
s
P
p
.002 w
.51252 .41024 m .50859 .41871 L .53205 .43493 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .50859 .41871 L .51252 .41024 L closepath p
1 g
F P
s
P
p
.002 w
.46643 .45673 m .48462 .45981 L .48459 .4313 L p
1 g
F P
s
P
p
.002 w
.48459 .4313 m .47539 .42972 L .46643 .45673 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .47539 .42972 L .48459 .4313 L closepath p
1 g
F P
s
P
p
.002 w
.53205 .43493 m .53985 .41822 L .51252 .41024 L p
1 g
F P
s
P
p
.002 w
.5135 .40099 m .51252 .41024 L .53985 .41822 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .51252 .41024 L .5135 .40099 L closepath p
1 g
F P
s
P
p
.002 w
.45027 .44795 m .46643 .45673 L .47539 .42972 L p
1 g
F P
s
P
p
.002 w
.47539 .42972 m .46723 .42526 L .45027 .44795 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .46723 .42526 L .47539 .42972 L closepath p
1 g
F P
s
P
p
.002 w
.5119 .48347 m .53603 .47081 L .51926 .44829 L p
1 g
F P
s
P
p
.002 w
.51926 .44829 m .50287 .45689 L .5119 .48347 L p
1 g
F P
s
P
p
.002 w
.53205 .43493 m .51926 .44829 L .53603 .47081 L p
1 g
F P
s
P
p
.002 w
.48502 .4878 m .5119 .48347 L .50287 .45689 L p
1 g
F P
s
P
p
.002 w
.50287 .45689 m .48462 .45981 L .48502 .4878 L p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .45736 .40984 L .461 .41839 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .461 .41839 L .46723 .42526 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .5135 .40099 L .5114 .39195 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .5114 .39195 L .50644 .3841 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .50644 .3841 L .49916 .3783 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .49916 .3783 L .49034 .37518 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .49034 .37518 L .48094 .37509 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .48094 .37509 L .47199 .37805 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .47199 .37805 L .46446 .38373 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .46446 .38373 L .45918 .39152 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .45918 .39152 L .45673 .40055 L closepath p
1 g
F P
s
P
p
.002 w
.48494 .40277 m .45673 .40055 L .45736 .40984 L closepath p
1 g
F P
s
P
p
.002 w
.53603 .47081 m .55487 .45115 L .53205 .43493 L p
1 g
F P
s
P
p
.002 w
.53985 .41822 m .53205 .43493 L .55487 .45115 L p
1 g
F P
s
P
p
.002 w
.53985 .41822 m .54183 .39992 L .5135 .40099 L p
1 g
F P
s
P
p
.002 w
.5114 .39195 m .5135 .40099 L .54183 .39992 L p
1 g
F P
s
P
p
.002 w
.45822 .48332 m .48502 .4878 L .48462 .45981 L p
1 g
F P
s
P
p
.002 w
.48462 .45981 m .46643 .45673 L .45822 .48332 L p
1 g
F P
s
P
p
.002 w
.43787 .43439 m .45027 .44795 L .46723 .42526 L p
1 g
F P
s
P
p
.002 w
.46723 .42526 m .461 .41839 L .43787 .43439 L p
1 g
F P
s
P
p
.002 w
.54183 .39992 m .53773 .38201 L .5114 .39195 L p
1 g
F P
s
P
p
.002 w
.50644 .3841 m .5114 .39195 L .53773 .38201 L p
1 g
F P
s
P
p
.002 w
.4306 .41748 m .43787 .43439 L .461 .41839 L p
1 g
F P
s
P
p
.002 w
.461 .41839 m .45736 .40984 L .4306 .41748 L p
1 g
F P
s
P
p
.002 w
.55487 .45115 m .56642 .42655 L .53985 .41822 L p
1 g
F P
s
P
p
.002 w
.54183 .39992 m .53985 .41822 L .56642 .42655 L p
1 g
F P
s
P
p
.002 w
.43434 .47044 m .45822 .48332 L .46643 .45673 L p
1 g
F P
s
P
p
.002 w
.46643 .45673 m .45027 .44795 L .43434 .47044 L p
1 g
F P
s
P
p
.002 w
.53773 .38201 m .52796 .36641 L .50644 .3841 L p
1 g
F P
s
P
p
.002 w
.49916 .3783 m .50644 .3841 L .52796 .36641 L p
1 g
F P
s
P
p
.002 w
.42929 .39904 m .4306 .41748 L .45736 .40984 L p
1 g
F P
s
P
p
.002 w
.45736 .40984 m .45673 .40055 L .42929 .39904 L p
1 g
F P
s
P
p
.002 w
.56642 .42655 m .56941 .39959 L .54183 .39992 L p
1 g
F P
s
P
p
.002 w
.53773 .38201 m .54183 .39992 L .56941 .39959 L p
1 g
F P
s
P
p
.002 w
.52796 .36641 m .51355 .35485 L .49916 .3783 L p
1 g
F P
s
P
p
.002 w
.49034 .37518 m .49916 .3783 L .51355 .35485 L p
1 g
F P
s
P
p
.002 w
.43412 .38108 m .42929 .39904 L .45673 .40055 L p
1 g
F P
s
P
p
.002 w
.45673 .40055 m .45918 .39152 L .43412 .38108 L p
1 g
F P
s
P
p
.002 w
.41598 .45049 m .43434 .47044 L .45027 .44795 L p
1 g
F P
s
P
p
.002 w
.45027 .44795 m .43787 .43439 L .41598 .45049 L p
1 g
F P
s
P
p
.002 w
.52074 .50907 m .55211 .49261 L .53603 .47081 L p
1 g
F P
s
P
p
.002 w
.53603 .47081 m .5119 .48347 L .52074 .50907 L p
1 g
F P
s
P
p
.002 w
.55487 .45115 m .53603 .47081 L .55211 .49261 L p
1 g
F P
s
P
p
.002 w
.48579 .51474 m .52074 .50907 L .5119 .48347 L p
1 g
F P
s
P
p
.002 w
.5119 .48347 m .48502 .4878 L .48579 .51474 L p
1 g
F P
s
P
p
.002 w
.51355 .35485 m .49605 .34861 L .49034 .37518 L p
1 g
F P
s
P
p
.002 w
.48094 .37509 m .49034 .37518 L .49605 .34861 L p
1 g
F P
s
P
p
.002 w
.44459 .36559 m .43412 .38108 L .45918 .39152 L p
1 g
F P
s
P
p
.002 w
.45918 .39152 m .46446 .38373 L .44459 .36559 L p
1 g
F P
s
P
p
.002 w
.49605 .34861 m .47736 .3484 L .48094 .37509 L p
1 g
F P
s
P
p
.002 w
.47199 .37805 m .48094 .37509 L .47736 .3484 L p
1 g
F P
s
P
p
.002 w
.55211 .49261 m .57664 .46707 L .55487 .45115 L p
1 g
F P
s
P
p
.002 w
.56642 .42655 m .55487 .45115 L .57664 .46707 L p
1 g
F P
s
P
p
.002 w
.45955 .35428 m .44459 .36559 L .46446 .38373 L p
1 g
F P
s
P
p
.002 w
.46446 .38373 m .47199 .37805 L .45955 .35428 L p
1 g
F P
s
P
p
.002 w
.45091 .50898 m .48579 .51474 L .48502 .4878 L p
1 g
F P
s
P
p
.002 w
.48502 .4878 m .45822 .48332 L .45091 .50898 L p
1 g
F P
s
P
p
.002 w
.47736 .3484 m .45955 .35428 L .47199 .37805 L p
1 g
F P
s
P
p
.002 w
.56941 .39959 m .56345 .37313 L .53773 .38201 L p
1 g
F P
s
P
p
.002 w
.52796 .36641 m .53773 .38201 L .56345 .37313 L p
1 g
F P
s
P
p
.002 w
.40516 .42554 m .41598 .45049 L .43787 .43439 L p
1 g
F P
s
P
p
.002 w
.43787 .43439 m .4306 .41748 L .40516 .42554 L p
1 g
F P
s
P
p
.002 w
.57664 .46707 m .59173 .43509 L .56642 .42655 L p
1 g
F P
s
P
p
.002 w
.56941 .39959 m .56642 .42655 L .59173 .43509 L p
1 g
F P
s
P
p
.002 w
.41979 .49231 m .45091 .50898 L .45822 .48332 L p
1 g
F P
s
P
p
.002 w
.45822 .48332 m .43434 .47044 L .41979 .49231 L p
1 g
F P
s
P
p
.002 w
.56345 .37313 m .5491 .35005 L .52796 .36641 L p
1 g
F P
s
P
p
.002 w
.51355 .35485 m .52796 .36641 L .5491 .35005 L p
1 g
F P
s
P
p
.002 w
.40315 .39828 m .40516 .42554 L .4306 .41748 L p
1 g
F P
s
P
p
.002 w
.4306 .41748 m .42929 .39904 L .40315 .39828 L p
1 g
F P
s
P
p
.002 w
.59173 .43509 m .59572 .40001 L .56941 .39959 L p
1 g
F P
s
P
p
.002 w
.56345 .37313 m .56941 .39959 L .59572 .40001 L p
1 g
F P
s
P
p
.002 w
.39578 .46638 m .41979 .49231 L .43434 .47044 L p
1 g
F P
s
P
p
.002 w
.43434 .47044 m .41598 .45049 L .39578 .46638 L p
1 g
F P
s
P
p
.002 w
.5491 .35005 m .52784 .33289 L .51355 .35485 L p
1 g
F P
s
P
p
.002 w
.49605 .34861 m .51355 .35485 L .52784 .33289 L p
1 g
F P
s
P
p
.002 w
.41024 .37168 m .40315 .39828 L .42929 .39904 L p
1 g
F P
s
P
p
.002 w
.42929 .39904 m .43412 .38108 L .41024 .37168 L p
1 g
F P
s
P
p
.002 w
.52923 .5332 m .5672 .51327 L .55211 .49261 L p
1 g
F P
s
P
p
.002 w
.55211 .49261 m .52074 .50907 L .52923 .5332 L p
1 g
F P
s
P
p
.002 w
.57664 .46707 m .55211 .49261 L .5672 .51327 L p
1 g
F P
s
P
p
.002 w
.48693 .54011 m .52923 .5332 L .52074 .50907 L p
1 g
F P
s
P
p
.002 w
.52074 .50907 m .48579 .51474 L .48693 .54011 L p
1 g
F P
s
P
p
.002 w
.52784 .33289 m .50195 .32359 L .49605 .34861 L p
1 g
F P
s
P
p
.002 w
.47736 .3484 m .49605 .34861 L .50195 .32359 L p
1 g
F P
s
P
p
.002 w
.42571 .34871 m .41024 .37168 L .43412 .38108 L p
1 g
F P
s
P
p
.002 w
.43412 .38108 m .44459 .36559 L .42571 .34871 L p
1 g
F P
s
P
p
.002 w
.5672 .51327 m .59693 .48238 L .57664 .46707 L p
1 g
F P
s
P
p
.002 w
.59173 .43509 m .57664 .46707 L .59693 .48238 L p
1 g
F P
s
P
p
.002 w
.50195 .32359 m .47427 .32324 L .47736 .3484 L p
1 g
F P
s
P
p
.002 w
.45955 .35428 m .47736 .3484 L .47427 .32324 L p
1 g
F P
s
P
p
.002 w
.44787 .33194 m .42571 .34871 L .44459 .36559 L p
1 g
F P
s
P
p
.002 w
.44459 .36559 m .45955 .35428 L .44787 .33194 L p
1 g
F P
s
P
p
.002 w
.44467 .53321 m .48693 .54011 L .48579 .51474 L p
1 g
F P
s
P
p
.002 w
.48579 .51474 m .45091 .50898 L .44467 .53321 L p
1 g
F P
s
P
p
.002 w
.59572 .40001 m .58806 .36552 L .56345 .37313 L p
1 g
F P
s
P
p
.002 w
.5491 .35005 m .56345 .37313 L .58806 .36552 L p
1 g
F P
s
P
p
.002 w
.47427 .32324 m .44787 .33194 L .45955 .35428 L p
1 g
F P
s
P
p
.002 w
.38157 .43388 m .39578 .46638 L .41598 .45049 L p
1 g
F P
s
P
p
.002 w
.41598 .45049 m .40516 .42554 L .38157 .43388 L p
1 g
F P
s
P
p
.002 w
.59693 .48238 m .61527 .4437 L .59173 .43509 L p
1 g
F P
s
P
p
.002 w
.59572 .40001 m .59173 .43509 L .61527 .4437 L p
1 g
F P
s
P
p
.002 w
.40691 .5131 m .44467 .53321 L .45091 .50898 L p
1 g
F P
s
P
p
.002 w
.45091 .50898 m .41979 .49231 L .40691 .5131 L p
1 g
F P
s
P
p
.002 w
.58806 .36552 m .56943 .33536 L .5491 .35005 L p
1 g
F P
s
P
p
.002 w
.52784 .33289 m .5491 .35005 L .56943 .33536 L p
1 g
F P
s
P
p
.002 w
.37885 .3983 m .38157 .43388 L .40516 .42554 L p
1 g
F P
s
P
p
.002 w
.40516 .42554 m .40315 .39828 L .37885 .3983 L p
1 g
F P
s
P
p
.002 w
.61527 .4437 m .62021 .4012 L .59572 .40001 L p
1 g
F P
s
P
p
.002 w
.58806 .36552 m .59572 .40001 L .62021 .4012 L p
1 g
F P
s
P
p
.002 w
.37771 .48175 m .40691 .5131 L .41979 .49231 L p
1 g
F P
s
P
p
.002 w
.41979 .49231 m .39578 .46638 L .37771 .48175 L p
1 g
F P
s
P
p
.002 w
.56943 .33536 m .54174 .31288 L .52784 .33289 L p
1 g
F P
s
P
p
.002 w
.50195 .32359 m .52784 .33289 L .54174 .31288 L p
1 g
F P
s
P
p
.002 w
.38804 .36353 m .37885 .3983 L .40315 .39828 L p
1 g
F P
s
P
p
.002 w
.40315 .39828 m .41024 .37168 L .38804 .36353 L p
1 g
F P
s
P
p
.002 w
.53719 .55534 m .58097 .53235 L .5672 .51327 L p
1 g
F P
s
P
p
.002 w
.5672 .51327 m .52923 .5332 L .53719 .55534 L p
1 g
F P
s
P
p
.002 w
.59693 .48238 m .5672 .51327 L .58097 .53235 L p
1 g
F P
s
P
p
.002 w
.48842 .56335 m .53719 .55534 L .52923 .5332 L p
1 g
F P
s
P
p
.002 w
.52923 .5332 m .48693 .54011 L .48842 .56335 L p
1 g
F P
s
P
p
.002 w
.54174 .31288 m .50794 .30066 L .50195 .32359 L p
1 g
F P
s
P
p
.002 w
.47427 .32324 m .50195 .32359 L .50794 .30066 L p
1 g
F P
s
P
p
.002 w
.40823 .33346 m .38804 .36353 L .41024 .37168 L p
1 g
F P
s
P
p
.002 w
.41024 .37168 m .42571 .34871 L .40823 .33346 L p
1 g
F P
s
P
p
.002 w
.62021 .4012 m .61104 .35936 L .58806 .36552 L p
1 g
F P
s
P
p
.002 w
.56943 .33536 m .58806 .36552 L .61104 .35936 L p
1 g
F P
s
P
p
.002 w
.58097 .53235 m .61528 .49677 L .59693 .48238 L p
1 g
F P
s
P
p
.002 w
.61527 .4437 m .59693 .48238 L .61528 .49677 L p
1 g
F P
s
P
p
.002 w
.36036 .44236 m .37771 .48175 L .39578 .46638 L p
1 g
F P
s
P
p
.002 w
.39578 .46638 m .38157 .43388 L .36036 .44236 L p
1 g
F P
s
P
p
.002 w
.50794 .30066 m .47175 .30016 L .47427 .32324 L p
1 g
F P
s
P
p
.002 w
.44787 .33194 m .47427 .32324 L .47175 .30016 L p
1 g
F P
s
P
p
.002 w
.43967 .55548 m .48842 .56335 L .48693 .54011 L p
1 g
F P
s
P
p
.002 w
.48693 .54011 m .44467 .53321 L .43967 .55548 L p
1 g
F P
s
P
p
.002 w
.43721 .31151 m .40823 .33346 L .42571 .34871 L p
1 g
F P
s
P
p
.002 w
.42571 .34871 m .44787 .33194 L .43721 .31151 L p
1 g
F P
s
P
p
.002 w
.47175 .30016 m .43721 .31151 L .44787 .33194 L p
1 g
F P
s
P
p
.002 w
.61528 .49677 m .63651 .45219 L .61527 .4437 L p
1 g
F P
s
P
p
.002 w
.62021 .4012 m .61527 .4437 L .63651 .45219 L p
1 g
F P
s
P
p
.002 w
.39604 .53238 m .43967 .55548 L .44467 .53321 L p
1 g
F P
s
P
p
.002 w
.44467 .53321 m .40691 .5131 L .39604 .53238 L p
1 g
F P
s
P
p
.002 w
.61104 .35936 m .58854 .32269 L .56943 .33536 L p
1 g
F P
s
P
p
.002 w
.54174 .31288 m .56943 .33536 L .58854 .32269 L p
1 g
F P
s
P
p
.002 w
.35694 .39914 m .36036 .44236 L .38157 .43388 L p
1 g
F P
s
P
p
.002 w
.38157 .43388 m .37885 .3983 L .35694 .39914 L p
1 g
F P
s
P
p
.002 w
.63651 .45219 m .64232 .40316 L .62021 .4012 L p
1 g
F P
s
P
p
.002 w
.61104 .35936 m .62021 .4012 L .64232 .40316 L p
1 g
F P
s
P
p
.002 w
.36223 .49626 m .39604 .53238 L .40691 .5131 L p
1 g
F P
s
P
p
.002 w
.40691 .5131 m .37771 .48175 L .36223 .49626 L p
1 g
F P
s
P
p
.002 w
.58854 .32269 m .55497 .2953 L .54174 .31288 L p
1 g
F P
s
P
p
.002 w
.50794 .30066 m .54174 .31288 L .55497 .2953 L p
1 g
F P
s
P
p
.002 w
.36803 .35684 m .35694 .39914 L .37885 .3983 L p
1 g
F P
s
P
p
.002 w
.37885 .3983 m .38804 .36353 L .36803 .35684 L p
1 g
F P
s
P
p
.002 w
.55497 .2953 m .51391 .28036 L .50794 .30066 L p
1 g
F P
s
P
p
.002 w
.47175 .30016 m .50794 .30066 L .51391 .28036 L p
1 g
F P
s
P
p
.002 w
.54444 .57495 m .59309 .54941 L .58097 .53235 L p
1 g
F P
s
P
p
.002 w
.58097 .53235 m .53719 .55534 L .54444 .57495 L p
1 g
F P
s
P
p
.002 w
.61528 .49677 m .58097 .53235 L .59309 .54941 L p
1 g
F P
s
P
p
.002 w
.49025 .5839 m .54444 .57495 L .53719 .55534 L p
1 g
F P
s
P
p
.002 w
.53719 .55534 m .48842 .56335 L .49025 .5839 L p
1 g
F P
s
P
p
.002 w
.39256 .32023 m .36803 .35684 L .38804 .36353 L p
1 g
F P
s
P
p
.002 w
.38804 .36353 m .40823 .33346 L .39256 .32023 L p
1 g
F P
s
P
p
.002 w
.64232 .40316 m .63185 .35482 L .61104 .35936 L p
1 g
F P
s
P
p
.002 w
.58854 .32269 m .61104 .35936 L .63185 .35482 L p
1 g
F P
s
P
p
.002 w
.34207 .45079 m .36223 .49626 L .37771 .48175 L p
1 g
F P
s
P
p
.002 w
.37771 .48175 m .36036 .44236 L .34207 .45079 L p
1 g
F P
s
P
p
.002 w
.59309 .54941 m .63124 .5099 L .61528 .49677 L p
1 g
F P
s
P
p
.002 w
.63651 .45219 m .61528 .49677 L .63124 .5099 L p
1 g
F P
s
P
p
.002 w
.43606 .57524 m .49025 .5839 L .48842 .56335 L p
1 g
F P
s
P
p
.002 w
.48842 .56335 m .43967 .55548 L .43606 .57524 L p
1 g
F P
s
P
p
.002 w
.51391 .28036 m .46987 .2797 L .47175 .30016 L p
1 g
F P
s
P
p
.002 w
.43721 .31151 m .47175 .30016 L .46987 .2797 L p
1 g
F P
s
P
p
.002 w
.42783 .2935 m .39256 .32023 L .40823 .33346 L p
1 g
F P
s
P
p
.002 w
.40823 .33346 m .43721 .31151 L .42783 .2935 L p
1 g
F P
s
P
p
.002 w
.46987 .2797 m .42783 .2935 L .43721 .31151 L p
1 g
F P
s
P
p
.002 w
.63124 .5099 m .65491 .46038 L .63651 .45219 L p
1 g
F P
s
P
p
.002 w
.64232 .40316 m .63651 .45219 L .65491 .46038 L p
1 g
F P
s
P
p
.002 w
.3875 .54965 m .43606 .57524 L .43967 .55548 L p
1 g
F P
s
P
p
.002 w
.43967 .55548 m .39604 .53238 L .3875 .54965 L p
1 g
F P
s
P
p
.002 w
.63185 .35482 m .60596 .31239 L .58854 .32269 L p
1 g
F P
s
P
p
.002 w
.55497 .2953 m .58854 .32269 L .60596 .31239 L p
1 g
F P
s
P
p
.002 w
.33801 .40082 m .34207 .45079 L .36036 .44236 L p
1 g
F P
s
P
p
.002 w
.36036 .44236 m .35694 .39914 L .33801 .40082 L p
1 g
F P
s
P
p
.002 w
.65491 .46038 m .66147 .40589 L .64232 .40316 L p
1 g
F P
s
P
p
.002 w
.63185 .35482 m .64232 .40316 L .66147 .40589 L p
1 g
F P
s
P
p
.002 w
.3498 .50955 m .3875 .54965 L .39604 .53238 L p
1 g
F P
s
P
p
.002 w
.39604 .53238 m .36223 .49626 L .3498 .50955 L p
1 g
F P
s
P
p
.002 w
.60596 .31239 m .56722 .28063 L .55497 .2953 L p
1 g
F P
s
P
p
.002 w
.51391 .28036 m .55497 .2953 L .56722 .28063 L p
1 g
F P
s
P
p
.002 w
.35077 .35183 m .33801 .40082 L .35694 .39914 L p
1 g
F P
s
P
p
.002 w
.35694 .39914 m .36803 .35684 L .35077 .35183 L p
1 g
F P
s
P
p
.002 w
.56722 .28063 m .51972 .26326 L .51391 .28036 L p
1 g
F P
s
P
p
.002 w
.46987 .2797 m .51391 .28036 L .51972 .26326 L p
1 g
F P
s
P
p
.002 w
.55078 .59149 m .60321 .56397 L .59309 .54941 L p
1 g
F P
s
P
p
.002 w
.59309 .54941 m .54444 .57495 L .55078 .59149 L p
1 g
F P
s
P
p
.002 w
.63124 .5099 m .59309 .54941 L .60321 .56397 L p
1 g
F P
s
P
p
.002 w
.4924 .60118 m .55078 .59149 L .54444 .57495 L p
1 g
F P
s
P
p
.002 w
.54444 .57495 m .49025 .5839 L .4924 .60118 L p
1 g
F P
s
P
p
.002 w
.37913 .3094 m .35077 .35183 L .36803 .35684 L p
1 g
F P
s
P
p
.002 w
.36803 .35684 m .39256 .32023 L .37913 .3094 L p
1 g
F P
s
P
p
.002 w
.66147 .40589 m .64995 .3521 L .63185 .35482 L p
1 g
F P
s
P
p
.002 w
.60596 .31239 m .63185 .35482 L .64995 .3521 L p
1 g
F P
s
P
p
.002 w
.32725 .45899 m .3498 .50955 L .36223 .49626 L p
1 g
F P
s
P
p
.002 w
.36223 .49626 m .34207 .45079 L .32725 .45899 L p
1 g
F P
s
P
p
.002 w
.60321 .56397 m .64434 .52142 L .63124 .5099 L p
1 g
F P
s
P
p
.002 w
.65491 .46038 m .63124 .5099 L .64434 .52142 L p
1 g
F P
s
P
p
.002 w
.43398 .59192 m .4924 .60118 L .49025 .5839 L p
1 g
F P
s
P
p
.002 w
.49025 .5839 m .43606 .57524 L .43398 .59192 L p
1 g
F P
s
P
p
.002 w
.51972 .26326 m .46872 .26244 L .46987 .2797 L p
1 g
F P
s
P
p
.002 w
.42783 .2935 m .46987 .2797 L .46872 .26244 L p
1 g
F P
s
P
p
.002 w
.42 .27841 m .37913 .3094 L .39256 .32023 L p
1 g
F P
s
P
p
.002 w
.39256 .32023 m .42783 .2935 L .42 .27841 L p
1 g
F P
s
P
p
.002 w
.46872 .26244 m .42 .27841 L .42783 .2935 L p
1 g
F P
s
P
p
.002 w
.64434 .52142 m .66992 .46809 L .65491 .46038 L p
1 g
F P
s
P
p
.002 w
.66147 .40589 m .65491 .46038 L .66992 .46809 L p
1 g
F P
s
P
p
.002 w
.38159 .56442 m .43398 .59192 L .43606 .57524 L p
1 g
F P
s
P
p
.002 w
.43606 .57524 m .3875 .54965 L .38159 .56442 L p
1 g
F P
s
P
p
.002 w
.64995 .3521 m .62124 .30481 L .60596 .31239 L p
1 g
F P
s
P
p
.002 w
.56722 .28063 m .60596 .31239 L .62124 .30481 L p
1 g
F P
s
P
p
.002 w
.32263 .40333 m .32725 .45899 L .34207 .45079 L p
1 g
F P
s
P
p
.002 w
.34207 .45079 m .33801 .40082 L .32263 .40333 L p
1 g
F P
s
P
p
.002 w
.66992 .46809 m .67709 .40936 L .66147 .40589 L p
1 g
F P
s
P
p
.002 w
.64995 .3521 m .66147 .40589 L .67709 .40936 L p
1 g
F P
s
P
p
.002 w
.34087 .52126 m .38159 .56442 L .3875 .54965 L p
1 g
F P
s
P
p
.002 w
.3875 .54965 m .3498 .50955 L .34087 .52126 L p
1 g
F P
s
P
p
.002 w
.62124 .30481 m .57814 .26936 L .56722 .28063 L p
1 g
F P
s
P
p
.002 w
.51972 .26326 m .56722 .28063 L .57814 .26936 L p
1 g
F P
s
P
p
.002 w
.33679 .34871 m .32263 .40333 L .33801 .40082 L p
1 g
F P
s
P
p
.002 w
.33801 .40082 m .35077 .35183 L .33679 .34871 L p
1 g
F P
s
P
p
.002 w
.57814 .26936 m .52522 .24993 L .51972 .26326 L p
1 g
F P
s
P
p
.002 w
.46872 .26244 m .51972 .26326 L .52522 .24993 L p
1 g
F P
s
P
p
.002 w
.36839 .30136 m .33679 .34871 L .35077 .35183 L p
1 g
F P
s
P
p
.002 w
.35077 .35183 m .37913 .3094 L .36839 .30136 L p
1 g
F P
s
P
p
.002 w
.55603 .60442 m .61099 .57556 L .60321 .56397 L p
1 g
F P
s
P
p
.002 w
.60321 .56397 m .55078 .59149 L .55603 .60442 L p
1 g
F P
s
P
p
.002 w
.64434 .52142 m .60321 .56397 L .61099 .57556 L p
1 g
F P
s
P
p
.002 w
.49483 .61461 m .55603 .60442 L .55078 .59149 L p
1 g
F P
s
P
p
.002 w
.55078 .59149 m .4924 .60118 L .49483 .61461 L p
1 g
F P
s
P
p
.002 w
.67709 .40936 m .66477 .35134 L .64995 .3521 L p
1 g
F P
s
P
p
.002 w
.62124 .30481 m .64995 .3521 L .66477 .35134 L p
1 g
F P
s
P
p
.002 w
.31646 .46675 m .34087 .52126 L .3498 .50955 L p
1 g
F P
s
P
p
.002 w
.3498 .50955 m .32725 .45899 L .31646 .46675 L p
1 g
F P
s
P
p
.002 w
.61099 .57556 m .65414 .53098 L .64434 .52142 L p
1 g
F P
s
P
p
.002 w
.66992 .46809 m .64434 .52142 L .65414 .53098 L p
1 g
F P
s
P
p
.002 w
.43358 .60496 m .49483 .61461 L .4924 .60118 L p
1 g
F P
s
P
p
.002 w
.4924 .60118 m .43398 .59192 L .43358 .60496 L p
1 g
F P
s
P
p
.002 w
.52522 .24993 m .46834 .24897 L .46872 .26244 L p
1 g
F P
s
P
p
.002 w
.42 .27841 m .46872 .26244 L .46834 .24897 L p
1 g
F P
s
P
p
.002 w
.41397 .26677 m .36839 .30136 L .37913 .3094 L p
1 g
F P
s
P
p
.002 w
.37913 .3094 m .42 .27841 L .41397 .26677 L p
1 g
F P
s
P
p
.002 w
.46834 .24897 m .41397 .26677 L .42 .27841 L p
1 g
F P
s
P
p
.002 w
.65414 .53098 m .68101 .4751 L .66992 .46809 L p
1 g
F P
s
P
p
.002 w
.67709 .40936 m .66992 .46809 L .68101 .4751 L p
1 g
F P
s
P
p
.002 w
.37862 .5762 m .43358 .60496 L .43398 .59192 L p
1 g
F P
s
P
p
.002 w
.43398 .59192 m .38159 .56442 L .37862 .5762 L p
1 g
F P
s
P
p
.002 w
.66477 .35134 m .63388 .30028 L .62124 .30481 L p
1 g
F P
s
P
p
.002 w
.57814 .26936 m .62124 .30481 L .63388 .30028 L p
1 g
F P
s
P
p
.002 w
.31139 .40668 m .31646 .46675 L .32725 .45899 L p
1 g
F P
s
P
p
.002 w
.32725 .45899 m .32263 .40333 L .31139 .40668 L p
1 g
F P
s
P
p
.002 w
.68101 .4751 m .6886 .41354 L .67709 .40936 L p
1 g
F P
s
P
p
.002 w
.66477 .35134 m .67709 .40936 L .6886 .41354 L p
1 g
F P
s
P
p
.002 w
.33587 .53099 m .37862 .5762 L .38159 .56442 L p
1 g
F P
s
P
p
.002 w
.38159 .56442 m .34087 .52126 L .33587 .53099 L p
1 g
F P
s
P
p
.002 w
.63388 .30028 m .58741 .26195 L .57814 .26936 L p
1 g
F P
s
P
p
.002 w
.52522 .24993 m .57814 .26936 L .58741 .26195 L p
1 g
F P
s
P
p
.002 w
.32663 .34767 m .31139 .40668 L .32263 .40333 L p
1 g
F P
s
P
p
.002 w
.32263 .40333 m .33679 .34871 L .32663 .34767 L p
1 g
F P
s
P
p
.002 w
.58741 .26195 m .53027 .24091 L .52522 .24993 L p
1 g
F P
s
P
p
.002 w
.46834 .24897 m .52522 .24993 L .53027 .24091 L p
1 g
F P
s
P
p
.002 w
.36076 .29647 m .32663 .34767 L .33679 .34871 L p
1 g
F P
s
P
p
.002 w
.33679 .34871 m .36839 .30136 L .36076 .29647 L p
1 g
F P
s
P
p
.002 w
.55999 .61319 m .6161 .58373 L .61099 .57556 L p
1 g
F P
s
P
p
.002 w
.61099 .57556 m .55603 .60442 L .55999 .61319 L p
1 g
F P
s
P
p
.002 w
.65414 .53098 m .61099 .57556 L .6161 .58373 L p
1 g
F P
s
P
p
.002 w
.4975 .62362 m .55999 .61319 L .55603 .60442 L p
1 g
F P
s
P
p
.002 w
.55603 .60442 m .49483 .61461 L .4975 .62362 L p
1 g
F P
s
P
p
.002 w
.6886 .41354 m .67575 .35268 L .66477 .35134 L p
1 g
F P
s
P
p
.002 w
.63388 .30028 m .66477 .35134 L .67575 .35268 L p
1 g
F P
s
P
p
.002 w
.3102 .47385 m .33587 .53099 L .34087 .52126 L p
1 g
F P
s
P
p
.002 w
.34087 .52126 m .31646 .46675 L .3102 .47385 L p
1 g
F P
s
P
p
.002 w
.6161 .58373 m .66018 .53822 L .65414 .53098 L p
1 g
F P
s
P
p
.002 w
.68101 .4751 m .65414 .53098 L .66018 .53822 L p
1 g
F P
s
P
p
.002 w
.43497 .61382 m .4975 .62362 L .49483 .61461 L p
1 g
F P
s
P
p
.002 w
.49483 .61461 m .43358 .60496 L .43497 .61382 L p
1 g
F P
s
P
p
.002 w
.53027 .24091 m .4688 .23984 L .46834 .24897 L p
1 g
F P
s
P
p
.002 w
.41397 .26677 m .46834 .24897 L .4688 .23984 L p
1 g
F P
s
P
p
.002 w
.41003 .25907 m .36076 .29647 L .36839 .30136 L p
1 g
F P
s
P
p
.002 w
.36839 .30136 m .41397 .26677 L .41003 .25907 L p
1 g
F P
s
P
p
.002 w
.4688 .23984 m .41003 .25907 L .41397 .26677 L p
1 g
F P
s
P
p
.002 w
.66018 .53822 m .68765 .48119 L .68101 .4751 L p
1 g
F P
s
P
p
.002 w
.6886 .41354 m .68101 .4751 L .68765 .48119 L p
1 g
F P
s
P
p
.002 w
.37884 .5845 m .43497 .61382 L .43358 .60496 L p
1 g
F P
s
P
p
.002 w
.43358 .60496 m .37862 .5762 L .37884 .5845 L p
1 g
F P
s
P
p
.002 w
.67575 .35268 m .64341 .29909 L .63388 .30028 L p
1 g
F P
s
P
p
.002 w
.58741 .26195 m .63388 .30028 L .64341 .29909 L p
1 g
F P
s
P
p
.002 w
.30483 .41081 m .3102 .47385 L .31646 .46675 L p
1 g
F P
s
P
p
.002 w
.31646 .46675 m .31139 .40668 L .30483 .41081 L p
1 g
F P
s
P
p
.002 w
.68765 .48119 m .69544 .41835 L .6886 .41354 L p
1 g
F P
s
P
p
.002 w
.67575 .35268 m .6886 .41354 L .69544 .41835 L p
1 g
F P
s
P
p
.002 w
.33516 .53838 m .37884 .5845 L .37862 .5762 L p
1 g
F P
s
P
p
.002 w
.37862 .5762 m .33587 .53099 L .33516 .53838 L p
1 g
F P
s
P
p
.002 w
.64341 .29909 m .59469 .25883 L .58741 .26195 L p
1 g
F P
s
P
p
.002 w
.53027 .24091 m .58741 .26195 L .59469 .25883 L p
1 g
F P
s
P
p
.002 w
.3208 .34885 m .30483 .41081 L .31139 .40668 L p
1 g
F P
s
P
p
.002 w
.31139 .40668 m .32663 .34767 L .3208 .34885 L p
1 g
F P
s
P
p
.002 w
.59469 .25883 m .53471 .23671 L .53027 .24091 L p
1 g
F P
s
P
p
.002 w
.4688 .23984 m .53027 .24091 L .53471 .23671 L p
1 g
F P
s
P
p
.002 w
.35663 .29507 m .3208 .34885 L .32663 .34767 L p
1 g
F P
s
P
p
.002 w
.32663 .34767 m .36076 .29647 L .35663 .29507 L p
1 g
F P
s
P
p
.002 w
.69544 .41835 m .68237 .35622 L .67575 .35268 L p
1 g
F P
s
P
p
.002 w
.64341 .29909 m .67575 .35268 L .68237 .35622 L p
1 g
F P
s
P
p
.002 w
.56247 .61732 m .61824 .58804 L .6161 .58373 L p
1 g
F P
s
P
p
.002 w
.6161 .58373 m .55999 .61319 L .56247 .61732 L p
1 g
F P
s
P
p
.002 w
.66018 .53822 m .6161 .58373 L .61824 .58804 L p
1 g
F P
s
P
p
.002 w
.50036 .6277 m .56247 .61732 L .55999 .61319 L p
1 g
F P
s
P
p
.002 w
.55999 .61319 m .4975 .62362 L .50036 .6277 L p
1 g
F P
s
P
p
.002 w
.30893 .48006 m .33516 .53838 L .33587 .53099 L p
1 g
F P
s
P
p
.002 w
.33587 .53099 m .3102 .47385 L .30893 .48006 L p
1 g
F P
s
P
p
.002 w
.61824 .58804 m .66206 .54281 L .66018 .53822 L p
1 g
F P
s
P
p
.002 w
.68765 .48119 m .66018 .53822 L .66206 .54281 L p
1 g
F P
s
P
p
.002 w
.43821 .61797 m .50036 .6277 L .4975 .62362 L p
1 g
F P
s
P
p
.002 w
.4975 .62362 m .43497 .61382 L .43821 .61797 L p
1 g
F P
s
P
p
.002 w
.53471 .23671 m .47015 .23557 L .4688 .23984 L p
1 g
F P
s
P
p
.002 w
.41003 .25907 m .4688 .23984 L .47015 .23557 L p
1 g
F P
s
P
p
.002 w
.4084 .25578 m .35663 .29507 L .36076 .29647 L p
1 g
F P
s
P
p
.002 w
.36076 .29647 m .41003 .25907 L .4084 .25578 L p
1 g
F P
s
P
p
.002 w
.47015 .23557 m .4084 .25578 L .41003 .25907 L p
1 g
F P
s
P
p
.002 w
.66206 .54281 m .68937 .48614 L .68765 .48119 L p
1 g
F P
s
P
p
.002 w
.69544 .41835 m .68765 .48119 L .68937 .48614 L p
1 g
F P
s
P
p
.002 w
.38245 .58886 m .43821 .61797 L .43497 .61382 L p
1 g
F P
s
P
p
.002 w
.43497 .61382 m .37884 .5845 L .38245 .58886 L p
1 g
F P
s
P
p
.002 w
.68237 .35622 m .64938 .3015 L .64341 .29909 L p
1 g
F P
s
P
p
.002 w
.59469 .25883 m .64341 .29909 L .64938 .3015 L p
1 g
F P
s
P
p
.002 w
.30344 .41569 m .30893 .48006 L .3102 .47385 L p
1 g
F P
s
P
p
.002 w
.3102 .47385 m .30483 .41081 L .30344 .41569 L p
1 g
F P
s
P
p
.004 w
.26986 .40863 m
.29491 .41102 L
s
P
p
.004 w
.25765 .40747 m
.26986 .40863 L
s
P
p
.004 w
.25109 .40685 m
.25765 .40747 L
s
P
p
.002 w
.68937 .48614 m .69713 .42372 L .69544 .41835 L p
1 g
F P
s
P
p
.002 w
.68237 .35622 m .69544 .41835 L .69713 .42372 L p
1 g
F P
s
P
p
.002 w
.33907 .54306 m .38245 .58886 L .37884 .5845 L p
1 g
F P
s
P
p
.002 w
.37884 .5845 m .33516 .53838 L .33907 .54306 L p
1 g
F P
s
P
p
.002 w
.64938 .3015 m .59964 .26038 L .59469 .25883 L p
1 g
F P
s
P
p
.002 w
.53471 .23671 m .59469 .25883 L .59964 .26038 L p
1 g
F P
s
P
p
.002 w
.31975 .35239 m .30344 .41569 L .30483 .41081 L p
1 g
F P
s
P
p
.002 w
.30483 .41081 m .3208 .34885 L .31975 .35239 L p
1 g
F P
s
P
p
.002 w
.59964 .26038 m .53837 .23778 L .53471 .23671 L p
1 g
F P
s
P
p
.002 w
.47015 .23557 m .53471 .23671 L .53837 .23778 L p
1 g
F P
s
P
p
.002 w
.69713 .42372 m .68416 .36201 L .68237 .35622 L p
1 g
F P
s
P
p
.002 w
.64938 .3015 m .68237 .35622 L .68416 .36201 L p
1 g
F P
s
P
p
.002 w
.35637 .29743 m .31975 .35239 L .3208 .34885 L p
1 g
F P
s
P
p
.002 w
.3208 .34885 m .35663 .29507 L .35637 .29743 L p
1 g
F P
s
P
p
.002 w
.5633 .61638 m .61715 .5881 L .61824 .58804 L p
1 g
F P
s
P
p
.002 w
.61824 .58804 m .56247 .61732 L .5633 .61638 L p
1 g
F P
s
P
p
.002 w
.66206 .54281 m .61824 .58804 L .61715 .5881 L p
1 g
F P
s
P
p
.002 w
.50334 .6264 m .5633 .61638 L .56247 .61732 L p
1 g
F P
s
P
p
.002 w
.56247 .61732 m .50036 .6277 L .50334 .6264 L p
1 g
F P
s
P
p
.002 w
.31303 .48513 m .33907 .54306 L .33516 .53838 L p
1 g
F P
s
P
p
.002 w
.33516 .53838 m .30893 .48006 L .31303 .48513 L p
1 g
F P
s
P
p
.002 w
.61715 .5881 m .65946 .54444 L .66206 .54281 L p
1 g
F P
s
P
p
.002 w
.68937 .48614 m .66206 .54281 L .65946 .54444 L p
1 g
F P
s
P
p
.002 w
.44336 .617 m .50334 .6264 L .50036 .6277 L p
1 g
F P
s
P
p
.002 w
.50036 .6277 m .43821 .61797 L .44336 .617 L p
1 g
F P
s
P
p
.002 w
.53837 .23778 m .47239 .23662 L .47015 .23557 L p
1 g
F P
s
P
p
.002 w
.4084 .25578 m .47015 .23557 L .47239 .23662 L p
1 g
F P
s
P
p
.002 w
.40928 .25727 m .35637 .29743 L .35663 .29507 L p
1 g
F P
s
P
p
.002 w
.35663 .29507 m .4084 .25578 L .40928 .25727 L p
1 g
F P
s
P
p
.002 w
.47239 .23662 m .40928 .25727 L .4084 .25578 L p
1 g
F P
s
P
p
.002 w
.65946 .54444 m .68581 .48974 L .68937 .48614 L p
1 g
F P
s
P
p
.002 w
.69713 .42372 m .68937 .48614 L .68581 .48974 L p
1 g
F P
s
P
p
.002 w
.68416 .36201 m .65138 .30766 L .64938 .3015 L p
1 g
F P
s
P
p
.002 w
.59964 .26038 m .64938 .3015 L .65138 .30766 L p
1 g
F P
s
P
p
.002 w
.38957 .5889 m .44336 .617 L .43821 .61797 L p
1 g
F P
s
P
p
.002 w
.43821 .61797 m .38245 .58886 L .38957 .5889 L p
1 g
F P
s
P
p
.002 w
.3076 .42119 m .31303 .48513 L .30893 .48006 L p
1 g
F P
s
P
p
.002 w
.30893 .48006 m .30344 .41569 L .3076 .42119 L p
1 g
F P
s
P
p
.002 w
.68581 .48974 m .69328 .42951 L .69713 .42372 L p
1 g
F P
s
P
p
.002 w
.68416 .36201 m .69713 .42372 L .69328 .42951 L p
1 g
F P
s
P
p
.002 w
.34776 .5447 m .38957 .5889 L .38245 .58886 L p
1 g
F P
s
P
p
.002 w
.38245 .58886 m .33907 .54306 L .34776 .5447 L p
1 g
F P
s
P
p
.002 w
.65138 .30766 m .60196 .26684 L .59964 .26038 L p
1 g
F P
s
P
p
.002 w
.53837 .23778 m .59964 .26038 L .60196 .26684 L p
1 g
F P
s
P
p
.002 w
.32384 .35832 m .3076 .42119 L .30344 .41569 L p
1 g
F P
s
P
p
.002 w
.30344 .41569 m .31975 .35239 L .32384 .35832 L p
1 g
F P
s
P
p
.004 w
.29491 .41102 m
.30384 .41186 L
s
P
p
.002 w
.60196 .26684 m .54109 .24443 L .53837 .23778 L p
1 g
F P
s
P
p
.002 w
.47239 .23662 m .53837 .23778 L .54109 .24443 L p
1 g
F P
s
P
p
.002 w
.69328 .42951 m .68073 .37001 L .68416 .36201 L p
1 g
F P
s
P
p
.002 w
.65138 .30766 m .68416 .36201 L .68073 .37001 L p
1 g
F P
s
P
p
.002 w
.36024 .30373 m .32384 .35832 L .31975 .35239 L p
1 g
F P
s
P
p
.002 w
.31975 .35239 m .35637 .29743 L .36024 .30373 L p
1 g
F P
s
P
p
.002 w
.32271 .48884 m .34776 .5447 L .33907 .54306 L p
1 g
F P
s
P
p
.002 w
.33907 .54306 m .31303 .48513 L .32271 .48884 L p
1 g
F P
s
P
p
.002 w
.56234 .61005 m .61265 .58364 L .61715 .5881 L p
1 g
F P
s
P
p
.002 w
.61715 .5881 m .5633 .61638 L .56234 .61005 L p
1 g
F P
s
P
p
.002 w
.65946 .54444 m .61715 .5881 L .61265 .58364 L p
1 g
F P
s
P
p
.002 w
.50635 .6194 m .56234 .61005 L .5633 .61638 L p
1 g
F P
s
P
p
.002 w
.5633 .61638 m .50334 .6264 L .50635 .6194 L p
1 g
F P
s
P
p
.002 w
.61265 .58364 m .65215 .54285 L .65946 .54444 L p
1 g
F P
s
P
p
.002 w
.68581 .48974 m .65946 .54444 L .65215 .54285 L p
1 g
F P
s
P
p
.002 w
.45036 .61059 m .50635 .6194 L .50334 .6264 L p
1 g
F P
s
P
p
.002 w
.50334 .6264 m .44336 .617 L .45036 .61059 L p
1 g
F P
s
P
p
.002 w
.54109 .24443 m .47554 .2433 L .47239 .23662 L p
1 g
F P
s
P
p
.002 w
.40928 .25727 m .47239 .23662 L .47554 .2433 L p
1 g
F P
s
P
p
.002 w
.41282 .26383 m .36024 .30373 L .35637 .29743 L p
1 g
F P
s
P
p
.002 w
.35637 .29743 m .40928 .25727 L .41282 .26383 L p
1 g
F P
s
P
p
.002 w
.47554 .2433 m .41282 .26383 L .40928 .25727 L p
1 g
F P
s
P
p
.002 w
.65215 .54285 m .67672 .49178 L .68581 .48974 L p
1 g
F P
s
P
p
.002 w
.69328 .42951 m .68581 .48974 L .67672 .49178 L p
1 g
F P
s
P
p
.002 w
.68073 .37001 m .64909 .31765 L .65138 .30766 L p
1 g
F P
s
P
p
.002 w
.60196 .26684 m .65138 .30766 L .64909 .31765 L p
1 g
F P
s
P
p
.002 w
.40021 .58433 m .45036 .61059 L .44336 .617 L p
1 g
F P
s
P
p
.002 w
.44336 .617 m .38957 .5889 L .40021 .58433 L p
1 g
F P
s
P
p
.002 w
.31755 .42721 m .32271 .48884 L .31303 .48513 L p
1 g
F P
s
P
p
.002 w
.31303 .48513 m .3076 .42119 L .31755 .42721 L p
1 g
F P
s
P
p
.002 w
.67672 .49178 m .68364 .43559 L .69328 .42951 L p
1 g
F P
s
P
p
.002 w
.68073 .37001 m .69328 .42951 L .68364 .43559 L p
1 g
F P
s
P
p
.002 w
.36129 .54307 m .40021 .58433 L .38957 .5889 L p
1 g
F P
s
P
p
.002 w
.38957 .5889 m .34776 .5447 L .36129 .54307 L p
1 g
F P
s
P
p
.002 w
.64909 .31765 m .60141 .27836 L .60196 .26684 L p
1 g
F P
s
P
p
.002 w
.54109 .24443 m .60196 .26684 L .60141 .27836 L p
1 g
F P
s
P
p
.002 w
.33326 .36663 m .31755 .42721 L .3076 .42119 L p
1 g
F P
s
P
p
.002 w
.3076 .42119 m .32384 .35832 L .33326 .36663 L p
1 g
F P
s
P
p
.004 w
.30384 .41186 m
.31738 .41315 L
s
P
p
.002 w
.68364 .43559 m .67187 .38012 L .68073 .37001 L p
1 g
F P
s
P
p
.002 w
.64909 .31765 m .68073 .37001 L .67187 .38012 L p
1 g
F P
s
P
p
.002 w
.60141 .27836 m .54272 .25681 L .54109 .24443 L p
1 g
F P
s
P
p
.002 w
.47554 .2433 m .54109 .24443 L .54272 .25681 L p
1 g
F P
s
P
p
.002 w
.36838 .31403 m .33326 .36663 L .32384 .35832 L p
1 g
F P
s
P
p
.002 w
.32384 .35832 m .36024 .30373 L .36838 .31403 L p
1 g
F P
s
P
p
.002 w
.33803 .49098 m .36129 .54307 L .34776 .5447 L p
1 g
F P
s
P
p
.002 w
.34776 .5447 m .32271 .48884 L .33803 .49098 L p
1 g
F P
s
P
p
.002 w
.55952 .59819 m .60465 .5745 L .61265 .58364 L p
1 g
F P
s
P
p
.002 w
.61265 .58364 m .56234 .61005 L .55952 .59819 L p
1 g
F P
s
P
p
.002 w
.65215 .54285 m .61265 .58364 L .60465 .5745 L p
1 g
F P
s
P
p
.002 w
.5093 .60654 m .55952 .59819 L .56234 .61005 L p
1 g
F P
s
P
p
.002 w
.56234 .61005 m .50635 .6194 L .5093 .60654 L p
1 g
F P
s
P
p
.002 w
.60465 .5745 m .64006 .5379 L .65215 .54285 L p
1 g
F P
s
P
p
.002 w
.67672 .49178 m .65215 .54285 L .64006 .5379 L p
1 g
F P
s
P
p
.002 w
.45912 .5986 m .5093 .60654 L .50635 .6194 L p
1 g
F P
s
P
p
.002 w
.50635 .6194 m .45036 .61059 L .45912 .5986 L p
1 g
F P
s
P
p
.002 w
.54272 .25681 m .47953 .25577 L .47554 .2433 L p
1 g
F P
s
P
p
.002 w
.41282 .26383 m .47554 .2433 L .47953 .25577 L p
1 g
F P
s
P
p
.002 w
.41908 .27558 m .36838 .31403 L .36024 .30373 L p
1 g
F P
s
P
p
.002 w
.36024 .30373 m .41282 .26383 L .41908 .27558 L p
1 g
F P
s
P
p
.002 w
.47953 .25577 m .41908 .27558 L .41282 .26383 L p
1 g
F P
s
P
p
.002 w
.64006 .5379 m .66204 .49209 L .67672 .49178 L p
1 g
F P
s
P
p
.002 w
.68364 .43559 m .67672 .49178 L .66204 .49209 L p
1 g
F P
s
P
p
.002 w
.67187 .38012 m .6423 .33138 L .64909 .31765 L p
1 g
F P
s
P
p
.002 w
.60141 .27836 m .64909 .31765 L .6423 .33138 L p
1 g
F P
s
P
p
.002 w
.41424 .57501 m .45912 .5986 L .45036 .61059 L p
1 g
F P
s
P
p
.002 w
.45036 .61059 m .40021 .58433 L .41424 .57501 L p
1 g
F P
s
P
p
.002 w
.33332 .43357 m .33803 .49098 L .32271 .48884 L p
1 g
F P
s
P
p
.002 w
.32271 .48884 m .31755 .42721 L .33332 .43357 L p
1 g
F P
s
P
p
.002 w
.66204 .49209 m .66816 .44175 L .68364 .43559 L p
1 g
F P
s
P
p
.002 w
.67187 .38012 m .68364 .43559 L .66816 .44175 L p
1 g
F P
s
P
p
.002 w
.37949 .53802 m .41424 .57501 L .40021 .58433 L p
1 g
F P
s
P
p
.002 w
.40021 .58433 m .36129 .54307 L .37949 .53802 L p
1 g
F P
s
P
p
.002 w
.6423 .33138 m .59783 .29485 L .60141 .27836 L p
1 g
F P
s
P
p
.002 w
.54272 .25681 m .60141 .27836 L .59783 .29485 L p
1 g
F P
s
P
p
.002 w
.34803 .37717 m .33332 .43357 L .31755 .42721 L p
1 g
F P
s
P
p
.002 w
.31755 .42721 m .33326 .36663 L .34803 .37717 L p
1 g
F P
s
P
p
.004 w
.31738 .41315 m
.3244 .41382 L
s
P
p
.002 w
.66816 .44175 m .65753 .39214 L .67187 .38012 L p
1 g
F P
s
P
p
.002 w
.6423 .33138 m .67187 .38012 L .65753 .39214 L p
1 g
F P
s
P
p
.002 w
.59783 .29485 m .54314 .27487 L .54272 .25681 L p
1 g
F P
s
P
p
.002 w
.47953 .25577 m .54272 .25681 L .54314 .27487 L p
1 g
F P
s
P
p
.002 w
.3588 .49139 m .37949 .53802 L .36129 .54307 L p
1 g
F P
s
P
p
.002 w
.36129 .54307 m .33803 .49098 L .3588 .49139 L p
1 g
F P
s
P
p
.002 w
.38079 .32823 m .34803 .37717 L .33326 .36663 L p
1 g
F P
s
P
p
.002 w
.33326 .36663 m .36838 .31403 L .38079 .32823 L p
1 g
F P
s
P
p
.002 w
.55481 .58084 m .5932 .56068 L .60465 .5745 L p
1 g
F P
s
P
p
.002 w
.60465 .5745 m .55952 .59819 L .55481 .58084 L p
1 g
F P
s
P
p
.002 w
.64006 .5379 m .60465 .5745 L .5932 .56068 L p
1 g
F P
s
P
p
.002 w
.51208 .58791 m .55481 .58084 L .55952 .59819 L p
1 g
F P
s
P
p
.002 w
.55952 .59819 m .5093 .60654 L .51208 .58791 L p
1 g
F P
s
P
p
.002 w
.5932 .56068 m .62329 .52953 L .64006 .5379 L p
1 g
F P
s
P
p
.002 w
.66204 .49209 m .64006 .5379 L .62329 .52953 L p
1 g
F P
s
P
p
.002 w
.46945 .5811 m .51208 .58791 L .5093 .60654 L p
1 g
F P
s
P
p
.002 w
.5093 .60654 m .45912 .5986 L .46945 .5811 L p
1 g
F P
s
P
p
.002 w
.54314 .27487 m .4843 .27397 L .47953 .25577 L p
1 g
F P
s
P
p
.002 w
.41908 .27558 m .47953 .25577 L .4843 .27397 L p
1 g
F P
s
P
p
.002 w
.42802 .29244 m .38079 .32823 L .36838 .31403 L p
1 g
F P
s
P
p
.002 w
.36838 .31403 m .41908 .27558 L .42802 .29244 L p
1 g
F P
s
P
p
.002 w
.4843 .27397 m .42802 .29244 L .41908 .27558 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.65753 .39214 m .63099 .34861 L .6423 .33138 L p
1 g
F P
s
P
p
.002 w
.59783 .29485 m .6423 .33138 L .63099 .34861 L p
1 g
F P
s
P
p
.002 w
.62329 .52953 m .64192 .49057 L .66204 .49209 L p
1 g
F P
s
P
p
.002 w
.66816 .44175 m .66204 .49209 L .64192 .49057 L p
1 g
F P
s
P
p
.002 w
.43138 .56098 m .46945 .5811 L .45912 .5986 L p
1 g
F P
s
P
p
.002 w
.45912 .5986 m .41424 .57501 L .43138 .56098 L p
1 g
F P
s
P
p
.002 w
.35471 .44007 m .3588 .49139 L .33803 .49098 L p
1 g
F P
s
P
p
.002 w
.33803 .49098 m .33332 .43357 L .35471 .44007 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.64192 .49057 m .64703 .44781 L .66816 .44175 L p
1 g
F P
s
P
p
.002 w
.65753 .39214 m .66816 .44175 L .64703 .44781 L p
1 g
F P
s
P
p
.002 w
.40198 .52952 m .43138 .56098 L .41424 .57501 L p
1 g
F P
s
P
p
.002 w
.41424 .57501 m .37949 .53802 L .40198 .52952 L p
1 g
F P
s
P
p
.002 w
.63099 .34861 m .59116 .31606 L .59783 .29485 L p
1 g
F P
s
P
p
.002 w
.54314 .27487 m .59783 .29485 L .59116 .31606 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.36795 .38971 m .35471 .44007 L .33332 .43357 L p
1 g
F P
s
P
p
.004 w
.3607 .41727 m
.5 .43051 L
s
P
p
.002 w
.33332 .43357 m .34803 .37717 L .36795 .38971 L p
1 g
F P
s
P
p
.004 w
.34278 .41557 m
.34402 .41568 L
s
P
p
.004 w
.33658 .41498 m
.34278 .41557 L
s
P
p
.004 w
.3244 .41382 m
.33658 .41498 L
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.64703 .44781 m .6379 .40574 L .65753 .39214 L p
1 g
F P
s
P
p
.002 w
.63099 .34861 m .65753 .39214 L .6379 .40574 L p
1 g
F P
s
P
p
.002 w
.59116 .31606 m .54227 .29831 L .54314 .27487 L p
1 g
F P
s
P
p
.002 w
.4843 .27397 m .54314 .27487 L .54227 .29831 L p
1 g
F P
s
P
p
.002 w
.38457 .48995 m .40198 .52952 L .37949 .53802 L p
1 g
F P
s
P
p
.002 w
.37949 .53802 m .3588 .49139 L .38457 .48995 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.39727 .34604 m .36795 .38971 L .34803 .37717 L p
1 g
F P
s
P
p
.002 w
.34803 .37717 m .38079 .32823 L .39727 .34604 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54927 .56326 L p
1 g
F P
s
P
p
.56075 .54566 m .54927 .56326 L .54943 .5631 L 1 g
F
P
p
.55481 .58084 m .53877 .57405 L .54927 .56326 L 1 g
F
P
p
.002 w
.5496 .56292 m .54963 .56304 L p
.54927 .56326 L 1 g
F P
s
P
p
.002 w
.54963 .56304 m .55481 .58084 L p
.54927 .56326 L 1 g
F P
s
P
p
.002 w
.54927 .56326 m .54854 .56129 L p
.54161 .56789 L 1 g
F P
s
P
p
.56075 .54566 m .54943 .5631 L .5549 .55627 L 1 g
F
P
p
.54943 .5631 m .54929 .56331 L .5496 .56292 L 1 g
F
P
p
.54943 .5631 m .5496 .56292 L .5549 .55627 L 1 g
F
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53157 .57397 L p
1 g
F P
s
P
p
.53877 .57405 m .53445 .57223 L .54927 .56326 L 1 g
F
P
p
.54854 .56129 m .53157 .57397 L .54161 .56789 L 1 g
F
P
p
.002 w
.55481 .58084 m .51208 .58791 L .51288 .58026 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51094 .58064 L p
1 g
F P
s
P
p
.51208 .58791 m .50555 .5817 L .51094 .58064 L 1 g
F
P
p
.002 w
.51288 .58026 m .51284 .58068 L p
.51094 .58064 L 1 g
F P
s
P
p
.002 w
.51284 .58068 m .51208 .58791 L p
.51094 .58064 L 1 g
F P
s
P
p
.002 w
.51094 .58064 m .51079 .57862 L p
.50172 .58043 L 1 g
F P
s
P
p
.53128 .57265 m .51094 .58064 L .51224 .58038 L 1 g
F
P
p
.53128 .57265 m .51096 .58091 L .52324 .57677 L 1 g
F
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .4891 .58015 L p
1 g
F P
s
P
p
.51079 .57862 m .4891 .58015 L .50172 .58043 L 1 g
F
P
p
.51094 .58064 m .48106 .5584 L .51288 .58026 L 1 g
F
P
p
.50555 .5817 m .50429 .58049 L .51094 .58064 L 1 g
F
P
p
.50429 .58049 m .48106 .5584 L .51094 .58064 L 1 g
F
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51208 .58791 m .46945 .5811 L .47204 .57603 L p
1 g
F P
s
P
p
.002 w
.4891 .58015 m .48921 .57862 L p
.47945 .57782 L 1 g
F P
s
P
p
.51208 .58791 m .47204 .57603 L .50899 .58496 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46831 .57455 L p
1 g
F P
s
P
p
.46945 .5811 m .4659 .5736 L .46831 .57455 L 1 g
F
P
p
.002 w
.47204 .57603 m .47162 .57685 L p
.46831 .57455 L 1 g
F P
s
P
p
.002 w
.47162 .57685 m .46945 .5811 L p
.46831 .57455 L 1 g
F P
s
P
p
.002 w
.46831 .57455 m .46872 .57265 L p
.46123 .56966 L 1 g
F P
s
P
p
.48921 .57862 m .46831 .57455 L .47583 .57752 L 1 g
F
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45098 .56257 L p
1 g
F P
s
P
p
.46872 .57265 m .45098 .56257 L .46123 .56966 L 1 g
F
P
p
.46831 .57455 m .45117 .54251 L .47204 .57603 L 1 g
F
P
p
.4659 .5736 m .4654 .57254 L .46831 .57455 L 1 g
F
P
p
.4654 .57254 m .45117 .54251 L .46831 .57455 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.46945 .5811 m .46462 .57855 L p
.45117 .54251 L 1 g
F P
s
P
p
.002 w
.46462 .57855 m .43138 .56098 L .44153 .5515 L p
1 g
F P
s
P
p
.002 w
.45098 .56257 m .45146 .56129 L p
.44537 .556 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43852 .54703 L p
1 g
F P
s
P
p
.43138 .56098 m .42933 .53335 L .43852 .54703 L 1 g
F
P
p
.002 w
.44153 .5515 m .44032 .55264 L p
.43852 .54703 L 1 g
F P
s
P
p
.002 w
.44032 .55264 m .43138 .56098 L p
.43852 .54703 L 1 g
F P
s
P
p
.002 w
.43852 .54703 m .43925 .54566 L p
.4361 .53942 L 1 g
F P
s
P
p
.45146 .56129 m .43852 .54703 L .44341 .55429 L 1 g
F
P
p
.42933 .53335 m .42817 .51773 L .43262 .52897 L 1 g
F
P
p
.002 w
.43263 .52855 m .43346 .52734 L p
.43313 .51792 L 1 g
F P
s
P
p
.002 w
.43278 .5227 m .42817 .51773 L .43334 .5151 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.42817 .51773 m .43427 .50657 L .43397 .50931 L 1 g
F
P
p
.002 w
.43334 .5151 m .43048 .51655 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.43048 .51655 m .42817 .51773 L p
.43397 .50931 L 1 g
F P
s
P
p
.002 w
.43397 .50931 m .43485 .50826 L p
.43784 .50126 L 1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43397 .50931 L p
1 g
F P
s
P
p
.002 w
.43397 .50931 m .43287 .51061 L p
.43311 .51723 L 1 g
F P
s
P
p
.43346 .52734 m .43397 .50931 L .43311 .51723 L 1 g
F
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44264 .4913 L p
1 g
F P
s
P
p
.43427 .50657 m .44258 .49135 L .43397 .50931 L 1 g
F
P
p
.44258 .49135 m .44285 .49087 L .44264 .4913 L 1 g
F
P
p
.44258 .49135 m .44264 .4913 L .43397 .50931 L 1 g
F
P
p
.002 w
.42817 .51773 m .41462 .48664 L .44796 .48151 L p
1 g
F P
s
P
p
.002 w
.44264 .4913 m .44166 .49233 L p
.43784 .50126 L 1 g
F P
s
P
p
.43485 .50826 m .44264 .4913 L .43784 .50126 L 1 g
F
P
p
.002 w
.44264 .4913 m .44339 .4905 L p
.45144 .48278 L 1 g
F P
s
P
p
.002 w
.45393 .48036 m .48339 .47471 L p
.44938 .48479 L 1 g
F P
s
P
p
.45144 .48278 m .45324 .48106 L .44938 .48479 L 1 g
F
P
p
.45144 .48278 m .44938 .48479 L .44264 .4913 L 1 g
F
P
p
.002 w
.4572 .50295 m .44938 .48479 L p
.48339 .47471 L 1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43397 .50931 m .44341 .49056 L .43334 .5151 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45765 .47674 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.48339 .47471 m .45393 .48036 L p
.46759 .47199 L 1 g
F P
s
P
p
.46759 .47199 m .47751 .46724 L .48339 .47471 L 1 g
F
P
p
.002 w
.47751 .46724 m .47786 .46667 L p
.49021 .46541 L 1 g
F P
s
P
p
.002 w
.49748 .46428 m .51179 .46571 L p
.48286 .46656 L 1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54941 .48582 m .54105 .49453 L .5199 .46696 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .46729 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54236 .47676 L p
1 g
F P
s
P
p
.52214 .46667 m .54236 .47676 L .533 .47229 L 1 g
F
P
p
.52345 .46774 m .52035 .46702 L .52252 .46729 L 1 g
F
P
p
.002 w
.54941 .48582 m .52035 .46702 L p
.52345 .46774 L 1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.54236 .47676 m .54941 .48582 L .52345 .46774 L 1 g
F
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56613 .50943 L p
1 g
F P
s
P
p
.002 w
.57729 .50314 m .56784 .51297 L p
.56613 .50943 L 1 g
F P
s
P
p
.56517 .50026 m .56613 .50943 L .56128 .49934 L 1 g
F
P
p
.57729 .50314 m .56613 .50943 L .56517 .50026 L 1 g
F
P
p
.002 w
.56613 .50943 m .56515 .50826 L p
.56699 .5202 L 1 g
F P
s
P
p
.60218 .51786 m .56748 .52844 L .56697 .51981 L 1 g
F
P
p
.56699 .5202 m .56664 .51421 L .56613 .50943 L 1 g
F
P
p
.002 w
.57729 .50314 m .60218 .51786 L p
.56697 .51981 L 1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.60218 .51786 m .5785 .54241 L .56748 .52844 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56749 .52872 L p
1 g
F P
s
P
p
.5785 .54241 m .56785 .53929 L .56749 .52872 L 1 g
F
P
p
.002 w
.56748 .52844 m .56755 .52853 L p
.56749 .52872 L 1 g
F P
s
P
p
.002 w
.56755 .52853 m .5785 .54241 L p
.56749 .52872 L 1 g
F P
s
P
p
.002 w
.56749 .52872 m .56654 .52734 L p
.56472 .53728 L 1 g
F P
s
P
p
.56515 .50826 m .56749 .52872 L .56726 .52193 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56154 .54714 L p
1 g
F P
s
P
p
.56654 .52734 m .56154 .54714 L .56472 .53728 L 1 g
F
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.56749 .52872 m .54002 .53112 L .56748 .52844 L 1 g
F
P
p
.56785 .53929 m .5644 .53828 L .56749 .52872 L 1 g
F
P
p
.5644 .53828 m .54002 .53112 L .56749 .52872 L 1 g
F
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54826 .55829 m .54002 .53112 L p
.56718 .53909 L 1 g
F P
s
P
p
.002 w
.5785 .54241 m .55691 .55375 L p
.56718 .53909 L 1 g
F P
s
P
p
.002 w
.55691 .55375 m .5785 .54241 L p
.55308 .55855 L 1 g
F P
s
P
p
.002 w
.56154 .54714 m .56075 .54566 L p
.55401 .55789 L 1 g
F P
s
P
p
.002 w
.55691 .55375 m .54826 .55829 L p
.56718 .53909 L 1 g
F P
s
P
p
.002 w
.5785 .54241 m .5932 .56068 L p
.55308 .55855 L 1 g
F P
s
P
p
.002 w
.5932 .56068 m .55481 .58084 L .5496 .56292 L p
1 g
F P
s
P
p
.002 w
.5496 .56292 m .54826 .55829 L p
.55308 .55855 L 1 g
F P
s
P
p
.5932 .56068 m .5496 .56292 L .55308 .55855 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56179 .54762 L p
1 g
F P
s
P
p
.002 w
.56179 .54762 m .56154 .54714 L p
.55894 .5512 L 1 g
F P
s
P
p
.55894 .5512 m .54998 .56518 L .56179 .54762 L 1 g
F
P
p
.55401 .55789 m .54998 .56518 L .56154 .54714 L 1 g
F
P
p
.002 w
.56154 .54714 m .56257 .5491 L p
.56472 .53728 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56749 .52872 L p
1 g
F P
s
P
p
.56472 .53728 m .56257 .5491 L .56749 .52872 L 1 g
F
P
p
.002 w
.56749 .52872 m .56854 .53025 L p
.56726 .52193 L 1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.54002 .53112 m .56094 .52014 L .56748 .52844 L p
1 g
F P
s
P
p
.002 w
.56094 .52014 m .56664 .51421 L p
.56697 .51981 L 1 g
F P
s
P
p
.002 w
.56664 .51421 m .57729 .50314 L p
.56697 .51981 L 1 g
F P
s
P
p
.55661 .4905 m .56613 .50943 L .56181 .50044 L 1 g
F
P
p
.002 w
.55745 .49139 m .55661 .4905 L p
.56181 .50044 L 1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55745 .49139 L p
1 g
F P
s
P
p
.56711 .50073 m .56128 .49934 L .55745 .49139 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55745 .49139 L p
1 g
F P
s
P
p
.56181 .50044 m .56713 .51061 L .55745 .49139 L 1 g
F
P
p
.54174 .47608 m .55745 .49139 L .55578 .48978 L 1 g
F
P
p
.002 w
.55578 .48978 m .54941 .48582 L p
.55147 .48561 L 1 g
F P
s
P
p
.55343 .4875 m .55578 .48978 L .55356 .48764 L 1 g
F
P
p
.54174 .47608 m .55578 .48978 L .55343 .4875 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.58734 .48192 m .57729 .50314 L .55578 .48978 L p
1 g
F P
s
P
p
.002 w
.54105 .49453 m .54941 .48582 L .55578 .48978 L p
1 g
F P
s
P
p
.002 w
.55578 .48978 m .55705 .49057 L p
.55669 .49066 L 1 g
F P
s
P
p
.55669 .49066 m .54105 .49453 L .55578 .48978 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.56128 .49934 m .54105 .49453 L .55669 .49066 L 1 g
F
P
p
.55745 .49139 m .55669 .49066 L .55705 .49057 L 1 g
F
P
p
.56128 .49934 m .55669 .49066 L .55745 .49139 L 1 g
F
P
p
.002 w
.55012 .48431 m .54941 .48582 L p
.54236 .47676 L 1 g
F P
s
P
p
.54174 .47608 m .55184 .48597 L .55012 .48431 L 1 g
F
P
p
.002 w
.54275 .47718 m .54236 .47676 L p
.55012 .48431 L 1 g
F P
s
P
p
.002 w
.54236 .47676 m .54174 .47608 L p
.55012 .48431 L 1 g
F P
s
P
p
.54174 .47608 m .55356 .48764 L .55204 .48616 L 1 g
F
P
p
.002 w
.55453 .47495 m .5516 .48116 L p
.54236 .47676 L 1 g
F P
s
P
p
.002 w
.52252 .46729 m .52214 .46667 L p
.533 .47229 L 1 g
F P
s
P
p
.53611 .47068 m .54236 .47676 L .52345 .46774 L 1 g
F
P
p
.55453 .47495 m .54236 .47676 L .53611 .47068 L 1 g
F
P
p
.002 w
.55453 .47495 m .58734 .48192 L p
.55147 .48561 L 1 g
F P
s
P
p
.002 w
.54941 .48582 m .55012 .48431 L p
.55147 .48561 L 1 g
F P
s
P
p
.002 w
.55012 .48431 m .55453 .47495 L p
.55147 .48561 L 1 g
F P
s
P
p
.002 w
.54282 .47726 m .54275 .47718 L p
.55204 .48616 L 1 g
F P
s
P
p
.55184 .48597 m .55204 .48616 L .54275 .47718 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54282 .47726 L p
1 g
F P
s
P
p
.55204 .48616 m .55834 .49233 L .54282 .47726 L 1 g
F
P
p
.55204 .48616 m .55799 .49197 L .55356 .48766 L 1 g
F
P
p
.55356 .48764 m .55799 .49197 L .55204 .48616 L 1 g
F
P
p
.58734 .48192 m .55578 .48978 L .55147 .48561 L 1 g
F
P
p
.002 w
.55745 .49139 m .55799 .49197 L p
.55356 .48764 L 1 g
F P
s
P
p
.002 w
.55705 .49057 m .57729 .50314 L p
.56711 .50073 L 1 g
F P
s
P
p
.56711 .50073 m .55745 .49139 L .55705 .49057 L 1 g
F
P
p
.56613 .50943 m .56094 .52014 L .56128 .49934 L 1 g
F
P
p
.002 w
.56784 .51297 m .56664 .51421 L p
.56613 .50943 L 1 g
F P
s
P
p
.002 w
.56664 .51421 m .56094 .52014 L p
.56613 .50943 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56713 .51061 L .56637 .50971 L p
1 g
F P
s
P
p
.002 w
.56637 .50971 m .56613 .50943 L p
.56659 .51334 L 1 g
F P
s
P
p
.56659 .51334 m .56854 .53025 L .56637 .50971 L 1 g
F
P
p
.56699 .5202 m .56786 .52585 L .56664 .51421 L 1 g
F
P
p
.002 w
.56748 .52844 m .56094 .52014 L p
.56697 .51981 L 1 g
F P
s
P
p
.56786 .52585 m .56854 .53025 L .56613 .50943 L 1 g
F
P
p
.002 w
.56613 .50943 m .56713 .51061 L p
.56181 .50044 L 1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56094 .52014 m .54105 .49453 L p
.56128 .49934 L 1 g
F P
s
P
p
.002 w
.5516 .48116 m .55012 .48431 L p
.54236 .47676 L 1 g
F P
s
P
p
.002 w
.55799 .49197 m .55834 .49233 L p
.55356 .48766 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52252 .46729 L p
1 g
F P
s
P
p
.533 .47229 m .54302 .47747 L .52252 .46729 L 1 g
F
P
p
.002 w
.52322 .46738 m .55453 .47495 L p
.52345 .46774 L 1 g
F P
s
P
p
.52345 .46774 m .52252 .46729 L .52322 .46738 L 1 g
F
P
p
.002 w
.54236 .47676 m .54302 .47747 L p
.533 .47229 L 1 g
F P
s
P
p
.002 w
.52252 .46729 m .52252 .4673 L p
.52242 .46728 L 1 g
F P
s
P
p
.5 .4634 m .52252 .46729 L .52242 .46728 L 1 g
F
P
p
.5 .4634 m .52252 .4673 L .52232 .46727 L 1 g
F
P
p
.5 .4634 m .52252 .46731 L .52088 .46709 L 1 g
F
P
p
.002 w
.52035 .46702 m .54941 .48582 L p
.5199 .46696 L 1 g
F P
s
P
p
.002 w
.54105 .49453 m .53034 .50016 L .51968 .46693 L p
1 g
F P
s
P
p
.002 w
.5199 .46696 m .54105 .49453 L p
.51968 .46693 L 1 g
F P
s
P
p
.5 .4634 m .52101 .46711 L .51305 .46591 L 1 g
F
P
p
.002 w
.53034 .50016 m .51842 .50209 L .51953 .46691 L p
1 g
F P
s
P
p
.002 w
.51968 .46693 m .53034 .50016 L p
.51953 .46691 L 1 g
F P
s
P
p
.002 w
.51842 .50209 m .50657 .50011 L .51939 .46689 L p
1 g
F P
s
P
p
.002 w
.51939 .46689 m .51954 .46649 L .51953 .46691 L p
1 g
F P
s
P
p
.002 w
.51953 .46691 m .51842 .50209 L p
.51939 .46689 L 1 g
F P
s
P
p
.002 w
.50657 .50011 m .49607 .49444 L .51923 .46687 L p
1 g
F P
s
P
p
.002 w
.51923 .46687 m .51954 .46649 L .51939 .46689 L p
1 g
F P
s
P
p
.002 w
.51939 .46689 m .50657 .50011 L p
.51923 .46687 L 1 g
F P
s
P
p
.51946 .4669 m .52257 .46739 L .51923 .46687 L 1 g
F
P
p
.51953 .46691 m .51959 .46692 L .51946 .4669 L 1 g
F
P
p
.51959 .46692 m .52257 .46739 L .51946 .4669 L 1 g
F
P
p
.52101 .46711 m .52121 .46715 L .51953 .46691 L 1 g
F
P
p
.52121 .46715 m .52257 .46739 L .51953 .46691 L 1 g
F
P
p
.002 w
.49607 .49444 m .48805 .48566 L .51898 .46683 L p
1 g
F P
s
P
p
.002 w
.51898 .46683 m .51954 .46649 L .51923 .46687 L p
1 g
F P
s
P
p
.002 w
.51923 .46687 m .49607 .49444 L p
.51898 .46683 L 1 g
F P
s
P
p
.52101 .46711 m .51939 .46689 L .51305 .46591 L 1 g
F
P
p
.002 w
.48805 .48566 m .48339 .47471 L .51843 .46674 L p
1 g
F P
s
P
p
.002 w
.51843 .46674 m .51954 .46649 L .51898 .46683 L p
1 g
F P
s
P
p
.002 w
.51898 .46683 m .48805 .48566 L p
.51843 .46674 L 1 g
F P
s
P
p
.51898 .46683 m .51923 .46687 L .51878 .4668 L 1 g
F
P
p
.51939 .46689 m .51931 .46688 L .51898 .46683 L 1 g
F
P
p
.51931 .46688 m .51923 .46687 L .51898 .46683 L 1 g
F
P
p
.51939 .46689 m .51878 .4668 L .51305 .46591 L 1 g
F
P
p
.002 w
.51953 .46691 m .51954 .46649 L .51968 .46693 L p
1 g
F P
s
P
p
.002 w
.52035 .46702 m .51954 .46649 L .52322 .46738 L p
1 g
F P
s
P
p
.002 w
.5199 .46696 m .51954 .46649 L .52035 .46702 L p
1 g
F P
s
P
p
.002 w
.52252 .4673 m .52252 .46731 L p
.52232 .46727 L 1 g
F P
s
P
p
.002 w
.52252 .46731 m .52257 .46739 L p
.52088 .46709 L 1 g
F P
s
P
p
.002 w
.51968 .46693 m .51954 .46649 L .5199 .46696 L p
1 g
F P
s
P
p
.48286 .46656 m .51179 .46571 L .51684 .4665 L 1 g
F
P
p
.002 w
.48339 .47471 m .48286 .46656 L p
.51684 .4665 L 1 g
F P
s
P
p
.002 w
.51843 .46674 m .48339 .47471 L p
.51684 .4665 L 1 g
F P
s
P
p
.5 .4634 m .51305 .46591 L .51179 .46571 L 1 g
F
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.48581 .45116 m .51954 .46649 L .51179 .46571 L p
1 g
F P
s
P
p
.002 w
.51179 .46571 m .49748 .46428 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.48286 .46656 m .48339 .47471 L p
.47751 .46724 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47739 .46744 L p
1 g
F P
s
P
p
.002 w
.47739 .46744 m .47751 .46724 L p
.48316 .46653 L 1 g
F P
s
P
p
.48316 .46653 m .5 .46442 L .47739 .46744 L 1 g
F
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49037 .4654 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46388 L .49037 .4654 L 1 g
F
P
p
.002 w
.48303 .46124 m .48581 .45116 L p
.50664 .46283 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51179 .46571 L 1 g
F P
s
P
p
.5 .46388 m .50664 .46283 L .51179 .46571 L 1 g
F
P
p
.48303 .46124 m .50664 .46283 L .5 .46388 L 1 g
F
P
p
.002 w
.48261 .46278 m .48303 .46124 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.49748 .46428 m .48261 .46278 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46388 L p
.51179 .46571 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.51305 .46591 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.002 w
.51954 .46649 m .51843 .46674 L p
.51684 .4665 L 1 g
F P
s
P
p
.002 w
.51179 .46571 m .51954 .46649 L p
.51684 .4665 L 1 g
F P
s
P
p
.002 w
.52257 .46739 m .52282 .46778 L p
.51305 .46591 L 1 g
F P
s
P
p
.49021 .46541 m .49865 .46455 L .48286 .46656 L 1 g
F
P
p
.49021 .46541 m .48286 .46656 L .47751 .46724 L 1 g
F
P
p
.002 w
.48286 .46656 m .48261 .46278 L .49748 .46428 L p
1 g
F P
s
P
p
.002 w
.48274 .46475 m .48286 .46656 L p
.47751 .46724 L 1 g
F P
s
P
p
.49865 .46455 m .5 .46442 L .47751 .46724 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47751 .46724 L p
1 g
F P
s
P
p
.002 w
.47751 .46724 m .47718 .46778 L p
.46762 .47198 L 1 g
F P
s
P
p
.45826 .47608 m .47751 .46724 L .46762 .47198 L 1 g
F
P
p
.44339 .4905 m .45765 .47674 L .45303 .48124 L 1 g
F
P
p
.002 w
.45393 .48036 m .44796 .48151 L p
.4501 .48035 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.4501 .48035 m .45874 .47568 L .45765 .47674 L 1 g
F
P
p
.4501 .48035 m .45765 .47674 L .45393 .48036 L 1 g
F
P
p
.002 w
.48261 .46278 m .48274 .46475 L p
.46759 .47199 L 1 g
F P
s
P
p
.002 w
.45765 .47674 m .45826 .47608 L p
.46762 .47198 L 1 g
F P
s
P
p
.45874 .47568 m .48261 .46278 L .45393 .48036 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45765 .47674 L p
1 g
F P
s
P
p
.46762 .47198 m .47718 .46778 L .45765 .47674 L 1 g
F
P
p
.002 w
.45765 .47674 m .4572 .47724 L p
.45303 .48124 L 1 g
F P
s
P
p
.44339 .4905 m .4572 .47724 L .45324 .48106 L 1 g
F
P
p
.44341 .49056 m .44796 .48151 L .44447 .48953 L 1 g
F
P
p
.44341 .49056 m .44447 .48953 L .43334 .5151 L 1 g
F
P
p
.002 w
.4572 .47724 m .45698 .47747 L p
.45324 .48106 L 1 g
F P
s
P
p
.002 w
.44938 .48479 m .44796 .48151 L .45393 .48036 L p
1 g
F P
s
P
p
.44285 .49087 m .44796 .48151 L .43397 .50931 L 1 g
F
P
p
.002 w
.44796 .48151 m .4572 .50295 L .43334 .5151 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44264 .4913 L p
1 g
F P
s
P
p
.45324 .48106 m .45698 .47747 L .44264 .4913 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43397 .50931 L p
1 g
F P
s
P
p
.43784 .50126 m .44166 .49233 L .43397 .50931 L 1 g
F
P
p
.43313 .51792 m .43311 .51723 L .43278 .5227 L 1 g
F
P
p
.43311 .51723 m .433 .51427 L .43287 .51944 L 1 g
F
P
p
.43311 .51723 m .43287 .51944 L .43278 .5227 L 1 g
F
P
p
.43313 .51792 m .43278 .5227 L .43263 .52855 L 1 g
F
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.45117 .54251 m .43278 .5227 L p
.4572 .50295 L 1 g
F P
s
P
p
.002 w
.43334 .5151 m .4572 .50295 L p
.43278 .5227 L 1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43263 .52855 L p
1 g
F P
s
P
p
.43925 .54566 m .43263 .52855 L .4361 .53942 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.42817 .51773 m .45117 .54251 L .44153 .5515 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43263 .52855 L p
1 g
F P
s
P
p
.433 .51427 m .43287 .51061 L .43263 .52855 L 1 g
F
P
p
.43255 .53134 m .43262 .52897 L .43336 .53084 L 1 g
F
P
p
.42933 .53335 m .43262 .52897 L .43255 .53134 L 1 g
F
P
p
.43852 .54703 m .43336 .53084 L .44153 .5515 L 1 g
F
P
p
.42933 .53335 m .43336 .53084 L .43852 .54703 L 1 g
F
P
p
.002 w
.43263 .52855 m .43146 .53025 L p
.4361 .53942 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43852 .54703 L p
1 g
F P
s
P
p
.4361 .53942 m .43146 .53025 L .43852 .54703 L 1 g
F
P
p
.002 w
.43852 .54703 m .43743 .5491 L p
.44341 .55429 L 1 g
F P
s
P
p
.002 w
.44153 .5515 m .45117 .54251 L p
.46462 .57855 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45098 .56257 L p
1 g
F P
s
P
p
.44537 .556 m .43743 .5491 L .45098 .56257 L 1 g
F
P
p
.002 w
.45098 .56257 m .45002 .56518 L p
.46123 .56966 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46831 .57455 L p
1 g
F P
s
P
p
.46123 .56966 m .45002 .56518 L .46831 .57455 L 1 g
F
P
p
.002 w
.46831 .57455 m .4678 .57686 L p
.47583 .57752 L 1 g
F P
s
P
p
.002 w
.45117 .54251 m .48106 .5584 L .47204 .57603 L p
1 g
F P
s
P
p
.002 w
.47204 .57603 m .48106 .5584 L p
.50899 .58496 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .4891 .58015 L p
1 g
F P
s
P
p
.47945 .57782 m .4678 .57686 L .4891 .58015 L 1 g
F
P
p
.002 w
.4891 .58015 m .48889 .583 L p
.50172 .58043 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .51111 .583 L .51094 .58064 L p
1 g
F P
s
P
p
.50172 .58043 m .48889 .583 L .51094 .58064 L 1 g
F
P
p
.002 w
.51094 .58064 m .51096 .58091 L p
.51224 .58038 L 1 g
F P
s
P
p
.002 w
.48106 .5584 m .5146 .56383 L .51288 .58026 L p
1 g
F P
s
P
p
.55481 .58084 m .51288 .58026 L .53547 .57266 L 1 g
F
P
p
.002 w
.51111 .583 m .5322 .57686 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51288 .58026 m .5146 .56383 L p
.53547 .57266 L 1 g
F P
s
P
p
.002 w
.51096 .58091 m .51111 .583 L p
.52324 .57677 L 1 g
F P
s
P
p
.002 w
.53157 .57397 m .5322 .57686 L p
.54161 .56789 L 1 g
F P
s
P
p
.54927 .56326 m .5146 .56383 L .5496 .56292 L 1 g
F
P
p
.53445 .57223 m .5146 .56383 L .54927 .56326 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54927 .56326 L p
1 g
F P
s
P
p
.54161 .56789 m .5322 .57686 L .54927 .56326 L 1 g
F
P
p
.002 w
.5146 .56383 m .54826 .55829 L .5496 .56292 L p
1 g
F P
s
P
p
.002 w
.54927 .56326 m .54929 .56331 L p
.54943 .5631 L 1 g
F P
s
P
p
.002 w
.54929 .56331 m .54998 .56518 L p
.5549 .55627 L 1 g
F P
s
P
p
.002 w
.54826 .55829 m .55691 .55375 L p
.55308 .55855 L 1 g
F P
s
P
p
.002 w
.62329 .52953 m .5932 .56068 L .5785 .54241 L p
1 g
F P
s
P
p
.002 w
.5785 .54241 m .60218 .51786 L .62329 .52953 L p
1 g
F P
s
P
p
.002 w
.64192 .49057 m .62329 .52953 L .60218 .51786 L p
1 g
F P
s
P
p
.002 w
.54227 .29831 m .48971 .29757 L .4843 .27397 L p
1 g
F P
s
P
p
.002 w
.42802 .29244 m .4843 .27397 L .48971 .29757 L p
1 g
F P
s
P
p
.002 w
.43946 .31409 m .39727 .34604 L .38079 .32823 L p
1 g
F P
s
P
p
.002 w
.38079 .32823 m .42802 .29244 L .43946 .31409 L p
1 g
F P
s
P
p
.002 w
.48971 .29757 m .43946 .31409 L .42802 .29244 L p
1 g
F P
s
P
p
.002 w
.6379 .40574 m .61529 .36892 L .63099 .34861 L p
1 g
F P
s
P
p
.002 w
.59116 .31606 m .63099 .34861 L .61529 .36892 L p
1 g
F P
s
P
p
.002 w
.60218 .51786 m .61679 .48717 L .64192 .49057 L p
1 g
F P
s
P
p
.002 w
.64703 .44781 m .64192 .49057 L .61679 .48717 L p
1 g
F P
s
P
p
.002 w
.38123 .44648 m .38457 .48995 L .3588 .49139 L p
1 g
F P
s
P
p
.002 w
.3588 .49139 m .35471 .44007 L .38123 .44648 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.61679 .48717 m .62072 .45354 L .64703 .44781 L p
1 g
F P
s
P
p
.002 w
.6379 .40574 m .64703 .44781 L .62072 .45354 L p
1 g
F P
s
P
p
.002 w
.43138 .56098 m .40198 .52952 L .42817 .51773 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.61529 .36892 m .58148 .34145 L .59116 .31606 L p
1 g
F P
s
P
p
.002 w
.54227 .29831 m .59116 .31606 L .58148 .34145 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.39255 .40389 m .38123 .44648 L .35471 .44007 L p
1 g
F P
s
P
p
.002 w
.35471 .44007 m .36795 .38971 L .39255 .40389 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.62072 .45354 m .61344 .42052 L .6379 .40574 L p
1 g
F P
s
P
p
.002 w
.61529 .36892 m .6379 .40574 L .61344 .42052 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.41462 .48664 m .42817 .51773 L .40198 .52952 L p
1 g
F P
s
P
p
.002 w
.40198 .52952 m .38457 .48995 L .41462 .48664 L p
1 g
F P
s
P
p
.002 w
.58148 .34145 m .54006 .32653 L .54227 .29831 L p
1 g
F P
s
P
p
.002 w
.48971 .29757 m .54227 .29831 L .54006 .32653 L p
1 g
F P
s
P
p
.002 w
.41741 .36698 m .39255 .40389 L .36795 .38971 L p
1 g
F P
s
P
p
.002 w
.36795 .38971 m .39727 .34604 L .41741 .36698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51675 .53492 m .54002 .53112 L .54826 .55829 L p
1 g
F P
s
P
p
.002 w
.54826 .55829 m .5146 .56383 L .51675 .53492 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.61679 .48717 m .60218 .51786 L .57729 .50314 L p
1 g
F P
s
P
p
.002 w
.49358 .53112 m .51675 .53492 L .5146 .56383 L p
1 g
F P
s
P
p
.002 w
.5146 .56383 m .48106 .5584 L .49358 .53112 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.54006 .32653 m .4956 .32598 L .48971 .29757 L p
1 g
F P
s
P
p
.002 w
.43946 .31409 m .48971 .29757 L .4956 .32598 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.4531 .33999 m .41741 .36698 L .39727 .34604 L p
1 g
F P
s
P
p
.002 w
.39727 .34604 m .43946 .31409 L .4531 .33999 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.4956 .32598 m .4531 .33999 L .43946 .31409 L p
1 g
F P
s
P
p
.002 w
.61344 .42052 m .5956 .39169 L .61529 .36892 L p
1 g
F P
s
P
p
.002 w
.58148 .34145 m .61529 .36892 L .5956 .39169 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.41212 .45257 m .41462 .48664 L .38457 .48995 L p
1 g
F P
s
P
p
.002 w
.38457 .48995 m .38123 .44648 L .41212 .45257 L p
1 g
F P
s
P
p
.002 w
.57729 .50314 m .58734 .48192 L .61679 .48717 L p
1 g
F P
s
P
p
.002 w
.62072 .45354 m .61679 .48717 L .58734 .48192 L p
1 g
F P
s
P
p
.002 w
.47299 .52008 m .49358 .53112 L .48106 .5584 L p
1 g
F P
s
P
p
.002 w
.48106 .5584 m .45117 .54251 L .47299 .52008 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.58734 .48192 m .58998 .4587 L .62072 .45354 L p
1 g
F P
s
P
p
.002 w
.61344 .42052 m .62072 .45354 L .58998 .4587 L p
1 g
F P
s
P
p
.002 w
.4572 .50295 m .47299 .52008 L .45117 .54251 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.5956 .39169 m .56903 .37026 L .58148 .34145 L p
1 g
F P
s
P
p
.002 w
.54006 .32653 m .58148 .34145 L .56903 .37026 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.42107 .41924 m .41212 .45257 L .38123 .44648 L p
1 g
F P
s
P
p
.002 w
.38123 .44648 m .39255 .40389 L .42107 .41924 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.58998 .4587 m .58487 .43596 L .61344 .42052 L p
1 g
F P
s
P
p
.002 w
.5956 .39169 m .61344 .42052 L .58487 .43596 L p
1 g
F P
s
P
p
.002 w
.56903 .37026 m .53656 .35867 L .54006 .32653 L p
1 g
F P
s
P
p
.002 w
.4956 .32598 m .54006 .32653 L .53656 .35867 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.44059 .39039 m .42107 .41924 L .39255 .40389 L p
1 g
F P
s
P
p
.002 w
.39255 .40389 m .41741 .36698 L .44059 .39039 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.53034 .50016 m .54105 .49453 L .56094 .52014 L p
1 g
F P
s
P
p
.002 w
.56094 .52014 m .54002 .53112 L .53034 .50016 L p
1 g
F P
s
P
p
.002 w
.51842 .50209 m .53034 .50016 L .54002 .53112 L p
1 g
F P
s
P
p
.002 w
.54002 .53112 m .51675 .53492 L .51842 .50209 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.50657 .50011 m .51842 .50209 L .51675 .53492 L p
1 g
F P
s
P
p
.002 w
.51675 .53492 m .49358 .53112 L .50657 .50011 L p
1 g
F P
s
P
p
.002 w
.53656 .35867 m .50176 .35831 L .4956 .32598 L p
1 g
F P
s
P
p
.002 w
.4531 .33999 m .4956 .32598 L .50176 .35831 L p
1 g
F P
s
P
p
.002 w
.46852 .36929 m .44059 .39039 L .41741 .36698 L p
1 g
F P
s
P
p
.002 w
.41741 .36698 m .4531 .33999 L .46852 .36929 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.58487 .43596 m .57252 .41616 L .5956 .39169 L p
1 g
F P
s
P
p
.002 w
.56903 .37026 m .5956 .39169 L .57252 .41616 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.44633 .45808 m .44796 .48151 L .41462 .48664 L p
1 g
F P
s
P
p
.002 w
.41462 .48664 m .41212 .45257 L .44633 .45808 L p
1 g
F P
s
P
p
.002 w
.50176 .35831 m .46852 .36929 L .4531 .33999 L p
1 g
F P
s
P
p
.002 w
.58998 .4587 m .58734 .48192 L .55453 .47495 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.49607 .49444 m .50657 .50011 L .49358 .53112 L p
1 g
F P
s
P
p
.002 w
.49358 .53112 m .47299 .52008 L .49607 .49444 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.55453 .47495 m .55583 .46308 L .58998 .4587 L p
1 g
F P
s
P
p
.002 w
.58487 .43596 m .58998 .4587 L .55583 .46308 L p
1 g
F P
s
P
p
.002 w
.48805 .48566 m .49607 .49444 L .47299 .52008 L p
1 g
F P
s
P
p
.002 w
.47299 .52008 m .4572 .50295 L .48805 .48566 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57252 .41616 m .55419 .4015 L .56903 .37026 L p
1 g
F P
s
P
p
.002 w
.53656 .35867 m .56903 .37026 L .55419 .4015 L p
1 g
F P
s
P
p
.002 w
.45256 .4352 m .44633 .45808 L .41212 .45257 L p
1 g
F P
s
P
p
.002 w
.41212 .45257 m .42107 .41924 L .45256 .4352 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.55583 .46308 m .55318 .45148 L .58487 .43596 L p
1 g
F P
s
P
p
.002 w
.57252 .41616 m .58487 .43596 L .55318 .45148 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.48339 .47471 m .48805 .48566 L .4572 .50295 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.55419 .4015 m .53186 .39361 L .53656 .35867 L p
1 g
F P
s
P
p
.002 w
.50176 .35831 m .53656 .35867 L .53186 .39361 L p
1 g
F P
s
P
p
.002 w
.46599 .41543 m .45256 .4352 L .42107 .41924 L p
1 g
F P
s
P
p
.002 w
.42107 .41924 m .44059 .39039 L .46599 .41543 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.55318 .45148 m .54684 .44142 L .57252 .41616 L p
1 g
F P
s
P
p
.002 w
.55419 .4015 m .57252 .41616 L .54684 .44142 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.44796 .48151 m .44633 .45808 L .48261 .46278 L p
1 g
F P
s
P
p
.002 w
.53186 .39361 m .50797 .39341 L .50176 .35831 L p
1 g
F P
s
P
p
.002 w
.46852 .36929 m .50176 .35831 L .50797 .39341 L p
1 g
F P
s
P
p
.002 w
.48517 .40096 m .46599 .41543 L .44059 .39039 L p
1 g
F P
s
P
p
.002 w
.44059 .39039 m .46852 .36929 L .48517 .40096 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.55583 .46308 m .55453 .47495 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50797 .39341 m .48517 .40096 L .46852 .36929 L p
1 g
F P
s
P
p
.002 w
.55318 .45148 m .55583 .46308 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.54684 .44142 m .53748 .434 L .55419 .4015 L p
1 g
F P
s
P
p
.002 w
.53186 .39361 m .55419 .4015 L .53748 .434 L p
1 g
F P
s
P
p
.002 w
.48581 .45116 m .48261 .46278 L .44633 .45808 L p
1 g
F P
s
P
p
.002 w
.44633 .45808 m .45256 .4352 L .48581 .45116 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.54684 .44142 m .55318 .45148 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.53748 .434 m .52611 .43002 L .53186 .39361 L p
1 g
F P
s
P
p
.002 w
.50797 .39341 m .53186 .39361 L .52611 .43002 L p
1 g
F P
s
P
p
.002 w
.53748 .434 m .54684 .44142 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.49265 .44113 m .48581 .45116 L .45256 .4352 L p
1 g
F P
s
P
p
.002 w
.45256 .4352 m .46599 .41543 L .49265 .44113 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.52611 .43002 m .53748 .434 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.51398 .42995 m .52611 .43002 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.5024 .43379 m .51398 .42995 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.49265 .44113 m .5024 .43379 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.50196 .43412 L
s
P
p
.002 w
.48581 .45116 m .49265 .44113 L .51954 .46649 L closepath p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.52611 .43002 m .51398 .42995 L .50797 .39341 L p
1 g
F P
s
P
p
.002 w
.48517 .40096 m .50797 .39341 L .51398 .42995 L p
1 g
F P
s
P
p
.002 w
.5024 .43379 m .49265 .44113 L .46599 .41543 L p
1 g
F P
s
P
p
.002 w
.46599 .41543 m .48517 .40096 L .5024 .43379 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.51398 .42995 m .5024 .43379 L .48517 .40096 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
.004 w
.51954 .46649 m
.53166 .48881 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .25109 .40685 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .53166 .48881 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.683721)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.683721)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.50349 .46236 m .52435 .445 L .50298 .42613 L p
1 g
F P
s
P
p
.002 w
.50298 .42613 m .48876 .43794 L .50349 .46236 L p
1 g
F P
s
P
p
.002 w
.51284 .41055 m .50298 .42613 L .52435 .445 L p
1 g
F P
s
P
p
.002 w
.48876 .43794 m .50298 .42613 L .48153 .40736 L p
1 g
F P
s
P
p
.002 w
.50298 .42613 m .51284 .41055 L .48652 .39944 L p
1 g
F P
s
P
p
.002 w
.48652 .39944 m .48153 .40736 L .50298 .42613 L p
1 g
F P
s
P
p
.002 w
.47842 .47241 m .50349 .46236 L .48876 .43794 L p
1 g
F P
s
P
p
.002 w
.48876 .43794 m .47168 .44475 L .47842 .47241 L p
1 g
F P
s
P
p
.002 w
.47168 .44475 m .48876 .43794 L .47431 .41335 L p
1 g
F P
s
P
p
.002 w
.48153 .40736 m .47431 .41335 L .48876 .43794 L p
1 g
F P
s
P
p
.002 w
.52435 .445 m .53888 .42215 L .51284 .41055 L p
1 g
F P
s
P
p
.002 w
.51732 .39282 m .51284 .41055 L .53888 .42215 L p
1 g
F P
s
P
p
.002 w
.51284 .41055 m .51732 .39282 L .48876 .39044 L p
1 g
F P
s
P
p
.002 w
.48876 .39044 m .48652 .39944 L .51284 .41055 L p
1 g
F P
s
P
p
.002 w
.51822 .48616 m .54526 .46365 L .52435 .445 L p
1 g
F P
s
P
p
.002 w
.52435 .445 m .50349 .46236 L .51822 .48616 L p
1 g
F P
s
P
p
.002 w
.53888 .42215 m .52435 .445 L .54526 .46365 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .47431 .41335 L .48153 .40736 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .48153 .40736 L .48652 .39944 L closepath p
1 g
F P
s
P
p
.002 w
.47431 .41335 m .46563 .41678 L .47168 .44475 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .46563 .41678 L .47431 .41335 L closepath p
1 g
F P
s
P
p
.002 w
.45173 .47409 m .47842 .47241 L .47168 .44475 L p
1 g
F P
s
P
p
.002 w
.47168 .44475 m .45352 .44581 L .45173 .47409 L p
1 g
F P
s
P
p
.002 w
.45352 .44581 m .47168 .44475 L .46563 .41678 L p
1 g
F P
s
P
p
.002 w
.48575 .49928 m .51822 .48616 L .50349 .46236 L p
1 g
F P
s
P
p
.002 w
.50349 .46236 m .47842 .47241 L .48575 .49928 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .48652 .39944 L .48876 .39044 L closepath p
1 g
F P
s
P
p
.002 w
.46563 .41678 m .45642 .41728 L .45352 .44581 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .45642 .41728 L .46563 .41678 L closepath p
1 g
F P
s
P
p
.002 w
.54526 .46365 m .56415 .43404 L .53888 .42215 L p
1 g
F P
s
P
p
.002 w
.54555 .39612 m .53888 .42215 L .56415 .43404 L p
1 g
F P
s
P
p
.002 w
.53888 .42215 m .54555 .39612 L .51732 .39282 L p
1 g
F P
s
P
p
.002 w
.5159 .3748 m .51732 .39282 L .54555 .39612 L p
1 g
F P
s
P
p
.002 w
.51732 .39282 m .5159 .3748 L .48799 .38132 L p
1 g
F P
s
P
p
.002 w
.48799 .38132 m .48876 .39044 L .51732 .39282 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .48876 .39044 L .48799 .38132 L closepath p
1 g
F P
s
P
p
.002 w
.43619 .44096 m .45352 .44581 L .45642 .41728 L p
1 g
F P
s
P
p
.002 w
.45642 .41728 m .44766 .41478 L .43619 .44096 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .44766 .41478 L .45642 .41728 L closepath p
1 g
F P
s
P
p
.002 w
.45111 .50159 m .48575 .49928 L .47842 .47241 L p
1 g
F P
s
P
p
.002 w
.47842 .47241 m .45173 .47409 L .45111 .50159 L p
1 g
F P
s
P
p
.002 w
.42618 .4671 m .45173 .47409 L .45352 .44581 L p
1 g
F P
s
P
p
.002 w
.45352 .44581 m .43619 .44096 L .42618 .4671 L p
1 g
F P
s
P
p
.002 w
.48429 .37305 m .48799 .38132 L .5159 .3748 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .48799 .38132 L .48429 .37305 L closepath p
1 g
F P
s
P
p
.002 w
.42156 .43067 m .43619 .44096 L .44766 .41478 L p
1 g
F P
s
P
p
.002 w
.44766 .41478 m .4403 .40953 L .42156 .43067 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .4403 .40953 L .44766 .41478 L closepath p
1 g
F P
s
P
p
.002 w
.5327 .5089 m .56533 .48171 L .54526 .46365 L p
1 g
F P
s
P
p
.002 w
.54526 .46365 m .51822 .48616 L .5327 .5089 L p
1 g
F P
s
P
p
.002 w
.56415 .43404 m .54526 .46365 L .56533 .48171 L p
1 g
F P
s
P
p
.002 w
.56415 .43404 m .57292 .40029 L .54555 .39612 L p
1 g
F P
s
P
p
.002 w
.54358 .3696 m .54555 .39612 L .57292 .40029 L p
1 g
F P
s
P
p
.002 w
.54555 .39612 m .54358 .3696 L .5159 .3748 L p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .43344 .38398 L .43276 .39325 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .43276 .39325 L .43514 .40209 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .43514 .40209 L .4403 .40953 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .48429 .37305 L .47802 .36653 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .47802 .36653 L .46987 .36249 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .46987 .36249 L .4607 .36138 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .4607 .36138 L .45153 .36333 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .45153 .36333 L .44337 .36815 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .44337 .36815 L .4371 .37529 L closepath p
1 g
F P
s
P
p
.002 w
.46039 .38902 m .4371 .37529 L .43344 .38398 L closepath p
1 g
F P
s
P
p
.002 w
.50866 .35841 m .5159 .3748 L .54358 .3696 L p
1 g
F P
s
P
p
.002 w
.5159 .3748 m .50866 .35841 L .48429 .37305 L p
1 g
F P
s
P
p
.002 w
.49353 .52484 m .5327 .5089 L .51822 .48616 L p
1 g
F P
s
P
p
.002 w
.51822 .48616 m .48575 .49928 L .49353 .52484 L p
1 g
F P
s
P
p
.002 w
.47802 .36653 m .48429 .37305 L .50866 .35841 L p
1 g
F P
s
P
p
.002 w
.41124 .41598 m .42156 .43067 L .4403 .40953 L p
1 g
F P
s
P
p
.002 w
.4403 .40953 m .43514 .40209 L .41124 .41598 L p
1 g
F P
s
P
p
.002 w
.56533 .48171 m .58819 .446 L .56415 .43404 L p
1 g
F P
s
P
p
.002 w
.57292 .40029 m .56415 .43404 L .58819 .446 L p
1 g
F P
s
P
p
.002 w
.40452 .45206 m .42618 .4671 L .43619 .44096 L p
1 g
F P
s
P
p
.002 w
.43619 .44096 m .42156 .43067 L .40452 .45206 L p
1 g
F P
s
P
p
.002 w
.41786 .49269 m .45111 .50159 L .45173 .47409 L p
1 g
F P
s
P
p
.002 w
.45173 .47409 m .42618 .4671 L .41786 .49269 L p
1 g
F P
s
P
p
.002 w
.50866 .35841 m .49634 .34542 L .47802 .36653 L p
1 g
F P
s
P
p
.002 w
.46987 .36249 m .47802 .36653 L .49634 .34542 L p
1 g
F P
s
P
p
.002 w
.45168 .5278 m .49353 .52484 L .48575 .49928 L p
1 g
F P
s
P
p
.002 w
.48575 .49928 m .45111 .50159 L .45168 .5278 L p
1 g
F P
s
P
p
.002 w
.40641 .39846 m .41124 .41598 L .43514 .40209 L p
1 g
F P
s
P
p
.002 w
.43514 .40209 m .43276 .39325 L .40641 .39846 L p
1 g
F P
s
P
p
.002 w
.54358 .3696 m .53307 .34539 L .50866 .35841 L p
1 g
F P
s
P
p
.002 w
.49634 .34542 m .50866 .35841 L .53307 .34539 L p
1 g
F P
s
P
p
.002 w
.49634 .34542 m .4802 .33731 L .46987 .36249 L p
1 g
F P
s
P
p
.002 w
.4607 .36138 m .46987 .36249 L .4802 .33731 L p
1 g
F P
s
P
p
.002 w
.57292 .40029 m .57054 .36584 L .54358 .3696 L p
1 g
F P
s
P
p
.002 w
.53307 .34539 m .54358 .3696 L .57054 .36584 L p
1 g
F P
s
P
p
.002 w
.40768 .38 m .40641 .39846 L .43276 .39325 L p
1 g
F P
s
P
p
.002 w
.43276 .39325 m .43344 .38398 L .40768 .38 L p
1 g
F P
s
P
p
.002 w
.38914 .43046 m .40452 .45206 L .42156 .43067 L p
1 g
F P
s
P
p
.002 w
.42156 .43067 m .41124 .41598 L .38914 .43046 L p
1 g
F P
s
P
p
.002 w
.58819 .446 m .59892 .40527 L .57292 .40029 L p
1 g
F P
s
P
p
.002 w
.57054 .36584 m .57292 .40029 L .59892 .40527 L p
1 g
F P
s
P
p
.002 w
.4802 .33731 m .46199 .33501 L .4607 .36138 L p
1 g
F P
s
P
p
.002 w
.45153 .36333 m .4607 .36138 L .46199 .33501 L p
1 g
F P
s
P
p
.002 w
.41495 .36267 m .40768 .38 L .43344 .38398 L p
1 g
F P
s
P
p
.002 w
.43344 .38398 m .4371 .37529 L .41495 .36267 L p
1 g
F P
s
P
p
.002 w
.38955 .47329 m .41786 .49269 L .42618 .4671 L p
1 g
F P
s
P
p
.002 w
.42618 .4671 m .40452 .45206 L .38955 .47329 L p
1 g
F P
s
P
p
.002 w
.46199 .33501 m .44372 .33885 L .45153 .36333 L p
1 g
F P
s
P
p
.002 w
.44337 .36815 m .45153 .36333 L .44372 .33885 L p
1 g
F P
s
P
p
.002 w
.54664 .53013 m .58416 .49884 L .56533 .48171 L p
1 g
F P
s
P
p
.002 w
.56533 .48171 m .5327 .5089 L .54664 .53013 L p
1 g
F P
s
P
p
.002 w
.58819 .446 m .56533 .48171 L .58416 .49884 L p
1 g
F P
s
P
p
.002 w
.42742 .34842 m .41495 .36267 L .4371 .37529 L p
1 g
F P
s
P
p
.002 w
.4371 .37529 m .44337 .36815 L .42742 .34842 L p
1 g
F P
s
P
p
.002 w
.44372 .33885 m .42742 .34842 L .44337 .36815 L p
1 g
F P
s
P
p
.002 w
.50162 .54856 m .54664 .53013 L .5327 .5089 L p
1 g
F P
s
P
p
.002 w
.5327 .5089 m .49353 .52484 L .50162 .54856 L p
1 g
F P
s
P
p
.002 w
.53307 .34539 m .51501 .32612 L .49634 .34542 L p
1 g
F P
s
P
p
.002 w
.4802 .33731 m .49634 .34542 L .51501 .32612 L p
1 g
F P
s
P
p
.002 w
.41142 .51724 m .45168 .5278 L .45111 .50159 L p
1 g
F P
s
P
p
.002 w
.45111 .50159 m .41786 .49269 L .41142 .51724 L p
1 g
F P
s
P
p
.002 w
.58416 .49884 m .61051 .4578 L .58819 .446 L p
1 g
F P
s
P
p
.002 w
.59892 .40527 m .58819 .446 L .61051 .4578 L p
1 g
F P
s
P
p
.002 w
.38188 .40456 m .38914 .43046 L .41124 .41598 L p
1 g
F P
s
P
p
.002 w
.41124 .41598 m .40641 .39846 L .38188 .40456 L p
1 g
F P
s
P
p
.002 w
.57054 .36584 m .55705 .33427 L .53307 .34539 L p
1 g
F P
s
P
p
.002 w
.51501 .32612 m .53307 .34539 L .55705 .33427 L p
1 g
F P
s
P
p
.002 w
.45348 .55215 m .50162 .54856 L .49353 .52484 L p
1 g
F P
s
P
p
.002 w
.49353 .52484 m .45168 .5278 L .45348 .55215 L p
1 g
F P
s
P
p
.002 w
.51501 .32612 m .49122 .31398 L .4802 .33731 L p
1 g
F P
s
P
p
.002 w
.46199 .33501 m .4802 .33731 L .49122 .31398 L p
1 g
F P
s
P
p
.002 w
.59892 .40527 m .59623 .36361 L .57054 .36584 L p
1 g
F P
s
P
p
.002 w
.55705 .33427 m .57054 .36584 L .59623 .36361 L p
1 g
F P
s
P
p
.002 w
.36935 .44525 m .38955 .47329 L .40452 .45206 L p
1 g
F P
s
P
p
.002 w
.40452 .45206 m .38914 .43046 L .36935 .44525 L p
1 g
F P
s
P
p
.002 w
.38365 .3772 m .38188 .40456 L .40641 .39846 L p
1 g
F P
s
P
p
.002 w
.40641 .39846 m .40768 .38 L .38365 .3772 L p
1 g
F P
s
P
p
.002 w
.61051 .4578 m .62299 .41099 L .59892 .40527 L p
1 g
F P
s
P
p
.002 w
.59623 .36361 m .59892 .40527 L .62299 .41099 L p
1 g
F P
s
P
p
.002 w
.49122 .31398 m .46426 .31046 L .46199 .33501 L p
1 g
F P
s
P
p
.002 w
.44372 .33885 m .46199 .33501 L .46426 .31046 L p
1 g
F P
s
P
p
.002 w
.37701 .49393 m .41142 .51724 L .41786 .49269 L p
1 g
F P
s
P
p
.002 w
.41786 .49269 m .38955 .47329 L .37701 .49393 L p
1 g
F P
s
P
p
.002 w
.39438 .35145 m .38365 .3772 L .40768 .38 L p
1 g
F P
s
P
p
.002 w
.40768 .38 m .41495 .36267 L .39438 .35145 L p
1 g
F P
s
P
p
.002 w
.55705 .33427 m .53367 .30903 L .51501 .32612 L p
1 g
F P
s
P
p
.002 w
.49122 .31398 m .51501 .32612 L .53367 .30903 L p
1 g
F P
s
P
p
.002 w
.46426 .31046 m .43713 .31607 L .44372 .33885 L p
1 g
F P
s
P
p
.002 w
.42742 .34842 m .44372 .33885 L .43713 .31607 L p
1 g
F P
s
P
p
.002 w
.55976 .54938 m .60134 .51468 L .58416 .49884 L p
1 g
F P
s
P
p
.002 w
.58416 .49884 m .54664 .53013 L .55976 .54938 L p
1 g
F P
s
P
p
.002 w
.61051 .4578 m .58416 .49884 L .60134 .51468 L p
1 g
F P
s
P
p
.002 w
.40706 .5402 m .45348 .55215 L .45168 .5278 L p
1 g
F P
s
P
p
.002 w
.45168 .5278 m .41142 .51724 L .40706 .5402 L p
1 g
F P
s
P
p
.002 w
.41291 .33026 m .39438 .35145 L .41495 .36267 L p
1 g
F P
s
P
p
.002 w
.41495 .36267 m .42742 .34842 L .41291 .33026 L p
1 g
F P
s
P
p
.002 w
.43713 .31607 m .41291 .33026 L .42742 .34842 L p
1 g
F P
s
P
p
.002 w
.50988 .56992 m .55976 .54938 L .54664 .53013 L p
1 g
F P
s
P
p
.002 w
.54664 .53013 m .50162 .54856 L .50988 .56992 L p
1 g
F P
s
P
p
.002 w
.3597 .41147 m .36935 .44525 L .38914 .43046 L p
1 g
F P
s
P
p
.002 w
.38914 .43046 m .38188 .40456 L .3597 .41147 L p
1 g
F P
s
P
p
.002 w
.59623 .36361 m .58012 .32532 L .55705 .33427 L p
1 g
F P
s
P
p
.002 w
.53367 .30903 m .55705 .33427 L .58012 .32532 L p
1 g
F P
s
P
p
.002 w
.60134 .51468 m .63061 .46922 L .61051 .4578 L p
1 g
F P
s
P
p
.002 w
.62299 .41099 m .61051 .4578 L .63061 .46922 L p
1 g
F P
s
P
p
.002 w
.53367 .30903 m .50271 .29304 L .49122 .31398 L p
1 g
F P
s
P
p
.002 w
.46426 .31046 m .49122 .31398 L .50271 .29304 L p
1 g
F P
s
P
p
.002 w
.62299 .41099 m .62011 .36301 L .59623 .36361 L p
1 g
F P
s
P
p
.002 w
.58012 .32532 m .59623 .36361 L .62011 .36301 L p
1 g
F P
s
P
p
.002 w
.4565 .57407 m .50988 .56992 L .50162 .54856 L p
1 g
F P
s
P
p
.002 w
.50162 .54856 m .45348 .55215 L .4565 .57407 L p
1 g
F P
s
P
p
.002 w
.35235 .46005 m .37701 .49393 L .38955 .47329 L p
1 g
F P
s
P
p
.002 w
.38955 .47329 m .36935 .44525 L .35235 .46005 L p
1 g
F P
s
P
p
.002 w
.3619 .37566 m .3597 .41147 L .38188 .40456 L p
1 g
F P
s
P
p
.002 w
.38188 .40456 m .38365 .3772 L .3619 .37566 L p
1 g
F P
s
P
p
.002 w
.36727 .51353 m .40706 .5402 L .41142 .51724 L p
1 g
F P
s
P
p
.002 w
.41142 .51724 m .37701 .49393 L .36727 .51353 L p
1 g
F P
s
P
p
.002 w
.63061 .46922 m .6446 .41735 L .62299 .41099 L p
1 g
F P
s
P
p
.002 w
.62011 .36301 m .62299 .41099 L .6446 .41735 L p
1 g
F P
s
P
p
.002 w
.50271 .29304 m .46749 .2883 L .46426 .31046 L p
1 g
F P
s
P
p
.002 w
.43713 .31607 m .46426 .31046 L .46749 .2883 L p
1 g
F P
s
P
p
.002 w
.58012 .32532 m .55195 .29459 L .53367 .30903 L p
1 g
F P
s
P
p
.002 w
.50271 .29304 m .53367 .30903 L .55195 .29459 L p
1 g
F P
s
P
p
.002 w
.3759 .3419 m .3619 .37566 L .38365 .3772 L p
1 g
F P
s
P
p
.002 w
.38365 .3772 m .39438 .35145 L .3759 .3419 L p
1 g
F P
s
P
p
.002 w
.40495 .56103 m .4565 .57407 L .45348 .55215 L p
1 g
F P
s
P
p
.002 w
.45348 .55215 m .40706 .5402 L .40495 .56103 L p
1 g
F P
s
P
p
.002 w
.46749 .2883 m .43195 .29555 L .43713 .31607 L p
1 g
F P
s
P
p
.002 w
.41291 .33026 m .43713 .31607 L .43195 .29555 L p
1 g
F P
s
P
p
.002 w
.34046 .41908 m .35235 .46005 L .36935 .44525 L p
1 g
F P
s
P
p
.002 w
.36935 .44525 m .3597 .41147 L .34046 .41908 L p
1 g
F P
s
P
p
.002 w
.57174 .56618 m .61644 .52885 L .60134 .51468 L p
1 g
F P
s
P
p
.002 w
.60134 .51468 m .55976 .54938 L .57174 .56618 L p
1 g
F P
s
P
p
.002 w
.63061 .46922 m .60134 .51468 L .61644 .52885 L p
1 g
F P
s
P
p
.002 w
.40018 .31412 m .3759 .3419 L .39438 .35145 L p
1 g
F P
s
P
p
.002 w
.39438 .35145 m .41291 .33026 L .40018 .31412 L p
1 g
F P
s
P
p
.002 w
.62011 .36301 m .60176 .31881 L .58012 .32532 L p
1 g
F P
s
P
p
.002 w
.55195 .29459 m .58012 .32532 L .60176 .31881 L p
1 g
F P
s
P
p
.002 w
.43195 .29555 m .40018 .31412 L .41291 .33026 L p
1 g
F P
s
P
p
.002 w
.51814 .58836 m .57174 .56618 L .55976 .54938 L p
1 g
F P
s
P
p
.002 w
.55976 .54938 m .50988 .56992 L .51814 .58836 L p
1 g
F P
s
P
p
.002 w
.61644 .52885 m .64798 .47999 L .63061 .46922 L p
1 g
F P
s
P
p
.002 w
.6446 .41735 m .63061 .46922 L .64798 .47999 L p
1 g
F P
s
P
p
.002 w
.55195 .29459 m .51446 .27501 L .50271 .29304 L p
1 g
F P
s
P
p
.002 w
.46749 .2883 m .50271 .29304 L .51446 .27501 L p
1 g
F P
s
P
p
.002 w
.6446 .41735 m .6416 .36412 L .62011 .36301 L p
1 g
F P
s
P
p
.002 w
.60176 .31881 m .62011 .36301 L .6416 .36412 L p
1 g
F P
s
P
p
.002 w
.33863 .47456 m .36727 .51353 L .37701 .49393 L p
1 g
F P
s
P
p
.002 w
.37701 .49393 m .35235 .46005 L .33863 .47456 L p
1 g
F P
s
P
p
.002 w
.46075 .59299 m .51814 .58836 L .50988 .56992 L p
1 g
F P
s
P
p
.002 w
.50988 .56992 m .4565 .57407 L .46075 .59299 L p
1 g
F P
s
P
p
.002 w
.34301 .3755 m .34046 .41908 L .3597 .41147 L p
1 g
F P
s
P
p
.002 w
.3597 .41147 m .3619 .37566 L .34301 .3755 L p
1 g
F P
s
P
p
.002 w
.36065 .53162 m .40495 .56103 L .40706 .5402 L p
1 g
F P
s
P
p
.002 w
.40706 .5402 m .36727 .51353 L .36065 .53162 L p
1 g
F P
s
P
p
.002 w
.64798 .47999 m .66316 .42424 L .6446 .41735 L p
1 g
F P
s
P
p
.002 w
.6416 .36412 m .6446 .41735 L .66316 .42424 L p
1 g
F P
s
P
p
.002 w
.60176 .31881 m .56944 .2832 L .55195 .29459 L p
1 g
F P
s
P
p
.002 w
.51446 .27501 m .55195 .29459 L .56944 .2832 L p
1 g
F P
s
P
p
.002 w
.51446 .27501 m .47166 .26909 L .46749 .2883 L p
1 g
F P
s
P
p
.002 w
.43195 .29555 m .46749 .2883 L .47166 .26909 L p
1 g
F P
s
P
p
.002 w
.36 .33432 m .34301 .3755 L .3619 .37566 L p
1 g
F P
s
P
p
.002 w
.3619 .37566 m .3759 .3419 L .36 .33432 L p
1 g
F P
s
P
p
.002 w
.40525 .57916 m .46075 .59299 L .4565 .57407 L p
1 g
F P
s
P
p
.002 w
.4565 .57407 m .40495 .56103 L .40525 .57916 L p
1 g
F P
s
P
p
.002 w
.32471 .42724 m .33863 .47456 L .35235 .46005 L p
1 g
F P
s
P
p
.002 w
.35235 .46005 m .34046 .41908 L .32471 .42724 L p
1 g
F P
s
P
p
.002 w
.6416 .36412 m .62146 .31497 L .60176 .31881 L p
1 g
F P
s
P
p
.002 w
.56944 .2832 m .60176 .31881 L .62146 .31497 L p
1 g
F P
s
P
p
.002 w
.47166 .26909 m .42835 .27783 L .43195 .29555 L p
1 g
F P
s
P
p
.002 w
.40018 .31412 m .43195 .29555 L .42835 .27783 L p
1 g
F P
s
P
p
.002 w
.58227 .58004 m .62905 .54095 L .61644 .52885 L p
1 g
F P
s
P
p
.002 w
.61644 .52885 m .57174 .56618 L .58227 .58004 L p
1 g
F P
s
P
p
.002 w
.64798 .47999 m .61644 .52885 L .62905 .54095 L p
1 g
F P
s
P
p
.002 w
.3896 .30043 m .36 .33432 L .3759 .3419 L p
1 g
F P
s
P
p
.002 w
.3759 .3419 m .40018 .31412 L .3896 .30043 L p
1 g
F P
s
P
p
.002 w
.42835 .27783 m .3896 .30043 L .40018 .31412 L p
1 g
F P
s
P
p
.002 w
.52621 .60334 m .58227 .58004 L .57174 .56618 L p
1 g
F P
s
P
p
.002 w
.57174 .56618 m .51814 .58836 L .52621 .60334 L p
1 g
F P
s
P
p
.002 w
.62905 .54095 m .66211 .48985 L .64798 .47999 L p
1 g
F P
s
P
p
.002 w
.66316 .42424 m .64798 .47999 L .66211 .48985 L p
1 g
F P
s
P
p
.002 w
.56944 .2832 m .52623 .26041 L .51446 .27501 L p
1 g
F P
s
P
p
.002 w
.47166 .26909 m .51446 .27501 L .52623 .26041 L p
1 g
F P
s
P
p
.002 w
.66316 .42424 m .66013 .36699 L .6416 .36412 L p
1 g
F P
s
P
p
.002 w
.62146 .31497 m .6416 .36412 L .66013 .36699 L p
1 g
F P
s
P
p
.002 w
.32867 .48843 m .36065 .53162 L .36727 .51353 L p
1 g
F P
s
P
p
.002 w
.36727 .51353 m .33863 .47456 L .32867 .48843 L p
1 g
F P
s
P
p
.002 w
.46618 .60833 m .52621 .60334 L .51814 .58836 L p
1 g
F P
s
P
p
.002 w
.51814 .58836 m .46075 .59299 L .46618 .60833 L p
1 g
F P
s
P
p
.002 w
.32755 .37677 m .32471 .42724 L .34046 .41908 L p
1 g
F P
s
P
p
.002 w
.34046 .41908 m .34301 .3755 L .32755 .37677 L p
1 g
F P
s
P
p
.002 w
.35748 .54768 m .40525 .57916 L .40495 .56103 L p
1 g
F P
s
P
p
.002 w
.40495 .56103 m .36065 .53162 L .35748 .54768 L p
1 g
F P
s
P
p
.002 w
.62146 .31497 m .58571 .27528 L .56944 .2832 L p
1 g
F P
s
P
p
.002 w
.52623 .26041 m .56944 .2832 L .58571 .27528 L p
1 g
F P
s
P
p
.002 w
.66211 .48985 m .67811 .43155 L .66316 .42424 L p
1 g
F P
s
P
p
.002 w
.66013 .36699 m .66316 .42424 L .67811 .43155 L p
1 g
F P
s
P
p
.002 w
.52623 .26041 m .47672 .25343 L .47166 .26909 L p
1 g
F P
s
P
p
.002 w
.42835 .27783 m .47166 .26909 L .47672 .25343 L p
1 g
F P
s
P
p
.002 w
.34719 .329 m .32755 .37677 L .34301 .3755 L p
1 g
F P
s
P
p
.002 w
.34301 .3755 m .36 .33432 L .34719 .329 L p
1 g
F P
s
P
p
.002 w
.40809 .59402 m .46618 .60833 L .46075 .59299 L p
1 g
F P
s
P
p
.002 w
.46075 .59299 m .40525 .57916 L .40809 .59402 L p
1 g
F P
s
P
p
.002 w
.31303 .4358 m .32867 .48843 L .33863 .47456 L p
1 g
F P
s
P
p
.002 w
.33863 .47456 m .32471 .42724 L .31303 .4358 L p
1 g
F P
s
P
p
.002 w
.66013 .36699 m .63865 .31405 L .62146 .31497 L p
1 g
F P
s
P
p
.002 w
.58571 .27528 m .62146 .31497 L .63865 .31405 L p
1 g
F P
s
P
p
.002 w
.47672 .25343 m .4265 .26347 L .42835 .27783 L p
1 g
F P
s
P
p
.002 w
.3896 .30043 m .42835 .27783 L .4265 .26347 L p
1 g
F P
s
P
p
.002 w
.59104 .59048 m .63874 .5506 L .62905 .54095 L p
1 g
F P
s
P
p
.002 w
.62905 .54095 m .58227 .58004 L .59104 .59048 L p
1 g
F P
s
P
p
.002 w
.66211 .48985 m .62905 .54095 L .63874 .5506 L p
1 g
F P
s
P
p
.002 w
.38152 .28966 m .34719 .329 L .36 .33432 L p
1 g
F P
s
P
p
.002 w
.36 .33432 m .3896 .30043 L .38152 .28966 L p
1 g
F P
s
P
p
.002 w
.4265 .26347 m .38152 .28966 L .3896 .30043 L p
1 g
F P
s
P
p
.002 w
.5339 .6143 m .59104 .59048 L .58227 .58004 L p
1 g
F P
s
P
p
.002 w
.58227 .58004 m .52621 .60334 L .5339 .6143 L p
1 g
F P
s
P
p
.002 w
.58571 .27528 m .53774 .24978 L .52623 .26041 L p
1 g
F P
s
P
p
.002 w
.47672 .25343 m .52623 .26041 L .53774 .24978 L p
1 g
F P
s
P
p
.002 w
.32291 .50127 m .35748 .54768 L .36065 .53162 L p
1 g
F P
s
P
p
.002 w
.36065 .53162 m .32867 .48843 L .32291 .50127 L p
1 g
F P
s
P
p
.002 w
.67811 .43155 m .6751 .37164 L .66013 .36699 L p
1 g
F P
s
P
p
.002 w
.63865 .31405 m .66013 .36699 L .6751 .37164 L p
1 g
F P
s
P
p
.002 w
.63874 .5506 m .67249 .49852 L .66211 .48985 L p
1 g
F P
s
P
p
.002 w
.67811 .43155 m .66211 .48985 L .67249 .49852 L p
1 g
F P
s
P
p
.002 w
.47273 .61949 m .5339 .6143 L .52621 .60334 L p
1 g
F P
s
P
p
.002 w
.52621 .60334 m .46618 .60833 L .47273 .61949 L p
1 g
F P
s
P
p
.002 w
.3161 .37953 m .31303 .4358 L .32471 .42724 L p
1 g
F P
s
P
p
.002 w
.32471 .42724 m .32755 .37677 L .3161 .37953 L p
1 g
F P
s
P
p
.002 w
.35803 .56121 m .40809 .59402 L .40525 .57916 L p
1 g
F P
s
P
p
.002 w
.40525 .57916 m .35748 .54768 L .35803 .56121 L p
1 g
F P
s
P
p
.002 w
.63865 .31405 m .60031 .27121 L .58571 .27528 L p
1 g
F P
s
P
p
.002 w
.53774 .24978 m .58571 .27528 L .60031 .27121 L p
1 g
F P
s
P
p
.002 w
.67249 .49852 m .68889 .43911 L .67811 .43155 L p
1 g
F P
s
P
p
.002 w
.6751 .37164 m .67811 .43155 L .68889 .43911 L p
1 g
F P
s
P
p
.002 w
.53774 .24978 m .4826 .24188 L .47672 .25343 L p
1 g
F P
s
P
p
.002 w
.4265 .26347 m .47672 .25343 L .4826 .24188 L p
1 g
F P
s
P
p
.002 w
.33797 .32619 m .3161 .37953 L .32755 .37677 L p
1 g
F P
s
P
p
.002 w
.32755 .37677 m .34719 .329 L .33797 .32619 L p
1 g
F P
s
P
p
.002 w
.30595 .44457 m .32291 .50127 L .32867 .48843 L p
1 g
F P
s
P
p
.002 w
.32867 .48843 m .31303 .4358 L .30595 .44457 L p
1 g
F P
s
P
p
.002 w
.41353 .60503 m .47273 .61949 L .46618 .60833 L p
1 g
F P
s
P
p
.002 w
.46618 .60833 m .40809 .59402 L .41353 .60503 L p
1 g
F P
s
P
p
.002 w
.6751 .37164 m .65278 .31621 L .63865 .31405 L p
1 g
F P
s
P
p
.002 w
.60031 .27121 m .63865 .31405 L .65278 .31621 L p
1 g
F P
s
P
p
.002 w
.4826 .24188 m .42656 .25301 L .4265 .26347 L p
1 g
F P
s
P
p
.002 w
.38152 .28966 m .4265 .26347 L .42656 .25301 L p
1 g
F P
s
P
p
.002 w
.37632 .28224 m .33797 .32619 L .34719 .329 L p
1 g
F P
s
P
p
.002 w
.34719 .329 m .38152 .28966 L .37632 .28224 L p
1 g
F P
s
P
p
.002 w
.59771 .59703 m .64508 .55742 L .63874 .5506 L p
1 g
F P
s
P
p
.002 w
.63874 .5506 m .59104 .59048 L .59771 .59703 L p
1 g
F P
s
P
p
.002 w
.67249 .49852 m .63874 .5506 L .64508 .55742 L p
1 g
F P
s
P
p
.002 w
.42656 .25301 m .37632 .28224 L .38152 .28966 L p
1 g
F P
s
P
p
.002 w
.54099 .62072 m .59771 .59703 L .59104 .59048 L p
1 g
F P
s
P
p
.002 w
.59104 .59048 m .5339 .6143 L .54099 .62072 L p
1 g
F P
s
P
p
.002 w
.32177 .51271 m .35803 .56121 L .35748 .54768 L p
1 g
F P
s
P
p
.002 w
.35748 .54768 m .32291 .50127 L .32177 .51271 L p
1 g
F P
s
P
p
.002 w
.60031 .27121 m .54868 .24361 L .53774 .24978 L p
1 g
F P
s
P
p
.002 w
.4826 .24188 m .53774 .24978 L .54868 .24361 L p
1 g
F P
s
P
p
.002 w
.68889 .43911 m .68594 .37808 L .6751 .37164 L p
1 g
F P
s
P
p
.002 w
.65278 .31621 m .6751 .37164 L .68594 .37808 L p
1 g
F P
s
P
p
.002 w
.64508 .55742 m .67863 .5057 L .67249 .49852 L p
1 g
F P
s
P
p
.002 w
.68889 .43911 m .67249 .49852 L .67863 .5057 L p
1 g
F P
s
P
p
.002 w
.48031 .62594 m .54099 .62072 L .5339 .6143 L p
1 g
F P
s
P
p
.002 w
.5339 .6143 m .47273 .61949 L .48031 .62594 L p
1 g
F P
s
P
p
.002 w
.30919 .38381 m .30595 .44457 L .31303 .4358 L p
1 g
F P
s
P
p
.002 w
.31303 .4358 m .3161 .37953 L .30919 .38381 L p
1 g
F P
s
P
p
.002 w
.36252 .5717 m .41353 .60503 L .40809 .59402 L p
1 g
F P
s
P
p
.002 w
.40809 .59402 m .35803 .56121 L .36252 .5717 L p
1 g
F P
s
P
p
.002 w
.65278 .31621 m .61276 .2713 L .60031 .27121 L p
1 g
F P
s
P
p
.002 w
.54868 .24361 m .60031 .27121 L .61276 .2713 L p
1 g
F P
s
P
p
.002 w
.67863 .5057 m .69497 .44676 L .68889 .43911 L p
1 g
F P
s
P
p
.002 w
.68594 .37808 m .68889 .43911 L .69497 .44676 L p
1 g
F P
s
P
p
.002 w
.54868 .24361 m .4892 .235 L .4826 .24188 L p
1 g
F P
s
P
p
.002 w
.42656 .25301 m .4826 .24188 L .4892 .235 L p
1 g
F P
s
P
p
.002 w
.30395 .45332 m .32177 .51271 L .32291 .50127 L p
1 g
F P
s
P
p
.002 w
.32291 .50127 m .30595 .44457 L .30395 .45332 L p
1 g
F P
s
P
p
.002 w
.68594 .37808 m .66331 .32158 L .65278 .31621 L p
1 g
F P
s
P
p
.002 w
.61276 .2713 m .65278 .31621 L .66331 .32158 L p
1 g
F P
s
P
p
.002 w
.33282 .32614 m .30919 .38381 L .3161 .37953 L p
1 g
F P
s
P
p
.002 w
.3161 .37953 m .33797 .32619 L .33282 .32614 L p
1 g
F P
s
P
p
.002 w
.42161 .61166 m .48031 .62594 L .47273 .61949 L p
1 g
F P
s
P
p
.002 w
.47273 .61949 m .41353 .60503 L .42161 .61166 L p
1 g
F P
s
P
p
.002 w
.4892 .235 m .42864 .24699 L .42656 .25301 L p
1 g
F P
s
P
p
.002 w
.37632 .28224 m .42656 .25301 L .42864 .24699 L p
1 g
F P
s
P
p
.002 w
.37429 .27859 m .33282 .32614 L .33797 .32619 L p
1 g
F P
s
P
p
.002 w
.33797 .32619 m .37632 .28224 L .37429 .27859 L p
1 g
F P
s
P
p
.002 w
.60197 .59927 m .6477 .56103 L .64508 .55742 L p
1 g
F P
s
P
p
.002 w
.64508 .55742 m .59771 .59703 L .60197 .59927 L p
1 g
F P
s
P
p
.002 w
.67863 .5057 m .64508 .55742 L .6477 .56103 L p
1 g
F P
s
P
p
.002 w
.32556 .52232 m .36252 .5717 L .35803 .56121 L p
1 g
F P
s
P
p
.002 w
.35803 .56121 m .32177 .51271 L .32556 .52232 L p
1 g
F P
s
P
p
.002 w
.54725 .62216 m .60197 .59927 L .59771 .59703 L p
1 g
F P
s
P
p
.002 w
.59771 .59703 m .54099 .62072 L .54725 .62216 L p
1 g
F P
s
P
p
.002 w
.42864 .24699 m .37429 .27859 L .37632 .28224 L p
1 g
F P
s
P
p
.002 w
.61276 .2713 m .55874 .24234 L .54868 .24361 L p
1 g
F P
s
P
p
.002 w
.4892 .235 m .54868 .24361 L .55874 .24234 L p
1 g
F P
s
P
p
.002 w
.69497 .44676 m .69211 .38622 L .68594 .37808 L p
1 g
F P
s
P
p
.002 w
.66331 .32158 m .68594 .37808 L .69211 .38622 L p
1 g
F P
s
P
p
.002 w
.6477 .56103 m .68009 .51112 L .67863 .5057 L p
1 g
F P
s
P
p
.002 w
.69497 .44676 m .67863 .5057 L .68009 .51112 L p
1 g
F P
s
P
p
.002 w
.30733 .38958 m .30395 .45332 L .30595 .44457 L p
1 g
F P
s
P
p
.002 w
.30595 .44457 m .30919 .38381 L .30733 .38958 L p
1 g
F P
s
P
p
.002 w
.48875 .6272 m .54725 .62216 L .54099 .62072 L p
1 g
F P
s
P
p
.002 w
.54099 .62072 m .48031 .62594 L .48875 .6272 L p
1 g
F P
s
P
p
.002 w
.37106 .57866 m .42161 .61166 L .41353 .60503 L p
1 g
F P
s
P
p
.002 w
.41353 .60503 m .36252 .5717 L .37106 .57866 L p
1 g
F P
s
P
p
.002 w
.66331 .32158 m .6226 .27582 L .61276 .2713 L p
1 g
F P
s
P
p
.002 w
.55874 .24234 m .61276 .2713 L .6226 .27582 L p
1 g
F P
s
P
p
.002 w
.68009 .51112 m .69587 .45428 L .69497 .44676 L p
1 g
F P
s
P
p
.002 w
.69211 .38622 m .69497 .44676 L .69587 .45428 L p
1 g
F P
s
P
p
.002 w
.55874 .24234 m .49639 .23328 L .4892 .235 L p
1 g
F P
s
P
p
.002 w
.42864 .24699 m .4892 .235 L .49639 .23328 L p
1 g
F P
s
P
p
.002 w
.3074 .4618 m .32556 .52232 L .32177 .51271 L p
1 g
F P
s
P
p
.002 w
.32177 .51271 m .30395 .45332 L .3074 .4618 L p
1 g
F P
s
P
p
.002 w
.69211 .38622 m .66971 .33023 L .66331 .32158 L p
1 g
F P
s
P
p
.002 w
.6226 .27582 m .66331 .32158 L .66971 .33023 L p
1 g
F P
s
P
p
.002 w
.43224 .61344 m .48875 .6272 L .48031 .62594 L p
1 g
F P
s
P
p
.002 w
.48031 .62594 m .42161 .61166 L .43224 .61344 L p
1 g
F P
s
P
p
.002 w
.33214 .32902 m .30733 .38958 L .30919 .38381 L p
1 g
F P
s
P
p
.002 w
.30919 .38381 m .33282 .32614 L .33214 .32902 L p
1 g
F P
s
P
p
.002 w
.49639 .23328 m .43282 .24586 L .42864 .24699 L p
1 g
F P
s
P
p
.002 w
.37429 .27859 m .42864 .24699 L .43282 .24586 L p
1 g
F P
s
P
p
.002 w
.33448 .52973 m .37106 .57866 L .36252 .5717 L p
1 g
F P
s
P
p
.002 w
.36252 .5717 m .32556 .52232 L .33448 .52973 L p
1 g
F P
s
P
p
.002 w
.37573 .27906 m .33214 .32902 L .33282 .32614 L p
1 g
F P
s
P
p
.002 w
.33282 .32614 m .37429 .27859 L .37573 .27906 L p
1 g
F P
s
P
p
.002 w
.60355 .59686 m .64628 .56112 L .6477 .56103 L p
1 g
F P
s
P
p
.002 w
.6477 .56103 m .60197 .59927 L .60355 .59686 L p
1 g
F P
s
P
p
.002 w
.68009 .51112 m .6477 .56103 L .64628 .56112 L p
1 g
F P
s
P
p
.002 w
.6226 .27582 m .56758 .2463 L .55874 .24234 L p
1 g
F P
s
P
p
.002 w
.49639 .23328 m .55874 .24234 L .56758 .2463 L p
1 g
F P
s
P
p
.002 w
.69587 .45428 m .69312 .39596 L .69211 .38622 L p
1 g
F P
s
P
p
.002 w
.66971 .33023 m .69211 .38622 L .69312 .39596 L p
1 g
F P
s
P
p
.002 w
.55245 .61822 m .60355 .59686 L .60197 .59927 L p
1 g
F P
s
P
p
.002 w
.60197 .59927 m .54725 .62216 L .55245 .61822 L p
1 g
F P
s
P
p
.002 w
.43282 .24586 m .37573 .27906 L .37429 .27859 L p
1 g
F P
s
P
p
.002 w
.64628 .56112 m .67653 .5145 L .68009 .51112 L p
1 g
F P
s
P
p
.002 w
.69587 .45428 m .68009 .51112 L .67653 .5145 L p
1 g
F P
s
P
p
.002 w
.3109 .39678 m .3074 .4618 L .30395 .45332 L p
1 g
F P
s
P
p
.002 w
.30395 .45332 m .30733 .38958 L .3109 .39678 L p
1 g
F P
s
P
p
.002 w
.49789 .6229 m .55245 .61822 L .54725 .62216 L p
1 g
F P
s
P
p
.002 w
.54725 .62216 m .48875 .6272 L .49789 .6229 L p
1 g
F P
s
P
p
.002 w
.38366 .58165 m .43224 .61344 L .42161 .61166 L p
1 g
F P
s
P
p
.002 w
.42161 .61166 m .37106 .57866 L .38366 .58165 L p
1 g
F P
s
P
p
.002 w
.66971 .33023 m .62938 .28491 L .6226 .27582 L p
1 g
F P
s
P
p
.002 w
.56758 .2463 m .6226 .27582 L .62938 .28491 L p
1 g
F P
s
P
p
.002 w
.67653 .5145 m .69124 .46145 L .69587 .45428 L p
1 g
F P
s
P
p
.002 w
.69312 .39596 m .69587 .45428 L .69124 .46145 L p
1 g
F P
s
P
p
.002 w
.56758 .2463 m .50399 .2371 L .49639 .23328 L p
1 g
F P
s
P
p
.002 w
.43282 .24586 m .49639 .23328 L .50399 .2371 L p
1 g
F P
s
P
p
.002 w
.31658 .46974 m .33448 .52973 L .32556 .52232 L p
1 g
F P
s
P
p
.002 w
.32556 .52232 m .3074 .4618 L .31658 .46974 L p
1 g
F P
s
P
p
.002 w
.69312 .39596 m .67154 .3421 L .66971 .33023 L p
1 g
F P
s
P
p
.002 w
.62938 .28491 m .66971 .33023 L .67154 .3421 L p
1 g
F P
s
P
p
.002 w
.44528 .61002 m .49789 .6229 L .48875 .6272 L p
1 g
F P
s
P
p
.002 w
.48875 .6272 m .43224 .61344 L .44528 .61002 L p
1 g
F P
s
P
p
.002 w
.33627 .33495 m .3109 .39678 L .30733 .38958 L p
1 g
F P
s
P
p
.002 w
.30733 .38958 m .33214 .32902 L .33627 .33495 L p
1 g
F P
s
P
p
.002 w
.50399 .2371 m .43911 .24998 L .43282 .24586 L p
1 g
F P
s
P
p
.002 w
.37573 .27906 m .43282 .24586 L .43911 .24998 L p
1 g
F P
s
P
p
.002 w
.34859 .53455 m .38366 .58165 L .37106 .57866 L p
1 g
F P
s
P
p
.002 w
.37106 .57866 m .33448 .52973 L .34859 .53455 L p
1 g
F P
s
P
p
.002 w
.62938 .28491 m .57485 .25573 L .56758 .2463 L p
1 g
F P
s
P
p
.002 w
.50399 .2371 m .56758 .2463 L .57485 .25573 L p
1 g
F P
s
P
p
.002 w
.69124 .46145 m .68863 .40711 L .69312 .39596 L p
1 g
F P
s
P
p
.002 w
.67154 .3421 m .69312 .39596 L .68863 .40711 L p
1 g
F P
s
P
p
.002 w
.3808 .28392 m .33627 .33495 L .33214 .32902 L p
1 g
F P
s
P
p
.002 w
.33214 .32902 m .37573 .27906 L .3808 .28392 L p
1 g
F P
s
P
p
.002 w
.60222 .58954 m .64058 .55746 L .64628 .56112 L p
1 g
F P
s
P
p
.002 w
.64628 .56112 m .60355 .59686 L .60222 .58954 L p
1 g
F P
s
P
p
.002 w
.67653 .5145 m .64628 .56112 L .64058 .55746 L p
1 g
F P
s
P
p
.002 w
.55635 .60868 m .60222 .58954 L .60355 .59686 L p
1 g
F P
s
P
p
.002 w
.60355 .59686 m .55245 .61822 L .55635 .60868 L p
1 g
F P
s
P
p
.002 w
.43911 .24998 m .3808 .28392 L .37573 .27906 L p
1 g
F P
s
P
p
.002 w
.64058 .55746 m .66772 .51561 L .67653 .5145 L p
1 g
F P
s
P
p
.002 w
.69124 .46145 m .67653 .5145 L .66772 .51561 L p
1 g
F P
s
P
p
.002 w
.32014 .40527 m .31658 .46974 L .3074 .4618 L p
1 g
F P
s
P
p
.002 w
.3074 .4618 m .3109 .39678 L .32014 .40527 L p
1 g
F P
s
P
p
.002 w
.40017 .58035 m .44528 .61002 L .43224 .61344 L p
1 g
F P
s
P
p
.002 w
.43224 .61344 m .38366 .58165 L .40017 .58035 L p
1 g
F P
s
P
p
.002 w
.50746 .6128 m .55635 .60868 L .55245 .61822 L p
1 g
F P
s
P
p
.002 w
.55245 .61822 m .49789 .6229 L .50746 .6128 L p
1 g
F P
s
P
p
.002 w
.67154 .3421 m .6327 .29859 L .62938 .28491 L p
1 g
F P
s
P
p
.002 w
.57485 .25573 m .62938 .28491 L .6327 .29859 L p
1 g
F P
s
P
p
.002 w
.66772 .51561 m .68086 .46802 L .69124 .46145 L p
1 g
F P
s
P
p
.002 w
.68863 .40711 m .69124 .46145 L .68086 .46802 L p
1 g
F P
s
P
p
.002 w
.57485 .25573 m .5118 .2467 L .50399 .2371 L p
1 g
F P
s
P
p
.002 w
.43911 .24998 m .50399 .2371 L .5118 .2467 L p
1 g
F P
s
P
p
.002 w
.68863 .40711 m .66846 .35703 L .67154 .3421 L p
1 g
F P
s
P
p
.002 w
.6327 .29859 m .67154 .3421 L .66846 .35703 L p
1 g
F P
s
P
p
.002 w
.33152 .47684 m .34859 .53455 L .33448 .52973 L p
1 g
F P
s
P
p
.002 w
.33448 .52973 m .31658 .46974 L .33152 .47684 L p
1 g
F P
s
P
p
.002 w
.46044 .60117 m .50746 .6128 L .49789 .6229 L p
1 g
F P
s
P
p
.002 w
.49789 .6229 m .44528 .61002 L .46044 .60117 L p
1 g
F P
s
P
p
.002 w
.34538 .34394 m .32014 .40527 L .3109 .39678 L p
1 g
F P
s
P
p
.002 w
.3109 .39678 m .33627 .33495 L .34538 .34394 L p
1 g
F P
s
P
p
.002 w
.36773 .53648 m .40017 .58035 L .38366 .58165 L p
1 g
F P
s
P
p
.002 w
.38366 .58165 m .34859 .53455 L .36773 .53648 L p
1 g
F P
s
P
p
.002 w
.5118 .2467 m .44746 .25957 L .43911 .24998 L p
1 g
F P
s
P
p
.002 w
.3808 .28392 m .43911 .24998 L .44746 .25957 L p
1 g
F P
s
P
p
.002 w
.6327 .29859 m .58022 .27067 L .57485 .25573 L p
1 g
F P
s
P
p
.002 w
.5118 .2467 m .57485 .25573 L .58022 .27067 L p
1 g
F P
s
P
p
.002 w
.68086 .46802 m .67843 .41939 L .68863 .40711 L p
1 g
F P
s
P
p
.002 w
.66846 .35703 m .68863 .40711 L .67843 .41939 L p
1 g
F P
s
P
p
.002 w
.3896 .29329 m .34538 .34394 L .33627 .33495 L p
1 g
F P
s
P
p
.002 w
.33627 .33495 m .3808 .28392 L .3896 .29329 L p
1 g
F P
s
P
p
.002 w
.59782 .57724 m .63051 .54992 L .64058 .55746 L p
1 g
F P
s
P
p
.002 w
.64058 .55746 m .60222 .58954 L .59782 .57724 L p
1 g
F P
s
P
p
.002 w
.66772 .51561 m .64058 .55746 L .63051 .54992 L p
1 g
F P
s
P
p
.002 w
.55876 .59349 m .59782 .57724 L .60222 .58954 L p
1 g
F P
s
P
p
.002 w
.60222 .58954 m .55635 .60868 L .55876 .59349 L p
1 g
F P
s
P
p
.002 w
.44746 .25957 m .3896 .29329 L .3808 .28392 L p
1 g
F P
s
P
p
.002 w
.63051 .54992 m .6536 .51425 L .66772 .51561 L p
1 g
F P
s
P
p
.002 w
.68086 .46802 m .66772 .51561 L .6536 .51425 L p
1 g
F P
s
P
p
.002 w
.42027 .57453 m .46044 .60117 L .44528 .61002 L p
1 g
F P
s
P
p
.002 w
.44528 .61002 m .40017 .58035 L .42027 .57453 L p
1 g
F P
s
P
p
.002 w
.3351 .41484 m .33152 .47684 L .31658 .46974 L p
1 g
F P
s
P
p
.002 w
.31658 .46974 m .32014 .40527 L .3351 .41484 L p
1 g
F P
s
P
p
.002 w
.66846 .35703 m .63225 .3167 L .6327 .29859 L p
1 g
F P
s
P
p
.002 w
.58022 .27067 m .6327 .29859 L .63225 .3167 L p
1 g
F P
s
P
p
.002 w
.51719 .5969 m .55876 .59349 L .55635 .60868 L p
1 g
F P
s
P
p
.002 w
.55635 .60868 m .50746 .6128 L .51719 .5969 L p
1 g
F P
s
P
p
.002 w
.6536 .51425 m .66471 .47375 L .68086 .46802 L p
1 g
F P
s
P
p
.002 w
.67843 .41939 m .68086 .46802 L .66471 .47375 L p
1 g
F P
s
P
p
.002 w
.58022 .27067 m .51957 .26214 L .5118 .2467 L p
1 g
F P
s
P
p
.002 w
.44746 .25957 m .5118 .2467 L .51957 .26214 L p
1 g
F P
s
P
p
.002 w
.67843 .41939 m .66026 .37471 L .66846 .35703 L p
1 g
F P
s
P
p
.002 w
.63225 .3167 m .66846 .35703 L .66026 .37471 L p
1 g
F P
s
P
p
.002 w
.35208 .48281 m .36773 .53648 L .34859 .53455 L p
1 g
F P
s
P
p
.002 w
.34859 .53455 m .33152 .47684 L .35208 .48281 L p
1 g
F P
s
P
p
.002 w
.47734 .58688 m .51719 .5969 L .50746 .6128 L p
1 g
F P
s
P
p
.002 w
.50746 .6128 m .46044 .60117 L .47734 .58688 L p
1 g
F P
s
P
p
.002 w
.35948 .35587 m .3351 .41484 L .32014 .40527 L p
1 g
F P
s
P
p
.002 w
.32014 .40527 m .34538 .34394 L .35948 .35587 L p
1 g
F P
s
P
p
.002 w
.39153 .53528 m .42027 .57453 L .40017 .58035 L p
1 g
F P
s
P
p
.002 w
.40017 .58035 m .36773 .53648 L .39153 .53528 L p
1 g
F P
s
P
p
.002 w
.63225 .3167 m .5834 .29093 L .58022 .27067 L p
1 g
F P
s
P
p
.002 w
.51957 .26214 m .58022 .27067 L .5834 .29093 L p
1 g
F P
s
P
p
.002 w
.51957 .26214 m .4577 .27464 L .44746 .25957 L p
1 g
F P
s
P
p
.002 w
.3896 .29329 m .44746 .25957 L .4577 .27464 L p
1 g
F P
s
P
p
.002 w
.66471 .47375 m .66252 .43247 L .67843 .41939 L p
1 g
F P
s
P
p
.002 w
.66026 .37471 m .67843 .41939 L .66252 .43247 L p
1 g
F P
s
P
p
.002 w
.40206 .30715 m .35948 .35587 L .34538 .34394 L p
1 g
F P
s
P
p
.002 w
.34538 .34394 m .3896 .29329 L .40206 .30715 L p
1 g
F P
s
P
p
.004 w
.33547 .31525 m
.34827 .32422 L
s
P
p
.002 w
.59032 .56006 m .61614 .5385 L .63051 .54992 L p
1 g
F P
s
P
p
.002 w
.63051 .54992 m .59782 .57724 L .59032 .56006 L p
1 g
F P
s
P
p
.002 w
.6536 .51425 m .63051 .54992 L .61614 .5385 L p
1 g
F P
s
P
p
.002 w
.55949 .57283 m .59032 .56006 L .59782 .57724 L p
1 g
F P
s
P
p
.002 w
.59782 .57724 m .55876 .59349 L .55949 .57283 L p
1 g
F P
s
P
p
.002 w
.4577 .27464 m .40206 .30715 L .3896 .29329 L p
1 g
F P
s
P
p
.002 w
.47734 .58688 m .46044 .60117 L p
.44415 .56568 L 1 g
F P
s
P
p
.002 w
.44787 .56713 m .47734 .58688 L p
.44415 .56568 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.51719 .5969 m .48333 .58046 L .48606 .58042 L 1 g
F
P
p
.002 w
.5109 .58014 m .51079 .57862 L p
.50272 .58023 L 1 g
F P
s
P
p
.002 w
.48908 .58039 m .48921 .57862 L p
.47938 .57781 L 1 g
F P
s
P
p
.002 w
.48425 .57946 m .47734 .58688 L p
.475 .57633 L 1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47734 .58688 m .44787 .56713 L p
.46841 .57409 L 1 g
F P
s
P
p
.47548 .5785 m .46841 .57409 L .475 .57633 L 1 g
F
P
p
.47734 .58688 m .46841 .57409 L .47548 .5785 L 1 g
F
P
p
.002 w
.46841 .57409 m .46872 .57265 L p
.4614 .56973 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46841 .57409 L p
1 g
F P
s
P
p
.002 w
.46841 .57409 m .4678 .57686 L p
.47938 .57781 L 1 g
F P
s
P
p
.48921 .57862 m .46841 .57409 L .47938 .57781 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45078 .56311 L p
1 g
F P
s
P
p
.002 w
.44345 .56417 m .44814 .56146 L p
.45078 .56311 L 1 g
F P
s
P
p
.46712 .57329 m .45641 .56916 L .45078 .56311 L 1 g
F
P
p
.45641 .56916 m .44345 .56417 L .45078 .56311 L 1 g
F
P
p
.002 w
.45078 .56311 m .45146 .56129 L p
.44501 .55568 L 1 g
F P
s
P
p
.002 w
.44886 .56105 m .44345 .56417 L p
.4449 .55554 L 1 g
F P
s
P
p
.002 w
.44345 .56417 m .41935 .53085 L .42599 .52922 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.44345 .56417 m .42599 .52922 L .43864 .54682 L 1 g
F
P
p
.44379 .56218 m .43864 .54682 L .4449 .55554 L 1 g
F
P
p
.44345 .56417 m .43864 .54682 L .44379 .56218 L 1 g
F
P
p
.002 w
.43864 .54682 m .43925 .54566 L p
.43628 .53978 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43864 .54682 L p
1 g
F P
s
P
p
.002 w
.43864 .54682 m .43743 .5491 L p
.44501 .55568 L 1 g
F P
s
P
p
.45146 .56129 m .43864 .54682 L .44501 .55568 L 1 g
F
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43255 .52866 L p
1 g
F P
s
P
p
.002 w
.42599 .52922 m .43222 .52768 L p
.43255 .52866 L 1 g
F P
s
P
p
.43864 .54682 m .43231 .53801 L .43255 .52866 L 1 g
F
P
p
.43231 .53801 m .42599 .52922 L .43255 .52866 L 1 g
F
P
p
.002 w
.43255 .52866 m .43346 .52734 L p
.43321 .52027 L 1 g
F P
s
P
p
.41935 .53085 m .43463 .50394 L .43419 .50905 L 1 g
F
P
p
.002 w
.43258 .5276 m .42459 .52956 L p
.43419 .50905 L 1 g
F P
s
P
p
.002 w
.42459 .52956 m .41935 .53085 L p
.43419 .50905 L 1 g
F P
s
P
p
.43321 .52027 m .43258 .5276 L .43255 .52866 L 1 g
F
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44238 .49158 L p
1 g
F P
s
P
p
.002 w
.44168 .49151 m .44241 .4915 L p
.44238 .49158 L 1 g
F P
s
P
p
.002 w
.44194 .49247 m .44184 .49209 L p
.44238 .49158 L 1 g
F P
s
P
p
.002 w
.44184 .49209 m .44168 .49151 L p
.44238 .49158 L 1 g
F P
s
P
p
.43485 .50826 m .44238 .49158 L .44214 .49206 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.44238 .49158 m .44339 .4905 L p
.45001 .48416 L 1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.44384 .49016 m .47951 .46769 L .44246 .4915 L 1 g
F
P
p
.45001 .48416 m .44246 .4915 L .44238 .49158 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.44168 .49151 m .44422 .45777 L .46977 .46495 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.44384 .49016 m .45777 .47662 L .47951 .46769 L 1 g
F
P
p
.45777 .47662 m .47748 .4673 L .47951 .46769 L 1 g
F
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56625 .50957 L p
1 g
F P
s
P
p
.002 w
.5558 .48798 m .57572 .50495 L .57344 .50685 L p
1 g
F P
s
P
p
.002 w
.57344 .50685 m .56738 .51191 L p
.56625 .50957 L 1 g
F P
s
P
p
.55661 .4905 m .56625 .50957 L .56213 .50107 L 1 g
F
P
p
.56503 .49872 m .56625 .50957 L .55745 .49139 L 1 g
F
P
p
.57344 .50685 m .56625 .50957 L .56503 .49872 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55745 .49139 L p
1 g
F P
s
P
p
.54174 .47608 m .55745 .49139 L .55351 .48758 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56742 .52862 L p
1 g
F P
s
P
p
.002 w
.5666 .51279 m .57981 .53833 L p
.56736 .52745 L 1 g
F P
s
P
p
.56515 .50826 m .56742 .52862 L .56698 .52013 L 1 g
F
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54911 .56282 L p
1 g
F P
s
P
p
.56075 .54566 m .54911 .56282 L .5526 .55871 L 1 g
F
P
p
.002 w
.55861 .55164 m .55949 .57283 L p
.54934 .56255 L 1 g
F P
s
P
p
.002 w
.55949 .57283 m .53924 .57442 L p
.54911 .56282 L 1 g
F P
s
P
p
.5494 .56261 m .54911 .56282 L .54934 .56255 L 1 g
F
P
p
.55949 .57283 m .54911 .56282 L .5494 .56261 L 1 g
F
P
p
.002 w
.54911 .56282 m .54854 .56129 L p
.54101 .56847 L 1 g
F P
s
P
p
.002 w
.53177 .57491 m .53128 .57265 L p
.5216 .57784 L 1 g
F P
s
P
p
.5216 .57784 m .52602 .57689 L .53177 .57491 L 1 g
F
P
p
.002 w
.5261 .57687 m .51719 .5969 L p
.50569 .58126 L 1 g
F P
s
P
p
.51865 .57942 m .53147 .57504 L .53177 .57491 L 1 g
F
P
p
.002 w
.51111 .583 m .51302 .58244 L p
.53128 .57265 L 1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.49548 .56739 m .52675 .57541 L .5261 .57687 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58039 L p
1 g
F P
s
P
p
.51079 .57862 m .48908 .58039 L .50272 .58023 L 1 g
F
P
p
.47938 .57781 m .48425 .57946 L .48908 .58039 L 1 g
F
P
p
.002 w
.48425 .57946 m .49548 .56739 L p
.50491 .58021 L 1 g
F P
s
P
p
.50767 .58396 m .48908 .58039 L .50491 .58021 L 1 g
F
P
p
.48908 .58039 m .48425 .57946 L .50491 .58021 L 1 g
F
P
p
.51719 .5969 m .48425 .57946 L .50767 .58396 L 1 g
F
P
p
.002 w
.48908 .58039 m .48889 .583 L p
.50272 .58023 L 1 g
F P
s
P
p
.5109 .58014 m .49548 .56739 L .5261 .57687 L 1 g
F
P
p
.50569 .58126 m .50491 .58021 L .5109 .58014 L 1 g
F
P
p
.50491 .58021 m .49548 .56739 L .5109 .58014 L 1 g
F
P
p
.5216 .57784 m .51865 .57942 L .52602 .57689 L 1 g
F
P
p
.002 w
.55949 .57283 m .55876 .59349 L p
.52887 .57661 L 1 g
F P
s
P
p
.52887 .57661 m .52812 .57618 L .52995 .57599 L 1 g
F
P
p
.52887 .57661 m .52995 .57599 L .55949 .57283 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53177 .57491 L p
1 g
F P
s
P
p
.54854 .56129 m .53177 .57491 L .53195 .57479 L 1 g
F
P
p
.54248 .57061 m .53441 .57307 L .54911 .56282 L 1 g
F
P
p
.53161 .57502 m .53177 .57491 L .54248 .57061 L 1 g
F
P
p
.54854 .56129 m .53195 .57479 L .54101 .56847 L 1 g
F
P
p
.002 w
.53147 .57504 m .52675 .57541 L p
.54248 .57061 L 1 g
F P
s
P
p
.54101 .56847 m .53178 .57493 L .53802 .57132 L 1 g
F
P
p
.53195 .57479 m .53178 .57493 L .54101 .56847 L 1 g
F
P
p
.002 w
.53924 .57442 m .53161 .57502 L p
.54248 .57061 L 1 g
F P
s
P
p
.002 w
.53161 .57502 m .53147 .57504 L p
.53177 .57491 L 1 g
F P
s
P
p
.54911 .56282 m .52675 .57541 L .54934 .56255 L 1 g
F
P
p
.53441 .57307 m .52675 .57541 L .54911 .56282 L 1 g
F
P
p
.002 w
.53177 .57491 m .53178 .57493 L p
.53195 .57479 L 1 g
F P
s
P
p
.002 w
.53147 .57504 m .55949 .57283 L p
.52812 .57618 L 1 g
F P
s
P
p
.002 w
.53178 .57493 m .5322 .57686 L p
.53802 .57132 L 1 g
F P
s
P
p
.002 w
.55876 .59349 m .51719 .5969 L .5261 .57687 L p
1 g
F P
s
P
p
.002 w
.5261 .57687 m .52675 .57541 L p
.52812 .57618 L 1 g
F P
s
P
p
.55876 .59349 m .5261 .57687 L .52812 .57618 L 1 g
F
P
p
.002 w
.51302 .58244 m .5322 .57686 L .53178 .57493 L p
1 g
F P
s
P
p
.002 w
.53178 .57493 m .53177 .57491 L p
.53147 .57504 L 1 g
F P
s
P
p
.53147 .57504 m .51302 .58244 L .53178 .57493 L 1 g
F
P
p
.51865 .57942 m .51302 .58244 L .53147 .57504 L 1 g
F
P
p
.002 w
.52675 .57541 m .53147 .57504 L p
.52812 .57618 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54911 .56282 L p
1 g
F P
s
P
p
.54101 .56847 m .5322 .57686 L .54911 .56282 L 1 g
F
P
p
.55532 .55551 m .54945 .56375 L .55433 .55729 L 1 g
F
P
p
.56075 .54566 m .5526 .55871 L .55532 .55551 L 1 g
F
P
p
.5526 .55871 m .54945 .56375 L .55532 .55551 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.52675 .57541 m .53578 .54882 L p
.54934 .56255 L 1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.57981 .53833 m .59032 .56006 L p
.56141 .54834 L 1 g
F P
s
P
p
.56141 .54834 m .56118 .54824 L .56152 .54806 L 1 g
F
P
p
.56141 .54834 m .56152 .54806 L .57981 .53833 L 1 g
F
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56173 .54751 L p
1 g
F P
s
P
p
.56654 .52734 m .56173 .54751 L .56252 .54544 L 1 g
F
P
p
.56654 .52734 m .56252 .54544 L .56443 .53889 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.57981 .53833 m .56252 .54544 L p
.56768 .52773 L 1 g
F P
s
P
p
.002 w
.56364 .54498 m .57981 .53833 L p
.56118 .54824 L 1 g
F P
s
P
p
.002 w
.56173 .54751 m .56075 .54566 L p
.55433 .55729 L 1 g
F P
s
P
p
.002 w
.59032 .56006 m .55949 .57283 L .55843 .54713 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56173 .54751 L p
1 g
F P
s
P
p
.55433 .55729 m .54998 .56518 L .56173 .54751 L 1 g
F
P
p
.002 w
.55843 .54713 m .56252 .54544 L p
.56118 .54824 L 1 g
F P
s
P
p
.002 w
.56252 .54544 m .56364 .54498 L p
.56173 .54751 L 1 g
F P
s
P
p
.56118 .54824 m .56252 .54544 L .56173 .54751 L 1 g
F
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56842 .53008 L p
1 g
F P
s
P
p
.002 w
.56842 .53008 m .56654 .52734 L p
.56388 .54191 L 1 g
F P
s
P
p
.56388 .54191 m .56257 .5491 L .56842 .53008 L 1 g
F
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.55843 .54713 m .55553 .51711 L p
.56768 .52773 L 1 g
F P
s
P
p
.002 w
.56252 .54544 m .55843 .54713 L p
.56768 .52773 L 1 g
F P
s
P
p
.56443 .53889 m .56252 .54544 L .56388 .54191 L 1 g
F
P
p
.002 w
.56173 .54751 m .56257 .5491 L p
.56388 .54191 L 1 g
F P
s
P
p
.002 w
.53578 .54882 m .55843 .54713 L .55861 .55164 L p
1 g
F P
s
P
p
.54934 .56255 m .53578 .54882 L .55861 .55164 L 1 g
F
P
p
.002 w
.54911 .56282 m .54945 .56375 L p
.5526 .55871 L 1 g
F P
s
P
p
.002 w
.54945 .56375 m .54998 .56518 L p
.55433 .55729 L 1 g
F P
s
P
p
.002 w
.56742 .52862 m .56854 .53025 L p
.56698 .52013 L 1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56848 .52944 L p
.56515 .50826 L 1 g
F P
s
P
p
.002 w
.56625 .50957 m .56515 .50826 L p
.56709 .52056 L 1 g
F P
s
P
p
.002 w
.57572 .50495 m .59771 .52339 L p
.56659 .51265 L 1 g
F P
s
P
p
.002 w
.56659 .51257 m .57572 .50495 L p
.56659 .51265 L 1 g
F P
s
P
p
.56709 .52056 m .56659 .51257 L .56625 .50957 L 1 g
F
P
p
.002 w
.59771 .52339 m .57981 .53833 L .5666 .51279 L p
1 g
F P
s
P
p
.002 w
.5666 .51279 m .56652 .51263 L p
.56659 .51265 L 1 g
F P
s
P
p
.59771 .52339 m .5666 .51279 L .56659 .51265 L 1 g
F
P
p
.002 w
.56738 .51191 m .56659 .51257 L p
.56625 .50957 L 1 g
F P
s
P
p
.002 w
.56848 .52944 m .56713 .51061 L .56641 .50976 L p
1 g
F P
s
P
p
.002 w
.56641 .50976 m .56625 .50957 L p
.56659 .51257 L 1 g
F P
s
P
p
.56659 .51257 m .56848 .52944 L .56641 .50976 L 1 g
F
P
p
.56709 .52056 m .56848 .52944 L .56659 .51257 L 1 g
F
P
p
.002 w
.56652 .51263 m .56659 .51257 L p
.56659 .51265 L 1 g
F P
s
P
p
.56625 .50957 m .56652 .51263 L .5558 .48798 L 1 g
F
P
p
.002 w
.56659 .51257 m .56652 .51263 L p
.56625 .50957 L 1 g
F P
s
P
p
.002 w
.55553 .51711 m .56652 .51263 L .5666 .51279 L p
1 g
F P
s
P
p
.56736 .52745 m .55553 .51711 L .5666 .51279 L 1 g
F
P
p
.002 w
.56713 .51061 m .56848 .52944 L p
.57056 .53318 L 1 g
F P
s
P
p
.002 w
.56848 .52944 m .56854 .53025 L .56858 .53031 L p
1 g
F P
s
P
p
.002 w
.56858 .53031 m .57056 .53318 L p
.56848 .52944 L 1 g
F P
s
P
p
.57344 .50685 m .55745 .49139 L .5558 .48798 L 1 g
F
P
p
.002 w
.55085 .48376 m .5558 .48798 L p
.55716 .49111 L 1 g
F P
s
P
p
.002 w
.56652 .51263 m .55227 .48639 L p
.55716 .49111 L 1 g
F P
s
P
p
.54174 .47608 m .55351 .48758 L .55227 .48639 L 1 g
F
P
p
.002 w
.55227 .48639 m .56652 .51263 L p
.55105 .48521 L 1 g
F P
s
P
p
.55188 .48601 m .55227 .48639 L .55189 .48602 L 1 g
F
P
p
.54174 .47608 m .55227 .48639 L .55188 .48601 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56652 .51263 m .55553 .51711 L .55105 .48521 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.51552 .47647 m .51966 .46693 L p
.54796 .48221 L 1 g
F P
s
P
p
.002 w
.54922 .48343 m .51552 .47647 L p
.54796 .48221 L 1 g
F P
s
P
p
.51966 .46693 m .52252 .46729 L .54749 .48175 L 1 g
F
P
p
.002 w
.52686 .46936 m .54749 .48175 L p
.52252 .46729 L 1 g
F P
s
P
p
.54174 .47608 m .55192 .48605 L .54749 .48175 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55553 .51711 m .54392 .51793 L .55064 .48481 L p
1 g
F P
s
P
p
.002 w
.55105 .48521 m .55553 .51711 L p
.55064 .48481 L 1 g
F P
s
P
p
.002 w
.54392 .51793 m .53293 .51497 L .55039 .48457 L p
1 g
F P
s
P
p
.002 w
.55039 .48457 m .55085 .48376 L .55064 .48481 L p
1 g
F P
s
P
p
.002 w
.55064 .48481 m .54392 .51793 L p
.55039 .48457 L 1 g
F P
s
P
p
.002 w
.53293 .51497 m .52374 .50852 L .55018 .48437 L p
1 g
F P
s
P
p
.002 w
.55018 .48437 m .55085 .48376 L .55039 .48457 L p
1 g
F P
s
P
p
.002 w
.55039 .48457 m .53293 .51497 L p
.55018 .48437 L 1 g
F P
s
P
p
.002 w
.52374 .50852 m .51736 .49926 L .54998 .48417 L p
1 g
F P
s
P
p
.002 w
.54998 .48417 m .55085 .48376 L .55018 .48437 L p
1 g
F P
s
P
p
.002 w
.55018 .48437 m .52374 .50852 L p
.54998 .48417 L 1 g
F P
s
P
p
.55039 .48457 m .55349 .48759 L .55009 .48428 L 1 g
F
P
p
.5505 .48468 m .55061 .48479 L .55039 .48457 L 1 g
F
P
p
.55061 .48479 m .55349 .48759 L .55039 .48457 L 1 g
F
P
p
.55064 .48481 m .55069 .48486 L .5505 .48468 L 1 g
F
P
p
.55069 .48486 m .55349 .48759 L .5505 .48468 L 1 g
F
P
p
.55192 .48605 m .55203 .48616 L .55064 .48481 L 1 g
F
P
p
.55203 .48616 m .55349 .48759 L .55064 .48481 L 1 g
F
P
p
.002 w
.51451 .48817 m .51552 .47647 L .54922 .48343 L p
1 g
F P
s
P
p
.002 w
.54922 .48343 m .55085 .48376 L .5497 .4839 L p
1 g
F P
s
P
p
.002 w
.5497 .4839 m .51451 .48817 L p
.54922 .48343 L 1 g
F P
s
P
p
.002 w
.51736 .49926 m .51451 .48817 L .5497 .4839 L p
1 g
F P
s
P
p
.55192 .48605 m .55029 .48447 L .54749 .48175 L 1 g
F
P
p
.002 w
.5497 .4839 m .55085 .48376 L .54998 .48417 L p
1 g
F P
s
P
p
.002 w
.54998 .48417 m .51736 .49926 L p
.5497 .4839 L 1 g
F P
s
P
p
.55029 .48447 m .55019 .48438 L .54985 .48404 L 1 g
F
P
p
.55029 .48447 m .54985 .48404 L .54749 .48175 L 1 g
F
P
p
.55019 .48438 m .55009 .48428 L .54922 .48343 L 1 g
F
P
p
.55019 .48438 m .54922 .48343 L .54749 .48175 L 1 g
F
P
p
.002 w
.55064 .48481 m .55085 .48376 L .55105 .48521 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54687 .47891 m .55085 .48376 L .54749 .48175 L p
1 g
F P
s
P
p
.002 w
.54749 .48175 m .52686 .46936 L p
.54236 .47676 L 1 g
F P
s
P
p
.002 w
.54236 .47676 m .54174 .47608 L p
.54749 .48175 L 1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.54236 .47676 m .54687 .47891 L .54749 .48175 L 1 g
F
P
p
.002 w
.54237 .47677 m .54236 .47676 L p
.54749 .48175 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54237 .47677 L p
1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52031 .46544 m .52836 .4563 L .54687 .47891 L p
1 g
F P
s
P
p
.002 w
.52252 .46729 m .52214 .46667 L p
.5331 .47235 L 1 g
F P
s
P
p
.52214 .46667 m .54237 .47677 L .5331 .47235 L 1 g
F
P
p
.002 w
.52686 .46936 m .52031 .46544 L p
.54687 .47891 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52252 .4673 L p
1 g
F P
s
P
p
.002 w
.52252 .4673 m .52252 .46729 L p
.5226 .46734 L 1 g
F P
s
P
p
.5226 .46734 m .54302 .47747 L .52252 .4673 L 1 g
F
P
p
.5331 .47235 m .54302 .47747 L .52252 .46729 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52252 .46729 L p
1 g
F P
s
P
p
.002 w
.52031 .46544 m .52365 .46744 L p
.52252 .46729 L 1 g
F P
s
P
p
.5 .4634 m .52252 .46729 L .52085 .46708 L 1 g
F
P
p
.5 .4634 m .52257 .46738 L .51257 .46582 L 1 g
F
P
p
.002 w
.51966 .46693 m .52002 .4661 L p
.52252 .46729 L 1 g
F P
s
P
p
.002 w
.52002 .4661 m .52031 .46544 L p
.52252 .46729 L 1 g
F P
s
P
p
.002 w
.52365 .46744 m .52686 .46936 L p
.52252 .46729 L 1 g
F P
s
P
p
.002 w
.54237 .47677 m .54302 .47747 L p
.5331 .47235 L 1 g
F P
s
P
p
.51966 .46693 m .54749 .48175 L .54796 .48221 L 1 g
F
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54237 .47677 L p
1 g
F P
s
P
p
.55349 .48759 m .55834 .49233 L .54237 .47677 L 1 g
F
P
p
.002 w
.54749 .48175 m .55085 .48376 L p
.54796 .48221 L 1 g
F P
s
P
p
.002 w
.55105 .48521 m .55085 .48376 L .55227 .48639 L p
1 g
F P
s
P
p
.002 w
.55227 .48639 m .55085 .48376 L p
.55716 .49111 L 1 g
F P
s
P
p
.55189 .48602 m .55798 .49195 L .55349 .48759 L 1 g
F
P
p
.55351 .48758 m .55798 .49195 L .55189 .48602 L 1 g
F
P
p
.002 w
.55745 .49139 m .55798 .49195 L p
.55351 .48758 L 1 g
F P
s
P
p
.002 w
.56625 .50957 m .56713 .51061 L p
.56213 .50107 L 1 g
F P
s
P
p
.002 w
.55798 .49195 m .55834 .49233 L p
.55349 .48759 L 1 g
F P
s
P
p
.002 w
.55085 .48376 m .54922 .48343 L p
.54796 .48221 L 1 g
F P
s
P
p
.002 w
.52252 .46729 m .52257 .46738 L p
.52085 .46708 L 1 g
F P
s
P
p
.47951 .46769 m .51215 .46575 L .51279 .46585 L 1 g
F
P
p
.002 w
.51552 .47647 m .47951 .46769 L p
.51279 .46585 L 1 g
F P
s
P
p
.002 w
.52031 .46544 m .51966 .46693 L p
.51279 .46585 L 1 g
F P
s
P
p
.002 w
.51966 .46693 m .51552 .47647 L p
.51279 .46585 L 1 g
F P
s
P
p
.002 w
.47951 .46769 m .4798 .467 L p
.51215 .46575 L 1 g
F P
s
P
p
.002 w
.5 .46385 m .5 .4634 L p
.51257 .46582 L 1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5142 .46163 m .52031 .46544 L p
.4798 .467 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46385 L p
1 g
F P
s
P
p
.51257 .46582 m .52282 .46778 L .5 .46385 L 1 g
F
P
p
.002 w
.52257 .46738 m .52282 .46778 L p
.51257 .46582 L 1 g
F P
s
P
p
.51279 .46585 m .51215 .46575 L .52031 .46544 L 1 g
F
P
p
.002 w
.47748 .4673 m .47786 .46667 L p
.48703 .46587 L 1 g
F P
s
P
p
.48703 .46587 m .47995 .46698 L .47748 .4673 L 1 g
F
P
p
.49106 .46552 m .47794 .46725 L .47748 .4673 L 1 g
F
P
p
.002 w
.5 .46442 m .49456 .46522 L p
.47786 .46667 L 1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.4798 .467 m .4889 .44587 L .5142 .46163 L p
1 g
F P
s
P
p
.48703 .46587 m .49106 .46552 L .47995 .46698 L 1 g
F
P
p
.002 w
.4798 .467 m .47951 .46769 L .47794 .46725 L p
1 g
F P
s
P
p
.49106 .46552 m .49456 .46522 L .47794 .46725 L 1 g
F
P
p
.002 w
.4889 .44587 m .4798 .467 L p
.44422 .45777 L 1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45698 .47747 L p
1 g
F P
s
P
p
.44168 .49151 m .4571 .47693 L .44384 .49016 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47748 .4673 L p
1 g
F P
s
P
p
.45826 .47608 m .47748 .4673 L .47726 .4674 L 1 g
F
P
p
.45826 .47608 m .47747 .46731 L .47017 .47086 L 1 g
F
P
p
.002 w
.45777 .47662 m .45826 .47608 L p
.4672 .47216 L 1 g
F P
s
P
p
.4571 .47693 m .46977 .46495 L .45777 .47662 L 1 g
F
P
p
.4571 .47693 m .45777 .47662 L .44384 .49016 L 1 g
F
P
p
.002 w
.47748 .4673 m .47747 .46731 L p
.47726 .4674 L 1 g
F P
s
P
p
.002 w
.47747 .46731 m .47718 .46778 L p
.47017 .47086 L 1 g
F P
s
P
p
.002 w
.47794 .46725 m .47773 .46719 L p
.4798 .467 L 1 g
F P
s
P
p
.002 w
.47773 .46719 m .44422 .45777 L p
.4787 .46672 L 1 g
F P
s
P
p
.4787 .46672 m .4798 .467 L .47773 .46719 L 1 g
F
P
p
.002 w
.47773 .46719 m .47794 .46725 L p
.47748 .4673 L 1 g
F P
s
P
p
.002 w
.47794 .46725 m .47951 .46769 L p
.47748 .4673 L 1 g
F P
s
P
p
.002 w
.49456 .46522 m .47718 .46778 L .47748 .4673 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45777 .47662 L p
1 g
F P
s
P
p
.4672 .47216 m .47718 .46778 L .45777 .47662 L 1 g
F
P
p
.002 w
.46977 .46495 m .47773 .46719 L p
.45777 .47662 L 1 g
F P
s
P
p
.002 w
.47951 .46769 m .47764 .49079 L .44246 .4915 L p
1 g
F P
s
P
p
.43485 .50826 m .44234 .49161 L .43799 .50091 L 1 g
F
P
p
.44194 .49247 m .44238 .49158 L .47764 .49079 L 1 g
F
P
p
.002 w
.44241 .4915 m .44246 .4915 L p
.44238 .49158 L 1 g
F P
s
P
p
.002 w
.44246 .4915 m .47764 .49079 L p
.44238 .49158 L 1 g
F P
s
P
p
.002 w
.44168 .49151 m .44194 .49247 L p
.44086 .49478 L 1 g
F P
s
P
p
.002 w
.43419 .50905 m .43485 .50826 L p
.43799 .50091 L 1 g
F P
s
P
p
.43463 .50394 m .44168 .49151 L .43258 .5276 L 1 g
F
P
p
.002 w
.44234 .49161 m .44166 .49233 L p
.43799 .50091 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44237 .49158 L p
1 g
F P
s
P
p
.002 w
.44237 .49158 m .44238 .49158 L p
.44242 .49154 L 1 g
F P
s
P
p
.44242 .49154 m .45698 .47747 L .44237 .49158 L 1 g
F
P
p
.45001 .48416 m .45268 .48159 L .44246 .4915 L 1 g
F
P
p
.002 w
.44246 .4915 m .44168 .49151 L p
.44384 .49016 L 1 g
F P
s
P
p
.45268 .48159 m .45698 .47747 L .44238 .49158 L 1 g
F
P
p
.002 w
.44238 .49158 m .44234 .49161 L p
.44214 .49206 L 1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.45034 .52322 m .44194 .49247 L p
.47764 .49079 L 1 g
F P
s
P
p
.002 w
.45034 .52322 m .43258 .5276 L p
.44086 .49478 L 1 g
F P
s
P
p
.002 w
.44194 .49247 m .45034 .52322 L p
.44086 .49478 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43419 .50905 L p
1 g
F P
s
P
p
.43799 .50091 m .44166 .49233 L .43419 .50905 L 1 g
F
P
p
.43321 .52027 m .43296 .51305 L .43258 .5276 L 1 g
F
P
p
.43925 .54566 m .43255 .52866 L .43628 .53978 L 1 g
F
P
p
.002 w
.43222 .52768 m .45034 .52322 L p
.43864 .54682 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43255 .52866 L p
1 g
F P
s
P
p
.43296 .51305 m .43287 .51061 L .43255 .52866 L 1 g
F
P
p
.002 w
.43255 .52866 m .43146 .53025 L p
.43628 .53978 L 1 g
F P
s
P
p
.4449 .55554 m .43864 .54682 L .45034 .52322 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43864 .54682 L p
1 g
F P
s
P
p
.43628 .53978 m .43146 .53025 L .43864 .54682 L 1 g
F
P
p
.46872 .57265 m .45078 .56311 L .4614 .56973 L 1 g
F
P
p
.46712 .57329 m .45078 .56311 L .46902 .54942 L 1 g
F
P
p
.002 w
.44814 .56146 m .44886 .56105 L p
.45078 .56311 L 1 g
F P
s
P
p
.44501 .55568 m .44886 .56105 L .45078 .56311 L 1 g
F
P
p
.002 w
.44886 .56105 m .46902 .54942 L p
.45078 .56311 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45063 .56351 L p
1 g
F P
s
P
p
.002 w
.45063 .56351 m .45078 .56311 L p
.44901 .56125 L 1 g
F P
s
P
p
.44901 .56125 m .43743 .5491 L .45063 .56351 L 1 g
F
P
p
.44501 .55568 m .4391 .55055 L .44886 .56105 L 1 g
F
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45034 .52322 m .46902 .54942 L .44886 .56105 L p
1 g
F P
s
P
p
.4449 .55554 m .45034 .52322 L .44886 .56105 L 1 g
F
P
p
.4391 .55055 m .43743 .5491 L .45078 .56311 L 1 g
F
P
p
.002 w
.45078 .56311 m .45002 .56518 L p
.4614 .56973 L 1 g
F P
s
P
p
.475 .57633 m .46712 .57329 L .46902 .54942 L 1 g
F
P
p
.002 w
.44787 .56713 m .44345 .56417 L p
.475 .57633 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46841 .57409 L p
1 g
F P
s
P
p
.4614 .56973 m .45002 .56518 L .46841 .57409 L 1 g
F
P
p
.002 w
.51719 .5969 m .47734 .58688 L .48333 .58046 L p
1 g
F P
s
P
p
.002 w
.48333 .58046 m .48425 .57946 L p
.48606 .58042 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48903 .58108 L p
1 g
F P
s
P
p
.002 w
.48903 .58108 m .48908 .58039 L p
.48498 .57971 L 1 g
F P
s
P
p
.48498 .57971 m .4678 .57686 L .48903 .58108 L 1 g
F
P
p
.47938 .57781 m .47286 .57728 L .48425 .57946 L 1 g
F
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.46902 .54942 m .49548 .56739 L .48425 .57946 L p
1 g
F P
s
P
p
.475 .57633 m .46902 .54942 L .48425 .57946 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .5109 .58014 L p
1 g
F P
s
P
p
.50272 .58023 m .48889 .583 L .5109 .58014 L 1 g
F
P
p
.47286 .57728 m .4678 .57686 L .48908 .58039 L 1 g
F
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48888 .58308 L p
1 g
F P
s
P
p
.002 w
.48888 .58308 m .48889 .583 L p
.48861 .58297 L 1 g
F P
s
P
p
.48861 .58297 m .46687 .58109 L .48888 .58308 L 1 g
F
P
p
.002 w
.44345 .56417 m .44787 .56713 L p
.44415 .56568 L 1 g
F P
s
P
p
.002 w
.46044 .60117 m .42027 .57453 L .44345 .56417 L p
1 g
F P
s
P
p
.002 w
.61614 .5385 m .63433 .51033 L .6536 .51425 L p
1 g
F P
s
P
p
.002 w
.66471 .47375 m .6536 .51425 L .63433 .51033 L p
1 g
F P
s
P
p
.002 w
.35559 .42524 m .35208 .48281 L .33152 .47684 L p
1 g
F P
s
P
p
.002 w
.33152 .47684 m .3351 .41484 L .35559 .42524 L p
1 g
F P
s
P
p
.002 w
.66026 .37471 m .62781 .33887 L .63225 .3167 L p
1 g
F P
s
P
p
.002 w
.5834 .29093 m .63225 .3167 L .62781 .33887 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.63433 .51033 m .643 .47839 L .66471 .47375 L p
1 g
F P
s
P
p
.002 w
.66252 .43247 m .66471 .47375 L .643 .47839 L p
1 g
F P
s
P
p
.002 w
.66252 .43247 m .64696 .39469 L .66026 .37471 L p
1 g
F P
s
P
p
.002 w
.62781 .33887 m .66026 .37471 L .64696 .39469 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.5834 .29093 m .52704 .28321 L .51957 .26214 L p
1 g
F P
s
P
p
.002 w
.4577 .27464 m .51957 .26214 L .52704 .28321 L p
1 g
F P
s
P
p
.002 w
.37781 .4874 m .39153 .53528 L .36773 .53648 L p
1 g
F P
s
P
p
.002 w
.36773 .53648 m .35208 .48281 L .37781 .4874 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.37835 .3705 m .35559 .42524 L .3351 .41484 L p
1 g
F P
s
P
p
.002 w
.3351 .41484 m .35948 .35587 L .37835 .3705 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.52657 .45833 L
s
P
p
.002 w
.41935 .53085 m .44345 .56417 L .42027 .57453 L p
1 g
F P
s
P
p
.002 w
.42027 .57453 m .39153 .53528 L .41935 .53085 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.62781 .33887 m .58416 .31612 L .5834 .29093 L p
1 g
F P
s
P
p
.002 w
.52704 .28321 m .5834 .29093 L .58416 .31612 L p
1 g
F P
s
P
p
.002 w
.643 .47839 m .64115 .44594 L .66252 .43247 L p
1 g
F P
s
P
p
.002 w
.64696 .39469 m .66252 .43247 L .64115 .44594 L p
1 g
F P
s
P
p
.002 w
.52704 .28321 m .4696 .29499 L .4577 .27464 L p
1 g
F P
s
P
p
.002 w
.40206 .30715 m .4577 .27464 L .4696 .29499 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.41793 .32525 m .37835 .3705 L .35948 .35587 L p
1 g
F P
s
P
p
.002 w
.35948 .35587 m .40206 .30715 L .41793 .32525 L p
1 g
F P
s
P
p
.004 w
.34827 .32422 m
.37127 .34033 L
s
P
p
.002 w
.57981 .53833 m .59771 .52339 L .61614 .5385 L p
1 g
F P
s
P
p
.002 w
.61614 .5385 m .59032 .56006 L .57981 .53833 L p
1 g
F P
s
P
p
.002 w
.63433 .51033 m .61614 .5385 L .59771 .52339 L p
1 g
F P
s
P
p
.002 w
.4696 .29499 m .41793 .32525 L .40206 .30715 L p
1 g
F P
s
P
p
.002 w
.64696 .39469 m .61934 .36452 L .62781 .33887 L p
1 g
F P
s
P
p
.002 w
.58416 .31612 m .62781 .33887 L .61934 .36452 L p
1 g
F P
s
P
p
.002 w
.38114 .43613 m .37781 .4874 L .35208 .48281 L p
1 g
F P
s
P
p
.002 w
.35208 .48281 m .35559 .42524 L .38114 .43613 L p
1 g
F P
s
P
p
.002 w
.59771 .52339 m .6103 .50384 L .63433 .51033 L p
1 g
F P
s
P
p
.002 w
.643 .47839 m .63433 .51033 L .6103 .50384 L p
1 g
F P
s
P
p
.002 w
.64115 .44594 m .62877 .41635 L .64696 .39469 L p
1 g
F P
s
P
p
.002 w
.61934 .36452 m .64696 .39469 L .62877 .41635 L p
1 g
F P
s
P
p
.002 w
.408 .49035 m .41935 .53085 L .39153 .53528 L p
1 g
F P
s
P
p
.002 w
.39153 .53528 m .37781 .4874 L .408 .49035 L p
1 g
F P
s
P
p
.002 w
.6103 .50384 m .61623 .48172 L .643 .47839 L p
1 g
F P
s
P
p
.002 w
.64115 .44594 m .643 .47839 L .61623 .48172 L p
1 g
F P
s
P
p
.002 w
.58416 .31612 m .53392 .30947 L .52704 .28321 L p
1 g
F P
s
P
p
.002 w
.4696 .29499 m .52704 .28321 L .53392 .30947 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51424 .54317 m .53578 .54882 L .52675 .57541 L p
1 g
F P
s
P
p
.002 w
.52675 .57541 m .49548 .56739 L .51424 .54317 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40155 .38742 m .38114 .43613 L .35559 .42524 L p
1 g
F P
s
P
p
.002 w
.35559 .42524 m .37835 .3705 L .40155 .38742 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.61934 .36452 m .58236 .34553 L .58416 .31612 L p
1 g
F P
s
P
p
.002 w
.53392 .30947 m .58416 .31612 L .58236 .34553 L p
1 g
F P
s
P
p
.002 w
.61623 .48172 m .61484 .45931 L .64115 .44594 L p
1 g
F P
s
P
p
.002 w
.62877 .41635 m .64115 .44594 L .61484 .45931 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.53392 .30947 m .48279 .32012 L .4696 .29499 L p
1 g
F P
s
P
p
.002 w
.41793 .32525 m .4696 .29499 L .48279 .32012 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.49611 .53067 m .51424 .54317 L .49548 .56739 L p
1 g
F P
s
P
p
.002 w
.49548 .56739 m .46902 .54942 L .49611 .53067 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.62877 .41635 m .60699 .39288 L .61934 .36452 L p
1 g
F P
s
P
p
.002 w
.58236 .34553 m .61934 .36452 L .60699 .39288 L p
1 g
F P
s
P
p
.002 w
.43682 .34714 m .40155 .38742 L .37835 .3705 L p
1 g
F P
s
P
p
.004 w
.41559 .37138 m
.5 .43051 L
s
P
p
.002 w
.37835 .3705 m .41793 .32525 L .43682 .34714 L p
1 g
F P
s
P
p
.004 w
.38508 .35001 m
.39323 .35572 L
s
P
p
.004 w
.39323 .35572 m
.39736 .35861 L
s
P
p
.004 w
.37127 .34033 m
.38508 .35001 L
s
P
p
.004 w
.39736 .35861 m
.39819 .35919 L
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.6103 .50384 m .59771 .52339 L .57572 .50495 L p
1 g
F P
s
P
p
.002 w
.41102 .44711 m .408 .49035 L .37781 .4874 L p
1 g
F P
s
P
p
.002 w
.37781 .4874 m .38114 .43613 L .41102 .44711 L p
1 g
F P
s
P
p
.002 w
.48279 .32012 m .43682 .34714 L .41793 .32525 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.57572 .50495 m .58217 .49491 L .6103 .50384 L p
1 g
F P
s
P
p
.002 w
.61623 .48172 m .6103 .50384 L .58217 .49491 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.54392 .51793 m .55553 .51711 L .55843 .54713 L p
1 g
F P
s
P
p
.002 w
.55843 .54713 m .53578 .54882 L .54392 .51793 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.61484 .45931 m .60618 .43898 L .62877 .41635 L p
1 g
F P
s
P
p
.002 w
.60699 .39288 m .62877 .41635 L .60618 .43898 L p
1 g
F P
s
P
p
.002 w
.41935 .53085 m .408 .49035 L .44168 .49151 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.58217 .49491 m .58517 .48355 L .61623 .48172 L p
1 g
F P
s
P
p
.002 w
.61484 .45931 m .61623 .48172 L .58517 .48355 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.58236 .34553 m .53993 .34014 L .53392 .30947 L p
1 g
F P
s
P
p
.002 w
.48279 .32012 m .53392 .30947 L .53993 .34014 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.53293 .51497 m .54392 .51793 L .53578 .54882 L p
1 g
F P
s
P
p
.002 w
.53578 .54882 m .51424 .54317 L .53293 .51497 L p
1 g
F P
s
P
p
.002 w
.48342 .51257 m .49611 .53067 L .46902 .54942 L p
1 g
F P
s
P
p
.002 w
.46902 .54942 m .45034 .52322 L .48342 .51257 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.42835 .40609 m .41102 .44711 L .38114 .43613 L p
1 g
F P
s
P
p
.002 w
.38114 .43613 m .40155 .38742 L .42835 .40609 L p
1 g
F P
s
P
p
.002 w
.58517 .48355 m .58439 .47209 L .61484 .45931 L p
1 g
F P
s
P
p
.002 w
.60618 .43898 m .61484 .45931 L .58439 .47209 L p
1 g
F P
s
P
p
.002 w
.60699 .39288 m .57797 .37823 L .58236 .34553 L p
1 g
F P
s
P
p
.002 w
.53993 .34014 m .58236 .34553 L .57797 .37823 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.52374 .50852 m .53293 .51497 L .51424 .54317 L p
1 g
F P
s
P
p
.002 w
.51424 .54317 m .49611 .53067 L .52374 .50852 L p
1 g
F P
s
P
p
.002 w
.60618 .43898 m .59108 .42296 L .60699 .39288 L p
1 g
F P
s
P
p
.002 w
.57797 .37823 m .60699 .39288 L .59108 .42296 L p
1 g
F P
s
P
p
.002 w
.53993 .34014 m .49684 .34929 L .48279 .32012 L p
1 g
F P
s
P
p
.002 w
.43682 .34714 m .48279 .32012 L .49684 .34929 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.44422 .45777 m .44168 .49151 L .408 .49035 L p
1 g
F P
s
P
p
.002 w
.408 .49035 m .41102 .44711 L .44422 .45777 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45811 .37214 m .42835 .40609 L .40155 .38742 L p
1 g
F P
s
P
p
.002 w
.40155 .38742 m .43682 .34714 L .45811 .37214 L p
1 g
F P
s
P
p
.002 w
.58439 .47209 m .57989 .46174 L .60618 .43898 L p
1 g
F P
s
P
p
.002 w
.59108 .42296 m .60618 .43898 L .57989 .46174 L p
1 g
F P
s
P
p
.002 w
.58217 .49491 m .57572 .50495 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.47764 .49079 m .48342 .51257 L .45034 .52322 L p
1 g
F P
s
P
p
.002 w
.49684 .34929 m .45811 .37214 L .43682 .34714 L p
1 g
F P
s
P
p
.002 w
.58517 .48355 m .58217 .49491 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.58439 .47209 m .58517 .48355 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.51736 .49926 m .52374 .50852 L .49611 .53067 L p
1 g
F P
s
P
p
.002 w
.49611 .53067 m .48342 .51257 L .51736 .49926 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57797 .37823 m .54481 .37422 L .53993 .34014 L p
1 g
F P
s
P
p
.002 w
.49684 .34929 m .53993 .34014 L .54481 .37422 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57989 .46174 m .58439 .47209 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.59108 .42296 m .57109 .41305 L .57797 .37823 L p
1 g
F P
s
P
p
.002 w
.54481 .37422 m .57797 .37823 L .57109 .41305 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.57989 .46174 m .57213 .45365 L .59108 .42296 L p
1 g
F P
s
P
p
.002 w
.57109 .41305 m .59108 .42296 L .57213 .45365 L p
1 g
F P
s
P
p
.002 w
.45784 .42582 m .44422 .45777 L .41102 .44711 L p
1 g
F P
s
P
p
.002 w
.41102 .44711 m .42835 .40609 L .45784 .42582 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.57213 .45365 m .57989 .46174 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51451 .48817 m .51736 .49926 L .48342 .51257 L p
1 g
F P
s
P
p
.002 w
.48342 .51257 m .47764 .49079 L .51451 .48817 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54481 .37422 m .51122 .3815 L .49684 .34929 L p
1 g
F P
s
P
p
.002 w
.45811 .37214 m .49684 .34929 L .51122 .3815 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.56193 .44869 m .57213 .45365 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.57213 .45365 m .56193 .44869 L .57109 .41305 L p
1 g
F P
s
P
p
.002 w
.48106 .39937 m .45784 .42582 L .42835 .40609 L p
1 g
F P
s
P
p
.002 w
.42835 .40609 m .45811 .37214 L .48106 .39937 L p
1 g
F P
s
P
p
.002 w
.55039 .44745 m .56193 .44869 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.53877 .45008 m .55039 .44745 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.52836 .4563 m .53877 .45008 L .55085 .48376 L closepath p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54835 .41045 m .57109 .41305 L .56193 .44869 L p
1 g
F P
s
P
p
.002 w
.57109 .41305 m .54835 .41045 L .54481 .37422 L p
1 g
F P
s
P
p
.002 w
.51122 .3815 m .54481 .37422 L .54835 .41045 L p
1 g
F P
s
P
p
.002 w
.51122 .3815 m .48106 .39937 L .45811 .37214 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.56193 .44869 m .55039 .44745 L .54835 .41045 L p
1 g
F P
s
P
p
.002 w
.51552 .47647 m .51451 .48817 L .47764 .49079 L p
1 g
F P
s
P
p
.002 w
.47764 .49079 m .47951 .46769 L .51552 .47647 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.004 w
.55085 .48376 m
.55248 .48548 L
s
P
p
.002 w
.44422 .45777 m .45784 .42582 L .4889 .44587 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.55039 .44745 m .53877 .45008 L .52539 .41554 L p
1 g
F P
s
P
p
.002 w
.52539 .41554 m .54835 .41045 L .55039 .44745 L p
1 g
F P
s
P
p
.002 w
.54835 .41045 m .52539 .41554 L .51122 .3815 L p
1 g
F P
s
P
p
.002 w
.48106 .39937 m .51122 .3815 L .52539 .41554 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.53877 .45008 m .52836 .4563 L .50479 .4278 L p
1 g
F P
s
P
p
.002 w
.50479 .4278 m .52539 .41554 L .53877 .45008 L p
1 g
F P
s
P
p
.002 w
.50479 .4278 m .4889 .44587 L .45784 .42582 L p
1 g
F P
s
P
p
.002 w
.45784 .42582 m .48106 .39937 L .50479 .4278 L p
1 g
F P
s
P
p
.002 w
.52836 .4563 m .52031 .46544 L .4889 .44587 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.4889 .44587 m .50479 .4278 L .52836 .4563 L p
1 g
F P
s
P
p
.002 w
.52539 .41554 m .50479 .4278 L .48106 .39937 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.004 w
.55248 .48548 m
.58209 .51649 L
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .33547 .31525 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58209 .51649 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.689147)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.689147)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.49073 .46895 m .52023 .45013 L .50162 .42853 L p
1 g
F P
s
P
p
.002 w
.50162 .42853 m .47878 .44306 L .49073 .46895 L p
1 g
F P
s
P
p
.002 w
.51929 .40808 m .50162 .42853 L .52023 .45013 L p
1 g
F P
s
P
p
.002 w
.47878 .44306 m .50162 .42853 L .48296 .40697 L p
1 g
F P
s
P
p
.002 w
.50162 .42853 m .51929 .40808 L .49501 .39298 L p
1 g
F P
s
P
p
.002 w
.49501 .39298 m .48296 .40697 L .50162 .42853 L p
1 g
F P
s
P
p
.002 w
.45751 .47833 m .49073 .46895 L .47878 .44306 L p
1 g
F P
s
P
p
.002 w
.47878 .44306 m .45307 .4502 L .45751 .47833 L p
1 g
F P
s
P
p
.002 w
.45307 .4502 m .47878 .44306 L .46735 .41688 L p
1 g
F P
s
P
p
.002 w
.48296 .40697 m .46735 .41688 L .47878 .44306 L p
1 g
F P
s
P
p
.002 w
.50299 .49408 m .53847 .47138 L .52023 .45013 L p
1 g
F P
s
P
p
.002 w
.52023 .45013 m .49073 .46895 L .50299 .49408 L p
1 g
F P
s
P
p
.002 w
.54313 .42373 m .52023 .45013 L .53847 .47138 L p
1 g
F P
s
P
p
.002 w
.52023 .45013 m .54313 .42373 L .51929 .40808 L p
1 g
F P
s
P
p
.002 w
.46735 .41688 m .48296 .40697 L .46461 .38585 L p
1 g
F P
s
P
p
.002 w
.48296 .40697 m .49501 .39298 L .47073 .37872 L p
1 g
F P
s
P
p
.002 w
.47073 .37872 m .46461 .38585 L .48296 .40697 L p
1 g
F P
s
P
p
.002 w
.53001 .38375 m .51929 .40808 L .54313 .42373 L p
1 g
F P
s
P
p
.002 w
.51929 .40808 m .53001 .38375 L .50225 .37634 L p
1 g
F P
s
P
p
.002 w
.50225 .37634 m .49501 .39298 L .51929 .40808 L p
1 g
F P
s
P
p
.002 w
.46735 .41688 m .44978 .42168 L .45307 .4502 L p
1 g
F P
s
P
p
.002 w
.44978 .42168 m .46735 .41688 L .45665 .39089 L p
1 g
F P
s
P
p
.002 w
.46461 .38585 m .45665 .39089 L .46735 .41688 L p
1 g
F P
s
P
p
.002 w
.49501 .39298 m .50225 .37634 L .47437 .37024 L p
1 g
F P
s
P
p
.002 w
.47437 .37024 m .47073 .37872 L .49501 .39298 L p
1 g
F P
s
P
p
.002 w
.46303 .50554 m .50299 .49408 L .49073 .46895 L p
1 g
F P
s
P
p
.002 w
.49073 .46895 m .45751 .47833 L .46303 .50554 L p
1 g
F P
s
P
p
.002 w
.53847 .47138 m .56608 .43967 L .54313 .42373 L p
1 g
F P
s
P
p
.002 w
.55713 .39232 m .54313 .42373 L .56608 .43967 L p
1 g
F P
s
P
p
.002 w
.54313 .42373 m .55713 .39232 L .53001 .38375 L p
1 g
F P
s
P
p
.002 w
.4238 .47719 m .45751 .47833 L .45307 .4502 L p
1 g
F P
s
P
p
.002 w
.45307 .4502 m .42705 .44914 L .4238 .47719 L p
1 g
F P
s
P
p
.002 w
.42705 .44914 m .45307 .4502 L .44978 .42168 L p
1 g
F P
s
P
p
.002 w
.44978 .42168 m .43205 .42084 L .42705 .44914 L p
1 g
F P
s
P
p
.002 w
.43205 .42084 m .44978 .42168 L .4477 .39329 L p
1 g
F P
s
P
p
.002 w
.45665 .39089 m .4477 .39329 L .44978 .42168 L p
1 g
F P
s
P
p
.002 w
.50387 .35876 m .50225 .37634 L .53001 .38375 L p
1 g
F P
s
P
p
.002 w
.50225 .37634 m .50387 .35876 L .47513 .3613 L p
1 g
F P
s
P
p
.002 w
.47513 .3613 m .47437 .37024 L .50225 .37634 L p
1 g
F P
s
P
p
.002 w
.53258 .35796 m .53001 .38375 L .55713 .39232 L p
1 g
F P
s
P
p
.002 w
.53001 .38375 m .53258 .35796 L .50387 .35876 L p
1 g
F P
s
P
p
.002 w
.51534 .51799 m .55599 .49191 L .53847 .47138 L p
1 g
F P
s
P
p
.002 w
.53847 .47138 m .50299 .49408 L .51534 .51799 L p
1 g
F P
s
P
p
.002 w
.56608 .43967 m .53847 .47138 L .55599 .49191 L p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .45665 .39089 L .46461 .38585 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .46461 .38585 L .47073 .37872 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .4477 .39329 L .45665 .39089 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .47073 .37872 L .47437 .37024 L closepath p
1 g
F P
s
P
p
.002 w
.46954 .53131 m .51534 .51799 L .50299 .49408 L p
1 g
F P
s
P
p
.002 w
.50299 .49408 m .46303 .50554 L .46954 .53131 L p
1 g
F P
s
P
p
.002 w
.42239 .50443 m .46303 .50554 L .45751 .47833 L p
1 g
F P
s
P
p
.002 w
.45751 .47833 m .4238 .47719 L .42239 .50443 L p
1 g
F P
s
P
p
.002 w
.4477 .39329 m .4387 .3928 L .43205 .42084 L p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .4387 .3928 L .4477 .39329 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .47437 .37024 L .47513 .3613 L closepath p
1 g
F P
s
P
p
.002 w
.55599 .49191 m .58772 .45559 L .56608 .43967 L p
1 g
F P
s
P
p
.002 w
.58312 .40191 m .56608 .43967 L .58772 .45559 L p
1 g
F P
s
P
p
.002 w
.56608 .43967 m .58312 .40191 L .55713 .39232 L p
1 g
F P
s
P
p
.002 w
.40341 .43984 m .42705 .44914 L .43205 .42084 L p
1 g
F P
s
P
p
.002 w
.43205 .42084 m .41602 .41437 L .40341 .43984 L p
1 g
F P
s
P
p
.002 w
.41602 .41437 m .43205 .42084 L .4387 .3928 L p
1 g
F P
s
P
p
.002 w
.5607 .35894 m .55713 .39232 L .58312 .40191 L p
1 g
F P
s
P
p
.002 w
.55713 .39232 m .5607 .35894 L .53258 .35796 L p
1 g
F P
s
P
p
.002 w
.49964 .34207 m .50387 .35876 L .53258 .35796 L p
1 g
F P
s
P
p
.002 w
.50387 .35876 m .49964 .34207 L .47291 .35287 L p
1 g
F P
s
P
p
.002 w
.47291 .35287 m .47513 .3613 L .50387 .35876 L p
1 g
F P
s
P
p
.002 w
.4387 .3928 m .43061 .38945 L .41602 .41437 L p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .43061 .38945 L .4387 .3928 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .47513 .3613 L .47291 .35287 L closepath p
1 g
F P
s
P
p
.002 w
.39304 .46539 m .4238 .47719 L .42705 .44914 L p
1 g
F P
s
P
p
.002 w
.42705 .44914 m .40341 .43984 L .39304 .46539 L p
1 g
F P
s
P
p
.002 w
.52658 .33337 m .53258 .35796 L .5607 .35894 L p
1 g
F P
s
P
p
.002 w
.53258 .35796 m .52658 .33337 L .49964 .34207 L p
1 g
F P
s
P
p
.002 w
.40344 .40288 m .41602 .41437 L .43061 .38945 L p
1 g
F P
s
P
p
.002 w
.43061 .38945 m .4243 .38358 L .40344 .40288 L p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .4243 .38358 L .43061 .38945 L closepath p
1 g
F P
s
P
p
.002 w
.46792 .34585 m .47291 .35287 L .49964 .34207 L p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .47291 .35287 L .46792 .34585 L closepath p
1 g
F P
s
P
p
.002 w
.52754 .54019 m .57246 .5113 L .55599 .49191 L p
1 g
F P
s
P
p
.002 w
.55599 .49191 m .51534 .51799 L .52754 .54019 L p
1 g
F P
s
P
p
.002 w
.58772 .45559 m .55599 .49191 L .57246 .5113 L p
1 g
F P
s
P
p
.002 w
.4229 .53033 m .46954 .53131 L .46303 .50554 L p
1 g
F P
s
P
p
.002 w
.46303 .50554 m .42239 .50443 L .4229 .53033 L p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .42674 .34989 L .42176 .35797 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .42176 .35797 L .4196 .36693 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .4196 .36693 L .42049 .37579 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .42049 .37579 L .4243 .38358 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .46792 .34585 L .46068 .34102 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .46068 .34102 L .45197 .33892 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .45197 .33892 L .44274 .33981 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .44274 .33981 L .434 .34361 L closepath p
1 g
F P
s
P
p
.002 w
.44688 .36555 m .434 .34361 L .42674 .34989 L closepath p
1 g
F P
s
P
p
.002 w
.38472 .4231 m .40341 .43984 L .41602 .41437 L p
1 g
F P
s
P
p
.002 w
.41602 .41437 m .40344 .40288 L .38472 .4231 L p
1 g
F P
s
P
p
.002 w
.58772 .45559 m .60747 .41235 L .58312 .40191 L p
1 g
F P
s
P
p
.002 w
.58771 .3617 m .58312 .40191 L .60747 .41235 L p
1 g
F P
s
P
p
.002 w
.58312 .40191 m .58771 .3617 L .5607 .35894 L p
1 g
F P
s
P
p
.002 w
.48991 .32809 m .49964 .34207 L .52658 .33337 L p
1 g
F P
s
P
p
.002 w
.49964 .34207 m .48991 .32809 L .46792 .34585 L p
1 g
F P
s
P
p
.002 w
.47695 .5551 m .52754 .54019 L .51534 .51799 L p
1 g
F P
s
P
p
.002 w
.51534 .51799 m .46954 .53131 L .47695 .5551 L p
1 g
F P
s
P
p
.002 w
.39573 .38752 m .40344 .40288 L .4243 .38358 L p
1 g
F P
s
P
p
.002 w
.4243 .38358 m .42049 .37579 L .39573 .38752 L p
1 g
F P
s
P
p
.002 w
.38516 .4905 m .42239 .50443 L .4238 .47719 L p
1 g
F P
s
P
p
.002 w
.4238 .47719 m .39304 .46539 L .38516 .4905 L p
1 g
F P
s
P
p
.002 w
.46068 .34102 m .46792 .34585 L .48991 .32809 L p
1 g
F P
s
P
p
.002 w
.57246 .5113 m .60761 .47119 L .58772 .45559 L p
1 g
F P
s
P
p
.002 w
.60747 .41235 m .58772 .45559 L .60761 .47119 L p
1 g
F P
s
P
p
.002 w
.55321 .32697 m .5607 .35894 L .58771 .3617 L p
1 g
F P
s
P
p
.002 w
.5607 .35894 m .55321 .32697 L .52658 .33337 L p
1 g
F P
s
P
p
.002 w
.39383 .36992 m .39573 .38752 L .42049 .37579 L p
1 g
F P
s
P
p
.002 w
.42049 .37579 m .4196 .36693 L .39383 .36992 L p
1 g
F P
s
P
p
.002 w
.36856 .44385 m .39304 .46539 L .40341 .43984 L p
1 g
F P
s
P
p
.002 w
.40341 .43984 m .38472 .4231 L .36856 .44385 L p
1 g
F P
s
P
p
.002 w
.48991 .32809 m .47565 .31837 L .46068 .34102 L p
1 g
F P
s
P
p
.002 w
.45197 .33892 m .46068 .34102 L .47565 .31837 L p
1 g
F P
s
P
p
.002 w
.37314 .40053 m .38472 .4231 L .40344 .40288 L p
1 g
F P
s
P
p
.002 w
.40344 .40288 m .39573 .38752 L .37314 .40053 L p
1 g
F P
s
P
p
.002 w
.51245 .31263 m .52658 .33337 L .55321 .32697 L p
1 g
F P
s
P
p
.002 w
.52658 .33337 m .51245 .31263 L .48991 .32809 L p
1 g
F P
s
P
p
.002 w
.39804 .35203 m .39383 .36992 L .4196 .36693 L p
1 g
F P
s
P
p
.002 w
.4196 .36693 m .42176 .35797 L .39804 .35203 L p
1 g
F P
s
P
p
.002 w
.47565 .31837 m .48991 .32809 L .51245 .31263 L p
1 g
F P
s
P
p
.002 w
.47565 .31837 m .45836 .31408 L .45197 .33892 L p
1 g
F P
s
P
p
.002 w
.44274 .33981 m .45197 .33892 L .45836 .31408 L p
1 g
F P
s
P
p
.002 w
.42536 .55431 m .47695 .5551 L .46954 .53131 L p
1 g
F P
s
P
p
.002 w
.46954 .53131 m .4229 .53033 L .42536 .55431 L p
1 g
F P
s
P
p
.002 w
.40795 .33588 m .39804 .35203 L .42176 .35797 L p
1 g
F P
s
P
p
.002 w
.42176 .35797 m .42674 .34989 L .40795 .33588 L p
1 g
F P
s
P
p
.002 w
.38002 .51466 m .4229 .53033 L .42239 .50443 L p
1 g
F P
s
P
p
.002 w
.42239 .50443 m .38516 .4905 L .38002 .51466 L p
1 g
F P
s
P
p
.002 w
.45836 .31408 m .43994 .31577 L .44274 .33981 L p
1 g
F P
s
P
p
.002 w
.434 .34361 m .44274 .33981 L .43994 .31577 L p
1 g
F P
s
P
p
.002 w
.53935 .56018 m .58751 .52914 L .57246 .5113 L p
1 g
F P
s
P
p
.002 w
.57246 .5113 m .52754 .54019 L .53935 .56018 L p
1 g
F P
s
P
p
.002 w
.60761 .47119 m .57246 .5113 L .58751 .52914 L p
1 g
F P
s
P
p
.002 w
.42247 .32331 m .40795 .33588 L .42674 .34989 L p
1 g
F P
s
P
p
.002 w
.42674 .34989 m .434 .34361 L .42247 .32331 L p
1 g
F P
s
P
p
.002 w
.60761 .47119 m .62964 .42347 L .60747 .41235 L p
1 g
F P
s
P
p
.002 w
.61303 .36624 m .60747 .41235 L .62964 .42347 L p
1 g
F P
s
P
p
.002 w
.60747 .41235 m .61303 .36624 L .58771 .3617 L p
1 g
F P
s
P
p
.002 w
.43994 .31577 m .42247 .32331 L .434 .34361 L p
1 g
F P
s
P
p
.002 w
.57899 .32305 m .58771 .3617 L .61303 .36624 L p
1 g
F P
s
P
p
.002 w
.58771 .3617 m .57899 .32305 L .55321 .32697 L p
1 g
F P
s
P
p
.002 w
.35537 .46474 m .38516 .4905 L .39304 .46539 L p
1 g
F P
s
P
p
.002 w
.39304 .46539 m .36856 .44385 L .35537 .46474 L p
1 g
F P
s
P
p
.002 w
.37014 .37451 m .37314 .40053 L .39573 .38752 L p
1 g
F P
s
P
p
.002 w
.39573 .38752 m .39383 .36992 L .37014 .37451 L p
1 g
F P
s
P
p
.002 w
.48514 .57636 m .53935 .56018 L .52754 .54019 L p
1 g
F P
s
P
p
.002 w
.52754 .54019 m .47695 .5551 L .48514 .57636 L p
1 g
F P
s
P
p
.002 w
.51245 .31263 m .49151 .2981 L .47565 .31837 L p
1 g
F P
s
P
p
.002 w
.45836 .31408 m .47565 .31837 L .49151 .2981 L p
1 g
F P
s
P
p
.002 w
.58751 .52914 m .62528 .48616 L .60761 .47119 L p
1 g
F P
s
P
p
.002 w
.62964 .42347 m .60761 .47119 L .62528 .48616 L p
1 g
F P
s
P
p
.002 w
.35324 .4146 m .36856 .44385 L .38472 .4231 L p
1 g
F P
s
P
p
.002 w
.38472 .4231 m .37314 .40053 L .35324 .4146 L p
1 g
F P
s
P
p
.002 w
.53509 .29985 m .55321 .32697 L .57899 .32305 L p
1 g
F P
s
P
p
.002 w
.55321 .32697 m .53509 .29985 L .51245 .31263 L p
1 g
F P
s
P
p
.002 w
.49151 .2981 m .51245 .31263 L .53509 .29985 L p
1 g
F P
s
P
p
.002 w
.37626 .34793 m .37014 .37451 L .39383 .36992 L p
1 g
F P
s
P
p
.002 w
.39383 .36992 m .39804 .35203 L .37626 .34793 L p
1 g
F P
s
P
p
.002 w
.49151 .2981 m .46595 .29157 L .45836 .31408 L p
1 g
F P
s
P
p
.002 w
.43994 .31577 m .45836 .31408 L .46595 .29157 L p
1 g
F P
s
P
p
.002 w
.37782 .53731 m .42536 .55431 L .4229 .53033 L p
1 g
F P
s
P
p
.002 w
.4229 .53033 m .38002 .51466 L .37782 .53731 L p
1 g
F P
s
P
p
.002 w
.42981 .57579 m .48514 .57636 L .47695 .5551 L p
1 g
F P
s
P
p
.002 w
.47695 .5551 m .42536 .55431 L .42981 .57579 L p
1 g
F P
s
P
p
.002 w
.39095 .32386 m .37626 .34793 L .39804 .35203 L p
1 g
F P
s
P
p
.002 w
.39804 .35203 m .40795 .33588 L .39095 .32386 L p
1 g
F P
s
P
p
.002 w
.46595 .29157 m .43858 .29396 L .43994 .31577 L p
1 g
F P
s
P
p
.002 w
.42247 .32331 m .43994 .31577 L .43858 .29396 L p
1 g
F P
s
P
p
.002 w
.34554 .48531 m .38002 .51466 L .38516 .4905 L p
1 g
F P
s
P
p
.002 w
.38516 .4905 m .35537 .46474 L .34554 .48531 L p
1 g
F P
s
P
p
.002 w
.62528 .48616 m .6491 .43507 L .62964 .42347 L p
1 g
F P
s
P
p
.002 w
.6361 .37251 m .62964 .42347 L .6491 .43507 L p
1 g
F P
s
P
p
.002 w
.62964 .42347 m .6361 .37251 L .61303 .36624 L p
1 g
F P
s
P
p
.002 w
.60336 .32176 m .61303 .36624 L .6361 .37251 L p
1 g
F P
s
P
p
.002 w
.61303 .36624 m .60336 .32176 L .57899 .32305 L p
1 g
F P
s
P
p
.002 w
.34911 .38065 m .35324 .4146 L .37314 .40053 L p
1 g
F P
s
P
p
.002 w
.37314 .40053 m .37014 .37451 L .34911 .38065 L p
1 g
F P
s
P
p
.002 w
.55051 .57746 m .60078 .545 L .58751 .52914 L p
1 g
F P
s
P
p
.002 w
.58751 .52914 m .53935 .56018 L .55051 .57746 L p
1 g
F P
s
P
p
.002 w
.62528 .48616 m .58751 .52914 L .60078 .545 L p
1 g
F P
s
P
p
.002 w
.41256 .30514 m .39095 .32386 L .40795 .33588 L p
1 g
F P
s
P
p
.002 w
.40795 .33588 m .42247 .32331 L .41256 .30514 L p
1 g
F P
s
P
p
.002 w
.33655 .42947 m .35537 .46474 L .36856 .44385 L p
1 g
F P
s
P
p
.002 w
.36856 .44385 m .35324 .4146 L .33655 .42947 L p
1 g
F P
s
P
p
.002 w
.43858 .29396 m .41256 .30514 L .42247 .32331 L p
1 g
F P
s
P
p
.002 w
.53509 .29985 m .50798 .2807 L .49151 .2981 L p
1 g
F P
s
P
p
.002 w
.46595 .29157 m .49151 .2981 L .50798 .2807 L p
1 g
F P
s
P
p
.002 w
.55737 .29008 m .57899 .32305 L .60336 .32176 L p
1 g
F P
s
P
p
.002 w
.57899 .32305 m .55737 .29008 L .53509 .29985 L p
1 g
F P
s
P
p
.002 w
.50798 .2807 m .53509 .29985 L .55737 .29008 L p
1 g
F P
s
P
p
.002 w
.49396 .59452 m .55051 .57746 L .53935 .56018 L p
1 g
F P
s
P
p
.002 w
.53935 .56018 m .48514 .57636 L .49396 .59452 L p
1 g
F P
s
P
p
.002 w
.60078 .545 m .64029 .50016 L .62528 .48616 L p
1 g
F P
s
P
p
.002 w
.6491 .43507 m .62528 .48616 L .64029 .50016 L p
1 g
F P
s
P
p
.002 w
.35698 .34582 m .34911 .38065 L .37014 .37451 L p
1 g
F P
s
P
p
.002 w
.37014 .37451 m .37626 .34793 L .35698 .34582 L p
1 g
F P
s
P
p
.002 w
.50798 .2807 m .47463 .27197 L .46595 .29157 L p
1 g
F P
s
P
p
.002 w
.43858 .29396 m .46595 .29157 L .47463 .27197 L p
1 g
F P
s
P
p
.002 w
.37873 .55788 m .42981 .57579 L .42536 .55431 L p
1 g
F P
s
P
p
.002 w
.42536 .55431 m .37782 .53731 L .37873 .55788 L p
1 g
F P
s
P
p
.002 w
.33944 .50509 m .37782 .53731 L .38002 .51466 L p
1 g
F P
s
P
p
.002 w
.38002 .51466 m .34554 .48531 L .33944 .50509 L p
1 g
F P
s
P
p
.002 w
.43623 .59419 m .49396 .59452 L .48514 .57636 L p
1 g
F P
s
P
p
.002 w
.48514 .57636 m .42981 .57579 L .43623 .59419 L p
1 g
F P
s
P
p
.002 w
.33131 .3883 m .33655 .42947 L .35324 .4146 L p
1 g
F P
s
P
p
.002 w
.35324 .4146 m .34911 .38065 L .33131 .3883 L p
1 g
F P
s
P
p
.002 w
.6491 .43507 m .65633 .38046 L .6361 .37251 L p
1 g
F P
s
P
p
.002 w
.62574 .32324 m .6361 .37251 L .65633 .38046 L p
1 g
F P
s
P
p
.002 w
.6361 .37251 m .62574 .32324 L .60336 .32176 L p
1 g
F P
s
P
p
.002 w
.32361 .44484 m .34554 .48531 L .35537 .46474 L p
1 g
F P
s
P
p
.002 w
.35537 .46474 m .33655 .42947 L .32361 .44484 L p
1 g
F P
s
P
p
.002 w
.37619 .31419 m .35698 .34582 L .37626 .34793 L p
1 g
F P
s
P
p
.002 w
.37626 .34793 m .39095 .32386 L .37619 .31419 L p
1 g
F P
s
P
p
.002 w
.64029 .50016 m .66533 .4469 L .6491 .43507 L p
1 g
F P
s
P
p
.002 w
.65633 .38046 m .6491 .43507 L .66533 .4469 L p
1 g
F P
s
P
p
.002 w
.47463 .27197 m .43877 .27497 L .43858 .29396 L p
1 g
F P
s
P
p
.002 w
.41256 .30514 m .43858 .29396 L .43877 .27497 L p
1 g
F P
s
P
p
.002 w
.55737 .29008 m .5247 .26667 L .50798 .2807 L p
1 g
F P
s
P
p
.002 w
.47463 .27197 m .50798 .2807 L .5247 .26667 L p
1 g
F P
s
P
p
.002 w
.5788 .28367 m .60336 .32176 L .62574 .32324 L p
1 g
F P
s
P
p
.002 w
.60336 .32176 m .5788 .28367 L .55737 .29008 L p
1 g
F P
s
P
p
.002 w
.5247 .26667 m .55737 .29008 L .5788 .28367 L p
1 g
F P
s
P
p
.002 w
.56075 .59152 m .6119 .55844 L .60078 .545 L p
1 g
F P
s
P
p
.002 w
.60078 .545 m .55051 .57746 L .56075 .59152 L p
1 g
F P
s
P
p
.002 w
.64029 .50016 m .60078 .545 L .6119 .55844 L p
1 g
F P
s
P
p
.002 w
.40459 .28959 m .37619 .31419 L .39095 .32386 L p
1 g
F P
s
P
p
.002 w
.39095 .32386 m .41256 .30514 L .40459 .28959 L p
1 g
F P
s
P
p
.002 w
.43877 .27497 m .40459 .28959 L .41256 .30514 L p
1 g
F P
s
P
p
.002 w
.50325 .60902 m .56075 .59152 L .55051 .57746 L p
1 g
F P
s
P
p
.002 w
.55051 .57746 m .49396 .59452 L .50325 .60902 L p
1 g
F P
s
P
p
.002 w
.6119 .55844 m .65217 .51284 L .64029 .50016 L p
1 g
F P
s
P
p
.002 w
.66533 .4469 m .64029 .50016 L .65217 .51284 L p
1 g
F P
s
P
p
.002 w
.34076 .34586 m .33131 .3883 L .34911 .38065 L p
1 g
F P
s
P
p
.002 w
.34911 .38065 m .35698 .34582 L .34076 .34586 L p
1 g
F P
s
P
p
.002 w
.5247 .26667 m .48427 .25586 L .47463 .27197 L p
1 g
F P
s
P
p
.002 w
.43877 .27497 m .47463 .27197 L .48427 .25586 L p
1 g
F P
s
P
p
.002 w
.3829 .57577 m .43623 .59419 L .42981 .57579 L p
1 g
F P
s
P
p
.002 w
.42981 .57579 m .37873 .55788 L .3829 .57577 L p
1 g
F P
s
P
p
.002 w
.33741 .52357 m .37873 .55788 L .37782 .53731 L p
1 g
F P
s
P
p
.002 w
.37782 .53731 m .33944 .50509 L .33741 .52357 L p
1 g
F P
s
P
p
.002 w
.31735 .39734 m .32361 .44484 L .33655 .42947 L p
1 g
F P
s
P
p
.002 w
.33655 .42947 m .33131 .3883 L .31735 .39734 L p
1 g
F P
s
P
p
.002 w
.31491 .46037 m .33944 .50509 L .34554 .48531 L p
1 g
F P
s
P
p
.002 w
.34554 .48531 m .32361 .44484 L .31491 .46037 L p
1 g
F P
s
P
p
.002 w
.44458 .60889 m .50325 .60902 L .49396 .59452 L p
1 g
F P
s
P
p
.002 w
.49396 .59452 m .43623 .59419 L .44458 .60889 L p
1 g
F P
s
P
p
.002 w
.66533 .4469 m .67313 .38997 L .65633 .38046 L p
1 g
F P
s
P
p
.002 w
.64555 .32758 m .65633 .38046 L .67313 .38997 L p
1 g
F P
s
P
p
.002 w
.65633 .38046 m .64555 .32758 L .62574 .32324 L p
1 g
F P
s
P
p
.002 w
.59883 .28091 m .62574 .32324 L .64555 .32758 L p
1 g
F P
s
P
p
.002 w
.62574 .32324 m .59883 .28091 L .5788 .28367 L p
1 g
F P
s
P
p
.002 w
.5788 .28367 m .54133 .25647 L .5247 .26667 L p
1 g
F P
s
P
p
.002 w
.48427 .25586 m .5247 .26667 L .54133 .25647 L p
1 g
F P
s
P
p
.002 w
.65217 .51284 m .67779 .45873 L .66533 .4469 L p
1 g
F P
s
P
p
.002 w
.67313 .38997 m .66533 .4469 L .67779 .45873 L p
1 g
F P
s
P
p
.002 w
.36414 .30722 m .34076 .34586 L .35698 .34582 L p
1 g
F P
s
P
p
.002 w
.35698 .34582 m .37619 .31419 L .36414 .30722 L p
1 g
F P
s
P
p
.002 w
.54133 .25647 m .5788 .28367 L .59883 .28091 L p
1 g
F P
s
P
p
.002 w
.48427 .25586 m .44057 .25938 L .43877 .27497 L p
1 g
F P
s
P
p
.002 w
.40459 .28959 m .43877 .27497 L .44057 .25938 L p
1 g
F P
s
P
p
.002 w
.39882 .27717 m .36414 .30722 L .37619 .31419 L p
1 g
F P
s
P
p
.002 w
.37619 .31419 m .40459 .28959 L .39882 .27717 L p
1 g
F P
s
P
p
.002 w
.56977 .60186 m .62049 .56901 L .6119 .55844 L p
1 g
F P
s
P
p
.002 w
.6119 .55844 m .56075 .59152 L .56977 .60186 L p
1 g
F P
s
P
p
.002 w
.65217 .51284 m .6119 .55844 L .62049 .56901 L p
1 g
F P
s
P
p
.002 w
.44057 .25938 m .39882 .27717 L .40459 .28959 L p
1 g
F P
s
P
p
.002 w
.51281 .61931 m .56977 .60186 L .56075 .59152 L p
1 g
F P
s
P
p
.002 w
.56075 .59152 m .50325 .60902 L .51281 .61931 L p
1 g
F P
s
P
p
.002 w
.62049 .56901 m .66047 .52382 L .65217 .51284 L p
1 g
F P
s
P
p
.002 w
.67779 .45873 m .65217 .51284 L .66047 .52382 L p
1 g
F P
s
P
p
.002 w
.32816 .34817 m .31735 .39734 L .33131 .3883 L p
1 g
F P
s
P
p
.002 w
.33131 .3883 m .34076 .34586 L .32816 .34817 L p
1 g
F P
s
P
p
.002 w
.54133 .25647 m .49468 .24379 L .48427 .25586 L p
1 g
F P
s
P
p
.002 w
.44057 .25938 m .48427 .25586 L .49468 .24379 L p
1 g
F P
s
P
p
.002 w
.3904 .5904 m .44458 .60889 L .43623 .59419 L p
1 g
F P
s
P
p
.002 w
.43623 .59419 m .3829 .57577 L .3904 .5904 L p
1 g
F P
s
P
p
.002 w
.33971 .5402 m .3829 .57577 L .37873 .55788 L p
1 g
F P
s
P
p
.002 w
.37873 .55788 m .33741 .52357 L .33971 .5402 L p
1 g
F P
s
P
p
.002 w
.30779 .40763 m .31491 .46037 L .32361 .44484 L p
1 g
F P
s
P
p
.002 w
.32361 .44484 m .31735 .39734 L .30779 .40763 L p
1 g
F P
s
P
p
.002 w
.3109 .47568 m .33741 .52357 L .33944 .50509 L p
1 g
F P
s
P
p
.002 w
.33944 .50509 m .31491 .46037 L .3109 .47568 L p
1 g
F P
s
P
p
.002 w
.67779 .45873 m .68592 .40091 L .67313 .38997 L p
1 g
F P
s
P
p
.002 w
.66216 .33481 m .67313 .38997 L .68592 .40091 L p
1 g
F P
s
P
p
.002 w
.67313 .38997 m .66216 .33481 L .64555 .32758 L p
1 g
F P
s
P
p
.002 w
.61694 .28204 m .64555 .32758 L .66216 .33481 L p
1 g
F P
s
P
p
.002 w
.64555 .32758 m .61694 .28204 L .59883 .28091 L p
1 g
F P
s
P
p
.002 w
.45476 .61933 m .51281 .61931 L .50325 .60902 L p
1 g
F P
s
P
p
.002 w
.50325 .60902 m .44458 .60889 L .45476 .61933 L p
1 g
F P
s
P
p
.002 w
.59883 .28091 m .55745 .25055 L .54133 .25647 L p
1 g
F P
s
P
p
.002 w
.49468 .24379 m .54133 .25647 L .55745 .25055 L p
1 g
F P
s
P
p
.002 w
.55745 .25055 m .59883 .28091 L .61694 .28204 L p
1 g
F P
s
P
p
.002 w
.66047 .52382 m .68596 .47025 L .67779 .45873 L p
1 g
F P
s
P
p
.002 w
.68592 .40091 m .67779 .45873 L .68596 .47025 L p
1 g
F P
s
P
p
.002 w
.35526 .30329 m .32816 .34817 L .34076 .34586 L p
1 g
F P
s
P
p
.002 w
.34076 .34586 m .36414 .30722 L .35526 .30329 L p
1 g
F P
s
P
p
.002 w
.49468 .24379 m .44405 .24776 L .44057 .25938 L p
1 g
F P
s
P
p
.002 w
.39882 .27717 m .44057 .25938 L .44405 .24776 L p
1 g
F P
s
P
p
.002 w
.39555 .26837 m .35526 .30329 L .36414 .30722 L p
1 g
F P
s
P
p
.002 w
.36414 .30722 m .39882 .27717 L .39555 .26837 L p
1 g
F P
s
P
p
.002 w
.57727 .60799 m .62619 .57629 L .62049 .56901 L p
1 g
F P
s
P
p
.002 w
.62049 .56901 m .56977 .60186 L .57727 .60799 L p
1 g
F P
s
P
p
.002 w
.66047 .52382 m .62049 .56901 L .62619 .57629 L p
1 g
F P
s
P
p
.002 w
.44405 .24776 m .39555 .26837 L .39882 .27717 L p
1 g
F P
s
P
p
.002 w
.52241 .62487 m .57727 .60799 L .56977 .60186 L p
1 g
F P
s
P
p
.002 w
.56977 .60186 m .51281 .61931 L .52241 .62487 L p
1 g
F P
s
P
p
.002 w
.62619 .57629 m .66477 .53272 L .66047 .52382 L p
1 g
F P
s
P
p
.002 w
.68596 .47025 m .66047 .52382 L .66477 .53272 L p
1 g
F P
s
P
p
.002 w
.31975 .35283 m .30779 .40763 L .31735 .39734 L p
1 g
F P
s
P
p
.002 w
.31735 .39734 m .32816 .34817 L .31975 .35283 L p
1 g
F P
s
P
p
.002 w
.34652 .55445 m .3904 .5904 L .3829 .57577 L p
1 g
F P
s
P
p
.002 w
.3829 .57577 m .33971 .5402 L .34652 .55445 L p
1 g
F P
s
P
p
.002 w
.40121 .60118 m .45476 .61933 L .44458 .60889 L p
1 g
F P
s
P
p
.002 w
.44458 .60889 m .3904 .5904 L .40121 .60118 L p
1 g
F P
s
P
p
.002 w
.55745 .25055 m .50564 .23631 L .49468 .24379 L p
1 g
F P
s
P
p
.002 w
.44405 .24776 m .49468 .24379 L .50564 .23631 L p
1 g
F P
s
P
p
.002 w
.31197 .49034 m .33971 .5402 L .33741 .52357 L p
1 g
F P
s
P
p
.002 w
.33741 .52357 m .3109 .47568 L .31197 .49034 L p
1 g
F P
s
P
p
.002 w
.30314 .41897 m .3109 .47568 L .31491 .46037 L p
1 g
F P
s
P
p
.002 w
.31491 .46037 m .30779 .40763 L .30314 .41897 L p
1 g
F P
s
P
p
.002 w
.68596 .47025 m .69416 .41308 L .68592 .40091 L p
1 g
F P
s
P
p
.002 w
.67499 .34491 m .68592 .40091 L .69416 .41308 L p
1 g
F P
s
P
p
.002 w
.68592 .40091 m .67499 .34491 L .66216 .33481 L p
1 g
F P
s
P
p
.002 w
.63253 .28725 m .66216 .33481 L .67499 .34491 L p
1 g
F P
s
P
p
.002 w
.66216 .33481 m .63253 .28725 L .61694 .28204 L p
1 g
F P
s
P
p
.002 w
.61694 .28204 m .57263 .2493 L .55745 .25055 L p
1 g
F P
s
P
p
.002 w
.50564 .23631 m .55745 .25055 L .57263 .2493 L p
1 g
F P
s
P
p
.002 w
.57263 .2493 m .61694 .28204 L .63253 .28725 L p
1 g
F P
s
P
p
.002 w
.46659 .62496 m .52241 .62487 L .51281 .61931 L p
1 g
F P
s
P
p
.002 w
.51281 .61931 m .45476 .61933 L .46659 .62496 L p
1 g
F P
s
P
p
.002 w
.66477 .53272 m .68939 .48115 L .68596 .47025 L p
1 g
F P
s
P
p
.002 w
.69416 .41308 m .68596 .47025 L .68939 .48115 L p
1 g
F P
s
P
p
.002 w
.34998 .3027 m .31975 .35283 L .32816 .34817 L p
1 g
F P
s
P
p
.002 w
.32816 .34817 m .35526 .30329 L .34998 .3027 L p
1 g
F P
s
P
p
.002 w
.50564 .23631 m .4492 .24066 L .44405 .24776 L p
1 g
F P
s
P
p
.002 w
.39555 .26837 m .44405 .24776 L .4492 .24066 L p
1 g
F P
s
P
p
.002 w
.39501 .26366 m .34998 .3027 L .35526 .30329 L p
1 g
F P
s
P
p
.002 w
.35526 .30329 m .39555 .26837 L .39501 .26366 L p
1 g
F P
s
P
p
.002 w
.58297 .60949 m .62865 .57986 L .62619 .57629 L p
1 g
F P
s
P
p
.002 w
.62619 .57629 m .57727 .60799 L .58297 .60949 L p
1 g
F P
s
P
p
.002 w
.66477 .53272 m .62619 .57629 L .62865 .57986 L p
1 g
F P
s
P
p
.002 w
.4492 .24066 m .39501 .26366 L .39555 .26837 L p
1 g
F P
s
P
p
.002 w
.31601 .35986 m .30314 .41897 L .30779 .40763 L p
1 g
F P
s
P
p
.002 w
.30779 .40763 m .31975 .35283 L .31601 .35986 L p
1 g
F P
s
P
p
.002 w
.5318 .62525 m .58297 .60949 L .57727 .60799 L p
1 g
F P
s
P
p
.002 w
.57727 .60799 m .52241 .62487 L .5318 .62525 L p
1 g
F P
s
P
p
.002 w
.35793 .56575 m .40121 .60118 L .3904 .5904 L p
1 g
F P
s
P
p
.002 w
.3904 .5904 m .34652 .55445 L .35793 .56575 L p
1 g
F P
s
P
p
.002 w
.62865 .57986 m .6647 .53918 L .66477 .53272 L p
1 g
F P
s
P
p
.002 w
.68939 .48115 m .66477 .53272 L .6647 .53918 L p
1 g
F P
s
P
p
.002 w
.41523 .60758 m .46659 .62496 L .45476 .61933 L p
1 g
F P
s
P
p
.002 w
.45476 .61933 m .40121 .60118 L .41523 .60758 L p
1 g
F P
s
P
p
.002 w
.31838 .5039 m .34652 .55445 L .33971 .5402 L p
1 g
F P
s
P
p
.002 w
.33971 .5402 m .31197 .49034 L .31838 .5039 L p
1 g
F P
s
P
p
.002 w
.57263 .2493 m .5169 .2339 L .50564 .23631 L p
1 g
F P
s
P
p
.002 w
.4492 .24066 m .50564 .23631 L .5169 .2339 L p
1 g
F P
s
P
p
.002 w
.30384 .43111 m .31197 .49034 L .3109 .47568 L p
1 g
F P
s
P
p
.002 w
.3109 .47568 m .30314 .41897 L .30384 .43111 L p
1 g
F P
s
P
p
.002 w
.69416 .41308 m .68347 .35778 L .67499 .34491 L p
1 g
F P
s
P
p
.002 w
.64505 .29665 m .67499 .34491 L .68347 .35778 L p
1 g
F P
s
P
p
.002 w
.67499 .34491 m .64505 .29665 L .63253 .28725 L p
1 g
F P
s
P
p
.002 w
.68939 .48115 m .69734 .42622 L .69416 .41308 L p
1 g
F P
s
P
p
.002 w
.68347 .35778 m .69416 .41308 L .69734 .42622 L p
1 g
F P
s
P
p
.002 w
.63253 .28725 m .58639 .25303 L .57263 .2493 L p
1 g
F P
s
P
p
.002 w
.58639 .25303 m .63253 .28725 L .64505 .29665 L p
1 g
F P
s
P
p
.002 w
.5169 .2339 m .57263 .2493 L .58639 .25303 L p
1 g
F P
s
P
p
.002 w
.47986 .62535 m .5318 .62525 L .52241 .62487 L p
1 g
F P
s
P
p
.002 w
.52241 .62487 m .46659 .62496 L .47986 .62535 L p
1 g
F P
s
P
p
.002 w
.6647 .53918 m .68768 .49111 L .68939 .48115 L p
1 g
F P
s
P
p
.002 w
.69734 .42622 m .68939 .48115 L .68768 .49111 L p
1 g
F P
s
P
p
.002 w
.34869 .30568 m .31601 .35986 L .31975 .35283 L p
1 g
F P
s
P
p
.002 w
.31975 .35283 m .34998 .3027 L .34869 .30568 L p
1 g
F P
s
P
p
.002 w
.5169 .2339 m .456 .23857 L .4492 .24066 L p
1 g
F P
s
P
p
.002 w
.39501 .26366 m .4492 .24066 L .456 .23857 L p
1 g
F P
s
P
p
.002 w
.39741 .26344 m .34869 .30568 L .34998 .3027 L p
1 g
F P
s
P
p
.002 w
.34998 .3027 m .39501 .26366 L .39741 .26344 L p
1 g
F P
s
P
p
.002 w
.58657 .60599 m .6276 .57939 L .62865 .57986 L p
1 g
F P
s
P
p
.002 w
.62865 .57986 m .58297 .60949 L .58657 .60599 L p
1 g
F P
s
P
p
.002 w
.6647 .53918 m .62865 .57986 L .6276 .57939 L p
1 g
F P
s
P
p
.002 w
.456 .23857 m .39741 .26344 L .39501 .26366 L p
1 g
F P
s
P
p
.002 w
.31736 .36922 m .30384 .43111 L .30314 .41897 L p
1 g
F P
s
P
p
.002 w
.30314 .41897 m .31601 .35986 L .31736 .36922 L p
1 g
F P
s
P
p
.002 w
.37385 .57362 m .41523 .60758 L .40121 .60118 L p
1 g
F P
s
P
p
.002 w
.40121 .60118 m .35793 .56575 L .37385 .57362 L p
1 g
F P
s
P
p
.002 w
.33026 .51588 m .35793 .56575 L .34652 .55445 L p
1 g
F P
s
P
p
.002 w
.34652 .55445 m .31838 .5039 L .33026 .51588 L p
1 g
F P
s
P
p
.002 w
.54068 .62012 m .58657 .60599 L .58297 .60949 L p
1 g
F P
s
P
p
.002 w
.58297 .60949 m .5318 .62525 L .54068 .62012 L p
1 g
F P
s
P
p
.002 w
.43222 .60916 m .47986 .62535 L .46659 .62496 L p
1 g
F P
s
P
p
.002 w
.46659 .62496 m .41523 .60758 L .43222 .60916 L p
1 g
F P
s
P
p
.002 w
.31021 .44372 m .31838 .5039 L .31197 .49034 L p
1 g
F P
s
P
p
.002 w
.31197 .49034 m .30384 .43111 L .31021 .44372 L p
1 g
F P
s
P
p
.002 w
.6276 .57939 m .65997 .54286 L .6647 .53918 L p
1 g
F P
s
P
p
.002 w
.68768 .49111 m .6647 .53918 L .65997 .54286 L p
1 g
F P
s
P
p
.002 w
.58639 .25303 m .52815 .23694 L .5169 .2339 L p
1 g
F P
s
P
p
.002 w
.456 .23857 m .5169 .2339 L .52815 .23694 L p
1 g
F P
s
P
p
.002 w
.69734 .42622 m .6871 .3732 L .68347 .35778 L p
1 g
F P
s
P
p
.002 w
.68347 .35778 m .65397 .31019 L .64505 .29665 L p
1 g
F P
s
P
p
.002 w
.65397 .31019 m .68347 .35778 L .6871 .3732 L p
1 g
F P
s
P
p
.002 w
.68768 .49111 m .69506 .44002 L .69734 .42622 L p
1 g
F P
s
P
p
.002 w
.6871 .3732 m .69734 .42622 L .69506 .44002 L p
1 g
F P
s
P
p
.002 w
.59826 .26194 m .64505 .29665 L .65397 .31019 L p
1 g
F P
s
P
p
.002 w
.64505 .29665 m .59826 .26194 L .58639 .25303 L p
1 g
F P
s
P
p
.002 w
.52815 .23694 m .58639 .25303 L .59826 .26194 L p
1 g
F P
s
P
p
.002 w
.49423 .62014 m .54068 .62012 L .5318 .62525 L p
1 g
F P
s
P
p
.002 w
.5318 .62525 m .47986 .62535 L .49423 .62014 L p
1 g
F P
s
P
p
.002 w
.65997 .54286 m .68055 .49976 L .68768 .49111 L p
1 g
F P
s
P
p
.002 w
.69506 .44002 m .68768 .49111 L .68055 .49976 L p
1 g
F P
s
P
p
.002 w
.35169 .31238 m .31736 .36922 L .31601 .35986 L p
1 g
F P
s
P
p
.002 w
.31601 .35986 m .34869 .30568 L .35169 .31238 L p
1 g
F P
s
P
p
.002 w
.52815 .23694 m .46435 .24189 L .456 .23857 L p
1 g
F P
s
P
p
.002 w
.39741 .26344 m .456 .23857 L .46435 .24189 L p
1 g
F P
s
P
p
.002 w
.39404 .57759 m .43222 .60916 L .41523 .60758 L p
1 g
F P
s
P
p
.002 w
.41523 .60758 m .37385 .57362 L .39404 .57759 L p
1 g
F P
s
P
p
.002 w
.40287 .26802 m .35169 .31238 L .34869 .30568 L p
1 g
F P
s
P
p
.002 w
.34869 .30568 m .39741 .26344 L .40287 .26802 L p
1 g
F P
s
P
p
.002 w
.3241 .38075 m .31021 .44372 L .30384 .43111 L p
1 g
F P
s
P
p
.002 w
.30384 .43111 m .31736 .36922 L .3241 .38075 L p
1 g
F P
s
P
p
.002 w
.34756 .52581 m .37385 .57362 L .35793 .56575 L p
1 g
F P
s
P
p
.002 w
.35793 .56575 m .33026 .51588 L .34756 .52581 L p
1 g
F P
s
P
p
.002 w
.58784 .59728 m .62283 .57461 L .6276 .57939 L p
1 g
F P
s
P
p
.002 w
.6276 .57939 m .58657 .60599 L .58784 .59728 L p
1 g
F P
s
P
p
.002 w
.65997 .54286 m .6276 .57939 L .62283 .57461 L p
1 g
F P
s
P
p
.002 w
.46435 .24189 m .40287 .26802 L .39741 .26344 L p
1 g
F P
s
P
p
.002 w
.32239 .45645 m .33026 .51588 L .31838 .5039 L p
1 g
F P
s
P
p
.002 w
.31838 .5039 m .31021 .44372 L .32239 .45645 L p
1 g
F P
s
P
p
.002 w
.45183 .60558 m .49423 .62014 L .47986 .62535 L p
1 g
F P
s
P
p
.002 w
.47986 .62535 m .43222 .60916 L .45183 .60558 L p
1 g
F P
s
P
p
.002 w
.69506 .44002 m .68549 .39087 L .6871 .3732 L p
1 g
F P
s
P
p
.002 w
.65878 .32772 m .6871 .3732 L .68549 .39087 L p
1 g
F P
s
P
p
.002 w
.6871 .3732 m .65878 .32772 L .65397 .31019 L p
1 g
F P
s
P
p
.002 w
.54875 .60926 m .58784 .59728 L .58657 .60599 L p
1 g
F P
s
P
p
.002 w
.58657 .60599 m .54068 .62012 L .54875 .60926 L p
1 g
F P
s
P
p
.002 w
.59826 .26194 m .53906 .24568 L .52815 .23694 L p
1 g
F P
s
P
p
.002 w
.46435 .24189 m .52815 .23694 L .53906 .24568 L p
1 g
F P
s
P
p
.002 w
.62283 .57461 m .65041 .54345 L .65997 .54286 L p
1 g
F P
s
P
p
.002 w
.68055 .49976 m .65997 .54286 L .65041 .54345 L p
1 g
F P
s
P
p
.002 w
.60775 .27606 m .65397 .31019 L .65878 .32772 L p
1 g
F P
s
P
p
.002 w
.65397 .31019 m .60775 .27606 L .59826 .26194 L p
1 g
F P
s
P
p
.002 w
.68055 .49976 m .68708 .45409 L .69506 .44002 L p
1 g
F P
s
P
p
.002 w
.68549 .39087 m .69506 .44002 L .68708 .45409 L p
1 g
F P
s
P
p
.002 w
.53906 .24568 m .59826 .26194 L .60775 .27606 L p
1 g
F P
s
P
p
.002 w
.50934 .60917 m .54875 .60926 L .54068 .62012 L p
1 g
F P
s
P
p
.002 w
.54068 .62012 m .49423 .62014 L .50934 .60917 L p
1 g
F P
s
P
p
.002 w
.65041 .54345 m .66787 .50675 L .68055 .49976 L p
1 g
F P
s
P
p
.002 w
.68708 .45409 m .68055 .49976 L .66787 .50675 L p
1 g
F P
s
P
p
.002 w
.35918 .32284 m .3241 .38075 L .31736 .36922 L p
1 g
F P
s
P
p
.002 w
.31736 .36922 m .35169 .31238 L .35918 .32284 L p
1 g
F P
s
P
p
.002 w
.53906 .24568 m .4741 .25084 L .46435 .24189 L p
1 g
F P
s
P
p
.002 w
.40287 .26802 m .46435 .24189 L .4741 .25084 L p
1 g
F P
s
P
p
.002 w
.41806 .57733 m .45183 .60558 L .43222 .60916 L p
1 g
F P
s
P
p
.002 w
.43222 .60916 m .39404 .57759 L .41806 .57733 L p
1 g
F P
s
P
p
.002 w
.36999 .53325 m .39404 .57759 L .37385 .57362 L p
1 g
F P
s
P
p
.002 w
.37385 .57362 m .34756 .52581 L .36999 .53325 L p
1 g
F P
s
P
p
.002 w
.33632 .39422 m .32239 .45645 L .31021 .44372 L p
1 g
F P
s
P
p
.002 w
.31021 .44372 m .3241 .38075 L .33632 .39422 L p
1 g
F P
s
P
p
.002 w
.3403 .46888 m .34756 .52581 L .33026 .51588 L p
1 g
F P
s
P
p
.002 w
.33026 .51588 m .32239 .45645 L .3403 .46888 L p
1 g
F P
s
P
p
.002 w
.47355 .59669 m .50934 .60917 L .49423 .62014 L p
1 g
F P
s
P
p
.002 w
.49423 .62014 m .45183 .60558 L .47355 .59669 L p
1 g
F P
s
P
p
.002 w
.68708 .45409 m .6784 .41035 L .68549 .39087 L p
1 g
F P
s
P
p
.002 w
.65913 .34889 m .68549 .39087 L .6784 .41035 L p
1 g
F P
s
P
p
.002 w
.68549 .39087 m .65913 .34889 L .65878 .32772 L p
1 g
F P
s
P
p
.002 w
.41142 .27758 m .35918 .32284 L .35169 .31238 L p
1 g
F P
s
P
p
.002 w
.35169 .31238 m .40287 .26802 L .41142 .27758 L p
1 g
F P
s
P
p
.002 w
.58657 .5833 m .61425 .56539 L .62283 .57461 L p
1 g
F P
s
P
p
.002 w
.62283 .57461 m .58784 .59728 L .58657 .5833 L p
1 g
F P
s
P
p
.002 w
.65041 .54345 m .62283 .57461 L .61425 .56539 L p
1 g
F P
s
P
p
.002 w
.4741 .25084 m .41142 .27758 L .40287 .26802 L p
1 g
F P
s
P
p
.002 w
.61444 .29524 m .65878 .32772 L .65913 .34889 L p
1 g
F P
s
P
p
.002 w
.65878 .32772 m .61444 .29524 L .60775 .27606 L p
1 g
F P
s
P
p
.002 w
.60775 .27606 m .54925 .2602 L .53906 .24568 L p
1 g
F P
s
P
p
.002 w
.4741 .25084 m .53906 .24568 L .54925 .2602 L p
1 g
F P
s
P
p
.002 w
.66787 .50675 m .67329 .46801 L .68708 .45409 L p
1 g
F P
s
P
p
.002 w
.6784 .41035 m .68708 .45409 L .67329 .46801 L p
1 g
F P
s
P
p
.002 w
.55571 .59269 m .58657 .5833 L .58784 .59728 L p
1 g
F P
s
P
p
.002 w
.58784 .59728 m .54875 .60926 L .55571 .59269 L p
1 g
F P
s
P
p
.002 w
.54925 .2602 m .60775 .27606 L .61444 .29524 L p
1 g
F P
s
P
p
.002 w
.61425 .56539 m .63603 .54074 L .65041 .54345 L p
1 g
F P
s
P
p
.002 w
.66787 .50675 m .65041 .54345 L .63603 .54074 L p
1 g
F P
s
P
p
.002 w
.5247 .5925 m .55571 .59269 L .54875 .60926 L p
1 g
F P
s
P
p
.002 w
.54875 .60926 m .50934 .60917 L .5247 .5925 L p
1 g
F P
s
P
p
.002 w
.63603 .54074 m .64973 .51176 L .66787 .50675 L p
1 g
F P
s
P
p
.002 w
.67329 .46801 m .66787 .50675 L .64973 .51176 L p
1 g
F P
s
P
p
.002 w
.37118 .33693 m .33632 .39422 L .3241 .38075 L p
1 g
F P
s
P
p
.002 w
.3241 .38075 m .35918 .32284 L .37118 .33693 L p
1 g
F P
s
P
p
.002 w
.44527 .57265 m .47355 .59669 L .45183 .60558 L p
1 g
F P
s
P
p
.002 w
.45183 .60558 m .41806 .57733 L .44527 .57265 L p
1 g
F P
s
P
p
.002 w
.54925 .2602 m .485 .2655 L .4741 .25084 L p
1 g
F P
s
P
p
.002 w
.41142 .27758 m .4741 .25084 L .485 .2655 L p
1 g
F P
s
P
p
.002 w
.39703 .53781 m .41806 .57733 L .39404 .57759 L p
1 g
F P
s
P
p
.002 w
.39404 .57759 m .36999 .53325 L .39703 .53781 L p
1 g
F P
s
P
p
.002 w
.36362 .48054 m .36999 .53325 L .34756 .52581 L p
1 g
F P
s
P
p
.002 w
.34756 .52581 m .3403 .46888 L .36362 .48054 L p
1 g
F P
s
P
p
.002 w
.67329 .46801 m .66575 .43109 L .6784 .41035 L p
1 g
F P
s
P
p
.002 w
.65474 .37321 m .6784 .41035 L .66575 .43109 L p
1 g
F P
s
P
p
.002 w
.6784 .41035 m .65474 .37321 L .65913 .34889 L p
1 g
F P
s
P
p
.002 w
.35392 .40927 m .3403 .46888 L .32239 .45645 L p
1 g
F P
s
P
p
.002 w
.32239 .45645 m .33632 .39422 L .35392 .40927 L p
1 g
F P
s
P
p
.002 w
.49673 .58252 m .5247 .5925 L .50934 .60917 L p
1 g
F P
s
P
p
.002 w
.50934 .60917 m .47355 .59669 L .49673 .58252 L p
1 g
F P
s
P
p
.002 w
.61795 .31912 m .65913 .34889 L .65474 .37321 L p
1 g
F P
s
P
p
.002 w
.65913 .34889 m .61795 .31912 L .61444 .29524 L p
1 g
F P
s
P
p
.002 w
.64973 .51176 m .65385 .48129 L .67329 .46801 L p
1 g
F P
s
P
p
.002 w
.66575 .43109 m .67329 .46801 L .65385 .48129 L p
1 g
F P
s
P
p
.002 w
.61444 .29524 m .55834 .28033 L .54925 .2602 L p
1 g
F P
s
P
p
.002 w
.485 .2655 m .54925 .2602 L .55834 .28033 L p
1 g
F P
s
P
p
.002 w
.42296 .29209 m .37118 .33693 L .35918 .32284 L p
1 g
F P
s
P
p
.002 w
.35918 .32284 m .41142 .27758 L .42296 .29209 L p
1 g
F P
s
P
p
.002 w
.55834 .28033 m .61444 .29524 L .61795 .31912 L p
1 g
F P
s
P
p
.002 w
.58266 .5642 m .6019 .55176 L .61425 .56539 L p
1 g
F P
s
P
p
.002 w
.61425 .56539 m .58657 .5833 L .58266 .5642 L p
1 g
F P
s
P
p
.002 w
.63603 .54074 m .61425 .56539 L .6019 .55176 L p
1 g
F P
s
P
p
.002 w
.485 .2655 m .42296 .29209 L .41142 .27758 L p
1 g
F P
s
P
p
.002 w
.56123 .57065 m .58266 .5642 L .58657 .5833 L p
1 g
F P
s
P
p
.002 w
.58657 .5833 m .55571 .59269 L .56123 .57065 L p
1 g
F P
s
P
p
.002 w
.6019 .55176 m .61701 .53462 L .63603 .54074 L p
1 g
F P
s
P
p
.002 w
.64973 .51176 m .63603 .54074 L .61701 .53462 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.5398 .57039 m .56123 .57065 L .55571 .59269 L p
1 g
F P
s
P
p
.002 w
.55571 .59269 m .5247 .5925 L .5398 .57039 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.61701 .53462 m .62645 .5145 L .64973 .51176 L p
1 g
F P
s
P
p
.002 w
.65385 .48129 m .64973 .51176 L .62645 .5145 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.49616 .58287 m .47355 .59669 L p
.47423 .57904 L 1 g
F P
s
P
p
.47423 .57904 m .47434 .57598 L .48906 .58063 L 1 g
F
P
p
.47423 .57904 m .48906 .58063 L .49616 .58287 L 1 g
F
P
p
.002 w
.5247 .5925 m .49673 .58252 L .49822 .58132 L p
1 g
F P
s
P
p
.002 w
.51093 .58044 m .51079 .57862 L p
.49732 .58131 L 1 g
F P
s
P
p
.002 w
.49822 .58132 m .49673 .58252 L p
.49706 .58131 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.49673 .58252 m .49531 .5813 L p
.49706 .58131 L 1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58063 L p
1 g
F P
s
P
p
.002 w
.49673 .58252 m .49616 .58287 L p
.49431 .58119 L 1 g
F P
s
P
p
.002 w
.49531 .5813 m .49673 .58252 L p
.49431 .58119 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58063 L .49667 .58144 L 1 g
F
P
p
.002 w
.48906 .58063 m .48921 .57862 L p
.48042 .5779 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .4684 .5741 L p
1 g
F P
s
P
p
.47355 .59669 m .45465 .56976 L .4684 .5741 L 1 g
F
P
p
.47429 .57747 m .4684 .5741 L .47434 .57598 L 1 g
F
P
p
.47355 .59669 m .4684 .5741 L .47429 .57747 L 1 g
F
P
p
.002 w
.4684 .5741 m .46872 .57265 L p
.45922 .56886 L 1 g
F P
s
P
p
.48921 .57862 m .4684 .5741 L .48042 .5779 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.47434 .57598 m .4684 .5741 L .47482 .56353 L 1 g
F
P
p
.002 w
.45465 .56976 m .45865 .56853 L p
.4684 .5741 L 1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45093 .56272 L p
1 g
F P
s
P
p
.44527 .57265 m .45013 .56212 L .45093 .56272 L 1 g
F
P
p
.002 w
.45865 .56853 m .45611 .56931 L p
.45093 .56272 L 1 g
F P
s
P
p
.002 w
.45611 .56931 m .44527 .57265 L p
.45093 .56272 L 1 g
F P
s
P
p
.002 w
.45093 .56272 m .45146 .56129 L p
.44623 .55674 L 1 g
F P
s
P
p
.46872 .57265 m .45093 .56272 L .45594 .56649 L 1 g
F
P
p
.46872 .57265 m .4505 .56387 L .45922 .56886 L 1 g
F
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.45093 .56272 m .46157 .53732 L .45865 .56853 L 1 g
F
P
p
.45013 .56212 m .45025 .56186 L .45093 .56272 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43855 .54698 L p
1 g
F P
s
P
p
.45146 .56129 m .43855 .54698 L .44623 .55674 L 1 g
F
P
p
.45025 .56186 m .46157 .53732 L .45093 .56272 L 1 g
F
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.44527 .57265 m .42789 .53922 L .43546 .5388 L p
1 g
F P
s
P
p
.002 w
.43855 .54698 m .43925 .54566 L p
.4351 .53745 L 1 g
F P
s
P
p
.002 w
.43546 .5388 m .42789 .53922 L p
.43388 .53288 L 1 g
F P
s
P
p
.4351 .53745 m .43451 .53628 L .43546 .5388 L 1 g
F
P
p
.4351 .53745 m .43546 .5388 L .43855 .54698 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4327 .52844 L p
1 g
F P
s
P
p
.42789 .53922 m .42515 .50007 L .4327 .52844 L 1 g
F
P
p
.43226 .5346 m .4327 .52844 L .43388 .53288 L 1 g
F
P
p
.42789 .53922 m .4327 .52844 L .43226 .5346 L 1 g
F
P
p
.002 w
.4327 .52844 m .43346 .52734 L p
.43324 .52097 L 1 g
F P
s
P
p
.43925 .54566 m .4327 .52844 L .4351 .53745 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.43388 .53288 m .4327 .52844 L .45872 .50659 L 1 g
F
P
p
.002 w
.42515 .50007 m .43461 .50191 L p
.43409 .50917 L 1 g
F P
s
P
p
.42995 .51809 m .42515 .50007 L .43409 .50917 L 1 g
F
P
p
.002 w
.43409 .50917 m .43485 .50826 L p
.43818 .50047 L 1 g
F P
s
P
p
.42382 .49981 m .44444 .48783 L .44282 .49111 L 1 g
F
P
p
.002 w
.43722 .50241 m .43217 .50143 L p
.44282 .49111 L 1 g
F P
s
P
p
.002 w
.43217 .50143 m .42382 .49981 L p
.44282 .49111 L 1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43409 .50917 L p
1 g
F P
s
P
p
.43346 .52734 m .43409 .50917 L .43324 .52097 L 1 g
F
P
p
.4327 .52844 m .43409 .50917 L .45872 .50659 L 1 g
F
P
p
.002 w
.43461 .50191 m .43722 .50241 L p
.43409 .50917 L 1 g
F P
s
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44212 .49185 L p
1 g
F P
s
P
p
.43485 .50826 m .44212 .49185 L .43891 .49878 L 1 g
F
P
p
.43818 .50047 m .43722 .50241 L .43409 .50917 L 1 g
F
P
p
.002 w
.43722 .50241 m .45872 .50659 L p
.43409 .50917 L 1 g
F P
s
P
p
.002 w
.44212 .49185 m .44166 .49233 L p
.43891 .49878 L 1 g
F P
s
P
p
.002 w
.44282 .49111 m .44339 .4905 L p
.44841 .48569 L 1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.44282 .49111 m .46691 .47478 L .43722 .50241 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45771 .47668 L p
1 g
F P
s
P
p
.44339 .4905 m .45771 .47668 L .44841 .48569 L 1 g
F
P
p
.44444 .48783 m .44884 .48527 L .44282 .49111 L 1 g
F
P
p
.44884 .48527 m .46691 .47478 L .44282 .49111 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.42382 .49981 m .42595 .49127 L p
.46691 .47478 L 1 g
F P
s
P
p
.002 w
.46691 .47478 m .46907 .47136 L p
.51359 .46956 L 1 g
F P
s
P
p
.002 w
.45771 .47668 m .45826 .47608 L p
.46944 .47118 L 1 g
F P
s
P
p
.46944 .47118 m .46931 .47124 L .45771 .47668 L 1 g
F
P
p
.46955 .47113 m .46445 .47358 L .45771 .47668 L 1 g
F
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.46907 .47136 m .47756 .46716 L .51359 .46956 L 1 g
F
P
p
.002 w
.47756 .46716 m .47786 .46667 L p
.48756 .46568 L 1 g
F P
s
P
p
.47756 .46716 m .5 .46384 L .51359 .46956 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52248 .46723 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56625 .50957 L p
1 g
F P
s
P
p
.55661 .4905 m .56625 .50957 L .56623 .50953 L 1 g
F
P
p
.002 w
.5645 .49821 m .56582 .50573 L p
.55745 .49139 L 1 g
F P
s
P
p
.002 w
.56582 .50573 m .56663 .51035 L p
.56625 .50957 L 1 g
F P
s
P
p
.55745 .49139 m .56582 .50573 L .56625 .50957 L 1 g
F
P
p
.002 w
.5761 .54036 m .56824 .54269 L p
.56764 .52811 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56654 .52734 L p
.56418 .54025 L 1 g
F P
s
P
p
.002 w
.56558 .53538 m .56507 .54363 L .56322 .5436 L p
1 g
F P
s
P
p
.56418 .54025 m .56415 .5404 L .56558 .53538 L 1 g
F
P
p
.56418 .54025 m .56558 .53538 L .56747 .5287 L 1 g
F
P
p
.56515 .50826 m .56701 .52035 L .567 .52 L 1 g
F
P
p
.002 w
.56663 .51333 m .567 .51244 L .56678 .516 L p
1 g
F P
s
P
p
.002 w
.567 .51244 m .56972 .52078 L p
.56764 .52811 L 1 g
F P
s
P
p
.002 w
.56972 .52078 m .5761 .54036 L p
.56764 .52811 L 1 g
F P
s
P
p
.002 w
.56678 .516 m .567 .51244 L p
.56824 .54269 L 1 g
F P
s
P
p
.002 w
.56625 .50957 m .56515 .50826 L p
.56705 .52034 L 1 g
F P
s
P
p
.002 w
.5666 .51291 m .567 .51244 L .56663 .51333 L p
1 g
F P
s
P
p
.56705 .52034 m .56659 .5128 L .56625 .50957 L 1 g
F
P
p
.56659 .5128 m .56658 .51257 L .56625 .50957 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.53246 .5237 m .53171 .51303 L .56657 .51245 L p
1 g
F P
s
P
p
.002 w
.56657 .51245 m .567 .51244 L .56658 .51257 L p
1 g
F P
s
P
p
.002 w
.56658 .51257 m .53246 .5237 L p
.56657 .51245 L 1 g
F P
s
P
p
.56658 .51257 m .56657 .51245 L .56656 .5124 L 1 g
F
P
p
.56658 .51257 m .56656 .5124 L .56625 .50957 L 1 g
F
P
p
.002 w
.56653 .51207 m .567 .51244 L .56655 .5123 L p
1 g
F P
s
P
p
.55661 .4905 m .56625 .50957 L .56228 .50135 L 1 g
F
P
p
.002 w
.57254 .47784 m .56716 .51144 L p
.56539 .50197 L 1 g
F P
s
P
p
.002 w
.56118 .47928 m .56281 .47907 L p
.56539 .50197 L 1 g
F P
s
P
p
.002 w
.56281 .47907 m .57254 .47784 L p
.56539 .50197 L 1 g
F P
s
P
p
.002 w
.56647 .51155 m .567 .51244 L .56653 .51207 L p
1 g
F P
s
P
p
.002 w
.56655 .5123 m .567 .51244 L .56657 .51245 L p
1 g
F P
s
P
p
.002 w
.56658 .51257 m .567 .51244 L .56659 .51272 L p
1 g
F P
s
P
p
.002 w
.56659 .51272 m .567 .51244 L .5666 .51291 L p
1 g
F P
s
P
p
.002 w
.56663 .51035 m .56118 .47928 L p
.56716 .51144 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55745 .49139 L p
1 g
F P
s
P
p
.002 w
.55745 .49139 m .55661 .4905 L p
.56213 .50106 L 1 g
F P
s
P
p
.56213 .50106 m .56713 .51061 L .55745 .49139 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55745 .49139 L p
1 g
F P
s
P
p
.54174 .47608 m .55745 .49139 L .55323 .48732 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.55031 .48422 m .55331 .48285 L p
.55711 .49107 L 1 g
F P
s
P
p
.55069 .48486 m .55711 .49107 L .56644 .51123 L 1 g
F
P
p
.56657 .51245 m .56651 .51188 L .56625 .50957 L 1 g
F
P
p
.002 w
.56663 .51035 m .567 .51244 L p
.55711 .49107 L 1 g
F P
s
P
p
.55331 .48285 m .55745 .49139 L .55711 .49107 L 1 g
F
P
p
.55745 .49139 m .56663 .51035 L .55711 .49107 L 1 g
F
P
p
.002 w
.56647 .51155 m .55068 .48485 L p
.56644 .51123 L 1 g
F P
s
P
p
.55069 .48486 m .56644 .51123 L .55068 .48485 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.54114 .49212 m .55016 .48435 L p
.56647 .51155 L 1 g
F P
s
P
p
.54174 .47608 m .55323 .48732 L .55189 .48602 L 1 g
F
P
p
.002 w
.55016 .48435 m .55031 .48422 L .55068 .48485 L p
1 g
F P
s
P
p
.002 w
.55068 .48485 m .56647 .51155 L p
.55016 .48435 L 1 g
F P
s
P
p
.54174 .47608 m .55189 .48602 L .55068 .48485 L 1 g
F
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.51709 .46654 m .52248 .46723 L .54969 .48389 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47674 L p
1 g
F P
s
P
p
.52214 .46667 m .54234 .47674 L .53235 .47196 L 1 g
F
P
p
.52248 .46723 m .54234 .47674 L .54969 .48389 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52248 .46723 L p
1 g
F P
s
P
p
.002 w
.52248 .46723 m .52214 .46667 L p
.53235 .47196 L 1 g
F P
s
P
p
.53235 .47196 m .54302 .47747 L .52248 .46723 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53178 .45387 m .54143 .46968 L p
.52248 .46723 L 1 g
F P
s
P
p
.5 .4634 m .52248 .46723 L .51716 .46654 L 1 g
F
P
p
.002 w
.51359 .46956 m .51709 .46654 L p
.54969 .48389 L 1 g
F P
s
P
p
.54984 .48403 m .54969 .48389 L .55031 .48422 L 1 g
F
P
p
.51359 .46956 m .54969 .48389 L .54984 .48403 L 1 g
F
P
p
.002 w
.54114 .49212 m .51359 .46956 L p
.54984 .48403 L 1 g
F P
s
P
p
.002 w
.55031 .48422 m .55016 .48435 L p
.54984 .48403 L 1 g
F P
s
P
p
.002 w
.55016 .48435 m .54114 .49212 L p
.54984 .48403 L 1 g
F P
s
P
p
.54174 .47608 m .55068 .48485 L .55016 .48435 L 1 g
F
P
p
.002 w
.54276 .47719 m .54234 .47674 L p
.55016 .48435 L 1 g
F P
s
P
p
.002 w
.54234 .47674 m .54174 .47608 L p
.55016 .48435 L 1 g
F P
s
P
p
.002 w
.54278 .47721 m .54276 .47719 L p
.55016 .48435 L 1 g
F P
s
P
p
.55016 .48435 m .55068 .48485 L .55018 .48437 L 1 g
F
P
p
.55016 .48435 m .55018 .48437 L .54278 .47721 L 1 g
F
P
p
.002 w
.51709 .46654 m .51359 .46956 L .5085 .46523 L p
1 g
F P
s
P
p
.5134 .46598 m .52268 .46755 L .51551 .46638 L 1 g
F
P
p
.5 .4634 m .5172 .46655 L .5134 .46598 L 1 g
F
P
p
.5172 .46655 m .52268 .46755 L .5134 .46598 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.53178 .45387 m .51709 .46654 L p
.48539 .44559 L 1 g
F P
s
P
p
.002 w
.5085 .46523 m .51359 .46956 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46384 L p
1 g
F P
s
P
p
.002 w
.5 .46384 m .5 .4634 L p
.51551 .46638 L 1 g
F P
s
P
p
.51551 .46638 m .52282 .46778 L .5 .46384 L 1 g
F
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46384 L p
1 g
F P
s
P
p
.002 w
.5 .46384 m .5 .46442 L p
.48756 .46568 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46384 L .48756 .46568 L 1 g
F
P
p
.002 w
.49856 .45678 m .50585 .46298 L p
.5 .46384 L 1 g
F P
s
P
p
.47756 .46716 m .48819 .46191 L .5 .46384 L 1 g
F
P
p
.48819 .46191 m .49856 .45678 L .5 .46384 L 1 g
F
P
p
.002 w
.5085 .46523 m .48539 .44559 L p
.51709 .46654 L 1 g
F P
s
P
p
.002 w
.51709 .46654 m .5185 .46532 L p
.52248 .46723 L 1 g
F P
s
P
p
.002 w
.5185 .46532 m .53178 .45387 L p
.52248 .46723 L 1 g
F P
s
P
p
.52248 .46723 m .53412 .46873 L .54234 .47674 L 1 g
F
P
p
.002 w
.54234 .47674 m .54302 .47747 L p
.53235 .47196 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54278 .47721 L p
1 g
F P
s
P
p
.55189 .48602 m .55834 .49233 L .54278 .47721 L 1 g
F
P
p
.55189 .48602 m .55803 .49201 L .55388 .48797 L 1 g
F
P
p
.55323 .48732 m .55803 .49201 L .55189 .48602 L 1 g
F
P
p
.002 w
.55068 .48485 m .55031 .48422 L p
.55069 .48486 L 1 g
F P
s
P
p
.55031 .48422 m .55711 .49107 L .55069 .48486 L 1 g
F
P
p
.002 w
.567 .51244 m .56647 .51155 L p
.56644 .51123 L 1 g
F P
s
P
p
.002 w
.56716 .51144 m .567 .51244 L .56663 .51035 L p
1 g
F P
s
P
p
.002 w
.58601 .53396 m .5761 .54036 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.59378 .52513 m .58601 .53396 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.59859 .51477 m .59378 .52513 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.5999 .50397 m .59859 .51477 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.59755 .49388 m .5999 .50397 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.59176 .4856 m .59755 .49388 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.58312 .48003 m .59176 .4856 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.57254 .47784 m .58312 .48003 L .567 .51244 L closepath p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56643 .50978 L p
.56833 .528 L 1 g
F P
s
P
p
.002 w
.56848 .52948 m .56846 .52918 L p
.56833 .528 L 1 g
F P
s
P
p
.002 w
.56846 .52918 m .56713 .51061 L p
.56833 .528 L 1 g
F P
s
P
p
.002 w
.56653 .51207 m .54114 .49212 L p
.56647 .51155 L 1 g
F P
s
P
p
.56653 .51207 m .56656 .5123 L .56651 .51188 L 1 g
F
P
p
.56657 .51245 m .56656 .51238 L .56653 .51207 L 1 g
F
P
p
.56656 .51238 m .56656 .5123 L .56653 .51207 L 1 g
F
P
p
.002 w
.53471 .5021 m .54114 .49212 L .56653 .51207 L p
1 g
F P
s
P
p
.002 w
.56655 .5123 m .53471 .5021 L p
.56653 .51207 L 1 g
F P
s
P
p
.002 w
.53171 .51303 m .53471 .5021 L .56655 .5123 L p
1 g
F P
s
P
p
.002 w
.56657 .51245 m .53171 .51303 L p
.56655 .5123 L 1 g
F P
s
P
p
.56657 .51251 m .56657 .51245 L .56656 .5123 L 1 g
F
P
p
.56659 .5128 m .56659 .51264 L .56657 .51251 L 1 g
F
P
p
.56659 .51264 m .56657 .51245 L .56657 .51251 L 1 g
F
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.53683 .53293 m .53246 .5237 L .56658 .51257 L p
1 g
F P
s
P
p
.002 w
.56659 .51272 m .53683 .53293 L p
.56658 .51257 L 1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.54432 .53974 m .53683 .53293 L .56659 .51272 L p
1 g
F P
s
P
p
.002 w
.5666 .51291 m .54432 .53974 L p
.56659 .51272 L 1 g
F P
s
P
p
.5666 .51291 m .56848 .52948 L .56657 .51245 L 1 g
F
P
p
.56705 .52034 m .56714 .52093 L .5666 .51291 L 1 g
F
P
p
.56714 .52093 m .56848 .52948 L .5666 .51291 L 1 g
F
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.55409 .54343 m .54432 .53974 L .5666 .51291 L p
1 g
F P
s
P
p
.002 w
.56663 .51333 m .55409 .54343 L p
.5666 .51291 L 1 g
F P
s
P
p
.002 w
.56643 .50978 m .56625 .50957 L p
.56658 .51252 L 1 g
F P
s
P
p
.56658 .51252 m .56848 .52948 L .56643 .50978 L 1 g
F
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56824 .54269 m .56507 .54363 L .56558 .53538 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .5617 .54746 L p
1 g
F P
s
P
p
.55777 .55745 m .5617 .54746 L .56507 .54363 L 1 g
F
P
p
.002 w
.56322 .5436 m .56477 .54363 L p
.5617 .54746 L 1 g
F P
s
P
p
.002 w
.56477 .54363 m .56507 .54363 L p
.5617 .54746 L 1 g
F P
s
P
p
.002 w
.56507 .54363 m .56123 .57065 L p
.55777 .55745 L 1 g
F P
s
P
p
.002 w
.5617 .54746 m .56075 .54566 L p
.55543 .5553 L 1 g
F P
s
P
p
.56654 .52734 m .5617 .54746 L .56264 .54507 L 1 g
F
P
p
.56654 .52734 m .562 .54802 L .56415 .5404 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54921 .56309 L p
1 g
F P
s
P
p
.56075 .54566 m .54921 .56309 L .55543 .5553 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55409 .54343 m .56322 .5436 L p
.5617 .54746 L 1 g
F P
s
P
p
.55777 .55745 m .55677 .55363 L .5617 .54746 L 1 g
F
P
p
.55677 .55363 m .55409 .54343 L .5617 .54746 L 1 g
F
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.56123 .57065 m .5398 .57039 L .54002 .56999 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57458 L p
1 g
F P
s
P
p
.5247 .5925 m .52286 .57937 L .53215 .57445 L 1 g
F
P
p
.002 w
.5398 .57039 m .5382 .57274 L p
.53215 .57445 L 1 g
F P
s
P
p
.002 w
.5382 .57274 m .5247 .5925 L p
.53215 .57445 L 1 g
F P
s
P
p
.002 w
.5317 .57458 m .53128 .57265 L p
.52242 .57719 L 1 g
F P
s
P
p
.54854 .56129 m .5317 .57458 L .53661 .57191 L 1 g
F
P
p
.002 w
.53957 .57031 m .5398 .57039 L p
.52286 .57937 L 1 g
F P
s
P
p
.53767 .57165 m .53201 .57601 L .53714 .57215 L 1 g
F
P
p
.54854 .56129 m .53396 .57427 L .53767 .57165 L 1 g
F
P
p
.53396 .57427 m .53201 .57601 L .53767 .57165 L 1 g
F
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54002 .56999 m .5398 .57039 L p
.53985 .57011 L 1 g
F P
s
P
p
.56123 .57065 m .54002 .56999 L .55759 .55678 L 1 g
F
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54933 .56341 L p
1 g
F P
s
P
p
.002 w
.54933 .56341 m .54854 .56129 L p
.53767 .57165 L 1 g
F P
s
P
p
.002 w
.5398 .57039 m .53957 .57031 L p
.53985 .57011 L 1 g
F P
s
P
p
.53767 .57165 m .5322 .57686 L .54933 .56341 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.5206 .56336 m .54432 .53974 L p
.53985 .57011 L 1 g
F P
s
P
p
.002 w
.53957 .57031 m .5206 .56336 L p
.53985 .57011 L 1 g
F P
s
P
p
.002 w
.54432 .53974 m .55409 .54343 L .54002 .56999 L p
1 g
F P
s
P
p
.53985 .57011 m .54432 .53974 L .54002 .56999 L 1 g
F
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51093 .58044 L p
1 g
F P
s
P
p
.53128 .57265 m .51093 .58044 L .52242 .57719 L 1 g
F
P
p
.002 w
.5206 .56336 m .53957 .57031 L p
.5317 .57458 L 1 g
F P
s
P
p
.52286 .57937 m .52254 .57716 L .5317 .57458 L 1 g
F
P
p
.52254 .57716 m .5206 .56336 L .5317 .57458 L 1 g
F
P
p
.49732 .58131 m .49822 .58132 L .51093 .58044 L 1 g
F
P
p
.002 w
.49822 .58132 m .5206 .56336 L p
.52289 .57961 L 1 g
F P
s
P
p
.5247 .5925 m .49822 .58132 L .52289 .57961 L 1 g
F
P
p
.002 w
.51093 .58044 m .51111 .583 L p
.52242 .57719 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5317 .57458 L p
1 g
F P
s
P
p
.52242 .57719 m .51111 .583 L .5317 .57458 L 1 g
F
P
p
.002 w
.5317 .57458 m .53201 .57601 L p
.53661 .57191 L 1 g
F P
s
P
p
.002 w
.54002 .56999 m .55409 .54343 L p
.55759 .55678 L 1 g
F P
s
P
p
.002 w
.53201 .57601 m .5322 .57686 L p
.53714 .57215 L 1 g
F P
s
P
p
.002 w
.54921 .56309 m .54998 .56518 L p
.55543 .5553 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .5617 .54746 L p
1 g
F P
s
P
p
.55543 .5553 m .54998 .56518 L .5617 .54746 L 1 g
F
P
p
.002 w
.5617 .54746 m .562 .54802 L p
.56264 .54507 L 1 g
F P
s
P
p
.002 w
.56558 .53538 m .56678 .516 L p
.56747 .5287 L 1 g
F P
s
P
p
.56824 .54269 m .56558 .53538 L .56747 .5287 L 1 g
F
P
p
.002 w
.562 .54802 m .56257 .5491 L p
.56415 .5404 L 1 g
F P
s
P
p
.002 w
.55409 .54343 m .56663 .51333 L p
.56558 .53538 L 1 g
F P
s
P
p
.002 w
.56678 .516 m .56558 .53538 L p
.56663 .51333 L 1 g
F P
s
P
p
.002 w
.56322 .5436 m .55409 .54343 L p
.56558 .53538 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56747 .5287 L p
1 g
F P
s
P
p
.56415 .5404 m .56257 .5491 L .56747 .5287 L 1 g
F
P
p
.002 w
.56854 .53025 m .56848 .52948 L p
.567 .52 L 1 g
F P
s
P
p
.56701 .52035 m .56854 .53025 L .567 .52 L 1 g
F
P
p
.002 w
.55745 .49139 m .55803 .49201 L p
.55323 .48732 L 1 g
F P
s
P
p
.002 w
.55331 .48285 m .56118 .47928 L .5645 .49821 L p
1 g
F P
s
P
p
.55331 .48285 m .5645 .49821 L .55745 .49139 L 1 g
F
P
p
.002 w
.56625 .50957 m .56625 .50957 L p
.56623 .50953 L 1 g
F P
s
P
p
.002 w
.56625 .50957 m .56713 .51061 L p
.56228 .50135 L 1 g
F P
s
P
p
.002 w
.54143 .46968 m .55031 .48422 L p
.54969 .48389 L 1 g
F P
s
P
p
.53412 .46873 m .54143 .46968 L .54969 .48389 L 1 g
F
P
p
.002 w
.55803 .49201 m .55834 .49233 L p
.55388 .48797 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52268 .46755 L p
.51716 .46654 L 1 g
F P
s
P
p
.002 w
.50585 .46298 m .5085 .46523 L p
.5 .46384 L 1 g
F P
s
P
p
.002 w
.52268 .46755 m .52282 .46778 L p
.51551 .46638 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47756 .46716 L p
1 g
F P
s
P
p
.48756 .46568 m .5 .46442 L .47756 .46716 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.46907 .47136 m .48539 .44559 L .49856 .45678 L p
1 g
F P
s
P
p
.46944 .47118 m .46955 .47113 L .46931 .47124 L 1 g
F
P
p
.002 w
.46907 .47136 m .46691 .47478 L .46445 .47358 L p
1 g
F P
s
P
p
.46955 .47113 m .47493 .46877 L .46445 .47358 L 1 g
F
P
p
.002 w
.48539 .44559 m .46907 .47136 L p
.43403 .45882 L 1 g
F P
s
P
p
.002 w
.46445 .47358 m .43403 .45882 L p
.46907 .47136 L 1 g
F P
s
P
p
.002 w
.42595 .49127 m .43403 .45882 L .46445 .47358 L p
1 g
F P
s
P
p
.002 w
.46445 .47358 m .46691 .47478 L p
.42595 .49127 L 1 g
F P
s
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45771 .47668 L p
1 g
F P
s
P
p
.47493 .46877 m .47718 .46778 L .45771 .47668 L 1 g
F
P
p
.002 w
.45771 .47668 m .45698 .47747 L p
.44841 .48569 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44282 .49111 L p
1 g
F P
s
P
p
.44841 .48569 m .45698 .47747 L .44282 .49111 L 1 g
F
P
p
.43818 .50047 m .43891 .49878 L .43722 .50241 L 1 g
F
P
p
.002 w
.46691 .47478 m .45872 .50659 L .43722 .50241 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43409 .50917 L p
1 g
F P
s
P
p
.43891 .49878 m .44166 .49233 L .43409 .50917 L 1 g
F
P
p
.4327 .52844 m .42995 .51809 L .43409 .50917 L 1 g
F
P
p
.002 w
.43409 .50917 m .43287 .51061 L p
.43324 .52097 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4327 .52844 L p
1 g
F P
s
P
p
.43324 .52097 m .43287 .51061 L .4327 .52844 L 1 g
F
P
p
.002 w
.4327 .52844 m .43146 .53025 L p
.4351 .53745 L 1 g
F P
s
P
p
.002 w
.42789 .53922 m .42382 .49981 L .42515 .50007 L p
1 g
F P
s
P
p
.002 w
.45872 .50659 m .46157 .53732 L .43546 .5388 L p
1 g
F P
s
P
p
.43388 .53288 m .45872 .50659 L .43546 .5388 L 1 g
F
P
p
.002 w
.43546 .5388 m .46157 .53732 L p
.44691 .5691 L 1 g
F P
s
P
p
.44527 .57265 m .43546 .5388 L .44691 .5691 L 1 g
F
P
p
.002 w
.43146 .53025 m .43743 .5491 L .43855 .54698 L p
1 g
F P
s
P
p
.43451 .53628 m .43146 .53025 L .43855 .54698 L 1 g
F
P
p
.002 w
.43855 .54698 m .43743 .5491 L p
.44623 .55674 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45093 .56272 L p
1 g
F P
s
P
p
.44623 .55674 m .43743 .5491 L .45093 .56272 L 1 g
F
P
p
.002 w
.45093 .56272 m .4505 .56387 L p
.45594 .56649 L 1 g
F P
s
P
p
.002 w
.46157 .53732 m .47482 .56353 L .45865 .56853 L p
1 g
F P
s
P
p
.002 w
.45865 .56853 m .47482 .56353 L p
.4684 .5741 L 1 g
F P
s
P
p
.002 w
.4505 .56387 m .45002 .56518 L p
.45922 .56886 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .4684 .5741 L p
1 g
F P
s
P
p
.45922 .56886 m .45002 .56518 L .4684 .5741 L 1 g
F
P
p
.002 w
.4684 .5741 m .4678 .57686 L p
.48042 .5779 L 1 g
F P
s
P
p
.002 w
.47355 .59669 m .44527 .57265 L .45465 .56976 L p
1 g
F P
s
P
p
.47434 .57598 m .47482 .56353 L .49616 .58287 L 1 g
F
P
p
.002 w
.48906 .58063 m .48889 .583 L p
.49667 .58144 L 1 g
F P
s
P
p
.002 w
.47482 .56353 m .49531 .5813 L p
.49431 .58119 L 1 g
F P
s
P
p
.002 w
.47482 .56353 m .50572 .55016 L p
.49706 .58131 L 1 g
F P
s
P
p
.002 w
.49531 .5813 m .47482 .56353 L p
.49706 .58131 L 1 g
F P
s
P
p
.002 w
.51111 .58299 m .511 .58142 L p
.49667 .58144 L 1 g
F P
s
P
p
.002 w
.511 .58142 m .51093 .58044 L p
.49839 .58132 L 1 g
F P
s
P
p
.49839 .58132 m .49667 .58144 L .511 .58142 L 1 g
F
P
p
.49732 .58131 m .49679 .58142 L .49822 .58132 L 1 g
F
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.50572 .55016 m .5206 .56336 L .49822 .58132 L p
1 g
F P
s
P
p
.49706 .58131 m .50572 .55016 L .49822 .58132 L 1 g
F
P
p
.49679 .58142 m .49667 .58144 L .51093 .58044 L 1 g
F
P
p
.002 w
.48889 .583 m .51111 .583 L .51111 .58299 L p
1 g
F P
s
P
p
.49667 .58144 m .48889 .583 L .51111 .58299 L 1 g
F
P
p
.002 w
.4678 .57686 m .48889 .583 L .48906 .58063 L p
1 g
F P
s
P
p
.48042 .5779 m .4678 .57686 L .48906 .58063 L 1 g
F
P
p
.002 w
.42789 .53922 m .44527 .57265 L .41806 .57733 L p
1 g
F P
s
P
p
.002 w
.41806 .57733 m .39703 .53781 L .42789 .53922 L p
1 g
F P
s
P
p
.002 w
.38753 .35437 m .35392 .40927 L .33632 .39422 L p
1 g
F P
s
P
p
.002 w
.33632 .39422 m .37118 .33693 L .38753 .35437 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.65385 .48129 m .64774 .45242 L .66575 .43109 L p
1 g
F P
s
P
p
.002 w
.64556 .39996 m .66575 .43109 L .64774 .45242 L p
1 g
F P
s
P
p
.002 w
.66575 .43109 m .64556 .39996 L .65474 .37321 L p
1 g
F P
s
P
p
.002 w
.39175 .491 m .39703 .53781 L .36999 .53325 L p
1 g
F P
s
P
p
.002 w
.36999 .53325 m .36362 .48054 L .39175 .491 L p
1 g
F P
s
P
p
.002 w
.55834 .28033 m .49674 .28567 L .485 .2655 L p
1 g
F P
s
P
p
.002 w
.42296 .29209 m .485 .2655 L .49674 .28567 L p
1 g
F P
s
P
p
.002 w
.61799 .34708 m .65474 .37321 L .64556 .39996 L p
1 g
F P
s
P
p
.002 w
.65474 .37321 m .61799 .34708 L .61795 .31912 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51693 .45122 L
s
P
p
.002 w
.37653 .42543 m .36362 .48054 L .3403 .46888 L p
1 g
F P
s
P
p
.002 w
.3403 .46888 m .35392 .40927 L .37653 .42543 L p
1 g
F P
s
P
p
.002 w
.56595 .30566 m .61795 .31912 L .61799 .34708 L p
1 g
F P
s
P
p
.002 w
.61795 .31912 m .56595 .30566 L .55834 .28033 L p
1 g
F P
s
P
p
.002 w
.62645 .5145 m .62917 .49344 L .65385 .48129 L p
1 g
F P
s
P
p
.002 w
.64774 .45242 m .65385 .48129 L .62917 .49344 L p
1 g
F P
s
P
p
.002 w
.49674 .28567 m .55834 .28033 L .56595 .30566 L p
1 g
F P
s
P
p
.002 w
.43725 .31133 m .38753 .35437 L .37118 .33693 L p
1 g
F P
s
P
p
.002 w
.37118 .33693 m .42296 .29209 L .43725 .31133 L p
1 g
F P
s
P
p
.002 w
.49674 .28567 m .43725 .31133 L .42296 .29209 L p
1 g
F P
s
P
p
.002 w
.5761 .54036 m .58601 .53396 L .6019 .55176 L p
1 g
F P
s
P
p
.002 w
.6019 .55176 m .58266 .5642 L .5761 .54036 L p
1 g
F P
s
P
p
.002 w
.61701 .53462 m .6019 .55176 L .58601 .53396 L p
1 g
F P
s
P
p
.002 w
.56507 .54363 m .5761 .54036 L .58266 .5642 L p
1 g
F P
s
P
p
.002 w
.58266 .5642 m .56123 .57065 L .56507 .54363 L p
1 g
F P
s
P
p
.002 w
.58601 .53396 m .59378 .52513 L .61701 .53462 L p
1 g
F P
s
P
p
.002 w
.62645 .5145 m .61701 .53462 L .59378 .52513 L p
1 g
F P
s
P
p
.002 w
.59378 .52513 m .59859 .51477 L .62645 .5145 L p
1 g
F P
s
P
p
.002 w
.62917 .49344 m .62645 .5145 L .59859 .51477 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.62917 .49344 m .62477 .47362 L .64774 .45242 L p
1 g
F P
s
P
p
.002 w
.63173 .42828 m .64774 .45242 L .62477 .47362 L p
1 g
F P
s
P
p
.002 w
.64774 .45242 m .63173 .42828 L .64556 .39996 L p
1 g
F P
s
P
p
.002 w
.61442 .37827 m .64556 .39996 L .63173 .42828 L p
1 g
F P
s
P
p
.002 w
.64556 .39996 m .61442 .37827 L .61799 .34708 L p
1 g
F P
s
P
p
.002 w
.42382 .49981 m .42789 .53922 L .39703 .53781 L p
1 g
F P
s
P
p
.002 w
.39703 .53781 m .39175 .491 L .42382 .49981 L p
1 g
F P
s
P
p
.002 w
.40783 .37468 m .37653 .42543 L .35392 .40927 L p
1 g
F P
s
P
p
.002 w
.35392 .40927 m .38753 .35437 L .40783 .37468 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.40353 .44216 m .39175 .491 L .36362 .48054 L p
1 g
F P
s
P
p
.002 w
.36362 .48054 m .37653 .42543 L .40353 .44216 L p
1 g
F P
s
P
p
.002 w
.56595 .30566 m .50895 .3109 L .49674 .28567 L p
1 g
F P
s
P
p
.002 w
.43725 .31133 m .49674 .28567 L .50895 .3109 L p
1 g
F P
s
P
p
.004 w
.46415 .27277 m
.47205 .30755 L
s
P
p
.002 w
.57175 .3355 m .61799 .34708 L .61442 .37827 L p
1 g
F P
s
P
p
.002 w
.61799 .34708 m .57175 .3355 L .56595 .30566 L p
1 g
F P
s
P
p
.002 w
.59859 .51477 m .5999 .50397 L .62917 .49344 L p
1 g
F P
s
P
p
.002 w
.62477 .47362 m .62917 .49344 L .5999 .50397 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.50895 .3109 m .56595 .30566 L .57175 .3355 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.45391 .33482 m .40783 .37468 L .38753 .35437 L p
1 g
F P
s
P
p
.002 w
.38753 .35437 m .43725 .31133 L .45391 .33482 L p
1 g
F P
s
P
p
.002 w
.49686 .53209 m .50572 .55016 L .47482 .56353 L p
1 g
F P
s
P
p
.002 w
.47482 .56353 m .46157 .53732 L .49686 .53209 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.50895 .3109 m .45391 .33482 L .43725 .31133 L p
1 g
F P
s
P
p
.002 w
.53683 .53293 m .54432 .53974 L .5206 .56336 L p
1 g
F P
s
P
p
.002 w
.5206 .56336 m .50572 .55016 L .53683 .53293 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.5999 .50397 m .59755 .49388 L .62477 .47362 L p
1 g
F P
s
P
p
.002 w
.6136 .45718 m .62477 .47362 L .59755 .49388 L p
1 g
F P
s
P
p
.002 w
.62477 .47362 m .6136 .45718 L .63173 .42828 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.60727 .41165 m .63173 .42828 L .6136 .45718 L p
1 g
F P
s
P
p
.002 w
.63173 .42828 m .60727 .41165 L .61442 .37827 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.57545 .36889 m .61442 .37827 L .60727 .41165 L p
1 g
F P
s
P
p
.002 w
.61442 .37827 m .57545 .36889 L .57175 .3355 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.43403 .45882 m .42382 .49981 L .39175 .491 L p
1 g
F P
s
P
p
.002 w
.39175 .491 m .40353 .44216 L .43403 .45882 L p
1 g
F P
s
P
p
.002 w
.43148 .39721 m .40353 .44216 L .37653 .42543 L p
1 g
F P
s
P
p
.002 w
.37653 .42543 m .40783 .37468 L .43148 .39721 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.57175 .3355 m .52119 .34046 L .50895 .3109 L p
1 g
F P
s
P
p
.002 w
.45391 .33482 m .50895 .3109 L .52119 .34046 L p
1 g
F P
s
P
p
.004 w
.47778 .33274 m
.47796 .33354 L
s
P
p
.004 w
.47872 .3369 m
.5 .43051 L
s
P
p
.004 w
.47688 .32877 m
.47778 .33274 L
s
P
p
.004 w
.47205 .30755 m
.47688 .32877 L
s
P
p
.002 w
.53246 .5237 m .53683 .53293 L .50572 .55016 L p
1 g
F P
s
P
p
.002 w
.50572 .55016 m .49686 .53209 L .53246 .5237 L p
1 g
F P
s
P
p
.002 w
.52119 .34046 m .57175 .3355 L .57545 .36889 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53025 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.59755 .49388 m .59176 .4856 L .6136 .45718 L p
1 g
F P
s
P
p
.002 w
.59671 .44601 m .6136 .45718 L .59176 .4856 L p
1 g
F P
s
P
p
.002 w
.6136 .45718 m .59671 .44601 L .60727 .41165 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49515 .51106 m .49686 .53209 L .46157 .53732 L p
1 g
F P
s
P
p
.002 w
.46157 .53732 m .45872 .50659 L .49515 .51106 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57685 .40466 m .60727 .41165 L .59671 .44601 L p
1 g
F P
s
P
p
.002 w
.60727 .41165 m .57685 .40466 L .57545 .36889 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.47239 .36184 m .43148 .39721 L .40783 .37468 L p
1 g
F P
s
P
p
.002 w
.40783 .37468 m .45391 .33482 L .47239 .36184 L p
1 g
F P
s
P
p
.002 w
.59176 .4856 m .58312 .48003 L .59671 .44601 L p
1 g
F P
s
P
p
.002 w
.52119 .34046 m .47239 .36184 L .45391 .33482 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.53171 .51303 m .53246 .5237 L .49686 .53209 L p
1 g
F P
s
P
p
.002 w
.49686 .53209 m .49515 .51106 L .53171 .51303 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.57587 .44145 m .59671 .44601 L .58312 .48003 L p
1 g
F P
s
P
p
.002 w
.59671 .44601 m .57587 .44145 L .57685 .40466 L p
1 g
F P
s
P
p
.002 w
.53297 .37335 m .57545 .36889 L .57685 .40466 L p
1 g
F P
s
P
p
.002 w
.57545 .36889 m .53297 .37335 L .52119 .34046 L p
1 g
F P
s
P
p
.002 w
.45766 .42115 m .43403 .45882 L .40353 .44216 L p
1 g
F P
s
P
p
.002 w
.40353 .44216 m .43148 .39721 L .45766 .42115 L p
1 g
F P
s
P
p
.002 w
.58312 .48003 m .57254 .47784 L .57587 .44145 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.47239 .36184 m .52119 .34046 L .53297 .37335 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.53471 .5021 m .53171 .51303 L .49515 .51106 L p
1 g
F P
s
P
p
.002 w
.57254 .47784 m .56118 .47928 L .55337 .44414 L p
1 g
F P
s
P
p
.002 w
.55337 .44414 m .57587 .44145 L .57254 .47784 L p
1 g
F P
s
P
p
.002 w
.50091 .48939 m .49515 .51106 L .45872 .50659 L p
1 g
F P
s
P
p
.002 w
.45872 .50659 m .46691 .47478 L .50091 .48939 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54385 .40836 m .57685 .40466 L .57587 .44145 L p
1 g
F P
s
P
p
.002 w
.57685 .40466 m .54385 .40836 L .53297 .37335 L p
1 g
F P
s
P
p
.002 w
.49515 .51106 m .50091 .48939 L .53471 .5021 L p
1 g
F P
s
P
p
.002 w
.54114 .49212 m .53471 .5021 L .50091 .48939 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.56118 .47928 m .55031 .48422 L .53178 .45387 L p
1 g
F P
s
P
p
.002 w
.53178 .45387 m .55337 .44414 L .56118 .47928 L p
1 g
F P
s
P
p
.002 w
.57587 .44145 m .55337 .44414 L .54385 .40836 L p
1 g
F P
s
P
p
.002 w
.49204 .39145 m .45766 .42115 L .43148 .39721 L p
1 g
F P
s
P
p
.002 w
.43148 .39721 m .47239 .36184 L .49204 .39145 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.50091 .48939 m .51359 .46956 L .54114 .49212 L p
1 g
F P
s
P
p
.002 w
.53297 .37335 m .49204 .39145 L .47239 .36184 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.43403 .45882 m .45766 .42115 L .48539 .44559 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.49204 .39145 m .53297 .37335 L .54385 .40836 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.51359 .46956 m .50091 .48939 L .46691 .47478 L p
1 g
F P
s
P
p
.002 w
.55337 .44414 m .53178 .45387 L .51209 .42253 L p
1 g
F P
s
P
p
.002 w
.51209 .42253 m .54385 .40836 L .55337 .44414 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.54385 .40836 m .51209 .42253 L .49204 .39145 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51209 .42253 m .48539 .44559 L .45766 .42115 L p
1 g
F P
s
P
p
.002 w
.45766 .42115 m .49204 .39145 L .51209 .42253 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.48539 .44559 m .51209 .42253 L .53178 .45387 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.004 w
.58997 .54053 m
.60751 .56199 L
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .46415 .27277 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60751 .56199 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.694574)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.694574)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.48266 .47316 m .52101 .4562 L .50624 .43187 L p
1 g
F P
s
P
p
.002 w
.50624 .43187 m .47428 .44595 L .48266 .47316 L p
1 g
F P
s
P
p
.002 w
.53328 .40994 m .50624 .43187 L .52101 .4562 L p
1 g
F P
s
P
p
.002 w
.47428 .44595 m .50624 .43187 L .49134 .40753 L p
1 g
F P
s
P
p
.002 w
.50624 .43187 m .53328 .40994 L .51226 .39047 L p
1 g
F P
s
P
p
.002 w
.51226 .39047 m .49134 .40753 L .50624 .43187 L p
1 g
F P
s
P
p
.002 w
.49134 .40753 m .46653 .41842 L .47428 .44595 L p
1 g
F P
s
P
p
.002 w
.46653 .41842 m .49134 .40753 L .47656 .38361 L p
1 g
F P
s
P
p
.002 w
.49134 .40753 m .51226 .39047 L .49087 .3719 L p
1 g
F P
s
P
p
.002 w
.49087 .3719 m .47656 .38361 L .49134 .40753 L p
1 g
F P
s
P
p
.002 w
.44202 .47921 m .48266 .47316 L .47428 .44595 L p
1 g
F P
s
P
p
.002 w
.47428 .44595 m .44042 .45081 L .44202 .47921 L p
1 g
F P
s
P
p
.002 w
.44042 .45081 m .47428 .44595 L .46653 .41842 L p
1 g
F P
s
P
p
.002 w
.49154 .49955 m .53538 .48009 L .52101 .4562 L p
1 g
F P
s
P
p
.002 w
.52101 .4562 m .48266 .47316 L .49154 .49955 L p
1 g
F P
s
P
p
.002 w
.55353 .42995 m .52101 .4562 L .53538 .48009 L p
1 g
F P
s
P
p
.002 w
.52101 .4562 m .55353 .42995 L .53328 .40994 L p
1 g
F P
s
P
p
.002 w
.46653 .41842 m .44028 .42205 L .44042 .45081 L p
1 g
F P
s
P
p
.002 w
.44028 .42205 m .46653 .41842 L .45956 .39105 L p
1 g
F P
s
P
p
.002 w
.47656 .38361 m .45956 .39105 L .46653 .41842 L p
1 g
F P
s
P
p
.002 w
.55275 .3822 m .53328 .40994 L .55353 .42995 L p
1 g
F P
s
P
p
.002 w
.53328 .40994 m .55275 .3822 L .52722 .36889 L p
1 g
F P
s
P
p
.002 w
.52722 .36889 m .51226 .39047 L .53328 .40994 L p
1 g
F P
s
P
p
.002 w
.51226 .39047 m .52722 .36889 L .501 .35708 L p
1 g
F P
s
P
p
.002 w
.501 .35708 m .49087 .3719 L .51226 .39047 L p
1 g
F P
s
P
p
.002 w
.44506 .50669 m .49154 .49955 L .48266 .47316 L p
1 g
F P
s
P
p
.002 w
.48266 .47316 m .44202 .47921 L .44506 .50669 L p
1 g
F P
s
P
p
.002 w
.45956 .39105 m .47656 .38361 L .46219 .36056 L p
1 g
F P
s
P
p
.002 w
.47656 .38361 m .49087 .3719 L .46947 .35457 L p
1 g
F P
s
P
p
.002 w
.46947 .35457 m .46219 .36056 L .47656 .38361 L p
1 g
F P
s
P
p
.002 w
.53538 .48009 m .57265 .45014 L .55353 .42995 L p
1 g
F P
s
P
p
.002 w
.57713 .39676 m .55353 .42995 L .57265 .45014 L p
1 g
F P
s
P
p
.002 w
.55353 .42995 m .57713 .39676 L .55275 .3822 L p
1 g
F P
s
P
p
.002 w
.45956 .39105 m .44158 .39344 L .44028 .42205 L p
1 g
F P
s
P
p
.002 w
.44158 .39344 m .45956 .39105 L .4535 .36435 L p
1 g
F P
s
P
p
.002 w
.46219 .36056 m .4535 .36435 L .45956 .39105 L p
1 g
F P
s
P
p
.002 w
.49087 .3719 m .501 .35708 L .4746 .34699 L p
1 g
F P
s
P
p
.002 w
.4746 .34699 m .46947 .35457 L .49087 .3719 L p
1 g
F P
s
P
p
.002 w
.40792 .44581 m .44042 .45081 L .44028 .42205 L p
1 g
F P
s
P
p
.002 w
.44028 .42205 m .41516 .41796 L .40792 .44581 L p
1 g
F P
s
P
p
.002 w
.41516 .41796 m .44028 .42205 L .44158 .39344 L p
1 g
F P
s
P
p
.002 w
.50074 .52461 m .54907 .50308 L .53538 .48009 L p
1 g
F P
s
P
p
.002 w
.53538 .48009 m .49154 .49955 L .50074 .52461 L p
1 g
F P
s
P
p
.002 w
.57265 .45014 m .53538 .48009 L .54907 .50308 L p
1 g
F P
s
P
p
.002 w
.40289 .47352 m .44202 .47921 L .44042 .45081 L p
1 g
F P
s
P
p
.002 w
.44042 .45081 m .40792 .44581 L .40289 .47352 L p
1 g
F P
s
P
p
.002 w
.5346 .34489 m .52722 .36889 L .55275 .3822 L p
1 g
F P
s
P
p
.002 w
.52722 .36889 m .5346 .34489 L .50588 .34065 L p
1 g
F P
s
P
p
.002 w
.50588 .34065 m .501 .35708 L .52722 .36889 L p
1 g
F P
s
P
p
.002 w
.44158 .39344 m .42446 .3905 L .41516 .41796 L p
1 g
F P
s
P
p
.002 w
.42446 .3905 m .44158 .39344 L .44433 .36552 L p
1 g
F P
s
P
p
.002 w
.4535 .36435 m .44433 .36552 L .44158 .39344 L p
1 g
F P
s
P
p
.002 w
.4495 .53274 m .50074 .52461 L .49154 .49955 L p
1 g
F P
s
P
p
.002 w
.49154 .49955 m .44506 .50669 L .4495 .53274 L p
1 g
F P
s
P
p
.002 w
.56259 .35125 m .55275 .3822 L .57713 .39676 L p
1 g
F P
s
P
p
.002 w
.55275 .3822 m .56259 .35125 L .5346 .34489 L p
1 g
F P
s
P
p
.002 w
.501 .35708 m .50588 .34065 L .477 .33861 L p
1 g
F P
s
P
p
.002 w
.477 .33861 m .4746 .34699 L .501 .35708 L p
1 g
F P
s
P
p
.002 w
.54907 .50308 m .59026 .47014 L .57265 .45014 L p
1 g
F P
s
P
p
.002 w
.59988 .41232 m .57265 .45014 L .59026 .47014 L p
1 g
F P
s
P
p
.002 w
.57265 .45014 m .59988 .41232 L .57713 .39676 L p
1 g
F P
s
P
p
.002 w
.4002 .50055 m .44506 .50669 L .44202 .47921 L p
1 g
F P
s
P
p
.002 w
.44202 .47921 m .40289 .47352 L .4002 .50055 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .4535 .36435 L .46219 .36056 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .46219 .36056 L .46947 .35457 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .44433 .36552 L .4535 .36435 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .46947 .35457 L .4746 .34699 L closepath p
1 g
F P
s
P
p
.002 w
.58932 .35965 m .57713 .39676 L .59988 .41232 L p
1 g
F P
s
P
p
.002 w
.57713 .39676 m .58932 .35965 L .56259 .35125 L p
1 g
F P
s
P
p
.002 w
.39379 .40639 m .41516 .41796 L .42446 .3905 L p
1 g
F P
s
P
p
.002 w
.42446 .3905 m .40999 .38245 L .39379 .40639 L p
1 g
F P
s
P
p
.002 w
.40999 .38245 m .42446 .3905 L .43564 .36395 L p
1 g
F P
s
P
p
.002 w
.44433 .36552 m .43564 .36395 L .42446 .3905 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .43564 .36395 L .44433 .36552 L closepath p
1 g
F P
s
P
p
.002 w
.38009 .43115 m .40792 .44581 L .41516 .41796 L p
1 g
F P
s
P
p
.002 w
.41516 .41796 m .39379 .40639 L .38009 .43115 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .4746 .34699 L .477 .33861 L closepath p
1 g
F P
s
P
p
.002 w
.51011 .54784 m .56182 .52473 L .54907 .50308 L p
1 g
F P
s
P
p
.002 w
.54907 .50308 m .50074 .52461 L .51011 .54784 L p
1 g
F P
s
P
p
.002 w
.59026 .47014 m .54907 .50308 L .56182 .52473 L p
1 g
F P
s
P
p
.002 w
.50491 .3243 m .50588 .34065 L .5346 .34489 L p
1 g
F P
s
P
p
.002 w
.50588 .34065 m .50491 .3243 L .4764 .33033 L p
1 g
F P
s
P
p
.002 w
.4764 .33033 m .477 .33861 L .50588 .34065 L p
1 g
F P
s
P
p
.002 w
.53347 .32086 m .5346 .34489 L .56259 .35125 L p
1 g
F P
s
P
p
.002 w
.5346 .34489 m .53347 .32086 L .50491 .3243 L p
1 g
F P
s
P
p
.002 w
.43564 .36395 m .42834 .35978 L .40999 .38245 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .42834 .35978 L .43564 .36395 L closepath p
1 g
F P
s
P
p
.002 w
.36919 .45624 m .40289 .47352 L .40792 .44581 L p
1 g
F P
s
P
p
.002 w
.40792 .44581 m .38009 .43115 L .36919 .45624 L p
1 g
F P
s
P
p
.002 w
.39997 .52634 m .4495 .53274 L .44506 .50669 L p
1 g
F P
s
P
p
.002 w
.44506 .50669 m .4002 .50055 L .39997 .52634 L p
1 g
F P
s
P
p
.002 w
.45531 .55678 m .51011 .54784 L .50074 .52461 L p
1 g
F P
s
P
p
.002 w
.50074 .52461 m .4495 .53274 L .45531 .55678 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .477 .33861 L .4764 .33033 L closepath p
1 g
F P
s
P
p
.002 w
.56182 .52473 m .60599 .48956 L .59026 .47014 L p
1 g
F P
s
P
p
.002 w
.62054 .42858 m .59026 .47014 L .60599 .48956 L p
1 g
F P
s
P
p
.002 w
.59026 .47014 m .62054 .42858 L .59988 .41232 L p
1 g
F P
s
P
p
.002 w
.39977 .37004 m .40999 .38245 L .42834 .35978 L p
1 g
F P
s
P
p
.002 w
.42834 .35978 m .42325 .35343 L .39977 .37004 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .42325 .35343 L .42834 .35978 L closepath p
1 g
F P
s
P
p
.002 w
.5615 .32012 m .56259 .35125 L .58932 .35965 L p
1 g
F P
s
P
p
.002 w
.56259 .35125 m .5615 .32012 L .53347 .32086 L p
1 g
F P
s
P
p
.002 w
.61422 .36994 m .59988 .41232 L .62054 .42858 L p
1 g
F P
s
P
p
.002 w
.59988 .41232 m .61422 .36994 L .58932 .35965 L p
1 g
F P
s
P
p
.002 w
.37852 .38834 m .39379 .40639 L .40999 .38245 L p
1 g
F P
s
P
p
.002 w
.40999 .38245 m .39977 .37004 L .37852 .38834 L p
1 g
F P
s
P
p
.002 w
.47284 .32303 m .4764 .33033 L .50491 .3243 L p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .4764 .33033 L .47284 .32303 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .44008 .31663 L .43181 .32171 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .43181 .32171 L .42544 .32878 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .42544 .32878 L .42169 .33704 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .42169 .33704 L .42094 .34557 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .42094 .34557 L .42325 .35343 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .47284 .32303 L .46667 .31752 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .46667 .31752 L .45854 .31443 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .45854 .31443 L .44934 .31411 L closepath p
1 g
F P
s
P
p
.002 w
.44849 .33883 m .44934 .31411 L .44008 .31663 L closepath p
1 g
F P
s
P
p
.002 w
.3614 .48117 m .4002 .50055 L .40289 .47352 L p
1 g
F P
s
P
p
.002 w
.40289 .47352 m .36919 .45624 L .3614 .48117 L p
1 g
F P
s
P
p
.002 w
.49807 .30978 m .50491 .3243 L .53347 .32086 L p
1 g
F P
s
P
p
.002 w
.50491 .3243 m .49807 .30978 L .47284 .32303 L p
1 g
F P
s
P
p
.002 w
.39499 .35452 m .39977 .37004 L .42325 .35343 L p
1 g
F P
s
P
p
.002 w
.42325 .35343 m .42094 .34557 L .39499 .35452 L p
1 g
F P
s
P
p
.002 w
.36 .408 m .38009 .43115 L .39379 .40639 L p
1 g
F P
s
P
p
.002 w
.39379 .40639 m .37852 .38834 L .36 .408 L p
1 g
F P
s
P
p
.002 w
.46667 .31752 m .47284 .32303 L .49807 .30978 L p
1 g
F P
s
P
p
.002 w
.51946 .56871 m .57334 .54456 L .56182 .52473 L p
1 g
F P
s
P
p
.002 w
.56182 .52473 m .51011 .54784 L .51946 .56871 L p
1 g
F P
s
P
p
.002 w
.60599 .48956 m .56182 .52473 L .57334 .54456 L p
1 g
F P
s
P
p
.002 w
.58843 .32216 m .58932 .35965 L .61422 .36994 L p
1 g
F P
s
P
p
.002 w
.58932 .35965 m .58843 .32216 L .5615 .32012 L p
1 g
F P
s
P
p
.002 w
.40229 .55031 m .45531 .55678 L .4495 .53274 L p
1 g
F P
s
P
p
.002 w
.4495 .53274 m .39997 .52634 L .40229 .55031 L p
1 g
F P
s
P
p
.002 w
.52368 .29937 m .53347 .32086 L .5615 .32012 L p
1 g
F P
s
P
p
.002 w
.53347 .32086 m .52368 .29937 L .49807 .30978 L p
1 g
F P
s
P
p
.002 w
.3963 .33756 m .39499 .35452 L .42094 .34557 L p
1 g
F P
s
P
p
.002 w
.42094 .34557 m .42169 .33704 L .3963 .33756 L p
1 g
F P
s
P
p
.002 w
.37121 .36557 m .37852 .38834 L .39977 .37004 L p
1 g
F P
s
P
p
.002 w
.39977 .37004 m .39499 .35452 L .37121 .36557 L p
1 g
F P
s
P
p
.002 w
.46242 .57825 m .51946 .56871 L .51011 .54784 L p
1 g
F P
s
P
p
.002 w
.51011 .54784 m .45531 .55678 L .46242 .57825 L p
1 g
F P
s
P
p
.002 w
.49807 .30978 m .48597 .29871 L .46667 .31752 L p
1 g
F P
s
P
p
.002 w
.45854 .31443 m .46667 .31752 L .48597 .29871 L p
1 g
F P
s
P
p
.002 w
.34466 .42864 m .36919 .45624 L .38009 .43115 L p
1 g
F P
s
P
p
.002 w
.38009 .43115 m .36 .408 L .34466 .42864 L p
1 g
F P
s
P
p
.002 w
.60599 .48956 m .63861 .44526 L .62054 .42858 L p
1 g
F P
s
P
p
.002 w
.63674 .38197 m .62054 .42858 L .63861 .44526 L p
1 g
F P
s
P
p
.002 w
.62054 .42858 m .63674 .38197 L .61422 .36994 L p
1 g
F P
s
P
p
.002 w
.48597 .29871 m .49807 .30978 L .52368 .29937 L p
1 g
F P
s
P
p
.002 w
.57334 .54456 m .61944 .508 L .60599 .48956 L p
1 g
F P
s
P
p
.002 w
.63861 .44526 m .60599 .48956 L .61944 .508 L p
1 g
F P
s
P
p
.002 w
.35698 .50538 m .39997 .52634 L .4002 .50055 L p
1 g
F P
s
P
p
.002 w
.4002 .50055 m .3614 .48117 L .35698 .50538 L p
1 g
F P
s
P
p
.002 w
.40369 .32104 m .3963 .33756 L .42169 .33704 L p
1 g
F P
s
P
p
.002 w
.42169 .33704 m .42544 .32878 L .40369 .32104 L p
1 g
F P
s
P
p
.002 w
.48597 .29871 m .46986 .29241 L .45854 .31443 L p
1 g
F P
s
P
p
.002 w
.44934 .31411 m .45854 .31443 L .46986 .29241 L p
1 g
F P
s
P
p
.002 w
.41638 .30686 m .40369 .32104 L .42544 .32878 L p
1 g
F P
s
P
p
.002 w
.42544 .32878 m .43181 .32171 L .41638 .30686 L p
1 g
F P
s
P
p
.002 w
.54915 .2921 m .5615 .32012 L .58843 .32216 L p
1 g
F P
s
P
p
.002 w
.5615 .32012 m .54915 .2921 L .52368 .29937 L p
1 g
F P
s
P
p
.002 w
.46986 .29241 m .45149 .29168 L .44934 .31411 L p
1 g
F P
s
P
p
.002 w
.44008 .31663 m .44934 .31411 L .45149 .29168 L p
1 g
F P
s
P
p
.002 w
.43295 .29668 m .41638 .30686 L .43181 .32171 L p
1 g
F P
s
P
p
.002 w
.43181 .32171 m .44008 .31663 L .43295 .29668 L p
1 g
F P
s
P
p
.002 w
.35017 .37852 m .36 .408 L .37852 .38834 L p
1 g
F P
s
P
p
.002 w
.37852 .38834 m .37121 .36557 L .35017 .37852 L p
1 g
F P
s
P
p
.002 w
.45149 .29168 m .43295 .29668 L .44008 .31663 L p
1 g
F P
s
P
p
.002 w
.61366 .32699 m .61422 .36994 L .63674 .38197 L p
1 g
F P
s
P
p
.002 w
.61422 .36994 m .61366 .32699 L .58843 .32216 L p
1 g
F P
s
P
p
.002 w
.37293 .34047 m .37121 .36557 L .39499 .35452 L p
1 g
F P
s
P
p
.002 w
.39499 .35452 m .3963 .33756 L .37293 .34047 L p
1 g
F P
s
P
p
.002 w
.52368 .29937 m .50602 .28286 L .48597 .29871 L p
1 g
F P
s
P
p
.002 w
.46986 .29241 m .48597 .29871 L .50602 .28286 L p
1 g
F P
s
P
p
.002 w
.50602 .28286 m .52368 .29937 L .54915 .2921 L p
1 g
F P
s
P
p
.002 w
.33296 .44985 m .3614 .48117 L .36919 .45624 L p
1 g
F P
s
P
p
.002 w
.36919 .45624 m .34466 .42864 L .33296 .44985 L p
1 g
F P
s
P
p
.002 w
.4072 .57186 m .46242 .57825 L .45531 .55678 L p
1 g
F P
s
P
p
.002 w
.45531 .55678 m .40229 .55031 L .4072 .57186 L p
1 g
F P
s
P
p
.002 w
.52861 .58668 m .58334 .56209 L .57334 .54456 L p
1 g
F P
s
P
p
.002 w
.57334 .54456 m .51946 .56871 L .52861 .58668 L p
1 g
F P
s
P
p
.002 w
.61944 .508 m .57334 .54456 L .58334 .56209 L p
1 g
F P
s
P
p
.002 w
.35616 .52831 m .40229 .55031 L .39997 .52634 L p
1 g
F P
s
P
p
.002 w
.39997 .52634 m .35698 .50538 L .35616 .52831 L p
1 g
F P
s
P
p
.002 w
.38375 .31588 m .37293 .34047 L .3963 .33756 L p
1 g
F P
s
P
p
.002 w
.3963 .33756 m .40369 .32104 L .38375 .31588 L p
1 g
F P
s
P
p
.002 w
.61944 .508 m .65364 .46201 L .63861 .44526 L p
1 g
F P
s
P
p
.002 w
.65632 .39555 m .63861 .44526 L .65364 .46201 L p
1 g
F P
s
P
p
.002 w
.63861 .44526 m .65632 .39555 L .63674 .38197 L p
1 g
F P
s
P
p
.002 w
.47071 .59657 m .52861 .58668 L .51946 .56871 L p
1 g
F P
s
P
p
.002 w
.51946 .56871 m .46242 .57825 L .47071 .59657 L p
1 g
F P
s
P
p
.002 w
.57393 .28821 m .58843 .32216 L .61366 .32699 L p
1 g
F P
s
P
p
.002 w
.58843 .32216 m .57393 .28821 L .54915 .2921 L p
1 g
F P
s
P
p
.002 w
.50602 .28286 m .48225 .27334 L .46986 .29241 L p
1 g
F P
s
P
p
.002 w
.45149 .29168 m .46986 .29241 L .48225 .27334 L p
1 g
F P
s
P
p
.002 w
.33245 .39319 m .34466 .42864 L .36 .408 L p
1 g
F P
s
P
p
.002 w
.36 .408 m .35017 .37852 L .33245 .39319 L p
1 g
F P
s
P
p
.002 w
.58334 .56209 m .63024 .52501 L .61944 .508 L p
1 g
F P
s
P
p
.002 w
.65364 .46201 m .61944 .508 L .63024 .52501 L p
1 g
F P
s
P
p
.002 w
.35216 .3458 m .35017 .37852 L .37121 .36557 L p
1 g
F P
s
P
p
.002 w
.37121 .36557 m .37293 .34047 L .35216 .3458 L p
1 g
F P
s
P
p
.002 w
.63659 .33461 m .63674 .38197 L .65632 .39555 L p
1 g
F P
s
P
p
.002 w
.63674 .38197 m .63659 .33461 L .61366 .32699 L p
1 g
F P
s
P
p
.002 w
.40259 .29471 m .38375 .31588 L .40369 .32104 L p
1 g
F P
s
P
p
.002 w
.40369 .32104 m .41638 .30686 L .40259 .29471 L p
1 g
F P
s
P
p
.002 w
.52642 .27039 m .54915 .2921 L .57393 .28821 L p
1 g
F P
s
P
p
.002 w
.54915 .2921 m .52642 .27039 L .50602 .28286 L p
1 g
F P
s
P
p
.002 w
.48225 .27334 m .45496 .27213 L .45149 .29168 L p
1 g
F P
s
P
p
.002 w
.43295 .29668 m .45149 .29168 L .45496 .27213 L p
1 g
F P
s
P
p
.002 w
.3253 .47115 m .35698 .50538 L .3614 .48117 L p
1 g
F P
s
P
p
.002 w
.3614 .48117 m .33296 .44985 L .3253 .47115 L p
1 g
F P
s
P
p
.002 w
.48225 .27334 m .50602 .28286 L .52642 .27039 L p
1 g
F P
s
P
p
.002 w
.42731 .27952 m .40259 .29471 L .41638 .30686 L p
1 g
F P
s
P
p
.002 w
.41638 .30686 m .43295 .29668 L .42731 .27952 L p
1 g
F P
s
P
p
.002 w
.45496 .27213 m .42731 .27952 L .43295 .29668 L p
1 g
F P
s
P
p
.002 w
.41471 .5904 m .47071 .59657 L .46242 .57825 L p
1 g
F P
s
P
p
.002 w
.46242 .57825 m .4072 .57186 L .41471 .5904 L p
1 g
F P
s
P
p
.002 w
.59746 .28792 m .61366 .32699 L .63659 .33461 L p
1 g
F P
s
P
p
.002 w
.61366 .32699 m .59746 .28792 L .57393 .28821 L p
1 g
F P
s
P
p
.002 w
.35912 .54937 m .4072 .57186 L .40229 .55031 L p
1 g
F P
s
P
p
.002 w
.40229 .55031 m .35616 .52831 L .35912 .54937 L p
1 g
F P
s
P
p
.002 w
.3186 .40928 m .33296 .44985 L .34466 .42864 L p
1 g
F P
s
P
p
.002 w
.34466 .42864 m .33245 .39319 L .3186 .40928 L p
1 g
F P
s
P
p
.002 w
.36617 .31354 m .35216 .3458 L .37293 .34047 L p
1 g
F P
s
P
p
.002 w
.37293 .34047 m .38375 .31588 L .36617 .31354 L p
1 g
F P
s
P
p
.002 w
.53733 .60122 m .59152 .57681 L .58334 .56209 L p
1 g
F P
s
P
p
.002 w
.58334 .56209 m .52861 .58668 L .53733 .60122 L p
1 g
F P
s
P
p
.002 w
.63024 .52501 m .58334 .56209 L .59152 .57681 L p
1 g
F P
s
P
p
.002 w
.63024 .52501 m .66515 .47848 L .65364 .46201 L p
1 g
F P
s
P
p
.002 w
.6724 .41044 m .65364 .46201 L .66515 .47848 L p
1 g
F P
s
P
p
.002 w
.65364 .46201 m .6724 .41044 L .65632 .39555 L p
1 g
F P
s
P
p
.002 w
.52642 .27039 m .49549 .25776 L .48225 .27334 L p
1 g
F P
s
P
p
.002 w
.45496 .27213 m .48225 .27334 L .49549 .25776 L p
1 g
F P
s
P
p
.002 w
.33459 .35353 m .33245 .39319 L .35017 .37852 L p
1 g
F P
s
P
p
.002 w
.35017 .37852 m .35216 .3458 L .33459 .35353 L p
1 g
F P
s
P
p
.002 w
.48007 .61116 m .53733 .60122 L .52861 .58668 L p
1 g
F P
s
P
p
.002 w
.52861 .58668 m .47071 .59657 L .48007 .61116 L p
1 g
F P
s
P
p
.002 w
.6566 .34497 m .65632 .39555 L .6724 .41044 L p
1 g
F P
s
P
p
.002 w
.65632 .39555 m .6566 .34497 L .63659 .33461 L p
1 g
F P
s
P
p
.002 w
.54672 .26175 m .57393 .28821 L .59746 .28792 L p
1 g
F P
s
P
p
.002 w
.57393 .28821 m .54672 .26175 L .52642 .27039 L p
1 g
F P
s
P
p
.002 w
.59152 .57681 m .63803 .54015 L .63024 .52501 L p
1 g
F P
s
P
p
.002 w
.66515 .47848 m .63024 .52501 L .63803 .54015 L p
1 g
F P
s
P
p
.002 w
.32206 .49204 m .35616 .52831 L .35698 .50538 L p
1 g
F P
s
P
p
.002 w
.35698 .50538 m .3253 .47115 L .32206 .49204 L p
1 g
F P
s
P
p
.002 w
.49549 .25776 m .52642 .27039 L .54672 .26175 L p
1 g
F P
s
P
p
.002 w
.39086 .28568 m .36617 .31354 L .38375 .31588 L p
1 g
F P
s
P
p
.002 w
.38375 .31588 m .40259 .29471 L .39086 .28568 L p
1 g
F P
s
P
p
.002 w
.49549 .25776 m .45974 .25603 L .45496 .27213 L p
1 g
F P
s
P
p
.002 w
.42731 .27952 m .45496 .27213 L .45974 .25603 L p
1 g
F P
s
P
p
.002 w
.61911 .29138 m .63659 .33461 L .6566 .34497 L p
1 g
F P
s
P
p
.002 w
.63659 .33461 m .61911 .29138 L .59746 .28792 L p
1 g
F P
s
P
p
.002 w
.42337 .26568 m .39086 .28568 L .40259 .29471 L p
1 g
F P
s
P
p
.002 w
.40259 .29471 m .42731 .27952 L .42337 .26568 L p
1 g
F P
s
P
p
.002 w
.45974 .25603 m .42337 .26568 L .42731 .27952 L p
1 g
F P
s
P
p
.002 w
.30915 .42649 m .3253 .47115 L .33296 .44985 L p
1 g
F P
s
P
p
.002 w
.33296 .44985 m .3186 .40928 L .30915 .42649 L p
1 g
F P
s
P
p
.002 w
.42477 .6053 m .48007 .61116 L .47071 .59657 L p
1 g
F P
s
P
p
.002 w
.47071 .59657 m .41471 .5904 L .42477 .6053 L p
1 g
F P
s
P
p
.002 w
.36597 .56793 m .41471 .5904 L .4072 .57186 L p
1 g
F P
s
P
p
.002 w
.4072 .57186 m .35912 .54937 L .36597 .56793 L p
1 g
F P
s
P
p
.002 w
.35149 .31424 m .33459 .35353 L .35216 .3458 L p
1 g
F P
s
P
p
.002 w
.35216 .3458 m .36617 .31354 L .35149 .31424 L p
1 g
F P
s
P
p
.002 w
.32083 .36362 m .3186 .40928 L .33245 .39319 L p
1 g
F P
s
P
p
.002 w
.33245 .39319 m .33459 .35353 L .32083 .36362 L p
1 g
F P
s
P
p
.002 w
.63803 .54015 m .6727 .49425 L .66515 .47848 L p
1 g
F P
s
P
p
.002 w
.68445 .42634 m .66515 .47848 L .6727 .49425 L p
1 g
F P
s
P
p
.002 w
.66515 .47848 m .68445 .42634 L .6724 .41044 L p
1 g
F P
s
P
p
.002 w
.54539 .61178 m .59759 .58823 L .59152 .57681 L p
1 g
F P
s
P
p
.002 w
.59152 .57681 m .53733 .60122 L .54539 .61178 L p
1 g
F P
s
P
p
.002 w
.63803 .54015 m .59152 .57681 L .59759 .58823 L p
1 g
F P
s
P
p
.002 w
.56645 .25729 m .59746 .28792 L .61911 .29138 L p
1 g
F P
s
P
p
.002 w
.59746 .28792 m .56645 .25729 L .54672 .26175 L p
1 g
F P
s
P
p
.002 w
.54672 .26175 m .50931 .24622 L .49549 .25776 L p
1 g
F P
s
P
p
.002 w
.45974 .25603 m .49549 .25776 L .50931 .24622 L p
1 g
F P
s
P
p
.002 w
.67307 .35793 m .6724 .41044 L .68445 .42634 L p
1 g
F P
s
P
p
.002 w
.6724 .41044 m .67307 .35793 L .6566 .34497 L p
1 g
F P
s
P
p
.002 w
.32354 .51197 m .35912 .54937 L .35616 .52831 L p
1 g
F P
s
P
p
.002 w
.35616 .52831 m .32206 .49204 L .32354 .51197 L p
1 g
F P
s
P
p
.002 w
.49032 .62146 m .54539 .61178 L .53733 .60122 L p
1 g
F P
s
P
p
.002 w
.53733 .60122 m .48007 .61116 L .49032 .62146 L p
1 g
F P
s
P
p
.002 w
.50931 .24622 m .54672 .26175 L .56645 .25729 L p
1 g
F P
s
P
p
.002 w
.59759 .58823 m .64244 .55296 L .63803 .54015 L p
1 g
F P
s
P
p
.002 w
.6727 .49425 m .63803 .54015 L .64244 .55296 L p
1 g
F P
s
P
p
.002 w
.38158 .28017 m .35149 .31424 L .36617 .31354 L p
1 g
F P
s
P
p
.002 w
.36617 .31354 m .39086 .28568 L .38158 .28017 L p
1 g
F P
s
P
p
.002 w
.63827 .29869 m .6566 .34497 L .67307 .35793 L p
1 g
F P
s
P
p
.002 w
.6566 .34497 m .63827 .29869 L .61911 .29138 L p
1 g
F P
s
P
p
.002 w
.50931 .24622 m .46577 .24397 L .45974 .25603 L p
1 g
F P
s
P
p
.002 w
.42337 .26568 m .45974 .25603 L .46577 .24397 L p
1 g
F P
s
P
p
.002 w
.30457 .44443 m .32206 .49204 L .3253 .47115 L p
1 g
F P
s
P
p
.002 w
.3253 .47115 m .30915 .42649 L .30457 .44443 L p
1 g
F P
s
P
p
.002 w
.37674 .58339 m .42477 .6053 L .41471 .5904 L p
1 g
F P
s
P
p
.002 w
.41471 .5904 m .36597 .56793 L .37674 .58339 L p
1 g
F P
s
P
p
.002 w
.42133 .25572 m .38158 .28017 L .39086 .28568 L p
1 g
F P
s
P
p
.002 w
.39086 .28568 m .42337 .26568 L .42133 .25572 L p
1 g
F P
s
P
p
.002 w
.43726 .61599 m .49032 .62146 L .48007 .61116 L p
1 g
F P
s
P
p
.002 w
.48007 .61116 m .42477 .6053 L .43726 .61599 L p
1 g
F P
s
P
p
.002 w
.46577 .24397 m .42133 .25572 L .42337 .26568 L p
1 g
F P
s
P
p
.002 w
.34026 .31813 m .32083 .36362 L .33459 .35353 L p
1 g
F P
s
P
p
.002 w
.33459 .35353 m .35149 .31424 L .34026 .31813 L p
1 g
F P
s
P
p
.002 w
.31144 .37592 m .30915 .42649 L .3186 .40928 L p
1 g
F P
s
P
p
.002 w
.3186 .40928 m .32083 .36362 L .31144 .37592 L p
1 g
F P
s
P
p
.002 w
.58506 .25735 m .61911 .29138 L .63827 .29869 L p
1 g
F P
s
P
p
.002 w
.61911 .29138 m .58506 .25735 L .56645 .25729 L p
1 g
F P
s
P
p
.002 w
.64244 .55296 m .67588 .50891 L .6727 .49425 L p
1 g
F P
s
P
p
.002 w
.69196 .44292 m .6727 .49425 L .67588 .50891 L p
1 g
F P
s
P
p
.002 w
.6727 .49425 m .69196 .44292 L .68445 .42634 L p
1 g
F P
s
P
p
.002 w
.32994 .53035 m .36597 .56793 L .35912 .54937 L p
1 g
F P
s
P
p
.002 w
.35912 .54937 m .32354 .51197 L .32994 .53035 L p
1 g
F P
s
P
p
.002 w
.68542 .3733 m .68445 .42634 L .69196 .44292 L p
1 g
F P
s
P
p
.002 w
.68445 .42634 m .68542 .3733 L .67307 .35793 L p
1 g
F P
s
P
p
.002 w
.56645 .25729 m .5234 .2392 L .50931 .24622 L p
1 g
F P
s
P
p
.002 w
.46577 .24397 m .50931 .24622 L .5234 .2392 L p
1 g
F P
s
P
p
.002 w
.55256 .61785 m .60128 .59585 L .59759 .58823 L p
1 g
F P
s
P
p
.002 w
.59759 .58823 m .54539 .61178 L .55256 .61785 L p
1 g
F P
s
P
p
.002 w
.64244 .55296 m .59759 .58823 L .60128 .59585 L p
1 g
F P
s
P
p
.002 w
.5234 .2392 m .56645 .25729 L .58506 .25735 L p
1 g
F P
s
P
p
.002 w
.50125 .62694 m .55256 .61785 L .54539 .61178 L p
1 g
F P
s
P
p
.002 w
.54539 .61178 m .49032 .62146 L .50125 .62694 L p
1 g
F P
s
P
p
.002 w
.65432 .30985 m .67307 .35793 L .68542 .3733 L p
1 g
F P
s
P
p
.002 w
.67307 .35793 m .65432 .30985 L .63827 .29869 L p
1 g
F P
s
P
p
.002 w
.60128 .59585 m .64315 .56297 L .64244 .55296 L p
1 g
F P
s
P
p
.002 w
.67588 .50891 m .64244 .55296 L .64315 .56297 L p
1 g
F P
s
P
p
.002 w
.30527 .46263 m .32354 .51197 L .32206 .49204 L p
1 g
F P
s
P
p
.002 w
.32206 .49204 m .30457 .44443 L .30527 .46263 L p
1 g
F P
s
P
p
.002 w
.37515 .27855 m .34026 .31813 L .35149 .31424 L p
1 g
F P
s
P
p
.002 w
.35149 .31424 m .38158 .28017 L .37515 .27855 L p
1 g
F P
s
P
p
.002 w
.5234 .2392 m .47299 .23651 L .46577 .24397 L p
1 g
F P
s
P
p
.002 w
.42133 .25572 m .46577 .24397 L .47299 .23651 L p
1 g
F P
s
P
p
.002 w
.39133 .59515 m .43726 .61599 L .42477 .6053 L p
1 g
F P
s
P
p
.002 w
.42477 .6053 m .37674 .58339 L .39133 .59515 L p
1 g
F P
s
P
p
.002 w
.30695 .39024 m .30457 .44443 L .30915 .42649 L p
1 g
F P
s
P
p
.002 w
.30915 .42649 m .31144 .37592 L .30695 .39024 L p
1 g
F P
s
P
p
.002 w
.60203 .26218 m .63827 .29869 L .65432 .30985 L p
1 g
F P
s
P
p
.002 w
.63827 .29869 m .60203 .26218 L .58506 .25735 L p
1 g
F P
s
P
p
.002 w
.45197 .62193 m .50125 .62694 L .49032 .62146 L p
1 g
F P
s
P
p
.002 w
.49032 .62146 m .43726 .61599 L .45197 .62193 L p
1 g
F P
s
P
p
.002 w
.333 .32531 m .31144 .37592 L .32083 .36362 L p
1 g
F P
s
P
p
.002 w
.32083 .36362 m .34026 .31813 L .333 .32531 L p
1 g
F P
s
P
p
.002 w
.42137 .25012 m .37515 .27855 L .38158 .28017 L p
1 g
F P
s
P
p
.002 w
.38158 .28017 m .42133 .25572 L .42137 .25012 L p
1 g
F P
s
P
p
.002 w
.47299 .23651 m .42137 .25012 L .42133 .25572 L p
1 g
F P
s
P
p
.002 w
.34134 .54658 m .37674 .58339 L .36597 .56793 L p
1 g
F P
s
P
p
.002 w
.36597 .56793 m .32994 .53035 L .34134 .54658 L p
1 g
F P
s
P
p
.002 w
.67588 .50891 m .69447 .45977 L .69196 .44292 L p
1 g
F P
s
P
p
.002 w
.69309 .39079 m .69196 .44292 L .69447 .45977 L p
1 g
F P
s
P
p
.002 w
.69196 .44292 m .69309 .39079 L .68542 .3733 L p
1 g
F P
s
P
p
.002 w
.64315 .56297 m .67435 .52199 L .67588 .50891 L p
1 g
F P
s
P
p
.002 w
.69447 .45977 m .67588 .50891 L .67435 .52199 L p
1 g
F P
s
P
p
.002 w
.58506 .25735 m .5374 .23718 L .5234 .2392 L p
1 g
F P
s
P
p
.002 w
.47299 .23651 m .5234 .2392 L .5374 .23718 L p
1 g
F P
s
P
p
.002 w
.5374 .23718 m .58506 .25735 L .60203 .26218 L p
1 g
F P
s
P
p
.002 w
.55858 .619 m .60233 .59924 L .60128 .59585 L p
1 g
F P
s
P
p
.002 w
.60128 .59585 m .55256 .61785 L .55858 .619 L p
1 g
F P
s
P
p
.002 w
.64315 .56297 m .60128 .59585 L .60233 .59924 L p
1 g
F P
s
P
p
.002 w
.66666 .32476 m .68542 .3733 L .69309 .39079 L p
1 g
F P
s
P
p
.002 w
.68542 .3733 m .66666 .32476 L .65432 .30985 L p
1 g
F P
s
P
p
.002 w
.3115 .4806 m .32994 .53035 L .32354 .51197 L p
1 g
F P
s
P
p
.002 w
.32354 .51197 m .30527 .46263 L .3115 .4806 L p
1 g
F P
s
P
p
.002 w
.51261 .62717 m .55858 .619 L .55256 .61785 L p
1 g
F P
s
P
p
.002 w
.55256 .61785 m .50125 .62694 L .51261 .62717 L p
1 g
F P
s
P
p
.002 w
.60233 .59924 m .63992 .56973 L .64315 .56297 L p
1 g
F P
s
P
p
.002 w
.67435 .52199 m .64315 .56297 L .63992 .56973 L p
1 g
F P
s
P
p
.002 w
.37194 .28113 m .333 .32531 L .34026 .31813 L p
1 g
F P
s
P
p
.002 w
.34026 .31813 m .37515 .27855 L .37194 .28113 L p
1 g
F P
s
P
p
.002 w
.40954 .60266 m .45197 .62193 L .43726 .61599 L p
1 g
F P
s
P
p
.002 w
.43726 .61599 m .39133 .59515 L .40954 .60266 L p
1 g
F P
s
P
p
.002 w
.5374 .23718 m .48128 .23414 L .47299 .23651 L p
1 g
F P
s
P
p
.002 w
.42137 .25012 m .47299 .23651 L .48128 .23414 L p
1 g
F P
s
P
p
.002 w
.65432 .30985 m .61677 .2719 L .60203 .26218 L p
1 g
F P
s
P
p
.002 w
.61677 .2719 m .65432 .30985 L .66666 .32476 L p
1 g
F P
s
P
p
.002 w
.30777 .40626 m .30527 .46263 L .30457 .44443 L p
1 g
F P
s
P
p
.002 w
.30457 .44443 m .30695 .39024 L .30777 .40626 L p
1 g
F P
s
P
p
.002 w
.33017 .33578 m .30695 .39024 L .31144 .37592 L p
1 g
F P
s
P
p
.002 w
.31144 .37592 m .333 .32531 L .33017 .33578 L p
1 g
F P
s
P
p
.002 w
.35768 .56007 m .39133 .59515 L .37674 .58339 L p
1 g
F P
s
P
p
.002 w
.37674 .58339 m .34134 .54658 L .35768 .56007 L p
1 g
F P
s
P
p
.002 w
.46863 .62268 m .51261 .62717 L .50125 .62694 L p
1 g
F P
s
P
p
.002 w
.50125 .62694 m .45197 .62193 L .46863 .62268 L p
1 g
F P
s
P
p
.002 w
.67435 .52199 m .69164 .47644 L .69447 .45977 L p
1 g
F P
s
P
p
.002 w
.69447 .45977 m .69562 .41003 L .69309 .39079 L p
1 g
F P
s
P
p
.002 w
.69562 .41003 m .69447 .45977 L .69164 .47644 L p
1 g
F P
s
P
p
.002 w
.48128 .23414 m .42361 .24934 L .42137 .25012 L p
1 g
F P
s
P
p
.002 w
.42361 .24934 m .37194 .28113 L .37515 .27855 L p
1 g
F P
s
P
p
.002 w
.37515 .27855 m .42137 .25012 L .42361 .24934 L p
1 g
F P
s
P
p
.002 w
.60203 .26218 m .55091 .24049 L .5374 .23718 L p
1 g
F P
s
P
p
.002 w
.55091 .24049 m .60203 .26218 L .61677 .2719 L p
1 g
F P
s
P
p
.002 w
.63992 .56973 m .66787 .53305 L .67435 .52199 L p
1 g
F P
s
P
p
.002 w
.69164 .47644 m .67435 .52199 L .66787 .53305 L p
1 g
F P
s
P
p
.002 w
.48128 .23414 m .5374 .23718 L .55091 .24049 L p
1 g
F P
s
P
p
.002 w
.69309 .39079 m .67472 .3432 L .66666 .32476 L p
1 g
F P
s
P
p
.002 w
.67472 .3432 m .69309 .39079 L .69562 .41003 L p
1 g
F P
s
P
p
.002 w
.32339 .49776 m .34134 .54658 L .32994 .53035 L p
1 g
F P
s
P
p
.002 w
.32994 .53035 m .3115 .4806 L .32339 .49776 L p
1 g
F P
s
P
p
.002 w
.56321 .61486 m .60053 .598 L .60233 .59924 L p
1 g
F P
s
P
p
.002 w
.60233 .59924 m .55858 .619 L .56321 .61486 L p
1 g
F P
s
P
p
.002 w
.63992 .56973 m .60233 .59924 L .60053 .598 L p
1 g
F P
s
P
p
.002 w
.52407 .62178 m .56321 .61486 L .55858 .619 L p
1 g
F P
s
P
p
.002 w
.55858 .619 m .51261 .62717 L .52407 .62178 L p
1 g
F P
s
P
p
.002 w
.60053 .598 m .63258 .57283 L .63992 .56973 L p
1 g
F P
s
P
p
.002 w
.66787 .53305 m .63992 .56973 L .63258 .57283 L p
1 g
F P
s
P
p
.002 w
.62874 .2865 m .66666 .32476 L .67472 .3432 L p
1 g
F P
s
P
p
.002 w
.66666 .32476 m .62874 .2865 L .61677 .2719 L p
1 g
F P
s
P
p
.002 w
.37226 .2881 m .33017 .33578 L .333 .32531 L p
1 g
F P
s
P
p
.002 w
.333 .32531 m .37194 .28113 L .37226 .2881 L p
1 g
F P
s
P
p
.002 w
.3142 .4236 m .3115 .4806 L .30527 .46263 L p
1 g
F P
s
P
p
.002 w
.30527 .46263 m .30777 .40626 L .3142 .4236 L p
1 g
F P
s
P
p
.002 w
.431 .60547 m .46863 .62268 L .45197 .62193 L p
1 g
F P
s
P
p
.002 w
.45197 .62193 m .40954 .60266 L .431 .60547 L p
1 g
F P
s
P
p
.002 w
.37869 .57024 m .40954 .60266 L .39133 .59515 L p
1 g
F P
s
P
p
.002 w
.39133 .59515 m .35768 .56007 L .37869 .57024 L p
1 g
F P
s
P
p
.002 w
.55091 .24049 m .49045 .23726 L .48128 .23414 L p
1 g
F P
s
P
p
.002 w
.42361 .24934 m .48128 .23414 L .49045 .23726 L p
1 g
F P
s
P
p
.002 w
.33215 .34942 m .30777 .40626 L .30695 .39024 L p
1 g
F P
s
P
p
.002 w
.30695 .39024 m .33017 .33578 L .33215 .34942 L p
1 g
F P
s
P
p
.002 w
.66787 .53305 m .68325 .49244 L .69164 .47644 L p
1 g
F P
s
P
p
.002 w
.69265 .43053 m .69164 .47644 L .68325 .49244 L p
1 g
F P
s
P
p
.002 w
.69164 .47644 m .69265 .43053 L .69562 .41003 L p
1 g
F P
s
P
p
.002 w
.48682 .61791 m .52407 .62178 L .51261 .62717 L p
1 g
F P
s
P
p
.002 w
.51261 .62717 m .46863 .62268 L .48682 .61791 L p
1 g
F P
s
P
p
.002 w
.56351 .24938 m .61677 .2719 L .62874 .2865 L p
1 g
F P
s
P
p
.002 w
.61677 .2719 m .56351 .24938 L .55091 .24049 L p
1 g
F P
s
P
p
.002 w
.42815 .25372 m .37226 .2881 L .37194 .28113 L p
1 g
F P
s
P
p
.002 w
.37194 .28113 m .42361 .24934 L .42815 .25372 L p
1 g
F P
s
P
p
.002 w
.49045 .23726 m .55091 .24049 L .56351 .24938 L p
1 g
F P
s
P
p
.002 w
.63258 .57283 m .65632 .54163 L .66787 .53305 L p
1 g
F P
s
P
p
.002 w
.68325 .49244 m .66787 .53305 L .65632 .54163 L p
1 g
F P
s
P
p
.002 w
.67803 .36479 m .69562 .41003 L .69265 .43053 L p
1 g
F P
s
P
p
.002 w
.69562 .41003 m .67803 .36479 L .67472 .3432 L p
1 g
F P
s
P
p
.002 w
.49045 .23726 m .42815 .25372 L .42361 .24934 L p
1 g
F P
s
P
p
.002 w
.34085 .51354 m .35768 .56007 L .34134 .54658 L p
1 g
F P
s
P
p
.002 w
.34134 .54658 m .32339 .49776 L .34085 .51354 L p
1 g
F P
s
P
p
.002 w
.56621 .6052 m .59575 .59187 L .60053 .598 L p
1 g
F P
s
P
p
.002 w
.60053 .598 m .56321 .61486 L .56621 .6052 L p
1 g
F P
s
P
p
.002 w
.63258 .57283 m .60053 .598 L .59575 .59187 L p
1 g
F P
s
P
p
.002 w
.6374 .30581 m .67472 .3432 L .67803 .36479 L p
1 g
F P
s
P
p
.002 w
.67472 .3432 m .6374 .30581 L .62874 .2865 L p
1 g
F P
s
P
p
.002 w
.32633 .44177 m .32339 .49776 L .3115 .4806 L p
1 g
F P
s
P
p
.002 w
.3115 .4806 m .3142 .4236 L .32633 .44177 L p
1 g
F P
s
P
p
.002 w
.5353 .61061 m .56621 .6052 L .56321 .61486 L p
1 g
F P
s
P
p
.002 w
.56321 .61486 m .52407 .62178 L .5353 .61061 L p
1 g
F P
s
P
p
.002 w
.45519 .60324 m .48682 .61791 L .46863 .62268 L p
1 g
F P
s
P
p
.002 w
.46863 .62268 m .431 .60547 L .45519 .60324 L p
1 g
F P
s
P
p
.002 w
.59575 .59187 m .62109 .57194 L .63258 .57283 L p
1 g
F P
s
P
p
.002 w
.65632 .54163 m .63258 .57283 L .62109 .57194 L p
1 g
F P
s
P
p
.002 w
.40393 .57662 m .431 .60547 L .40954 .60266 L p
1 g
F P
s
P
p
.002 w
.40954 .60266 m .37869 .57024 L .40393 .57662 L p
1 g
F P
s
P
p
.002 w
.37633 .29953 m .33215 .34942 L .33017 .33578 L p
1 g
F P
s
P
p
.002 w
.33017 .33578 m .37226 .2881 L .37633 .29953 L p
1 g
F P
s
P
p
.002 w
.33915 .366 m .3142 .4236 L .30777 .40626 L p
1 g
F P
s
P
p
.002 w
.30777 .40626 m .33215 .34942 L .33915 .366 L p
1 g
F P
s
P
p
.002 w
.56351 .24938 m .50028 .24613 L .49045 .23726 L p
1 g
F P
s
P
p
.002 w
.42815 .25372 m .49045 .23726 L .50028 .24613 L p
1 g
F P
s
P
p
.002 w
.65632 .54163 m .66924 .50723 L .68325 .49244 L p
1 g
F P
s
P
p
.002 w
.68399 .45173 m .68325 .49244 L .66924 .50723 L p
1 g
F P
s
P
p
.002 w
.68325 .49244 m .68399 .45173 L .69265 .43053 L p
1 g
F P
s
P
p
.002 w
.57474 .26388 m .62874 .2865 L .6374 .30581 L p
1 g
F P
s
P
p
.002 w
.62874 .2865 m .57474 .26388 L .56351 .24938 L p
1 g
F P
s
P
p
.002 w
.50605 .60746 m .5353 .61061 L .52407 .62178 L p
1 g
F P
s
P
p
.002 w
.52407 .62178 m .48682 .61791 L .50605 .60746 L p
1 g
F P
s
P
p
.002 w
.67626 .389 m .69265 .43053 L .68399 .45173 L p
1 g
F P
s
P
p
.002 w
.69265 .43053 m .67626 .389 L .67803 .36479 L p
1 g
F P
s
P
p
.002 w
.36357 .52734 m .37869 .57024 L .35768 .56007 L p
1 g
F P
s
P
p
.002 w
.35768 .56007 m .34085 .51354 L .36357 .52734 L p
1 g
F P
s
P
p
.002 w
.50028 .24613 m .56351 .24938 L .57474 .26388 L p
1 g
F P
s
P
p
.002 w
.62109 .57194 m .63975 .5473 L .65632 .54163 L p
1 g
F P
s
P
p
.002 w
.66924 .50723 m .65632 .54163 L .63975 .5473 L p
1 g
F P
s
P
p
.002 w
.43498 .26347 m .37633 .29953 L .37226 .2881 L p
1 g
F P
s
P
p
.002 w
.37226 .2881 m .42815 .25372 L .43498 .26347 L p
1 g
F P
s
P
p
.002 w
.50028 .24613 m .43498 .26347 L .42815 .25372 L p
1 g
F P
s
P
p
.002 w
.6423 .32943 m .67803 .36479 L .67626 .389 L p
1 g
F P
s
P
p
.002 w
.67803 .36479 m .6423 .32943 L .6374 .30581 L p
1 g
F P
s
P
p
.002 w
.34406 .46019 m .34085 .51354 L .32339 .49776 L p
1 g
F P
s
P
p
.002 w
.32339 .49776 m .32633 .44177 L .34406 .46019 L p
1 g
F P
s
P
p
.002 w
.43272 .57882 m .45519 .60324 L .431 .60547 L p
1 g
F P
s
P
p
.002 w
.431 .60547 m .40393 .57662 L .43272 .57882 L p
1 g
F P
s
P
p
.002 w
.48143 .59581 m .50605 .60746 L .48682 .61791 L p
1 g
F P
s
P
p
.002 w
.48682 .61791 m .45519 .60324 L .48143 .59581 L p
1 g
F P
s
P
p
.002 w
.56738 .58998 m .58794 .58072 L .59575 .59187 L p
1 g
F P
s
P
p
.002 w
.59575 .59187 m .56621 .6052 L .56738 .58998 L p
1 g
F P
s
P
p
.002 w
.62109 .57194 m .59575 .59187 L .58794 .58072 L p
1 g
F P
s
P
p
.004 w
.59006 .59081 m
.60155 .61126 L
s
P
p
.002 w
.54592 .59369 m .56738 .58998 L .56621 .6052 L p
1 g
F P
s
P
p
.002 w
.56621 .6052 m .5353 .61061 L .54592 .59369 L p
1 g
F P
s
P
p
.002 w
.38425 .31533 m .33915 .366 L .33215 .34942 L p
1 g
F P
s
P
p
.002 w
.33215 .34942 m .37633 .29953 L .38425 .31533 L p
1 g
F P
s
P
p
.002 w
.58794 .58072 m .60555 .56684 L .62109 .57194 L p
1 g
F P
s
P
p
.002 w
.63975 .5473 m .62109 .57194 L .60555 .56684 L p
1 g
F P
s
P
p
.002 w
.35123 .38512 m .32633 .44177 L .3142 .4236 L p
1 g
F P
s
P
p
.002 w
.3142 .4236 m .33915 .366 L .35123 .38512 L p
1 g
F P
s
P
p
.002 w
.63975 .5473 m .64976 .52027 L .66924 .50723 L p
1 g
F P
s
P
p
.002 w
.66964 .47298 m .66924 .50723 L .64976 .52027 L p
1 g
F P
s
P
p
.002 w
.66924 .50723 m .66964 .47298 L .68399 .45173 L p
1 g
F P
s
P
p
.002 w
.58417 .28386 m .6374 .30581 L .6423 .32943 L p
1 g
F P
s
P
p
.002 w
.6374 .30581 m .58417 .28386 L .57474 .26388 L p
1 g
F P
s
P
p
.002 w
.66921 .41517 m .68399 .45173 L .66964 .47298 L p
1 g
F P
s
P
p
.002 w
.68399 .45173 m .66921 .41517 L .67626 .389 L p
1 g
F P
s
P
p
.002 w
.391 .53859 m .40393 .57662 L .37869 .57024 L p
1 g
F P
s
P
p
.002 w
.37869 .57024 m .36357 .52734 L .391 .53859 L p
1 g
F P
s
P
p
.002 w
.57474 .26388 m .5105 .26081 L .50028 .24613 L p
1 g
F P
s
P
p
.002 w
.43498 .26347 m .50028 .24613 L .5105 .26081 L p
1 g
F P
s
P
p
.002 w
.52572 .59139 m .54592 .59369 L .5353 .61061 L p
1 g
F P
s
P
p
.002 w
.5353 .61061 m .50605 .60746 L .52572 .59139 L p
1 g
F P
s
P
p
.002 w
.5105 .26081 m .57474 .26388 L .58417 .28386 L p
1 g
F P
s
P
p
.002 w
.60555 .56684 m .61843 .54971 L .63975 .5473 L p
1 g
F P
s
P
p
.002 w
.64976 .52027 m .63975 .5473 L .61843 .54971 L p
1 g
F P
s
P
p
.002 w
.64309 .35678 m .67626 .389 L .66921 .41517 L p
1 g
F P
s
P
p
.002 w
.67626 .389 m .64309 .35678 L .6423 .32943 L p
1 g
F P
s
P
p
.002 w
.44403 .2786 m .38425 .31533 L .37633 .29953 L p
1 g
F P
s
P
p
.002 w
.37633 .29953 m .43498 .26347 L .44403 .2786 L p
1 g
F P
s
P
p
.002 w
.36702 .47824 m .36357 .52734 L .34085 .51354 L p
1 g
F P
s
P
p
.002 w
.34085 .51354 m .34406 .46019 L .36702 .47824 L p
1 g
F P
s
P
p
.002 w
.5105 .26081 m .44403 .2786 L .43498 .26347 L p
1 g
F P
s
P
p
.002 w
.46419 .57659 m .48143 .59581 L .45519 .60324 L p
1 g
F P
s
P
p
.002 w
.45519 .60324 m .43272 .57882 L .46419 .57659 L p
1 g
F P
s
P
p
.002 w
.5089 .58322 m .52572 .59139 L .50605 .60746 L p
1 g
F P
s
P
p
.002 w
.50605 .60746 m .48143 .59581 L .5089 .58322 L p
1 g
F P
s
P
p
.002 w
.64976 .52027 m .64983 .49355 L .66964 .47298 L p
1 g
F P
s
P
p
.002 w
.6569 .44247 m .66964 .47298 L .64983 .49355 L p
1 g
F P
s
P
p
.002 w
.66964 .47298 m .6569 .44247 L .66921 .41517 L p
1 g
F P
s
P
p
.002 w
.42232 .54681 m .43272 .57882 L .40393 .57662 L p
1 g
F P
s
P
p
.002 w
.40393 .57662 m .391 .53859 L .42232 .54681 L p
1 g
F P
s
P
p
.002 w
.61843 .54971 m .6252 .53103 L .64976 .52027 L p
1 g
F P
s
P
p
.002 w
.64983 .49355 m .64976 .52027 L .6252 .53103 L p
1 g
F P
s
P
p
.002 w
.59137 .30888 m .6423 .32943 L .64309 .35678 L p
1 g
F P
s
P
p
.002 w
.6423 .32943 m .59137 .30888 L .58417 .28386 L p
1 g
F P
s
P
p
.002 w
.56656 .5694 m .57718 .56463 L .58794 .58072 L p
1 g
F P
s
P
p
.002 w
.58794 .58072 m .56738 .58998 L .56656 .5694 L p
1 g
F P
s
P
p
.002 w
.60555 .56684 m .58794 .58072 L .57718 .56463 L p
1 g
F P
s
P
p
.002 w
.36823 .40622 m .34406 .46019 L .32633 .44177 L p
1 g
F P
s
P
p
.002 w
.32633 .44177 m .35123 .38512 L .36823 .40622 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.39596 .33519 m .35123 .38512 L .33915 .366 L p
1 g
F P
s
P
p
.002 w
.33915 .366 m .38425 .31533 L .39596 .33519 L p
1 g
F P
s
P
p
.002 w
.55551 .57126 m .56656 .5694 L .56738 .58998 L p
1 g
F P
s
P
p
.002 w
.56738 .58998 m .54592 .59369 L .55551 .57126 L p
1 g
F P
s
P
p
.002 w
.57718 .56463 m .58625 .55745 L .60555 .56684 L p
1 g
F P
s
P
p
.002 w
.61843 .54971 m .60555 .56684 L .58625 .55745 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.58417 .28386 m .52077 .28113 L .5105 .26081 L p
1 g
F P
s
P
p
.002 w
.44403 .2786 m .5105 .26081 L .52077 .28113 L p
1 g
F P
s
P
p
.002 w
.63959 .38705 m .66921 .41517 L .6569 .44247 L p
1 g
F P
s
P
p
.002 w
.66921 .41517 m .63959 .38705 L .64309 .35678 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.54517 .57001 m .55551 .57126 L .54592 .59369 L p
1 g
F P
s
P
p
.002 w
.54592 .59369 m .52572 .59139 L .54517 .57001 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.52077 .28113 m .58417 .28386 L .59137 .30888 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.58625 .55745 m .59284 .54861 L .61843 .54971 L p
1 g
F P
s
P
p
.002 w
.6252 .53103 m .61843 .54971 L .59284 .54861 L p
1 g
F P
s
P
p
.002 w
.39455 .49522 m .391 .53859 L .36357 .52734 L p
1 g
F P
s
P
p
.002 w
.36357 .52734 m .36702 .47824 L .39455 .49522 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.5089 .58322 m .48143 .59581 L p
.49085 .58043 L 1 g
F P
s
P
p
.002 w
.50718 .58125 m .5089 .58322 L p
.49085 .58043 L 1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.43272 .57882 m .44844 .56083 L .45399 .56639 L 1 g
F
P
p
.002 w
.45094 .56269 m .45146 .56129 L p
.44553 .55614 L 1 g
F P
s
P
p
.46872 .57265 m .45928 .56888 L .46076 .56998 L 1 g
F
P
p
.002 w
.46419 .57659 m .46251 .57671 L p
.45399 .56639 L 1 g
F P
s
P
p
.002 w
.46251 .57671 m .43272 .57882 L p
.45399 .56639 L 1 g
F P
s
P
p
.002 w
.46257 .57132 m .46419 .57659 L p
.44844 .56083 L 1 g
F P
s
P
p
.002 w
.46934 .57555 m .46419 .57659 L p
.46679 .57439 L 1 g
F P
s
P
p
.46679 .57439 m .46708 .57414 L .46824 .57486 L 1 g
F
P
p
.46679 .57439 m .46824 .57486 L .46934 .57555 L 1 g
F
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46824 .57486 L p
1 g
F P
s
P
p
.48143 .59581 m .47225 .57949 L .49066 .58074 L 1 g
F
P
p
.47225 .57949 m .46996 .57543 L .48908 .58034 L 1 g
F
P
p
.47225 .57949 m .48908 .58034 L .49066 .58074 L 1 g
F
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48908 .58034 L p
1 g
F P
s
P
p
.51079 .57862 m .48908 .58034 L .49957 .58086 L 1 g
F
P
p
.48921 .57862 m .46824 .57486 L .46996 .57543 L 1 g
F
P
p
.47919 .5778 m .46996 .57543 L .47652 .57758 L 1 g
F
P
p
.48921 .57862 m .46996 .57543 L .47919 .5778 L 1 g
F
P
p
.002 w
.48908 .58034 m .48921 .57862 L p
.47919 .5778 L 1 g
F P
s
P
p
.002 w
.46996 .57543 m .4973 .5699 L p
.49066 .58074 L 1 g
F P
s
P
p
.002 w
.48908 .58034 m .48889 .583 L p
.49957 .58086 L 1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.49235 .55273 m .4973 .5699 L .46934 .57555 L p
1 g
F P
s
P
p
.002 w
.46824 .57486 m .46872 .57265 L p
.46002 .56973 L 1 g
F P
s
P
p
.46708 .57414 m .49235 .55273 L .46934 .57555 L 1 g
F
P
p
.002 w
.48143 .59581 m .46419 .57659 L .46934 .57555 L p
1 g
F P
s
P
p
.002 w
.46934 .57555 m .46996 .57543 L p
.4703 .57604 L 1 g
F P
s
P
p
.48143 .59581 m .46934 .57555 L .4703 .57604 L 1 g
F
P
p
.002 w
.46824 .57486 m .4678 .57686 L p
.47652 .57758 L 1 g
F P
s
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45053 .5638 L p
1 g
F P
s
P
p
.46872 .57265 m .45053 .5638 L .45755 .56819 L 1 g
F
P
p
.002 w
.45651 .5516 m .49235 .55273 L p
.46708 .57414 L 1 g
F P
s
P
p
.002 w
.46419 .57659 m .46257 .57132 L p
.46708 .57414 L 1 g
F P
s
P
p
.002 w
.46257 .57132 m .45651 .5516 L p
.46708 .57414 L 1 g
F P
s
P
p
.002 w
.45053 .5638 m .45002 .56518 L p
.45755 .56819 L 1 g
F P
s
P
p
.002 w
.46821 .57498 m .46824 .57486 L p
.45373 .56762 L 1 g
F P
s
P
p
.46002 .56973 m .45373 .56762 L .46824 .57486 L 1 g
F
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.45651 .5516 m .46257 .57132 L p
.45094 .56269 L 1 g
F P
s
P
p
.44844 .56083 m .44894 .56026 L .45094 .56269 L 1 g
F
P
p
.002 w
.45146 .56129 m .43925 .54566 L .43846 .54716 L p
1 g
F P
s
P
p
.42232 .54681 m .43355 .53977 L .43846 .54716 L 1 g
F
P
p
.002 w
.43986 .54927 m .43906 .54915 L p
.43846 .54716 L 1 g
F P
s
P
p
.002 w
.43906 .54915 m .42232 .54681 L p
.43846 .54716 L 1 g
F P
s
P
p
.002 w
.43846 .54716 m .43925 .54566 L p
.43619 .53961 L 1 g
F P
s
P
p
.45146 .56129 m .43846 .54716 L .43933 .54847 L 1 g
F
P
p
.45146 .56129 m .43832 .54741 L .44553 .55614 L 1 g
F
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.43846 .54716 m .45961 .52344 L .43986 .54927 L 1 g
F
P
p
.43355 .53977 m .43581 .53835 L .43846 .54716 L 1 g
F
P
p
.002 w
.43925 .54566 m .43346 .52734 L .4328 .52831 L p
1 g
F P
s
P
p
.43925 .54566 m .4328 .52831 L .43619 .53961 L 1 g
F
P
p
.43581 .53835 m .45961 .52344 L .43846 .54716 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.42232 .54681 m .42579 .51049 L .4335 .51345 L p
1 g
F P
s
P
p
.002 w
.4328 .52831 m .43346 .52734 L p
.4332 .51983 L 1 g
F P
s
P
p
.42232 .54681 m .4335 .51345 L .43221 .54061 L 1 g
F
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43396 .50932 L p
1 g
F P
s
P
p
.42579 .51049 m .43412 .50784 L .43396 .50932 L 1 g
F
P
p
.002 w
.4335 .51345 m .4322 .51295 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.4322 .51295 m .42579 .51049 L p
.43396 .50932 L 1 g
F P
s
P
p
.002 w
.43396 .50932 m .43485 .50826 L p
.43764 .50175 L 1 g
F P
s
P
p
.43346 .52734 m .43396 .50932 L .4331 .51707 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.43396 .50932 m .47352 .49528 L .4335 .51345 L 1 g
F
P
p
.43412 .50784 m .43478 .50763 L .43396 .50932 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .44278 .49115 L p
1 g
F P
s
P
p
.43485 .50826 m .44278 .49115 L .43764 .50175 L 1 g
F
P
p
.43478 .50763 m .47352 .49528 L .43396 .50932 L 1 g
F
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.002 w
.42579 .51049 m .42841 .50505 L p
.47352 .49528 L 1 g
F P
s
P
p
.002 w
.44278 .49115 m .44339 .4905 L p
.44971 .48444 L 1 g
F P
s
P
p
.002 w
.45326 .48101 m .47352 .49528 L p
.42841 .50505 L 1 g
F P
s
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45775 .47663 L p
1 g
F P
s
P
p
.002 w
.49685 .47051 m .47352 .49528 L .45326 .48101 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.45775 .47663 m .49685 .47051 L .45326 .48101 L 1 g
F
P
p
.002 w
.45775 .47663 m .45826 .47608 L p
.46533 .47298 L 1 g
F P
s
P
p
.46629 .47252 m .49685 .47051 L .45775 .47663 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47763 .46705 L p
1 g
F P
s
P
p
.45826 .47608 m .47763 .46705 L .46533 .47298 L 1 g
F
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.44334 .47402 m .44593 .47124 L p
.49685 .47051 L 1 g
F P
s
P
p
.002 w
.47763 .46705 m .47786 .46667 L p
.48928 .46551 L 1 g
F P
s
P
p
.002 w
.4924 .4651 m .49685 .47051 L p
.44593 .47124 L 1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.49685 .47051 m .4924 .4651 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.5 .4634 m .52214 .46667 L .52241 .46713 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.50613 .46485 m .52241 .46713 L .54078 .4853 L 1 g
F
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54234 .47674 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.54078 .4853 m .53593 .4737 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56623 .50954 L p
1 g
F P
s
P
p
.56327 .47865 m .5678 .5128 L .56623 .50954 L 1 g
F
P
p
.002 w
.56421 .50535 m .56349 .48508 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56349 .48508 m .56327 .47865 L p
.56623 .50954 L 1 g
F P
s
P
p
.55661 .4905 m .56623 .50954 L .56421 .50535 L 1 g
F
P
p
.55661 .4905 m .56421 .50535 L .56205 .5009 L 1 g
F
P
p
.002 w
.56394 .49766 m .56421 .50535 L p
.55739 .49133 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .55834 .49233 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.54174 .47608 m .55661 .4905 L .55739 .49133 L p
1 g
F P
s
P
p
.54174 .47608 m .55739 .49133 L .55276 .48686 L 1 g
F
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.54078 .4853 m .54873 .48295 L p
.56448 .51285 L 1 g
F P
s
P
p
.54174 .47608 m .55276 .48686 L .55103 .48518 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.54873 .48295 m .55575 .48974 L .56448 .51285 L 1 g
F
P
p
.002 w
.56421 .50535 m .56448 .51285 L p
.55575 .48974 L 1 g
F P
s
P
p
.55739 .49133 m .56421 .50535 L .55575 .48974 L 1 g
F
P
p
.002 w
.54873 .48295 m .54078 .4853 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54263 .47705 L p
1 g
F P
s
P
p
.54174 .47608 m .55103 .48518 L .54873 .48295 L 1 g
F
P
p
.002 w
.54234 .47674 m .54174 .47608 L p
.54873 .48295 L 1 g
F P
s
P
p
.52692 .45218 m .55288 .48172 L .54234 .47674 L 1 g
F
P
p
.52214 .46667 m .54234 .47674 L .53949 .47538 L 1 g
F
P
p
.52214 .46667 m .54248 .47689 L .53248 .47202 L 1 g
F
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.53593 .4737 m .53366 .46829 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.53366 .46829 m .52692 .45218 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.54263 .47705 m .54234 .47674 L p
.54873 .48295 L 1 g
F P
s
P
p
.55103 .48518 m .55834 .49233 L .54263 .47705 L 1 g
F
P
p
.55274 .48176 m .55739 .49133 L .55575 .48974 L 1 g
F
P
p
.002 w
.54873 .48295 m .55274 .48176 L p
.55575 .48974 L 1 g
F P
s
P
p
.55103 .48518 m .55796 .49193 L .55311 .48722 L 1 g
F
P
p
.55276 .48686 m .55796 .49193 L .55103 .48518 L 1 g
F
P
p
.002 w
.55739 .49133 m .55796 .49193 L p
.55276 .48686 L 1 g
F P
s
P
p
.002 w
.55274 .48176 m .56327 .47865 L .56394 .49766 L p
1 g
F P
s
P
p
.55274 .48176 m .56394 .49766 L .55739 .49133 L 1 g
F
P
p
.56205 .5009 m .56421 .50535 L .56236 .50149 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56747 .5287 L p
1 g
F P
s
P
p
.002 w
.57553 .51269 m .56772 .53327 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56659 .51282 m .57201 .51274 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.57201 .51274 m .57553 .51269 L p
.56747 .5287 L 1 g
F P
s
P
p
.002 w
.56747 .5287 m .56654 .52734 L p
.56418 .54027 L 1 g
F P
s
P
p
.56515 .50826 m .56747 .5287 L .56701 .52031 L 1 g
F
P
p
.002 w
.56772 .53327 m .5637 .54388 L p
.56396 .54103 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56173 .54751 L p
1 g
F P
s
P
p
.002 w
.56247 .54561 m .5637 .54388 L p
.56272 .54626 L 1 g
F P
s
P
p
.55259 .57091 m .56173 .54751 L .56272 .54626 L 1 g
F
P
p
.56173 .54751 m .56247 .54561 L .56272 .54626 L 1 g
F
P
p
.002 w
.5637 .54388 m .55551 .57126 L .55259 .57091 L p
1 g
F P
s
P
p
.002 w
.56173 .54751 m .56075 .54566 L p
.55515 .55582 L 1 g
F P
s
P
p
.002 w
.54517 .57001 m .54425 .56955 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.55596 .55479 m .55079 .56208 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.55079 .56208 m .54517 .57001 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54854 .56129 L p
.53904 .57034 L 1 g
F P
s
P
p
.002 w
.54517 .57001 m .54476 .57046 L p
.53328 .57366 L 1 g
F P
s
P
p
.002 w
.54476 .57046 m .52572 .59139 L p
.53308 .57413 L 1 g
F P
s
P
p
.53308 .57413 m .53328 .57366 L .54476 .57046 L 1 g
F
P
p
.002 w
.5317 .57457 m .53128 .57265 L p
.52099 .57793 L 1 g
F P
s
P
p
.002 w
.52572 .59139 m .5089 .58322 L .51255 .58092 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51097 .58101 L p
1 g
F P
s
P
p
.53128 .57265 m .51097 .58101 L .51149 .58086 L 1 g
F
P
p
.5089 .58322 m .51086 .58104 L .51097 .58101 L 1 g
F
P
p
.002 w
.51362 .58025 m .51255 .58092 L p
.51097 .58101 L 1 g
F P
s
P
p
.002 w
.51255 .58092 m .5089 .58322 L p
.51097 .58101 L 1 g
F P
s
P
p
.51079 .57862 m .49957 .58086 L .50718 .58125 L 1 g
F
P
p
.002 w
.51097 .58101 m .51079 .57862 L p
.50718 .58125 L 1 g
F P
s
P
p
.53128 .57265 m .51149 .58086 L .52099 .57793 L 1 g
F
P
p
.51149 .58086 m .51097 .58108 L .51362 .58025 L 1 g
F
P
p
.51149 .58086 m .51362 .58025 L .52099 .57793 L 1 g
F
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.51086 .58104 m .53088 .55888 L .51362 .58025 L 1 g
F
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.4973 .5699 m .53088 .55888 L p
.51088 .58102 L 1 g
F P
s
P
p
.002 w
.5089 .58322 m .50718 .58125 L p
.51088 .58102 L 1 g
F P
s
P
p
.002 w
.50718 .58125 m .4973 .5699 L p
.51088 .58102 L 1 g
F P
s
P
p
.50718 .58125 m .48889 .583 L .511 .58144 L 1 g
F
P
p
.49957 .58086 m .4934 .5821 L .50718 .58125 L 1 g
F
P
p
.4934 .5821 m .48889 .583 L .50718 .58125 L 1 g
F
P
p
.002 w
.511 .58144 m .51097 .58101 L p
.50718 .58125 L 1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.53088 .55888 m .53665 .56574 L .51362 .58025 L p
1 g
F P
s
P
p
.002 w
.51097 .58101 m .51097 .58108 L p
.51149 .58086 L 1 g
F P
s
P
p
.002 w
.51255 .58092 m .51362 .58025 L p
.53098 .57904 L 1 g
F P
s
P
p
.53098 .57904 m .52295 .5796 L .53308 .57413 L 1 g
F
P
p
.52295 .5796 m .51362 .58025 L .5317 .57457 L 1 g
F
P
p
.52295 .5796 m .5317 .57457 L .53308 .57413 L 1 g
F
P
p
.002 w
.54854 .56129 m .53128 .57265 L .5317 .57457 L p
1 g
F P
s
P
p
.54854 .56129 m .5317 .57457 L .53904 .57034 L 1 g
F
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.51362 .58025 m .53665 .56574 L p
.53308 .57413 L 1 g
F P
s
P
p
.002 w
.54221 .56852 m .54517 .57001 L p
.53328 .57366 L 1 g
F P
s
P
p
.002 w
.5317 .57457 m .5322 .57686 L p
.53904 .57034 L 1 g
F P
s
P
p
.52572 .59139 m .51255 .58092 L .53098 .57904 L 1 g
F
P
p
.002 w
.51097 .58108 m .51111 .583 L p
.52099 .57793 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .511 .58144 L p
.49939 .58226 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .49212 .583 L p
.49939 .58226 L 1 g
F P
s
P
p
.002 w
.49212 .583 m .51111 .583 L p
.49939 .58226 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .5317 .57457 L p
1 g
F P
s
P
p
.52099 .57793 m .51111 .583 L .5317 .57457 L 1 g
F
P
p
.53904 .57034 m .53632 .57294 L .54221 .56852 L 1 g
F
P
p
.53904 .57034 m .54221 .56852 L .54926 .56323 L 1 g
F
P
p
.002 w
.53665 .56574 m .54221 .56852 L p
.53328 .57366 L 1 g
F P
s
P
p
.55515 .55582 m .55596 .55479 L .56173 .54751 L 1 g
F
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.55259 .57091 m .54517 .57001 L .55079 .56208 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54927 .56324 L p
1 g
F P
s
P
p
.56075 .54566 m .54927 .56324 L .55514 .55583 L 1 g
F
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.54926 .56323 m .53665 .56574 L .55596 .55479 L 1 g
F
P
p
.002 w
.54425 .56955 m .54221 .56852 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.54221 .56852 m .53665 .56574 L p
.54926 .56323 L 1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54927 .56324 L p
1 g
F P
s
P
p
.002 w
.54927 .56324 m .54926 .56323 L p
.5488 .5636 L 1 g
F P
s
P
p
.5488 .5636 m .5322 .57686 L .54927 .56324 L 1 g
F
P
p
.002 w
.55079 .56208 m .55596 .55479 L p
.55513 .55878 L 1 g
F P
s
P
p
.55259 .57091 m .55079 .56208 L .55513 .55878 L 1 g
F
P
p
.56654 .52734 m .56173 .54751 L .56247 .54561 L 1 g
F
P
p
.002 w
.56289 .54454 m .5637 .54388 L .56247 .54561 L p
1 g
F P
s
P
p
.56255 .5454 m .56247 .54561 L .56255 .54541 L 1 g
F
P
p
.56654 .52734 m .56247 .54561 L .56255 .5454 L 1 g
F
P
p
.56654 .52734 m .56254 .54546 L .56418 .54027 L 1 g
F
P
p
.56254 .54546 m .56306 .54409 L .56418 .54027 L 1 g
F
P
p
.56306 .54409 m .56311 .54394 L .56418 .54027 L 1 g
F
P
p
.56309 .54399 m .5632 .54366 L .56418 .54027 L 1 g
F
P
p
.5632 .54366 m .56325 .54349 L .56418 .54027 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.53487 .53085 m .54293 .52247 L .56327 .54344 L p
1 g
F P
s
P
p
.002 w
.56327 .54344 m .5637 .54388 L .5632 .54366 L p
1 g
F P
s
P
p
.002 w
.5632 .54366 m .53487 .53085 L p
.56327 .54344 L 1 g
F P
s
P
p
.5632 .54366 m .56323 .54356 L .56325 .54349 L 1 g
F
P
p
.002 w
.56338 .54306 m .5637 .54388 L .56327 .54344 L p
1 g
F P
s
P
p
.56323 .54356 m .5635 .54267 L .56418 .54027 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55319 .51623 m .56448 .51285 L .56375 .54178 L p
1 g
F P
s
P
p
.002 w
.56375 .54178 m .5637 .54388 L .56338 .54306 L p
1 g
F P
s
P
p
.002 w
.56338 .54306 m .55319 .51623 L p
.56375 .54178 L 1 g
F P
s
P
p
.56338 .54306 m .56332 .54329 L .5635 .54267 L 1 g
F
P
p
.56323 .54356 m .56327 .54345 L .56338 .54306 L 1 g
F
P
p
.56327 .54345 m .56332 .54329 L .56338 .54306 L 1 g
F
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.54293 .52247 m .55319 .51623 L .56338 .54306 L p
1 g
F P
s
P
p
.002 w
.56327 .54344 m .54293 .52247 L p
.56338 .54306 L 1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .55013 m .52989 .54043 L .56314 .54383 L p
1 g
F P
s
P
p
.002 w
.56314 .54383 m .5637 .54388 L .56309 .54399 L p
1 g
F P
s
P
p
.002 w
.56309 .54399 m .52853 .55013 L p
.56314 .54383 L 1 g
F P
s
P
p
.002 w
.56309 .54399 m .5637 .54388 L .56302 .54419 L p
1 g
F P
s
P
p
.56306 .54409 m .56309 .54399 L .56311 .54394 L 1 g
F
P
p
.56309 .54399 m .56321 .54368 L .56332 .54329 L 1 g
F
P
p
.002 w
.52989 .54043 m .53487 .53085 L .5632 .54366 L p
1 g
F P
s
P
p
.002 w
.5632 .54366 m .5637 .54388 L .56314 .54383 L p
1 g
F P
s
P
p
.002 w
.56314 .54383 m .52989 .54043 L p
.5632 .54366 L 1 g
F P
s
P
p
.002 w
.53088 .55888 m .52853 .55013 L .56309 .54399 L p
1 g
F P
s
P
p
.002 w
.56302 .54419 m .53088 .55888 L p
.56309 .54399 L 1 g
F P
s
P
p
.56302 .54419 m .56198 .54799 L .56321 .54368 L 1 g
F
P
p
.56254 .54546 m .56251 .5456 L .56302 .54419 L 1 g
F
P
p
.56251 .5456 m .56198 .54799 L .56302 .54419 L 1 g
F
P
p
.002 w
.53665 .56574 m .53088 .55888 L .56302 .54419 L p
1 g
F P
s
P
p
.002 w
.56302 .54419 m .5637 .54388 L .56289 .54454 L p
1 g
F P
s
P
p
.002 w
.56289 .54454 m .53665 .56574 L p
.56302 .54419 L 1 g
F P
s
P
p
.002 w
.53665 .56574 m .56289 .54454 L p
.55596 .55479 L 1 g
F P
s
P
p
.002 w
.56247 .54561 m .55596 .55479 L p
.56289 .54454 L 1 g
F P
s
P
p
.002 w
.55596 .55479 m .56247 .54561 L p
.56173 .54751 L 1 g
F P
s
P
p
.55259 .57091 m .55596 .55479 L .56173 .54751 L 1 g
F
P
p
.002 w
.54927 .56324 m .54998 .56518 L p
.55514 .55583 L 1 g
F P
s
P
p
.53632 .57294 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.55515 .55582 m .55514 .55583 L .55596 .55479 L 1 g
F
P
p
.002 w
.56656 .5694 m .55551 .57126 L .56315 .54572 L p
1 g
F P
s
P
p
.002 w
.56315 .54572 m .5637 .54388 L .56381 .54488 L p
1 g
F P
s
P
p
.002 w
.56381 .54488 m .56656 .5694 L p
.56315 .54572 L 1 g
F P
s
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56174 .54753 L p
1 g
F P
s
P
p
.002 w
.56174 .54753 m .56173 .54751 L p
.56161 .54769 L 1 g
F P
s
P
p
.56161 .54769 m .54998 .56518 L .56174 .54753 L 1 g
F
P
p
.55514 .55583 m .54998 .56518 L .56173 .54751 L 1 g
F
P
p
.002 w
.56173 .54751 m .56198 .54799 L p
.56255 .54541 L 1 g
F P
s
P
p
.002 w
.56854 .53025 m .56854 .53021 L p
.56515 .50826 L 1 g
F P
s
P
p
.002 w
.56623 .50954 m .56515 .50826 L p
.56854 .53021 L 1 g
F P
s
P
p
.002 w
.56448 .51285 m .56421 .50535 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.5678 .5128 m .56659 .51282 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56659 .51282 m .56448 .51285 L p
.56623 .50954 L 1 g
F P
s
P
p
.002 w
.56854 .53021 m .56713 .51061 L .56623 .50954 L p
1 g
F P
s
P
p
.56659 .51282 m .56747 .5287 L .56396 .54103 L 1 g
F
P
p
.56747 .5287 m .56772 .53327 L .56396 .54103 L 1 g
F
P
p
.002 w
.5637 .54388 m .56448 .51285 L .56659 .51282 L p
1 g
F P
s
P
p
.002 w
.56198 .54799 m .56257 .5491 L p
.56418 .54027 L 1 g
F P
s
P
p
.002 w
.57718 .56463 m .56656 .5694 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.58625 .55745 m .57718 .56463 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.59284 .54861 m .58625 .55745 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.59622 .53903 m .59284 .54861 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.59601 .5297 m .59622 .53903 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.59219 .52164 m .59601 .5297 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.58511 .51575 m .59219 .52164 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.57553 .51269 m .58511 .51575 L .5637 .54388 L closepath p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56747 .5287 L p
1 g
F P
s
P
p
.56418 .54027 m .56257 .5491 L .56747 .5287 L 1 g
F
P
p
.002 w
.56747 .5287 m .56854 .53025 L p
.56701 .52031 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56854 .53021 L p
.57056 .53318 L 1 g
F P
s
P
p
.002 w
.56854 .53021 m .56854 .53025 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .57056 .53318 L p
.56854 .53021 L 1 g
F P
s
P
p
.002 w
.56623 .50954 m .56713 .51061 L p
.56236 .50149 L 1 g
F P
s
P
p
.002 w
.57553 .51269 m .5678 .5128 L p
.56327 .47865 L 1 g
F P
s
P
p
.002 w
.55288 .48172 m .54873 .48295 L p
.54234 .47674 L 1 g
F P
s
P
p
.002 w
.55796 .49193 m .55834 .49233 L p
.55311 .48722 L 1 g
F P
s
P
p
.002 w
.54234 .47674 m .54248 .47689 L p
.53949 .47538 L 1 g
F P
s
P
p
.002 w
.56327 .47865 m .55288 .48172 L p
.52692 .45218 L 1 g
F P
s
P
p
.002 w
.53593 .4737 m .54078 .4853 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52241 .46713 L p
1 g
F P
s
P
p
.002 w
.52241 .46713 m .52214 .46667 L p
.53248 .47202 L 1 g
F P
s
P
p
.53248 .47202 m .54302 .47747 L .52241 .46713 L 1 g
F
P
p
.002 w
.52692 .45218 m .53384 .46872 L p
.52241 .46713 L 1 g
F P
s
P
p
.5 .4634 m .52241 .46713 L .51488 .46607 L 1 g
F
P
p
.5 .4634 m .52262 .46746 L .51424 .46614 L 1 g
F
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.49685 .47051 m .50613 .46485 L p
.54078 .4853 L 1 g
F P
s
P
p
.002 w
.50613 .46485 m .49685 .47051 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46388 L p
1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .4634 L p
.51424 .46614 L 1 g
F P
s
P
p
.51424 .46614 m .52282 .46778 L .5 .46388 L 1 g
F
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.47328 .44187 m .51047 .46221 L .5 .46388 L 1 g
F
P
p
.47786 .46667 m .5 .46388 L .49076 .46536 L 1 g
F
P
p
.002 w
.4924 .4651 m .49011 .46232 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.49011 .46232 m .47328 .44187 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.50613 .46485 m .51129 .46171 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.51129 .46171 m .52692 .45218 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.53384 .46872 m .53593 .4737 L p
.52241 .46713 L 1 g
F P
s
P
p
.002 w
.54248 .47689 m .54302 .47747 L p
.53248 .47202 L 1 g
F P
s
P
p
.002 w
.52241 .46713 m .52262 .46746 L p
.51488 .46607 L 1 g
F P
s
P
p
.002 w
.51047 .46221 m .50613 .46485 L p
.5 .46388 L 1 g
F P
s
P
p
.002 w
.52262 .46746 m .52282 .46778 L p
.51424 .46614 L 1 g
F P
s
P
p
.002 w
.5 .46388 m .5 .46442 L p
.49076 .46536 L 1 g
F P
s
P
p
.002 w
.52692 .45218 m .51047 .46221 L p
.47328 .44187 L 1 g
F P
s
P
p
.002 w
.44593 .47124 m .47328 .44187 L .4924 .4651 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47763 .46705 L p
1 g
F P
s
P
p
.48928 .46551 m .5 .46442 L .47763 .46705 L 1 g
F
P
p
.002 w
.47763 .46705 m .47718 .46778 L p
.46533 .47298 L 1 g
F P
s
P
p
.44334 .47402 m .46167 .47282 L .45775 .47663 L 1 g
F
P
p
.44339 .4905 m .45775 .47663 L .45128 .48294 L 1 g
F
P
p
.002 w
.45326 .48101 m .4514 .4797 L p
.45775 .47663 L 1 g
F P
s
P
p
.002 w
.4514 .4797 m .44334 .47402 L p
.45775 .47663 L 1 g
F P
s
P
p
.46167 .47282 m .46629 .47252 L .45775 .47663 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45775 .47663 L p
1 g
F P
s
P
p
.46533 .47298 m .47718 .46778 L .45775 .47663 L 1 g
F
P
p
.002 w
.45775 .47663 m .45698 .47747 L p
.45128 .48294 L 1 g
F P
s
P
p
.002 w
.42841 .50505 m .44334 .47402 L .45326 .48101 L p
1 g
F P
s
P
p
.002 w
.44278 .49115 m .44166 .49233 L p
.43764 .50175 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44278 .49115 L p
1 g
F P
s
P
p
.44971 .48444 m .45698 .47747 L .44278 .49115 L 1 g
F
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43396 .50932 L p
1 g
F P
s
P
p
.43764 .50175 m .44166 .49233 L .43396 .50932 L 1 g
F
P
p
.002 w
.43396 .50932 m .43287 .51061 L p
.4331 .51707 L 1 g
F P
s
P
p
.002 w
.47352 .49528 m .45961 .52344 L .4335 .51345 L p
1 g
F P
s
P
p
.002 w
.4335 .51345 m .45961 .52344 L p
.43221 .54061 L 1 g
F P
s
P
p
.002 w
.43287 .51061 m .43146 .53025 L .4328 .52831 L p
1 g
F P
s
P
p
.4332 .51983 m .43287 .51061 L .4328 .52831 L 1 g
F
P
p
.002 w
.4328 .52831 m .43146 .53025 L p
.43619 .53961 L 1 g
F P
s
P
p
.002 w
.43272 .57882 m .42232 .54681 L .43906 .54915 L p
1 g
F P
s
P
p
.002 w
.43906 .54915 m .45651 .5516 L p
.4454 .5643 L 1 g
F P
s
P
p
.43272 .57882 m .43906 .54915 L .4454 .5643 L 1 g
F
P
p
.002 w
.43146 .53025 m .43247 .53343 L p
.43846 .54716 L 1 g
F P
s
P
p
.002 w
.43247 .53343 m .43743 .5491 L .43832 .54741 L p
1 g
F P
s
P
p
.002 w
.43832 .54741 m .43846 .54716 L p
.43247 .53343 L 1 g
F P
s
P
p
.43619 .53961 m .43146 .53025 L .43846 .54716 L 1 g
F
P
p
.002 w
.43846 .54716 m .43832 .54741 L p
.43933 .54847 L 1 g
F P
s
P
p
.002 w
.45961 .52344 m .45651 .5516 L .43986 .54927 L p
1 g
F P
s
P
p
.44894 .56026 m .45651 .5516 L .45094 .56269 L 1 g
F
P
p
.002 w
.43832 .54741 m .43743 .5491 L p
.44553 .55614 L 1 g
F P
s
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45094 .56269 L p
1 g
F P
s
P
p
.44553 .55614 m .43743 .5491 L .45094 .56269 L 1 g
F
P
p
.002 w
.45002 .56518 m .45373 .56762 L p
.46076 .56998 L 1 g
F P
s
P
p
.45928 .56888 m .45002 .56518 L .46076 .56998 L 1 g
F
P
p
.002 w
.45373 .56762 m .4678 .57686 L .46821 .57498 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48908 .58034 L p
1 g
F P
s
P
p
.47919 .5778 m .4678 .57686 L .48908 .58034 L 1 g
F
P
p
.002 w
.4973 .5699 m .50718 .58125 L p
.49085 .58043 L 1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.51039 .44901 L
s
P
p
.004 w
.52845 .48114 m
.54944 .51851 L
s
P
p
.002 w
.45511 .29888 m .39596 .33519 L .38425 .31533 L p
1 g
F P
s
P
p
.002 w
.38425 .31533 m .44403 .2786 L .45511 .29888 L p
1 g
F P
s
P
p
.002 w
.6252 .53103 m .62504 .5127 L .64983 .49355 L p
1 g
F P
s
P
p
.002 w
.6396 .46997 m .64983 .49355 L .62504 .5127 L p
1 g
F P
s
P
p
.002 w
.64983 .49355 m .6396 .46997 L .6569 .44247 L p
1 g
F P
s
P
p
.002 w
.52077 .28113 m .45511 .29888 L .44403 .2786 L p
1 g
F P
s
P
p
.002 w
.59598 .3383 m .64309 .35678 L .63959 .38705 L p
1 g
F P
s
P
p
.002 w
.64309 .35678 m .59598 .3383 L .59137 .30888 L p
1 g
F P
s
P
p
.002 w
.59284 .54861 m .59622 .53903 L .6252 .53103 L p
1 g
F P
s
P
p
.002 w
.62504 .5127 m .6252 .53103 L .59622 .53903 L p
1 g
F P
s
P
p
.002 w
.38972 .42861 m .36702 .47824 L .34406 .46019 L p
1 g
F P
s
P
p
.002 w
.34406 .46019 m .36823 .40622 L .38972 .42861 L p
1 g
F P
s
P
p
.002 w
.63176 .41925 m .6569 .44247 L .6396 .46997 L p
1 g
F P
s
P
p
.002 w
.6569 .44247 m .63176 .41925 L .63959 .38705 L p
1 g
F P
s
P
p
.002 w
.41124 .35859 m .36823 .40622 L .35123 .38512 L p
1 g
F P
s
P
p
.002 w
.35123 .38512 m .39596 .33519 L .41124 .35859 L p
1 g
F P
s
P
p
.002 w
.42579 .51049 m .42232 .54681 L .391 .53859 L p
1 g
F P
s
P
p
.002 w
.391 .53859 m .39455 .49522 L .42579 .51049 L p
1 g
F P
s
P
p
.002 w
.53073 .30665 m .59137 .30888 L .59598 .3383 L p
1 g
F P
s
P
p
.002 w
.59137 .30888 m .53073 .30665 L .52077 .28113 L p
1 g
F P
s
P
p
.002 w
.45511 .29888 m .52077 .28113 L .53073 .30665 L p
1 g
F P
s
P
p
.002 w
.59622 .53903 m .59601 .5297 L .62504 .5127 L p
1 g
F P
s
P
p
.002 w
.61779 .49669 m .62504 .5127 L .59601 .5297 L p
1 g
F P
s
P
p
.002 w
.62504 .5127 m .61779 .49669 L .6396 .46997 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.59774 .37119 m .63959 .38705 L .63176 .41925 L p
1 g
F P
s
P
p
.002 w
.63959 .38705 m .59774 .37119 L .59598 .3383 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.61979 .45225 m .6396 .46997 L .61779 .49669 L p
1 g
F P
s
P
p
.002 w
.6396 .46997 m .61979 .45225 L .63176 .41925 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.41505 .4515 m .39455 .49522 L .36702 .47824 L p
1 g
F P
s
P
p
.002 w
.36702 .47824 m .38972 .42861 L .41505 .4515 L p
1 g
F P
s
P
p
.002 w
.46791 .32385 m .41124 .35859 L .39596 .33519 L p
1 g
F P
s
P
p
.002 w
.39596 .33519 m .45511 .29888 L .46791 .32385 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.52853 .55013 m .53088 .55888 L .4973 .5699 L p
1 g
F P
s
P
p
.002 w
.4973 .5699 m .49235 .55273 L .52853 .55013 L p
1 g
F P
s
P
p
.002 w
.53073 .30665 m .46791 .32385 L .45511 .29888 L p
1 g
F P
s
P
p
.002 w
.59601 .5297 m .59219 .52164 L .61779 .49669 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.60405 .48482 m .61779 .49669 L .59219 .52164 L p
1 g
F P
s
P
p
.002 w
.61779 .49669 m .60405 .48482 L .61979 .45225 L p
1 g
F P
s
P
p
.002 w
.42965 .38482 m .38972 .42861 L .36823 .40622 L p
1 g
F P
s
P
p
.002 w
.36823 .40622 m .41124 .35859 L .42965 .38482 L p
1 g
F P
s
P
p
.002 w
.54 .33665 m .59598 .3383 L .59774 .37119 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.5599 .34855 L
s
P
p
.002 w
.59598 .3383 m .54 .33665 L .53073 .30665 L p
1 g
F P
s
P
p
.004 w
.57516 .32768 m
.60037 .29318 L
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.59651 .4064 m .63176 .41925 L .61979 .45225 L p
1 g
F P
s
P
p
.002 w
.63176 .41925 m .59651 .4064 L .59774 .37119 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59219 .52164 m .58511 .51575 L .60405 .48482 L p
1 g
F P
s
P
p
.002 w
.49476 .53354 m .49235 .55273 L .45651 .5516 L p
1 g
F P
s
P
p
.002 w
.45651 .5516 m .45961 .52344 L .49476 .53354 L p
1 g
F P
s
P
p
.002 w
.46791 .32385 m .53073 .30665 L .54 .33665 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.44334 .47402 m .42579 .51049 L .39455 .49522 L p
1 g
F P
s
P
p
.002 w
.39455 .49522 m .41505 .4515 L .44334 .47402 L p
1 g
F P
s
P
p
.002 w
.52989 .54043 m .52853 .55013 L .49235 .55273 L p
1 g
F P
s
P
p
.002 w
.49235 .55273 m .49476 .53354 L .52989 .54043 L p
1 g
F P
s
P
p
.002 w
.59228 .44264 m .61979 .45225 L .60405 .48482 L p
1 g
F P
s
P
p
.002 w
.61979 .45225 m .59228 .44264 L .59651 .4064 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.58511 .51575 m .57553 .51269 L .58519 .47853 L p
1 g
F P
s
P
p
.002 w
.58519 .47853 m .60405 .48482 L .58511 .51575 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.60405 .48482 m .58519 .47853 L .59228 .44264 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.54819 .37014 m .59774 .37119 L .59651 .4064 L p
1 g
F P
s
P
p
.002 w
.59774 .37119 m .54819 .37014 L .54 .33665 L p
1 g
F P
s
P
p
.004 w
.56228 .34529 m
.57516 .32768 L
s
P
p
.004 w
.56178 .34599 m
.56228 .34529 L
s
P
p
.002 w
.48203 .35275 m .42965 .38482 L .41124 .35859 L p
1 g
F P
s
P
p
.002 w
.41124 .35859 m .46791 .32385 L .48203 .35275 L p
1 g
F P
s
P
p
.002 w
.53487 .53085 m .52989 .54043 L .49476 .53354 L p
1 g
F P
s
P
p
.002 w
.56327 .47865 m .58519 .47853 L .57553 .51269 L p
1 g
F P
s
P
p
.002 w
.54 .33665 m .48203 .35275 L .46791 .32385 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.45059 .41293 m .41505 .4515 L .38972 .42861 L p
1 g
F P
s
P
p
.002 w
.38972 .42861 m .42965 .38482 L .45059 .41293 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.54293 .52247 m .53487 .53085 L .50443 .51447 L p
1 g
F P
s
P
p
.002 w
.49476 .53354 m .50443 .51447 L .53487 .53085 L p
1 g
F P
s
P
p
.002 w
.56448 .51285 m .55319 .51623 L .54078 .4853 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50443 .51447 m .49476 .53354 L .45961 .52344 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.48203 .35275 m .54 .33665 L .54819 .37014 L p
1 g
F P
s
P
p
.002 w
.55319 .51623 m .54293 .52247 L .52037 .49772 L p
1 g
F P
s
P
p
.002 w
.50443 .51447 m .52037 .49772 L .54293 .52247 L p
1 g
F P
s
P
p
.002 w
.45961 .52344 m .47352 .49528 L .50443 .51447 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.52037 .49772 m .54078 .4853 L .55319 .51623 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55498 .40589 m .59651 .4064 L .59228 .44264 L p
1 g
F P
s
P
p
.002 w
.59651 .4064 m .55498 .40589 L .54819 .37014 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.58519 .47853 m .56327 .47865 L .56007 .44254 L p
1 g
F P
s
P
p
.002 w
.56007 .44254 m .59228 .44264 L .58519 .47853 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.59228 .44264 m .56007 .44254 L .55498 .40589 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.47328 .44187 m .44334 .47402 L .41505 .4515 L p
1 g
F P
s
P
p
.002 w
.41505 .4515 m .45059 .41293 L .47328 .44187 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.52037 .49772 m .50443 .51447 L .47352 .49528 L p
1 g
F P
s
P
p
.002 w
.49695 .38458 m .45059 .41293 L .42965 .38482 L p
1 g
F P
s
P
p
.002 w
.42965 .38482 m .48203 .35275 L .49695 .38458 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.54819 .37014 m .49695 .38458 L .48203 .35275 L p
1 g
F P
s
P
p
.002 w
.52692 .45218 m .56007 .44254 L .56327 .47865 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.49695 .38458 m .54819 .37014 L .55498 .40589 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.54078 .4853 m .52037 .49772 L .49685 .47051 L p
1 g
F P
s
P
p
.002 w
.47352 .49528 m .49685 .47051 L .52037 .49772 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.56007 .44254 m .52692 .45218 L .51211 .41817 L p
1 g
F P
s
P
p
.002 w
.51211 .41817 m .55498 .40589 L .56007 .44254 L p
1 g
F P
s
P
p
.002 w
.55498 .40589 m .51211 .41817 L .49695 .38458 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.51211 .41817 m .47328 .44187 L .45059 .41293 L p
1 g
F P
s
P
p
.002 w
.45059 .41293 m .49695 .38458 L .51211 .41817 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.47328 .44187 m .51211 .41817 L .52692 .45218 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.004 w
.58531 .58235 m
.59006 .59081 L
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .60037 .29318 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60155 .61126 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95118 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00412314 0.991754 -0.0653656 0.991754 [
[(0.7)] .5 .95118 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 .95118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.7)] .5 .95118 0 -1.5 Mshowa
0 0 m
1 0 L
1 .95118 L
0 .95118 L
closepath
clip
newpath
p
P
p
.002 w
.47362 .45259 m .51437 .44288 L .50442 .41609 L p
1 g
F P
s
P
p
.002 w
.50442 .41609 m .4704 .42416 L .47362 .45259 L p
1 g
F P
s
P
p
.002 w
.53515 .40001 m .50442 .41609 L .51437 .44288 L p
1 g
F P
s
P
p
.002 w
.4704 .42416 m .50442 .41609 L .49433 .38959 L p
1 g
F P
s
P
p
.002 w
.50442 .41609 m .53515 .40001 L .51817 .37702 L p
1 g
F P
s
P
p
.002 w
.51817 .37702 m .49433 .38959 L .50442 .41609 L p
1 g
F P
s
P
p
.002 w
.47749 .4806 m .52401 .46947 L .51437 .44288 L p
1 g
F P
s
P
p
.002 w
.51437 .44288 m .47362 .45259 L .47749 .4806 L p
1 g
F P
s
P
p
.002 w
.55127 .42372 m .51437 .44288 L .52401 .46947 L p
1 g
F P
s
P
p
.002 w
.51437 .44288 m .55127 .42372 L .53515 .40001 L p
1 g
F P
s
P
p
.002 w
.4327 .45191 m .47362 .45259 L .4704 .42416 L p
1 g
F P
s
P
p
.002 w
.4704 .42416 m .43628 .42341 L .4327 .45191 L p
1 g
F P
s
P
p
.002 w
.43628 .42341 m .4704 .42416 L .46789 .39582 L p
1 g
F P
s
P
p
.002 w
.49433 .38959 m .46789 .39582 L .4704 .42416 L p
1 g
F P
s
P
p
.002 w
.43074 .48008 m .47749 .4806 L .47362 .45259 L p
1 g
F P
s
P
p
.002 w
.47362 .45259 m .4327 .45191 L .43074 .48008 L p
1 g
F P
s
P
p
.002 w
.46789 .39582 m .49433 .38959 L .4843 .36384 L p
1 g
F P
s
P
p
.002 w
.49433 .38959 m .51817 .37702 L .50062 .35517 L p
1 g
F P
s
P
p
.002 w
.50062 .35517 m .4843 .36384 L .49433 .38959 L p
1 g
F P
s
P
p
.002 w
.48194 .50768 m .53316 .49537 L .52401 .46947 L p
1 g
F P
s
P
p
.002 w
.52401 .46947 m .47749 .4806 L .48194 .50768 L p
1 g
F P
s
P
p
.002 w
.56622 .44771 m .52401 .46947 L .53316 .49537 L p
1 g
F P
s
P
p
.002 w
.52401 .46947 m .56622 .44771 L .55127 .42372 L p
1 g
F P
s
P
p
.002 w
.55967 .37734 m .53515 .40001 L .55127 .42372 L p
1 g
F P
s
P
p
.002 w
.53515 .40001 m .55967 .37734 L .53706 .3593 L p
1 g
F P
s
P
p
.002 w
.53706 .3593 m .51817 .37702 L .53515 .40001 L p
1 g
F P
s
P
p
.002 w
.46789 .39582 m .44141 .3951 L .43628 .42341 L p
1 g
F P
s
P
p
.002 w
.44141 .3951 m .46789 .39582 L .46615 .3681 L p
1 g
F P
s
P
p
.002 w
.4843 .36384 m .46615 .3681 L .46789 .39582 L p
1 g
F P
s
P
p
.002 w
.58088 .39674 m .55127 .42372 L .56622 .44771 L p
1 g
F P
s
P
p
.002 w
.55127 .42372 m .58088 .39674 L .55967 .37734 L p
1 g
F P
s
P
p
.002 w
.43046 .50737 m .48194 .50768 L .47749 .4806 L p
1 g
F P
s
P
p
.002 w
.47749 .4806 m .43074 .48008 L .43046 .50737 L p
1 g
F P
s
P
p
.002 w
.51817 .37702 m .53706 .3593 L .51346 .34294 L p
1 g
F P
s
P
p
.002 w
.51346 .34294 m .50062 .35517 L .51817 .37702 L p
1 g
F P
s
P
p
.002 w
.39541 .44069 m .4327 .45191 L .43628 .42341 L p
1 g
F P
s
P
p
.002 w
.43628 .42341 m .40532 .41377 L .39541 .44069 L p
1 g
F P
s
P
p
.002 w
.40532 .41377 m .43628 .42341 L .44141 .3951 L p
1 g
F P
s
P
p
.002 w
.53316 .49537 m .57971 .47156 L .56622 .44771 L p
1 g
F P
s
P
p
.002 w
.60028 .41712 m .56622 .44771 L .57971 .47156 L p
1 g
F P
s
P
p
.002 w
.56622 .44771 m .60028 .41712 L .58088 .39674 L p
1 g
F P
s
P
p
.002 w
.44141 .3951 m .41749 .3874 L .40532 .41377 L p
1 g
F P
s
P
p
.002 w
.41749 .3874 m .44141 .3951 L .448 .36751 L p
1 g
F P
s
P
p
.002 w
.46615 .3681 m .448 .36751 L .44141 .3951 L p
1 g
F P
s
P
p
.002 w
.46615 .3681 m .4843 .36384 L .47449 .33933 L p
1 g
F P
s
P
p
.002 w
.4843 .36384 m .50062 .35517 L .48283 .33488 L p
1 g
F P
s
P
p
.002 w
.48283 .33488 m .47449 .33933 L .4843 .36384 L p
1 g
F P
s
P
p
.002 w
.388 .46764 m .43074 .48008 L .4327 .45191 L p
1 g
F P
s
P
p
.002 w
.4327 .45191 m .39541 .44069 L .388 .46764 L p
1 g
F P
s
P
p
.002 w
.448 .36751 m .46615 .3681 L .46521 .3415 L p
1 g
F P
s
P
p
.002 w
.47449 .33933 m .46521 .3415 L .46615 .3681 L p
1 g
F P
s
P
p
.002 w
.48692 .53331 m .54164 .52009 L .53316 .49537 L p
1 g
F P
s
P
p
.002 w
.53316 .49537 m .48194 .50768 L .48692 .53331 L p
1 g
F P
s
P
p
.002 w
.57971 .47156 m .53316 .49537 L .54164 .52009 L p
1 g
F P
s
P
p
.002 w
.50062 .35517 m .51346 .34294 L .48933 .32859 L p
1 g
F P
s
P
p
.002 w
.48933 .32859 m .48283 .33488 L .50062 .35517 L p
1 g
F P
s
P
p
.002 w
.43191 .53324 m .48692 .53331 L .48194 .50768 L p
1 g
F P
s
P
p
.002 w
.48194 .50768 m .43046 .50737 L .43191 .53324 L p
1 g
F P
s
P
p
.002 w
.57543 .35011 m .55967 .37734 L .58088 .39674 L p
1 g
F P
s
P
p
.002 w
.55967 .37734 m .57543 .35011 L .54901 .33808 L p
1 g
F P
s
P
p
.002 w
.54901 .33808 m .53706 .3593 L .55967 .37734 L p
1 g
F P
s
P
p
.002 w
.53706 .3593 m .54901 .33808 L .52146 .32835 L p
1 g
F P
s
P
p
.002 w
.52146 .32835 m .51346 .34294 L .53706 .3593 L p
1 g
F P
s
P
p
.002 w
.448 .36751 m .4317 .36209 L .41749 .3874 L p
1 g
F P
s
P
p
.002 w
.4317 .36209 m .448 .36751 L .45595 .34116 L p
1 g
F P
s
P
p
.002 w
.46521 .3415 m .45595 .34116 L .448 .36751 L p
1 g
F P
s
P
p
.002 w
.38328 .49409 m .43046 .50737 L .43074 .48008 L p
1 g
F P
s
P
p
.002 w
.43074 .48008 m .388 .46764 L .38328 .49409 L p
1 g
F P
s
P
p
.002 w
.60019 .36424 m .58088 .39674 L .60028 .41712 L p
1 g
F P
s
P
p
.002 w
.58088 .39674 m .60019 .36424 L .57543 .35011 L p
1 g
F P
s
P
p
.002 w
.51346 .34294 m .52146 .32835 L .49331 .32113 L p
1 g
F P
s
P
p
.002 w
.49331 .32113 m .48933 .32859 L .51346 .34294 L p
1 g
F P
s
P
p
.002 w
.54164 .52009 m .59146 .49479 L .57971 .47156 L p
1 g
F P
s
P
p
.002 w
.61746 .43813 m .57971 .47156 L .59146 .49479 L p
1 g
F P
s
P
p
.002 w
.57971 .47156 m .61746 .43813 L .60028 .41712 L p
1 g
F P
s
P
p
.002 w
.38068 .39589 m .40532 .41377 L .41749 .3874 L p
1 g
F P
s
P
p
.002 w
.41749 .3874 m .39862 .37332 L .38068 .39589 L p
1 g
F P
s
P
p
.002 w
.39862 .37332 m .41749 .3874 L .4317 .36209 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .46521 .3415 L .47449 .33933 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .47449 .33933 L .48283 .33488 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .45595 .34116 L .46521 .3415 L closepath p
1 g
F P
s
P
p
.002 w
.36552 .41959 m .39541 .44069 L .40532 .41377 L p
1 g
F P
s
P
p
.002 w
.40532 .41377 m .38068 .39589 L .36552 .41959 L p
1 g
F P
s
P
p
.002 w
.4317 .36209 m .41895 .35231 L .39862 .37332 L p
1 g
F P
s
P
p
.002 w
.41895 .35231 m .4317 .36209 L .44767 .33832 L p
1 g
F P
s
P
p
.002 w
.45595 .34116 m .44767 .33832 L .4317 .36209 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .48283 .33488 L .48933 .32859 L closepath p
1 g
F P
s
P
p
.002 w
.49234 .55694 m .54928 .54313 L .54164 .52009 L p
1 g
F P
s
P
p
.002 w
.54164 .52009 m .48692 .53331 L .49234 .55694 L p
1 g
F P
s
P
p
.002 w
.59146 .49479 m .54164 .52009 L .54928 .54313 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .44767 .33832 L .45595 .34116 L closepath p
1 g
F P
s
P
p
.002 w
.62276 .38022 m .60028 .41712 L .61746 .43813 L p
1 g
F P
s
P
p
.002 w
.60028 .41712 m .62276 .38022 L .60019 .36424 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .48933 .32859 L .49331 .32113 L closepath p
1 g
F P
s
P
p
.002 w
.43511 .55712 m .49234 .55694 L .48692 .53331 L p
1 g
F P
s
P
p
.002 w
.48692 .53331 m .43191 .53324 L .43511 .55712 L p
1 g
F P
s
P
p
.002 w
.38142 .51948 m .43191 .53324 L .43046 .50737 L p
1 g
F P
s
P
p
.002 w
.43046 .50737 m .38328 .49409 L .38142 .51948 L p
1 g
F P
s
P
p
.002 w
.52369 .31289 m .52146 .32835 L .54901 .33808 L p
1 g
F P
s
P
p
.002 w
.52146 .32835 m .52369 .31289 L .49432 .31328 L p
1 g
F P
s
P
p
.002 w
.49432 .31328 m .49331 .32113 L .52146 .32835 L p
1 g
F P
s
P
p
.002 w
.55261 .31544 m .54901 .33808 L .57543 .35011 L p
1 g
F P
s
P
p
.002 w
.54901 .33808 m .55261 .31544 L .52369 .31289 L p
1 g
F P
s
P
p
.002 w
.35353 .44395 m .388 .46764 L .39541 .44069 L p
1 g
F P
s
P
p
.002 w
.39541 .44069 m .36552 .41959 L .35353 .44395 L p
1 g
F P
s
P
p
.002 w
.44767 .33832 m .44127 .33327 L .41895 .35231 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .44127 .33327 L .44767 .33832 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .49331 .32113 L .49432 .31328 L closepath p
1 g
F P
s
P
p
.002 w
.58052 .3209 m .57543 .35011 L .60019 .36424 L p
1 g
F P
s
P
p
.002 w
.57543 .35011 m .58052 .3209 L .55261 .31544 L p
1 g
F P
s
P
p
.002 w
.54928 .54313 m .60119 .51694 L .59146 .49479 L p
1 g
F P
s
P
p
.002 w
.63202 .45934 m .59146 .49479 L .60119 .51694 L p
1 g
F P
s
P
p
.002 w
.59146 .49479 m .63202 .45934 L .61746 .43813 L p
1 g
F P
s
P
p
.002 w
.38692 .35413 m .39862 .37332 L .41895 .35231 L p
1 g
F P
s
P
p
.002 w
.41895 .35231 m .41119 .33912 L .38692 .35413 L p
1 g
F P
s
P
p
.002 w
.41119 .33912 m .41895 .35231 L .44127 .33327 L p
1 g
F P
s
P
p
.002 w
.44127 .33327 m .43744 .32652 L .41119 .33912 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .43744 .32652 L .44127 .33327 L closepath p
1 g
F P
s
P
p
.002 w
.36517 .37129 m .38068 .39589 L .39862 .37332 L p
1 g
F P
s
P
p
.002 w
.39862 .37332 m .38692 .35413 L .36517 .37129 L p
1 g
F P
s
P
p
.002 w
.49222 .30587 m .49432 .31328 L .52369 .31289 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .49432 .31328 L .49222 .30587 L closepath p
1 g
F P
s
P
p
.002 w
.64263 .39776 m .61746 .43813 L .63202 .45934 L p
1 g
F P
s
P
p
.002 w
.61746 .43813 m .64263 .39776 L .62276 .38022 L p
1 g
F P
s
P
p
.002 w
.34504 .46846 m .38328 .49409 L .388 .46764 L p
1 g
F P
s
P
p
.002 w
.388 .46764 m .35353 .44395 L .34504 .46846 L p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .439 .31091 L .43665 .31879 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .43665 .31879 L .43744 .32652 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .47071 .29376 L .46107 .29466 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .46107 .29466 L .45192 .29812 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .45192 .29812 L .44428 .30375 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .44428 .30375 L .439 .31091 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .49222 .30587 L .48719 .29972 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .48719 .29972 L .47975 .29552 L closepath p
1 g
F P
s
P
p
.002 w
.46512 .31658 m .47975 .29552 L .47071 .29376 L closepath p
1 g
F P
s
P
p
.002 w
.51976 .29819 m .52369 .31289 L .55261 .31544 L p
1 g
F P
s
P
p
.002 w
.52369 .31289 m .51976 .29819 L .49222 .30587 L p
1 g
F P
s
P
p
.002 w
.60679 .32922 m .60019 .36424 L .62276 .38022 L p
1 g
F P
s
P
p
.002 w
.60019 .36424 m .60679 .32922 L .58052 .3209 L p
1 g
F P
s
P
p
.002 w
.40939 .32385 m .41119 .33912 L .43744 .32652 L p
1 g
F P
s
P
p
.002 w
.43744 .32652 m .43665 .31879 L .40939 .32385 L p
1 g
F P
s
P
p
.002 w
.4981 .57802 m .55587 .56396 L .54928 .54313 L p
1 g
F P
s
P
p
.002 w
.54928 .54313 m .49234 .55694 L .4981 .57802 L p
1 g
F P
s
P
p
.002 w
.60119 .51694 m .54928 .54313 L .55587 .56396 L p
1 g
F P
s
P
p
.002 w
.38255 .54322 m .43511 .55712 L .43191 .53324 L p
1 g
F P
s
P
p
.002 w
.43191 .53324 m .38142 .51948 L .38255 .54322 L p
1 g
F P
s
P
p
.002 w
.34645 .39028 m .36552 .41959 L .38068 .39589 L p
1 g
F P
s
P
p
.002 w
.38068 .39589 m .36517 .37129 L .34645 .39028 L p
1 g
F P
s
P
p
.002 w
.48719 .29972 m .49222 .30587 L .51976 .29819 L p
1 g
F P
s
P
p
.002 w
.54719 .29375 m .55261 .31544 L .58052 .3209 L p
1 g
F P
s
P
p
.002 w
.55261 .31544 m .54719 .29375 L .51976 .29819 L p
1 g
F P
s
P
p
.002 w
.44007 .57843 m .4981 .57802 L .49234 .55694 L p
1 g
F P
s
P
p
.002 w
.49234 .55694 m .43511 .55712 L .44007 .57843 L p
1 g
F P
s
P
p
.002 w
.38394 .33171 m .38692 .35413 L .41119 .33912 L p
1 g
F P
s
P
p
.002 w
.41119 .33912 m .40939 .32385 L .38394 .33171 L p
1 g
F P
s
P
p
.002 w
.41388 .30816 m .40939 .32385 L .43665 .31879 L p
1 g
F P
s
P
p
.002 w
.43665 .31879 m .439 .31091 L .41388 .30816 L p
1 g
F P
s
P
p
.002 w
.51976 .29819 m .50997 .28587 L .48719 .29972 L p
1 g
F P
s
P
p
.002 w
.47975 .29552 m .48719 .29972 L .50997 .28587 L p
1 g
F P
s
P
p
.002 w
.63084 .3403 m .62276 .38022 L .64263 .39776 L p
1 g
F P
s
P
p
.002 w
.62276 .38022 m .63084 .3403 L .60679 .32922 L p
1 g
F P
s
P
p
.002 w
.34037 .49259 m .38142 .51948 L .38328 .49409 L p
1 g
F P
s
P
p
.002 w
.38328 .49409 m .34504 .46846 L .34037 .49259 L p
1 g
F P
s
P
p
.002 w
.55587 .56396 m .60861 .5375 L .60119 .51694 L p
1 g
F P
s
P
p
.002 w
.64358 .48034 m .60119 .51694 L .60861 .5375 L p
1 g
F P
s
P
p
.002 w
.60119 .51694 m .64358 .48034 L .63202 .45934 L p
1 g
F P
s
P
p
.002 w
.50997 .28587 m .51976 .29819 L .54719 .29375 L p
1 g
F P
s
P
p
.002 w
.4243 .29381 m .41388 .30816 L .439 .31091 L p
1 g
F P
s
P
p
.002 w
.439 .31091 m .44428 .30375 L .4243 .29381 L p
1 g
F P
s
P
p
.002 w
.3313 .41074 m .35353 .44395 L .36552 .41959 L p
1 g
F P
s
P
p
.002 w
.36552 .41959 m .34645 .39028 L .3313 .41074 L p
1 g
F P
s
P
p
.002 w
.65929 .41653 m .63202 .45934 L .64358 .48034 L p
1 g
F P
s
P
p
.002 w
.63202 .45934 m .65929 .41653 L .64263 .39776 L p
1 g
F P
s
P
p
.002 w
.5739 .29272 m .58052 .3209 L .60679 .32922 L p
1 g
F P
s
P
p
.002 w
.58052 .3209 m .5739 .29272 L .54719 .29375 L p
1 g
F P
s
P
p
.002 w
.36091 .34229 m .36517 .37129 L .38692 .35413 L p
1 g
F P
s
P
p
.002 w
.38692 .35413 m .38394 .33171 L .36091 .34229 L p
1 g
F P
s
P
p
.002 w
.50997 .28587 m .49526 .27738 L .47975 .29552 L p
1 g
F P
s
P
p
.002 w
.47071 .29376 m .47975 .29552 L .49526 .27738 L p
1 g
F P
s
P
p
.002 w
.43955 .28248 m .4243 .29381 L .44428 .30375 L p
1 g
F P
s
P
p
.002 w
.44428 .30375 m .45192 .29812 L .43955 .28248 L p
1 g
F P
s
P
p
.002 w
.46107 .29466 m .47071 .29376 L .47722 .27378 L p
1 g
F P
s
P
p
.002 w
.49526 .27738 m .47722 .27378 L .47071 .29376 L p
1 g
F P
s
P
p
.002 w
.39032 .30848 m .38394 .33171 L .40939 .32385 L p
1 g
F P
s
P
p
.002 w
.40939 .32385 m .41388 .30816 L .39032 .30848 L p
1 g
F P
s
P
p
.002 w
.4579 .27553 m .43955 .28248 L .45192 .29812 L p
1 g
F P
s
P
p
.002 w
.45192 .29812 m .46107 .29466 L .4579 .27553 L p
1 g
F P
s
P
p
.002 w
.47722 .27378 m .4579 .27553 L .46107 .29466 L p
1 g
F P
s
P
p
.002 w
.38679 .56472 m .44007 .57843 L .43511 .55712 L p
1 g
F P
s
P
p
.002 w
.43511 .55712 m .38255 .54322 L .38679 .56472 L p
1 g
F P
s
P
p
.002 w
.50409 .59598 m .56125 .58203 L .55587 .56396 L p
1 g
F P
s
P
p
.002 w
.55587 .56396 m .4981 .57802 L .50409 .59598 L p
1 g
F P
s
P
p
.002 w
.60861 .5375 m .55587 .56396 L .56125 .58203 L p
1 g
F P
s
P
p
.002 w
.53299 .27542 m .54719 .29375 L .5739 .29272 L p
1 g
F P
s
P
p
.002 w
.54719 .29375 m .53299 .27542 L .50997 .28587 L p
1 g
F P
s
P
p
.002 w
.49526 .27738 m .50997 .28587 L .53299 .27542 L p
1 g
F P
s
P
p
.002 w
.65205 .35396 m .64263 .39776 L .65929 .41653 L p
1 g
F P
s
P
p
.002 w
.64263 .39776 m .65205 .35396 L .63084 .3403 L p
1 g
F P
s
P
p
.002 w
.32018 .43226 m .34504 .46846 L .35353 .44395 L p
1 g
F P
s
P
p
.002 w
.35353 .44395 m .3313 .41074 L .32018 .43226 L p
1 g
F P
s
P
p
.002 w
.59931 .29522 m .60679 .32922 L .63084 .3403 L p
1 g
F P
s
P
p
.002 w
.60679 .32922 m .59931 .29522 L .5739 .29272 L p
1 g
F P
s
P
p
.002 w
.34091 .35545 m .34645 .39028 L .36517 .37129 L p
1 g
F P
s
P
p
.002 w
.36517 .37129 m .36091 .34229 L .34091 .35545 L p
1 g
F P
s
P
p
.002 w
.44674 .59659 m .50409 .59598 L .4981 .57802 L p
1 g
F P
s
P
p
.002 w
.4981 .57802 m .44007 .57843 L .44674 .59659 L p
1 g
F P
s
P
p
.002 w
.33976 .51576 m .38255 .54322 L .38142 .51948 L p
1 g
F P
s
P
p
.002 w
.38142 .51948 m .34037 .49259 L .33976 .51576 L p
1 g
F P
s
P
p
.002 w
.40564 .2871 m .39032 .30848 L .41388 .30816 L p
1 g
F P
s
P
p
.002 w
.41388 .30816 m .4243 .29381 L .40564 .2871 L p
1 g
F P
s
P
p
.002 w
.60861 .5375 m .65176 .50066 L .64358 .48034 L p
1 g
F P
s
P
p
.002 w
.67225 .43616 m .64358 .48034 L .65176 .50066 L p
1 g
F P
s
P
p
.002 w
.64358 .48034 m .67225 .43616 L .65929 .41653 L p
1 g
F P
s
P
p
.002 w
.36893 .312 m .36091 .34229 L .38394 .33171 L p
1 g
F P
s
P
p
.002 w
.38394 .33171 m .39032 .30848 L .36893 .312 L p
1 g
F P
s
P
p
.002 w
.56125 .58203 m .61347 .55597 L .60861 .5375 L p
1 g
F P
s
P
p
.002 w
.65176 .50066 m .60861 .5375 L .61347 .55597 L p
1 g
F P
s
P
p
.002 w
.53299 .27542 m .51134 .26268 L .49526 .27738 L p
1 g
F P
s
P
p
.002 w
.47722 .27378 m .49526 .27738 L .51134 .26268 L p
1 g
F P
s
P
p
.002 w
.42832 .27015 m .40564 .2871 L .4243 .29381 L p
1 g
F P
s
P
p
.002 w
.4243 .29381 m .43955 .28248 L .42832 .27015 L p
1 g
F P
s
P
p
.002 w
.55576 .26872 m .5739 .29272 L .59931 .29522 L p
1 g
F P
s
P
p
.002 w
.5739 .29272 m .55576 .26872 L .53299 .27542 L p
1 g
F P
s
P
p
.002 w
.4579 .27553 m .47722 .27378 L .48454 .25719 L p
1 g
F P
s
P
p
.002 w
.51134 .26268 m .48454 .25719 L .47722 .27378 L p
1 g
F P
s
P
p
.002 w
.51134 .26268 m .53299 .27542 L .55576 .26872 L p
1 g
F P
s
P
p
.002 w
.32454 .37099 m .3313 .41074 L .34645 .39028 L p
1 g
F P
s
P
p
.002 w
.34645 .39028 m .34091 .35545 L .32454 .37099 L p
1 g
F P
s
P
p
.002 w
.62276 .30133 m .63084 .3403 L .65205 .35396 L p
1 g
F P
s
P
p
.002 w
.63084 .3403 m .62276 .30133 L .59931 .29522 L p
1 g
F P
s
P
p
.002 w
.31352 .45435 m .34037 .49259 L .34504 .46846 L p
1 g
F P
s
P
p
.002 w
.34504 .46846 m .32018 .43226 L .31352 .45435 L p
1 g
F P
s
P
p
.002 w
.39416 .58336 m .44674 .59659 L .44007 .57843 L p
1 g
F P
s
P
p
.002 w
.44007 .57843 m .38679 .56472 L .39416 .58336 L p
1 g
F P
s
P
p
.002 w
.45571 .25976 m .42832 .27015 L .43955 .28248 L p
1 g
F P
s
P
p
.002 w
.43955 .28248 m .4579 .27553 L .45571 .25976 L p
1 g
F P
s
P
p
.002 w
.66983 .37 m .65929 .41653 L .67225 .43616 L p
1 g
F P
s
P
p
.002 w
.65929 .41653 m .66983 .37 L .65205 .35396 L p
1 g
F P
s
P
p
.002 w
.48454 .25719 m .45571 .25976 L .4579 .27553 L p
1 g
F P
s
P
p
.002 w
.34343 .53736 m .38679 .56472 L .38255 .54322 L p
1 g
F P
s
P
p
.002 w
.38255 .54322 m .33976 .51576 L .34343 .53736 L p
1 g
F P
s
P
p
.002 w
.5102 .61026 m .56522 .5968 L .56125 .58203 L p
1 g
F P
s
P
p
.002 w
.56125 .58203 m .50409 .59598 L .5102 .61026 L p
1 g
F P
s
P
p
.002 w
.61347 .55597 m .56125 .58203 L .56522 .5968 L p
1 g
F P
s
P
p
.002 w
.38882 .28394 m .36893 .312 L .39032 .30848 L p
1 g
F P
s
P
p
.002 w
.39032 .30848 m .40564 .2871 L .38882 .28394 L p
1 g
F P
s
P
p
.002 w
.35032 .31879 m .34091 .35545 L .36091 .34229 L p
1 g
F P
s
P
p
.002 w
.36091 .34229 m .36893 .312 L .35032 .31879 L p
1 g
F P
s
P
p
.002 w
.45507 .61099 m .5102 .61026 L .50409 .59598 L p
1 g
F P
s
P
p
.002 w
.50409 .59598 m .44674 .59659 L .45507 .61099 L p
1 g
F P
s
P
p
.002 w
.61347 .55597 m .65622 .51979 L .65176 .50066 L p
1 g
F P
s
P
p
.002 w
.68106 .45623 m .65176 .50066 L .65622 .51979 L p
1 g
F P
s
P
p
.002 w
.65176 .50066 m .68106 .45623 L .67225 .43616 L p
1 g
F P
s
P
p
.002 w
.57773 .26609 m .59931 .29522 L .62276 .30133 L p
1 g
F P
s
P
p
.002 w
.59931 .29522 m .57773 .26609 L .55576 .26872 L p
1 g
F P
s
P
p
.002 w
.55576 .26872 m .52764 .25191 L .51134 .26268 L p
1 g
F P
s
P
p
.002 w
.48454 .25719 m .51134 .26268 L .52764 .25191 L p
1 g
F P
s
P
p
.002 w
.56522 .5968 m .61551 .5718 L .61347 .55597 L p
1 g
F P
s
P
p
.002 w
.65622 .51979 m .61347 .55597 L .61551 .5718 L p
1 g
F P
s
P
p
.002 w
.31237 .38862 m .32018 .43226 L .3313 .41074 L p
1 g
F P
s
P
p
.002 w
.3313 .41074 m .32454 .37099 L .31237 .38862 L p
1 g
F P
s
P
p
.002 w
.64363 .31106 m .65205 .35396 L .66983 .37 L p
1 g
F P
s
P
p
.002 w
.65205 .35396 m .64363 .31106 L .62276 .30133 L p
1 g
F P
s
P
p
.002 w
.52764 .25191 m .55576 .26872 L .57773 .26609 L p
1 g
F P
s
P
p
.002 w
.31171 .47648 m .33976 .51576 L .34037 .49259 L p
1 g
F P
s
P
p
.002 w
.34037 .49259 m .31352 .45435 L .31171 .47648 L p
1 g
F P
s
P
p
.002 w
.41855 .26161 m .38882 .28394 L .40564 .2871 L p
1 g
F P
s
P
p
.002 w
.40564 .2871 m .42832 .27015 L .41855 .26161 L p
1 g
F P
s
P
p
.002 w
.6836 .38812 m .67225 .43616 L .68106 .45623 L p
1 g
F P
s
P
p
.002 w
.67225 .43616 m .6836 .38812 L .66983 .37 L p
1 g
F P
s
P
p
.002 w
.45571 .25976 m .48454 .25719 L .49255 .24458 L p
1 g
F P
s
P
p
.002 w
.52764 .25191 m .49255 .24458 L .48454 .25719 L p
1 g
F P
s
P
p
.002 w
.40466 .59853 m .45507 .61099 L .44674 .59659 L p
1 g
F P
s
P
p
.002 w
.44674 .59659 m .39416 .58336 L .40466 .59853 L p
1 g
F P
s
P
p
.002 w
.35146 .55676 m .39416 .58336 L .38679 .56472 L p
1 g
F P
s
P
p
.002 w
.38679 .56472 m .34343 .53736 L .35146 .55676 L p
1 g
F P
s
P
p
.002 w
.45462 .24791 m .41855 .26161 L .42832 .27015 L p
1 g
F P
s
P
p
.002 w
.42832 .27015 m .45571 .25976 L .45462 .24791 L p
1 g
F P
s
P
p
.002 w
.33509 .32884 m .32454 .37099 L .34091 .35545 L p
1 g
F P
s
P
p
.002 w
.34091 .35545 m .35032 .31879 L .33509 .32884 L p
1 g
F P
s
P
p
.002 w
.49255 .24458 m .45462 .24791 L .45571 .25976 L p
1 g
F P
s
P
p
.002 w
.37435 .28461 m .35032 .31879 L .36893 .312 L p
1 g
F P
s
P
p
.002 w
.36893 .312 m .38882 .28394 L .37435 .28461 L p
1 g
F P
s
P
p
.002 w
.59833 .26777 m .62276 .30133 L .64363 .31106 L p
1 g
F P
s
P
p
.002 w
.62276 .30133 m .59833 .26777 L .57773 .26609 L p
1 g
F P
s
P
p
.002 w
.51628 .6203 m .5676 .60771 L .56522 .5968 L p
1 g
F P
s
P
p
.002 w
.56522 .5968 m .5102 .61026 L .51628 .6203 L p
1 g
F P
s
P
p
.002 w
.61551 .5718 m .56522 .5968 L .5676 .60771 L p
1 g
F P
s
P
p
.002 w
.30494 .40799 m .31352 .45435 L .32018 .43226 L p
1 g
F P
s
P
p
.002 w
.32018 .43226 m .31237 .38862 L .30494 .40799 L p
1 g
F P
s
P
p
.002 w
.61551 .5718 m .65667 .53722 L .65622 .51979 L p
1 g
F P
s
P
p
.002 w
.6853 .47626 m .65622 .51979 L .65667 .53722 L p
1 g
F P
s
P
p
.002 w
.65622 .51979 m .6853 .47626 L .68106 .45623 L p
1 g
F P
s
P
p
.002 w
.46494 .62107 m .51628 .6203 L .5102 .61026 L p
1 g
F P
s
P
p
.002 w
.5102 .61026 m .45507 .61099 L .46494 .62107 L p
1 g
F P
s
P
p
.002 w
.66127 .32431 m .66983 .37 L .6836 .38812 L p
1 g
F P
s
P
p
.002 w
.66983 .37 m .66127 .32431 L .64363 .31106 L p
1 g
F P
s
P
p
.002 w
.57773 .26609 m .54379 .24553 L .52764 .25191 L p
1 g
F P
s
P
p
.002 w
.49255 .24458 m .52764 .25191 L .54379 .24553 L p
1 g
F P
s
P
p
.002 w
.31502 .49806 m .34343 .53736 L .33976 .51576 L p
1 g
F P
s
P
p
.002 w
.33976 .51576 m .31171 .47648 L .31502 .49806 L p
1 g
F P
s
P
p
.002 w
.54379 .24553 m .57773 .26609 L .59833 .26777 L p
1 g
F P
s
P
p
.002 w
.5676 .60771 m .61452 .58446 L .61551 .5718 L p
1 g
F P
s
P
p
.002 w
.65667 .53722 m .61551 .5718 L .61452 .58446 L p
1 g
F P
s
P
p
.002 w
.69283 .40796 m .68106 .45623 L .6853 .47626 L p
1 g
F P
s
P
p
.002 w
.68106 .45623 m .69283 .40796 L .6836 .38812 L p
1 g
F P
s
P
p
.002 w
.41059 .2573 m .37435 .28461 L .38882 .28394 L p
1 g
F P
s
P
p
.002 w
.38882 .28394 m .41855 .26161 L .41059 .2573 L p
1 g
F P
s
P
p
.002 w
.32385 .34207 m .31237 .38862 L .32454 .37099 L p
1 g
F P
s
P
p
.002 w
.32454 .37099 m .33509 .32884 L .32385 .34207 L p
1 g
F P
s
P
p
.002 w
.36388 .57333 m .40466 .59853 L .39416 .58336 L p
1 g
F P
s
P
p
.002 w
.39416 .58336 m .35146 .55676 L .36388 .57333 L p
1 g
F P
s
P
p
.002 w
.41816 .60964 m .46494 .62107 L .45507 .61099 L p
1 g
F P
s
P
p
.002 w
.45507 .61099 m .40466 .59853 L .41816 .60964 L p
1 g
F P
s
P
p
.002 w
.45462 .24791 m .49255 .24458 L .50108 .2365 L p
1 g
F P
s
P
p
.002 w
.54379 .24553 m .50108 .2365 L .49255 .24458 L p
1 g
F P
s
P
p
.002 w
.36274 .28932 m .33509 .32884 L .35032 .31879 L p
1 g
F P
s
P
p
.002 w
.35032 .31879 m .37435 .28461 L .36274 .28932 L p
1 g
F P
s
P
p
.002 w
.61696 .27394 m .64363 .31106 L .66127 .32431 L p
1 g
F P
s
P
p
.002 w
.64363 .31106 m .61696 .27394 L .59833 .26777 L p
1 g
F P
s
P
p
.002 w
.45471 .24053 m .41059 .2573 L .41855 .26161 L p
1 g
F P
s
P
p
.002 w
.41855 .26161 m .45462 .24791 L .45471 .24053 L p
1 g
F P
s
P
p
.002 w
.30269 .42864 m .31171 .47648 L .31352 .45435 L p
1 g
F P
s
P
p
.002 w
.31352 .45435 m .30494 .40799 L .30269 .42864 L p
1 g
F P
s
P
p
.002 w
.50108 .2365 m .45471 .24053 L .45462 .24791 L p
1 g
F P
s
P
p
.002 w
.67506 .3409 m .6836 .38812 L .69283 .40796 L p
1 g
F P
s
P
p
.002 w
.6836 .38812 m .67506 .3409 L .66127 .32431 L p
1 g
F P
s
P
p
.002 w
.61452 .58446 m .65286 .5524 L .65667 .53722 L p
1 g
F P
s
P
p
.002 w
.68463 .49574 m .65667 .53722 L .65286 .5524 L p
1 g
F P
s
P
p
.002 w
.65667 .53722 m .68463 .49574 L .6853 .47626 L p
1 g
F P
s
P
p
.002 w
.32361 .51846 m .35146 .55676 L .34343 .53736 L p
1 g
F P
s
P
p
.002 w
.34343 .53736 m .31502 .49806 L .32361 .51846 L p
1 g
F P
s
P
p
.002 w
.52217 .62556 m .56824 .61425 L .5676 .60771 L p
1 g
F P
s
P
p
.002 w
.5676 .60771 m .51628 .6203 L .52217 .62556 L p
1 g
F P
s
P
p
.002 w
.61452 .58446 m .5676 .60771 L .56824 .61425 L p
1 g
F P
s
P
p
.002 w
.59833 .26777 m .55937 .24396 L .54379 .24553 L p
1 g
F P
s
P
p
.002 w
.50108 .2365 m .54379 .24553 L .55937 .24396 L p
1 g
F P
s
P
p
.002 w
.55937 .24396 m .59833 .26777 L .61696 .27394 L p
1 g
F P
s
P
p
.002 w
.47618 .6263 m .52217 .62556 L .51628 .6203 L p
1 g
F P
s
P
p
.002 w
.51628 .6203 m .46494 .62107 L .47618 .6263 L p
1 g
F P
s
P
p
.002 w
.69705 .42908 m .6853 .47626 L .68463 .49574 L p
1 g
F P
s
P
p
.002 w
.6853 .47626 m .69705 .42908 L .69283 .40796 L p
1 g
F P
s
P
p
.002 w
.56824 .61425 m .61034 .59342 L .61452 .58446 L p
1 g
F P
s
P
p
.002 w
.65286 .5524 m .61452 .58446 L .61034 .59342 L p
1 g
F P
s
P
p
.002 w
.31713 .35828 m .30494 .40799 L .31237 .38862 L p
1 g
F P
s
P
p
.002 w
.31237 .38862 m .32385 .34207 L .31713 .35828 L p
1 g
F P
s
P
p
.002 w
.40477 .25762 m .36274 .28932 L .37435 .28461 L p
1 g
F P
s
P
p
.002 w
.37435 .28461 m .41059 .2573 L .40477 .25762 L p
1 g
F P
s
P
p
.002 w
.63301 .28468 m .66127 .32431 L .67506 .3409 L p
1 g
F P
s
P
p
.002 w
.66127 .32431 m .63301 .28468 L .61696 .27394 L p
1 g
F P
s
P
p
.002 w
.38055 .58646 m .41816 .60964 L .40466 .59853 L p
1 g
F P
s
P
p
.002 w
.40466 .59853 m .36388 .57333 L .38055 .58646 L p
1 g
F P
s
P
p
.002 w
.35451 .29819 m .32385 .34207 L .33509 .32884 L p
1 g
F P
s
P
p
.002 w
.33509 .32884 m .36274 .28932 L .35451 .29819 L p
1 g
F P
s
P
p
.002 w
.43447 .61614 m .47618 .6263 L .46494 .62107 L p
1 g
F P
s
P
p
.002 w
.46494 .62107 m .41816 .60964 L .43447 .61614 L p
1 g
F P
s
P
p
.002 w
.30594 .45006 m .31502 .49806 L .31171 .47648 L p
1 g
F P
s
P
p
.002 w
.31171 .47648 m .30269 .42864 L .30594 .45006 L p
1 g
F P
s
P
p
.002 w
.55937 .24396 m .50994 .23345 L .50108 .2365 L p
1 g
F P
s
P
p
.002 w
.45471 .24053 m .50108 .2365 L .50994 .23345 L p
1 g
F P
s
P
p
.002 w
.68442 .36055 m .69283 .40796 L .69705 .42908 L p
1 g
F P
s
P
p
.002 w
.69283 .40796 m .68442 .36055 L .67506 .3409 L p
1 g
F P
s
P
p
.002 w
.45607 .23811 m .40477 .25762 L .41059 .2573 L p
1 g
F P
s
P
p
.002 w
.41059 .2573 m .45471 .24053 L .45607 .23811 L p
1 g
F P
s
P
p
.002 w
.33749 .53703 m .36388 .57333 L .35146 .55676 L p
1 g
F P
s
P
p
.002 w
.35146 .55676 m .32361 .51846 L .33749 .53703 L p
1 g
F P
s
P
p
.002 w
.50994 .23345 m .45607 .23811 L .45471 .24053 L p
1 g
F P
s
P
p
.002 w
.61696 .27394 m .5739 .24752 L .55937 .24396 L p
1 g
F P
s
P
p
.002 w
.5739 .24752 m .61696 .27394 L .63301 .28468 L p
1 g
F P
s
P
p
.002 w
.61034 .59342 m .64466 .5648 L .65286 .5524 L p
1 g
F P
s
P
p
.002 w
.67881 .51411 m .65286 .5524 L .64466 .5648 L p
1 g
F P
s
P
p
.002 w
.65286 .5524 m .67881 .51411 L .68463 .49574 L p
1 g
F P
s
P
p
.002 w
.50994 .23345 m .55937 .24396 L .5739 .24752 L p
1 g
F P
s
P
p
.002 w
.68463 .49574 m .69589 .45093 L .69705 .42908 L p
1 g
F P
s
P
p
.002 w
.69589 .45093 m .68463 .49574 L .67881 .51411 L p
1 g
F P
s
P
p
.002 w
.5277 .6256 m .567 .61595 L .56824 .61425 L p
1 g
F P
s
P
p
.004 w
.5598 .62582 m
.56732 .65039 L
s
P
p
.002 w
.56824 .61425 m .52217 .62556 L .5277 .6256 L p
1 g
F P
s
P
p
.002 w
.61034 .59342 m .56824 .61425 L .567 .61595 L p
1 g
F P
s
P
p
.002 w
.48856 .62623 m .5277 .6256 L .52217 .62556 L p
1 g
F P
s
P
p
.002 w
.52217 .62556 m .47618 .6263 L .48856 .62623 L p
1 g
F P
s
P
p
.002 w
.31538 .37716 m .30269 .42864 L .30494 .40799 L p
1 g
F P
s
P
p
.002 w
.30494 .40799 m .31713 .35828 L .31538 .37716 L p
1 g
F P
s
P
p
.002 w
.67506 .3409 m .64588 .29991 L .63301 .28468 L p
1 g
F P
s
P
p
.002 w
.64588 .29991 m .67506 .3409 L .68442 .36055 L p
1 g
F P
s
P
p
.002 w
.567 .61595 m .6029 .5982 L .61034 .59342 L p
1 g
F P
s
P
p
.002 w
.64466 .5648 m .61034 .59342 L .6029 .5982 L p
1 g
F P
s
P
p
.002 w
.4014 .26285 m .35451 .29819 L .36274 .28932 L p
1 g
F P
s
P
p
.002 w
.36274 .28932 m .40477 .25762 L .4014 .26285 L p
1 g
F P
s
P
p
.002 w
.31489 .47162 m .32361 .51846 L .31502 .49806 L p
1 g
F P
s
P
p
.002 w
.31502 .49806 m .30594 .45006 L .31489 .47162 L p
1 g
F P
s
P
p
.002 w
.4012 .59557 m .43447 .61614 L .41816 .60964 L p
1 g
F P
s
P
p
.002 w
.41816 .60964 m .38055 .58646 L .4012 .59557 L p
1 g
F P
s
P
p
.002 w
.69705 .42908 m .68886 .38283 L .68442 .36055 L p
1 g
F P
s
P
p
.002 w
.68886 .38283 m .69705 .42908 L .69589 .45093 L p
1 g
F P
s
P
p
.004 w
.68923 .37352 m
.70495 .36878 L
s
P
p
.002 w
.35011 .31121 m .31713 .35828 L .32385 .34207 L p
1 g
F P
s
P
p
.002 w
.32385 .34207 m .35451 .29819 L .35011 .31121 L p
1 g
F P
s
P
p
.002 w
.45326 .61759 m .48856 .62623 L .47618 .6263 L p
1 g
F P
s
P
p
.002 w
.47618 .6263 m .43447 .61614 L .45326 .61759 L p
1 g
F P
s
P
p
.002 w
.35649 .5531 m .38055 .58646 L .36388 .57333 L p
1 g
F P
s
P
p
.002 w
.36388 .57333 m .33749 .53703 L .35649 .5531 L p
1 g
F P
s
P
p
.002 w
.5739 .24752 m .5189 .23582 L .50994 .23345 L p
1 g
F P
s
P
p
.002 w
.45607 .23811 m .50994 .23345 L .5189 .23582 L p
1 g
F P
s
P
p
.002 w
.58691 .25641 m .63301 .28468 L .64588 .29991 L p
1 g
F P
s
P
p
.002 w
.63301 .28468 m .58691 .25641 L .5739 .24752 L p
1 g
F P
s
P
p
.002 w
.45874 .24106 m .4014 .26285 L .40477 .25762 L p
1 g
F P
s
P
p
.002 w
.40477 .25762 m .45607 .23811 L .45874 .24106 L p
1 g
F P
s
P
p
.002 w
.64466 .5648 m .66772 .53077 L .67881 .51411 L p
1 g
F P
s
P
p
.002 w
.68913 .47292 m .67881 .51411 L .66772 .53077 L p
1 g
F P
s
P
p
.002 w
.67881 .51411 m .68913 .47292 L .69589 .45093 L p
1 g
F P
s
P
p
.002 w
.6029 .5982 m .63203 .57388 L .64466 .5648 L p
1 g
F P
s
P
p
.002 w
.66772 .53077 m .64466 .5648 L .63203 .57388 L p
1 g
F P
s
P
p
.002 w
.5189 .23582 m .5739 .24752 L .58691 .25641 L p
1 g
F P
s
P
p
.002 w
.5189 .23582 m .45874 .24106 L .45607 .23811 L p
1 g
F P
s
P
p
.002 w
.31895 .39826 m .30594 .45006 L .30269 .42864 L p
1 g
F P
s
P
p
.002 w
.30269 .42864 m .31538 .37716 L .31895 .39826 L p
1 g
F P
s
P
p
.002 w
.65502 .31943 m .68442 .36055 L .68886 .38283 L p
1 g
F P
s
P
p
.002 w
.68442 .36055 m .65502 .31943 L .64588 .29991 L p
1 g
F P
s
P
p
.002 w
.53268 .62006 m .56379 .61243 L .567 .61595 L p
1 g
F P
s
P
p
.002 w
.567 .61595 m .5277 .6256 L .53268 .62006 L p
1 g
F P
s
P
p
.002 w
.6029 .5982 m .567 .61595 L .56379 .61243 L p
1 g
F P
s
P
p
.002 w
.32952 .49265 m .33749 .53703 L .32361 .51846 L p
1 g
F P
s
P
p
.002 w
.32361 .51846 m .31489 .47162 L .32952 .49265 L p
1 g
F P
s
P
p
.002 w
.50177 .62053 m .53268 .62006 L .5277 .6256 L p
1 g
F P
s
P
p
.002 w
.5277 .6256 m .48856 .62623 L .50177 .62053 L p
1 g
F P
s
P
p
.002 w
.68801 .40718 m .69589 .45093 L .68913 .47292 L p
1 g
F P
s
P
p
.002 w
.69589 .45093 m .68801 .40718 L .68886 .38283 L p
1 g
F P
s
P
p
.002 w
.42537 .60018 m .45326 .61759 L .43447 .61614 L p
1 g
F P
s
P
p
.002 w
.43447 .61614 m .4012 .59557 L .42537 .60018 L p
1 g
F P
s
P
p
.002 w
.56379 .61243 m .59218 .59837 L .6029 .5982 L p
1 g
F P
s
P
p
.002 w
.63203 .57388 m .6029 .5982 L .59218 .59837 L p
1 g
F P
s
P
p
.002 w
.40073 .27317 m .35011 .31121 L .35451 .29819 L p
1 g
F P
s
P
p
.002 w
.35451 .29819 m .4014 .26285 L .40073 .27317 L p
1 g
F P
s
P
p
.002 w
.3499 .32824 m .31538 .37716 L .31713 .35828 L p
1 g
F P
s
P
p
.002 w
.31713 .35828 m .35011 .31121 L .3499 .32824 L p
1 g
F P
s
P
p
.002 w
.38023 .56606 m .4012 .59557 L .38055 .58646 L p
1 g
F P
s
P
p
.002 w
.38055 .58646 m .35649 .5531 L .38023 .56606 L p
1 g
F P
s
P
p
.002 w
.47407 .61366 m .50177 .62053 L .48856 .62623 L p
1 g
F P
s
P
p
.002 w
.48856 .62623 m .45326 .61759 L .47407 .61366 L p
1 g
F P
s
P
p
.002 w
.59791 .27067 m .64588 .29991 L .65502 .31943 L p
1 g
F P
s
P
p
.002 w
.64588 .29991 m .59791 .27067 L .58691 .25641 L p
1 g
F P
s
P
p
.002 w
.58691 .25641 m .5277 .24392 L .5189 .23582 L p
1 g
F P
s
P
p
.002 w
.45874 .24106 m .5189 .23582 L .5277 .24392 L p
1 g
F P
s
P
p
.002 w
.63203 .57388 m .65142 .54512 L .66772 .53077 L p
1 g
F P
s
P
p
.002 w
.67669 .49438 m .66772 .53077 L .65142 .54512 L p
1 g
F P
s
P
p
.002 w
.66772 .53077 m .67669 .49438 L .68913 .47292 L p
1 g
F P
s
P
p
.002 w
.32798 .42102 m .31489 .47162 L .30594 .45006 L p
1 g
F P
s
P
p
.002 w
.30594 .45006 m .31895 .39826 L .32798 .42102 L p
1 g
F P
s
P
p
.002 w
.59218 .59837 m .61509 .57918 L .63203 .57388 L p
1 g
F P
s
P
p
.002 w
.65142 .54512 m .63203 .57388 L .61509 .57918 L p
1 g
F P
s
P
p
.002 w
.65993 .34282 m .68886 .38283 L .68801 .40718 L p
1 g
F P
s
P
p
.002 w
.68886 .38283 m .65993 .34282 L .65502 .31943 L p
1 g
F P
s
P
p
.002 w
.5277 .24392 m .58691 .25641 L .59791 .27067 L p
1 g
F P
s
P
p
.002 w
.46272 .24964 m .40073 .27317 L .4014 .26285 L p
1 g
F P
s
P
p
.002 w
.4014 .26285 m .45874 .24106 L .46272 .24964 L p
1 g
F P
s
P
p
.002 w
.3496 .51242 m .35649 .5531 L .33749 .53703 L p
1 g
F P
s
P
p
.002 w
.33749 .53703 m .32952 .49265 L .3496 .51242 L p
1 g
F P
s
P
p
.002 w
.5277 .24392 m .46272 .24964 L .45874 .24106 L p
1 g
F P
s
P
p
.002 w
.68164 .43294 m .68913 .47292 L .67669 .49438 L p
1 g
F P
s
P
p
.002 w
.68913 .47292 m .68164 .43294 L .68801 .40718 L p
1 g
F P
s
P
p
.002 w
.45244 .59993 m .47407 .61366 L .45326 .61759 L p
1 g
F P
s
P
p
.002 w
.45326 .61759 m .42537 .60018 L .45244 .59993 L p
1 g
F P
s
P
p
.002 w
.53692 .60876 m .55859 .60345 L .56379 .61243 L p
1 g
F P
s
P
p
.002 w
.56379 .61243 m .53268 .62006 L .53692 .60876 L p
1 g
F P
s
P
p
.002 w
.59218 .59837 m .56379 .61243 L .55859 .60345 L p
1 g
F P
s
P
p
.002 w
.40811 .57534 m .42537 .60018 L .4012 .59557 L p
1 g
F P
s
P
p
.002 w
.4012 .59557 m .38023 .56606 L .40811 .57534 L p
1 g
F P
s
P
p
.002 w
.51545 .60904 m .53692 .60876 L .53268 .62006 L p
1 g
F P
s
P
p
.002 w
.53268 .62006 m .50177 .62053 L .51545 .60904 L p
1 g
F P
s
P
p
.002 w
.35415 .34893 m .31895 .39826 L .31538 .37716 L p
1 g
F P
s
P
p
.002 w
.31538 .37716 m .3499 .32824 L .35415 .34893 L p
1 g
F P
s
P
p
.002 w
.40297 .28857 m .3499 .32824 L .35011 .31121 L p
1 g
F P
s
P
p
.002 w
.35011 .31121 m .40073 .27317 L .40297 .28857 L p
1 g
F P
s
P
p
.002 w
.55859 .60345 m .57833 .59365 L .59218 .59837 L p
1 g
F P
s
P
p
.002 w
.61509 .57918 m .59218 .59837 L .57833 .59365 L p
1 g
F P
s
P
p
.002 w
.60643 .29016 m .65502 .31943 L .65993 .34282 L p
1 g
F P
s
P
p
.002 w
.65502 .31943 m .60643 .29016 L .59791 .27067 L p
1 g
F P
s
P
p
.002 w
.49635 .6042 m .51545 .60904 L .50177 .62053 L p
1 g
F P
s
P
p
.002 w
.50177 .62053 m .47407 .61366 L .49635 .6042 L p
1 g
F P
s
P
p
.002 w
.61509 .57918 m .63016 .5566 L .65142 .54512 L p
1 g
F P
s
P
p
.002 w
.65871 .51459 m .65142 .54512 L .63016 .5566 L p
1 g
F P
s
P
p
.002 w
.65142 .54512 m .65871 .51459 L .67669 .49438 L p
1 g
F P
s
P
p
.002 w
.34242 .44474 m .32952 .49265 L .31489 .47162 L p
1 g
F P
s
P
p
.002 w
.31489 .47162 m .32798 .42102 L .34242 .44474 L p
1 g
F P
s
P
p
.002 w
.66027 .36952 m .68801 .40718 L .68164 .43294 L p
1 g
F P
s
P
p
.002 w
.68801 .40718 m .66027 .36952 L .65993 .34282 L p
1 g
F P
s
P
p
.002 w
.37465 .53022 m .38023 .56606 L .35649 .5531 L p
1 g
F P
s
P
p
.002 w
.35649 .5531 m .3496 .51242 L .37465 .53022 L p
1 g
F P
s
P
p
.002 w
.59791 .27067 m .53604 .25783 L .5277 .24392 L p
1 g
F P
s
P
p
.002 w
.46272 .24964 m .5277 .24392 L .53604 .25783 L p
1 g
F P
s
P
p
.002 w
.57833 .59365 m .59416 .5803 L .61509 .57918 L p
1 g
F P
s
P
p
.002 w
.63016 .5566 m .61509 .57918 L .59416 .5803 L p
1 g
F P
s
P
p
.002 w
.66974 .45931 m .67669 .49438 L .65871 .51459 L p
1 g
F P
s
P
p
.002 w
.67669 .49438 m .66974 .45931 L .68164 .43294 L p
1 g
F P
s
P
p
.002 w
.53604 .25783 m .59791 .27067 L .60643 .29016 L p
1 g
F P
s
P
p
.002 w
.46798 .26393 m .40297 .28857 L .40073 .27317 L p
1 g
F P
s
P
p
.002 w
.40073 .27317 m .46272 .24964 L .46798 .26393 L p
1 g
F P
s
P
p
.002 w
.43934 .58049 m .45244 .59993 L .42537 .60018 L p
1 g
F P
s
P
p
.002 w
.42537 .60018 m .40811 .57534 L .43934 .58049 L p
1 g
F P
s
P
p
.002 w
.48162 .59464 m .49635 .6042 L .47407 .61366 L p
1 g
F P
s
P
p
.002 w
.47407 .61366 m .45244 .59993 L .48162 .59464 L p
1 g
F P
s
P
p
.002 w
.53604 .25783 m .46798 .26393 L .46272 .24964 L p
1 g
F P
s
P
p
.002 w
.36294 .37277 m .32798 .42102 L .31895 .39826 L p
1 g
F P
s
P
p
.002 w
.31895 .39826 m .35415 .34893 L .36294 .37277 L p
1 g
F P
s
P
p
.002 w
.54023 .59171 m .55143 .58897 L .55859 .60345 L p
1 g
F P
s
P
p
.002 w
.55859 .60345 m .53692 .60876 L .54023 .59171 L p
1 g
F P
s
P
p
.002 w
.57833 .59365 m .55859 .60345 L .55143 .58897 L p
1 g
F P
s
P
p
.002 w
.61206 .31448 m .65993 .34282 L .66027 .36952 L p
1 g
F P
s
P
p
.002 w
.65993 .34282 m .61206 .31448 L .60643 .29016 L p
1 g
F P
s
P
p
.002 w
.52917 .59181 m .54023 .59171 L .53692 .60876 L p
1 g
F P
s
P
p
.002 w
.53692 .60876 m .51545 .60904 L .52917 .59181 L p
1 g
F P
s
P
p
.002 w
.65582 .39875 m .68164 .43294 L .66974 .45931 L p
1 g
F P
s
P
p
.002 w
.68164 .43294 m .65582 .39875 L .66027 .36952 L p
1 g
F P
s
P
p
.004 w
.66997 .37932 m
.68923 .37352 L
s
P
p
.002 w
.40822 .30882 m .35415 .34893 L .3499 .32824 L p
1 g
F P
s
P
p
.002 w
.3499 .32824 m .40297 .28857 L .40822 .30882 L p
1 g
F P
s
P
p
.002 w
.362 .46861 m .3496 .51242 L .32952 .49265 L p
1 g
F P
s
P
p
.002 w
.32952 .49265 m .34242 .44474 L .362 .46861 L p
1 g
F P
s
P
p
.002 w
.59416 .5803 m .60441 .56469 L .63016 .5566 L p
1 g
F P
s
P
p
.002 w
.63558 .53283 m .63016 .5566 L .60441 .56469 L p
1 g
F P
s
P
p
.002 w
.63016 .5566 m .63558 .53283 L .65871 .51459 L p
1 g
F P
s
P
p
.002 w
.55143 .58897 m .56161 .58389 L .57833 .59365 L p
1 g
F P
s
P
p
.002 w
.59416 .5803 m .57833 .59365 L .56161 .58389 L p
1 g
F P
s
P
p
.002 w
.40396 .54535 m .40811 .57534 L .38023 .56606 L p
1 g
F P
s
P
p
.002 w
.38023 .56606 m .37465 .53022 L .40396 .54535 L p
1 g
F P
s
P
p
.002 w
.65251 .48541 m .65871 .51459 L .63558 .53283 L p
1 g
F P
s
P
p
.002 w
.65871 .51459 m .65251 .48541 L .66974 .45931 L p
1 g
F P
s
P
p
.002 w
.5194 .58927 m .52917 .59181 L .51545 .60904 L p
1 g
F P
s
P
p
.002 w
.51545 .60904 m .49635 .6042 L .5194 .58927 L p
1 g
F P
s
P
p
.002 w
.56161 .58389 m .56971 .57699 L .59416 .5803 L p
1 g
F P
s
P
p
.002 w
.60441 .56469 m .59416 .5803 L .56971 .57699 L p
1 g
F P
s
P
p
.002 w
.60643 .29016 m .54362 .27742 L .53604 .25783 L p
1 g
F P
s
P
p
.002 w
.46798 .26393 m .53604 .25783 L .54362 .27742 L p
1 g
F P
s
P
p
.002 w
.54362 .27742 m .60643 .29016 L .61206 .31448 L p
1 g
F P
s
P
p
.002 w
.47292 .58123 m .48162 .59464 L .45244 .59993 L p
1 g
F P
s
P
p
.002 w
.45244 .59993 m .43934 .58049 L .47292 .58123 L p
1 g
F P
s
P
p
.002 w
.51197 .5843 m .5194 .58927 L .49635 .6042 L p
1 g
F P
s
P
p
.002 w
.49635 .6042 m .48162 .59464 L .51197 .5843 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .49108 .55286 L .49139 .54865 L p
1 g
F P
s
P
p
.002 w
.49139 .54865 m .47506 .54384 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .50892 .55286 L .50861 .54865 L p
1 g
F P
s
P
p
.002 w
.50861 .54865 m .49139 .54865 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.52494 .54384 m .50861 .54865 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.37616 .39905 m .34242 .44474 L .32798 .42102 L p
1 g
F P
s
P
p
.002 w
.32798 .42102 m .36294 .37277 L .37616 .39905 L p
1 g
F P
s
P
p
.002 w
.64657 .42956 m .66974 .45931 L .65251 .48541 L p
1 g
F P
s
P
p
.002 w
.66974 .45931 m .64657 .42956 L .65582 .39875 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .47417 .54789 L .47506 .54384 L p
1 g
F P
s
P
p
.002 w
.47506 .54384 m .46133 .53469 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .52583 .54789 L .52494 .54384 L p
1 g
F P
s
P
p
.002 w
.53867 .53469 m .52494 .54384 L .52583 .54789 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.53304 .53844 L
s
P
p
.002 w
.4744 .28379 m .40822 .30882 L .40297 .28857 L p
1 g
F P
s
P
p
.002 w
.40297 .28857 m .46798 .26393 L .4744 .28379 L p
1 g
F P
s
P
p
.002 w
.43657 .55721 m .43934 .58049 L .40811 .57534 L p
1 g
F P
s
P
p
.002 w
.40811 .57534 m .40396 .54535 L .43657 .55721 L p
1 g
F P
s
P
p
.002 w
.61446 .34302 m .66027 .36952 L .65582 .39875 L p
1 g
F P
s
P
p
.002 w
.66027 .36952 m .61446 .34302 L .61206 .31448 L p
1 g
F P
s
P
p
.002 w
.38616 .49177 m .37465 .53022 L .3496 .51242 L p
1 g
F P
s
P
p
.002 w
.3496 .51242 m .362 .46861 L .38616 .49177 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .49078 .5571 L .49108 .55286 L p
1 g
F P
s
P
p
.002 w
.49108 .55286 m .47417 .54789 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .50922 .5571 L .50892 .55286 L p
1 g
F P
s
P
p
.002 w
.50892 .55286 m .49108 .55286 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .50892 .55286 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.56971 .57699 m .57487 .56897 L .60441 .56469 L p
1 g
F P
s
P
p
.002 w
.6079 .54839 m .60441 .56469 L .57487 .56897 L p
1 g
F P
s
P
p
.002 w
.60441 .56469 m .6079 .54839 L .63558 .53283 L p
1 g
F P
s
P
p
.002 w
.63038 .51032 m .63558 .53283 L .6079 .54839 L p
1 g
F P
s
P
p
.002 w
.63558 .53283 m .63038 .51032 L .65251 .48541 L p
1 g
F P
s
P
p
.002 w
.54362 .27742 m .4744 .28379 L .46798 .26393 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .47328 .55196 L .47417 .54789 L p
1 g
F P
s
P
p
.002 w
.47417 .54789 m .45994 .53843 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .52672 .55196 L .52583 .54789 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .52583 .54789 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.52583 .54789 m .54006 .53843 L .53867 .53469 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .45994 .53843 L .46133 .53469 L p
1 g
F P
s
P
p
.002 w
.46133 .53469 m .45166 .52214 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.54834 .52214 m .53867 .53469 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .49046 .56135 L .49078 .5571 L p
1 g
F P
s
P
p
.002 w
.49078 .5571 m .47328 .55196 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .50954 .56135 L .50922 .5571 L p
1 g
F P
s
P
p
.002 w
.50922 .5571 m .49078 .5571 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .50922 .5571 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.41644 .33346 m .36294 .37277 L .35415 .34893 L p
1 g
F P
s
P
p
.002 w
.35415 .34893 m .40822 .30882 L .41644 .33346 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .47238 .55605 L .47328 .55196 L p
1 g
F P
s
P
p
.002 w
.47328 .55196 m .45855 .54218 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .52762 .55605 L .52672 .55196 L p
1 g
F P
s
P
p
.002 w
.54145 .54218 m .52672 .55196 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52672 .55196 m .54145 .54218 L .54006 .53843 L p
1 g
F P
s
P
p
.002 w
.55143 .58897 m .54023 .59171 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.56161 .58389 m .55143 .58897 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .45855 .54218 L .45994 .53843 L p
1 g
F P
s
P
p
.002 w
.45994 .53843 m .44992 .52544 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .54006 .53843 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.54006 .53843 m .55008 .52544 L .54834 .52214 L p
1 g
F P
s
P
p
.002 w
.54023 .59171 m .52917 .59181 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .49015 .56564 L .49046 .56135 L p
1 g
F P
s
P
p
.002 w
.49046 .56135 m .47238 .55605 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.49015 .56564 m .50985 .56564 L .50954 .56135 L p
1 g
F P
s
P
p
.002 w
.50954 .56135 m .49046 .56135 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .50954 .56135 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.56971 .57699 m .56161 .58389 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.48921 .57862 m .51079 .57862 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51197 .5843 m .48162 .59464 L p
.50228 .581 L 1 g
F P
s
P
p
.002 w
.51005 .58122 m .51016 .58139 L p
.50228 .581 L 1 g
F P
s
P
p
.002 w
.51016 .58139 m .51197 .5843 L p
.50569 .58216 L 1 g
F P
s
P
p
.50228 .581 m .51016 .58139 L .50569 .58216 L 1 g
F
P
p
.002 w
.53128 .57265 m .51079 .57862 L .51098 .58113 L p
1 g
F P
s
P
p
.53128 .57265 m .51098 .58113 L .512 .58081 L 1 g
F
P
p
.002 w
.51197 .5843 m .51016 .58139 L p
.51098 .58113 L 1 g
F P
s
P
p
.002 w
.53068 .575 m .52003 .5803 L p
.51098 .58113 L 1 g
F P
s
P
p
.002 w
.52003 .5803 m .51197 .5843 L p
.51098 .58113 L 1 g
F P
s
P
p
.52056 .57815 m .51098 .58124 L .51633 .58032 L 1 g
F
P
p
.53128 .57265 m .512 .58081 L .52056 .57815 L 1 g
F
P
p
.512 .58081 m .51098 .58124 L .52056 .57815 L 1 g
F
P
p
.51079 .57862 m .4993 .58092 L .51005 .58122 L 1 g
F
P
p
.002 w
.51016 .58139 m .51005 .58122 L p
.51098 .58113 L 1 g
F P
s
P
p
.002 w
.51098 .58124 m .51098 .58113 L p
.51005 .58122 L 1 g
F P
s
P
p
.002 w
.51098 .58113 m .51079 .57862 L p
.51005 .58122 L 1 g
F P
s
P
p
.002 w
.53036 .56847 m .51048 .57427 L .51079 .57862 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .53128 .57265 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.51079 .57862 m .48921 .57862 L .48906 .58063 L p
1 g
F P
s
P
p
.48162 .59464 m .48058 .58039 L .48906 .58063 L 1 g
F
P
p
.49928 .58298 m .48906 .58063 L .50228 .581 L 1 g
F
P
p
.48162 .59464 m .48906 .58063 L .49928 .58298 L 1 g
F
P
p
.002 w
.48162 .59464 m .47292 .58123 L .48058 .58039 L p
1 g
F P
s
P
p
.002 w
.48906 .58063 m .48921 .57862 L p
.47732 .57764 L 1 g
F P
s
P
p
.002 w
.48563 .57984 m .47292 .58123 L p
.48068 .57853 L 1 g
F P
s
P
p
.47732 .57764 m .48563 .57984 L .48906 .58063 L 1 g
F
P
p
.002 w
.47056 .5643 m .48984 .56994 L .49015 .56564 L p
1 g
F P
s
P
p
.002 w
.50985 .56564 m .49015 .56564 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .51016 .56994 L .50985 .56564 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .48952 .57427 L .48984 .56994 L p
1 g
F P
s
P
p
.002 w
.48984 .56994 m .47056 .5643 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .51048 .57427 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .48984 .56994 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.46872 .57265 m .48921 .57862 L .48952 .57427 L p
1 g
F P
s
P
p
.002 w
.48952 .57427 m .46964 .56847 L .46872 .57265 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .48952 .57427 L .48921 .57862 L p
1 g
F P
s
P
p
.002 w
.47292 .58123 m .47244 .57635 L p
.48068 .57853 L 1 g
F P
s
P
p
.002 w
.48921 .57862 m .46872 .57265 L .46827 .5747 L p
1 g
F P
s
P
p
.45916 .5711 m .46827 .5747 L .47292 .58123 L 1 g
F
P
p
.002 w
.47244 .57635 m .47256 .57759 L p
.46827 .5747 L 1 g
F P
s
P
p
.002 w
.47256 .57759 m .47292 .58123 L p
.46827 .5747 L 1 g
F P
s
P
p
.002 w
.47292 .58123 m .43934 .58049 L p
.45916 .5711 L 1 g
F P
s
P
p
.002 w
.46827 .5747 m .46872 .57265 L p
.46007 .5692 L 1 g
F P
s
P
p
.48921 .57862 m .46827 .5747 L .47528 .57748 L 1 g
F
P
p
.002 w
.45289 .55742 m .46964 .56847 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45146 .56129 m .46872 .57265 L .46964 .56847 L p
1 g
F P
s
P
p
.002 w
.46964 .56847 m .45289 .55742 L .45146 .56129 L p
1 g
F P
s
P
p
.002 w
.47137 .56532 m .47244 .57635 L p
.46827 .5747 L 1 g
F P
s
P
p
.45916 .5711 m .46136 .57006 L .46827 .5747 L 1 g
F
P
p
.002 w
.46872 .57265 m .45146 .56129 L .45083 .56299 L p
1 g
F P
s
P
p
.46872 .57265 m .45083 .56299 L .46007 .5692 L 1 g
F
P
p
.46136 .57006 m .47137 .56532 L .46827 .5747 L 1 g
F
P
p
.002 w
.43925 .54566 m .45146 .56129 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.43934 .58049 m .43657 .55721 L .44804 .55988 L p
1 g
F P
s
P
p
.002 w
.45083 .56299 m .45146 .56129 L p
.44426 .55504 L 1 g
F P
s
P
p
.002 w
.44804 .55988 m .43657 .55721 L p
.44463 .55551 L 1 g
F P
s
P
p
.44426 .55504 m .44804 .55988 L .45083 .56299 L 1 g
F
P
p
.002 w
.45574 .54976 m .47147 .56017 L .47238 .55605 L p
1 g
F P
s
P
p
.002 w
.47238 .55605 m .45715 .54596 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .45715 .54596 L .45855 .54218 L p
1 g
F P
s
P
p
.002 w
.45855 .54218 m .44816 .52876 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.47147 .56017 m .45574 .54976 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .45574 .54976 L .45715 .54596 L p
1 g
F P
s
P
p
.002 w
.45715 .54596 m .4464 .53209 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .45432 .55358 L .45574 .54976 L p
1 g
F P
s
P
p
.002 w
.45574 .54976 m .44463 .53545 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44463 .53545 L .4464 .53209 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .45289 .55742 L .45432 .55358 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .44285 .53883 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.45289 .55742 m .44105 .54223 L .43925 .54566 L p
1 g
F P
s
P
p
.002 w
.43657 .55721 m .43942 .54881 L p
.44463 .55551 L 1 g
F P
s
P
p
.002 w
.45146 .56129 m .43925 .54566 L .4384 .54726 L p
1 g
F P
s
P
p
.43152 .53674 m .4384 .54726 L .43657 .55721 L 1 g
F
P
p
.002 w
.43942 .54881 m .43914 .54963 L p
.4384 .54726 L 1 g
F P
s
P
p
.002 w
.43914 .54963 m .43657 .55721 L p
.4384 .54726 L 1 g
F P
s
P
p
.002 w
.4384 .54726 m .43925 .54566 L p
.43579 .53881 L 1 g
F P
s
P
p
.45146 .56129 m .4384 .54726 L .44247 .55348 L 1 g
F
P
p
.002 w
.43743 .52157 m .44285 .53883 L .44463 .53545 L p
1 g
F P
s
P
p
.002 w
.44463 .53545 m .43939 .51871 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .44105 .54223 L .44285 .53883 L p
1 g
F P
s
P
p
.002 w
.44285 .53883 m .43743 .52157 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43925 .54566 L .44105 .54223 L p
1 g
F P
s
P
p
.002 w
.44105 .54223 m .43545 .52444 L .43346 .52734 L p
1 g
F P
s
P
p
.002 w
.43925 .54566 m .43346 .52734 L .43262 .52857 L p
1 g
F P
s
P
p
.43925 .54566 m .43262 .52857 L .43579 .53881 L 1 g
F
P
p
.002 w
.44491 .53255 m .43942 .54881 L p
.4384 .54726 L 1 g
F P
s
P
p
.43152 .53674 m .43482 .5357 L .4384 .54726 L 1 g
F
P
p
.43482 .5357 m .44491 .53255 L .4384 .54726 L 1 g
F
P
p
.002 w
.43485 .50826 m .43346 .52734 L .43545 .52444 L p
1 g
F P
s
P
p
.002 w
.40396 .54535 m .41413 .51336 L .43273 .52496 L p
1 g
F P
s
P
p
.002 w
.43262 .52857 m .43346 .52734 L p
.4332 .51989 L 1 g
F P
s
P
p
.002 w
.43273 .52496 m .41413 .51336 L p
.43396 .51176 L 1 g
F P
s
P
p
.4332 .51989 m .43303 .51506 L .43273 .52496 L 1 g
F
P
p
.4332 .51989 m .43273 .52496 L .43262 .52857 L 1 g
F
P
p
.002 w
.44521 .51024 m .44992 .52544 L .45166 .52214 L p
1 g
F P
s
P
p
.002 w
.45166 .52214 m .44712 .50746 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44816 .52876 L .44992 .52544 L p
1 g
F P
s
P
p
.002 w
.44992 .52544 m .44521 .51024 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .4464 .53209 L .44816 .52876 L p
1 g
F P
s
P
p
.002 w
.44816 .52876 m .44328 .51305 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.4464 .53209 m .44134 .51587 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .43545 .52444 L .43743 .52157 L p
1 g
F P
s
P
p
.002 w
.43545 .52444 m .43681 .50592 L .43485 .50826 L p
1 g
F P
s
P
p
.002 w
.43346 .52734 m .43485 .50826 L .43422 .50901 L p
1 g
F P
s
P
p
.002 w
.41413 .51336 m .43643 .48526 L p
.43422 .50901 L 1 g
F P
s
P
p
.43287 .51185 m .43422 .50901 L .43396 .51176 L 1 g
F
P
p
.41413 .51336 m .43422 .50901 L .43287 .51185 L 1 g
F
P
p
.002 w
.43422 .50901 m .43485 .50826 L p
.43738 .50234 L 1 g
F P
s
P
p
.43346 .52734 m .43422 .50901 L .4332 .51989 L 1 g
F
P
p
.002 w
.44641 .49446 m .44521 .51024 L .44712 .50746 L p
1 g
F P
s
P
p
.002 w
.44712 .50746 m .44829 .49221 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .44328 .51305 L .44521 .51024 L p
1 g
F P
s
P
p
.002 w
.44521 .51024 m .44641 .49446 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .44641 .49446 L .44829 .49221 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .44134 .51587 L .44328 .51305 L p
1 g
F P
s
P
p
.002 w
.44328 .51305 m .44452 .49672 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .44452 .49672 L .44641 .49446 L p
1 g
F P
s
P
p
.002 w
.44641 .49446 m .45349 .4798 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .43939 .51871 L .44134 .51587 L p
1 g
F P
s
P
p
.002 w
.44134 .51587 m .44261 .499 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .44261 .499 L .44452 .49672 L p
1 g
F P
s
P
p
.002 w
.44452 .49672 m .45184 .48155 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .43743 .52157 L .43939 .51871 L p
1 g
F P
s
P
p
.002 w
.43939 .51871 m .44069 .50129 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .44069 .50129 L .44261 .499 L p
1 g
F P
s
P
p
.002 w
.44261 .499 m .45017 .48332 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.43743 .52157 m .43876 .5036 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .43876 .5036 L .44069 .50129 L p
1 g
F P
s
P
p
.002 w
.44069 .50129 m .44849 .48509 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .43681 .50592 L .43876 .5036 L p
1 g
F P
s
P
p
.002 w
.43876 .5036 m .44681 .48688 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.44339 .4905 m .43485 .50826 L .43681 .50592 L p
1 g
F P
s
P
p
.002 w
.43681 .50592 m .4451 .48869 L .44339 .4905 L p
1 g
F P
s
P
p
.43396 .51176 m .43442 .50857 L .46381 .50935 L 1 g
F
P
p
.43442 .50857 m .43601 .4977 L .4426 .49134 L 1 g
F
P
p
.002 w
.43485 .50826 m .44339 .4905 L .4426 .49134 L p
1 g
F P
s
P
p
.002 w
.44829 .49221 m .45513 .47806 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.4426 .49134 m .44339 .4905 L p
.44959 .48456 L 1 g
F P
s
P
p
.44946 .48468 m .49132 .49047 L .44444 .48956 L 1 g
F
P
p
.44959 .48456 m .44444 .48956 L .4426 .49134 L 1 g
F
P
p
.002 w
.43814 .48312 m .47354 .45845 L .47456 .46029 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .46574 .46792 L .46695 .46659 L p
1 g
F P
s
P
p
.002 w
.46695 .46659 m .48248 .45912 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .46451 .46925 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46574 .46792 m .48184 .46018 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .46328 .4706 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .48119 .46124 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .46204 .47195 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .48053 .46231 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .46079 .47332 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .47987 .46339 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .45953 .47469 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .47921 .46447 L .47854 .46557 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .45826 .47608 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .47854 .46557 L .47786 .46667 L p
1 g
F P
s
P
p
.002 w
.5 .4634 m .47786 .46667 L .47854 .46557 L p
1 g
F P
s
P
p
.44946 .48468 m .45781 .47657 L .49132 .49047 L 1 g
F
P
p
.45781 .47657 m .47753 .46721 L .49132 .49047 L 1 g
F
P
p
.002 w
.47753 .46721 m .47786 .46667 L p
.48727 .46571 L 1 g
F P
s
P
p
.4907 .46518 m .5242 .4783 L .47835 .46711 L 1 g
F
P
p
.002 w
.51752 .45912 m .53305 .46659 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .48184 .46018 L .48248 .45912 L p
1 g
F P
s
P
p
.002 w
.48248 .45912 m .5 .45653 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .51816 .46018 L .51752 .45912 L p
1 g
F P
s
P
p
.002 w
.5 .45653 m .51752 .45912 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .5 .45749 L .5 .45653 L p
1 g
F P
s
P
p
.002 w
.51816 .46018 m .53426 .46792 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .48119 .46124 L .48184 .46018 L p
1 g
F P
s
P
p
.002 w
.48184 .46018 m .5 .45749 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .51881 .46124 L .51816 .46018 L p
1 g
F P
s
P
p
.002 w
.5 .45749 m .51816 .46018 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .5 .45846 L .5 .45749 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .48053 .46231 L .48119 .46124 L p
1 g
F P
s
P
p
.002 w
.48119 .46124 m .5 .45846 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.5 .45846 m .51881 .46124 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .5 .45943 L .5 .45846 L p
1 g
F P
s
P
p
.002 w
.48053 .46231 m .5 .45943 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.5 .45943 m .51947 .46231 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .5 .46041 L .5 .45943 L p
1 g
F P
s
P
p
.002 w
.47354 .45845 m .51611 .44264 L .52017 .46056 L p
1 g
F P
s
P
p
.002 w
.51881 .46124 m .53549 .46925 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .51947 .46231 L .51881 .46124 L p
1 g
F P
s
P
p
.002 w
.51947 .46231 m .53672 .4706 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .52013 .46339 L .51947 .46231 L p
1 g
F P
s
P
p
.002 w
.52013 .46339 m .53796 .47195 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .52079 .46447 L .52013 .46339 L p
1 g
F P
s
P
p
.002 w
.5 .46041 m .52013 .46339 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .53921 .47332 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52079 .46447 m .5 .4614 L .5 .46041 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .52146 .46557 L .52079 .46447 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .52079 .46447 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .5 .4624 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .52146 .46557 L .52214 .46667 L p
1 g
F P
s
P
p
.002 w
.52214 .46667 m .5 .4634 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.54487 .47806 m .55171 .49221 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .54651 .4798 L .54487 .47806 L p
1 g
F P
s
P
p
.002 w
.53305 .46659 m .54487 .47806 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .55359 .49446 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .54816 .48155 L .54651 .4798 L p
1 g
F P
s
P
p
.002 w
.53426 .46792 m .54651 .4798 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.54651 .4798 m .53426 .46792 L .53305 .46659 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .55548 .49672 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .54983 .48332 L .54816 .48155 L p
1 g
F P
s
P
p
.002 w
.53549 .46925 m .54816 .48155 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.54816 .48155 m .53549 .46925 L .53426 .46792 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .55739 .499 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .55151 .48509 L .54983 .48332 L p
1 g
F P
s
P
p
.002 w
.53672 .4706 m .54983 .48332 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.54983 .48332 m .53672 .4706 L .53549 .46925 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .55931 .50129 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .55319 .48688 L .55151 .48509 L p
1 g
F P
s
P
p
.002 w
.53796 .47195 m .55151 .48509 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.55151 .48509 m .53796 .47195 L .53672 .4706 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .56124 .5036 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .5549 .48869 L .55319 .48688 L p
1 g
F P
s
P
p
.002 w
.53921 .47332 m .55319 .48688 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.55319 .48688 m .53921 .47332 L .53796 .47195 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .56319 .50592 L .56515 .50826 L p
1 g
F P
s
P
p
.002 w
.56515 .50826 m .55661 .4905 L .5549 .48869 L p
1 g
F P
s
P
p
.002 w
.54047 .47469 m .5549 .48869 L .55661 .4905 L p
1 g
F P
s
P
p
.002 w
.5549 .48869 m .54047 .47469 L .53921 .47332 L p
1 g
F P
s
P
p
.002 w
.55661 .4905 m .56515 .50826 L .56618 .50949 L p
1 g
F P
s
P
p
.002 w
.57598 .51231 m .56693 .51104 L p
.56618 .50949 L 1 g
F P
s
P
p
.55753 .4916 m .56509 .50009 L .56618 .50949 L 1 g
F
P
p
.56509 .50009 m .57598 .51231 L .56618 .50949 L 1 g
F
P
p
.002 w
.56455 .52444 m .55895 .54223 L .56075 .54566 L p
1 g
F P
s
P
p
.002 w
.56868 .54675 m .56304 .54412 L p
.57598 .51231 L 1 g
F P
s
P
p
.002 w
.56654 .52734 m .56075 .54566 L .56173 .5475 L p
1 g
F P
s
P
p
.002 w
.56868 .54675 m .55873 .55525 L p
.56173 .5475 L 1 g
F P
s
P
p
.002 w
.56304 .54412 m .56404 .54458 L p
.56173 .5475 L 1 g
F P
s
P
p
.002 w
.56404 .54458 m .56868 .54675 L p
.56173 .5475 L 1 g
F P
s
P
p
.002 w
.56173 .5475 m .56075 .54566 L p
.55518 .55576 L 1 g
F P
s
P
p
.56654 .52734 m .56173 .5475 L .56245 .54562 L 1 g
F
P
p
.56654 .52734 m .56194 .54791 L .56424 .53993 L 1 g
F
P
p
.002 w
.56075 .54566 m .54854 .56129 L .54926 .56323 L p
1 g
F P
s
P
p
.002 w
.55873 .55525 m .55034 .56241 L p
.55338 .55803 L 1 g
F P
s
P
p
.56173 .5475 m .55873 .55525 L .55338 .55803 L 1 g
F
P
p
.002 w
.55034 .56241 m .54245 .56915 L p
.54415 .56709 L 1 g
F P
s
P
p
.56075 .54566 m .54926 .56323 L .55518 .55576 L 1 g
F
P
p
.002 w
.54926 .56323 m .54854 .56129 L p
.53881 .57056 L 1 g
F P
s
P
p
.002 w
.5404 .56964 m .54245 .56915 L .53404 .57333 L p
1 g
F P
s
P
p
.002 w
.5194 .58927 m .5134 .58526 L p
.53352 .5741 L 1 g
F P
s
P
p
.002 w
.53863 .57249 m .5194 .58927 L p
.53352 .5741 L 1 g
F P
s
P
p
.002 w
.53172 .57467 m .53128 .57265 L p
.52029 .57829 L 1 g
F P
s
P
p
.002 w
.54245 .56915 m .53863 .57249 L p
.53352 .5741 L 1 g
F P
s
P
p
.002 w
.53404 .57333 m .54245 .56915 L p
.5134 .58526 L 1 g
F P
s
P
p
.002 w
.54854 .56129 m .53128 .57265 L .53174 .57476 L p
1 g
F P
s
P
p
.54854 .56129 m .53174 .57476 L .53726 .5715 L 1 g
F
P
p
.53704 .57225 m .53206 .5762 L .53605 .57319 L 1 g
F
P
p
.53804 .5713 m .53506 .57349 L .53758 .57174 L 1 g
F
P
p
.53862 .57074 m .53656 .57213 L .53838 .57097 L 1 g
F
P
p
.54854 .56129 m .537 .57174 L .53862 .57074 L 1 g
F
P
p
.537 .57174 m .53656 .57213 L .53862 .57074 L 1 g
F
P
p
.53881 .57056 m .54185 .5688 L .54926 .56323 L 1 g
F
P
p
.002 w
.54268 .56818 m .54245 .56915 L .54232 .56844 L p
1 g
F P
s
P
p
.54185 .5688 m .54196 .56873 L .54349 .56758 L 1 g
F
P
p
.54185 .5688 m .54349 .56758 L .54926 .56323 L 1 g
F
P
p
.002 w
.55537 .53545 m .54426 .54976 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.54426 .54976 m .55537 .53545 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .53036 .56847 L .53128 .57265 L p
1 g
F P
s
P
p
.002 w
.53036 .56847 m .54711 .55742 L .54568 .55358 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .54568 .55358 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .55715 .53883 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.53128 .57265 m .54854 .56129 L .54711 .55742 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .54711 .55742 L .54854 .56129 L p
1 g
F P
s
P
p
.002 w
.54711 .55742 m .55895 .54223 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.54854 .56129 m .56075 .54566 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.54922 .54128 m .55998 .54269 L .54349 .56758 L p
1 g
F P
s
P
p
.002 w
.54349 .56758 m .54245 .56915 L .54268 .56818 L p
1 g
F P
s
P
p
.002 w
.54268 .56818 m .54922 .54128 L p
.54349 .56758 L 1 g
F P
s
P
p
.002 w
.50985 .56564 m .52853 .56017 L .52762 .55605 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .50985 .56564 L .51016 .56994 L p
1 g
F P
s
P
p
.002 w
.51016 .56994 m .52944 .5643 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .51016 .56994 L .51048 .57427 L p
1 g
F P
s
P
p
.002 w
.51048 .57427 m .53036 .56847 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.54568 .55358 m .52944 .5643 L .53036 .56847 L p
1 g
F P
s
P
p
.002 w
.5071 .56934 m .51029 .56093 L .54158 .56893 L p
1 g
F P
s
P
p
.002 w
.54158 .56893 m .54245 .56915 L .54121 .56916 L p
1 g
F P
s
P
p
.002 w
.54121 .56916 m .5071 .56934 L p
.54158 .56893 L 1 g
F P
s
P
p
.002 w
.54426 .54976 m .52853 .56017 L .52944 .5643 L p
1 g
F P
s
P
p
.002 w
.52944 .5643 m .54568 .55358 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.51029 .56093 m .51697 .55312 L .54184 .56877 L p
1 g
F P
s
P
p
.002 w
.54184 .56877 m .54245 .56915 L .54158 .56893 L p
1 g
F P
s
P
p
.002 w
.54158 .56893 m .51029 .56093 L p
.54184 .56877 L 1 g
F P
s
P
p
.53838 .57097 m .53592 .57271 L .53804 .5713 L 1 g
F
P
p
.53656 .57213 m .53592 .57271 L .53838 .57097 L 1 g
F
P
p
.53592 .57271 m .53506 .57349 L .53804 .5713 L 1 g
F
P
p
.002 w
.54285 .54596 m .52762 .55605 L .52853 .56017 L p
1 g
F P
s
P
p
.002 w
.52762 .55605 m .54285 .54596 L .54145 .54218 L p
1 g
F P
s
P
p
.002 w
.52853 .56017 m .54426 .54976 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.51697 .55312 m .52642 .5468 L .54206 .56862 L p
1 g
F P
s
P
p
.002 w
.54206 .56862 m .54245 .56915 L .54184 .56877 L p
1 g
F P
s
P
p
.002 w
.54184 .56877 m .51697 .55312 L p
.54206 .56862 L 1 g
F P
s
P
p
.002 w
.52642 .5468 m .53759 .5427 L .54232 .56844 L p
1 g
F P
s
P
p
.002 w
.54232 .56844 m .54245 .56915 L .54206 .56862 L p
1 g
F P
s
P
p
.002 w
.54206 .56862 m .52642 .5468 L p
.54232 .56844 L 1 g
F P
s
P
p
.53758 .57174 m .53402 .57443 L .53704 .57225 L 1 g
F
P
p
.53506 .57349 m .53402 .57443 L .53758 .57174 L 1 g
F
P
p
.53402 .57443 m .53206 .5762 L .53704 .57225 L 1 g
F
P
p
.002 w
.55184 .52876 m .54145 .54218 L .54285 .54596 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .54285 .54596 L .54426 .54976 L p
1 g
F P
s
P
p
.002 w
.54285 .54596 m .5536 .53209 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.53759 .5427 m .54922 .54128 L .54268 .56818 L p
1 g
F P
s
P
p
.002 w
.54232 .56844 m .53759 .5427 L p
.54268 .56818 L 1 g
F P
s
P
p
.002 w
.5077 .57742 m .5071 .56934 L .54121 .56916 L p
1 g
F P
s
P
p
.002 w
.54121 .56916 m .54245 .56915 L .5404 .56964 L p
1 g
F P
s
P
p
.002 w
.5404 .56964 m .5077 .57742 L p
.54121 .56916 L 1 g
F P
s
P
p
.002 w
.53174 .57476 m .53206 .5762 L p
.53726 .5715 L 1 g
F P
s
P
p
.002 w
.53206 .5762 m .5322 .57686 L p
.53605 .57319 L 1 g
F P
s
P
p
.002 w
.56075 .54566 m .56654 .52734 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.55998 .54269 m .56304 .54412 L p
.54415 .56709 L 1 g
F P
s
P
p
.002 w
.54245 .56915 m .54349 .56758 L p
.54415 .56709 L 1 g
F P
s
P
p
.002 w
.54349 .56758 m .55998 .54269 L p
.54415 .56709 L 1 g
F P
s
P
p
.002 w
.5134 .58526 m .51197 .5843 L .53404 .57333 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .5322 .57686 L .53172 .57467 L p
1 g
F P
s
P
p
.52029 .57829 m .51111 .583 L .53172 .57467 L 1 g
F
P
p
.53881 .57056 m .53878 .57059 L .54196 .56873 L 1 g
F
P
p
.53878 .57059 m .53605 .57319 L .54185 .56882 L 1 g
F
P
p
.53878 .57059 m .54185 .56882 L .54196 .56873 L 1 g
F
P
p
.002 w
.5077 .57742 m .5404 .56964 L p
.53068 .575 L 1 g
F P
s
P
p
.002 w
.53404 .57333 m .53068 .575 L p
.5404 .56964 L 1 g
F P
s
P
p
.56304 .54412 m .55034 .56241 L .54415 .56709 L 1 g
F
P
p
.002 w
.57438 .55298 m .54594 .56738 L p
.55685 .55749 L 1 g
F P
s
P
p
.002 w
.54594 .56738 m .54245 .56915 L .549 .56356 L p
1 g
F P
s
P
p
.002 w
.549 .56356 m .56868 .54675 L p
.54594 .56738 L 1 g
F P
s
P
p
.002 w
.52917 .59181 m .5194 .58927 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.57487 .56897 m .56971 .57699 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.5765 .56067 m .57487 .56897 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.57438 .55298 m .5765 .56067 L .54245 .56915 L closepath p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .54998 .56518 L .54926 .56323 L p
1 g
F P
s
P
p
.002 w
.54926 .56323 m .54926 .56323 L p
.5492 .56328 L 1 g
F P
s
P
p
.5492 .56328 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.002 w
.56868 .54675 m .56964 .5478 L p
.55685 .55749 L 1 g
F P
s
P
p
.002 w
.56964 .5478 m .57438 .55298 L p
.55685 .55749 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54926 .56323 L p
.55518 .55576 L 1 g
F P
s
P
p
.002 w
.54926 .56323 m .54998 .56518 L p
.55505 .55599 L 1 g
F P
s
P
p
.55518 .55576 m .54926 .56323 L .55505 .55599 L 1 g
F
P
p
.56304 .54412 m .56173 .5475 L .55338 .55803 L 1 g
F
P
p
.53605 .57319 m .5322 .57686 L .54926 .56323 L 1 g
F
P
p
.002 w
.54998 .56518 m .56257 .5491 L .56173 .5475 L p
1 g
F P
s
P
p
.55518 .55576 m .54998 .56518 L .56173 .5475 L 1 g
F
P
p
.002 w
.56173 .5475 m .56194 .54791 L p
.56245 .54562 L 1 g
F P
s
P
p
.002 w
.56764 .52815 m .57598 .51231 L p
.56767 .53273 L 1 g
F P
s
P
p
.56767 .53273 m .56304 .54412 L .56748 .5287 L 1 g
F
P
p
.56767 .53273 m .56748 .5287 L .56764 .52815 L 1 g
F
P
p
.002 w
.56515 .50826 m .56654 .52734 L .56748 .5287 L p
1 g
F P
s
P
p
.56515 .50826 m .56748 .5287 L .56747 .52847 L 1 g
F
P
p
.002 w
.56635 .51096 m .57598 .51231 L .56747 .52847 L p
1 g
F P
s
P
p
.5669 .51964 m .56747 .52847 L .56711 .52096 L 1 g
F
P
p
.56515 .50826 m .56747 .52847 L .5669 .51964 L 1 g
F
P
p
.002 w
.55479 .51024 m .55008 .52544 L .55184 .52876 L p
1 g
F P
s
P
p
.002 w
.55008 .52544 m .55479 .51024 L .55288 .50746 L p
1 g
F P
s
P
p
.002 w
.55171 .49221 m .55288 .50746 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55184 .52876 L .5536 .53209 L p
1 g
F P
s
P
p
.002 w
.55184 .52876 m .55672 .51305 L .55479 .51024 L p
1 g
F P
s
P
p
.002 w
.55359 .49446 m .55479 .51024 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55479 .51024 m .55359 .49446 L .55171 .49221 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .5536 .53209 L .55537 .53545 L p
1 g
F P
s
P
p
.002 w
.5536 .53209 m .55866 .51587 L .55672 .51305 L p
1 g
F P
s
P
p
.002 w
.55548 .49672 m .55672 .51305 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55672 .51305 m .55548 .49672 L .55359 .49446 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55537 .53545 L .55715 .53883 L p
1 g
F P
s
P
p
.002 w
.55537 .53545 m .56061 .51871 L .55866 .51587 L p
1 g
F P
s
P
p
.002 w
.55739 .499 m .55866 .51587 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55866 .51587 m .55739 .499 L .55548 .49672 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .55715 .53883 L .55895 .54223 L p
1 g
F P
s
P
p
.002 w
.55715 .53883 m .56257 .52157 L .56061 .51871 L p
1 g
F P
s
P
p
.002 w
.55931 .50129 m .56061 .51871 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56061 .51871 m .55931 .50129 L .55739 .499 L p
1 g
F P
s
P
p
.002 w
.55895 .54223 m .56455 .52444 L .56257 .52157 L p
1 g
F P
s
P
p
.002 w
.56124 .5036 m .56257 .52157 L .56455 .52444 L p
1 g
F P
s
P
p
.002 w
.56257 .52157 m .56124 .5036 L .55931 .50129 L p
1 g
F P
s
P
p
.002 w
.56319 .50592 m .56455 .52444 L .56654 .52734 L p
1 g
F P
s
P
p
.002 w
.56455 .52444 m .56319 .50592 L .56124 .5036 L p
1 g
F P
s
P
p
.002 w
.56654 .52734 m .56515 .50826 L .56319 .50592 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56844 .52892 L p
.56515 .50826 L 1 g
F P
s
P
p
.002 w
.56693 .51104 m .56635 .51096 L p
.56618 .50949 L 1 g
F P
s
P
p
.002 w
.56844 .52892 m .56713 .51061 L .56618 .50949 L p
1 g
F P
s
P
p
.002 w
.56618 .50949 m .56515 .50826 L p
.56844 .52892 L 1 g
F P
s
P
p
.55661 .4905 m .56618 .50949 L .56179 .5004 L 1 g
F
P
p
.002 w
.5574 .49134 m .55661 .4905 L p
.56179 .5004 L 1 g
F P
s
P
p
.57345 .50684 m .57598 .51231 L .55666 .49062 L 1 g
F
P
p
.002 w
.56713 .51061 m .55834 .49233 L .5574 .49134 L p
1 g
F P
s
P
p
.56179 .5004 m .56713 .51061 L .5574 .49134 L 1 g
F
P
p
.55842 .47437 m .57345 .50684 L .5574 .49134 L 1 g
F
P
p
.002 w
.54174 .47608 m .55661 .4905 L .5574 .49134 L p
1 g
F P
s
P
p
.54174 .47608 m .5574 .49134 L .55666 .49062 L 1 g
F
P
p
.002 w
.55666 .49062 m .55463 .50932 L p
.54198 .47657 L 1 g
F P
s
P
p
.002 w
.52214 .46667 m .54174 .47608 L .54235 .47674 L p
1 g
F P
s
P
p
.54186 .47627 m .54235 .47674 L .54198 .47657 L 1 g
F
P
p
.54235 .47674 m .55666 .49062 L .54198 .47657 L 1 g
F
P
p
.52214 .46667 m .54235 .47674 L .54144 .47632 L 1 g
F
P
p
.002 w
.54144 .47632 m .5242 .4783 L p
.52266 .4673 L 1 g
F P
s
P
p
.53226 .47191 m .54144 .47632 L .53472 .47318 L 1 g
F
P
p
.52214 .46667 m .54144 .47632 L .53226 .47191 L 1 g
F
P
p
.002 w
.5242 .4783 m .52166 .4671 L p
.52266 .4673 L 1 g
F P
s
P
p
.54174 .47608 m .55666 .49062 L .54969 .48387 L 1 g
F
P
p
.002 w
.55661 .4905 m .54174 .47608 L .54047 .47469 L p
1 g
F P
s
P
p
.002 w
.52146 .46557 m .54047 .47469 L .54174 .47608 L p
1 g
F P
s
P
p
.002 w
.55463 .50932 m .55666 .49062 L p
.55753 .4916 L 1 g
F P
s
P
p
.002 w
.55834 .49233 m .54302 .47747 L .54237 .47676 L p
1 g
F P
s
P
p
.002 w
.54237 .47676 m .54174 .47608 L p
.55807 .49207 L 1 g
F P
s
P
p
.55807 .49207 m .55834 .49233 L .54237 .47676 L 1 g
F
P
p
.002 w
.54174 .47608 m .52214 .46667 L .52146 .46557 L p
1 g
F P
s
P
p
.002 w
.55288 .50746 m .54834 .52214 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.5242 .4783 m .54144 .47632 L p
.55463 .50932 L 1 g
F P
s
P
p
.002 w
.54144 .47632 m .54186 .47627 L p
.54198 .47657 L 1 g
F P
s
P
p
.54144 .47632 m .54198 .47657 L .55463 .50932 L 1 g
F
P
p
.002 w
.54302 .47747 m .52282 .46778 L .52268 .46756 L p
1 g
F P
s
P
p
.002 w
.52246 .4672 m .52214 .46667 L p
.53226 .47191 L 1 g
F P
s
P
p
.51611 .44264 m .55421 .47121 L .52246 .4672 L 1 g
F
P
p
.002 w
.5 .4634 m .52214 .46667 L .52246 .4672 L p
1 g
F P
s
P
p
.5 .4634 m .52246 .4672 L .52192 .46713 L 1 g
F
P
p
.55421 .47121 m .55842 .47437 L .52166 .4671 L 1 g
F
P
p
.5 .4634 m .52248 .46723 L .50883 .4651 L 1 g
F
P
p
.002 w
.52166 .4671 m .52159 .46678 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52159 .46678 m .51611 .44264 L p
.52246 .4672 L 1 g
F P
s
P
p
.002 w
.52268 .46756 m .52246 .4672 L p
.53472 .47318 L 1 g
F P
s
P
p
.53226 .47191 m .53472 .47318 L .52246 .4672 L 1 g
F
P
p
.53472 .47318 m .54302 .47747 L .52268 .46756 L 1 g
F
P
p
.52266 .4673 m .5352 .46978 L .54144 .47632 L 1 g
F
P
p
.002 w
.55842 .47437 m .54186 .47627 L p
.5352 .46978 L 1 g
F P
s
P
p
.002 w
.54186 .47627 m .54144 .47632 L p
.5352 .46978 L 1 g
F P
s
P
p
.002 w
.54235 .47674 m .54302 .47747 L p
.53472 .47318 L 1 g
F P
s
P
p
.54969 .48387 m .55666 .49062 L .55186 .48599 L 1 g
F
P
p
.002 w
.54186 .47627 m .55842 .47437 L .55666 .49062 L p
1 g
F P
s
P
p
.002 w
.55666 .49062 m .55673 .48995 L p
.5574 .49134 L 1 g
F P
s
P
p
.002 w
.55673 .48995 m .55842 .47437 L p
.5574 .49134 L 1 g
F P
s
P
p
.55753 .4916 m .56618 .50949 L .55463 .50932 L 1 g
F
P
p
.002 w
.56635 .51096 m .55463 .50932 L p
.56618 .50949 L 1 g
F P
s
P
p
.002 w
.55463 .50932 m .56635 .51096 L p
.55998 .54269 L 1 g
F P
s
P
p
.002 w
.56257 .5491 m .56854 .53025 L .56748 .52871 L p
1 g
F P
s
P
p
.002 w
.56748 .52871 m .56654 .52734 L p
.56401 .54119 L 1 g
F P
s
P
p
.56401 .54119 m .56257 .5491 L .56748 .52871 L 1 g
F
P
p
.002 w
.56747 .52847 m .55998 .54269 L p
.56635 .51096 L 1 g
F P
s
P
p
.002 w
.56304 .54412 m .55998 .54269 L .56764 .52815 L p
1 g
F P
s
P
p
.002 w
.56748 .5287 m .56854 .53025 L p
.56711 .52096 L 1 g
F P
s
P
p
.002 w
.56194 .54791 m .56257 .5491 L p
.56424 .53993 L 1 g
F P
s
P
p
.002 w
.56713 .51061 m .56844 .52892 L p
.57056 .53318 L 1 g
F P
s
P
p
.002 w
.56844 .52892 m .56854 .53025 L .56861 .53035 L p
1 g
F P
s
P
p
.002 w
.56861 .53035 m .57056 .53318 L p
.56844 .52892 L 1 g
F P
s
P
p
.002 w
.56618 .50949 m .56713 .51061 L p
.56179 .5004 L 1 g
F P
s
P
p
.002 w
.5574 .49134 m .55834 .49233 L p
.55186 .48599 L 1 g
F P
s
P
p
.002 w
.52246 .4672 m .52248 .46723 L p
.52192 .46713 L 1 g
F P
s
P
p
.002 w
.52166 .4671 m .5242 .4783 L p
.5 .46372 L 1 g
F P
s
P
p
.002 w
.52248 .46723 m .52282 .46778 L p
.50883 .4651 L 1 g
F P
s
P
p
.4907 .46518 m .5 .46372 L .5242 .4783 L 1 g
F
P
p
.002 w
.52282 .46778 m .5 .46442 L .5 .46372 L p
1 g
F P
s
P
p
.002 w
.5 .46372 m .5 .4634 L p
.50883 .4651 L 1 g
F P
s
P
p
.50883 .4651 m .52282 .46778 L .5 .46372 L 1 g
F
P
p
.002 w
.5 .46041 m .47987 .46339 L .48053 .46231 L p
1 g
F P
s
P
p
.002 w
.5 .4614 m .47921 .46447 L .47987 .46339 L p
1 g
F P
s
P
p
.002 w
.47987 .46339 m .5 .46041 L .5 .4614 L p
1 g
F P
s
P
p
.002 w
.5 .4624 m .47854 .46557 L .47921 .46447 L p
1 g
F P
s
P
p
.002 w
.47921 .46447 m .5 .4614 L .5 .4624 L p
1 g
F P
s
P
p
.002 w
.47854 .46557 m .5 .4624 L .5 .4634 L p
1 g
F P
s
P
p
.002 w
.47786 .46667 m .5 .4634 L .5 .46437 L p
1 g
F P
s
P
p
.002 w
.5 .46437 m .5 .46442 L p
.49824 .4646 L 1 g
F P
s
P
p
.47786 .46667 m .5 .46437 L .49824 .4646 L 1 g
F
P
p
.002 w
.45826 .47608 m .47786 .46667 L .47753 .46721 L p
1 g
F P
s
P
p
.002 w
.47753 .46721 m .47718 .46778 L p
.46593 .47272 L 1 g
F P
s
P
p
.45826 .47608 m .47753 .46721 L .46593 .47272 L 1 g
F
P
p
.002 w
.45781 .47657 m .45826 .47608 L p
.46593 .47272 L 1 g
F P
s
P
p
.002 w
.46574 .46792 m .45349 .4798 L .45513 .47806 L p
1 g
F P
s
P
p
.002 w
.45513 .47806 m .46695 .46659 L .46574 .46792 L p
1 g
F P
s
P
p
.002 w
.46451 .46925 m .45184 .48155 L .45349 .4798 L p
1 g
F P
s
P
p
.002 w
.45349 .4798 m .46574 .46792 L .46451 .46925 L p
1 g
F P
s
P
p
.002 w
.46328 .4706 m .45017 .48332 L .45184 .48155 L p
1 g
F P
s
P
p
.002 w
.45184 .48155 m .46451 .46925 L .46328 .4706 L p
1 g
F P
s
P
p
.002 w
.46204 .47195 m .44849 .48509 L .45017 .48332 L p
1 g
F P
s
P
p
.002 w
.45017 .48332 m .46328 .4706 L .46204 .47195 L p
1 g
F P
s
P
p
.002 w
.46079 .47332 m .44681 .48688 L .44849 .48509 L p
1 g
F P
s
P
p
.002 w
.44849 .48509 m .46204 .47195 L .46079 .47332 L p
1 g
F P
s
P
p
.002 w
.45953 .47469 m .4451 .48869 L .44681 .48688 L p
1 g
F P
s
P
p
.002 w
.44681 .48688 m .46079 .47332 L .45953 .47469 L p
1 g
F P
s
P
p
.002 w
.45826 .47608 m .44339 .4905 L .4451 .48869 L p
1 g
F P
s
P
p
.002 w
.4451 .48869 m .45953 .47469 L .45826 .47608 L p
1 g
F P
s
P
p
.43485 .50826 m .4426 .49134 L .43738 .50234 L 1 g
F
P
p
.43442 .50857 m .4426 .49134 L .46381 .50935 L 1 g
F
P
p
.002 w
.44339 .4905 m .45826 .47608 L .45702 .47743 L p
1 g
F P
s
P
p
.44339 .4905 m .45702 .47743 L .45608 .47834 L 1 g
F
P
p
.002 w
.44377 .48887 m .44444 .48956 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.44444 .48956 m .46381 .50935 L p
.4426 .49134 L 1 g
F P
s
P
p
.002 w
.45702 .47743 m .45698 .47747 L p
.45608 .47834 L 1 g
F P
s
P
p
.43814 .48312 m .47456 .46029 L .45781 .47657 L 1 g
F
P
p
.44268 .48375 m .45781 .47657 L .44946 .48468 L 1 g
F
P
p
.43814 .48312 m .45781 .47657 L .44268 .48375 L 1 g
F
P
p
.002 w
.47456 .46029 m .47822 .46688 L p
.47753 .46721 L 1 g
F P
s
P
p
.45781 .47657 m .46593 .46868 L .47753 .46721 L 1 g
F
P
p
.46593 .46868 m .47456 .46029 L .47753 .46721 L 1 g
F
P
p
.47354 .45845 m .52017 .46056 L .5 .46372 L 1 g
F
P
p
.47838 .46035 m .5 .46372 L .4907 .46518 L 1 g
F
P
p
.47354 .45845 m .5 .46372 L .47838 .46035 L 1 g
F
P
p
.002 w
.52017 .46056 m .52166 .4671 L p
.5 .46372 L 1 g
F P
s
P
p
.002 w
.5242 .4783 m .49132 .49047 L .47835 .46711 L p
1 g
F P
s
P
p
.002 w
.47835 .46711 m .49132 .49047 L p
.47753 .46721 L 1 g
F P
s
P
p
.002 w
.5 .46442 m .47718 .46778 L .47752 .46724 L p
1 g
F P
s
P
p
.002 w
.47752 .46724 m .47753 .46721 L p
.4783 .46712 L 1 g
F P
s
P
p
.4783 .46712 m .5 .46442 L .47752 .46724 L 1 g
F
P
p
.48727 .46571 m .49824 .4646 L .47835 .46711 L 1 g
F
P
p
.48727 .46571 m .47835 .46711 L .47753 .46721 L 1 g
F
P
p
.002 w
.47835 .46711 m .47354 .45845 L p
.4907 .46518 L 1 g
F P
s
P
p
.002 w
.47822 .46688 m .47835 .46711 L p
.47753 .46721 L 1 g
F P
s
P
p
.49824 .4646 m .5 .46442 L .47753 .46721 L 1 g
F
P
p
.002 w
.47718 .46778 m .45698 .47747 L .45781 .47657 L p
1 g
F P
s
P
p
.46593 .47272 m .47718 .46778 L .45781 .47657 L 1 g
F
P
p
.002 w
.49132 .49047 m .46381 .50935 L .44444 .48956 L p
1 g
F P
s
P
p
.002 w
.4426 .49134 m .44166 .49233 L p
.43738 .50234 L 1 g
F P
s
P
p
.002 w
.45698 .47747 m .44166 .49233 L .44244 .49151 L p
1 g
F P
s
P
p
.002 w
.44244 .49151 m .4426 .49134 L p
.44436 .48965 L 1 g
F P
s
P
p
.44436 .48965 m .45698 .47747 L .44244 .49151 L 1 g
F
P
p
.44959 .48456 m .45608 .47834 L .44444 .48956 L 1 g
F
P
p
.002 w
.44444 .48956 m .43814 .48312 L p
.44946 .48468 L 1 g
F P
s
P
p
.45608 .47834 m .45698 .47747 L .4426 .49134 L 1 g
F
P
p
.002 w
.43814 .48312 m .44377 .48887 L p
.4426 .49134 L 1 g
F P
s
P
p
.43601 .4977 m .43814 .48312 L .4426 .49134 L 1 g
F
P
p
.002 w
.43643 .48526 m .43814 .48312 L p
.43396 .51176 L 1 g
F P
s
P
p
.002 w
.44166 .49233 m .43287 .51061 L .43422 .50901 L p
1 g
F P
s
P
p
.43738 .50234 m .44166 .49233 L .43422 .50901 L 1 g
F
P
p
.002 w
.43422 .50901 m .43287 .51061 L p
.4332 .51989 L 1 g
F P
s
P
p
.002 w
.46381 .50935 m .44491 .53255 L .43273 .52496 L p
1 g
F P
s
P
p
.43396 .51176 m .46381 .50935 L .43273 .52496 L 1 g
F
P
p
.002 w
.43273 .52496 m .44491 .53255 L p
.43237 .53647 L 1 g
F P
s
P
p
.40396 .54535 m .43273 .52496 L .43237 .53647 L 1 g
F
P
p
.002 w
.43287 .51061 m .43146 .53025 L .43262 .52857 L p
1 g
F P
s
P
p
.43303 .51506 m .43287 .51061 L .43262 .52857 L 1 g
F
P
p
.002 w
.43262 .52857 m .43146 .53025 L p
.43579 .53881 L 1 g
F P
s
P
p
.002 w
.43146 .53025 m .43743 .5491 L .4384 .54726 L p
1 g
F P
s
P
p
.43579 .53881 m .43146 .53025 L .4384 .54726 L 1 g
F
P
p
.002 w
.4384 .54726 m .43743 .5491 L p
.44247 .55348 L 1 g
F P
s
P
p
.002 w
.43657 .55721 m .40396 .54535 L p
.43152 .53674 L 1 g
F P
s
P
p
.002 w
.44491 .53255 m .47737 .5486 L p
.44463 .55551 L 1 g
F P
s
P
p
.002 w
.43942 .54881 m .44491 .53255 L p
.44463 .55551 L 1 g
F P
s
P
p
.43934 .58049 m .44804 .55988 L .45844 .57144 L 1 g
F
P
p
.002 w
.43743 .5491 m .45002 .56518 L .45071 .56331 L p
1 g
F P
s
P
p
.002 w
.45071 .56331 m .45083 .56299 L p
.44888 .56096 L 1 g
F P
s
P
p
.44888 .56096 m .43743 .5491 L .45071 .56331 L 1 g
F
P
p
.44426 .55504 m .44157 .5527 L .44804 .55988 L 1 g
F
P
p
.002 w
.49015 .56564 m .47147 .56017 L .47056 .5643 L p
1 g
F P
s
P
p
.002 w
.45432 .55358 m .47056 .5643 L .47147 .56017 L p
1 g
F P
s
P
p
.002 w
.47056 .5643 m .45432 .55358 L .45289 .55742 L p
1 g
F P
s
P
p
.002 w
.47737 .5486 m .47137 .56532 L .44804 .55988 L p
1 g
F P
s
P
p
.44463 .55551 m .47737 .5486 L .44804 .55988 L 1 g
F
P
p
.002 w
.44804 .55988 m .47137 .56532 L p
.45844 .57144 L 1 g
F P
s
P
p
.44157 .5527 m .43743 .5491 L .45083 .56299 L 1 g
F
P
p
.002 w
.45083 .56299 m .45002 .56518 L p
.46007 .5692 L 1 g
F P
s
P
p
.002 w
.45002 .56518 m .4678 .57686 L .46827 .5747 L p
1 g
F P
s
P
p
.46007 .5692 m .45002 .56518 L .46827 .5747 L 1 g
F
P
p
.002 w
.46827 .5747 m .4678 .57686 L p
.47528 .57748 L 1 g
F P
s
P
p
.002 w
.47137 .56532 m .5071 .56934 L p
.48068 .57853 L 1 g
F P
s
P
p
.002 w
.47244 .57635 m .47137 .56532 L p
.48068 .57853 L 1 g
F P
s
P
p
.51079 .57862 m .48906 .58063 L .4993 .58092 L 1 g
F
P
p
.50228 .581 m .48906 .58063 L .5077 .57742 L 1 g
F
P
p
.002 w
.48058 .58039 m .48563 .57984 L p
.48906 .58063 L 1 g
F P
s
P
p
.002 w
.48563 .57984 m .5077 .57742 L p
.48906 .58063 L 1 g
F P
s
P
p
.002 w
.4678 .57686 m .48889 .583 L .48905 .58074 L p
1 g
F P
s
P
p
.002 w
.48905 .58074 m .48906 .58063 L p
.48771 .58039 L 1 g
F P
s
P
p
.48771 .58039 m .4678 .57686 L .48905 .58074 L 1 g
F
P
p
.47732 .57764 m .4754 .57749 L .48563 .57984 L 1 g
F
P
p
.002 w
.5071 .56934 m .5077 .57742 L .48563 .57984 L p
1 g
F P
s
P
p
.48068 .57853 m .5071 .56934 L .48563 .57984 L 1 g
F
P
p
.4754 .57749 m .4678 .57686 L .48906 .58063 L 1 g
F
P
p
.002 w
.48906 .58063 m .48889 .583 L p
.4993 .58092 L 1 g
F P
s
P
p
.51098 .58113 m .5077 .57742 L .53068 .575 L 1 g
F
P
p
.002 w
.51005 .58122 m .5077 .57742 L p
.51098 .58113 L 1 g
F P
s
P
p
.002 w
.51111 .583 m .51098 .58124 L p
.50249 .58192 L 1 g
F P
s
P
p
.002 w
.48889 .583 m .49083 .583 L p
.50249 .58192 L 1 g
F P
s
P
p
.002 w
.49083 .583 m .51111 .583 L p
.50249 .58192 L 1 g
F P
s
P
p
.002 w
.51098 .58113 m .51098 .58124 L p
.512 .58081 L 1 g
F P
s
P
p
.002 w
.51098 .58124 m .51111 .583 L p
.51633 .58032 L 1 g
F P
s
P
p
.4993 .58092 m .48889 .583 L .51098 .58124 L 1 g
F
P
p
.002 w
.5077 .57742 m .51005 .58122 L p
.50228 .581 L 1 g
F P
s
P
p
.002 w
.54145 .54218 m .55184 .52876 L .55008 .52544 L p
1 g
F P
s
P
p
.002 w
.63271 .4609 m .65251 .48541 L .63038 .51032 L p
1 g
F P
s
P
p
.002 w
.65251 .48541 m .63271 .4609 L .64657 .42956 L p
1 g
F P
s
P
p
.002 w
.55012 .30232 m .61206 .31448 L .61446 .34302 L p
1 g
F P
s
P
p
.002 w
.61206 .31448 m .55012 .30232 L .54362 .27742 L p
1 g
F P
s
P
p
.002 w
.41413 .51336 m .40396 .54535 L .37465 .53022 L p
1 g
F P
s
P
p
.002 w
.37465 .53022 m .38616 .49177 L .41413 .51336 L p
1 g
F P
s
P
p
.002 w
.57487 .56897 m .5765 .56067 L .6079 .54839 L p
1 g
F P
s
P
p
.002 w
.60405 .53313 m .6079 .54839 L .5765 .56067 L p
1 g
F P
s
P
p
.002 w
.6079 .54839 m .60405 .53313 L .63038 .51032 L p
1 g
F P
s
P
p
.002 w
.4744 .28379 m .54362 .27742 L .55012 .30232 L p
1 g
F P
s
P
p
.002 w
.61342 .3749 m .65582 .39875 L .64657 .42956 L p
1 g
F P
s
P
p
.002 w
.65582 .39875 m .61342 .3749 L .61446 .34302 L p
1 g
F P
s
P
p
.004 w
.65428 .38404 m
.66997 .37932 L
s
P
p
.002 w
.39349 .42689 m .362 .46861 L .34242 .44474 L p
1 g
F P
s
P
p
.002 w
.34242 .44474 m .37616 .39905 L .39349 .42689 L p
1 g
F P
s
P
p
.002 w
.61467 .49163 m .63038 .51032 L .60405 .53313 L p
1 g
F P
s
P
p
.002 w
.63038 .51032 m .61467 .49163 L .63271 .4609 L p
1 g
F P
s
P
p
.002 w
.48182 .30881 m .41644 .33346 L .40822 .30882 L p
1 g
F P
s
P
p
.002 w
.40822 .30882 m .4744 .28379 L .48182 .30881 L p
1 g
F P
s
P
p
.002 w
.5765 .56067 m .57438 .55298 L .60405 .53313 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .48857 .5874 L .48889 .583 L p
1 g
F P
s
P
p
.002 w
.48889 .583 m .4678 .57686 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .51143 .5874 L .51111 .583 L p
1 g
F P
s
P
p
.002 w
.51111 .583 m .48889 .583 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.5322 .57686 m .51111 .583 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.55012 .30232 m .48182 .30881 L .4744 .28379 L p
1 g
F P
s
P
p
.002 w
.42747 .36178 m .37616 .39905 L .36294 .37277 L p
1 g
F P
s
P
p
.002 w
.36294 .37277 m .41644 .33346 L .42747 .36178 L p
1 g
F P
s
P
p
.002 w
.60887 .40904 m .64657 .42956 L .63271 .4609 L p
1 g
F P
s
P
p
.002 w
.64657 .42956 m .60887 .40904 L .61342 .3749 L p
1 g
F P
s
P
p
.004 w
.5 .43051 m
.61044 .39725 L
s
P
p
.004 w
.63602 .38954 m
.65428 .38404 L
s
P
p
.004 w
.62717 .39221 m
.6282 .3919 L
s
P
p
.004 w
.6282 .3919 m
.63602 .38954 L
s
P
p
.002 w
.44856 .56909 m .46687 .58109 L .4678 .57686 L p
1 g
F P
s
P
p
.002 w
.4678 .57686 m .45002 .56518 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .53313 .58109 L .5322 .57686 L p
1 g
F P
s
P
p
.002 w
.54998 .56518 m .5322 .57686 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.59306 .5206 m .60405 .53313 L .57438 .55298 L p
1 g
F P
s
P
p
.002 w
.60405 .53313 m .59306 .5206 L .61467 .49163 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .48824 .59182 L .48857 .5874 L p
1 g
F P
s
P
p
.002 w
.48857 .5874 m .46687 .58109 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .51176 .59182 L .51143 .5874 L p
1 g
F P
s
P
p
.002 w
.51143 .5874 m .48857 .5874 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .51143 .5874 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.55526 .33186 m .61446 .34302 L .61342 .3749 L p
1 g
F P
s
P
p
.002 w
.61446 .34302 m .55526 .33186 L .55012 .30232 L p
1 g
F P
s
P
p
.002 w
.57438 .55298 m .56868 .54675 L .59306 .5206 L p
1 g
F P
s
P
p
.002 w
.4144 .45527 m .38616 .49177 L .362 .46861 L p
1 g
F P
s
P
p
.002 w
.362 .46861 m .39349 .42689 L .4144 .45527 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .46593 .58535 L .46687 .58109 L p
1 g
F P
s
P
p
.002 w
.46687 .58109 m .44856 .56909 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .53407 .58535 L .53313 .58109 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .53313 .58109 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.53313 .58109 m .55144 .56909 L .54998 .56518 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .48792 .59627 L .48824 .59182 L p
1 g
F P
s
P
p
.002 w
.48824 .59182 m .46593 .58535 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .51208 .59627 L .51176 .59182 L p
1 g
F P
s
P
p
.002 w
.51176 .59182 m .48824 .59182 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .51176 .59182 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .44856 .56909 L .45002 .56518 L p
1 g
F P
s
P
p
.002 w
.45002 .56518 m .43743 .5491 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.56257 .5491 m .54998 .56518 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.51029 .56093 m .5071 .56934 L .47137 .56532 L p
1 g
F P
s
P
p
.002 w
.47137 .56532 m .47737 .5486 L .51029 .56093 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .46499 .58963 L .46593 .58535 L p
1 g
F P
s
P
p
.002 w
.46593 .58535 m .4471 .57302 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .53501 .58963 L .53407 .58535 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .53407 .58535 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.53407 .58535 m .5529 .57302 L .55144 .56909 L p
1 g
F P
s
P
p
.002 w
.48182 .30881 m .55012 .30232 L .55526 .33186 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .48759 .60074 L .48792 .59627 L p
1 g
F P
s
P
p
.002 w
.48792 .59627 m .46499 .58963 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.51208 .59627 m .48792 .59627 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .51241 .60074 L .51208 .59627 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .51208 .59627 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.60091 .44421 m .63271 .4609 L .61467 .49163 L p
1 g
F P
s
P
p
.002 w
.63271 .4609 m .60091 .44421 L .60887 .40904 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .4471 .57302 L .44856 .56909 L p
1 g
F P
s
P
p
.002 w
.44856 .56909 m .4356 .55256 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .55144 .56909 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.55144 .56909 m .5644 .55256 L .56257 .5491 L p
1 g
F P
s
P
p
.002 w
.57598 .51231 m .59306 .5206 L .56868 .54675 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .46404 .59393 L .46499 .58963 L p
1 g
F P
s
P
p
.002 w
.46499 .58963 m .44564 .57698 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .53596 .59393 L .53501 .58963 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .53501 .58963 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.53501 .58963 m .55436 .57698 L .5529 .57302 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .48727 .60524 L .48759 .60074 L p
1 g
F P
s
P
p
.002 w
.48759 .60074 m .46404 .59393 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .51273 .60524 L .51241 .60074 L p
1 g
F P
s
P
p
.002 w
.51241 .60074 m .48759 .60074 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .51241 .60074 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51697 .55312 m .51029 .56093 L .47737 .5486 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .4356 .55256 L .43743 .5491 L p
1 g
F P
s
P
p
.002 w
.43743 .5491 m .43146 .53025 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.56854 .53025 m .56257 .5491 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.5898 .47907 m .61467 .49163 L .59306 .5206 L p
1 g
F P
s
P
p
.002 w
.61467 .49163 m .5898 .47907 L .60091 .44421 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .44564 .57698 L .4471 .57302 L p
1 g
F P
s
P
p
.002 w
.4471 .57302 m .43376 .55605 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .5529 .57302 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.5529 .57302 m .56624 .55605 L .5644 .55256 L p
1 g
F P
s
P
p
.002 w
.59306 .5206 m .57598 .51231 L .5898 .47907 L p
1 g
F P
s
P
p
.002 w
.43814 .48312 m .41413 .51336 L .38616 .49177 L p
1 g
F P
s
P
p
.002 w
.38616 .49177 m .4144 .45527 L .43814 .48312 L p
1 g
F P
s
P
p
.002 w
.49 .33828 m .42747 .36178 L .41644 .33346 L p
1 g
F P
s
P
p
.002 w
.41644 .33346 m .48182 .30881 L .49 .33828 L p
1 g
F P
s
P
p
.002 w
.441 .39283 m .39349 .42689 L .37616 .39905 L p
1 g
F P
s
P
p
.002 w
.37616 .39905 m .42747 .36178 L .441 .39283 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .46309 .59826 L .46404 .59393 L p
1 g
F P
s
P
p
.002 w
.46404 .59393 m .44416 .58096 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .53691 .59826 L .53596 .59393 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .53596 .59393 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.53596 .59393 m .55584 .58096 L .55436 .57698 L p
1 g
F P
s
P
p
.002 w
.55998 .54269 m .54922 .54128 L .55463 .50932 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .48694 .60976 L .48727 .60524 L p
1 g
F P
s
P
p
.002 w
.48727 .60524 m .46309 .59826 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .51306 .60976 L .51273 .60524 L p
1 g
F P
s
P
p
.002 w
.51273 .60524 m .48727 .60524 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .51273 .60524 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.5588 .36509 m .61342 .3749 L .60887 .40904 L p
1 g
F P
s
P
p
.002 w
.61342 .3749 m .5588 .36509 L .55526 .33186 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .43376 .55605 L .4356 .55256 L p
1 g
F P
s
P
p
.002 w
.4356 .55256 m .42944 .53318 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .5644 .55256 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.5644 .55256 m .57056 .53318 L .56854 .53025 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .44416 .58096 L .44564 .57698 L p
1 g
F P
s
P
p
.002 w
.44564 .57698 m .43191 .55955 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .55436 .57698 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.55436 .57698 m .56809 .55955 L .56624 .55605 L p
1 g
F P
s
P
p
.002 w
.52642 .5468 m .51697 .55312 L .49043 .53297 L p
1 g
F P
s
P
p
.002 w
.47737 .5486 m .49043 .53297 L .51697 .55312 L p
1 g
F P
s
P
p
.002 w
.55526 .33186 m .49 .33828 L .48182 .30881 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .46213 .60261 L .46309 .59826 L p
1 g
F P
s
P
p
.002 w
.46309 .59826 m .44267 .58496 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .53787 .60261 L .53691 .59826 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .53691 .59826 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.53691 .59826 m .55733 .58496 L .55584 .58096 L p
1 g
F P
s
P
p
.002 w
.54922 .54128 m .53759 .5427 L .53145 .51207 L p
1 g
F P
s
P
p
.002 w
.53145 .51207 m .55463 .50932 L .54922 .54128 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .48661 .61431 L .48694 .60976 L p
1 g
F P
s
P
p
.002 w
.48694 .60976 m .46213 .60261 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .51339 .61431 L .51306 .60976 L p
1 g
F P
s
P
p
.002 w
.51306 .60976 m .48694 .60976 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .51306 .60976 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.49043 .53297 m .47737 .5486 L .44491 .53255 L p
1 g
F P
s
P
p
.002 w
.53759 .5427 m .52642 .5468 L .50917 .52028 L p
1 g
F P
s
P
p
.002 w
.49043 .53297 m .50917 .52028 L .52642 .5468 L p
1 g
F P
s
P
p
.002 w
.50917 .52028 m .53145 .51207 L .53759 .5427 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .44267 .58496 L .44416 .58096 L p
1 g
F P
s
P
p
.002 w
.44416 .58096 m .43005 .56308 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .55584 .58096 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.55584 .58096 m .56995 .56308 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .43191 .55955 L .43376 .55605 L p
1 g
F P
s
P
p
.002 w
.43376 .55605 m .42742 .53614 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .56624 .55605 L .56809 .55955 L p
1 g
F P
s
P
p
.002 w
.56624 .55605 m .57258 .53614 L .57056 .53318 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .42944 .53318 L .43146 .53025 L p
1 g
F P
s
P
p
.002 w
.43146 .53025 m .43287 .51061 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.44491 .53255 m .46381 .50935 L .49043 .53297 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .46117 .60699 L .46213 .60261 L p
1 g
F P
s
P
p
.002 w
.46213 .60261 m .44118 .58899 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .53883 .60699 L .53787 .60261 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .53787 .60261 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.53787 .60261 m .55882 .58899 L .55733 .58496 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .48627 .61888 L .48661 .61431 L p
1 g
F P
s
P
p
.002 w
.48661 .61431 m .46117 .60699 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .51373 .61888 L .51339 .61431 L p
1 g
F P
s
P
p
.002 w
.51339 .61431 m .48661 .61431 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .51339 .61431 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.49 .33828 m .55526 .33186 L .5588 .36509 L p
1 g
F P
s
P
p
.002 w
.55842 .47437 m .5898 .47907 L .57598 .51231 L p
1 g
F P
s
P
p
.002 w
.56056 .40083 m .60887 .40904 L .60091 .44421 L p
1 g
F P
s
P
p
.002 w
.60887 .40904 m .56056 .40083 L .5588 .36509 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .44118 .58899 L .44267 .58496 L p
1 g
F P
s
P
p
.002 w
.44267 .58496 m .42818 .56663 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .55733 .58496 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.55733 .58496 m .57182 .56663 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .43005 .56308 L .43191 .55955 L p
1 g
F P
s
P
p
.002 w
.43191 .55955 m .42537 .53911 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .56809 .55955 L .56995 .56308 L p
1 g
F P
s
P
p
.002 w
.56809 .55955 m .57463 .53911 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .42742 .53614 L .42944 .53318 L p
1 g
F P
s
P
p
.002 w
.42944 .53318 m .43089 .51299 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .57056 .53318 L .57258 .53614 L p
1 g
F P
s
P
p
.002 w
.57056 .53318 m .56911 .51299 L .56713 .51061 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .4602 .61139 L .46117 .60699 L p
1 g
F P
s
P
p
.002 w
.46117 .60699 m .43967 .59304 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .5398 .61139 L .53883 .60699 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .53883 .60699 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.53883 .60699 m .56033 .59304 L .55882 .58899 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .48594 .62348 L .48627 .61888 L p
1 g
F P
s
P
p
.002 w
.48627 .61888 m .4602 .61139 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .51406 .62348 L .51373 .61888 L p
1 g
F P
s
P
p
.002 w
.51373 .61888 m .48627 .61888 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .51373 .61888 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.45655 .42547 m .4144 .45527 L .39349 .42689 L p
1 g
F P
s
P
p
.002 w
.39349 .42689 m .441 .39283 L .45655 .42547 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .43967 .59304 L .44118 .58899 L p
1 g
F P
s
P
p
.002 w
.44118 .58899 m .42629 .57021 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .55882 .58899 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.55882 .58899 m .57371 .57021 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.50917 .52028 m .49043 .53297 L .46381 .50935 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42818 .56663 L .43005 .56308 L p
1 g
F P
s
P
p
.002 w
.43005 .56308 m .42332 .5421 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .56995 .56308 L .57182 .56663 L p
1 g
F P
s
P
p
.002 w
.56995 .56308 m .57668 .5421 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.5898 .47907 m .55842 .47437 L .56043 .43774 L p
1 g
F P
s
P
p
.002 w
.56043 .43774 m .60091 .44421 L .5898 .47907 L p
1 g
F P
s
P
p
.002 w
.60091 .44421 m .56043 .43774 L .56056 .40083 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .45922 .61582 L .4602 .61139 L p
1 g
F P
s
P
p
.002 w
.4602 .61139 m .43816 .59712 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .54078 .61582 L .5398 .61139 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .5398 .61139 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.5398 .61139 m .56184 .59712 L .56033 .59304 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .4856 .62811 L .48594 .62348 L p
1 g
F P
s
P
p
.002 w
.48594 .62348 m .45922 .61582 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .5144 .62811 L .51406 .62348 L p
1 g
F P
s
P
p
.002 w
.51406 .62348 m .48594 .62348 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .51406 .62348 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .42537 .53911 L .42742 .53614 L p
1 g
F P
s
P
p
.002 w
.42742 .53614 m .42888 .51537 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .57258 .53614 L .57463 .53911 L p
1 g
F P
s
P
p
.002 w
.57258 .53614 m .57112 .51537 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.49866 .37123 m .441 .39283 L .42747 .36178 L p
1 g
F P
s
P
p
.002 w
.42747 .36178 m .49 .33828 L .49866 .37123 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .43089 .51299 L .43287 .51061 L p
1 g
F P
s
P
p
.002 w
.43287 .51061 m .44166 .49233 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.55834 .49233 m .56713 .51061 L .56911 .51299 L p
1 g
F P
s
P
p
.002 w
.55463 .50932 m .53145 .51207 L .5242 .4783 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .43816 .59712 L .43967 .59304 L p
1 g
F P
s
P
p
.002 w
.43967 .59304 m .4244 .5738 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .56033 .59304 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.56033 .59304 m .5756 .5738 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42629 .57021 L .42818 .56663 L p
1 g
F P
s
P
p
.002 w
.42818 .56663 m .42125 .54511 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57182 .56663 L .57371 .57021 L p
1 g
F P
s
P
p
.002 w
.57182 .56663 m .57875 .54511 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.5588 .36509 m .49866 .37123 L .49 .33828 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .45824 .62027 L .45922 .61582 L p
1 g
F P
s
P
p
.002 w
.45922 .61582 m .43664 .60122 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .54176 .62027 L .54078 .61582 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .54078 .61582 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.54078 .61582 m .56336 .60122 L .56184 .59712 L p
1 g
F P
s
P
p
.002 w
.45726 .62475 m .48526 .63276 L .4856 .62811 L p
1 g
F P
s
P
p
.002 w
.4856 .62811 m .45824 .62027 L .45726 .62475 L p
1 g
F P
s
P
p
.002 w
.48526 .63276 m .51474 .63276 L .5144 .62811 L p
1 g
F P
s
P
p
.002 w
.5144 .62811 m .4856 .62811 L .48526 .63276 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .5144 .62811 L .51474 .63276 L p
1 g
F P
s
P
p
.002 w
.53145 .51207 m .50917 .52028 L .49132 .49047 L p
1 g
F P
s
P
p
.002 w
.46381 .50935 m .49132 .49047 L .50917 .52028 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .42332 .5421 L .42537 .53911 L p
1 g
F P
s
P
p
.002 w
.42537 .53911 m .42687 .51778 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .57463 .53911 L .57668 .5421 L p
1 g
F P
s
P
p
.002 w
.57463 .53911 m .57313 .51778 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.47354 .45845 m .43814 .48312 L .4144 .45527 L p
1 g
F P
s
P
p
.002 w
.4144 .45527 m .45655 .42547 L .47354 .45845 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .42888 .51537 L .43089 .51299 L p
1 g
F P
s
P
p
.002 w
.43089 .51299 m .43993 .49417 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .56911 .51299 L .57112 .51537 L p
1 g
F P
s
P
p
.002 w
.56911 .51299 m .56007 .49417 L .55834 .49233 L p
1 g
F P
s
P
p
.002 w
.49866 .37123 m .5588 .36509 L .56056 .40083 L p
1 g
F P
s
P
p
.002 w
.49132 .49047 m .5242 .4783 L .53145 .51207 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .43664 .60122 L .43816 .59712 L p
1 g
F P
s
P
p
.002 w
.43816 .59712 m .42249 .57742 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .56184 .59712 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.56184 .59712 m .57751 .57742 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.51474 .63276 m .54274 .62475 L .54176 .62027 L p
1 g
F P
s
P
p
.002 w
.43357 .60949 m .45726 .62475 L .45824 .62027 L p
1 g
F P
s
P
p
.002 w
.45824 .62027 m .43511 .60534 L .43357 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .54176 .62027 L .54274 .62475 L p
1 g
F P
s
P
p
.002 w
.54176 .62027 m .56489 .60534 L .56336 .60122 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .4244 .5738 L .42629 .57021 L p
1 g
F P
s
P
p
.002 w
.42629 .57021 m .41917 .54814 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57371 .57021 L .5756 .5738 L p
1 g
F P
s
P
p
.002 w
.57371 .57021 m .58083 .54814 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .43993 .49417 L .44166 .49233 L p
1 g
F P
s
P
p
.002 w
.44166 .49233 m .45698 .47747 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.54302 .47747 m .55834 .49233 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .42125 .54511 L .42332 .5421 L p
1 g
F P
s
P
p
.002 w
.42332 .5421 m .42484 .5202 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .57668 .5421 L .57875 .54511 L p
1 g
F P
s
P
p
.002 w
.57668 .5421 m .57516 .5202 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .42687 .51778 L .42888 .51537 L p
1 g
F P
s
P
p
.002 w
.42888 .51537 m .43817 .49603 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .57112 .51537 L .57313 .51778 L p
1 g
F P
s
P
p
.002 w
.57112 .51537 m .56183 .49603 L .56007 .49417 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .43511 .60534 L .43664 .60122 L p
1 g
F P
s
P
p
.002 w
.43664 .60122 m .42057 .58106 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .56336 .60122 L .56489 .60534 L p
1 g
F P
s
P
p
.002 w
.56336 .60122 m .57943 .58106 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.51611 .44264 m .56043 .43774 L .55842 .47437 L p
1 g
F P
s
P
p
.002 w
.54274 .62475 m .56643 .60949 L .56489 .60534 L p
1 g
F P
s
P
p
.004 w
.55671 .61575 m
.5598 .62582 L
s
P
p
.002 w
.50748 .40647 m .45655 .42547 L .441 .39283 L p
1 g
F P
s
P
p
.002 w
.441 .39283 m .49866 .37123 L .50748 .40647 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .42249 .57742 L .4244 .5738 L p
1 g
F P
s
P
p
.002 w
.4244 .5738 m .41707 .5512 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .5756 .5738 L .57751 .57742 L p
1 g
F P
s
P
p
.002 w
.5756 .5738 m .58293 .5512 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.50748 .40647 m .56056 .40083 L .56043 .43774 L p
1 g
F P
s
P
p
.002 w
.56056 .40083 m .50748 .40647 L .49866 .37123 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .41917 .54814 L .42125 .54511 L p
1 g
F P
s
P
p
.002 w
.42125 .54511 m .42279 .52264 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .57875 .54511 L .58083 .54814 L p
1 g
F P
s
P
p
.002 w
.57875 .54511 m .57721 .52264 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .43817 .49603 L .43993 .49417 L p
1 g
F P
s
P
p
.002 w
.43993 .49417 m .45569 .47888 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .56007 .49417 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.56007 .49417 m .54431 .47888 L .54302 .47747 L p
1 g
F P
s
P
p
.002 w
.56043 .43774 m .51611 .44264 L .50748 .40647 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .42484 .5202 L .42687 .51778 L p
1 g
F P
s
P
p
.002 w
.42687 .51778 m .43641 .4979 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .57313 .51778 L .57516 .5202 L p
1 g
F P
s
P
p
.002 w
.57313 .51778 m .56359 .4979 L .56183 .49603 L p
1 g
F P
s
P
p
.002 w
.41669 .58841 m .43357 .60949 L .43511 .60534 L p
1 g
F P
s
P
p
.002 w
.43511 .60534 m .41863 .58473 L .41669 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .56489 .60534 L .56643 .60949 L p
1 g
F P
s
P
p
.002 w
.56489 .60534 m .58137 .58473 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .45569 .47888 L .45698 .47747 L p
1 g
F P
s
P
p
.002 w
.45698 .47747 m .47718 .46778 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.52282 .46778 m .54302 .47747 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .42057 .58106 L .42249 .57742 L p
1 g
F P
s
P
p
.002 w
.42249 .57742 m .41496 .55427 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .57751 .57742 L .57943 .58106 L p
1 g
F P
s
P
p
.002 w
.57751 .57742 m .58504 .55427 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .41707 .5512 L .41917 .54814 L p
1 g
F P
s
P
p
.002 w
.41917 .54814 m .42074 .5251 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .58083 .54814 L .58293 .5512 L p
1 g
F P
s
P
p
.002 w
.58083 .54814 m .57926 .5251 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.51611 .44264 m .47354 .45845 L .45655 .42547 L p
1 g
F P
s
P
p
.002 w
.45655 .42547 m .50748 .40647 L .51611 .44264 L p
1 g
F P
s
P
p
.002 w
.56643 .60949 m .58331 .58841 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .43641 .4979 L .43817 .49603 L p
1 g
F P
s
P
p
.002 w
.43817 .49603 m .45439 .4803 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .56183 .49603 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.56183 .49603 m .54561 .4803 L .54431 .47888 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .42279 .52264 L .42484 .5202 L p
1 g
F P
s
P
p
.002 w
.42484 .5202 m .43463 .49978 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .57516 .5202 L .57721 .52264 L p
1 g
F P
s
P
p
.002 w
.57516 .5202 m .56537 .49978 L .56359 .4979 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .4765 .4689 L .47718 .46778 L p
1 g
F P
s
P
p
.002 w
.47718 .46778 m .5 .46442 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.54431 .47888 m .5235 .4689 L .52282 .46778 L p
1 g
F P
s
P
p
.002 w
.5 .46442 m .52282 .46778 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41863 .58473 L .42057 .58106 L p
1 g
F P
s
P
p
.002 w
.42057 .58106 m .41283 .55736 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .57943 .58106 L .58137 .58473 L p
1 g
F P
s
P
p
.002 w
.57943 .58106 m .58717 .55736 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .45439 .4803 L .45569 .47888 L p
1 g
F P
s
P
p
.002 w
.45569 .47888 m .4765 .4689 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .54431 .47888 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.5235 .4689 m .5 .46544 L .5 .46442 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .41496 .55427 L .41707 .5512 L p
1 g
F P
s
P
p
.002 w
.41707 .5512 m .41866 .52757 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .58293 .5512 L .58504 .55427 L p
1 g
F P
s
P
p
.002 w
.58293 .5512 m .58134 .52757 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .43463 .49978 L .43641 .4979 L p
1 g
F P
s
P
p
.002 w
.43641 .4979 m .45309 .48173 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .56359 .4979 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.56359 .4979 m .54691 .48173 L .54561 .4803 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .42074 .5251 L .42279 .52264 L p
1 g
F P
s
P
p
.002 w
.42279 .52264 m .43284 .50168 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .57721 .52264 L .57926 .5251 L p
1 g
F P
s
P
p
.002 w
.57721 .52264 m .56716 .50168 L .56537 .49978 L p
1 g
F P
s
P
p
.002 w
.40854 .56361 m .41669 .58841 L .41863 .58473 L p
1 g
F P
s
P
p
.002 w
.41863 .58473 m .41069 .56047 L .40854 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58137 .58473 L .58331 .58841 L p
1 g
F P
s
P
p
.002 w
.58137 .58473 m .58931 .56047 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .47581 .47003 L .4765 .4689 L p
1 g
F P
s
P
p
.002 w
.4765 .4689 m .5 .46544 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.54561 .4803 m .52419 .47003 L .5235 .4689 L p
1 g
F P
s
P
p
.002 w
.5 .46544 m .5235 .4689 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .45309 .48173 L .45439 .4803 L p
1 g
F P
s
P
p
.002 w
.45439 .4803 m .47581 .47003 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .54561 .4803 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .41283 .55736 L .41496 .55427 L p
1 g
F P
s
P
p
.002 w
.41496 .55427 m .41657 .53007 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .58504 .55427 L .58717 .55736 L p
1 g
F P
s
P
p
.002 w
.58504 .55427 m .58343 .53007 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.52419 .47003 m .5 .46647 L .5 .46544 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .43284 .50168 L .43463 .49978 L p
1 g
F P
s
P
p
.002 w
.43463 .49978 m .45177 .48317 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .56537 .49978 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.56537 .49978 m .54823 .48317 L .54691 .48173 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .41866 .52757 L .42074 .5251 L p
1 g
F P
s
P
p
.002 w
.42074 .5251 m .43104 .50359 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .57926 .5251 L .58134 .52757 L p
1 g
F P
s
P
p
.002 w
.57926 .5251 m .56896 .50359 L .56716 .50168 L p
1 g
F P
s
P
p
.002 w
.58331 .58841 m .59146 .56361 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .47511 .47117 L .47581 .47003 L p
1 g
F P
s
P
p
.002 w
.47581 .47003 m .5 .46647 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.54691 .48173 m .52489 .47117 L .52419 .47003 L p
1 g
F P
s
P
p
.002 w
.5 .46647 m .52419 .47003 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .45177 .48317 L .45309 .48173 L p
1 g
F P
s
P
p
.002 w
.45309 .48173 m .47511 .47117 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .54691 .48173 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .41069 .56047 L .41283 .55736 L p
1 g
F P
s
P
p
.002 w
.41283 .55736 m .41447 .53258 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .58717 .55736 L .58931 .56047 L p
1 g
F P
s
P
p
.002 w
.58717 .55736 m .58553 .53258 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.52489 .47117 m .5 .4675 L .5 .46647 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .41657 .53007 L .41866 .52757 L p
1 g
F P
s
P
p
.002 w
.41866 .52757 m .42922 .50552 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .58134 .52757 L .58343 .53007 L p
1 g
F P
s
P
p
.002 w
.58134 .52757 m .57078 .50552 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .43104 .50359 L .43284 .50168 L p
1 g
F P
s
P
p
.002 w
.43284 .50168 m .45044 .48462 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .56716 .50168 L .56896 .50359 L p
1 g
F P
s
P
p
.002 w
.56716 .50168 m .54956 .48462 L .54823 .48317 L p
1 g
F P
s
P
p
.002 w
.41022 .53765 m .40854 .56361 L .41069 .56047 L p
1 g
F P
s
P
p
.002 w
.41069 .56047 m .41235 .5351 L .41022 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .58931 .56047 L .59146 .56361 L p
1 g
F P
s
P
p
.002 w
.58931 .56047 m .58765 .5351 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .47441 .47232 L .47511 .47117 L p
1 g
F P
s
P
p
.002 w
.47511 .47117 m .5 .4675 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.54823 .48317 m .52559 .47232 L .52489 .47117 L p
1 g
F P
s
P
p
.002 w
.5 .4675 m .52489 .47117 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .45044 .48462 L .45177 .48317 L p
1 g
F P
s
P
p
.002 w
.45177 .48317 m .47441 .47232 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .54823 .48317 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.52559 .47232 m .5 .46855 L .5 .4675 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .41447 .53258 L .41657 .53007 L p
1 g
F P
s
P
p
.002 w
.41657 .53007 m .42739 .50746 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .58343 .53007 L .58553 .53258 L p
1 g
F P
s
P
p
.002 w
.58343 .53007 m .57261 .50746 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .42922 .50552 L .43104 .50359 L p
1 g
F P
s
P
p
.002 w
.43104 .50359 m .4491 .48608 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .56896 .50359 L .57078 .50552 L p
1 g
F P
s
P
p
.002 w
.56896 .50359 m .5509 .48608 L .54956 .48462 L p
1 g
F P
s
P
p
.002 w
.59146 .56361 m .58978 .53765 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .4737 .47348 L .47441 .47232 L p
1 g
F P
s
P
p
.002 w
.47441 .47232 m .5 .46855 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.54956 .48462 m .5263 .47348 L .52559 .47232 L p
1 g
F P
s
P
p
.002 w
.5 .46855 m .52559 .47232 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .4491 .48608 L .45044 .48462 L p
1 g
F P
s
P
p
.002 w
.45044 .48462 m .4737 .47348 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .54956 .48462 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5263 .47348 m .5 .4696 L .5 .46855 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .41235 .5351 L .41447 .53258 L p
1 g
F P
s
P
p
.002 w
.41447 .53258 m .42554 .50942 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .58553 .53258 L .58765 .5351 L p
1 g
F P
s
P
p
.002 w
.58553 .53258 m .57446 .50942 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .42739 .50746 L .42922 .50552 L p
1 g
F P
s
P
p
.002 w
.42922 .50552 m .44775 .48756 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .57078 .50552 L .57261 .50746 L p
1 g
F P
s
P
p
.002 w
.57078 .50552 m .55225 .48756 L .5509 .48608 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .47299 .47464 L .4737 .47348 L p
1 g
F P
s
P
p
.002 w
.4737 .47348 m .5 .4696 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.5509 .48608 m .52701 .47464 L .5263 .47348 L p
1 g
F P
s
P
p
.002 w
.5 .4696 m .5263 .47348 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .44775 .48756 L .4491 .48608 L p
1 g
F P
s
P
p
.002 w
.4491 .48608 m .47299 .47464 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5509 .48608 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.42181 .51337 m .41022 .53765 L .41235 .5351 L p
1 g
F P
s
P
p
.002 w
.41235 .5351 m .42368 .51139 L .42181 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .58765 .5351 L .58978 .53765 L p
1 g
F P
s
P
p
.002 w
.58765 .5351 m .57632 .51139 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.52701 .47464 m .5 .47066 L .5 .4696 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .42554 .50942 L .42739 .50746 L p
1 g
F P
s
P
p
.002 w
.42739 .50746 m .44639 .48904 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .57261 .50746 L .57446 .50942 L p
1 g
F P
s
P
p
.002 w
.57261 .50746 m .55361 .48904 L .55225 .48756 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .44639 .48904 L .44775 .48756 L p
1 g
F P
s
P
p
.002 w
.44775 .48756 m .47227 .47582 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .55225 .48756 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.55225 .48756 m .52773 .47582 L .52701 .47464 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .47227 .47582 L .47299 .47464 L p
1 g
F P
s
P
p
.002 w
.47299 .47464 m .5 .47066 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.5 .47066 m .52701 .47464 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.58978 .53765 m .57819 .51337 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .42368 .51139 L .42554 .50942 L p
1 g
F P
s
P
p
.002 w
.42554 .50942 m .44502 .49054 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .57446 .50942 L .57632 .51139 L p
1 g
F P
s
P
p
.002 w
.57446 .50942 m .55498 .49054 L .55361 .48904 L p
1 g
F P
s
P
p
.002 w
.52773 .47582 m .5 .47173 L .5 .47066 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .44502 .49054 L .44639 .48904 L p
1 g
F P
s
P
p
.002 w
.44639 .48904 m .47154 .477 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .55361 .48904 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.55361 .48904 m .52846 .477 L .52773 .47582 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .47154 .477 L .47227 .47582 L p
1 g
F P
s
P
p
.002 w
.47227 .47582 m .5 .47173 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.5 .47173 m .52773 .47582 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.44224 .49357 m .42181 .51337 L .42368 .51139 L p
1 g
F P
s
P
p
.002 w
.42368 .51139 m .44363 .49205 L .44224 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .57632 .51139 L .57819 .51337 L p
1 g
F P
s
P
p
.002 w
.57632 .51139 m .55637 .49205 L .55498 .49054 L p
1 g
F P
s
P
p
.002 w
.52846 .477 m .5 .47281 L .5 .47173 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .44363 .49205 L .44502 .49054 L p
1 g
F P
s
P
p
.002 w
.44502 .49054 m .47081 .4782 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .55498 .49054 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.55498 .49054 m .52919 .4782 L .52846 .477 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .47081 .4782 L .47154 .477 L p
1 g
F P
s
P
p
.002 w
.47154 .477 m .5 .47281 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.5 .47281 m .52846 .477 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.57819 .51337 m .55776 .49357 L .55637 .49205 L p
1 g
F P
s
P
p
.002 w
.52919 .4782 m .5 .4739 L .5 .47281 L p
1 g
F P
s
P
p
.002 w
.46933 .48061 m .44224 .49357 L .44363 .49205 L p
1 g
F P
s
P
p
.002 w
.44363 .49205 m .47007 .4794 L .46933 .48061 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .55637 .49205 L .55776 .49357 L p
1 g
F P
s
P
p
.002 w
.55637 .49205 m .52993 .4794 L .52919 .4782 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .47007 .4794 L .47081 .4782 L p
1 g
F P
s
P
p
.002 w
.47081 .4782 m .5 .4739 L .5 .475 L p
1 g
F P
s
P
p
.002 w
.5 .4739 m .52919 .4782 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.52993 .4794 m .5 .475 L .5 .4739 L p
1 g
F P
s
P
p
.002 w
.55776 .49357 m .53067 .48061 L .52993 .4794 L p
1 g
F P
s
P
p
.002 w
.5 .47611 m .46933 .48061 L .47007 .4794 L p
1 g
F P
s
P
p
.002 w
.47007 .4794 m .5 .475 L .5 .47611 L p
1 g
F P
s
P
p
.002 w
.5 .475 m .52993 .4794 L .53067 .48061 L p
1 g
F P
s
P
p
.002 w
.53067 .48061 m .5 .47611 L .5 .475 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .70495 .36878 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .56732 .65039 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 268},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0,
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[TextData[{
  StyleBox[
  "\tThis animation finally shows the complete motion through one precession \
period, which is just the extension of what we saw in the previous animation. \
 The symmetry axis moves ahead the vector ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " in its \"orbit\", and as it does so, the star changes its orientation.  \
At its most extreme, this means that at around time t = 0.2 when the symmetry \
axis vector is on the opposite side of its cone from ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", the orientation of the star has changed so that ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " is pointed at its maximum upward angle.  After this, the symmetry axis \
begins to \"catch up\" with the emission beam vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " moves back down relative to our point of view.  Basically, over the \
entire motion, we see ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " climbing from its low, original position, to a high maximum when the \
symmetry axis is at the opposite end of the cone, and then falling back down \
(from our viewpoint) to its original location at the end of the precession \
period.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Strobe function"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "\tWe've just seen the motion of the entire star, as well as the motion of \
the symmetry axis and the emission beam vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", due to free precession.  We are also concerned with how those vectors \
are oriented when the beam points in our general direction.  Our primary \
concern in this is with pulsars, and we can only \"see\" pulsars when the \
radio beam comes across our point of view.  If we're interested in how the \
pulsar is oriented at that time, then all we need to do is solve for the time \
when the beam vector,  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", crosses our line of sight.  For each such successive time, we display \
the star, the emission beam, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", the symmetry axis of the star (",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox["), and the precession cone that ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  "'s motion describes.  \n\tWe are essentially \"strobing\" when the beam \
points toward us, to see how the star's orientation changes over time because \
of free precession.  Below is the function we have developed to plot the star \
at the times when the emission beam ( ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ") crosses our line our sight.  First, given an inertial reference frame \
with its origin at the center of the star, and the observer lying in the xz \
plane, we simply solve numerically for the time that the beam lies in the xz \
plane. Our method was inspired by Nelson, Finn, and Wasserman, 1990, ApJ, \
348, 226, \"Trompe L'Oeil Binary Pulsars,\" but our variables and equations \
of motion were expanded from Shaham's treatment.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"PlotIntersect[t1_, t2_, tGuess_] := Module[\n\t{transits = {}, pastTransit, \
tIndex, t, newTransit}, \n\n\tpastTransit = tGuess;\n\tincPeriod = tGuess;\n\t\
For[tIndex = t1, tIndex <= t2, tIndex = tIndex + tGuess,\n\t\tnewRoot = \n\t\t\
\tFindRoot[((Cos[beta] Cos[alpha]) * (Cos[omegap t] Sin[omega t] - \n\t\t\t\t \
Cos[theta] Sin[omegap t] Cos[omega t]) + \n\t\t\t\t(Sin[beta] Cos[alpha]) * \
(Sin[omegap t] Sin[omega t] + \n\t\t\t\t Cos[theta] Cos[omegap t] Cos[omega \
t]) + \n\t\t\t\t(Sin[alpha]) * (Sin[theta] Cos[omega t])) == 0, \n\t\t\t\t{t, \
tIndex}];\n\t\tnewTransit = newRoot[[1,2]];\n\t\tpastTransit = newTransit;\n\t\
\tposVector = 1.5*arbVector[newTransit, alpha, beta, omegap, omega, theta];\n\
\t\tsymVector = 1.5*arbVector[newTransit, 0, Pi/2, omegap, omega, theta];\n\t \
   star = ParametricPlot3D[\n\t   \t\t\t\tarbVector[newTransit, alphaLoop, \
betaLoop, omegap, omega, theta], \n  \t\t\t\t\t{betaLoop, -Pi/2, Pi/2}, \
{alphaLoop, 0, 2*Pi}, \n\t\t\t\t\tCompiled -> False, \n\t\t\t\t\tShading -> \
False, \n\t\t\t\t\tDisplayFunction -> Identity]; \n\t\tShow[Graphics3D[\n\t\t\
\t\t   {Line[{{0,0,0}, posVector}], \n\t\t\t\t\tLine[{{0,0,0}, symVector}], \n\
\t\t\t\t\tText[FontForm[\"n\", {\"Courier-Bold\", 14}], \n\t\t\t\t\t\t\t\t\
posVector], \n\t\t\t\t\tText[FontForm[\"k\", {\"Courier-Bold\", 14}],\n\t\t\t\
\t\t\t\t\tsymVector]}],\n\t\t\t\tstar, \n\t\t\t\tcone,\n\t\t\t\tPlotLabel -> \
tIndex,\n\t\t\t\tBoxed -> False,\n\t\t\t\tPlotLabel -> newTransit,\n\t\t\t\t\
Shading -> False,\n\t\t\t\tViewPoint -> {4, 0, 4}, \n\t\t\t\tPlotRange -> \
{{-1.7,1.7},{-1.7,1.7},{-1.7, 1.7}}, \n\t\t\t\tDisplayFunction -> \
$DisplayFunction]]];"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["PlotIntersect[0, 0.7, 0.07];"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.45089 .6762 m .44783 .63877 L .49325 .63044 L p
1 g
F P
s
P
p
.002 w
.49325 .63044 m .50536 .66613 L .45089 .6762 L p
1 g
F P
s
P
p
.002 w
.48134 .5943 m .49325 .63044 L .44783 .63877 L p
1 g
F P
s
P
p
.002 w
.50536 .66613 m .49325 .63044 L .53506 .60993 L p
1 g
F P
s
P
p
.002 w
.49325 .63044 m .48134 .5943 L .51373 .57839 L p
1 g
F P
s
P
p
.002 w
.51373 .57839 m .53506 .60993 L .49325 .63044 L p
1 g
F P
s
P
p
.002 w
.44783 .63877 m .44613 .60071 L .48134 .5943 L p
1 g
F P
s
P
p
.002 w
.46989 .55855 m .48134 .5943 L .44613 .60071 L p
1 g
F P
s
P
p
.002 w
.48134 .5943 m .46989 .55855 L .49201 .54768 L p
1 g
F P
s
P
p
.002 w
.49201 .54768 m .51373 .57839 L .48134 .5943 L p
1 g
F P
s
P
p
.002 w
.53506 .60993 m .55551 .64155 L .50536 .66613 L p
1 g
F P
s
P
p
.002 w
.55551 .64155 m .53506 .60993 L .56893 .57934 L p
1 g
F P
s
P
p
.002 w
.53506 .60993 m .51373 .57839 L .53993 .55465 L p
1 g
F P
s
P
p
.002 w
.53993 .55465 m .56893 .57934 L .53506 .60993 L p
1 g
F P
s
P
p
.002 w
.51373 .57839 m .49201 .54768 L .50987 .53144 L p
1 g
F P
s
P
p
.002 w
.50987 .53144 m .53993 .55465 L .51373 .57839 L p
1 g
F P
s
P
p
.002 w
.45524 .7121 m .45089 .6762 L .50536 .66613 L p
1 g
F P
s
P
p
.002 w
.50536 .66613 m .51737 .70055 L .45524 .7121 L p
1 g
F P
s
P
p
.002 w
.51737 .70055 m .50536 .66613 L .55551 .64155 L p
1 g
F P
s
P
p
.002 w
.40348 .63402 m .41179 .59694 L .44613 .60071 L p
1 g
F P
s
P
p
.002 w
.44613 .60071 m .44783 .63877 L .40348 .63402 L p
1 g
F P
s
P
p
.002 w
.44583 .56291 m .44613 .60071 L .41179 .59694 L p
1 g
F P
s
P
p
.002 w
.44613 .60071 m .44583 .56291 L .46989 .55855 L p
1 g
F P
s
P
p
.002 w
.39766 .67063 m .40348 .63402 L .44783 .63877 L p
1 g
F P
s
P
p
.002 w
.44783 .63877 m .45089 .6762 L .39766 .67063 L p
1 g
F P
s
P
p
.002 w
.45917 .52405 m .46989 .55855 L .44583 .56291 L p
1 g
F P
s
P
p
.002 w
.46989 .55855 m .45917 .52405 L .47042 .51852 L p
1 g
F P
s
P
p
.002 w
.47042 .51852 m .49201 .54768 L .46989 .55855 L p
1 g
F P
s
P
p
.002 w
.55551 .64155 m .57459 .67252 L .51737 .70055 L p
1 g
F P
s
P
p
.002 w
.57459 .67252 m .55551 .64155 L .5962 .60494 L p
1 g
F P
s
P
p
.002 w
.56893 .57934 m .5962 .60494 L .55551 .64155 L p
1 g
F P
s
P
p
.002 w
.49201 .54768 m .47042 .51852 L .47948 .51025 L p
1 g
F P
s
P
p
.002 w
.47948 .51025 m .50987 .53144 L .49201 .54768 L p
1 g
F P
s
P
p
.002 w
.56893 .57934 m .53993 .55465 L .55715 .52552 L p
1 g
F P
s
P
p
.002 w
.53993 .55465 m .50987 .53144 L .52157 .51152 L p
1 g
F P
s
P
p
.002 w
.52157 .51152 m .55715 .52552 L .53993 .55465 L p
1 g
F P
s
P
p
.002 w
.41179 .59694 m .4224 .56027 L .44583 .56291 L p
1 g
F P
s
P
p
.002 w
.44694 .52625 m .44583 .56291 L .4224 .56027 L p
1 g
F P
s
P
p
.002 w
.44583 .56291 m .44694 .52625 L .45917 .52405 L p
1 g
F P
s
P
p
.002 w
.5962 .60494 m .56893 .57934 L .5913 .5418 L p
1 g
F P
s
P
p
.002 w
.55715 .52552 m .5913 .5418 L .56893 .57934 L p
1 g
F P
s
P
p
.002 w
.50987 .53144 m .47948 .51025 L .48538 .50012 L p
1 g
F P
s
P
p
.002 w
.48538 .50012 m .52157 .51152 L .50987 .53144 L p
1 g
F P
s
P
p
.002 w
.39449 .7059 m .39766 .67063 L .45089 .6762 L p
1 g
F P
s
P
p
.002 w
.45089 .6762 m .45524 .7121 L .39449 .7059 L p
1 g
F P
s
P
p
.002 w
.36483 .61656 m .38193 .58331 L .41179 .59694 L p
1 g
F P
s
P
p
.002 w
.41179 .59694 m .40348 .63402 L .36483 .61656 L p
1 g
F P
s
P
p
.002 w
.4224 .56027 m .41179 .59694 L .38193 .58331 L p
1 g
F P
s
P
p
.002 w
.46079 .74562 m .45524 .7121 L .51737 .70055 L p
1 g
F P
s
P
p
.002 w
.51737 .70055 m .529 .73287 L .46079 .74562 L p
1 g
F P
s
P
p
.002 w
.529 .73287 m .51737 .70055 L .57459 .67252 L p
1 g
F P
s
P
p
.002 w
.38193 .58331 m .40207 .55089 L .4224 .56027 L p
1 g
F P
s
P
p
.002 w
.43505 .52488 m .4224 .56027 L .40207 .55089 L p
1 g
F P
s
P
p
.002 w
.4224 .56027 m .43505 .52488 L .44694 .52625 L p
1 g
F P
s
P
p
.002 w
.57459 .67252 m .59184 .70211 L .529 .73287 L p
1 g
F P
s
P
p
.002 w
.59184 .70211 m .57459 .67252 L .62109 .63083 L p
1 g
F P
s
P
p
.002 w
.5962 .60494 m .62109 .63083 L .57459 .67252 L p
1 g
F P
s
P
p
.002 w
.62109 .63083 m .5962 .60494 L .62319 .55997 L p
1 g
F P
s
P
p
.002 w
.5913 .5418 m .62319 .55997 L .5962 .60494 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .45917 .52405 L .44694 .52625 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47042 .51852 L .45917 .52405 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47948 .51025 L .47042 .51852 L closepath p
1 g
F P
s
P
p
.002 w
.35119 .64985 m .36483 .61656 L .40348 .63402 L p
1 g
F P
s
P
p
.002 w
.40348 .63402 m .39766 .67063 L .35119 .64985 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .44694 .52625 L .43505 .52488 L closepath p
1 g
F P
s
P
p
.002 w
.55715 .52552 m .52157 .51152 L .52581 .49004 L p
1 g
F P
s
P
p
.002 w
.52157 .51152 m .48538 .50012 L .48748 .48921 L p
1 g
F P
s
P
p
.002 w
.48748 .48921 m .52581 .49004 L .52157 .51152 L p
1 g
F P
s
P
p
.002 w
.5913 .5418 m .55715 .52552 L .56351 .49405 L p
1 g
F P
s
P
p
.002 w
.52581 .49004 m .56351 .49405 L .55715 .52552 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .48538 .50012 L .47948 .51025 L closepath p
1 g
F P
s
P
p
.002 w
.40207 .55089 m .42475 .52008 L .43505 .52488 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .43505 .52488 L .42475 .52008 L closepath p
1 g
F P
s
P
p
.002 w
.39407 .73897 m .39449 .7059 L .45524 .7121 L p
1 g
F P
s
P
p
.002 w
.45524 .7121 m .46079 .74562 L .39407 .73897 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .48748 .48921 L .48538 .50012 L closepath p
1 g
F P
s
P
p
.002 w
.62319 .55997 m .5913 .5418 L .59969 .50116 L p
1 g
F P
s
P
p
.002 w
.56351 .49405 m .59969 .50116 L .5913 .5418 L p
1 g
F P
s
P
p
.002 w
.35978 .56116 m .38704 .53572 L .40207 .55089 L p
1 g
F P
s
P
p
.002 w
.40207 .55089 m .38193 .58331 L .35978 .56116 L p
1 g
F P
s
P
p
.002 w
.42475 .52008 m .40207 .55089 L .38704 .53572 L p
1 g
F P
s
P
p
.002 w
.34138 .68237 m .35119 .64985 L .39766 .67063 L p
1 g
F P
s
P
p
.002 w
.39766 .67063 m .39449 .7059 L .34138 .68237 L p
1 g
F P
s
P
p
.002 w
.38704 .53572 m .41718 .51235 L .42475 .52008 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .42475 .52008 L .41718 .51235 L closepath p
1 g
F P
s
P
p
.002 w
.33606 .58806 m .35978 .56116 L .38193 .58331 L p
1 g
F P
s
P
p
.002 w
.38193 .58331 m .36483 .61656 L .33606 .58806 L p
1 g
F P
s
P
p
.002 w
.62109 .63083 m .64298 .65641 L .59184 .70211 L p
1 g
F P
s
P
p
.002 w
.64298 .65641 m .62109 .63083 L .65204 .57961 L p
1 g
F P
s
P
p
.002 w
.62319 .55997 m .65204 .57961 L .62109 .63083 L p
1 g
F P
s
P
p
.002 w
.52581 .49004 m .48748 .48921 L .48554 .47871 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .48554 .47871 L .48748 .48921 L closepath p
1 g
F P
s
P
p
.002 w
.56351 .49405 m .52581 .49004 L .52208 .46928 L p
1 g
F P
s
P
p
.002 w
.48554 .47871 m .52208 .46928 L .52581 .49004 L p
1 g
F P
s
P
p
.002 w
.46743 .77593 m .46079 .74562 L .529 .73287 L p
1 g
F P
s
P
p
.002 w
.529 .73287 m .53998 .76229 L .46743 .77593 L p
1 g
F P
s
P
p
.002 w
.53998 .76229 m .529 .73287 L .59184 .70211 L p
1 g
F P
s
P
p
.002 w
.59184 .70211 m .60683 .72958 L .53998 .76229 L p
1 g
F P
s
P
p
.002 w
.60683 .72958 m .59184 .70211 L .64298 .65641 L p
1 g
F P
s
P
p
.002 w
.37899 .51635 m .41315 .50252 L .41718 .51235 L p
1 g
F P
s
P
p
.002 w
.41718 .51235 m .38704 .53572 L .37899 .51635 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41718 .51235 L .41315 .50252 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41313 .49164 L .41713 .48091 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41315 .50252 L .41313 .49164 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47974 .46974 L .48554 .47871 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47071 .46329 L .47974 .46974 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41713 .48091 L .42472 .47148 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .45942 .46008 L .47071 .46329 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .4471 .46047 L .45942 .46008 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .43509 .46441 L .4471 .46047 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .42472 .47148 L .43509 .46441 L closepath p
1 g
F P
s
P
p
.002 w
.65204 .57961 m .62319 .55997 L .63347 .51122 L p
1 g
F P
s
P
p
.002 w
.59969 .50116 m .63347 .51122 L .62319 .55997 L p
1 g
F P
s
P
p
.002 w
.59969 .50116 m .56351 .49405 L .5582 .46356 L p
1 g
F P
s
P
p
.002 w
.52208 .46928 m .5582 .46356 L .56351 .49405 L p
1 g
F P
s
P
p
.002 w
.52208 .46928 m .48554 .47871 L .47974 .46974 L p
1 g
F P
s
P
p
.002 w
.3165 .61579 m .33606 .58806 L .36483 .61656 L p
1 g
F P
s
P
p
.002 w
.36483 .61656 m .35119 .64985 L .3165 .61579 L p
1 g
F P
s
P
p
.002 w
.34782 .53278 m .37899 .51635 L .38704 .53572 L p
1 g
F P
s
P
p
.002 w
.38704 .53572 m .35978 .56116 L .34782 .53278 L p
1 g
F P
s
P
p
.002 w
.39645 .769 m .39407 .73897 L .46079 .74562 L p
1 g
F P
s
P
p
.002 w
.46079 .74562 m .46743 .77593 L .39645 .769 L p
1 g
F P
s
P
p
.002 w
.37885 .49485 m .41313 .49164 L .41315 .50252 L p
1 g
F P
s
P
p
.002 w
.41315 .50252 m .37899 .51635 L .37885 .49485 L p
1 g
F P
s
P
p
.002 w
.33568 .71333 m .34138 .68237 L .39449 .7059 L p
1 g
F P
s
P
p
.002 w
.39449 .7059 m .39407 .73897 L .33568 .71333 L p
1 g
F P
s
P
p
.002 w
.47974 .46974 m .51072 .45151 L .52208 .46928 L p
1 g
F P
s
P
p
.002 w
.51072 .45151 m .47974 .46974 L .47071 .46329 L p
1 g
F P
s
P
p
.002 w
.5582 .46356 m .52208 .46928 L .51072 .45151 L p
1 g
F P
s
P
p
.002 w
.3867 .47357 m .41713 .48091 L .41313 .49164 L p
1 g
F P
s
P
p
.002 w
.41313 .49164 m .37885 .49485 L .3867 .47357 L p
1 g
F P
s
P
p
.002 w
.63347 .51122 m .59969 .50116 L .59302 .46171 L p
1 g
F P
s
P
p
.002 w
.5582 .46356 m .59302 .46171 L .59969 .50116 L p
1 g
F P
s
P
p
.002 w
.32042 .55143 m .34782 .53278 L .35978 .56116 L p
1 g
F P
s
P
p
.002 w
.35978 .56116 m .33606 .58806 L .32042 .55143 L p
1 g
F P
s
P
p
.002 w
.64298 .65641 m .6613 .68105 L .60683 .72958 L p
1 g
F P
s
P
p
.002 w
.6613 .68105 m .64298 .65641 L .67711 .60026 L p
1 g
F P
s
P
p
.002 w
.65204 .57961 m .67711 .60026 L .64298 .65641 L p
1 g
F P
s
P
p
.002 w
.47071 .46329 m .49292 .43868 L .51072 .45151 L p
1 g
F P
s
P
p
.002 w
.49292 .43868 m .47071 .46329 L .45942 .46008 L p
1 g
F P
s
P
p
.002 w
.30164 .64367 m .3165 .61579 L .35119 .64985 L p
1 g
F P
s
P
p
.002 w
.35119 .64985 m .34138 .68237 L .30164 .64367 L p
1 g
F P
s
P
p
.002 w
.34748 .50119 m .37885 .49485 L .37899 .51635 L p
1 g
F P
s
P
p
.002 w
.37899 .51635 m .34782 .53278 L .34748 .50119 L p
1 g
F P
s
P
p
.002 w
.40172 .45486 m .42472 .47148 L .41713 .48091 L p
1 g
F P
s
P
p
.002 w
.41713 .48091 m .3867 .47357 L .40172 .45486 L p
1 g
F P
s
P
p
.002 w
.67711 .60026 m .65204 .57961 L .66398 .52403 L p
1 g
F P
s
P
p
.002 w
.63347 .51122 m .66398 .52403 L .65204 .57961 L p
1 g
F P
s
P
p
.002 w
.475 .80223 m .46743 .77593 L .53998 .76229 L p
1 g
F P
s
P
p
.002 w
.53998 .76229 m .55002 .78806 L .475 .80223 L p
1 g
F P
s
P
p
.002 w
.55002 .78806 m .53998 .76229 L .60683 .72958 L p
1 g
F P
s
P
p
.002 w
.45942 .46008 m .47056 .43226 L .49292 .43868 L p
1 g
F P
s
P
p
.002 w
.47056 .43226 m .45942 .46008 L .4471 .46047 L p
1 g
F P
s
P
p
.002 w
.60683 .72958 m .61917 .75425 L .55002 .78806 L p
1 g
F P
s
P
p
.002 w
.61917 .75425 m .60683 .72958 L .6613 .68105 L p
1 g
F P
s
P
p
.002 w
.42228 .44081 m .43509 .46441 L .42472 .47148 L p
1 g
F P
s
P
p
.002 w
.42472 .47148 m .40172 .45486 L .42228 .44081 L p
1 g
F P
s
P
p
.002 w
.59302 .46171 m .5582 .46356 L .54165 .43737 L p
1 g
F P
s
P
p
.002 w
.51072 .45151 m .54165 .43737 L .5582 .46356 L p
1 g
F P
s
P
p
.002 w
.4471 .46047 m .44612 .43299 L .47056 .43226 L p
1 g
F P
s
P
p
.002 w
.44612 .43299 m .4471 .46047 L .43509 .46441 L p
1 g
F P
s
P
p
.002 w
.54165 .43737 m .51072 .45151 L .49292 .43868 L p
1 g
F P
s
P
p
.002 w
.43509 .46441 m .42228 .44081 L .44612 .43299 L p
1 g
F P
s
P
p
.002 w
.3343 .74191 m .33568 .71333 L .39407 .73897 L p
1 g
F P
s
P
p
.002 w
.39407 .73897 m .39645 .769 L .3343 .74191 L p
1 g
F P
s
P
p
.002 w
.29753 .57187 m .32042 .55143 L .33606 .58806 L p
1 g
F P
s
P
p
.002 w
.33606 .58806 m .3165 .61579 L .29753 .57187 L p
1 g
F P
s
P
p
.002 w
.66398 .52403 m .63347 .51122 L .62566 .46382 L p
1 g
F P
s
P
p
.002 w
.59302 .46171 m .62566 .46382 L .63347 .51122 L p
1 g
F P
s
P
p
.002 w
.40161 .7952 m .39645 .769 L .46743 .77593 L p
1 g
F P
s
P
p
.002 w
.46743 .77593 m .475 .80223 L .40161 .7952 L p
1 g
F P
s
P
p
.002 w
.35894 .46983 m .3867 .47357 L .37885 .49485 L p
1 g
F P
s
P
p
.002 w
.37885 .49485 m .34748 .50119 L .35894 .46983 L p
1 g
F P
s
P
p
.002 w
.31983 .51053 m .34748 .50119 L .34782 .53278 L p
1 g
F P
s
P
p
.002 w
.34782 .53278 m .32042 .55143 L .31983 .51053 L p
1 g
F P
s
P
p
.002 w
.49292 .43868 m .51552 .41842 L .54165 .43737 L p
1 g
F P
s
P
p
.002 w
.51552 .41842 m .49292 .43868 L .47056 .43226 L p
1 g
F P
s
P
p
.002 w
.29191 .671 m .30164 .64367 L .34138 .68237 L p
1 g
F P
s
P
p
.002 w
.34138 .68237 m .33568 .71333 L .29191 .671 L p
1 g
F P
s
P
p
.002 w
.6613 .68105 m .67556 .70414 L .61917 .75425 L p
1 g
F P
s
P
p
.002 w
.67556 .70414 m .6613 .68105 L .69775 .62143 L p
1 g
F P
s
P
p
.002 w
.67711 .60026 m .69775 .62143 L .6613 .68105 L p
1 g
F P
s
P
p
.002 w
.62566 .46382 m .59302 .46171 L .57174 .42774 L p
1 g
F P
s
P
p
.002 w
.54165 .43737 m .57174 .42774 L .59302 .46171 L p
1 g
F P
s
P
p
.002 w
.69775 .62143 m .67711 .60026 L .69044 .5393 L p
1 g
F P
s
P
p
.002 w
.66398 .52403 m .69044 .5393 L .67711 .60026 L p
1 g
F P
s
P
p
.002 w
.38104 .44221 m .40172 .45486 L .3867 .47357 L p
1 g
F P
s
P
p
.002 w
.3867 .47357 m .35894 .46983 L .38104 .44221 L p
1 g
F P
s
P
p
.002 w
.57174 .42774 m .54165 .43737 L .51552 .41842 L p
1 g
F P
s
P
p
.002 w
.47056 .43226 m .48262 .40888 L .51552 .41842 L p
1 g
F P
s
P
p
.002 w
.48262 .40888 m .47056 .43226 L .44612 .43299 L p
1 g
F P
s
P
p
.002 w
.48334 .82379 m .475 .80223 L .55002 .78806 L p
1 g
F P
s
P
p
.002 w
.55002 .78806 m .55886 .80947 L .48334 .82379 L p
1 g
F P
s
P
p
.002 w
.55886 .80947 m .55002 .78806 L .61917 .75425 L p
1 g
F P
s
P
p
.002 w
.2798 .59361 m .29753 .57187 L .3165 .61579 L p
1 g
F P
s
P
p
.002 w
.3165 .61579 m .30164 .64367 L .2798 .59361 L p
1 g
F P
s
P
p
.002 w
.41138 .42145 m .42228 .44081 L .40172 .45486 L p
1 g
F P
s
P
p
.002 w
.40172 .45486 m .38104 .44221 L .41138 .42145 L p
1 g
F P
s
P
p
.002 w
.61917 .75425 m .6285 .77545 L .55886 .80947 L p
1 g
F P
s
P
p
.002 w
.6285 .77545 m .61917 .75425 L .67556 .70414 L p
1 g
F P
s
P
p
.002 w
.69044 .5393 m .66398 .52403 L .65528 .46989 L p
1 g
F P
s
P
p
.002 w
.62566 .46382 m .65528 .46989 L .66398 .52403 L p
1 g
F P
s
P
p
.002 w
.44612 .43299 m .44656 .40991 L .48262 .40888 L p
1 g
F P
s
P
p
.002 w
.44656 .40991 m .44612 .43299 L .42228 .44081 L p
1 g
F P
s
P
p
.002 w
.42228 .44081 m .41138 .42145 L .44656 .40991 L p
1 g
F P
s
P
p
.002 w
.33734 .76737 m .3343 .74191 L .39645 .769 L p
1 g
F P
s
P
p
.002 w
.39645 .769 m .40161 .7952 L .33734 .76737 L p
1 g
F P
s
P
p
.002 w
.33459 .46983 m .35894 .46983 L .34748 .50119 L p
1 g
F P
s
P
p
.002 w
.34748 .50119 m .31983 .51053 L .33459 .46983 L p
1 g
F P
s
P
p
.002 w
.29667 .52269 m .31983 .51053 L .32042 .55143 L p
1 g
F P
s
P
p
.002 w
.32042 .55143 m .29753 .57187 L .29667 .52269 L p
1 g
F P
s
P
p
.002 w
.40948 .81683 m .40161 .7952 L .475 .80223 L p
1 g
F P
s
P
p
.002 w
.475 .80223 m .48334 .82379 L .40948 .81683 L p
1 g
F P
s
P
p
.002 w
.28765 .69707 m .29191 .671 L .33568 .71333 L p
1 g
F P
s
P
p
.002 w
.33568 .71333 m .3343 .74191 L .28765 .69707 L p
1 g
F P
s
P
p
.002 w
.51552 .41842 m .53798 .40308 L .57174 .42774 L p
1 g
F P
s
P
p
.002 w
.53798 .40308 m .51552 .41842 L .48262 .40888 L p
1 g
F P
s
P
p
.002 w
.65528 .46989 m .62566 .46382 L .60025 .42291 L p
1 g
F P
s
P
p
.002 w
.57174 .42774 m .60025 .42291 L .62566 .46382 L p
1 g
F P
s
P
p
.002 w
.60025 .42291 m .57174 .42774 L .53798 .40308 L p
1 g
F P
s
P
p
.002 w
.69775 .62143 m .71335 .6426 L .67556 .70414 L p
1 g
F P
s
P
p
.002 w
.71335 .6426 m .69775 .62143 L .7121 .55667 L p
1 g
F P
s
P
p
.002 w
.69044 .5393 m .7121 .55667 L .69775 .62143 L p
1 g
F P
s
P
p
.002 w
.67556 .70414 m .68531 .72506 L .6285 .77545 L p
1 g
F P
s
P
p
.002 w
.68531 .72506 m .67556 .70414 L .71335 .6426 L p
1 g
F P
s
P
p
.002 w
.36325 .43392 m .38104 .44221 L .35894 .46983 L p
1 g
F P
s
P
p
.002 w
.35894 .46983 m .33459 .46983 L .36325 .43392 L p
1 g
F P
s
P
p
.002 w
.26778 .61612 m .2798 .59361 L .30164 .64367 L p
1 g
F P
s
P
p
.002 w
.30164 .64367 m .29191 .671 L .26778 .61612 L p
1 g
F P
s
P
p
.002 w
.48262 .40888 m .4953 .39062 L .53798 .40308 L p
1 g
F P
s
P
p
.002 w
.4953 .39062 m .48262 .40888 L .44656 .40991 L p
1 g
F P
s
P
p
.002 w
.7121 .55667 m .69044 .5393 L .68109 .47984 L p
1 g
F P
s
P
p
.002 w
.65528 .46989 m .68109 .47984 L .69044 .5393 L p
1 g
F P
s
P
p
.002 w
.49225 .83998 m .48334 .82379 L .55886 .80947 L p
1 g
F P
s
P
p
.002 w
.55886 .80947 m .56625 .8259 L .49225 .83998 L p
1 g
F P
s
P
p
.002 w
.56625 .8259 m .55886 .80947 L .6285 .77545 L p
1 g
F P
s
P
p
.002 w
.27868 .53743 m .29667 .52269 L .29753 .57187 L p
1 g
F P
s
P
p
.002 w
.29753 .57187 m .2798 .59361 L .27868 .53743 L p
1 g
F P
s
P
p
.002 w
.31436 .47365 m .33459 .46983 L .31983 .51053 L p
1 g
F P
s
P
p
.002 w
.31983 .51053 m .29667 .52269 L .31436 .47365 L p
1 g
F P
s
P
p
.002 w
.40269 .40691 m .41138 .42145 L .38104 .44221 L p
1 g
F P
s
P
p
.002 w
.38104 .44221 m .36325 .43392 L .40269 .40691 L p
1 g
F P
s
P
p
.002 w
.6285 .77545 m .63451 .79256 L .56625 .8259 L p
1 g
F P
s
P
p
.002 w
.63451 .79256 m .6285 .77545 L .68531 .72506 L p
1 g
F P
s
P
p
.002 w
.34482 .78896 m .33734 .76737 L .40161 .7952 L p
1 g
F P
s
P
p
.002 w
.40161 .7952 m .40948 .81683 L .34482 .78896 L p
1 g
F P
s
P
p
.002 w
.44656 .40991 m .44844 .39192 L .4953 .39062 L p
1 g
F P
s
P
p
.002 w
.44844 .39192 m .44656 .40991 L .41138 .42145 L p
1 g
F P
s
P
p
.002 w
.41138 .42145 m .40269 .40691 L .44844 .39192 L p
1 g
F P
s
P
p
.002 w
.68109 .47984 m .65528 .46989 L .62642 .42309 L p
1 g
F P
s
P
p
.002 w
.60025 .42291 m .62642 .42309 L .65528 .46989 L p
1 g
F P
s
P
p
.002 w
.28909 .72118 m .28765 .69707 L .3343 .74191 L p
1 g
F P
s
P
p
.002 w
.3343 .74191 m .33734 .76737 L .28909 .72118 L p
1 g
F P
s
P
p
.002 w
.53798 .40308 m .55971 .39314 L .60025 .42291 L p
1 g
F P
s
P
p
.002 w
.55971 .39314 m .53798 .40308 L .4953 .39062 L p
1 g
F P
s
P
p
.002 w
.41991 .83323 m .40948 .81683 L .48334 .82379 L p
1 g
F P
s
P
p
.002 w
.48334 .82379 m .49225 .83998 L .41991 .83323 L p
1 g
F P
s
P
p
.002 w
.62642 .42309 m .60025 .42291 L .55971 .39314 L p
1 g
F P
s
P
p
.002 w
.71335 .6426 m .72343 .66323 L .68531 .72506 L p
1 g
F P
s
P
p
.002 w
.72343 .66323 m .71335 .6426 L .72834 .57576 L p
1 g
F P
s
P
p
.002 w
.7121 .55667 m .72834 .57576 L .71335 .6426 L p
1 g
F P
s
P
p
.002 w
.26189 .63881 m .26778 .61612 L .29191 .671 L p
1 g
F P
s
P
p
.002 w
.29191 .671 m .28765 .69707 L .26189 .63881 L p
1 g
F P
s
P
p
.002 w
.68531 .72506 m .69021 .74324 L .63451 .79256 L p
1 g
F P
s
P
p
.002 w
.69021 .74324 m .68531 .72506 L .72343 .66323 L p
1 g
F P
s
P
p
.002 w
.34889 .43031 m .36325 .43392 L .33459 .46983 L p
1 g
F P
s
P
p
.002 w
.33459 .46983 m .31436 .47365 L .34889 .43031 L p
1 g
F P
s
P
p
.002 w
.72834 .57576 m .7121 .55667 L .70234 .49348 L p
1 g
F P
s
P
p
.002 w
.68109 .47984 m .70234 .49348 L .7121 .55667 L p
1 g
F P
s
P
p
.002 w
.26644 .55439 m .27868 .53743 L .2798 .59361 L p
1 g
F P
s
P
p
.002 w
.2798 .59361 m .26778 .61612 L .26644 .55439 L p
1 g
F P
s
P
p
.002 w
.4953 .39062 m .5083 .37805 L .55971 .39314 L p
1 g
F P
s
P
p
.002 w
.5083 .37805 m .4953 .39062 L .44844 .39192 L p
1 g
F P
s
P
p
.002 w
.29885 .48128 m .31436 .47365 L .29667 .52269 L p
1 g
F P
s
P
p
.002 w
.29667 .52269 m .27868 .53743 L .29885 .48128 L p
1 g
F P
s
P
p
.002 w
.70234 .49348 m .68109 .47984 L .64952 .42837 L p
1 g
F P
s
P
p
.002 w
.62642 .42309 m .64952 .42837 L .68109 .47984 L p
1 g
F P
s
P
p
.002 w
.50151 .85024 m .49225 .83998 L .56625 .8259 L p
1 g
F P
s
P
p
.002 w
.56625 .8259 m .57197 .83681 L .50151 .85024 L p
1 g
F P
s
P
p
.002 w
.57197 .83681 m .56625 .8259 L .63451 .79256 L p
1 g
F P
s
P
p
.002 w
.35663 .80605 m .34482 .78896 L .40948 .81683 L p
1 g
F P
s
P
p
.002 w
.40948 .81683 m .41991 .83323 L .35663 .80605 L p
1 g
F P
s
P
p
.002 w
.39649 .39768 m .40269 .40691 L .36325 .43392 L p
1 g
F P
s
P
p
.002 w
.36325 .43392 m .34889 .43031 L .39649 .39768 L p
1 g
F P
s
P
p
.002 w
.29629 .74264 m .28909 .72118 L .33734 .76737 L p
1 g
F P
s
P
p
.002 w
.33734 .76737 m .34482 .78896 L .29629 .74264 L p
1 g
F P
s
P
p
.002 w
.63451 .79256 m .63698 .80506 L .57197 .83681 L p
1 g
F P
s
P
p
.002 w
.63698 .80506 m .63451 .79256 L .69021 .74324 L p
1 g
F P
s
P
p
.002 w
.44844 .39192 m .45175 .37958 L .5083 .37805 L p
1 g
F P
s
P
p
.002 w
.45175 .37958 m .44844 .39192 L .40269 .40691 L p
1 g
F P
s
P
p
.002 w
.55971 .39314 m .58013 .38897 L .62642 .42309 L p
1 g
F P
s
P
p
.002 w
.58013 .38897 m .55971 .39314 L .5083 .37805 L p
1 g
F P
s
P
p
.002 w
.40269 .40691 m .39649 .39768 L .45175 .37958 L p
1 g
F P
s
P
p
.002 w
.64952 .42837 m .62642 .42309 L .58013 .38897 L p
1 g
F P
s
P
p
.002 w
.43268 .84387 m .41991 .83323 L .49225 .83998 L p
1 g
F P
s
P
p
.002 w
.49225 .83998 m .50151 .85024 L .43268 .84387 L p
1 g
F P
s
P
p
.002 w
.26243 .66109 m .26189 .63881 L .28765 .69707 L p
1 g
F P
s
P
p
.002 w
.28765 .69707 m .28909 .72118 L .26243 .66109 L p
1 g
F P
s
P
p
.002 w
.72343 .66323 m .7276 .68276 L .69021 .74324 L p
1 g
F P
s
P
p
.002 w
.7276 .68276 m .72343 .66323 L .7386 .59608 L p
1 g
F P
s
P
p
.002 w
.72834 .57576 m .7386 .59608 L .72343 .66323 L p
1 g
F P
s
P
p
.002 w
.7386 .59608 m .72834 .57576 L .71838 .51052 L p
1 g
F P
s
P
p
.002 w
.70234 .49348 m .71838 .51052 L .72834 .57576 L p
1 g
F P
s
P
p
.002 w
.69021 .74324 m .69003 .75814 L .63698 .80506 L p
1 g
F P
s
P
p
.002 w
.69003 .75814 m .69021 .74324 L .7276 .68276 L p
1 g
F P
s
P
p
.002 w
.33841 .43159 m .34889 .43031 L .31436 .47365 L p
1 g
F P
s
P
p
.002 w
.31436 .47365 m .29885 .48128 L .33841 .43159 L p
1 g
F P
s
P
p
.002 w
.26042 .57318 m .26644 .55439 L .26778 .61612 L p
1 g
F P
s
P
p
.002 w
.26778 .61612 m .26189 .63881 L .26042 .57318 L p
1 g
F P
s
P
p
.002 w
.2886 .4926 m .29885 .48128 L .27868 .53743 L p
1 g
F P
s
P
p
.002 w
.27868 .53743 m .26644 .55439 L .2886 .4926 L p
1 g
F P
s
P
p
.002 w
.5083 .37805 m .52128 .37164 L .58013 .38897 L p
1 g
F P
s
P
p
.002 w
.52128 .37164 m .5083 .37805 L .45175 .37958 L p
1 g
F P
s
P
p
.002 w
.71838 .51052 m .70234 .49348 L .66888 .43873 L p
1 g
F P
s
P
p
.002 w
.64952 .42837 m .66888 .43873 L .70234 .49348 L p
1 g
F P
s
P
p
.002 w
.37254 .81807 m .35663 .80605 L .41991 .83323 L p
1 g
F P
s
P
p
.002 w
.41991 .83323 m .43268 .84387 L .37254 .81807 L p
1 g
F P
s
P
p
.002 w
.30919 .76082 m .29629 .74264 L .34482 .78896 L p
1 g
F P
s
P
p
.002 w
.34482 .78896 m .35663 .80605 L .30919 .76082 L p
1 g
F P
s
P
p
.002 w
.39301 .39415 m .39649 .39768 L .34889 .43031 L p
1 g
F P
s
P
p
.002 w
.34889 .43031 m .33841 .43159 L .39301 .39415 L p
1 g
F P
s
P
p
.002 w
.51088 .85415 m .50151 .85024 L .57197 .83681 L p
1 g
F P
s
P
p
.002 w
.57197 .83681 m .57582 .84177 L .51088 .85415 L p
1 g
F P
s
P
p
.002 w
.57582 .84177 m .57197 .83681 L .63698 .80506 L p
1 g
F P
s
P
p
.002 w
.66888 .43873 m .64952 .42837 L .59868 .39081 L p
1 g
F P
s
P
p
.002 w
.58013 .38897 m .59868 .39081 L .64952 .42837 L p
1 g
F P
s
P
p
.002 w
.59868 .39081 m .58013 .38897 L .52128 .37164 L p
1 g
F P
s
P
p
.002 w
.63698 .80506 m .63576 .8125 L .57582 .84177 L p
1 g
F P
s
P
p
.002 w
.63576 .8125 m .63698 .80506 L .69003 .75814 L p
1 g
F P
s
P
p
.002 w
.45175 .37958 m .45642 .37338 L .52128 .37164 L p
1 g
F P
s
P
p
.002 w
.45642 .37338 m .45175 .37958 L .39649 .39768 L p
1 g
F P
s
P
p
.002 w
.26951 .68233 m .26243 .66109 L .28909 .72118 L p
1 g
F P
s
P
p
.002 w
.28909 .72118 m .29629 .74264 L .26951 .68233 L p
1 g
F P
s
P
p
.002 w
.39649 .39768 m .39301 .39415 L .45642 .37338 L p
1 g
F P
s
P
p
.002 w
.7276 .68276 m .72563 .70065 L .69003 .75814 L p
1 g
F P
s
P
p
.002 w
.72563 .70065 m .7276 .68276 L .7425 .61713 L p
1 g
F P
s
P
p
.002 w
.7386 .59608 m .7425 .61713 L .7276 .68276 L p
1 g
F P
s
P
p
.002 w
.4475 .8483 m .43268 .84387 L .50151 .85024 L p
1 g
F P
s
P
p
.002 w
.50151 .85024 m .51088 .85415 L .4475 .8483 L p
1 g
F P
s
P
p
.002 w
.7425 .61713 m .7386 .59608 L .72868 .53057 L p
1 g
F P
s
P
p
.002 w
.71838 .51052 m .72868 .53057 L .7386 .59608 L p
1 g
F P
s
P
p
.002 w
.26091 .59332 m .26042 .57318 L .26189 .63881 L p
1 g
F P
s
P
p
.002 w
.26189 .63881 m .26243 .66109 L .26091 .59332 L p
1 g
F P
s
P
p
.002 w
.33219 .43783 m .33841 .43159 L .29885 .48128 L p
1 g
F P
s
P
p
.002 w
.29885 .48128 m .2886 .4926 L .33219 .43783 L p
1 g
F P
s
P
p
.002 w
.69003 .75814 m .68465 .76928 L .63576 .8125 L p
1 g
F P
s
P
p
.002 w
.68465 .76928 m .69003 .75814 L .72563 .70065 L p
1 g
F P
s
P
p
.002 w
.28402 .50739 m .2886 .4926 L .26644 .55439 L p
1 g
F P
s
P
p
.002 w
.26644 .55439 m .26042 .57318 L .28402 .50739 L p
1 g
F P
s
P
p
.002 w
.66888 .43873 m .68388 .45398 L .71838 .51052 L p
1 g
F P
s
P
p
.002 w
.72868 .53057 m .71838 .51052 L .68388 .45398 L p
1 g
F P
s
P
p
.002 w
.52128 .37164 m .53389 .37171 L .59868 .39081 L p
1 g
F P
s
P
p
.002 w
.53389 .37171 m .52128 .37164 L .45642 .37338 L p
1 g
F P
s
P
p
.002 w
.32754 .77515 m .30919 .76082 L .35663 .80605 L p
1 g
F P
s
P
p
.002 w
.35663 .80605 m .37254 .81807 L .32754 .77515 L p
1 g
F P
s
P
p
.002 w
.39221 .82458 m .37254 .81807 L .43268 .84387 L p
1 g
F P
s
P
p
.002 w
.43268 .84387 m .4475 .8483 L .39221 .82458 L p
1 g
F P
s
P
p
.002 w
.59868 .39081 m .6148 .39874 L .66888 .43873 L p
1 g
F P
s
P
p
.002 w
.68388 .45398 m .66888 .43873 L .6148 .39874 L p
1 g
F P
s
P
p
.002 w
.6148 .39874 m .59868 .39081 L .53389 .37171 L p
1 g
F P
s
P
p
.002 w
.39242 .39654 m .39301 .39415 L .33841 .43159 L p
1 g
F P
s
P
p
.002 w
.33841 .43159 m .33219 .43783 L .39242 .39654 L p
1 g
F P
s
P
p
.002 w
.28308 .70192 m .26951 .68233 L .29629 .74264 L p
1 g
F P
s
P
p
.002 w
.29629 .74264 m .30919 .76082 L .28308 .70192 L p
1 g
F P
s
P
p
.002 w
.52011 .85146 m .51088 .85415 L .57582 .84177 L p
1 g
F P
s
P
p
.002 w
.57582 .84177 m .57765 .84049 L .52011 .85146 L p
1 g
F P
s
P
p
.002 w
.57765 .84049 m .57582 .84177 L .63576 .8125 L p
1 g
F P
s
P
p
.002 w
.63576 .8125 m .63078 .81455 L .57765 .84049 L p
1 g
F P
s
P
p
.002 w
.63078 .81455 m .63576 .8125 L .68465 .76928 L p
1 g
F P
s
P
p
.002 w
.45642 .37338 m .46238 .37362 L .53389 .37171 L p
1 g
F P
s
P
p
.002 w
.46238 .37362 m .45642 .37338 L .39301 .39415 L p
1 g
F P
s
P
p
.002 w
.72563 .70065 m .71741 .71638 L .68465 .76928 L p
1 g
F P
s
P
p
.002 w
.7425 .61713 m .73979 .63834 L .72563 .70065 L p
1 g
F P
s
P
p
.002 w
.71741 .71638 m .72563 .70065 L .73979 .63834 L p
1 g
F P
s
P
p
.002 w
.39301 .39415 m .39242 .39654 L .46238 .37362 L p
1 g
F P
s
P
p
.002 w
.72868 .53057 m .73281 .55314 L .7425 .61713 L p
1 g
F P
s
P
p
.002 w
.73979 .63834 m .7425 .61713 L .73281 .55314 L p
1 g
F P
s
P
p
.002 w
.46401 .84627 m .4475 .8483 L .51088 .85415 L p
1 g
F P
s
P
p
.002 w
.51088 .85415 m .52011 .85146 L .46401 .84627 L p
1 g
F P
s
P
p
.002 w
.26804 .61426 m .26091 .59332 L .26243 .66109 L p
1 g
F P
s
P
p
.002 w
.26243 .66109 m .26951 .68233 L .26804 .61426 L p
1 g
F P
s
P
p
.002 w
.33051 .44901 m .33219 .43783 L .2886 .4926 L p
1 g
F P
s
P
p
.002 w
.2886 .4926 m .28402 .50739 L .33051 .44901 L p
1 g
F P
s
P
p
.002 w
.68465 .76928 m .67409 .77626 L .63078 .81455 L p
1 g
F P
s
P
p
.002 w
.67409 .77626 m .68465 .76928 L .71741 .71638 L p
1 g
F P
s
P
p
.002 w
.73281 .55314 m .72868 .53057 L .69403 .47382 L p
1 g
F P
s
P
p
.002 w
.68388 .45398 m .69403 .47382 L .72868 .53057 L p
1 g
F P
s
P
p
.002 w
.28536 .52531 m .28402 .50739 L .26042 .57318 L p
1 g
F P
s
P
p
.002 w
.26042 .57318 m .26091 .59332 L .28536 .52531 L p
1 g
F P
s
P
p
.002 w
.35095 .78512 m .32754 .77515 L .37254 .81807 L p
1 g
F P
s
P
p
.002 w
.37254 .81807 m .39221 .82458 L .35095 .78512 L p
1 g
F P
s
P
p
.002 w
.53389 .37171 m .54576 .37842 L .6148 .39874 L p
1 g
F P
s
P
p
.002 w
.54576 .37842 m .53389 .37171 L .46238 .37362 L p
1 g
F P
s
P
p
.002 w
.69403 .47382 m .68388 .45398 L .62799 .41269 L p
1 g
F P
s
P
p
.002 w
.6148 .39874 m .62799 .41269 L .68388 .45398 L p
1 g
F P
s
P
p
.002 w
.41517 .82526 m .39221 .82458 L .4475 .8483 L p
1 g
F P
s
P
p
.002 w
.4475 .8483 m .46401 .84627 L .41517 .82526 L p
1 g
F P
s
P
p
.002 w
.30288 .71926 m .28308 .70192 L .30919 .76082 L p
1 g
F P
s
P
p
.002 w
.30919 .76082 m .32754 .77515 L .30288 .71926 L p
1 g
F P
s
P
p
.002 w
.62799 .41269 m .6148 .39874 L .54576 .37842 L p
1 g
F P
s
P
p
.002 w
.39481 .40495 m .39242 .39654 L .33219 .43783 L p
1 g
F P
s
P
p
.002 w
.33219 .43783 m .33051 .44901 L .39481 .40495 L p
1 g
F P
s
P
p
.002 w
.52893 .84207 m .52011 .85146 L .57765 .84049 L p
1 g
F P
s
P
p
.002 w
.57765 .84049 m .57737 .83284 L .52893 .84207 L p
1 g
F P
s
P
p
.002 w
.57737 .83284 m .57765 .84049 L .63078 .81455 L p
1 g
F P
s
P
p
.002 w
.63078 .81455 m .62209 .811 L .57737 .83284 L p
1 g
F P
s
P
p
.002 w
.62209 .811 m .63078 .81455 L .67409 .77626 L p
1 g
F P
s
P
p
.002 w
.71741 .71638 m .70305 .72944 L .67409 .77626 L p
1 g
F P
s
P
p
.002 w
.70305 .72944 m .71741 .71638 L .73039 .65912 L p
1 g
F P
s
P
p
.002 w
.73979 .63834 m .73039 .65912 L .71741 .71638 L p
1 g
F P
s
P
p
.002 w
.73039 .65912 m .73979 .63834 L .73055 .57766 L p
1 g
F P
s
P
p
.002 w
.73281 .55314 m .73055 .57766 L .73979 .63834 L p
1 g
F P
s
P
p
.002 w
.46238 .37362 m .46948 .38048 L .54576 .37842 L p
1 g
F P
s
P
p
.002 w
.46948 .38048 m .46238 .37362 L .39242 .39654 L p
1 g
F P
s
P
p
.002 w
.28176 .63544 m .26804 .61426 L .26951 .68233 L p
1 g
F P
s
P
p
.002 w
.26951 .68233 m .28308 .70192 L .28176 .63544 L p
1 g
F P
s
P
p
.002 w
.39242 .39654 m .39481 .40495 L .46948 .38048 L p
1 g
F P
s
P
p
.002 w
.48177 .83767 m .46401 .84627 L .52011 .85146 L p
1 g
F P
s
P
p
.002 w
.52011 .85146 m .52893 .84207 L .48177 .83767 L p
1 g
F P
s
P
p
.002 w
.73055 .57766 m .73281 .55314 L .69892 .49778 L p
1 g
F P
s
P
p
.002 w
.69403 .47382 m .69892 .49778 L .73281 .55314 L p
1 g
F P
s
P
p
.002 w
.33354 .46491 m .33051 .44901 L .28402 .50739 L p
1 g
F P
s
P
p
.002 w
.28402 .50739 m .28536 .52531 L .33354 .46491 L p
1 g
F P
s
P
p
.002 w
.29273 .54592 m .28536 .52531 L .26091 .59332 L p
1 g
F P
s
P
p
.002 w
.26091 .59332 m .26804 .61426 L .29273 .54592 L p
1 g
F P
s
P
p
.002 w
.67409 .77626 m .65852 .77877 L .62209 .811 L p
1 g
F P
s
P
p
.002 w
.65852 .77877 m .67409 .77626 L .70305 .72944 L p
1 g
F P
s
P
p
.002 w
.37884 .79037 m .35095 .78512 L .39221 .82458 L p
1 g
F P
s
P
p
.002 w
.39221 .82458 m .41517 .82526 L .37884 .79037 L p
1 g
F P
s
P
p
.002 w
.69892 .49778 m .69403 .47382 L .63782 .4324 L p
1 g
F P
s
P
p
.002 w
.62799 .41269 m .63782 .4324 L .69403 .47382 L p
1 g
F P
s
P
p
.002 w
.54576 .37842 m .55655 .39173 L .62799 .41269 L p
1 g
F P
s
P
p
.002 w
.55655 .39173 m .54576 .37842 L .46948 .38048 L p
1 g
F P
s
P
p
.002 w
.32847 .73381 m .30288 .71926 L .32754 .77515 L p
1 g
F P
s
P
p
.002 w
.32754 .77515 m .35095 .78512 L .32847 .73381 L p
1 g
F P
s
P
p
.002 w
.44081 .81997 m .41517 .82526 L .46401 .84627 L p
1 g
F P
s
P
p
.002 w
.46401 .84627 m .48177 .83767 L .44081 .81997 L p
1 g
F P
s
P
p
.002 w
.63782 .4324 m .62799 .41269 L .55655 .39173 L p
1 g
F P
s
P
p
.002 w
.73039 .65912 m .71444 .67887 L .70305 .72944 L p
1 g
F P
s
P
p
.002 w
.71444 .67887 m .73039 .65912 L .72182 .60346 L p
1 g
F P
s
P
p
.002 w
.73055 .57766 m .72182 .60346 L .73039 .65912 L p
1 g
F P
s
P
p
.002 w
.40018 .41929 m .39481 .40495 L .33051 .44901 L p
1 g
F P
s
P
p
.002 w
.33051 .44901 m .33354 .46491 L .40018 .41929 L p
1 g
F P
s
P
p
.002 w
.3018 .65622 m .28176 .63544 L .28308 .70192 L p
1 g
F P
s
P
p
.002 w
.28308 .70192 m .30288 .71926 L .3018 .65622 L p
1 g
F P
s
P
p
.002 w
.70305 .72944 m .6828 .73942 L .65852 .77877 L p
1 g
F P
s
P
p
.002 w
.6828 .73942 m .70305 .72944 L .71444 .67887 L p
1 g
F P
s
P
p
.002 w
.52893 .84207 m .57737 .83284 L p
.53789 .82622 L 1 g
F P
s
P
p
.002 w
.53685 .82656 m .52893 .84207 L p
.53789 .82622 L 1 g
F P
s
P
p
.002 w
.48177 .83767 m .52893 .84207 L p
.51221 .8307 L 1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.44081 .81997 m .48177 .83767 L p
.47926 .83222 L 1 g
F P
s
P
p
.47926 .83222 m .46497 .8258 L .44081 .81997 L 1 g
F
P
p
.002 w
.4637 .82523 m .46403 .82325 L p
.4545 .8211 L 1 g
F P
s
P
p
.48758 .82869 m .47758 .82884 L .47894 .82919 L 1 g
F
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.47926 .83222 m .47772 .82887 L .46497 .8258 L 1 g
F
P
p
.002 w
.44186 .81955 m .44081 .81997 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .4637 .82523 L p
1 g
F P
s
P
p
.002 w
.4637 .82523 m .46305 .82905 L p
.47758 .82884 L 1 g
F P
s
P
p
.48758 .82869 m .4637 .82523 L .47758 .82884 L 1 g
F
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.50031 .82261 m .46845 .80876 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48742 .8314 L p
1 g
F P
s
P
p
.002 w
.48177 .83767 m .48899 .83181 L p
.48742 .8314 L 1 g
F P
s
P
p
.51242 .82869 m .48742 .8314 L .48925 .83159 L 1 g
F
P
p
.51221 .8307 m .51215 .83066 L .48899 .83181 L 1 g
F
P
p
.002 w
.48925 .83159 m .48899 .83181 L p
.51215 .83066 L 1 g
F P
s
P
p
.51221 .8307 m .48899 .83181 L .5 .83275 L 1 g
F
P
p
.50241 .83106 m .48925 .83159 L .49672 .8324 L 1 g
F
P
p
.51242 .82869 m .48925 .83159 L .50241 .83106 L 1 g
F
P
p
.002 w
.48899 .83181 m .48465 .83533 L p
.5 .83275 L 1 g
F P
s
P
p
.002 w
.48465 .83533 m .48177 .83767 L p
.51221 .8307 L 1 g
F P
s
P
p
.002 w
.52893 .84207 m .53524 .82972 L p
.51253 .83064 L 1 g
F P
s
P
p
.51221 .8307 m .51253 .83064 L .51215 .83066 L 1 g
F
P
p
.52893 .84207 m .51253 .83064 L .51221 .8307 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51253 .83064 L p
1 g
F P
s
P
p
.53597 .82325 m .51253 .83064 L .52526 .82851 L 1 g
F
P
p
.002 w
.51253 .83064 m .51242 .82869 L p
.50241 .83106 L 1 g
F P
s
P
p
.002 w
.53654 .82661 m .53597 .82325 L p
.52526 .82851 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53654 .82661 L p
1 g
F P
s
P
p
.52572 .83011 m .53709 .82608 L .51215 .83066 L 1 g
F
P
p
.002 w
.53524 .82972 m .53688 .8265 L p
.52572 .83011 L 1 g
F P
s
P
p
.002 w
.53688 .8265 m .53709 .82608 L p
.52572 .83011 L 1 g
F P
s
P
p
.002 w
.57737 .83284 m .57491 .8189 L .53822 .82587 L p
1 g
F P
s
P
p
.57737 .83284 m .53822 .82587 L .53758 .82617 L 1 g
F
P
p
.55573 .81291 m .53654 .82661 L .53688 .8265 L 1 g
F
P
p
.53789 .82622 m .53758 .82617 L .53685 .82656 L 1 g
F
P
p
.002 w
.53688 .8265 m .53685 .82656 L p
.53758 .82617 L 1 g
F P
s
P
p
.57491 .8189 m .56121 .81214 L .55632 .81506 L 1 g
F
P
p
.002 w
.53822 .82587 m .54658 .82428 L p
.55632 .81506 L 1 g
F P
s
P
p
.002 w
.54658 .82428 m .57491 .8189 L p
.55632 .81506 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55632 .81506 L p
1 g
F P
s
P
p
.56958 .79874 m .55632 .81506 L .56381 .80797 L 1 g
F
P
p
.55573 .81291 m .53688 .8265 L .53822 .82587 L 1 g
F
P
p
.54618 .82111 m .53822 .82587 L .54358 .82335 L 1 g
F
P
p
.55573 .81291 m .53822 .82587 L .54618 .82111 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.57062 .80153 m .56958 .79874 L p
.56381 .80797 L 1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57062 .80153 L p
1 g
F P
s
P
p
.002 w
.57031 .7989 m .54432 .80382 L p
.56417 .8136 L 1 g
F P
s
P
p
.002 w
.57491 .8189 m .57083 .80114 L p
.56417 .8136 L 1 g
F P
s
P
p
.576 .78222 m .57062 .80153 L .57083 .80114 L 1 g
F
P
p
.002 w
.57491 .8189 m .60985 .80183 L p
.57182 .79901 L 1 g
F P
s
P
p
.002 w
.57083 .80114 m .57086 .8013 L p
.57182 .79901 L 1 g
F P
s
P
p
.002 w
.57086 .8013 m .57491 .8189 L p
.57198 .80004 L 1 g
F P
s
P
p
.57182 .79901 m .57086 .8013 L .57198 .80004 L 1 g
F
P
p
.002 w
.57083 .80114 m .57031 .7989 L p
.56417 .8136 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57063 .80156 L p
1 g
F P
s
P
p
.002 w
.57063 .80156 m .57062 .80153 L p
.57032 .80191 L 1 g
F P
s
P
p
.57032 .80191 m .55726 .81844 L .57063 .80156 L 1 g
F
P
p
.576 .78222 m .57083 .80114 L .57234 .79791 L 1 g
F
P
p
.59432 .78717 m .57839 .77997 L .57693 .7843 L 1 g
F
P
p
.002 w
.57234 .79791 m .5779 .79519 L p
.57693 .7843 L 1 g
F P
s
P
p
.002 w
.5779 .79519 m .59432 .78717 L p
.57693 .7843 L 1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57693 .7843 L p
1 g
F P
s
P
p
.57421 .76511 m .57693 .7843 L .57622 .77637 L 1 g
F
P
p
.576 .78222 m .57234 .79791 L .5734 .79476 L 1 g
F
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.60985 .80183 m .59432 .78717 L .57234 .79791 L p
1 g
F P
s
P
p
.002 w
.57234 .79791 m .57031 .7989 L p
.57182 .79901 L 1 g
F P
s
P
p
.60985 .80183 m .57234 .79791 L .57182 .79901 L 1 g
F
P
p
.002 w
.5715 .8039 m .57811 .78694 L .5778 .78625 L p
1 g
F P
s
P
p
.002 w
.5778 .78625 m .576 .78222 L p
.57307 .79634 L 1 g
F P
s
P
p
.57307 .79634 m .5715 .8039 L .5778 .78625 L 1 g
F
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.57693 .7843 m .56365 .77332 L .57234 .79791 L 1 g
F
P
p
.57839 .77997 m .57647 .7791 L .57693 .7843 L 1 g
F
P
p
.57647 .7791 m .56365 .77332 L .57693 .7843 L 1 g
F
P
p
.002 w
.57544 .76765 m .57421 .76511 L p
.57622 .77637 L 1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57544 .76765 L p
1 g
F P
s
P
p
.56431 .74928 m .57544 .76765 L .57539 .76758 L 1 g
F
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.57343 .76441 m .55745 .74559 L p
.57539 .76758 L 1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56516 .75109 L p
1 g
F P
s
P
p
.56431 .74928 m .57539 .76758 L .57343 .76441 L 1 g
F
P
p
.002 w
.55745 .74559 m .57343 .76441 L p
.56516 .75109 L 1 g
F P
s
P
p
.57083 .76022 m .57343 .76441 L .57087 .76029 L 1 g
F
P
p
.56431 .74928 m .57343 .76441 L .57083 .76022 L 1 g
F
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.58125 .76257 m .58583 .75849 L p
.56344 .74831 L 1 g
F P
s
P
p
.54732 .73647 m .56516 .75109 L .56495 .75094 L 1 g
F
P
p
.54732 .73647 m .56518 .75113 L .55831 .7462 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.55745 .74559 m .55726 .74545 L .57539 .76758 L 1 g
F
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56365 .77332 m .57539 .76758 L p
.55726 .74545 L 1 g
F P
s
P
p
.002 w
.55548 .74418 m .56365 .77332 L p
.55726 .74545 L 1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55039 .77582 m .56365 .77332 L .55548 .74418 L p
1 g
F P
s
P
p
.54732 .73647 m .55831 .7462 L .55548 .74418 L 1 g
F
P
p
.54732 .73647 m .55548 .74418 L .55496 .7438 L 1 g
F
P
p
.002 w
.55467 .74359 m .53754 .77455 L p
.55496 .7438 L 1 g
F P
s
P
p
.002 w
.52647 .76966 m .53754 .77455 L .55467 .74359 L p
1 g
F P
s
P
p
.002 w
.55445 .74342 m .52647 .76966 L p
.55467 .74359 L 1 g
F P
s
P
p
.54732 .73647 m .55496 .7438 L .55456 .7435 L 1 g
F
P
p
.002 w
.51838 .76164 m .52647 .76966 L .55445 .74342 L p
1 g
F P
s
P
p
.002 w
.55423 .74326 m .51838 .76164 L p
.55445 .74342 L 1 g
F P
s
P
p
.002 w
.51416 .75135 m .51838 .76164 L .55423 .74326 L p
1 g
F P
s
P
p
.002 w
.55397 .74305 m .51416 .75135 L p
.55423 .74326 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52543 .72987 L p
1 g
F P
s
P
p
.5 .72527 m .52543 .72987 L .52529 .72986 L 1 g
F
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.52157 .72962 m .5523 .74171 L p
.54799 .73824 L 1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54799 .73824 L p
1 g
F P
s
P
p
.52506 .72815 m .54799 .73824 L .53725 .73426 L 1 g
F
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.52157 .72962 m .54799 .73824 L .52543 .72987 L 1 g
F
P
p
.002 w
.5143 .73989 m .55353 .7427 L p
.52145 .72961 L 1 g
F P
s
P
p
.002 w
.47299 .7333 m .5143 .73989 L .51843 .72941 L p
1 g
F P
s
P
p
.5 .72527 m .52543 .72988 L .51843 .72941 L 1 g
F
P
p
.5 .72527 m .51843 .72941 L .51562 .72899 L 1 g
F
P
p
.47299 .7333 m .51843 .72941 L .51507 .72891 L 1 g
F
P
p
.002 w
.51843 .72941 m .5143 .73989 L p
.52145 .72961 L 1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.47299 .7333 m .51507 .72891 L .5 .72668 L 1 g
F
P
p
.47299 .7333 m .5 .72668 L .47918 .7294 L 1 g
F
P
p
.002 w
.47454 .73001 m .47494 .72815 L p
.4876 .7283 L 1 g
F P
s
P
p
.002 w
.47422 .73015 m .47299 .7333 L p
.47918 .7294 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72668 L p
1 g
F P
s
P
p
.47494 .72815 m .5 .72668 L .4876 .7283 L 1 g
F
P
p
.47918 .7294 m .48662 .7247 L .47454 .73001 L 1 g
F
P
p
.47918 .7294 m .47454 .73001 L .47422 .73015 L 1 g
F
P
p
.002 w
.5 .72668 m .5 .72845 L p
.4876 .7283 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47454 .73001 L p
1 g
F P
s
P
p
.4876 .7283 m .5 .72845 L .47454 .73001 L 1 g
F
P
p
.47918 .7294 m .5 .72668 L .48662 .7247 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47453 .73003 L p
1 g
F P
s
P
p
.45268 .73647 m .47453 .73003 L .47199 .73099 L 1 g
F
P
p
.002 w
.46871 .73224 m .47299 .7333 L .47422 .73015 L p
1 g
F P
s
P
p
.45268 .73647 m .47448 .73029 L .46422 .73376 L 1 g
F
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.43246 .72325 m .46871 .73224 L p
.48175 .71082 L 1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.47422 .73015 m .48175 .71082 L p
.46871 .73224 L 1 g
F P
s
P
p
.002 w
.47453 .73003 m .47448 .73029 L p
.47199 .73099 L 1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.47299 .7333 m .46871 .73224 L p
.43245 .75634 L 1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.43245 .75634 m .46871 .73224 L .45216 .73785 L 1 g
F
P
p
.43245 .75634 m .45216 .73785 L .43566 .75056 L 1 g
F
P
p
.002 w
.43477 .75124 m .43569 .74928 L p
.44284 .74502 L 1 g
F P
s
P
p
.002 w
.43245 .75505 m .43245 .75634 L p
.43566 .75056 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45216 .73785 L p
1 g
F P
s
P
p
.43569 .74928 m .45216 .73785 L .44284 .74502 L 1 g
F
P
p
.43566 .75056 m .44052 .74179 L .43477 .75124 L 1 g
F
P
p
.43566 .75056 m .43477 .75124 L .43245 .75505 L 1 g
F
P
p
.002 w
.45216 .73785 m .45136 .73996 L p
.44284 .74502 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43477 .75124 L p
1 g
F P
s
P
p
.44284 .74502 m .45136 .73996 L .43477 .75124 L 1 g
F
P
p
.43566 .75056 m .45216 .73785 L .44052 .74179 L 1 g
F
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43466 .75147 L p
1 g
F P
s
P
p
.42579 .76511 m .43466 .75147 L .43284 .75442 L 1 g
F
P
p
.42579 .76511 m .43436 .75211 L .43048 .75816 L 1 g
F
P
p
.002 w
.39417 .75268 m .4317 .75626 L p
.43246 .72325 L 1 g
F P
s
P
p
.002 w
.4317 .75626 m .43245 .75634 L .43245 .75505 L p
1 g
F P
s
P
p
.002 w
.43245 .75505 m .43246 .72325 L p
.4317 .75626 L 1 g
F P
s
P
p
.002 w
.43466 .75147 m .43436 .75211 L p
.43284 .75442 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.41047 .79066 m .42489 .76814 L .425 .76712 L 1 g
F
P
p
.002 w
.424 .78222 m .42579 .76511 L .42505 .76664 L p
1 g
F P
s
P
p
.424 .78222 m .42505 .76664 L .42389 .77731 L 1 g
F
P
p
.002 w
.41014 .7899 m .41047 .79066 L p
.4317 .75626 L 1 g
F P
s
P
p
.002 w
.42315 .78411 m .424 .78222 L p
.42389 .77731 L 1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.44495 .78588 m .43245 .75634 L p
.42048 .77502 L 1 g
F P
s
P
p
.002 w
.41047 .79066 m .42451 .78871 L p
.42048 .77502 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42281 .78489 L p
1 g
F P
s
P
p
.002 w
.41047 .79066 m .43665 .81595 L p
.42976 .8005 L 1 g
F P
s
P
p
.002 w
.42451 .78871 m .41954 .7894 L p
.42976 .8005 L 1 g
F P
s
P
p
.002 w
.41954 .7894 m .41047 .79066 L p
.42976 .8005 L 1 g
F P
s
P
p
.002 w
.44356 .81548 m .44427 .81291 L p
.43778 .8092 L 1 g
F P
s
P
p
.43042 .79874 m .42281 .78489 L .42667 .79356 L 1 g
F
P
p
.002 w
.42877 .80318 m .43042 .79874 L p
.42543 .79184 L 1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42976 .8005 L p
1 g
F P
s
P
p
.44427 .81291 m .42976 .8005 L .43778 .8092 L 1 g
F
P
p
.002 w
.44495 .78588 m .42451 .78871 L p
.43182 .80273 L 1 g
F P
s
P
p
.44081 .81997 m .44161 .81337 L .43182 .80273 L 1 g
F
P
p
.44161 .81337 m .44495 .78588 L .43182 .80273 L 1 g
F
P
p
.002 w
.43665 .81595 m .44081 .81997 L p
.42451 .78871 L 1 g
F P
s
P
p
.002 w
.42976 .8005 m .4285 .8039 L p
.43778 .8092 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.44081 .81997 m .44669 .81759 L p
.44152 .81411 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44339 .81611 L p
1 g
F P
s
P
p
.46403 .82325 m .44339 .81611 L .4545 .8211 L 1 g
F
P
p
.002 w
.46845 .80876 m .44669 .81759 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.44669 .81759 m .44186 .81955 L p
.4637 .82523 L 1 g
F P
s
P
p
.47772 .82887 m .44669 .81759 L .4637 .82523 L 1 g
F
P
p
.002 w
.44339 .81611 m .44274 .81844 L p
.4545 .8211 L 1 g
F P
s
P
p
.002 w
.46845 .80876 m .44495 .78588 L p
.44152 .81411 L 1 g
F P
s
P
p
.002 w
.44669 .81759 m .46845 .80876 L p
.44152 .81411 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46311 .82866 L p
1 g
F P
s
P
p
.002 w
.46311 .82866 m .4637 .82523 L p
.45278 .82169 L 1 g
F P
s
P
p
.45278 .82169 m .44274 .81844 L .46311 .82866 L 1 g
F
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44356 .81548 L p
1 g
F P
s
P
p
.43778 .8092 m .4285 .8039 L .44356 .81548 L 1 g
F
P
p
.002 w
.42281 .78489 m .42189 .78694 L p
.42667 .79356 L 1 g
F P
s
P
p
.002 w
.42451 .78871 m .44495 .78588 L p
.42048 .77502 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42877 .80318 L p
1 g
F P
s
P
p
.42543 .79184 m .42189 .78694 L .42877 .80318 L 1 g
F
P
p
.002 w
.42505 .76664 m .42372 .76938 L p
.42389 .77731 L 1 g
F P
s
P
p
.002 w
.39417 .75268 m .41014 .7899 L p
.42505 .76664 L 1 g
F P
s
P
p
.002 w
.4317 .75626 m .42623 .75574 L p
.42505 .76664 L 1 g
F P
s
P
p
.002 w
.42623 .75574 m .39417 .75268 L p
.42505 .76664 L 1 g
F P
s
P
p
.002 w
.43245 .75634 m .4317 .75626 L p
.425 .76712 L 1 g
F P
s
P
p
.42489 .76814 m .43245 .75634 L .425 .76712 L 1 g
F
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42315 .78411 L p
1 g
F P
s
P
p
.42389 .77731 m .42372 .76938 L .42315 .78411 L 1 g
F
P
p
.002 w
.43436 .75211 m .43389 .75311 L p
.43048 .75816 L 1 g
F P
s
P
p
.002 w
.43245 .74452 m .43245 .75505 L p
.44052 .74179 L 1 g
F P
s
P
p
.002 w
.42372 .76938 m .42579 .76511 L p
.43121 .75708 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .4238 .76925 L p
.43121 .75708 L 1 g
F P
s
P
p
.002 w
.4238 .76925 m .42372 .76938 L p
.43121 .75708 L 1 g
F P
s
P
p
.002 w
.47448 .73029 m .47424 .73141 L p
.46422 .73376 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .45268 .73647 L p
.468 .73288 L 1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.46871 .73224 m .43246 .72325 L .43245 .74452 L p
1 g
F P
s
P
p
.002 w
.4769 .72326 m .47422 .73015 L p
.48662 .7247 L 1 g
F P
s
P
p
.002 w
.47424 .73141 m .45475 .73869 L p
.468 .73288 L 1 g
F P
s
P
p
.002 w
.45475 .73869 m .45136 .73996 L p
.468 .73288 L 1 g
F P
s
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72668 L p
1 g
F P
s
P
p
.002 w
.5 .72668 m .5 .72527 L p
.51562 .72899 L 1 g
F P
s
P
p
.51562 .72899 m .52576 .73141 L .5 .72668 L 1 g
F
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.51878 .72852 m .48175 .71082 L .4769 .72326 L p
1 g
F P
s
P
p
.51507 .72891 m .51878 .72852 L .4769 .72326 L 1 g
F
P
p
.002 w
.51843 .72941 m .51878 .72852 L p
.51507 .72891 L 1 g
F P
s
P
p
.51562 .72899 m .51843 .72941 L .51694 .72931 L 1 g
F
P
p
.002 w
.5523 .74171 m .52157 .72962 L p
.55353 .7427 L 1 g
F P
s
P
p
.002 w
.52157 .72962 m .51878 .72852 L p
.52145 .72961 L 1 g
F P
s
P
p
.55353 .7427 m .52157 .72962 L .52145 .72961 L 1 g
F
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52543 .72987 L p
1 g
F P
s
P
p
.002 w
.52543 .72987 m .52506 .72815 L p
.53725 .73426 L 1 g
F P
s
P
p
.53725 .73426 m .54864 .73996 L .52543 .72987 L 1 g
F
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.52202 .7286 m .53863 .7307 L .52567 .72025 L 1 g
F
P
p
.52157 .72962 m .52543 .72987 L .52202 .7286 L 1 g
F
P
p
.52543 .72987 m .53863 .7307 L .52202 .7286 L 1 g
F
P
p
.52543 .72987 m .54799 .73824 L .53863 .7307 L 1 g
F
P
p
.002 w
.54799 .73824 m .54864 .73996 L p
.53725 .73426 L 1 g
F P
s
P
p
.002 w
.52567 .72025 m .51878 .72852 L .52157 .72962 L p
1 g
F P
s
P
p
.002 w
.52543 .72987 m .52543 .72988 L p
.52529 .72986 L 1 g
F P
s
P
p
.002 w
.52543 .72988 m .52576 .73141 L p
.51694 .72931 L 1 g
F P
s
P
p
.002 w
.51878 .72852 m .51843 .72941 L p
.52145 .72961 L 1 g
F P
s
P
p
.54732 .73647 m .55456 .7435 L .55411 .74316 L 1 g
F
P
p
.55395 .74304 m .55411 .74316 L .55397 .74306 L 1 g
F
P
p
.54732 .73647 m .55411 .74316 L .55395 .74304 L 1 g
F
P
p
.002 w
.5143 .73989 m .51416 .75135 L .55397 .74305 L p
1 g
F P
s
P
p
.002 w
.55353 .7427 m .5143 .73989 L p
.55397 .74305 L 1 g
F P
s
P
p
.54732 .73647 m .55397 .74306 L .55376 .74289 L 1 g
F
P
p
.002 w
.54799 .73824 m .54732 .73647 L p
.55379 .74292 L 1 g
F P
s
P
p
.002 w
.55397 .74305 m .5551 .74281 L .55353 .7427 L p
1 g
F P
s
P
p
.002 w
.55353 .7427 m .5551 .74281 L .5523 .74171 L p
1 g
F P
s
P
p
.55376 .74289 m .55397 .74306 L .55379 .74292 L 1 g
F
P
p
.002 w
.54811 .73857 m .54799 .73824 L p
.55379 .74292 L 1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.5551 .74281 m .52714 .71848 L .52567 .72025 L p
1 g
F P
s
P
p
.002 w
.5523 .74171 m .5551 .74281 L p
.52567 .72025 L 1 g
F P
s
P
p
.002 w
.55423 .74326 m .5551 .74281 L .55397 .74305 L p
1 g
F P
s
P
p
.002 w
.54822 .73883 m .54811 .73857 L p
.55423 .74326 L 1 g
F P
s
P
p
.55423 .74326 m .55456 .7435 L .55445 .74343 L 1 g
F
P
p
.55423 .74326 m .55445 .74343 L .54822 .73883 L 1 g
F
P
p
.002 w
.55445 .74342 m .5551 .74281 L .55423 .74326 L p
1 g
F P
s
P
p
.002 w
.55467 .74359 m .5551 .74281 L .55445 .74342 L p
1 g
F P
s
P
p
.002 w
.54826 .73894 m .54822 .73883 L p
.55467 .74359 L 1 g
F P
s
P
p
.55467 .74359 m .55496 .7438 L .5548 .74368 L 1 g
F
P
p
.55467 .74359 m .5548 .74368 L .54826 .73894 L 1 g
F
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.53754 .77455 m .55039 .77582 L .55496 .7438 L p
1 g
F P
s
P
p
.002 w
.55496 .7438 m .5551 .74281 L .55467 .74359 L p
1 g
F P
s
P
p
.002 w
.55548 .74418 m .5551 .74281 L .55496 .7438 L p
1 g
F P
s
P
p
.002 w
.55496 .7438 m .55039 .77582 L p
.55548 .74418 L 1 g
F P
s
P
p
.002 w
.54829 .73902 m .54826 .73894 L p
.55548 .74418 L 1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54829 .73902 L p
1 g
F P
s
P
p
.55831 .7462 m .56611 .75311 L .54829 .73902 L 1 g
F
P
p
.002 w
.5551 .74281 m .55548 .74418 L p
.55726 .74545 L 1 g
F P
s
P
p
.56344 .74831 m .55745 .74559 L .56516 .75109 L 1 g
F
P
p
.002 w
.57539 .76758 m .56365 .77332 L p
.58551 .78319 L 1 g
F P
s
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57544 .76765 L p
1 g
F P
s
P
p
.57622 .77637 m .57811 .78694 L .57544 .76765 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56431 .74928 L p
1 g
F P
s
P
p
.56344 .74831 m .56516 .75109 L .58125 .76257 L 1 g
F
P
p
.002 w
.5759 .76733 m .58125 .76257 L p
.56516 .75109 L 1 g
F P
s
P
p
.002 w
.57343 .76441 m .5759 .76733 L p
.56516 .75109 L 1 g
F P
s
P
p
.57087 .76029 m .57343 .76441 L .57311 .76405 L 1 g
F
P
p
.57343 .76441 m .57539 .76758 L .57536 .76753 L 1 g
F
P
p
.57343 .76441 m .57536 .76753 L .57311 .76405 L 1 g
F
P
p
.002 w
.56516 .75109 m .56518 .75113 L p
.56495 .75094 L 1 g
F P
s
P
p
.002 w
.58583 .75849 m .5551 .74281 L .55745 .74559 L p
1 g
F P
s
P
p
.002 w
.55745 .74559 m .5551 .74281 L p
.55726 .74545 L 1 g
F P
s
P
p
.002 w
.56518 .75113 m .56611 .75311 L p
.55831 .7462 L 1 g
F P
s
P
p
.002 w
.57539 .76758 m .5759 .76733 L .57343 .76441 L p
1 g
F P
s
P
p
.002 w
.59432 .78717 m .5759 .76733 L .57539 .76758 L p
1 g
F P
s
P
p
.59432 .78717 m .57539 .76758 L .58551 .78319 L 1 g
F
P
p
.002 w
.57544 .76765 m .57628 .76938 L p
.57311 .76405 L 1 g
F P
s
P
p
.002 w
.57693 .7843 m .57811 .78694 L p
.57622 .77637 L 1 g
F P
s
P
p
.5734 .79476 m .57234 .79791 L .57307 .79634 L 1 g
F
P
p
.002 w
.56365 .77332 m .57031 .7989 L .57234 .79791 L p
1 g
F P
s
P
p
.57307 .79634 m .57083 .80114 L .57287 .79731 L 1 g
F
P
p
.002 w
.57031 .7989 m .57083 .80114 L p
.57182 .79901 L 1 g
F P
s
P
p
.002 w
.57062 .80153 m .5715 .8039 L p
.57287 .79731 L 1 g
F P
s
P
p
.56121 .81214 m .56002 .81156 L .55632 .81506 L 1 g
F
P
p
.56381 .80797 m .55726 .81844 L .57062 .80153 L 1 g
F
P
p
.55632 .81506 m .54432 .80382 L .53822 .82587 L 1 g
F
P
p
.56002 .81156 m .54432 .80382 L .55632 .81506 L 1 g
F
P
p
.002 w
.55632 .81506 m .55726 .81844 L p
.56381 .80797 L 1 g
F P
s
P
p
.002 w
.54432 .80382 m .53709 .82608 L .53822 .82587 L p
1 g
F P
s
P
p
.54358 .82335 m .53822 .82587 L .54175 .82492 L 1 g
F
P
p
.53822 .82587 m .53688 .8265 L .5375 .8263 L 1 g
F
P
p
.53822 .82587 m .5375 .8263 L .54175 .82492 L 1 g
F
P
p
.002 w
.53709 .82608 m .53688 .8265 L p
.53758 .82617 L 1 g
F P
s
P
p
.002 w
.53822 .82587 m .53709 .82608 L p
.53758 .82617 L 1 g
F P
s
P
p
.54175 .82492 m .53688 .8265 L .53695 .82905 L 1 g
F
P
p
.002 w
.53654 .82661 m .53655 .82666 L p
.53688 .8265 L 1 g
F P
s
P
p
.002 w
.53655 .82666 m .53695 .82905 L p
.53688 .8265 L 1 g
F P
s
P
p
.002 w
.51253 .83064 m .51276 .83464 L p
.52526 .82851 L 1 g
F P
s
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51253 .83064 L p
1 g
F P
s
P
p
.50241 .83106 m .48724 .83464 L .51253 .83064 L 1 g
F
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.53709 .82608 m .50031 .82261 L p
.51215 .83066 L 1 g
F P
s
P
p
.002 w
.50031 .82261 m .48925 .83159 L p
.51215 .83066 L 1 g
F P
s
P
p
.47844 .83043 m .48742 .8314 L .47772 .82887 L 1 g
F
P
p
.48177 .83767 m .48742 .8314 L .47844 .83043 L 1 g
F
P
p
.002 w
.48741 .83167 m .48758 .82869 L p
.4667 .82989 L 1 g
F P
s
P
p
.002 w
.48899 .83181 m .50031 .82261 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.48742 .8314 m .48724 .83464 L p
.49672 .8324 L 1 g
F P
s
P
p
.4545 .8211 m .44274 .81844 L .4637 .82523 L 1 g
F
P
p
.002 w
.46305 .82905 m .4667 .82989 L p
.47894 .82919 L 1 g
F P
s
P
p
.47758 .82884 m .46305 .82905 L .47894 .82919 L 1 g
F
P
p
.002 w
.4667 .82989 m .48724 .83464 L .48741 .83167 L p
1 g
F P
s
P
p
.002 w
.53655 .82666 m .53654 .82661 L p
.51434 .83386 L 1 g
F P
s
P
p
.52526 .82851 m .51434 .83386 L .53654 .82661 L 1 g
F
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53655 .82666 L p
1 g
F P
s
P
p
.51434 .83386 m .51276 .83464 L .53655 .82666 L 1 g
F
P
p
.002 w
.57491 .8189 m .57737 .83284 L .62209 .811 L p
1 g
F P
s
P
p
.002 w
.62209 .811 m .60985 .80183 L .57491 .8189 L p
1 g
F P
s
P
p
.002 w
.60985 .80183 m .62209 .811 L .65852 .77877 L p
1 g
F P
s
P
p
.002 w
.46948 .38048 m .47755 .39392 L .55655 .39173 L p
1 g
F P
s
P
p
.002 w
.47755 .39392 m .46948 .38048 L .39481 .40495 L p
1 g
F P
s
P
p
.002 w
.72182 .60346 m .73055 .57766 L .6983 .52524 L p
1 g
F P
s
P
p
.002 w
.69892 .49778 m .6983 .52524 L .73055 .57766 L p
1 g
F P
s
P
p
.002 w
.39481 .40495 m .40018 .41929 L .47755 .39392 L p
1 g
F P
s
P
p
.002 w
.30604 .56868 m .29273 .54592 L .26804 .61426 L p
1 g
F P
s
P
p
.002 w
.26804 .61426 m .28176 .63544 L .30604 .56868 L p
1 g
F P
s
P
p
.002 w
.3413 .48519 m .33354 .46491 L .28536 .52531 L p
1 g
F P
s
P
p
.002 w
.28536 .52531 m .29273 .54592 L .3413 .48519 L p
1 g
F P
s
P
p
.002 w
.65852 .77877 m .63826 .77665 L .60985 .80183 L p
1 g
F P
s
P
p
.002 w
.63826 .77665 m .65852 .77877 L .6828 .73942 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.41047 .79066 m .37884 .79037 L .41517 .82526 L p
1 g
F P
s
P
p
.002 w
.41517 .82526 m .44081 .81997 L .41047 .79066 L p
1 g
F P
s
P
p
.002 w
.6983 .52524 m .69892 .49778 L .64392 .45742 L p
1 g
F P
s
P
p
.002 w
.63782 .4324 m .64392 .45742 L .69892 .49778 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.35918 .74508 m .32847 .73381 L .35095 .78512 L p
1 g
F P
s
P
p
.002 w
.35095 .78512 m .37884 .79037 L .35918 .74508 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.55655 .39173 m .56592 .41142 L .63782 .4324 L p
1 g
F P
s
P
p
.002 w
.56592 .41142 m .55655 .39173 L .47755 .39392 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.64392 .45742 m .63782 .4324 L .56592 .41142 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.71444 .67887 m .69227 .69699 L .6828 .73942 L p
1 g
F P
s
P
p
.002 w
.69227 .69699 m .71444 .67887 L .70675 .62981 L p
1 g
F P
s
P
p
.002 w
.72182 .60346 m .70675 .62981 L .71444 .67887 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.32767 .67598 m .3018 .65622 L .30288 .71926 L p
1 g
F P
s
P
p
.002 w
.30288 .71926 m .32847 .73381 L .32767 .67598 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.6828 .73942 m .65714 .74595 L .63826 .77665 L p
1 g
F P
s
P
p
.002 w
.65714 .74595 m .6828 .73942 L .69227 .69699 L p
1 g
F P
s
P
p
.002 w
.40845 .43928 m .40018 .41929 L .33354 .46491 L p
1 g
F P
s
P
p
.002 w
.33354 .46491 m .3413 .48519 L .40845 .43928 L p
1 g
F P
s
P
p
.002 w
.70675 .62981 m .72182 .60346 L .6921 .55548 L p
1 g
F P
s
P
p
.002 w
.6983 .52524 m .6921 .55548 L .72182 .60346 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.32501 .59294 m .30604 .56868 L .28176 .63544 L p
1 g
F P
s
P
p
.002 w
.28176 .63544 m .3018 .65622 L .32501 .59294 L p
1 g
F P
s
P
p
.002 w
.59432 .78717 m .60985 .80183 L .63826 .77665 L p
1 g
F P
s
P
p
.002 w
.47755 .39392 m .48638 .41371 L .56592 .41142 L p
1 g
F P
s
P
p
.002 w
.48638 .41371 m .47755 .39392 L .40018 .41929 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.35366 .50933 m .3413 .48519 L .29273 .54592 L p
1 g
F P
s
P
p
.002 w
.29273 .54592 m .30604 .56868 L .35366 .50933 L p
1 g
F P
s
P
p
.002 w
.51908 .8014 m .50031 .82261 L .53709 .82608 L p
1 g
F P
s
P
p
.002 w
.53709 .82608 m .54432 .80382 L .51908 .8014 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.40018 .41929 m .40845 .43928 L .48638 .41371 L p
1 g
F P
s
P
p
.002 w
.6921 .55548 m .6983 .52524 L .64603 .48711 L p
1 g
F P
s
P
p
.002 w
.64392 .45742 m .64603 .48711 L .6983 .52524 L p
1 g
F P
s
P
p
.002 w
.39417 .75268 m .35918 .74508 L .37884 .79037 L p
1 g
F P
s
P
p
.002 w
.37884 .79037 m .41047 .79066 L .39417 .75268 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.63826 .77665 m .61382 .76986 L .59432 .78717 L p
1 g
F P
s
P
p
.002 w
.61382 .76986 m .63826 .77665 L .65714 .74595 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.64603 .48711 m .64392 .45742 L .57356 .43704 L p
1 g
F P
s
P
p
.002 w
.56592 .41142 m .57356 .43704 L .64392 .45742 L p
1 g
F P
s
P
p
.002 w
.57356 .43704 m .56592 .41142 L .48638 .41371 L p
1 g
F P
s
P
p
.002 w
.49729 .79184 m .46845 .80876 L .50031 .82261 L p
1 g
F P
s
P
p
.002 w
.50031 .82261 m .51908 .8014 L .49729 .79184 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.35869 .69412 m .32767 .67598 L .32847 .73381 L p
1 g
F P
s
P
p
.002 w
.32847 .73381 m .35918 .74508 L .35869 .69412 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.69227 .69699 m .66441 .71292 L .65714 .74595 L p
1 g
F P
s
P
p
.002 w
.66441 .71292 m .69227 .69699 L .68568 .65594 L p
1 g
F P
s
P
p
.002 w
.70675 .62981 m .68568 .65594 L .69227 .69699 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.68568 .65594 m .70675 .62981 L .68039 .58763 L p
1 g
F P
s
P
p
.002 w
.6921 .55548 m .68039 .58763 L .70675 .62981 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.65714 .74595 m .62672 .74878 L .61382 .76986 L p
1 g
F P
s
P
p
.002 w
.62672 .74878 m .65714 .74595 L .66441 .71292 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.34916 .61799 m .32501 .59294 L .3018 .65622 L p
1 g
F P
s
P
p
.002 w
.3018 .65622 m .32767 .67598 L .34916 .61799 L p
1 g
F P
s
P
p
.002 w
.41943 .46444 m .40845 .43928 L .3413 .48519 L p
1 g
F P
s
P
p
.002 w
.3413 .48519 m .35366 .50933 L .41943 .46444 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.68039 .58763 m .6921 .55548 L .64402 .52067 L p
1 g
F P
s
P
p
.002 w
.64603 .48711 m .64402 .52067 L .6921 .55548 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.55039 .77582 m .54432 .80382 L .57031 .7989 L p
1 g
F P
s
P
p
.002 w
.57031 .7989 m .56365 .77332 L .55039 .77582 L p
1 g
F P
s
P
p
.002 w
.48129 .77613 m .44495 .78588 L .46845 .80876 L p
1 g
F P
s
P
p
.002 w
.46845 .80876 m .49729 .79184 L .48129 .77613 L p
1 g
F P
s
P
p
.002 w
.5759 .76733 m .59432 .78717 L .61382 .76986 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.37034 .53669 m .35366 .50933 L .30604 .56868 L p
1 g
F P
s
P
p
.002 w
.30604 .56868 m .32501 .59294 L .37034 .53669 L p
1 g
F P
s
P
p
.002 w
.48638 .41371 m .49572 .43938 L .57356 .43704 L p
1 g
F P
s
P
p
.002 w
.49572 .43938 m .48638 .41371 L .40845 .43928 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.53754 .77455 m .51908 .8014 L .54432 .80382 L p
1 g
F P
s
P
p
.002 w
.54432 .80382 m .55039 .77582 L .53754 .77455 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.40845 .43928 m .41943 .46444 L .49572 .43938 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.61382 .76986 m .58583 .75849 L .5759 .76733 L p
1 g
F P
s
P
p
.002 w
.58583 .75849 m .61382 .76986 L .62672 .74878 L p
1 g
F P
s
P
p
.002 w
.39397 .71004 m .35869 .69412 L .35918 .74508 L p
1 g
F P
s
P
p
.002 w
.35918 .74508 m .39417 .75268 L .39397 .71004 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.66441 .71292 m .63161 .72615 L .62672 .74878 L p
1 g
F P
s
P
p
.002 w
.63161 .72615 m .66441 .71292 L .65915 .68106 L p
1 g
F P
s
P
p
.002 w
.68568 .65594 m .65915 .68106 L .66441 .71292 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.64402 .52067 m .64603 .48711 L .5792 .46794 L p
1 g
F P
s
P
p
.002 w
.57356 .43704 m .5792 .46794 L .64603 .48711 L p
1 g
F P
s
P
p
.002 w
.65915 .68106 m .68568 .65594 L .66346 .62075 L p
1 g
F P
s
P
p
.002 w
.68039 .58763 m .66346 .62075 L .68568 .65594 L p
1 g
F P
s
P
p
.002 w
.52647 .76966 m .49729 .79184 L .51908 .8014 L p
1 g
F P
s
P
p
.002 w
.51908 .8014 m .53754 .77455 L .52647 .76966 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.5792 .46794 m .57356 .43704 L .49572 .43938 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.62672 .74878 m .59237 .74774 L .58583 .75849 L p
1 g
F P
s
P
p
.002 w
.59237 .74774 m .62672 .74878 L .63161 .72615 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.37782 .64307 m .34916 .61799 L .32767 .67598 L p
1 g
F P
s
P
p
.002 w
.32767 .67598 m .35869 .69412 L .37782 .64307 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.47286 .7559 m .43245 .75634 L .44495 .78588 L p
1 g
F P
s
P
p
.002 w
.44495 .78588 m .48129 .77613 L .47286 .7559 L p
1 g
F P
s
P
p
.002 w
.66346 .62075 m .68039 .58763 L .6379 .55713 L p
1 g
F P
s
P
p
.002 w
.64402 .52067 m .6379 .55713 L .68039 .58763 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.51838 .76164 m .48129 .77613 L .49729 .79184 L p
1 g
F P
s
P
p
.002 w
.49729 .79184 m .52647 .76966 L .51838 .76164 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.43284 .49411 m .41943 .46444 L .35366 .50933 L p
1 g
F P
s
P
p
.002 w
.35366 .50933 m .37034 .53669 L .43284 .49411 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.43246 .72325 m .39397 .71004 L .39417 .75268 L p
1 g
F P
s
P
p
.002 w
.39089 .56646 m .37034 .53669 L .32501 .59294 L p
1 g
F P
s
P
p
.002 w
.32501 .59294 m .34916 .61799 L .39089 .56646 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.63161 .72615 m .59481 .73623 L .59237 .74774 L p
1 g
F P
s
P
p
.002 w
.59481 .73623 m .63161 .72615 L .62791 .70439 L p
1 g
F P
s
P
p
.002 w
.65915 .68106 m .62791 .70439 L .63161 .72615 L p
1 g
F P
s
P
p
.002 w
.62791 .70439 m .65915 .68106 L .64176 .65383 L p
1 g
F P
s
P
p
.002 w
.66346 .62075 m .64176 .65383 L .65915 .68106 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.49572 .43938 m .50529 .47028 L .5792 .46794 L p
1 g
F P
s
P
p
.002 w
.50529 .47028 m .49572 .43938 L .41943 .46444 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.6379 .55713 m .64402 .52067 L .58265 .50325 L p
1 g
F P
s
P
p
.002 w
.5792 .46794 m .58265 .50325 L .64402 .52067 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.59237 .74774 m .5551 .74281 L .58583 .75849 L closepath p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41943 .46444 m .43284 .49411 L .50529 .47028 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.51416 .75135 m .47286 .7559 L .48129 .77613 L p
1 g
F P
s
P
p
.002 w
.48129 .77613 m .51838 .76164 L .51416 .75135 L p
1 g
F P
s
P
p
.002 w
.59481 .73623 m .5551 .74281 L .59237 .74774 L closepath p
1 g
F P
s
P
p
.002 w
.58265 .50325 m .5792 .46794 L .50529 .47028 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.64176 .65383 m .66346 .62075 L .62779 .59539 L p
1 g
F P
s
P
p
.002 w
.6379 .55713 m .62779 .59539 L .66346 .62075 L p
1 g
F P
s
P
p
.002 w
.41015 .66741 m .37782 .64307 L .35869 .69412 L p
1 g
F P
s
P
p
.002 w
.35869 .69412 m .39397 .71004 L .41015 .66741 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.43245 .75634 m .47286 .7559 L .47299 .7333 L p
1 g
F P
s
P
p
.002 w
.62791 .70439 m .59287 .72519 L .59481 .73623 L p
1 g
F P
s
P
p
.002 w
.59287 .72519 m .62791 .70439 L .61593 .68586 L p
1 g
F P
s
P
p
.002 w
.64176 .65383 m .61593 .68586 L .62791 .70439 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.59287 .72519 m .5551 .74281 L .59481 .73623 L closepath p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.41472 .59775 m .39089 .56646 L .34916 .61799 L p
1 g
F P
s
P
p
.002 w
.34916 .61799 m .37782 .64307 L .41472 .59775 L p
1 g
F P
s
P
p
.002 w
.4483 .52743 m .43284 .49411 L .37034 .53669 L p
1 g
F P
s
P
p
.002 w
.37034 .53669 m .39089 .56646 L .4483 .52743 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.62779 .59539 m .6379 .55713 L .58375 .54196 L p
1 g
F P
s
P
p
.002 w
.58265 .50325 m .58375 .54196 L .6379 .55713 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.61593 .68586 m .64176 .65383 L .61399 .63429 L p
1 g
F P
s
P
p
.002 w
.62779 .59539 m .61399 .63429 L .64176 .65383 L p
1 g
F P
s
P
p
.002 w
.5143 .73989 m .47299 .7333 L .47286 .7559 L p
1 g
F P
s
P
p
.002 w
.47286 .7559 m .51416 .75135 L .5143 .73989 L p
1 g
F P
s
P
p
.002 w
.58674 .71583 m .5551 .74281 L .59287 .72519 L closepath p
1 g
F P
s
P
p
.002 w
.61593 .68586 m .58674 .71583 L .59287 .72519 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.44515 .69023 m .41015 .66741 L .39397 .71004 L p
1 g
F P
s
P
p
.002 w
.39397 .71004 m .43246 .72325 L .44515 .69023 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.57706 .70917 m .5551 .74281 L .58674 .71583 L closepath p
1 g
F P
s
P
p
.002 w
.56489 .70595 m .5551 .74281 L .57706 .70917 L closepath p
1 g
F P
s
P
p
.002 w
.55154 .70654 m .5551 .74281 L .56489 .70595 L closepath p
1 g
F P
s
P
p
.002 w
.53848 .71087 m .5551 .74281 L .55154 .70654 L closepath p
1 g
F P
s
P
p
.004 w
.5 .6118 m
.54127 .70994 L
s
P
p
.002 w
.52714 .71848 m .5551 .74281 L .53848 .71087 L closepath p
1 g
F P
s
P
p
.002 w
.50529 .47028 m .5148 .50553 L .58265 .50325 L p
1 g
F P
s
P
p
.002 w
.5148 .50553 m .50529 .47028 L .43284 .49411 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.58674 .71583 m .61593 .68586 L .5969 .67262 L p
1 g
F P
s
P
p
.002 w
.61399 .63429 m .5969 .67262 L .61593 .68586 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.004 w
.5551 .74281 m
.55671 .74666 L
s
P
p
.002 w
.58375 .54196 m .58265 .50325 L .5148 .50553 L p
1 g
F P
s
P
p
.002 w
.43284 .49411 m .4483 .52743 L .5148 .50553 L p
1 g
F P
s
P
p
.002 w
.5969 .67262 m .57706 .70917 L .58674 .71583 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.48175 .71082 m .44515 .69023 L .43246 .72325 L p
1 g
F P
s
P
p
.002 w
.61399 .63429 m .62779 .59539 L .58246 .58287 L p
1 g
F P
s
P
p
.002 w
.58375 .54196 m .58246 .58287 L .62779 .59539 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.44111 .62959 m .41472 .59775 L .37782 .64307 L p
1 g
F P
s
P
p
.002 w
.37782 .64307 m .41015 .66741 L .44111 .62959 L p
1 g
F P
s
P
p
.002 w
.57706 .70917 m .5969 .67262 L .57287 .66617 L p
1 g
F P
s
P
p
.002 w
.57287 .66617 m .56489 .70595 L .57706 .70917 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.48175 .71082 m .51878 .72852 L .52714 .71848 L p
1 g
F P
s
P
p
.002 w
.46536 .56341 m .4483 .52743 L .39089 .56646 L p
1 g
F P
s
P
p
.002 w
.39089 .56646 m .41472 .59775 L .46536 .56341 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.5969 .67262 m .61399 .63429 L .57879 .62471 L p
1 g
F P
s
P
p
.002 w
.58246 .58287 m .57879 .62471 L .61399 .63429 L p
1 g
F P
s
P
p
.002 w
.57879 .62471 m .57287 .66617 L .5969 .67262 L p
1 g
F P
s
P
p
.002 w
.56489 .70595 m .57287 .66617 L .54647 .66728 L p
1 g
F P
s
P
p
.002 w
.54647 .66728 m .55154 .70654 L .56489 .70595 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.52714 .71848 m .49822 .69092 L .48175 .71082 L p
1 g
F P
s
P
p
.002 w
.49822 .69092 m .52714 .71848 L .53848 .71087 L p
1 g
F P
s
P
p
.002 w
.58246 .58287 m .58375 .54196 L .52396 .54408 L p
1 g
F P
s
P
p
.002 w
.5148 .50553 m .52396 .54408 L .58375 .54196 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55154 .70654 m .54647 .66728 L .52063 .67584 L p
1 g
F P
s
P
p
.002 w
.52063 .67584 m .53848 .71087 L .55154 .70654 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.52396 .54408 m .5148 .50553 L .4483 .52743 L p
1 g
F P
s
P
p
.004 w
.4772 .53379 m
.5 .6118 L
s
P
p
.004 w
.46246 .48333 m
.47479 .52555 L
s
P
p
.002 w
.53848 .71087 m .52063 .67584 L .49822 .69092 L p
1 g
F P
s
P
p
.002 w
.46924 .66098 m .44111 .62959 L .41015 .66741 L p
1 g
F P
s
P
p
.002 w
.41015 .66741 m .44515 .69023 L .46924 .66098 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.44515 .69023 m .48175 .71082 L .49822 .69092 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.4483 .52743 m .46536 .56341 L .52396 .54408 L p
1 g
F P
s
P
p
.004 w
.47479 .52555 m
.47571 .52868 L
s
P
p
.004 w
.47571 .52868 m
.47589 .52931 L
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.49822 .69092 m .46924 .66098 L .44515 .69023 L p
1 g
F P
s
P
p
.002 w
.57287 .66617 m .57879 .62471 L .54005 .62625 L p
1 g
F P
s
P
p
.002 w
.54005 .62625 m .54647 .66728 L .57287 .66617 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.57879 .62471 m .58246 .58287 L .53246 .58475 L p
1 g
F P
s
P
p
.002 w
.52396 .54408 m .53246 .58475 L .58246 .58287 L p
1 g
F P
s
P
p
.002 w
.48348 .60093 m .46536 .56341 L .41472 .59775 L p
1 g
F P
s
P
p
.002 w
.41472 .59775 m .44111 .62959 L .48348 .60093 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.53246 .58475 m .54005 .62625 L .57879 .62471 L p
1 g
F P
s
P
p
.002 w
.46924 .66098 m .49822 .69092 L .52063 .67584 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.54647 .66728 m .54005 .62625 L .5021 .63881 L p
1 g
F P
s
P
p
.002 w
.5021 .63881 m .52063 .67584 L .54647 .66728 L p
1 g
F P
s
P
p
.002 w
.53246 .58475 m .52396 .54408 L .46536 .56341 L p
1 g
F P
s
P
p
.002 w
.52063 .67584 m .5021 .63881 L .46924 .66098 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.5021 .63881 m .48348 .60093 L .44111 .62959 L p
1 g
F P
s
P
p
.002 w
.44111 .62959 m .46924 .66098 L .5021 .63881 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.46536 .56341 m .48348 .60093 L .53246 .58475 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.54005 .62625 m .53246 .58475 L .48348 .60093 L p
1 g
F P
s
P
p
.002 w
.48348 .60093 m .5021 .63881 L .54005 .62625 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.004 w
.57584 .79214 m
.58455 .81284 L
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.004 w
.55671 .74666 m
.57584 .79214 L
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .46246 .48333 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58455 .81284 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.07)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.07)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.45343 .67667 m .44529 .63983 L .49813 .62344 L p
1 g
F P
s
P
p
.002 w
.49813 .62344 m .5136 .65793 L .45343 .67667 L p
1 g
F P
s
P
p
.002 w
.48272 .58868 m .49813 .62344 L .44529 .63983 L p
1 g
F P
s
P
p
.002 w
.5136 .65793 m .49813 .62344 L .54597 .59506 L p
1 g
F P
s
P
p
.002 w
.49813 .62344 m .48272 .58868 L .52265 .56495 L p
1 g
F P
s
P
p
.002 w
.52265 .56495 m .54597 .59506 L .49813 .62344 L p
1 g
F P
s
P
p
.002 w
.44529 .63983 m .43858 .6023 L .48272 .58868 L p
1 g
F P
s
P
p
.002 w
.46772 .55444 m .48272 .58868 L .43858 .6023 L p
1 g
F P
s
P
p
.002 w
.48272 .58868 m .46772 .55444 L .4987 .536 L p
1 g
F P
s
P
p
.002 w
.4987 .536 m .52265 .56495 L .48272 .58868 L p
1 g
F P
s
P
p
.002 w
.46281 .71195 m .45343 .67667 L .5136 .65793 L p
1 g
F P
s
P
p
.002 w
.5136 .65793 m .52877 .69134 L .46281 .71195 L p
1 g
F P
s
P
p
.002 w
.52877 .69134 m .5136 .65793 L .56813 .62564 L p
1 g
F P
s
P
p
.002 w
.54597 .59506 m .56813 .62564 L .5136 .65793 L p
1 g
F P
s
P
p
.002 w
.56813 .62564 m .54597 .59506 L .58399 .55749 L p
1 g
F P
s
P
p
.002 w
.54597 .59506 m .52265 .56495 L .5543 .5335 L p
1 g
F P
s
P
p
.002 w
.5543 .5335 m .58399 .55749 L .54597 .59506 L p
1 g
F P
s
P
p
.002 w
.52265 .56495 m .4987 .536 L .52319 .51155 L p
1 g
F P
s
P
p
.002 w
.52319 .51155 m .5543 .5335 L .52265 .56495 L p
1 g
F P
s
P
p
.002 w
.39357 .67989 m .39275 .64249 L .44529 .63983 L p
1 g
F P
s
P
p
.002 w
.44529 .63983 m .45343 .67667 L .39357 .67989 L p
1 g
F P
s
P
p
.002 w
.43858 .6023 m .44529 .63983 L .39275 .64249 L p
1 g
F P
s
P
p
.002 w
.39275 .64249 m .39472 .60439 L .43858 .6023 L p
1 g
F P
s
P
p
.002 w
.43345 .56498 m .43858 .6023 L .39472 .60439 L p
1 g
F P
s
P
p
.002 w
.43858 .6023 m .43345 .56498 L .46772 .55444 L p
1 g
F P
s
P
p
.002 w
.4535 .52154 m .46772 .55444 L .43345 .56498 L p
1 g
F P
s
P
p
.002 w
.46772 .55444 m .4535 .52154 L .47468 .50891 L p
1 g
F P
s
P
p
.002 w
.47468 .50891 m .4987 .536 L .46772 .55444 L p
1 g
F P
s
P
p
.002 w
.56813 .62564 m .58858 .65597 L .52877 .69134 L p
1 g
F P
s
P
p
.002 w
.58858 .65597 m .56813 .62564 L .61155 .58294 L p
1 g
F P
s
P
p
.002 w
.58399 .55749 m .61155 .58294 L .56813 .62564 L p
1 g
F P
s
P
p
.002 w
.4987 .536 m .47468 .50891 L .49138 .49215 L p
1 g
F P
s
P
p
.002 w
.49138 .49215 m .52319 .51155 L .4987 .536 L p
1 g
F P
s
P
p
.002 w
.39719 .71568 m .39357 .67989 L .45343 .67667 L p
1 g
F P
s
P
p
.002 w
.45343 .67667 m .46281 .71195 L .39719 .71568 L p
1 g
F P
s
P
p
.002 w
.39472 .60439 m .39944 .56649 L .43345 .56498 L p
1 g
F P
s
P
p
.002 w
.43005 .52872 m .43345 .56498 L .39944 .56649 L p
1 g
F P
s
P
p
.002 w
.43345 .56498 m .43005 .52872 L .4535 .52154 L p
1 g
F P
s
P
p
.002 w
.47323 .74484 m .46281 .71195 L .52877 .69134 L p
1 g
F P
s
P
p
.002 w
.52877 .69134 m .54328 .72287 L .47323 .74484 L p
1 g
F P
s
P
p
.002 w
.54328 .72287 m .52877 .69134 L .58858 .65597 L p
1 g
F P
s
P
p
.002 w
.58399 .55749 m .5543 .5335 L .57433 .49751 L p
1 g
F P
s
P
p
.002 w
.5543 .5335 m .52319 .51155 L .53858 .48358 L p
1 g
F P
s
P
p
.002 w
.53858 .48358 m .57433 .49751 L .5543 .5335 L p
1 g
F P
s
P
p
.002 w
.58858 .65597 m .60685 .68533 L .54328 .72287 L p
1 g
F P
s
P
p
.002 w
.60685 .68533 m .58858 .65597 L .63632 .60927 L p
1 g
F P
s
P
p
.002 w
.61155 .58294 m .63632 .60927 L .58858 .65597 L p
1 g
F P
s
P
p
.002 w
.61155 .58294 m .58399 .55749 L .6082 .51445 L p
1 g
F P
s
P
p
.002 w
.57433 .49751 m .6082 .51445 L .58399 .55749 L p
1 g
F P
s
P
p
.002 w
.44039 .49077 m .4535 .52154 L .43005 .52872 L p
1 g
F P
s
P
p
.002 w
.4535 .52154 m .44039 .49077 L .45117 .48433 L p
1 g
F P
s
P
p
.002 w
.45117 .48433 m .47468 .50891 L .4535 .52154 L p
1 g
F P
s
P
p
.002 w
.52319 .51155 m .49138 .49215 L .50181 .473 L p
1 g
F P
s
P
p
.002 w
.50181 .473 m .53858 .48358 L .52319 .51155 L p
1 g
F P
s
P
p
.002 w
.34588 .631 m .35567 .59461 L .39472 .60439 L p
1 g
F P
s
P
p
.002 w
.39472 .60439 m .39275 .64249 L .34588 .631 L p
1 g
F P
s
P
p
.002 w
.39944 .56649 m .39472 .60439 L .35567 .59461 L p
1 g
F P
s
P
p
.002 w
.47468 .50891 m .45117 .48433 L .45964 .47579 L p
1 g
F P
s
P
p
.002 w
.45964 .47579 m .49138 .49215 L .47468 .50891 L p
1 g
F P
s
P
p
.002 w
.40354 .749 m .39719 .71568 L .46281 .71195 L p
1 g
F P
s
P
p
.002 w
.46281 .71195 m .47323 .74484 L .40354 .749 L p
1 g
F P
s
P
p
.002 w
.39944 .56649 m .40679 .52969 L .43005 .52872 L p
1 g
F P
s
P
p
.002 w
.42845 .49441 m .43005 .52872 L .40679 .52969 L p
1 g
F P
s
P
p
.002 w
.43005 .52872 m .42845 .49441 L .44039 .49077 L p
1 g
F P
s
P
p
.002 w
.35567 .59461 m .36922 .55875 L .39944 .56649 L p
1 g
F P
s
P
p
.002 w
.40679 .52969 m .39944 .56649 L .36922 .55875 L p
1 g
F P
s
P
p
.002 w
.3401 .66705 m .34588 .631 L .39275 .64249 L p
1 g
F P
s
P
p
.002 w
.39275 .64249 m .39357 .67989 L .3401 .66705 L p
1 g
F P
s
P
p
.002 w
.63632 .60927 m .61155 .58294 L .63936 .53403 L p
1 g
F P
s
P
p
.002 w
.6082 .51445 m .63936 .53403 L .61155 .58294 L p
1 g
F P
s
P
p
.002 w
.48445 .77452 m .47323 .74484 L .54328 .72287 L p
1 g
F P
s
P
p
.002 w
.54328 .72287 m .55678 .75175 L .48445 .77452 L p
1 g
F P
s
P
p
.002 w
.55678 .75175 m .54328 .72287 L .60685 .68533 L p
1 g
F P
s
P
p
.002 w
.49138 .49215 m .45964 .47579 L .46489 .46604 L p
1 g
F P
s
P
p
.002 w
.46489 .46604 m .50181 .473 L .49138 .49215 L p
1 g
F P
s
P
p
.002 w
.36922 .55875 m .38619 .5243 L .40679 .52969 L p
1 g
F P
s
P
p
.002 w
.41663 .49487 m .40679 .52969 L .38619 .5243 L p
1 g
F P
s
P
p
.002 w
.40679 .52969 m .41663 .49487 L .42845 .49441 L p
1 g
F P
s
P
p
.002 w
.33851 .70188 m .3401 .66705 L .39357 .67989 L p
1 g
F P
s
P
p
.002 w
.39357 .67989 m .39719 .71568 L .33851 .70188 L p
1 g
F P
s
P
p
.002 w
.60685 .68533 m .62247 .71301 L .55678 .75175 L p
1 g
F P
s
P
p
.002 w
.62247 .71301 m .60685 .68533 L .65768 .63585 L p
1 g
F P
s
P
p
.002 w
.63632 .60927 m .65768 .63585 L .60685 .68533 L p
1 g
F P
s
P
p
.002 w
.57433 .49751 m .53858 .48358 L .54317 .45501 L p
1 g
F P
s
P
p
.002 w
.53858 .48358 m .50181 .473 L .50481 .45349 L p
1 g
F P
s
P
p
.002 w
.50481 .45349 m .54317 .45501 L .53858 .48358 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .44039 .49077 L .42845 .49441 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .45117 .48433 L .44039 .49077 L closepath p
1 g
F P
s
P
p
.002 w
.41251 .77899 m .40354 .749 L .47323 .74484 L p
1 g
F P
s
P
p
.002 w
.47323 .74484 m .48445 .77452 L .41251 .77899 L p
1 g
F P
s
P
p
.002 w
.6082 .51445 m .57433 .49751 L .58049 .46066 L p
1 g
F P
s
P
p
.002 w
.54317 .45501 m .58049 .46066 L .57433 .49751 L p
1 g
F P
s
P
p
.002 w
.65768 .63585 m .63632 .60927 L .66704 .55577 L p
1 g
F P
s
P
p
.002 w
.63936 .53403 m .66704 .55577 L .63632 .60927 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .45964 .47579 L .45117 .48433 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .42845 .49441 L .41663 .49487 L closepath p
1 g
F P
s
P
p
.002 w
.50181 .473 m .46489 .46604 L .46635 .45614 L p
1 g
F P
s
P
p
.002 w
.46635 .45614 m .50481 .45349 L .50181 .473 L p
1 g
F P
s
P
p
.002 w
.32561 .57378 m .34605 .54247 L .36922 .55875 L p
1 g
F P
s
P
p
.002 w
.36922 .55875 m .35567 .59461 L .32561 .57378 L p
1 g
F P
s
P
p
.002 w
.38619 .5243 m .36922 .55875 L .34605 .54247 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .46489 .46604 L .45964 .47579 L closepath p
1 g
F P
s
P
p
.002 w
.34605 .54247 m .37046 .51308 L .38619 .5243 L p
1 g
F P
s
P
p
.002 w
.40618 .49208 m .38619 .5243 L .37046 .51308 L p
1 g
F P
s
P
p
.002 w
.38619 .5243 m .40618 .49208 L .41663 .49487 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .41663 .49487 L .40618 .49208 L closepath p
1 g
F P
s
P
p
.002 w
.30968 .60627 m .32561 .57378 L .35567 .59461 L p
1 g
F P
s
P
p
.002 w
.35567 .59461 m .34588 .631 L .30968 .60627 L p
1 g
F P
s
P
p
.002 w
.63936 .53403 m .6082 .51445 L .61586 .47032 L p
1 g
F P
s
P
p
.002 w
.58049 .46066 m .61586 .47032 L .6082 .51445 L p
1 g
F P
s
P
p
.002 w
.3412 .73461 m .33851 .70188 L .39719 .71568 L p
1 g
F P
s
P
p
.002 w
.39719 .71568 m .40354 .749 L .3412 .73461 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .46635 .45614 L .46489 .46604 L closepath p
1 g
F P
s
P
p
.002 w
.49619 .80021 m .48445 .77452 L .55678 .75175 L p
1 g
F P
s
P
p
.002 w
.55678 .75175 m .56893 .77724 L .49619 .80021 L p
1 g
F P
s
P
p
.002 w
.56893 .77724 m .55678 .75175 L .62247 .71301 L p
1 g
F P
s
P
p
.002 w
.37046 .51308 m .39825 .48634 L .40618 .49208 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .40618 .49208 L .39825 .48634 L closepath p
1 g
F P
s
P
p
.002 w
.29869 .63914 m .30968 .60627 L .34588 .631 L p
1 g
F P
s
P
p
.002 w
.34588 .631 m .3401 .66705 L .29869 .63914 L p
1 g
F P
s
P
p
.002 w
.54317 .45501 m .50481 .45349 L .49998 .4357 L p
1 g
F P
s
P
p
.002 w
.50481 .45349 m .46635 .45614 L .46383 .44714 L p
1 g
F P
s
P
p
.002 w
.46383 .44714 m .49998 .4357 L .50481 .45349 L p
1 g
F P
s
P
p
.002 w
.62247 .71301 m .63502 .73832 L .56893 .77724 L p
1 g
F P
s
P
p
.002 w
.63502 .73832 m .62247 .71301 L .67506 .66203 L p
1 g
F P
s
P
p
.002 w
.65768 .63585 m .67506 .66203 L .62247 .71301 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .46383 .44714 L .46635 .45614 L closepath p
1 g
F P
s
P
p
.002 w
.67506 .66203 m .65768 .63585 L .69051 .57918 L p
1 g
F P
s
P
p
.002 w
.66704 .55577 m .69051 .57918 L .65768 .63585 L p
1 g
F P
s
P
p
.002 w
.66704 .55577 m .63936 .53403 L .64838 .4838 L p
1 g
F P
s
P
p
.002 w
.61586 .47032 m .64838 .4838 L .63936 .53403 L p
1 g
F P
s
P
p
.002 w
.36134 .49718 m .39369 .47825 L .39825 .48634 L p
1 g
F P
s
P
p
.002 w
.39825 .48634 m .37046 .51308 L .36134 .49718 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39825 .48634 L .39369 .47825 L closepath p
1 g
F P
s
P
p
.002 w
.58049 .46066 m .54317 .45501 L .53629 .42887 L p
1 g
F P
s
P
p
.002 w
.49998 .4357 m .53629 .42887 L .54317 .45501 L p
1 g
F P
s
P
p
.002 w
.3325 .51925 m .36134 .49718 L .37046 .51308 L p
1 g
F P
s
P
p
.002 w
.37046 .51308 m .34605 .54247 L .3325 .51925 L p
1 g
F P
s
P
p
.002 w
.4239 .80486 m .41251 .77899 L .48445 .77452 L p
1 g
F P
s
P
p
.002 w
.48445 .77452 m .49619 .80021 L .4239 .80486 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39633 .45863 L .40329 .44925 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39302 .46866 L .39633 .45863 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39369 .47825 L .39302 .46866 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .4576 .44003 L .46383 .44714 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .4483 .4356 L .4576 .44003 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .43695 .43433 L .4483 .4356 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .42478 .43639 L .43695 .43433 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .41313 .44156 L .42478 .43639 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .40329 .44925 L .41313 .44156 L closepath p
1 g
F P
s
P
p
.002 w
.34815 .76438 m .3412 .73461 L .40354 .749 L p
1 g
F P
s
P
p
.002 w
.40354 .749 m .41251 .77899 L .34815 .76438 L p
1 g
F P
s
P
p
.002 w
.49998 .4357 m .46383 .44714 L .4576 .44003 L p
1 g
F P
s
P
p
.002 w
.30791 .54394 m .3325 .51925 L .34605 .54247 L p
1 g
F P
s
P
p
.002 w
.34605 .54247 m .32561 .57378 L .30791 .54394 L p
1 g
F P
s
P
p
.002 w
.29299 .67155 m .29869 .63914 L .3401 .66705 L p
1 g
F P
s
P
p
.002 w
.3401 .66705 m .33851 .70188 L .29299 .67155 L p
1 g
F P
s
P
p
.002 w
.3599 .47828 m .39302 .46866 L .39369 .47825 L p
1 g
F P
s
P
p
.002 w
.39369 .47825 m .36134 .49718 L .3599 .47828 L p
1 g
F P
s
P
p
.002 w
.61586 .47032 m .58049 .46066 L .57185 .42685 L p
1 g
F P
s
P
p
.002 w
.53629 .42887 m .57185 .42685 L .58049 .46066 L p
1 g
F P
s
P
p
.002 w
.53629 .42887 m .49998 .4357 L .48777 .42159 L p
1 g
F P
s
P
p
.002 w
.4576 .44003 m .48777 .42159 L .49998 .4357 L p
1 g
F P
s
P
p
.002 w
.69051 .57918 m .66704 .55577 L .67722 .5008 L p
1 g
F P
s
P
p
.002 w
.64838 .4838 m .67722 .5008 L .66704 .55577 L p
1 g
F P
s
P
p
.002 w
.48777 .42159 m .4576 .44003 L .4483 .4356 L p
1 g
F P
s
P
p
.002 w
.28825 .57064 m .30791 .54394 L .32561 .57378 L p
1 g
F P
s
P
p
.002 w
.32561 .57378 m .30968 .60627 L .28825 .57064 L p
1 g
F P
s
P
p
.002 w
.36637 .45841 m .39633 .45863 L .39302 .46866 L p
1 g
F P
s
P
p
.002 w
.39302 .46866 m .3599 .47828 L .36637 .45841 L p
1 g
F P
s
P
p
.002 w
.50819 .82121 m .49619 .80021 L .56893 .77724 L p
1 g
F P
s
P
p
.002 w
.56893 .77724 m .57939 .79867 L .50819 .82121 L p
1 g
F P
s
P
p
.002 w
.57939 .79867 m .56893 .77724 L .63502 .73832 L p
1 g
F P
s
P
p
.002 w
.33022 .49153 m .3599 .47828 L .36134 .49718 L p
1 g
F P
s
P
p
.002 w
.36134 .49718 m .3325 .51925 L .33022 .49153 L p
1 g
F P
s
P
p
.002 w
.67506 .66203 m .68799 .68717 L .63502 .73832 L p
1 g
F P
s
P
p
.002 w
.68799 .68717 m .67506 .66203 L .70914 .60368 L p
1 g
F P
s
P
p
.002 w
.69051 .57918 m .70914 .60368 L .67506 .66203 L p
1 g
F P
s
P
p
.002 w
.64838 .4838 m .61586 .47032 L .60577 .42975 L p
1 g
F P
s
P
p
.002 w
.57185 .42685 m .60577 .42975 L .61586 .47032 L p
1 g
F P
s
P
p
.002 w
.4483 .4356 m .46944 .41273 L .48777 .42159 L p
1 g
F P
s
P
p
.002 w
.46944 .41273 m .4483 .4356 L .43695 .43433 L p
1 g
F P
s
P
p
.002 w
.29278 .70269 m .29299 .67155 L .33851 .70188 L p
1 g
F P
s
P
p
.002 w
.33851 .70188 m .3412 .73461 L .29278 .70269 L p
1 g
F P
s
P
p
.002 w
.38012 .43978 m .40329 .44925 L .39633 .45863 L p
1 g
F P
s
P
p
.002 w
.39633 .45863 m .36637 .45841 L .38012 .43978 L p
1 g
F P
s
P
p
.002 w
.63502 .73832 m .64413 .76058 L .57939 .79867 L p
1 g
F P
s
P
p
.002 w
.64413 .76058 m .63502 .73832 L .68799 .68717 L p
1 g
F P
s
P
p
.002 w
.57185 .42685 m .53629 .42887 L .51851 .40805 L p
1 g
F P
s
P
p
.002 w
.48777 .42159 m .51851 .40805 L .53629 .42887 L p
1 g
F P
s
P
p
.002 w
.43695 .43433 m .44695 .41017 L .46944 .41273 L p
1 g
F P
s
P
p
.002 w
.44695 .41017 m .43695 .43433 L .42478 .43639 L p
1 g
F P
s
P
p
.002 w
.43747 .82588 m .4239 .80486 L .49619 .80021 L p
1 g
F P
s
P
p
.002 w
.49619 .80021 m .50819 .82121 L .43747 .82588 L p
1 g
F P
s
P
p
.002 w
.35925 .7904 m .34815 .76438 L .41251 .77899 L p
1 g
F P
s
P
p
.002 w
.41251 .77899 m .4239 .80486 L .35925 .7904 L p
1 g
F P
s
P
p
.002 w
.39965 .42448 m .41313 .44156 L .40329 .44925 L p
1 g
F P
s
P
p
.002 w
.40329 .44925 m .38012 .43978 L .39965 .42448 L p
1 g
F P
s
P
p
.002 w
.27407 .59871 m .28825 .57064 L .30968 .60627 L p
1 g
F P
s
P
p
.002 w
.30968 .60627 m .29869 .63914 L .27407 .59871 L p
1 g
F P
s
P
p
.002 w
.51851 .40805 m .48777 .42159 L .46944 .41273 L p
1 g
F P
s
P
p
.002 w
.42478 .43639 m .42279 .41423 L .44695 .41017 L p
1 g
F P
s
P
p
.002 w
.42279 .41423 m .42478 .43639 L .41313 .44156 L p
1 g
F P
s
P
p
.002 w
.41313 .44156 m .39965 .42448 L .42279 .41423 L p
1 g
F P
s
P
p
.002 w
.30478 .50813 m .33022 .49153 L .3325 .51925 L p
1 g
F P
s
P
p
.002 w
.3325 .51925 m .30791 .54394 L .30478 .50813 L p
1 g
F P
s
P
p
.002 w
.70914 .60368 m .69051 .57918 L .70158 .52093 L p
1 g
F P
s
P
p
.002 w
.67722 .5008 m .70158 .52093 L .69051 .57918 L p
1 g
F P
s
P
p
.002 w
.33963 .46229 m .36637 .45841 L .3599 .47828 L p
1 g
F P
s
P
p
.002 w
.3599 .47828 m .33022 .49153 L .33963 .46229 L p
1 g
F P
s
P
p
.002 w
.67722 .5008 m .64838 .4838 L .63717 .43754 L p
1 g
F P
s
P
p
.002 w
.60577 .42975 m .63717 .43754 L .64838 .4838 L p
1 g
F P
s
P
p
.002 w
.60577 .42975 m .57185 .42685 L .54905 .39983 L p
1 g
F P
s
P
p
.002 w
.51851 .40805 m .54905 .39983 L .57185 .42685 L p
1 g
F P
s
P
p
.002 w
.29817 .73171 m .29278 .70269 L .3412 .73461 L p
1 g
F P
s
P
p
.002 w
.3412 .73461 m .34815 .76438 L .29817 .73171 L p
1 g
F P
s
P
p
.002 w
.46944 .41273 m .49163 .39493 L .51851 .40805 L p
1 g
F P
s
P
p
.002 w
.49163 .39493 m .46944 .41273 L .44695 .41017 L p
1 g
F P
s
P
p
.002 w
.68799 .68717 m .69605 .7106 L .64413 .76058 L p
1 g
F P
s
P
p
.002 w
.69605 .7106 m .68799 .68717 L .72238 .62868 L p
1 g
F P
s
P
p
.002 w
.70914 .60368 m .72238 .62868 L .68799 .68717 L p
1 g
F P
s
P
p
.002 w
.52014 .83689 m .50819 .82121 L .57939 .79867 L p
1 g
F P
s
P
p
.002 w
.57939 .79867 m .58788 .8154 L .52014 .83689 L p
1 g
F P
s
P
p
.002 w
.58788 .8154 m .57939 .79867 L .64413 .76058 L p
1 g
F P
s
P
p
.002 w
.26584 .62743 m .27407 .59871 L .29869 .63914 L p
1 g
F P
s
P
p
.002 w
.29869 .63914 m .29299 .67155 L .26584 .62743 L p
1 g
F P
s
P
p
.002 w
.35984 .4348 m .38012 .43978 L .36637 .45841 L p
1 g
F P
s
P
p
.002 w
.36637 .45841 m .33963 .46229 L .35984 .4348 L p
1 g
F P
s
P
p
.002 w
.28431 .52772 m .30478 .50813 L .30791 .54394 L p
1 g
F P
s
P
p
.002 w
.30791 .54394 m .28825 .57064 L .28431 .52772 L p
1 g
F P
s
P
p
.002 w
.54905 .39983 m .51851 .40805 L .49163 .39493 L p
1 g
F P
s
P
p
.002 w
.64413 .76058 m .64951 .77917 L .58788 .8154 L p
1 g
F P
s
P
p
.002 w
.64951 .77917 m .64413 .76058 L .69605 .7106 L p
1 g
F P
s
P
p
.002 w
.3743 .81192 m .35925 .7904 L .4239 .80486 L p
1 g
F P
s
P
p
.002 w
.4239 .80486 m .43747 .82588 L .3743 .81192 L p
1 g
F P
s
P
p
.002 w
.31686 .47024 m .33963 .46229 L .33022 .49153 L p
1 g
F P
s
P
p
.002 w
.33022 .49153 m .30478 .50813 L .31686 .47024 L p
1 g
F P
s
P
p
.002 w
.44695 .41017 m .45851 .39108 L .49163 .39493 L p
1 g
F P
s
P
p
.002 w
.45851 .39108 m .44695 .41017 L .42279 .41423 L p
1 g
F P
s
P
p
.002 w
.70158 .52093 m .67722 .5008 L .6652 .4501 L p
1 g
F P
s
P
p
.002 w
.63717 .43754 m .6652 .4501 L .67722 .5008 L p
1 g
F P
s
P
p
.002 w
.72238 .62868 m .70914 .60368 L .72079 .54373 L p
1 g
F P
s
P
p
.002 w
.70158 .52093 m .72079 .54373 L .70914 .60368 L p
1 g
F P
s
P
p
.002 w
.45292 .84142 m .43747 .82588 L .50819 .82121 L p
1 g
F P
s
P
p
.002 w
.50819 .82121 m .52014 .83689 L .45292 .84142 L p
1 g
F P
s
P
p
.002 w
.38866 .41218 m .39965 .42448 L .38012 .43978 L p
1 g
F P
s
P
p
.002 w
.38012 .43978 m .35984 .4348 L .38866 .41218 L p
1 g
F P
s
P
p
.002 w
.63717 .43754 m .60577 .42975 L .5786 .39722 L p
1 g
F P
s
P
p
.002 w
.54905 .39983 m .5786 .39722 L .60577 .42975 L p
1 g
F P
s
P
p
.002 w
.42279 .41423 m .42284 .39704 L .45851 .39108 L p
1 g
F P
s
P
p
.002 w
.42284 .39704 m .42279 .41423 L .39965 .42448 L p
1 g
F P
s
P
p
.002 w
.39965 .42448 m .38866 .41218 L .42284 .39704 L p
1 g
F P
s
P
p
.002 w
.30909 .75782 m .29817 .73171 L .34815 .76438 L p
1 g
F P
s
P
p
.002 w
.34815 .76438 m .35925 .7904 L .30909 .75782 L p
1 g
F P
s
P
p
.002 w
.26387 .65606 m .26584 .62743 L .29299 .67155 L p
1 g
F P
s
P
p
.002 w
.29299 .67155 m .29278 .70269 L .26387 .65606 L p
1 g
F P
s
P
p
.002 w
.26943 .54983 m .28431 .52772 L .28825 .57064 L p
1 g
F P
s
P
p
.002 w
.28825 .57064 m .27407 .59871 L .26943 .54983 L p
1 g
F P
s
P
p
.002 w
.49163 .39493 m .51432 .38274 L .54905 .39983 L p
1 g
F P
s
P
p
.002 w
.51432 .38274 m .49163 .39493 L .45851 .39108 L p
1 g
F P
s
P
p
.002 w
.5786 .39722 m .54905 .39983 L .51432 .38274 L p
1 g
F P
s
P
p
.002 w
.34304 .43452 m .35984 .4348 L .33963 .46229 L p
1 g
F P
s
P
p
.002 w
.33963 .46229 m .31686 .47024 L .34304 .43452 L p
1 g
F P
s
P
p
.002 w
.69605 .7106 m .69894 .7317 L .64951 .77917 L p
1 g
F P
s
P
p
.002 w
.69894 .7317 m .69605 .7106 L .72978 .65353 L p
1 g
F P
s
P
p
.002 w
.72238 .62868 m .72978 .65353 L .69605 .7106 L p
1 g
F P
s
P
p
.002 w
.29874 .48215 m .31686 .47024 L .30478 .50813 L p
1 g
F P
s
P
p
.002 w
.30478 .50813 m .28431 .52772 L .29874 .48215 L p
1 g
F P
s
P
p
.002 w
.72079 .54373 m .70158 .52093 L .68907 .46719 L p
1 g
F P
s
P
p
.002 w
.6652 .4501 m .68907 .46719 L .70158 .52093 L p
1 g
F P
s
P
p
.002 w
.53173 .84672 m .52014 .83689 L .58788 .8154 L p
1 g
F P
s
P
p
.002 w
.58788 .8154 m .59414 .8269 L .53173 .84672 L p
1 g
F P
s
P
p
.002 w
.59414 .8269 m .58788 .8154 L .64951 .77917 L p
1 g
F P
s
P
p
.002 w
.6652 .4501 m .63717 .43754 L .60637 .40038 L p
1 g
F P
s
P
p
.002 w
.5786 .39722 m .60637 .40038 L .63717 .43754 L p
1 g
F P
s
P
p
.002 w
.72978 .65353 m .72238 .62868 L .73423 .56863 L p
1 g
F P
s
P
p
.002 w
.72079 .54373 m .73423 .56863 L .72238 .62868 L p
1 g
F P
s
P
p
.002 w
.39297 .82827 m .3743 .81192 L .43747 .82588 L p
1 g
F P
s
P
p
.002 w
.43747 .82588 m .45292 .84142 L .39297 .82827 L p
1 g
F P
s
P
p
.002 w
.64951 .77917 m .65094 .79353 L .59414 .8269 L p
1 g
F P
s
P
p
.002 w
.65094 .79353 m .64951 .77917 L .69894 .7317 L p
1 g
F P
s
P
p
.002 w
.45851 .39108 m .47137 .37768 L .51432 .38274 L p
1 g
F P
s
P
p
.002 w
.47137 .37768 m .45851 .39108 L .42284 .39704 L p
1 g
F P
s
P
p
.002 w
.3805 .40509 m .38866 .41218 L .35984 .4348 L p
1 g
F P
s
P
p
.002 w
.35984 .4348 m .34304 .43452 L .3805 .40509 L p
1 g
F P
s
P
p
.002 w
.46987 .85095 m .45292 .84142 L .52014 .83689 L p
1 g
F P
s
P
p
.002 w
.52014 .83689 m .53173 .84672 L .46987 .85095 L p
1 g
F P
s
P
p
.002 w
.26833 .68384 m .26387 .65606 L .29278 .70269 L p
1 g
F P
s
P
p
.002 w
.29278 .70269 m .29817 .73171 L .26833 .68384 L p
1 g
F P
s
P
p
.002 w
.26064 .57391 m .26943 .54983 L .27407 .59871 L p
1 g
F P
s
P
p
.002 w
.27407 .59871 m .26584 .62743 L .26064 .57391 L p
1 g
F P
s
P
p
.002 w
.32537 .78026 m .30909 .75782 L .35925 .7904 L p
1 g
F P
s
P
p
.002 w
.35925 .7904 m .3743 .81192 L .32537 .78026 L p
1 g
F P
s
P
p
.002 w
.42284 .39704 m .42499 .38539 L .47137 .37768 L p
1 g
F P
s
P
p
.002 w
.42499 .38539 m .42284 .39704 L .38866 .41218 L p
1 g
F P
s
P
p
.002 w
.60637 .40038 m .5786 .39722 L .53693 .37658 L p
1 g
F P
s
P
p
.002 w
.51432 .38274 m .53693 .37658 L .5786 .39722 L p
1 g
F P
s
P
p
.002 w
.38866 .41218 m .3805 .40509 L .42499 .38539 L p
1 g
F P
s
P
p
.002 w
.53693 .37658 m .51432 .38274 L .47137 .37768 L p
1 g
F P
s
P
p
.002 w
.73423 .56863 m .72079 .54373 L .70807 .48841 L p
1 g
F P
s
P
p
.002 w
.68907 .46719 m .70807 .48841 L .72079 .54373 L p
1 g
F P
s
P
p
.002 w
.68907 .46719 m .6652 .4501 L .63159 .40934 L p
1 g
F P
s
P
p
.002 w
.60637 .40038 m .63159 .40934 L .6652 .4501 L p
1 g
F P
s
P
p
.002 w
.33026 .43907 m .34304 .43452 L .31686 .47024 L p
1 g
F P
s
P
p
.002 w
.31686 .47024 m .29874 .48215 L .33026 .43907 L p
1 g
F P
s
P
p
.002 w
.28584 .49777 m .29874 .48215 L .28431 .52772 L p
1 g
F P
s
P
p
.002 w
.28431 .52772 m .26943 .54983 L .28584 .49777 L p
1 g
F P
s
P
p
.002 w
.69894 .7317 m .69647 .74987 L .65094 .79353 L p
1 g
F P
s
P
p
.002 w
.69647 .74987 m .69894 .7317 L .73105 .67759 L p
1 g
F P
s
P
p
.002 w
.72978 .65353 m .73105 .67759 L .69894 .7317 L p
1 g
F P
s
P
p
.002 w
.73105 .67759 m .72978 .65353 L .74147 .59502 L p
1 g
F P
s
P
p
.002 w
.73423 .56863 m .74147 .59502 L .72978 .65353 L p
1 g
F P
s
P
p
.002 w
.41483 .83892 m .39297 .82827 L .45292 .84142 L p
1 g
F P
s
P
p
.002 w
.45292 .84142 m .46987 .85095 L .41483 .83892 L p
1 g
F P
s
P
p
.002 w
.25831 .59936 m .26064 .57391 L .26584 .62743 L p
1 g
F P
s
P
p
.002 w
.26584 .62743 m .26387 .65606 L .25831 .59936 L p
1 g
F P
s
P
p
.002 w
.27921 .70997 m .26833 .68384 L .29817 .73171 L p
1 g
F P
s
P
p
.002 w
.29817 .73171 m .30909 .75782 L .27921 .70997 L p
1 g
F P
s
P
p
.002 w
.54264 .85031 m .53173 .84672 L .59414 .8269 L p
1 g
F P
s
P
p
.002 w
.59414 .8269 m .59793 .83273 L .54264 .85031 L p
1 g
F P
s
P
p
.002 w
.59793 .83273 m .59414 .8269 L .65094 .79353 L p
1 g
F P
s
P
p
.002 w
.47137 .37768 m .4852 .37044 L .53693 .37658 L p
1 g
F P
s
P
p
.002 w
.4852 .37044 m .47137 .37768 L .42499 .38539 L p
1 g
F P
s
P
p
.002 w
.65094 .79353 m .64827 .80317 L .59793 .83273 L p
1 g
F P
s
P
p
.002 w
.64827 .80317 m .65094 .79353 L .69647 .74987 L p
1 g
F P
s
P
p
.002 w
.34666 .79835 m .32537 .78026 L .3743 .81192 L p
1 g
F P
s
P
p
.002 w
.3743 .81192 m .39297 .82827 L .34666 .79835 L p
1 g
F P
s
P
p
.002 w
.63159 .40934 m .60637 .40038 L .55886 .37676 L p
1 g
F P
s
P
p
.002 w
.53693 .37658 m .55886 .37676 L .60637 .40038 L p
1 g
F P
s
P
p
.002 w
.37548 .40353 m .3805 .40509 L .34304 .43452 L p
1 g
F P
s
P
p
.002 w
.34304 .43452 m .33026 .43907 L .37548 .40353 L p
1 g
F P
s
P
p
.002 w
.48791 .85407 m .46987 .85095 L .53173 .84672 L p
1 g
F P
s
P
p
.002 w
.53173 .84672 m .54264 .85031 L .48791 .85407 L p
1 g
F P
s
P
p
.002 w
.70807 .48841 m .68907 .46719 L .65354 .42395 L p
1 g
F P
s
P
p
.002 w
.63159 .40934 m .65354 .42395 L .68907 .46719 L p
1 g
F P
s
P
p
.002 w
.55886 .37676 m .53693 .37658 L .4852 .37044 L p
1 g
F P
s
P
p
.002 w
.74147 .59502 m .73423 .56863 L .72161 .51328 L p
1 g
F P
s
P
p
.002 w
.70807 .48841 m .72161 .51328 L .73423 .56863 L p
1 g
F P
s
P
p
.002 w
.42499 .38539 m .42922 .37973 L .4852 .37044 L p
1 g
F P
s
P
p
.002 w
.42922 .37973 m .42499 .38539 L .3805 .40509 L p
1 g
F P
s
P
p
.002 w
.27865 .51676 m .28584 .49777 L .26943 .54983 L p
1 g
F P
s
P
p
.002 w
.26943 .54983 m .26064 .57391 L .27865 .51676 L p
1 g
F P
s
P
p
.002 w
.3805 .40509 m .37548 .40353 L .42922 .37973 L p
1 g
F P
s
P
p
.002 w
.32193 .44844 m .33026 .43907 L .29874 .48215 L p
1 g
F P
s
P
p
.002 w
.29874 .48215 m .28584 .49777 L .32193 .44844 L p
1 g
F P
s
P
p
.002 w
.69647 .74987 m .68859 .76454 L .64827 .80317 L p
1 g
F P
s
P
p
.002 w
.68859 .76454 m .69647 .74987 L .72601 .70018 L p
1 g
F P
s
P
p
.002 w
.73105 .67759 m .72601 .70018 L .69647 .74987 L p
1 g
F P
s
P
p
.002 w
.74147 .59502 m .74217 .6222 L .73105 .67759 L p
1 g
F P
s
P
p
.002 w
.72601 .70018 m .73105 .67759 L .74217 .6222 L p
1 g
F P
s
P
p
.002 w
.26262 .62549 m .25831 .59936 L .26387 .65606 L p
1 g
F P
s
P
p
.002 w
.26387 .65606 m .26833 .68384 L .26262 .62549 L p
1 g
F P
s
P
p
.002 w
.29632 .73371 m .27921 .70997 L .30909 .75782 L p
1 g
F P
s
P
p
.002 w
.30909 .75782 m .32537 .78026 L .29632 .73371 L p
1 g
F P
s
P
p
.002 w
.43933 .84345 m .41483 .83892 L .46987 .85095 L p
1 g
F P
s
P
p
.002 w
.46987 .85095 m .48791 .85407 L .43933 .84345 L p
1 g
F P
s
P
p
.002 w
.55886 .37676 m .57948 .38339 L .63159 .40934 L p
1 g
F P
s
P
p
.002 w
.65354 .42395 m .63159 .40934 L .57948 .38339 L p
1 g
F P
s
P
p
.002 w
.37244 .81151 m .34666 .79835 L .39297 .82827 L p
1 g
F P
s
P
p
.002 w
.39297 .82827 m .41483 .83892 L .37244 .81151 L p
1 g
F P
s
P
p
.002 w
.55256 .8474 m .54264 .85031 L .59793 .83273 L p
1 g
F P
s
P
p
.002 w
.59793 .83273 m .59911 .83261 L .55256 .8474 L p
1 g
F P
s
P
p
.002 w
.59911 .83261 m .59793 .83273 L .64827 .80317 L p
1 g
F P
s
P
p
.002 w
.4852 .37044 m .49966 .36971 L .55886 .37676 L p
1 g
F P
s
P
p
.002 w
.49966 .36971 m .4852 .37044 L .42922 .37973 L p
1 g
F P
s
P
p
.002 w
.65354 .42395 m .67154 .44393 L .70807 .48841 L p
1 g
F P
s
P
p
.002 w
.72161 .51328 m .70807 .48841 L .67154 .44393 L p
1 g
F P
s
P
p
.002 w
.72161 .51328 m .72919 .54116 L .74147 .59502 L p
1 g
F P
s
P
p
.002 w
.74217 .6222 m .74147 .59502 L .72919 .54116 L p
1 g
F P
s
P
p
.002 w
.64827 .80317 m .64149 .80771 L .59911 .83261 L p
1 g
F P
s
P
p
.002 w
.64149 .80771 m .64827 .80317 L .68859 .76454 L p
1 g
F P
s
P
p
.002 w
.3738 .40769 m .37548 .40353 L .33026 .43907 L p
1 g
F P
s
P
p
.002 w
.33026 .43907 m .32193 .44844 L .3738 .40769 L p
1 g
F P
s
P
p
.002 w
.50656 .85055 m .48791 .85407 L .54264 .85031 L p
1 g
F P
s
P
p
.002 w
.54264 .85031 m .55256 .8474 L .50656 .85055 L p
1 g
F P
s
P
p
.002 w
.57948 .38339 m .55886 .37676 L .49966 .36971 L p
1 g
F P
s
P
p
.002 w
.27748 .53867 m .27865 .51676 L .26064 .57391 L p
1 g
F P
s
P
p
.002 w
.26064 .57391 m .25831 .59936 L .27748 .53867 L p
1 g
F P
s
P
p
.002 w
.27359 .65157 m .26262 .62549 L .26833 .68384 L p
1 g
F P
s
P
p
.002 w
.26833 .68384 m .27921 .70997 L .27359 .65157 L p
1 g
F P
s
P
p
.002 w
.42922 .37973 m .43547 .38037 L .49966 .36971 L p
1 g
F P
s
P
p
.002 w
.43547 .38037 m .42922 .37973 L .37548 .40353 L p
1 g
F P
s
P
p
.002 w
.31839 .4625 m .32193 .44844 L .28584 .49777 L p
1 g
F P
s
P
p
.002 w
.28584 .49777 m .27865 .51676 L .31839 .4625 L p
1 g
F P
s
P
p
.002 w
.3193 .75433 m .29632 .73371 L .32537 .78026 L p
1 g
F P
s
P
p
.002 w
.32537 .78026 m .34666 .79835 L .3193 .75433 L p
1 g
F P
s
P
p
.002 w
.37548 .40353 m .3738 .40769 L .43547 .38037 L p
1 g
F P
s
P
p
.002 w
.72601 .70018 m .71469 .72065 L .68859 .76454 L p
1 g
F P
s
P
p
.002 w
.71469 .72065 m .72601 .70018 L .7362 .64944 L p
1 g
F P
s
P
p
.002 w
.74217 .6222 m .7362 .64944 L .72601 .70018 L p
1 g
F P
s
P
p
.002 w
.68859 .76454 m .67539 .77522 L .64149 .80771 L p
1 g
F P
s
P
p
.002 w
.67539 .77522 m .68859 .76454 L .71469 .72065 L p
1 g
F P
s
P
p
.002 w
.67154 .44393 m .65354 .42395 L .59821 .39643 L p
1 g
F P
s
P
p
.002 w
.57948 .38339 m .59821 .39643 L .65354 .42395 L p
1 g
F P
s
P
p
.002 w
.46585 .84161 m .43933 .84345 L .48791 .85407 L p
1 g
F P
s
P
p
.002 w
.48791 .85407 m .50656 .85055 L .46585 .84161 L p
1 g
F P
s
P
p
.002 w
.40208 .81926 m .37244 .81151 L .41483 .83892 L p
1 g
F P
s
P
p
.002 w
.41483 .83892 m .43933 .84345 L .40208 .81926 L p
1 g
F P
s
P
p
.002 w
.72919 .54116 m .72161 .51328 L .685 .46882 L p
1 g
F P
s
P
p
.002 w
.67154 .44393 m .685 .46882 L .72161 .51328 L p
1 g
F P
s
P
p
.002 w
.7362 .64944 m .74217 .6222 L .73052 .57133 L p
1 g
F P
s
P
p
.002 w
.72919 .54116 m .73052 .57133 L .74217 .6222 L p
1 g
F P
s
P
p
.002 w
.49966 .36971 m .51436 .37566 L .57948 .38339 L p
1 g
F P
s
P
p
.002 w
.51436 .37566 m .49966 .36971 L .43547 .38037 L p
1 g
F P
s
P
p
.002 w
.56119 .83791 m .55256 .8474 L .59911 .83261 L p
1 g
F P
s
P
p
.002 w
.59911 .83261 m .59756 .82636 L .56119 .83791 L p
1 g
F P
s
P
p
.002 w
.59756 .82636 m .59911 .83261 L .64149 .80771 L p
1 g
F P
s
P
p
.004 w
.60536 .83192 m
.61733 .85693 L
s
P
p
.002 w
.28252 .56293 m .27748 .53867 L .25831 .59936 L p
1 g
F P
s
P
p
.002 w
.25831 .59936 m .26262 .62549 L .28252 .56293 L p
1 g
F P
s
P
p
.002 w
.59821 .39643 m .57948 .38339 L .51436 .37566 L p
1 g
F P
s
P
p
.002 w
.64149 .80771 m .63067 .80691 L .59756 .82636 L p
1 g
F P
s
P
p
.002 w
.63067 .80691 m .64149 .80771 L .67539 .77522 L p
1 g
F P
s
P
p
.002 w
.3756 .41758 m .3738 .40769 L .32193 .44844 L p
1 g
F P
s
P
p
.002 w
.32193 .44844 m .31839 .4625 L .3756 .41758 L p
1 g
F P
s
P
p
.002 w
.29103 .67685 m .27359 .65157 L .27921 .70997 L p
1 g
F P
s
P
p
.002 w
.27921 .70997 m .29632 .73371 L .29103 .67685 L p
1 g
F P
s
P
p
.002 w
.34757 .77119 m .3193 .75433 L .34666 .79835 L p
1 g
F P
s
P
p
.002 w
.34666 .79835 m .37244 .81151 L .34757 .77119 L p
1 g
F P
s
P
p
.002 w
.52531 .84034 m .50656 .85055 L .55256 .8474 L p
1 g
F P
s
P
p
.002 w
.55256 .8474 m .56119 .83791 L .52531 .84034 L p
1 g
F P
s
P
p
.002 w
.31987 .48094 m .31839 .4625 L .27865 .51676 L p
1 g
F P
s
P
p
.002 w
.27865 .51676 m .27748 .53867 L .31987 .48094 L p
1 g
F P
s
P
p
.002 w
.71469 .72065 m .69725 .7384 L .67539 .77522 L p
1 g
F P
s
P
p
.002 w
.69725 .7384 m .71469 .72065 L .7236 .67596 L p
1 g
F P
s
P
p
.002 w
.7362 .64944 m .7236 .67596 L .71469 .72065 L p
1 g
F P
s
P
p
.002 w
.43547 .38037 m .44362 .38745 L .51436 .37566 L p
1 g
F P
s
P
p
.002 w
.44362 .38745 m .43547 .38037 L .3738 .40769 L p
1 g
F P
s
P
p
.002 w
.685 .46882 m .67154 .44393 L .61446 .41566 L p
1 g
F P
s
P
p
.002 w
.59821 .39643 m .61446 .41566 L .67154 .44393 L p
1 g
F P
s
P
p
.002 w
.3738 .40769 m .3756 .41758 L .44362 .38745 L p
1 g
F P
s
P
p
.002 w
.73052 .57133 m .72919 .54116 L .69348 .49799 L p
1 g
F P
s
P
p
.002 w
.685 .46882 m .69348 .49799 L .72919 .54116 L p
1 g
F P
s
P
p
.002 w
.67539 .77522 m .65711 .78154 L .63067 .80691 L p
1 g
F P
s
P
p
.002 w
.65711 .78154 m .67539 .77522 L .69725 .7384 L p
1 g
F P
s
P
p
.002 w
.43478 .82129 m .40208 .81926 L .43933 .84345 L p
1 g
F P
s
P
p
.002 w
.43933 .84345 m .46585 .84161 L .43478 .82129 L p
1 g
F P
s
P
p
.002 w
.7236 .67596 m .7362 .64944 L .72543 .60297 L p
1 g
F P
s
P
p
.002 w
.73052 .57133 m .72543 .60297 L .7362 .64944 L p
1 g
F P
s
P
p
.002 w
.49366 .83332 m .46585 .84161 L .50656 .85055 L p
1 g
F P
s
P
p
.002 w
.50656 .85055 m .52531 .84034 L .49366 .83332 L p
1 g
F P
s
P
p
.002 w
.29372 .58888 m .28252 .56293 L .26262 .62549 L p
1 g
F P
s
P
p
.002 w
.26262 .62549 m .27359 .65157 L .29372 .58888 L p
1 g
F P
s
P
p
.002 w
.31452 .70057 m .29103 .67685 L .29632 .73371 L p
1 g
F P
s
P
p
.002 w
.29632 .73371 m .3193 .75433 L .31452 .70057 L p
1 g
F P
s
P
p
.002 w
.3804 .78374 m .34757 .77119 L .37244 .81151 L p
1 g
F P
s
P
p
.002 w
.37244 .81151 m .40208 .81926 L .3804 .78374 L p
1 g
F P
s
P
p
.002 w
.61446 .41566 m .59821 .39643 L .5289 .38829 L p
1 g
F P
s
P
p
.002 w
.51436 .37566 m .5289 .38829 L .59821 .39643 L p
1 g
F P
s
P
p
.002 w
.5289 .38829 m .51436 .37566 L .44362 .38745 L p
1 g
F P
s
P
p
.002 w
.56825 .82195 m .56119 .83791 L .59756 .82636 L p
1 g
F P
s
P
p
.002 w
.59756 .82636 m .59325 .81402 L .56825 .82195 L p
1 g
F P
s
P
p
.002 w
.59325 .81402 m .59756 .82636 L .63067 .80691 L p
1 g
F P
s
P
p
.002 w
.38091 .43308 m .3756 .41758 L .31839 .4625 L p
1 g
F P
s
P
p
.002 w
.31839 .4625 m .31987 .48094 L .38091 .43308 L p
1 g
F P
s
P
p
.002 w
.63067 .80691 m .61602 .80064 L .59325 .81402 L p
1 g
F P
s
P
p
.002 w
.61602 .80064 m .63067 .80691 L .65711 .78154 L p
1 g
F P
s
P
p
.002 w
.69725 .7384 m .67408 .75284 L .65711 .78154 L p
1 g
F P
s
P
p
.002 w
.67408 .75284 m .69725 .7384 L .70461 .701 L p
1 g
F P
s
P
p
.002 w
.7236 .67596 m .70461 .701 L .69725 .7384 L p
1 g
F P
s
P
p
.002 w
.54362 .82359 m .52531 .84034 L .56119 .83791 L p
1 g
F P
s
P
p
.002 w
.56119 .83791 m .56825 .82195 L .54362 .82359 L p
1 g
F P
s
P
p
.002 w
.32644 .50333 m .31987 .48094 L .27748 .53867 L p
1 g
F P
s
P
p
.002 w
.27748 .53867 m .28252 .56293 L .32644 .50333 L p
1 g
F P
s
P
p
.002 w
.72543 .60297 m .73052 .57133 L .69661 .53068 L p
1 g
F P
s
P
p
.002 w
.69348 .49799 m .69661 .53068 L .73052 .57133 L p
1 g
F P
s
P
p
.002 w
.69348 .49799 m .685 .46882 L .62771 .44064 L p
1 g
F P
s
P
p
.002 w
.61446 .41566 m .62771 .44064 L .685 .46882 L p
1 g
F P
s
P
p
.002 w
.70461 .701 m .7236 .67596 L .71397 .63517 L p
1 g
F P
s
P
p
.002 w
.72543 .60297 m .71397 .63517 L .7236 .67596 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.43478 .82129 m .46585 .84161 L p
.46811 .82714 L 1 g
F P
s
P
p
.46811 .82714 m .46822 .82644 L .46557 .82603 L 1 g
F
P
p
.46811 .82714 m .46557 .82603 L .43478 .82129 L 1 g
F
P
p
.002 w
.4637 .82521 m .46403 .82325 L p
.45402 .82099 L 1 g
F P
s
P
p
.002 w
.44504 .82017 m .43478 .82129 L p
.46822 .82644 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .4637 .82521 L p
1 g
F P
s
P
p
.46585 .84161 m .49365 .83332 L .48741 .83163 L 1 g
F
P
p
.46783 .82896 m .48741 .83163 L .46822 .82644 L 1 g
F
P
p
.46585 .84161 m .48741 .83163 L .46783 .82896 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51256 .83108 L p
1 g
F P
s
P
p
.52531 .84034 m .52375 .83027 L .5096 .8317 L 1 g
F
P
p
.002 w
.49766 .83421 m .52531 .84034 L p
.5096 .8317 L 1 g
F P
s
P
p
.53597 .82325 m .51256 .83108 L .52558 .82835 L 1 g
F
P
p
.002 w
.51256 .83108 m .51242 .82869 L p
.49772 .83216 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.49561 .83232 m .49366 .83332 L p
.52375 .83027 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48741 .83163 L p
1 g
F P
s
P
p
.002 w
.49365 .83332 m .49205 .83226 L p
.48741 .83163 L 1 g
F P
s
P
p
.002 w
.49205 .83226 m .49366 .83332 L p
.49414 .83229 L 1 g
F P
s
P
p
.51242 .82869 m .48741 .83163 L .49205 .83226 L 1 g
F
P
p
.002 w
.49366 .83332 m .49561 .83232 L p
.49414 .83229 L 1 g
F P
s
P
p
.49698 .83234 m .49205 .83226 L .49538 .83272 L 1 g
F
P
p
.51242 .82869 m .49205 .83226 L .49698 .83234 L 1 g
F
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.52196 .81872 m .50561 .80781 L p
.49414 .83229 L 1 g
F P
s
P
p
.002 w
.49561 .83232 m .52196 .81872 L p
.49414 .83229 L 1 g
F P
s
P
p
.48758 .82869 m .4637 .82521 L .47712 .82885 L 1 g
F
P
p
.002 w
.48741 .83163 m .48758 .82869 L p
.47712 .82885 L 1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.50561 .80781 m .46962 .81747 L .49205 .83226 L p
1 g
F P
s
P
p
.49414 .83229 m .50561 .80781 L .49205 .83226 L 1 g
F
P
p
.49538 .83272 m .49205 .83226 L .48724 .83464 L 1 g
F
P
p
.002 w
.48741 .83163 m .48738 .83219 L p
.49205 .83226 L 1 g
F P
s
P
p
.002 w
.48738 .83219 m .48724 .83464 L p
.49205 .83226 L 1 g
F P
s
P
p
.46822 .82644 m .48741 .83163 L .46962 .81747 L 1 g
F
P
p
.002 w
.49205 .83226 m .46962 .81747 L p
.48741 .83163 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.52196 .81872 m .49561 .83232 L p
.51256 .83108 L 1 g
F P
s
P
p
.52375 .83027 m .52352 .82878 L .51256 .83108 L 1 g
F
P
p
.52352 .82878 m .52196 .81872 L .51256 .83108 L 1 g
F
P
p
.002 w
.53644 .82606 m .53597 .82325 L p
.52558 .82835 L 1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.52531 .84034 m .54362 .82359 L .54321 .8235 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53644 .82606 L p
1 g
F P
s
P
p
.55573 .81291 m .53644 .82606 L .54321 .8235 L 1 g
F
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.54993 .79814 m .52196 .81872 L .54321 .8235 L p
1 g
F P
s
P
p
.002 w
.54321 .8235 m .54362 .82359 L p
.54371 .82322 L 1 g
F P
s
P
p
.55573 .81291 m .54321 .8235 L .54349 .82334 L 1 g
F
P
p
.54379 .82317 m .54338 .82344 L .54374 .82321 L 1 g
F
P
p
.55573 .81291 m .54349 .82334 L .54379 .82317 L 1 g
F
P
p
.54349 .82334 m .54338 .82344 L .54379 .82317 L 1 g
F
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56093 .80065 m .54993 .79814 L p
.54371 .82322 L 1 g
F P
s
P
p
.002 w
.54362 .82359 m .54404 .82303 L p
.54371 .82322 L 1 g
F P
s
P
p
.56825 .82195 m .56432 .81052 L .55608 .81573 L 1 g
F
P
p
.002 w
.54362 .82359 m .54828 .82328 L p
.55608 .81573 L 1 g
F P
s
P
p
.002 w
.54828 .82328 m .56825 .82195 L p
.55608 .81573 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55642 .8154 L p
1 g
F P
s
P
p
.56958 .79874 m .55642 .8154 L .56339 .80864 L 1 g
F
P
p
.002 w
.54404 .82303 m .54362 .82359 L p
.55608 .81573 L 1 g
F P
s
P
p
.56432 .81052 m .55642 .8154 L .55608 .81573 L 1 g
F
P
p
.55642 .8154 m .54404 .82303 L .55608 .81573 L 1 g
F
P
p
.002 w
.57065 .80161 m .56958 .79874 L p
.56339 .80864 L 1 g
F P
s
P
p
.002 w
.55642 .8154 m .55573 .81291 L p
.54374 .82321 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56093 .80065 m .54404 .82303 L p
.56432 .81052 L 1 g
F P
s
P
p
.002 w
.56825 .82195 m .57349 .79984 L .57151 .79997 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57065 .80161 L p
1 g
F P
s
P
p
.576 .78222 m .57065 .80161 L .57151 .79997 L 1 g
F
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.57918 .77819 m .57673 .7721 L .57629 .77586 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57699 .78443 L p
1 g
F P
s
P
p
.57421 .76511 m .57699 .78443 L .57697 .78426 L 1 g
F
P
p
.57918 .77819 m .57629 .77586 L .57699 .78443 L 1 g
F
P
p
.57642 .77748 m .57701 .78447 L .57642 .77751 L 1 g
F
P
p
.57421 .76511 m .57697 .78426 L .57642 .77748 L 1 g
F
P
p
.57697 .78426 m .57701 .78447 L .57642 .77748 L 1 g
F
P
p
.002 w
.57444 .79171 m .57349 .79984 L p
.57712 .78602 L 1 g
F P
s
P
p
.57918 .77819 m .57699 .78443 L .57712 .78602 L 1 g
F
P
p
.57699 .78443 m .57444 .79171 L .57712 .78602 L 1 g
F
P
p
.576 .78222 m .57151 .79997 L .57169 .79947 L 1 g
F
P
p
.002 w
.57151 .79997 m .57349 .79984 L .57444 .79171 L p
1 g
F P
s
P
p
.576 .78222 m .57161 .79978 L .57345 .79455 L 1 g
F
P
p
.002 w
.58626 .7958 m .57918 .77819 L p
.57712 .78602 L 1 g
F P
s
P
p
.002 w
.57349 .79984 m .57813 .79837 L p
.57712 .78602 L 1 g
F P
s
P
p
.002 w
.57813 .79837 m .58626 .7958 L p
.57712 .78602 L 1 g
F P
s
P
p
.002 w
.57673 .7721 m .57607 .77328 L p
.57621 .77488 L 1 g
F P
s
P
p
.57421 .76511 m .57642 .77748 L .57629 .77586 L 1 g
F
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57701 .78447 L p
1 g
F P
s
P
p
.002 w
.57701 .78447 m .576 .78222 L p
.57346 .79447 L 1 g
F P
s
P
p
.57346 .79447 m .5715 .8039 L .57701 .78447 L 1 g
F
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.57444 .79171 m .57629 .77586 L p
.57151 .79997 L 1 g
F P
s
P
p
.002 w
.57629 .77586 m .57673 .7721 L p
.57621 .77488 L 1 g
F P
s
P
p
.57421 .76511 m .57629 .77586 L .57607 .77328 L 1 g
F
P
p
.57421 .76511 m .57607 .77328 L .57601 .77264 L 1 g
F
P
p
.57421 .76511 m .57601 .77264 L .57598 .77233 L 1 g
F
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.53663 .77478 m .53707 .78448 L .57598 .77233 L p
1 g
F P
s
P
p
.002 w
.57598 .77233 m .57673 .7721 L .57596 .77215 L p
1 g
F P
s
P
p
.57421 .76511 m .57598 .77233 L .57597 .77224 L 1 g
F
P
p
.57421 .76511 m .57597 .77224 L .57592 .77179 L 1 g
F
P
p
.57421 .76511 m .57592 .77179 L .57589 .77158 L 1 g
F
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.5481 .75479 m .57589 .77159 L p
.5588 .74673 L 1 g
F P
s
P
p
.002 w
.55876 .7467 m .5481 .75479 L p
.5588 .74673 L 1 g
F P
s
P
p
.002 w
.51784 .73323 m .5481 .75479 L .55876 .7467 L p
1 g
F P
s
P
p
.54732 .73647 m .55927 .74706 L .55874 .74668 L 1 g
F
P
p
.002 w
.55876 .7467 m .55877 .74669 L p
.55873 .74667 L 1 g
F P
s
P
p
.51784 .73323 m .55876 .7467 L .55873 .74667 L 1 g
F
P
p
.002 w
.54793 .73807 m .54732 .73647 L p
.55874 .74668 L 1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.5753 .76737 m .57421 .76511 L p
.57589 .7716 L 1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.5588 .74673 m .57578 .77076 L p
.57525 .76728 L 1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .5753 .76737 L p
1 g
F P
s
P
p
.56431 .74928 m .5753 .76737 L .57051 .75969 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.5588 .74673 m .57525 .76728 L .56522 .75121 L 1 g
F
P
p
.002 w
.57578 .77076 m .57673 .7721 L .57302 .75095 L p
1 g
F P
s
P
p
.002 w
.57539 .76755 m .5753 .76737 L p
.57589 .7716 L 1 g
F P
s
P
p
.002 w
.57302 .75095 m .57129 .74111 L p
.57578 .77076 L 1 g
F P
s
P
p
.002 w
.5755 .76778 m .57539 .76755 L p
.57597 .77224 L 1 g
F P
s
P
p
.002 w
.5756 .76799 m .5755 .76778 L p
.57596 .77216 L 1 g
F P
s
P
p
.57596 .77216 m .57599 .77234 L .5756 .76799 L 1 g
F
P
p
.002 w
.57564 .76805 m .5756 .76799 L p
.57603 .77278 L 1 g
F P
s
P
p
.002 w
.57589 .77159 m .57673 .7721 L .57578 .77076 L p
1 g
F P
s
P
p
.57603 .77278 m .57605 .77298 L .57564 .76805 L 1 g
F
P
p
.002 w
.57593 .77193 m .57673 .7721 L .57589 .77159 L p
1 g
F P
s
P
p
.002 w
.57565 .76808 m .57564 .76805 L p
.57629 .77586 L 1 g
F P
s
P
p
.002 w
.57596 .77215 m .57673 .7721 L .57593 .77193 L p
1 g
F P
s
P
p
.002 w
.576 .77252 m .57673 .7721 L .57598 .77233 L p
1 g
F P
s
P
p
.002 w
.57603 .77278 m .57673 .7721 L .576 .77252 L p
1 g
F P
s
P
p
.002 w
.57607 .77328 m .57673 .7721 L .57603 .77278 L p
1 g
F P
s
P
p
.002 w
.58427 .73866 m .57129 .74111 L .57613 .76869 L p
1 g
F P
s
P
p
.002 w
.57613 .76869 m .57673 .7721 L .57713 .7703 L p
1 g
F P
s
P
p
.002 w
.57713 .7703 m .58427 .73866 L p
.57613 .76869 L 1 g
F P
s
P
p
.002 w
.57569 .76842 m .57628 .76938 L .57565 .76808 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .5757 .76845 L p
.57811 .78694 L 1 g
F P
s
P
p
.57642 .77748 m .57811 .78694 L .57565 .76808 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56528 .75134 L p
1 g
F P
s
P
p
.002 w
.56528 .75134 m .56522 .75121 L p
.56594 .7524 L 1 g
F P
s
P
p
.56594 .7524 m .57628 .76938 L .56528 .75134 L 1 g
F
P
p
.002 w
.56522 .75121 m .56431 .74928 L p
.57051 .75969 L 1 g
F P
s
P
p
.57051 .75969 m .57628 .76938 L .56522 .75121 L 1 g
F
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.56163 .74546 m .57372 .75715 L .57129 .74111 L 1 g
F
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56522 .75121 L p
1 g
F P
s
P
p
.002 w
.56522 .75121 m .56611 .75311 L p
.55927 .74706 L 1 g
F P
s
P
p
.54732 .73647 m .56522 .75121 L .55927 .74706 L 1 g
F
P
p
.55927 .74706 m .5588 .74673 L .55876 .7467 L 1 g
F
P
p
.55927 .74706 m .55876 .7467 L .55874 .74668 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.5588 .74673 m .56522 .75121 L .56163 .74546 L 1 g
F
P
p
.56522 .75121 m .57372 .75715 L .56163 .74546 L 1 g
F
P
p
.56522 .75121 m .57525 .76728 L .57372 .75715 L 1 g
F
P
p
.002 w
.5753 .76737 m .57628 .76938 L p
.57051 .75969 L 1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54793 .73807 L p
1 g
F P
s
P
p
.52506 .72815 m .54793 .73807 L .53674 .734 L 1 g
F
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.51784 .73323 m .55873 .74667 L .54793 .73807 L 1 g
F
P
p
.002 w
.52543 .72988 m .52506 .72815 L p
.53674 .734 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52543 .72988 L p
1 g
F P
s
P
p
.5 .72527 m .52543 .72988 L .52246 .72971 L 1 g
F
P
p
.5 .72527 m .52246 .72971 L .51637 .72898 L 1 g
F
P
p
.002 w
.51196 .72845 m .51784 .73323 L .52246 .72971 L p
1 g
F P
s
P
p
.5 .72527 m .51856 .72948 L .51595 .72907 L 1 g
F
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.51784 .73323 m .51196 .72845 L p
.46484 .73644 L 1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.46484 .73644 m .51196 .72845 L .5 .7266 L 1 g
F
P
p
.46484 .73644 m .5 .7266 L .47799 .72926 L 1 g
F
P
p
.002 w
.47461 .72967 m .47494 .72815 L p
.48606 .72828 L 1 g
F P
s
P
p
.002 w
.46786 .73255 m .46484 .73644 L p
.47799 .72926 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .7266 L p
1 g
F P
s
P
p
.47494 .72815 m .5 .7266 L .48606 .72828 L 1 g
F
P
p
.47799 .72926 m .48665 .72453 L .47461 .72967 L 1 g
F
P
p
.47799 .72926 m .47461 .72967 L .46786 .73255 L 1 g
F
P
p
.002 w
.5 .7266 m .5 .72845 L p
.48606 .72828 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47461 .72967 L p
1 g
F P
s
P
p
.48606 .72828 m .5 .72845 L .47461 .72967 L 1 g
F
P
p
.47799 .72926 m .5 .7266 L .48665 .72453 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47455 .72997 L p
1 g
F P
s
P
p
.45268 .73647 m .47455 .72997 L .46725 .73279 L 1 g
F
P
p
.002 w
.46187 .73486 m .46484 .73644 L .46786 .73255 L p
1 g
F P
s
P
p
.45268 .73647 m .47433 .731 L .46912 .73261 L 1 g
F
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.46484 .73644 m .46187 .73486 L p
.44834 .74071 L 1 g
F P
s
P
p
.44312 .74461 m .46484 .73644 L .44834 .74071 L 1 g
F
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45215 .73788 L p
1 g
F P
s
P
p
.43569 .74928 m .45215 .73788 L .44143 .74586 L 1 g
F
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.41662 .74891 m .41434 .75542 L p
.46187 .73486 L 1 g
F P
s
P
p
.002 w
.43507 .7506 m .43569 .74928 L p
.44143 .74586 L 1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.45418 .76632 m .46484 .73644 L p
.43743 .74674 L 1 g
F P
s
P
p
.42579 .76511 m .42994 .75896 L .42956 .75958 L 1 g
F
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4161 .78068 m .41686 .79155 L p
.42439 .7726 L 1 g
F P
s
P
p
.42439 .7726 m .42502 .7667 L .4161 .78068 L 1 g
F
P
p
.002 w
.424 .78222 m .42579 .76511 L .42502 .7667 L p
1 g
F P
s
P
p
.41686 .79155 m .42279 .78754 L .42316 .7841 L 1 g
F
P
p
.42169 .77938 m .42316 .7841 L .42439 .7726 L 1 g
F
P
p
.41686 .79155 m .42316 .7841 L .42169 .77938 L 1 g
F
P
p
.002 w
.41686 .79155 m .43478 .82129 L p
.43775 .8175 L 1 g
F P
s
P
p
.43042 .79874 m .42567 .79218 L .42567 .79218 L 1 g
F
P
p
.002 w
.42971 .80064 m .43042 .79874 L p
.42567 .79218 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.43775 .8175 m .44147 .81275 L .42971 .80064 L 1 g
F
P
p
.43775 .8175 m .42971 .80064 L .41686 .79155 L 1 g
F
P
p
.002 w
.42567 .79218 m .42118 .79186 L p
.42971 .80064 L 1 g
F P
s
P
p
.002 w
.42118 .79186 m .41686 .79155 L p
.42971 .80064 L 1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42971 .80064 L p
1 g
F P
s
P
p
.002 w
.42971 .80064 m .4285 .8039 L p
.43832 .80951 L 1 g
F P
s
P
p
.44427 .81291 m .42971 .80064 L .43832 .80951 L 1 g
F
P
p
.002 w
.44368 .81504 m .44427 .81291 L p
.43832 .80951 L 1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.43478 .82129 m .45071 .81954 L p
.44102 .81333 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44333 .81632 L p
1 g
F P
s
P
p
.46403 .82325 m .44333 .81632 L .45402 .82099 L 1 g
F
P
p
.002 w
.46962 .81747 m .45071 .81954 L p
.46822 .82644 L 1 g
F P
s
P
p
.002 w
.45071 .81954 m .44504 .82017 L p
.4637 .82521 L 1 g
F P
s
P
p
.46822 .82644 m .45071 .81954 L .4637 .82521 L 1 g
F
P
p
.002 w
.44333 .81632 m .44274 .81844 L p
.45402 .82099 L 1 g
F P
s
P
p
.002 w
.46962 .81747 m .4559 .79433 L p
.44102 .81333 L 1 g
F P
s
P
p
.002 w
.45071 .81954 m .46962 .81747 L p
.44102 .81333 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46329 .82761 L p
1 g
F P
s
P
p
.002 w
.46329 .82761 m .4637 .82521 L p
.45534 .82251 L 1 g
F P
s
P
p
.45534 .82251 m .44274 .81844 L .46329 .82761 L 1 g
F
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44368 .81504 L p
1 g
F P
s
P
p
.43832 .80951 m .4285 .8039 L .44368 .81504 L 1 g
F
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42316 .7841 L p
1 g
F P
s
P
p
.42279 .78754 m .42398 .78673 L .42316 .7841 L 1 g
F
P
p
.43042 .79874 m .42316 .7841 L .42567 .79218 L 1 g
F
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.41686 .79155 m .4559 .79433 L .45418 .76632 L p
1 g
F P
s
P
p
.002 w
.42316 .7841 m .42189 .78694 L p
.42567 .79218 L 1 g
F P
s
P
p
.424 .78222 m .42502 .7667 L .42389 .77726 L 1 g
F
P
p
.002 w
.42316 .7841 m .424 .78222 L p
.42389 .77726 L 1 g
F P
s
P
p
.42316 .7841 m .45418 .76632 L .42439 .7726 L 1 g
F
P
p
.42398 .78673 m .45418 .76632 L .42316 .7841 L 1 g
F
P
p
.002 w
.4559 .79433 m .42567 .79218 L p
.42971 .80064 L 1 g
F P
s
P
p
.44147 .81275 m .4559 .79433 L .42971 .80064 L 1 g
F
P
p
.002 w
.42895 .80269 m .42971 .80064 L p
.42567 .79218 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42895 .80269 L p
1 g
F P
s
P
p
.42567 .79218 m .42189 .78694 L .42895 .80269 L 1 g
F
P
p
.002 w
.42502 .7667 m .42372 .76938 L p
.42389 .77726 L 1 g
F P
s
P
p
.002 w
.45418 .76632 m .42956 .75958 L p
.42439 .7726 L 1 g
F P
s
P
p
.42439 .7726 m .42956 .75958 L .42502 .7667 L 1 g
F
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42316 .7841 L p
1 g
F P
s
P
p
.42389 .77726 m .42372 .76938 L .42316 .7841 L 1 g
F
P
p
.002 w
.42435 .76809 m .42502 .7667 L p
.42956 .75958 L 1 g
F P
s
P
p
.002 w
.42502 .7667 m .42579 .76511 L p
.42956 .75958 L 1 g
F P
s
P
p
.002 w
.42956 .75958 m .45418 .76632 L p
.43743 .74674 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.42956 .75958 m .41434 .75542 L .4161 .78068 L p
1 g
F P
s
P
p
.002 w
.41434 .75542 m .42956 .75958 L p
.43743 .74674 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42435 .76809 L p
1 g
F P
s
P
p
.42994 .75896 m .43389 .75311 L .42435 .76809 L 1 g
F
P
p
.002 w
.45215 .73788 m .45136 .73996 L p
.44143 .74586 L 1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.42785 .71679 m .41662 .74891 L p
.45215 .73788 L 1 g
F P
s
P
p
.45268 .73647 m .466 .73335 L .46397 .73421 L 1 g
F
P
p
.002 w
.45152 .73953 m .45215 .73788 L p
.46397 .73421 L 1 g
F P
s
P
p
.002 w
.45215 .73788 m .45268 .73647 L p
.46397 .73421 L 1 g
F P
s
P
p
.002 w
.46187 .73486 m .45856 .73311 L p
.45215 .73788 L 1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45856 .73311 m .42785 .71679 L p
.45215 .73788 L 1 g
F P
s
P
p
.41434 .75542 m .44312 .74461 L .44834 .74071 L 1 g
F
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43507 .7506 L p
1 g
F P
s
P
p
.44143 .74586 m .45136 .73996 L .43507 .7506 L 1 g
F
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.42785 .71679 m .46187 .73486 L p
.48686 .70805 L 1 g
F P
s
P
p
.002 w
.46786 .73255 m .48686 .70805 L p
.46187 .73486 L 1 g
F P
s
P
p
.002 w
.47455 .72997 m .47433 .731 L p
.46725 .73279 L 1 g
F P
s
P
p
.002 w
.47433 .731 m .47424 .73141 L p
.46912 .73261 L 1 g
F P
s
P
p
.002 w
.47543 .72279 m .46786 .73255 L p
.48665 .72453 L 1 g
F P
s
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45152 .73953 L p
1 g
F P
s
P
p
.466 .73335 m .47424 .73141 L .45152 .73953 L 1 g
F
P
p
.51784 .73323 m .54793 .73807 L .52543 .72988 L 1 g
F
P
p
.002 w
.52327 .72909 m .52246 .72971 L p
.52543 .72988 L 1 g
F P
s
P
p
.002 w
.52246 .72971 m .51784 .73323 L p
.52543 .72988 L 1 g
F P
s
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72838 L p
1 g
F P
s
P
p
.002 w
.5 .72838 m .5 .72527 L p
.51735 .7294 L 1 g
F P
s
P
p
.51735 .7294 m .52576 .73141 L .5 .72838 L 1 g
F
P
p
.002 w
.48686 .70805 m .51196 .72845 L p
.53895 .71715 L 1 g
F P
s
P
p
.002 w
.52246 .72971 m .53895 .71715 L p
.51196 .72845 L 1 g
F P
s
P
p
.51637 .72898 m .52246 .72971 L .51856 .72948 L 1 g
F
P
p
.51595 .72907 m .51856 .72948 L .51735 .7294 L 1 g
F
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.51196 .72845 m .48686 .70805 L .47543 .72279 L p
1 g
F P
s
P
p
.002 w
.52543 .72988 m .52576 .73141 L p
.51735 .7294 L 1 g
F P
s
P
p
.002 w
.53011 .72389 m .52327 .72909 L p
.52543 .72988 L 1 g
F P
s
P
p
.52543 .72988 m .54793 .73807 L .53862 .73066 L 1 g
F
P
p
.52543 .72988 m .53862 .73066 L .53011 .72389 L 1 g
F
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52543 .72988 L p
1 g
F P
s
P
p
.53674 .734 m .54864 .73996 L .52543 .72988 L 1 g
F
P
p
.002 w
.54793 .73807 m .54864 .73996 L p
.53674 .734 L 1 g
F P
s
P
p
.002 w
.53895 .71715 m .53011 .72389 L p
.54796 .73808 L 1 g
F P
s
P
p
.002 w
.55877 .74669 m .55463 .74051 L p
.54796 .73808 L 1 g
F P
s
P
p
.002 w
.55463 .74051 m .53895 .71715 L p
.54796 .73808 L 1 g
F P
s
P
p
.55873 .74667 m .55877 .74669 L .53011 .72389 L 1 g
F
P
p
.55874 .74668 m .55876 .7467 L .54845 .73945 L 1 g
F
P
p
.002 w
.54845 .73945 m .54793 .73807 L p
.55874 .74668 L 1 g
F P
s
P
p
.55927 .74706 m .55928 .74707 L .5588 .74673 L 1 g
F
P
p
.002 w
.57129 .74111 m .55877 .74669 L .5588 .74673 L p
1 g
F P
s
P
p
.002 w
.57578 .77076 m .55877 .74669 L p
.57589 .77159 L 1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54845 .73945 L p
1 g
F P
s
P
p
.55928 .74707 m .56611 .75311 L .54845 .73945 L 1 g
F
P
p
.002 w
.55877 .74669 m .55876 .7467 L p
.5588 .74673 L 1 g
F P
s
P
p
.57589 .77158 m .57592 .77179 L .57589 .7716 L 1 g
F
P
p
.002 w
.57596 .77215 m .53663 .77478 L p
.57598 .77233 L 1 g
F P
s
P
p
.57597 .77224 m .57598 .77233 L .57597 .77224 L 1 g
F
P
p
.002 w
.54044 .76451 m .53663 .77478 L .57596 .77215 L p
1 g
F P
s
P
p
.002 w
.57593 .77193 m .54044 .76451 L p
.57596 .77215 L 1 g
F P
s
P
p
.002 w
.5481 .75479 m .54044 .76451 L .57593 .77193 L p
1 g
F P
s
P
p
.002 w
.57589 .77159 m .5481 .75479 L p
.57593 .77193 L 1 g
F P
s
P
p
.57596 .77216 m .57601 .77264 L .57599 .77234 L 1 g
F
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.53707 .78448 m .54167 .79255 L .576 .77252 L p
1 g
F P
s
P
p
.002 w
.57598 .77233 m .53707 .78448 L p
.576 .77252 L 1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.54167 .79255 m .54993 .79814 L .57603 .77278 L p
1 g
F P
s
P
p
.002 w
.576 .77252 m .54167 .79255 L p
.57603 .77278 L 1 g
F P
s
P
p
.57603 .77278 m .57607 .77328 L .57605 .77298 L 1 g
F
P
p
.002 w
.54993 .79814 m .56093 .80065 L .57607 .77328 L p
1 g
F P
s
P
p
.002 w
.57603 .77278 m .54993 .79814 L p
.57607 .77328 L 1 g
F P
s
P
p
.57629 .77586 m .57621 .77488 L .57151 .79997 L 1 g
F
P
p
.002 w
.57629 .77586 m .57444 .79171 L p
.57699 .78443 L 1 g
F P
s
P
p
.002 w
.57699 .78443 m .57701 .78447 L p
.57697 .78426 L 1 g
F P
s
P
p
.002 w
.57701 .78447 m .57811 .78694 L p
.57642 .77751 L 1 g
F P
s
P
p
.002 w
.56093 .80065 m .57151 .79997 L p
.57621 .77488 L 1 g
F P
s
P
p
.002 w
.57607 .77328 m .56093 .80065 L p
.57621 .77488 L 1 g
F P
s
P
p
.57169 .79947 m .57151 .79997 L .57161 .79978 L 1 g
F
P
p
.57345 .79455 m .57161 .79978 L .57285 .79743 L 1 g
F
P
p
.002 w
.57151 .79997 m .56093 .80065 L p
.56497 .81241 L 1 g
F P
s
P
p
.56825 .82195 m .57151 .79997 L .56497 .81241 L 1 g
F
P
p
.002 w
.57065 .80161 m .5715 .8039 L p
.57285 .79743 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57065 .80161 L p
1 g
F P
s
P
p
.56339 .80864 m .55726 .81844 L .57065 .80161 L 1 g
F
P
p
.52531 .84034 m .54321 .8235 L .52384 .83084 L 1 g
F
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55642 .8154 L p
1 g
F P
s
P
p
.54374 .82321 m .53695 .82905 L .55642 .8154 L 1 g
F
P
p
.002 w
.55642 .8154 m .55726 .81844 L p
.56339 .80864 L 1 g
F P
s
P
p
.002 w
.54404 .82303 m .56093 .80065 L p
.54371 .82322 L 1 g
F P
s
P
p
.54371 .82322 m .54993 .79814 L .54321 .8235 L 1 g
F
P
p
.54349 .82334 m .54321 .8235 L .54338 .82344 L 1 g
F
P
p
.54374 .82321 m .54338 .82344 L .54356 .82337 L 1 g
F
P
p
.002 w
.54321 .8235 m .52196 .81872 L p
.52384 .83084 L 1 g
F P
s
P
p
.002 w
.53644 .82606 m .53695 .82905 L p
.54356 .82337 L 1 g
F P
s
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53644 .82606 L p
1 g
F P
s
P
p
.52558 .82835 m .51276 .83464 L .53644 .82606 L 1 g
F
P
p
.002 w
.51256 .83108 m .51276 .83464 L p
.52558 .82835 L 1 g
F P
s
P
p
.002 w
.49366 .83332 m .49766 .83421 L p
.5096 .8317 L 1 g
F P
s
P
p
.002 w
.51276 .83464 m .51256 .83108 L p
.49538 .83272 L 1 g
F P
s
P
p
.49772 .83216 m .49538 .83272 L .51256 .83108 L 1 g
F
P
p
.002 w
.46585 .84161 m .49366 .83332 L .49365 .83332 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .50949 .83464 L p
.49538 .83272 L 1 g
F P
s
P
p
.002 w
.50949 .83464 m .51276 .83464 L p
.49538 .83272 L 1 g
F P
s
P
p
.002 w
.4637 .82521 m .46305 .82905 L p
.47712 .82885 L 1 g
F P
s
P
p
.45402 .82099 m .44274 .81844 L .4637 .82521 L 1 g
F
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48741 .83163 L p
1 g
F P
s
P
p
.47712 .82885 m .46305 .82905 L .48741 .83163 L 1 g
F
P
p
.002 w
.44362 .38745 m .45349 .40093 L .5289 .38829 L p
1 g
F P
s
P
p
.002 w
.45349 .40093 m .44362 .38745 L .3756 .41758 L p
1 g
F P
s
P
p
.002 w
.65711 .78154 m .63416 .7832 L .61602 .80064 L p
1 g
F P
s
P
p
.002 w
.63416 .7832 m .65711 .78154 L .67408 .75284 L p
1 g
F P
s
P
p
.002 w
.3756 .41758 m .38091 .43308 L .45349 .40093 L p
1 g
F P
s
P
p
.002 w
.34347 .72201 m .31452 .70057 L .3193 .75433 L p
1 g
F P
s
P
p
.002 w
.3193 .75433 m .34757 .77119 L .34347 .72201 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.004 w
.5 .6118 m
.56008 .73733 L
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.31089 .61579 m .29372 .58888 L .27359 .65157 L p
1 g
F P
s
P
p
.002 w
.27359 .65157 m .29103 .67685 L .31089 .61579 L p
1 g
F P
s
P
p
.002 w
.41686 .79155 m .3804 .78374 L .40208 .81926 L p
1 g
F P
s
P
p
.002 w
.40208 .81926 m .43478 .82129 L .41686 .79155 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.62771 .44064 m .61446 .41566 L .54283 .40739 L p
1 g
F P
s
P
p
.002 w
.5289 .38829 m .54283 .40739 L .61446 .41566 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.71397 .63517 m .72543 .60297 L .69425 .56596 L p
1 g
F P
s
P
p
.002 w
.69661 .53068 m .69425 .56596 L .72543 .60297 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.54283 .40739 m .5289 .38829 L .45349 .40093 L p
1 g
F P
s
P
p
.002 w
.69661 .53068 m .69348 .49799 L .63753 .47073 L p
1 g
F P
s
P
p
.002 w
.62771 .44064 m .63753 .47073 L .69348 .49799 L p
1 g
F P
s
P
p
.002 w
.67408 .75284 m .64575 .76351 L .63416 .7832 L p
1 g
F P
s
P
p
.002 w
.64575 .76351 m .67408 .75284 L .67969 .7238 L p
1 g
F P
s
P
p
.002 w
.70461 .701 m .67969 .7238 L .67408 .75284 L p
1 g
F P
s
P
p
.002 w
.67969 .7238 m .70461 .701 L .6964 .667 L p
1 g
F P
s
P
p
.002 w
.71397 .63517 m .6964 .667 L .70461 .701 L p
1 g
F P
s
P
p
.002 w
.33801 .5291 m .32644 .50333 L .28252 .56293 L p
1 g
F P
s
P
p
.002 w
.28252 .56293 m .29372 .58888 L .33801 .5291 L p
1 g
F P
s
P
p
.002 w
.57349 .79984 m .56825 .82195 L .59325 .81402 L p
1 g
F P
s
P
p
.002 w
.59325 .81402 m .58626 .7958 L .57349 .79984 L p
1 g
F P
s
P
p
.002 w
.58626 .7958 m .59325 .81402 L .61602 .80064 L p
1 g
F P
s
P
p
.002 w
.38967 .45386 m .38091 .43308 L .31987 .48094 L p
1 g
F P
s
P
p
.002 w
.31987 .48094 m .32644 .50333 L .38967 .45386 L p
1 g
F P
s
P
p
.002 w
.61602 .80064 m .59789 .78896 L .58626 .7958 L p
1 g
F P
s
P
p
.002 w
.59789 .78896 m .61602 .80064 L .63416 .7832 L p
1 g
F P
s
P
p
.002 w
.37707 .74049 m .34347 .72201 L .34757 .77119 L p
1 g
F P
s
P
p
.002 w
.34757 .77119 m .3804 .78374 L .37707 .74049 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.33359 .64285 m .31089 .61579 L .29103 .67685 L p
1 g
F P
s
P
p
.002 w
.29103 .67685 m .31452 .70057 L .33359 .64285 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.63416 .7832 m .60713 .78005 L .59789 .78896 L p
1 g
F P
s
P
p
.002 w
.60713 .78005 m .63416 .7832 L .64575 .76351 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.45349 .40093 m .46481 .42055 L .54283 .40739 L p
1 g
F P
s
P
p
.002 w
.46481 .42055 m .45349 .40093 L .38091 .43308 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.6964 .667 m .71397 .63517 L .68637 .60282 L p
1 g
F P
s
P
p
.002 w
.69425 .56596 m .68637 .60282 L .71397 .63517 L p
1 g
F P
s
P
p
.002 w
.38091 .43308 m .38967 .45386 L .46481 .42055 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.63753 .47073 m .62771 .44064 L .55574 .43251 L p
1 g
F P
s
P
p
.002 w
.54283 .40739 m .55574 .43251 L .62771 .44064 L p
1 g
F P
s
P
p
.002 w
.69425 .56596 m .69661 .53068 L .64355 .50513 L p
1 g
F P
s
P
p
.002 w
.63753 .47073 m .64355 .50513 L .69661 .53068 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.67969 .7238 m .64948 .74365 L .64575 .76351 L p
1 g
F P
s
P
p
.002 w
.64948 .74365 m .67969 .7238 L .67316 .6975 L p
1 g
F P
s
P
p
.002 w
.6964 .667 m .67316 .6975 L .67969 .7238 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.64575 .76351 m .61299 .77002 L .60713 .78005 L p
1 g
F P
s
P
p
.002 w
.61299 .77002 m .64575 .76351 L .64948 .74365 L p
1 g
F P
s
P
p
.002 w
.41434 .75542 m .37707 .74049 L .3804 .78374 L p
1 g
F P
s
P
p
.002 w
.3804 .78374 m .41686 .79155 L .41434 .75542 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.55574 .43251 m .54283 .40739 L .46481 .42055 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.54167 .79255 m .50561 .80781 L .52196 .81872 L p
1 g
F P
s
P
p
.002 w
.52196 .81872 m .54993 .79814 L .54167 .79255 L p
1 g
F P
s
P
p
.002 w
.49638 .79196 m .4559 .79433 L .46962 .81747 L p
1 g
F P
s
P
p
.002 w
.46962 .81747 m .50561 .80781 L .49638 .79196 L p
1 g
F P
s
P
p
.002 w
.35431 .55752 m .33801 .5291 L .29372 .58888 L p
1 g
F P
s
P
p
.002 w
.29372 .58888 m .31089 .61579 L .35431 .55752 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.36121 .66924 m .33359 .64285 L .31452 .70057 L p
1 g
F P
s
P
p
.002 w
.31452 .70057 m .34347 .72201 L .36121 .66924 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.40168 .47941 m .38967 .45386 L .32644 .50333 L p
1 g
F P
s
P
p
.002 w
.32644 .50333 m .33801 .5291 L .40168 .47941 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.67316 .6975 m .6964 .667 L .67316 .64016 L p
1 g
F P
s
P
p
.002 w
.68637 .60282 m .67316 .64016 L .6964 .667 L p
1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.59789 .78896 m .57673 .7721 L .58626 .7958 L closepath p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.60713 .78005 m .57673 .7721 L .59789 .78896 L closepath p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.68637 .60282 m .69425 .56596 L .64554 .54284 L p
1 g
F P
s
P
p
.002 w
.64355 .50513 m .64554 .54284 L .69425 .56596 L p
1 g
F P
s
P
p
.002 w
.61299 .77002 m .57673 .7721 L .60713 .78005 L closepath p
1 g
F P
s
P
p
.002 w
.64948 .74365 m .61483 .75993 L .61299 .77002 L p
1 g
F P
s
P
p
.002 w
.61483 .75993 m .64948 .74365 L .6449 .72575 L p
1 g
F P
s
P
p
.002 w
.67316 .6975 m .6449 .72575 L .64948 .74365 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.64355 .50513 m .63753 .47073 L .56722 .46302 L p
1 g
F P
s
P
p
.002 w
.55574 .43251 m .56722 .46302 L .63753 .47073 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.53707 .78448 m .49638 .79196 L .50561 .80781 L p
1 g
F P
s
P
p
.002 w
.50561 .80781 m .54167 .79255 L .53707 .78448 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.46481 .42055 m .47729 .44588 L .55574 .43251 L p
1 g
F P
s
P
p
.002 w
.47729 .44588 m .46481 .42055 L .38967 .45386 L p
1 g
F P
s
P
p
.002 w
.61483 .75993 m .57673 .7721 L .61299 .77002 L closepath p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.6449 .72575 m .67316 .6975 L .65499 .67686 L p
1 g
F P
s
P
p
.002 w
.67316 .64016 m .65499 .67686 L .67316 .6975 L p
1 g
F P
s
P
p
.002 w
.38967 .45386 m .40168 .47941 L .47729 .44588 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.39295 .69415 m .36121 .66924 L .34347 .72201 L p
1 g
F P
s
P
p
.002 w
.34347 .72201 m .37707 .74049 L .39295 .69415 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.37494 .58776 m .35431 .55752 L .31089 .61579 L p
1 g
F P
s
P
p
.002 w
.31089 .61579 m .33359 .64285 L .37494 .58776 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.61243 .75088 m .57673 .7721 L .61483 .75993 L closepath p
1 g
F P
s
P
p
.002 w
.60602 .74385 m .57673 .7721 L .61243 .75088 L closepath p
1 g
F P
s
P
p
.002 w
.59629 .73962 m .57673 .7721 L .60602 .74385 L closepath p
1 g
F P
s
P
p
.002 w
.58427 .73866 m .57673 .7721 L .59629 .73962 L closepath p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.49536 .77284 m .45418 .76632 L .4559 .79433 L p
1 g
F P
s
P
p
.002 w
.4559 .79433 m .49638 .79196 L .49536 .77284 L p
1 g
F P
s
P
p
.002 w
.56722 .46302 m .55574 .43251 L .47729 .44588 L p
1 g
F P
s
P
p
.002 w
.6449 .72575 m .61243 .75088 L .61483 .75993 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.67316 .64016 m .68637 .60282 L .64339 .58274 L p
1 g
F P
s
P
p
.002 w
.64554 .54284 m .64339 .58274 L .68637 .60282 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.61243 .75088 m .6449 .72575 L .63238 .71177 L p
1 g
F P
s
P
p
.002 w
.65499 .67686 m .63238 .71177 L .6449 .72575 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.41663 .50903 m .40168 .47941 L .33801 .5291 L p
1 g
F P
s
P
p
.002 w
.33801 .5291 m .35431 .55752 L .41663 .50903 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.53663 .77478 m .49536 .77284 L .49638 .79196 L p
1 g
F P
s
P
p
.002 w
.49638 .79196 m .53707 .78448 L .53663 .77478 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.64554 .54284 m .64355 .50513 L .57689 .49807 L p
1 g
F P
s
P
p
.002 w
.56722 .46302 m .57689 .49807 L .64355 .50513 L p
1 g
F P
s
P
p
.002 w
.63238 .71177 m .60602 .74385 L .61243 .75088 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.42785 .71679 m .39295 .69415 L .37707 .74049 L p
1 g
F P
s
P
p
.002 w
.37707 .74049 m .41434 .75542 L .42785 .71679 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.65499 .67686 m .67316 .64016 L .63715 .62363 L p
1 g
F P
s
P
p
.002 w
.64339 .58274 m .63715 .62363 L .67316 .64016 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.60602 .74385 m .63238 .71177 L .61322 .7033 L p
1 g
F P
s
P
p
.002 w
.61322 .7033 m .59629 .73962 L .60602 .74385 L p
1 g
F P
s
P
p
.002 w
.39929 .6189 m .37494 .58776 L .33359 .64285 L p
1 g
F P
s
P
p
.002 w
.33359 .64285 m .36121 .66924 L .39929 .6189 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.63238 .71177 m .65499 .67686 L .62699 .66423 L p
1 g
F P
s
P
p
.002 w
.63715 .62363 m .62699 .66423 L .65499 .67686 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.47729 .44588 m .49056 .47623 L .56722 .46302 L p
1 g
F P
s
P
p
.002 w
.49056 .47623 m .47729 .44588 L .40168 .47941 L p
1 g
F P
s
P
p
.002 w
.49536 .77284 m .53663 .77478 L .54044 .76451 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.62699 .66423 m .61322 .7033 L .63238 .71177 L p
1 g
F P
s
P
p
.002 w
.40168 .47941 m .41663 .50903 L .49056 .47623 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.57689 .49807 m .56722 .46302 L .49056 .47623 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.50276 .75251 m .46484 .73644 L .45418 .76632 L p
1 g
F P
s
P
p
.002 w
.45418 .76632 m .49536 .77284 L .50276 .75251 L p
1 g
F P
s
P
p
.002 w
.54044 .76451 m .50276 .75251 L .49536 .77284 L p
1 g
F P
s
P
p
.002 w
.64339 .58274 m .64554 .54284 L .58444 .53663 L p
1 g
F P
s
P
p
.002 w
.57689 .49807 m .58444 .53663 L .64554 .54284 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.59629 .73962 m .61322 .7033 L .58948 .70132 L p
1 g
F P
s
P
p
.002 w
.58948 .70132 m .58427 .73866 L .59629 .73962 L p
1 g
F P
s
P
p
.002 w
.50276 .75251 m .54044 .76451 L .5481 .75479 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.43411 .54187 m .41663 .50903 L .35431 .55752 L p
1 g
F P
s
P
p
.002 w
.35431 .55752 m .37494 .58776 L .43411 .54187 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.58427 .73866 m .58948 .70132 L .56376 .7061 L p
1 g
F P
s
P
p
.002 w
.56376 .7061 m .57129 .74111 L .58427 .73866 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5481 .75479 m .51784 .73323 L .50276 .75251 L p
1 g
F P
s
P
p
.002 w
.42664 .64997 m .39929 .6189 L .36121 .66924 L p
1 g
F P
s
P
p
.002 w
.36121 .66924 m .39295 .69415 L .42664 .64997 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.57129 .74111 m .56376 .7061 L .53895 .71715 L p
1 g
F P
s
P
p
.002 w
.53895 .71715 m .55877 .74669 L .57129 .74111 L p
1 g
F P
s
P
p
.002 w
.63715 .62363 m .64339 .58274 L .58959 .57752 L p
1 g
F P
s
P
p
.002 w
.58444 .53663 m .58959 .57752 L .64339 .58274 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.61322 .7033 m .62699 .66423 L .59215 .66117 L p
1 g
F P
s
P
p
.002 w
.59215 .66117 m .58948 .70132 L .61322 .7033 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.46484 .73644 m .50276 .75251 L .51784 .73323 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.62699 .66423 m .63715 .62363 L .59219 .61947 L p
1 g
F P
s
P
p
.002 w
.58959 .57752 m .59219 .61947 L .63715 .62363 L p
1 g
F P
s
P
p
.002 w
.59219 .61947 m .59215 .66117 L .62699 .66423 L p
1 g
F P
s
P
p
.002 w
.58444 .53663 m .57689 .49807 L .50422 .51074 L p
1 g
F P
s
P
p
.002 w
.49056 .47623 m .50422 .51074 L .57689 .49807 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.50422 .51074 m .49056 .47623 L .41663 .50903 L p
1 g
F P
s
P
p
.002 w
.45614 .68001 m .42664 .64997 L .39295 .69415 L p
1 g
F P
s
P
p
.002 w
.39295 .69415 m .42785 .71679 L .45614 .68001 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.004 w
.59955 .81978 m
.60536 .83192 L
s
P
p
.002 w
.41663 .50903 m .43411 .54187 L .50422 .51074 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.48686 .70805 m .45614 .68001 L .42785 .71679 L p
1 g
F P
s
P
p
.002 w
.4536 .57693 m .43411 .54187 L .37494 .58776 L p
1 g
F P
s
P
p
.002 w
.37494 .58776 m .39929 .6189 L .4536 .57693 L p
1 g
F P
s
P
p
.002 w
.58948 .70132 m .59215 .66117 L .55434 .66813 L p
1 g
F P
s
P
p
.002 w
.55434 .66813 m .56376 .7061 L .58948 .70132 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.56376 .7061 m .55434 .66813 L .51786 .68437 L p
1 g
F P
s
P
p
.002 w
.51786 .68437 m .53895 .71715 L .56376 .7061 L p
1 g
F P
s
P
p
.002 w
.58959 .57752 m .58444 .53663 L .51785 .54839 L p
1 g
F P
s
P
p
.002 w
.50422 .51074 m .51785 .54839 L .58444 .53663 L p
1 g
F P
s
P
p
.002 w
.53895 .71715 m .51786 .68437 L .48686 .70805 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.59215 .66117 m .59219 .61947 L .54332 .62834 L p
1 g
F P
s
P
p
.002 w
.54332 .62834 m .55434 .66813 L .59215 .66117 L p
1 g
F P
s
P
p
.002 w
.51785 .54839 m .50422 .51074 L .43411 .54187 L p
1 g
F P
s
P
p
.002 w
.4745 .61313 m .4536 .57693 L .39929 .6189 L p
1 g
F P
s
P
p
.002 w
.39929 .6189 m .42664 .64997 L .4745 .61313 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.45614 .68001 m .48686 .70805 L .51786 .68437 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.43411 .54187 m .4536 .57693 L .51785 .54839 L p
1 g
F P
s
P
p
.002 w
.59219 .61947 m .58959 .57752 L .53102 .588 L p
1 g
F P
s
P
p
.002 w
.51785 .54839 m .53102 .588 L .58959 .57752 L p
1 g
F P
s
P
p
.002 w
.53102 .588 m .54332 .62834 L .59219 .61947 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.49615 .64933 m .4745 .61313 L .42664 .64997 L p
1 g
F P
s
P
p
.002 w
.42664 .64997 m .45614 .68001 L .49615 .64933 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.51786 .68437 m .49615 .64933 L .45614 .68001 L p
1 g
F P
s
P
p
.002 w
.55434 .66813 m .54332 .62834 L .49615 .64933 L p
1 g
F P
s
P
p
.002 w
.49615 .64933 m .51786 .68437 L .55434 .66813 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.53102 .588 m .51785 .54839 L .4536 .57693 L p
1 g
F P
s
P
p
.004 w
.47102 .55687 m
.48091 .57563 L
s
P
p
.004 w
.48127 .57631 m
.48142 .57658 L
s
P
p
.004 w
.48389 .58126 m
.5 .6118 L
s
P
p
.004 w
.48091 .57563 m
.48127 .57631 L
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.4536 .57693 m .4745 .61313 L .53102 .588 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.54332 .62834 m .53102 .588 L .4745 .61313 L p
1 g
F P
s
P
p
.002 w
.4745 .61313 m .49615 .64933 L .54332 .62834 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .47102 .55687 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .61733 .85693 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.14)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.14)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.4621 .66551 m .4543 .62844 L .51522 .61097 L p
1 g
F P
s
P
p
.002 w
.51522 .61097 m .52878 .64635 L .4621 .66551 L p
1 g
F P
s
P
p
.002 w
.50126 .57563 m .51522 .61097 L .4543 .62844 L p
1 g
F P
s
P
p
.002 w
.52878 .64635 m .51522 .61097 L .57098 .58286 L p
1 g
F P
s
P
p
.002 w
.51522 .61097 m .50126 .57563 L .55024 .55083 L p
1 g
F P
s
P
p
.002 w
.55024 .55083 m .57098 .58286 L .51522 .61097 L p
1 g
F P
s
P
p
.002 w
.4543 .62844 m .44769 .59096 L .50126 .57563 L p
1 g
F P
s
P
p
.002 w
.48723 .54115 m .50126 .57563 L .44769 .59096 L p
1 g
F P
s
P
p
.002 w
.50126 .57563 m .48723 .54115 L .52816 .52035 L p
1 g
F P
s
P
p
.002 w
.52816 .52035 m .55024 .55083 L .50126 .57563 L p
1 g
F P
s
P
p
.002 w
.47091 .7013 m .4621 .66551 L .52878 .64635 L p
1 g
F P
s
P
p
.002 w
.52878 .64635 m .54164 .68093 L .47091 .7013 L p
1 g
F P
s
P
p
.002 w
.54164 .68093 m .52878 .64635 L .58989 .61566 L p
1 g
F P
s
P
p
.002 w
.57098 .58286 m .58989 .61566 L .52878 .64635 L p
1 g
F P
s
P
p
.002 w
.39628 .67126 m .39418 .63352 L .4543 .62844 L p
1 g
F P
s
P
p
.002 w
.4543 .62844 m .4621 .66551 L .39628 .67126 L p
1 g
F P
s
P
p
.002 w
.44769 .59096 m .4543 .62844 L .39418 .63352 L p
1 g
F P
s
P
p
.002 w
.39418 .63352 m .39483 .59527 L .44769 .59096 L p
1 g
F P
s
P
p
.002 w
.44243 .55394 m .44769 .59096 L .39483 .59527 L p
1 g
F P
s
P
p
.002 w
.44769 .59096 m .44243 .55394 L .48723 .54115 L p
1 g
F P
s
P
p
.002 w
.40111 .7076 m .39628 .67126 L .4621 .66551 L p
1 g
F P
s
P
p
.002 w
.4621 .66551 m .47091 .7013 L .40111 .7076 L p
1 g
F P
s
P
p
.002 w
.47347 .50834 m .48723 .54115 L .44243 .55394 L p
1 g
F P
s
P
p
.002 w
.48723 .54115 m .47347 .50834 L .50525 .49212 L p
1 g
F P
s
P
p
.002 w
.50525 .49212 m .52816 .52035 L .48723 .54115 L p
1 g
F P
s
P
p
.002 w
.58989 .61566 m .57098 .58286 L .61605 .54677 L p
1 g
F P
s
P
p
.002 w
.57098 .58286 m .55024 .55083 L .58972 .51897 L p
1 g
F P
s
P
p
.002 w
.58972 .51897 m .61605 .54677 L .57098 .58286 L p
1 g
F P
s
P
p
.002 w
.55024 .55083 m .52816 .52035 L .56103 .49359 L p
1 g
F P
s
P
p
.002 w
.56103 .49359 m .58972 .51897 L .55024 .55083 L p
1 g
F P
s
P
p
.002 w
.48054 .73496 m .47091 .7013 L .54164 .68093 L p
1 g
F P
s
P
p
.002 w
.54164 .68093 m .55349 .7139 L .48054 .73496 L p
1 g
F P
s
P
p
.002 w
.55349 .7139 m .54164 .68093 L .60652 .64848 L p
1 g
F P
s
P
p
.002 w
.58989 .61566 m .60652 .64848 L .54164 .68093 L p
1 g
F P
s
P
p
.002 w
.39483 .59527 m .39824 .55742 L .44243 .55394 L p
1 g
F P
s
P
p
.002 w
.43864 .51826 m .44243 .55394 L .39824 .55742 L p
1 g
F P
s
P
p
.002 w
.44243 .55394 m .43864 .51826 L .47347 .50834 L p
1 g
F P
s
P
p
.002 w
.60652 .64848 m .58989 .61566 L .63941 .57634 L p
1 g
F P
s
P
p
.002 w
.61605 .54677 m .63941 .57634 L .58989 .61566 L p
1 g
F P
s
P
p
.002 w
.40857 .74164 m .40111 .7076 L .47091 .7013 L p
1 g
F P
s
P
p
.002 w
.47091 .7013 m .48054 .73496 L .40857 .74164 L p
1 g
F P
s
P
p
.002 w
.52816 .52035 m .50525 .49212 L .53069 .47126 L p
1 g
F P
s
P
p
.002 w
.53069 .47126 m .56103 .49359 L .52816 .52035 L p
1 g
F P
s
P
p
.002 w
.34083 .62553 m .34801 .588 L .39483 .59527 L p
1 g
F P
s
P
p
.002 w
.39483 .59527 m .39418 .63352 L .34083 .62553 L p
1 g
F P
s
P
p
.002 w
.39824 .55742 m .39483 .59527 L .34801 .588 L p
1 g
F P
s
P
p
.002 w
.4603 .47799 m .47347 .50834 L .43864 .51826 L p
1 g
F P
s
P
p
.002 w
.47347 .50834 m .4603 .47799 L .48205 .46685 L p
1 g
F P
s
P
p
.002 w
.48205 .46685 m .50525 .49212 L .47347 .50834 L p
1 g
F P
s
P
p
.002 w
.33782 .66283 m .34083 .62553 L .39418 .63352 L p
1 g
F P
s
P
p
.002 w
.39418 .63352 m .39628 .67126 L .33782 .66283 L p
1 g
F P
s
P
p
.002 w
.39824 .55742 m .40431 .52086 L .43864 .51826 L p
1 g
F P
s
P
p
.002 w
.43644 .48477 m .43864 .51826 L .40431 .52086 L p
1 g
F P
s
P
p
.002 w
.43864 .51826 m .43644 .48477 L .4603 .47799 L p
1 g
F P
s
P
p
.002 w
.60652 .64848 m .62046 .68053 L .55349 .7139 L p
1 g
F P
s
P
p
.002 w
.62046 .68053 m .60652 .64848 L .6592 .60698 L p
1 g
F P
s
P
p
.002 w
.63941 .57634 m .6592 .60698 L .60652 .64848 L p
1 g
F P
s
P
p
.002 w
.49075 .76566 m .48054 .73496 L .55349 .7139 L p
1 g
F P
s
P
p
.002 w
.55349 .7139 m .56403 .74446 L .49075 .76566 L p
1 g
F P
s
P
p
.002 w
.56403 .74446 m .55349 .7139 L .62046 .68053 L p
1 g
F P
s
P
p
.002 w
.34801 .588 m .35917 .55113 L .39824 .55742 L p
1 g
F P
s
P
p
.002 w
.40431 .52086 m .39824 .55742 L .35917 .55113 L p
1 g
F P
s
P
p
.002 w
.33908 .69897 m .33782 .66283 L .39628 .67126 L p
1 g
F P
s
P
p
.002 w
.39628 .67126 m .40111 .7076 L .33908 .69897 L p
1 g
F P
s
P
p
.002 w
.50525 .49212 m .48205 .46685 L .4994 .45252 L p
1 g
F P
s
P
p
.002 w
.4994 .45252 m .53069 .47126 L .50525 .49212 L p
1 g
F P
s
P
p
.002 w
.4185 .77254 m .40857 .74164 L .48054 .73496 L p
1 g
F P
s
P
p
.002 w
.48054 .73496 m .49075 .76566 L .4185 .77254 L p
1 g
F P
s
P
p
.002 w
.61605 .54677 m .58972 .51897 L .61555 .48315 L p
1 g
F P
s
P
p
.002 w
.58972 .51897 m .56103 .49359 L .58239 .46354 L p
1 g
F P
s
P
p
.002 w
.58239 .46354 m .61555 .48315 L .58972 .51897 L p
1 g
F P
s
P
p
.002 w
.35917 .55113 m .37404 .51583 L .40431 .52086 L p
1 g
F P
s
P
p
.002 w
.41294 .4865 m .40431 .52086 L .37404 .51583 L p
1 g
F P
s
P
p
.002 w
.40431 .52086 m .41294 .4865 L .43644 .48477 L p
1 g
F P
s
P
p
.002 w
.63941 .57634 m .61605 .54677 L .64573 .5062 L p
1 g
F P
s
P
p
.002 w
.61555 .48315 m .64573 .5062 L .61605 .54677 L p
1 g
F P
s
P
p
.002 w
.56103 .49359 m .53069 .47126 L .54709 .44785 L p
1 g
F P
s
P
p
.002 w
.54709 .44785 m .58239 .46354 L .56103 .49359 L p
1 g
F P
s
P
p
.002 w
.34461 .73305 m .33908 .69897 L .40111 .7076 L p
1 g
F P
s
P
p
.002 w
.40111 .7076 m .40857 .74164 L .34461 .73305 L p
1 g
F P
s
P
p
.002 w
.62046 .68053 m .63135 .71103 L .56403 .74446 L p
1 g
F P
s
P
p
.002 w
.63135 .71103 m .62046 .68053 L .67493 .63794 L p
1 g
F P
s
P
p
.002 w
.6592 .60698 m .67493 .63794 L .62046 .68053 L p
1 g
F P
s
P
p
.002 w
.44805 .45086 m .4603 .47799 L .43644 .48477 L p
1 g
F P
s
P
p
.002 w
.4603 .47799 m .44805 .45086 L .45912 .44517 L p
1 g
F P
s
P
p
.002 w
.45912 .44517 m .48205 .46685 L .4603 .47799 L p
1 g
F P
s
P
p
.002 w
.43588 .45431 m .43644 .48477 L .41294 .4865 L p
1 g
F P
s
P
p
.002 w
.43644 .48477 m .43588 .45431 L .44805 .45086 L p
1 g
F P
s
P
p
.002 w
.6592 .60698 m .63941 .57634 L .67219 .53214 L p
1 g
F P
s
P
p
.002 w
.64573 .5062 m .67219 .53214 L .63941 .57634 L p
1 g
F P
s
P
p
.002 w
.53069 .47126 m .4994 .45252 L .51049 .43647 L p
1 g
F P
s
P
p
.002 w
.51049 .43647 m .54709 .44785 L .53069 .47126 L p
1 g
F P
s
P
p
.002 w
.48205 .46685 m .45912 .44517 L .46792 .43785 L p
1 g
F P
s
P
p
.002 w
.46792 .43785 m .4994 .45252 L .48205 .46685 L p
1 g
F P
s
P
p
.002 w
.50131 .79261 m .49075 .76566 L .56403 .74446 L p
1 g
F P
s
P
p
.002 w
.56403 .74446 m .57299 .77185 L .50131 .79261 L p
1 g
F P
s
P
p
.002 w
.57299 .77185 m .56403 .74446 L .63135 .71103 L p
1 g
F P
s
P
p
.002 w
.37404 .51583 m .39227 .48295 L .41294 .4865 L p
1 g
F P
s
P
p
.002 w
.42392 .45516 m .41294 .4865 L .39227 .48295 L p
1 g
F P
s
P
p
.002 w
.41294 .4865 m .42392 .45516 L .43588 .45431 L p
1 g
F P
s
P
p
.002 w
.31213 .56966 m .32935 .53557 L .35917 .55113 L p
1 g
F P
s
P
p
.002 w
.35917 .55113 m .34801 .588 L .31213 .56966 L p
1 g
F P
s
P
p
.002 w
.37404 .51583 m .35917 .55113 L .32935 .53557 L p
1 g
F P
s
P
p
.002 w
.29984 .605 m .31213 .56966 L .34801 .588 L p
1 g
F P
s
P
p
.002 w
.34801 .588 m .34083 .62553 L .29984 .605 L p
1 g
F P
s
P
p
.002 w
.4307 .79949 m .4185 .77254 L .49075 .76566 L p
1 g
F P
s
P
p
.002 w
.49075 .76566 m .50131 .79261 L .4307 .79949 L p
1 g
F P
s
P
p
.002 w
.32935 .53557 m .35103 .50358 L .37404 .51583 L p
1 g
F P
s
P
p
.002 w
.39227 .48295 m .37404 .51583 L .35103 .50358 L p
1 g
F P
s
P
p
.002 w
.35434 .7642 m .34461 .73305 L .40857 .74164 L p
1 g
F P
s
P
p
.002 w
.40857 .74164 m .4185 .77254 L .35434 .7642 L p
1 g
F P
s
P
p
.002 w
.67493 .63794 m .6592 .60698 L .69422 .56035 L p
1 g
F P
s
P
p
.002 w
.67219 .53214 m .69422 .56035 L .6592 .60698 L p
1 g
F P
s
P
p
.002 w
.4994 .45252 m .46792 .43785 L .4735 .42968 L p
1 g
F P
s
P
p
.002 w
.4735 .42968 m .51049 .43647 L .4994 .45252 L p
1 g
F P
s
P
p
.002 w
.29281 .64071 m .29984 .605 L .34083 .62553 L p
1 g
F P
s
P
p
.002 w
.34083 .62553 m .33782 .66283 L .29281 .64071 L p
1 g
F P
s
P
p
.002 w
.63135 .71103 m .63887 .73923 L .57299 .77185 L p
1 g
F P
s
P
p
.002 w
.63887 .73923 m .63135 .71103 L .68615 .66847 L p
1 g
F P
s
P
p
.002 w
.67493 .63794 m .68615 .66847 L .63135 .71103 L p
1 g
F P
s
P
p
.002 w
.35103 .50358 m .37664 .47446 L .39227 .48295 L p
1 g
F P
s
P
p
.002 w
.41343 .45331 m .39227 .48295 L .37664 .47446 L p
1 g
F P
s
P
p
.002 w
.39227 .48295 m .41343 .45331 L .42392 .45516 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .44805 .45086 L .43588 .45431 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .45912 .44517 L .44805 .45086 L closepath p
1 g
F P
s
P
p
.002 w
.61555 .48315 m .58239 .46354 L .58978 .43328 L p
1 g
F P
s
P
p
.002 w
.58239 .46354 m .54709 .44785 L .55259 .42434 L p
1 g
F P
s
P
p
.002 w
.55259 .42434 m .58978 .43328 L .58239 .46354 L p
1 g
F P
s
P
p
.002 w
.29127 .6759 m .29281 .64071 L .33782 .66283 L p
1 g
F P
s
P
p
.002 w
.33782 .66283 m .33908 .69897 L .29127 .6759 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .43588 .45431 L .42392 .45516 L closepath p
1 g
F P
s
P
p
.002 w
.54709 .44785 m .51049 .43647 L .51408 .42039 L p
1 g
F P
s
P
p
.002 w
.51408 .42039 m .55259 .42434 L .54709 .44785 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .46792 .43785 L .45912 .44517 L closepath p
1 g
F P
s
P
p
.002 w
.64573 .5062 m .61555 .48315 L .62474 .447 L p
1 g
F P
s
P
p
.002 w
.58978 .43328 m .62474 .447 L .61555 .48315 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .42392 .45516 L .41343 .45331 L closepath p
1 g
F P
s
P
p
.002 w
.51049 .43647 m .4735 .42968 L .47524 .42151 L p
1 g
F P
s
P
p
.002 w
.47524 .42151 m .51408 .42039 L .51049 .43647 L p
1 g
F P
s
P
p
.002 w
.51197 .81509 m .50131 .79261 L .57299 .77185 L p
1 g
F P
s
P
p
.002 w
.57299 .77185 m .58012 .79532 L .51197 .81509 L p
1 g
F P
s
P
p
.002 w
.58012 .79532 m .57299 .77185 L .63887 .73923 L p
1 g
F P
s
P
p
.002 w
.68615 .66847 m .67493 .63794 L .71125 .59014 L p
1 g
F P
s
P
p
.002 w
.69422 .56035 m .71125 .59014 L .67493 .63794 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .4735 .42968 L .46792 .43785 L closepath p
1 g
F P
s
P
p
.002 w
.67219 .53214 m .64573 .5062 L .65655 .4652 L p
1 g
F P
s
P
p
.002 w
.62474 .447 m .65655 .4652 L .64573 .5062 L p
1 g
F P
s
P
p
.002 w
.36806 .79159 m .35434 .7642 L .4185 .77254 L p
1 g
F P
s
P
p
.002 w
.4185 .77254 m .4307 .79949 L .36806 .79159 L p
1 g
F P
s
P
p
.002 w
.37664 .47446 m .40554 .44895 L .41343 .45331 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .41343 .45331 L .40554 .44895 L closepath p
1 g
F P
s
P
p
.002 w
.44489 .82175 m .4307 .79949 L .50131 .79261 L p
1 g
F P
s
P
p
.002 w
.50131 .79261 m .51197 .81509 L .44489 .82175 L p
1 g
F P
s
P
p
.002 w
.29532 .70965 m .29127 .6759 L .33908 .69897 L p
1 g
F P
s
P
p
.002 w
.33908 .69897 m .34461 .73305 L .29532 .70965 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .47524 .42151 L .4735 .42968 L closepath p
1 g
F P
s
P
p
.002 w
.31213 .51218 m .33787 .48529 L .35103 .50358 L p
1 g
F P
s
P
p
.002 w
.35103 .50358 m .32935 .53557 L .31213 .51218 L p
1 g
F P
s
P
p
.002 w
.37664 .47446 m .35103 .50358 L .33787 .48529 L p
1 g
F P
s
P
p
.002 w
.33787 .48529 m .36779 .46188 L .37664 .47446 L p
1 g
F P
s
P
p
.002 w
.40554 .44895 m .37664 .47446 L .36779 .46188 L p
1 g
F P
s
P
p
.002 w
.29127 .5419 m .31213 .51218 L .32935 .53557 L p
1 g
F P
s
P
p
.002 w
.32935 .53557 m .31213 .56966 L .29127 .5419 L p
1 g
F P
s
P
p
.002 w
.36779 .46188 m .40113 .44252 L .40554 .44895 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .40554 .44895 L .40113 .44252 L closepath p
1 g
F P
s
P
p
.002 w
.63887 .73923 m .64279 .76438 L .58012 .79532 L p
1 g
F P
s
P
p
.002 w
.64279 .76438 m .63887 .73923 L .69253 .69781 L p
1 g
F P
s
P
p
.002 w
.68615 .66847 m .69253 .69781 L .63887 .73923 L p
1 g
F P
s
P
p
.002 w
.69422 .56035 m .67219 .53214 L .68438 .48744 L p
1 g
F P
s
P
p
.002 w
.65655 .4652 m .68438 .48744 L .67219 .53214 L p
1 g
F P
s
P
p
.002 w
.51408 .42039 m .47524 .42151 L .47294 .41425 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .47294 .41425 L .47524 .42151 L closepath p
1 g
F P
s
P
p
.002 w
.55259 .42434 m .51408 .42039 L .5097 .40602 L p
1 g
F P
s
P
p
.002 w
.47294 .41425 m .5097 .40602 L .51408 .42039 L p
1 g
F P
s
P
p
.002 w
.27587 .5737 m .29127 .5419 L .31213 .56966 L p
1 g
F P
s
P
p
.002 w
.31213 .56966 m .29984 .605 L .27587 .5737 L p
1 g
F P
s
P
p
.002 w
.69253 .69781 m .68615 .66847 L .72277 .62077 L p
1 g
F P
s
P
p
.002 w
.71125 .59014 m .72277 .62077 L .68615 .66847 L p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .40068 .43472 L .40428 .42639 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .40113 .44252 L .40068 .43472 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .40428 .42639 L .41155 .41843 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .46681 .40868 L .47294 .41425 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .4575 .40542 L .46681 .40868 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .44603 .40484 L .4575 .40542 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .43364 .40702 L .44603 .40484 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .42171 .41173 L .43364 .40702 L closepath p
1 g
F P
s
P
p
.002 w
.43703 .42768 m .41155 .41843 L .42171 .41173 L closepath p
1 g
F P
s
P
p
.002 w
.58978 .43328 m .55259 .42434 L .5464 .40325 L p
1 g
F P
s
P
p
.002 w
.5097 .40602 m .5464 .40325 L .55259 .42434 L p
1 g
F P
s
P
p
.002 w
.36676 .44653 m .40068 .43472 L .40113 .44252 L p
1 g
F P
s
P
p
.002 w
.40113 .44252 m .36779 .46188 L .36676 .44653 L p
1 g
F P
s
P
p
.002 w
.30492 .74107 m .29532 .70965 L .34461 .73305 L p
1 g
F P
s
P
p
.002 w
.34461 .73305 m .35434 .7642 L .30492 .74107 L p
1 g
F P
s
P
p
.002 w
.5097 .40602 m .47294 .41425 L .46681 .40868 L p
1 g
F P
s
P
p
.002 w
.62474 .447 m .58978 .43328 L .58208 .40604 L p
1 g
F P
s
P
p
.002 w
.5464 .40325 m .58208 .40604 L .58978 .43328 L p
1 g
F P
s
P
p
.002 w
.33616 .46285 m .36676 .44653 L .36779 .46188 L p
1 g
F P
s
P
p
.002 w
.36779 .46188 m .33787 .48529 L .33616 .46285 L p
1 g
F P
s
P
p
.002 w
.3855 .81443 m .36806 .79159 L .4307 .79949 L p
1 g
F P
s
P
p
.002 w
.4307 .79949 m .44489 .82175 L .3855 .81443 L p
1 g
F P
s
P
p
.002 w
.52246 .83245 m .51197 .81509 L .58012 .79532 L p
1 g
F P
s
P
p
.002 w
.58012 .79532 m .58522 .81422 L .52246 .83245 L p
1 g
F P
s
P
p
.002 w
.58522 .81422 m .58012 .79532 L .64279 .76438 L p
1 g
F P
s
P
p
.002 w
.26639 .60678 m .27587 .5737 L .29984 .605 L p
1 g
F P
s
P
p
.002 w
.29984 .605 m .29281 .64071 L .26639 .60678 L p
1 g
F P
s
P
p
.002 w
.71125 .59014 m .69422 .56035 L .70746 .51319 L p
1 g
F P
s
P
p
.002 w
.68438 .48744 m .70746 .51319 L .69422 .56035 L p
1 g
F P
s
P
p
.002 w
.37376 .43004 m .40428 .42639 L .40068 .43472 L p
1 g
F P
s
P
p
.002 w
.40068 .43472 m .36676 .44653 L .37376 .43004 L p
1 g
F P
s
P
p
.002 w
.46076 .83866 m .44489 .82175 L .51197 .81509 L p
1 g
F P
s
P
p
.002 w
.51197 .81509 m .52246 .83245 L .46076 .83866 L p
1 g
F P
s
P
p
.002 w
.30969 .48331 m .33616 .46285 L .33787 .48529 L p
1 g
F P
s
P
p
.002 w
.33787 .48529 m .31213 .51218 L .30969 .48331 L p
1 g
F P
s
P
p
.002 w
.46681 .40868 m .49772 .39495 L .5097 .40602 L p
1 g
F P
s
P
p
.002 w
.49772 .39495 m .46681 .40868 L .4575 .40542 L p
1 g
F P
s
P
p
.002 w
.5464 .40325 m .5097 .40602 L .49772 .39495 L p
1 g
F P
s
P
p
.002 w
.65655 .4652 m .62474 .447 L .61584 .41438 L p
1 g
F P
s
P
p
.002 w
.58208 .40604 m .61584 .41438 L .62474 .447 L p
1 g
F P
s
P
p
.002 w
.38811 .41425 m .41155 .41843 L .40428 .42639 L p
1 g
F P
s
P
p
.002 w
.40428 .42639 m .37376 .43004 L .38811 .41425 L p
1 g
F P
s
P
p
.002 w
.64279 .76438 m .64293 .78578 L .58522 .81422 L p
1 g
F P
s
P
p
.002 w
.64293 .78578 m .64279 .76438 L .69382 .72518 L p
1 g
F P
s
P
p
.002 w
.69253 .69781 m .69382 .72518 L .64279 .76438 L p
1 g
F P
s
P
p
.002 w
.26315 .64029 m .26639 .60678 L .29281 .64071 L p
1 g
F P
s
P
p
.002 w
.29281 .64071 m .29127 .6759 L .26315 .64029 L p
1 g
F P
s
P
p
.002 w
.4575 .40542 m .47936 .38843 L .49772 .39495 L p
1 g
F P
s
P
p
.002 w
.47936 .38843 m .4575 .40542 L .44603 .40484 L p
1 g
F P
s
P
p
.002 w
.31992 .7693 m .30492 .74107 L .35434 .7642 L p
1 g
F P
s
P
p
.002 w
.35434 .7642 m .36806 .79159 L .31992 .7693 L p
1 g
F P
s
P
p
.002 w
.69382 .72518 m .69253 .69781 L .7284 .65148 L p
1 g
F P
s
P
p
.002 w
.72277 .62077 m .7284 .65148 L .69253 .69781 L p
1 g
F P
s
P
p
.002 w
.3463 .43864 m .37376 .43004 L .36676 .44653 L p
1 g
F P
s
P
p
.002 w
.36676 .44653 m .33616 .46285 L .3463 .43864 L p
1 g
F P
s
P
p
.002 w
.72277 .62077 m .71125 .59014 L .72515 .54183 L p
1 g
F P
s
P
p
.002 w
.70746 .51319 m .72515 .54183 L .71125 .59014 L p
1 g
F P
s
P
p
.002 w
.40826 .40092 m .42171 .41173 L .41155 .41843 L p
1 g
F P
s
P
p
.002 w
.41155 .41843 m .38811 .41425 L .40826 .40092 L p
1 g
F P
s
P
p
.002 w
.28812 .50744 m .30969 .48331 L .31213 .51218 L p
1 g
F P
s
P
p
.002 w
.31213 .51218 m .29127 .5419 L .28812 .50744 L p
1 g
F P
s
P
p
.002 w
.58208 .40604 m .5464 .40325 L .52897 .38692 L p
1 g
F P
s
P
p
.002 w
.49772 .39495 m .52897 .38692 L .5464 .40325 L p
1 g
F P
s
P
p
.002 w
.44603 .40484 m .45661 .38725 L .47936 .38843 L p
1 g
F P
s
P
p
.002 w
.45661 .38725 m .44603 .40484 L .43364 .40702 L p
1 g
F P
s
P
p
.002 w
.68438 .48744 m .65655 .4652 L .64675 .42812 L p
1 g
F P
s
P
p
.002 w
.61584 .41438 m .64675 .42812 L .65655 .4652 L p
1 g
F P
s
P
p
.002 w
.43199 .39157 m .43364 .40702 L .42171 .41173 L p
1 g
F P
s
P
p
.002 w
.42171 .41173 m .40826 .40092 L .43199 .39157 L p
1 g
F P
s
P
p
.002 w
.43364 .40702 m .43199 .39157 L .45661 .38725 L p
1 g
F P
s
P
p
.002 w
.52897 .38692 m .49772 .39495 L .47936 .38843 L p
1 g
F P
s
P
p
.002 w
.40625 .83206 m .3855 .81443 L .44489 .82175 L p
1 g
F P
s
P
p
.002 w
.44489 .82175 m .46076 .83866 L .40625 .83206 L p
1 g
F P
s
P
p
.002 w
.26633 .67334 m .26315 .64029 L .29127 .6759 L p
1 g
F P
s
P
p
.002 w
.29127 .6759 m .29532 .70965 L .26633 .67334 L p
1 g
F P
s
P
p
.002 w
.5325 .84412 m .52246 .83245 L .58522 .81422 L p
1 g
F P
s
P
p
.002 w
.58522 .81422 m .58809 .82796 L .5325 .84412 L p
1 g
F P
s
P
p
.002 w
.58809 .82796 m .58522 .81422 L .64293 .78578 L p
1 g
F P
s
P
p
.002 w
.27209 .53466 m .28812 .50744 L .29127 .5419 L p
1 g
F P
s
P
p
.002 w
.29127 .5419 m .27587 .5737 L .27209 .53466 L p
1 g
F P
s
P
p
.002 w
.36736 .41535 m .38811 .41425 L .37376 .43004 L p
1 g
F P
s
P
p
.002 w
.37376 .43004 m .3463 .43864 L .36736 .41535 L p
1 g
F P
s
P
p
.002 w
.32267 .45203 m .3463 .43864 L .33616 .46285 L p
1 g
F P
s
P
p
.002 w
.33616 .46285 m .30969 .48331 L .32267 .45203 L p
1 g
F P
s
P
p
.002 w
.61584 .41438 m .58208 .40604 L .55977 .38487 L p
1 g
F P
s
P
p
.002 w
.52897 .38692 m .55977 .38487 L .58208 .40604 L p
1 g
F P
s
P
p
.002 w
.47792 .84966 m .46076 .83866 L .52246 .83245 L p
1 g
F P
s
P
p
.002 w
.52246 .83245 m .5325 .84412 L .47792 .84966 L p
1 g
F P
s
P
p
.002 w
.70746 .51319 m .68438 .48744 L .67397 .44697 L p
1 g
F P
s
P
p
.002 w
.64675 .42812 m .67397 .44697 L .68438 .48744 L p
1 g
F P
s
P
p
.002 w
.7284 .65148 m .72277 .62077 L .73688 .57264 L p
1 g
F P
s
P
p
.002 w
.72515 .54183 m .73688 .57264 L .72277 .62077 L p
1 g
F P
s
P
p
.002 w
.33997 .79353 m .31992 .7693 L .36806 .79159 L p
1 g
F P
s
P
p
.002 w
.36806 .79159 m .3855 .81443 L .33997 .79353 L p
1 g
F P
s
P
p
.002 w
.47936 .38843 m .50205 .37726 L .52897 .38692 L p
1 g
F P
s
P
p
.002 w
.50205 .37726 m .47936 .38843 L .45661 .38725 L p
1 g
F P
s
P
p
.002 w
.69382 .72518 m .68989 .74984 L .64293 .78578 L p
1 g
F P
s
P
p
.002 w
.68989 .74984 m .69382 .72518 L .72791 .68144 L p
1 g
F P
s
P
p
.002 w
.7284 .65148 m .72791 .68144 L .69382 .72518 L p
1 g
F P
s
P
p
.002 w
.64293 .78578 m .63921 .80281 L .58809 .82796 L p
1 g
F P
s
P
p
.002 w
.63921 .80281 m .64293 .78578 L .68989 .74984 L p
1 g
F P
s
P
p
.002 w
.55977 .38487 m .52897 .38692 L .50205 .37726 L p
1 g
F P
s
P
p
.002 w
.27593 .70502 m .26633 .67334 L .29532 .70965 L p
1 g
F P
s
P
p
.002 w
.29532 .70965 m .30492 .74107 L .27593 .70502 L p
1 g
F P
s
P
p
.002 w
.3971 .39566 m .40826 .40092 L .38811 .41425 L p
1 g
F P
s
P
p
.002 w
.38811 .41425 m .36736 .41535 L .3971 .39566 L p
1 g
F P
s
P
p
.002 w
.26211 .56427 m .27209 .53466 L .27587 .5737 L p
1 g
F P
s
P
p
.002 w
.27587 .5737 m .26639 .60678 L .26211 .56427 L p
1 g
F P
s
P
p
.002 w
.45661 .38725 m .46852 .37547 L .50205 .37726 L p
1 g
F P
s
P
p
.002 w
.46852 .37547 m .45661 .38725 L .43199 .39157 L p
1 g
F P
s
P
p
.002 w
.64675 .42812 m .61584 .41438 L .58929 .38896 L p
1 g
F P
s
P
p
.002 w
.55977 .38487 m .58929 .38896 L .61584 .41438 L p
1 g
F P
s
P
p
.002 w
.30357 .46995 m .32267 .45203 L .30969 .48331 L p
1 g
F P
s
P
p
.002 w
.30969 .48331 m .28812 .50744 L .30357 .46995 L p
1 g
F P
s
P
p
.002 w
.72515 .54183 m .70746 .51319 L .6967 .4705 L p
1 g
F P
s
P
p
.002 w
.67397 .44697 m .6967 .4705 L .70746 .51319 L p
1 g
F P
s
P
p
.002 w
.43215 .38183 m .43199 .39157 L .40826 .40092 L p
1 g
F P
s
P
p
.002 w
.40826 .40092 m .3971 .39566 L .43215 .38183 L p
1 g
F P
s
P
p
.002 w
.42983 .84391 m .40625 .83206 L .46076 .83866 L p
1 g
F P
s
P
p
.002 w
.46076 .83866 m .47792 .84966 L .42983 .84391 L p
1 g
F P
s
P
p
.002 w
.43199 .39157 m .43215 .38183 L .46852 .37547 L p
1 g
F P
s
P
p
.002 w
.34992 .42183 m .36736 .41535 L .3463 .43864 L p
1 g
F P
s
P
p
.002 w
.3463 .43864 m .32267 .45203 L .34992 .42183 L p
1 g
F P
s
P
p
.002 w
.72791 .68144 m .7284 .65148 L .74227 .60483 L p
1 g
F P
s
P
p
.002 w
.73688 .57264 m .74227 .60483 L .7284 .65148 L p
1 g
F P
s
P
p
.002 w
.36463 .81304 m .33997 .79353 L .3855 .81443 L p
1 g
F P
s
P
p
.002 w
.3855 .81443 m .40625 .83206 L .36463 .81304 L p
1 g
F P
s
P
p
.002 w
.54182 .84965 m .5325 .84412 L .58809 .82796 L p
1 g
F P
s
P
p
.002 w
.58809 .82796 m .58862 .83604 L .54182 .84965 L p
1 g
F P
s
P
p
.002 w
.58862 .83604 m .58809 .82796 L .63921 .80281 L p
1 g
F P
s
P
p
.002 w
.25855 .5955 m .26211 .56427 L .26639 .60678 L p
1 g
F P
s
P
p
.002 w
.26639 .60678 m .26315 .64029 L .25855 .5955 L p
1 g
F P
s
P
p
.002 w
.29178 .73445 m .27593 .70502 L .30492 .74107 L p
1 g
F P
s
P
p
.002 w
.30492 .74107 m .31992 .7693 L .29178 .73445 L p
1 g
F P
s
P
p
.002 w
.50205 .37726 m .52499 .37231 L .55977 .38487 L p
1 g
F P
s
P
p
.002 w
.52499 .37231 m .50205 .37726 L .46852 .37547 L p
1 g
F P
s
P
p
.002 w
.49594 .85434 m .47792 .84966 L .5325 .84412 L p
1 g
F P
s
P
p
.002 w
.5325 .84412 m .54182 .84965 L .49594 .85434 L p
1 g
F P
s
P
p
.002 w
.58929 .38896 m .55977 .38487 L .52499 .37231 L p
1 g
F P
s
P
p
.002 w
.68989 .74984 m .68075 .77109 L .63921 .80281 L p
1 g
F P
s
P
p
.002 w
.68075 .77109 m .68989 .74984 L .7212 .70986 L p
1 g
F P
s
P
p
.002 w
.72791 .68144 m .7212 .70986 L .68989 .74984 L p
1 g
F P
s
P
p
.002 w
.67397 .44697 m .64675 .42812 L .61671 .39919 L p
1 g
F P
s
P
p
.002 w
.58929 .38896 m .61671 .39919 L .64675 .42812 L p
1 g
F P
s
P
p
.002 w
.73688 .57264 m .72515 .54183 L .71428 .49813 L p
1 g
F P
s
P
p
.002 w
.6967 .4705 m .71428 .49813 L .72515 .54183 L p
1 g
F P
s
P
p
.002 w
.28961 .492 m .30357 .46995 L .28812 .50744 L p
1 g
F P
s
P
p
.002 w
.28812 .50744 m .27209 .53466 L .28961 .492 L p
1 g
F P
s
P
p
.002 w
.63921 .80281 m .63164 .81489 L .58862 .83604 L p
1 g
F P
s
P
p
.002 w
.63164 .81489 m .63921 .80281 L .68075 .77109 L p
1 g
F P
s
P
p
.002 w
.38855 .39622 m .3971 .39566 L .36736 .41535 L p
1 g
F P
s
P
p
.002 w
.36736 .41535 m .34992 .42183 L .38855 .39622 L p
1 g
F P
s
P
p
.002 w
.7212 .70986 m .72791 .68144 L .74107 .63752 L p
1 g
F P
s
P
p
.002 w
.74227 .60483 m .74107 .63752 L .72791 .68144 L p
1 g
F P
s
P
p
.002 w
.46852 .37547 m .48149 .36995 L .52499 .37231 L p
1 g
F P
s
P
p
.002 w
.48149 .36995 m .46852 .37547 L .43215 .38183 L p
1 g
F P
s
P
p
.002 w
.26162 .62752 m .25855 .5955 L .26315 .64029 L p
1 g
F P
s
P
p
.002 w
.26315 .64029 m .26633 .67334 L .26162 .62752 L p
1 g
F P
s
P
p
.002 w
.33633 .43362 m .34992 .42183 L .32267 .45203 L p
1 g
F P
s
P
p
.002 w
.32267 .45203 m .30357 .46995 L .33633 .43362 L p
1 g
F P
s
P
p
.002 w
.45564 .84953 m .42983 .84391 L .47792 .84966 L p
1 g
F P
s
P
p
.002 w
.47792 .84966 m .49594 .85434 L .45564 .84953 L p
1 g
F P
s
P
p
.002 w
.31353 .76076 m .29178 .73445 L .31992 .7693 L p
1 g
F P
s
P
p
.002 w
.31992 .7693 m .33997 .79353 L .31353 .76076 L p
1 g
F P
s
P
p
.002 w
.39328 .82721 m .36463 .81304 L .40625 .83206 L p
1 g
F P
s
P
p
.002 w
.40625 .83206 m .42983 .84391 L .39328 .82721 L p
1 g
F P
s
P
p
.002 w
.43418 .37822 m .43215 .38183 L .3971 .39566 L p
1 g
F P
s
P
p
.002 w
.3971 .39566 m .38855 .39622 L .43418 .37822 L p
1 g
F P
s
P
p
.002 w
.61671 .39919 m .64125 .41537 L .67397 .44697 L p
1 g
F P
s
P
p
.002 w
.6967 .4705 m .67397 .44697 L .64125 .41537 L p
1 g
F P
s
P
p
.002 w
.43215 .38183 m .43418 .37822 L .48149 .36995 L p
1 g
F P
s
P
p
.002 w
.52499 .37231 m .54758 .37384 L .58929 .38896 L p
1 g
F P
s
P
p
.002 w
.61671 .39919 m .58929 .38896 L .54758 .37384 L p
1 g
F P
s
P
p
.002 w
.71428 .49813 m .72613 .52917 L .73688 .57264 L p
1 g
F P
s
P
p
.002 w
.74227 .60483 m .73688 .57264 L .72613 .52917 L p
1 g
F P
s
P
p
.002 w
.28129 .51764 m .28961 .492 L .27209 .53466 L p
1 g
F P
s
P
p
.002 w
.27209 .53466 m .26211 .56427 L .28129 .51764 L p
1 g
F P
s
P
p
.002 w
.54758 .37384 m .52499 .37231 L .48149 .36995 L p
1 g
F P
s
P
p
.002 w
.68075 .77109 m .66653 .78829 L .63164 .81489 L p
1 g
F P
s
P
p
.002 w
.7212 .70986 m .70836 .73592 L .68075 .77109 L p
1 g
F P
s
P
p
.002 w
.66653 .78829 m .68075 .77109 L .70836 .73592 L p
1 g
F P
s
P
p
.002 w
.55016 .84876 m .54182 .84965 L .58862 .83604 L p
1 g
F P
s
P
p
.002 w
.58862 .83604 m .58672 .83812 L .55016 .84876 L p
1 g
F P
s
P
p
.002 w
.58672 .83812 m .58862 .83604 L .63164 .81489 L p
1 g
F P
s
P
p
.002 w
.51436 .85241 m .49594 .85434 L .54182 .84965 L p
1 g
F P
s
P
p
.002 w
.54182 .84965 m .55016 .84876 L .51436 .85241 L p
1 g
F P
s
P
p
.002 w
.27134 .65942 m .26162 .62752 L .26633 .67334 L p
1 g
F P
s
P
p
.002 w
.26633 .67334 m .27593 .70502 L .27134 .65942 L p
1 g
F P
s
P
p
.002 w
.74107 .63752 m .73322 .66983 L .7212 .70986 L p
1 g
F P
s
P
p
.002 w
.70836 .73592 m .7212 .70986 L .73322 .66983 L p
1 g
F P
s
P
p
.002 w
.63164 .81489 m .62033 .8216 L .58672 .83812 L p
1 g
F P
s
P
p
.002 w
.62033 .8216 m .63164 .81489 L .66653 .78829 L p
1 g
F P
s
P
p
.002 w
.38294 .40274 m .38855 .39622 L .34992 .42183 L p
1 g
F P
s
P
p
.002 w
.34992 .42183 m .33633 .43362 L .38294 .40274 L p
1 g
F P
s
P
p
.002 w
.34065 .78319 m .31353 .76076 L .33997 .79353 L p
1 g
F P
s
P
p
.002 w
.33997 .79353 m .36463 .81304 L .34065 .78319 L p
1 g
F P
s
P
p
.002 w
.71428 .49813 m .6967 .4705 L .66217 .43716 L p
1 g
F P
s
P
p
.002 w
.64125 .41537 m .66217 .43716 L .6967 .4705 L p
1 g
F P
s
P
p
.002 w
.32706 .45053 m .33633 .43362 L .30357 .46995 L p
1 g
F P
s
P
p
.002 w
.30357 .46995 m .28961 .492 L .32706 .45053 L p
1 g
F P
s
P
p
.002 w
.74107 .63752 m .74227 .60483 L .73184 .56279 L p
1 g
F P
s
P
p
.002 w
.72613 .52917 m .73184 .56279 L .74227 .60483 L p
1 g
F P
s
P
p
.002 w
.42517 .83556 m .39328 .82721 L .42983 .84391 L p
1 g
F P
s
P
p
.002 w
.42983 .84391 m .45564 .84953 L .42517 .83556 L p
1 g
F P
s
P
p
.002 w
.64125 .41537 m .61671 .39919 L .56917 .38195 L p
1 g
F P
s
P
p
.002 w
.54758 .37384 m .56917 .38195 L .61671 .39919 L p
1 g
F P
s
P
p
.002 w
.48149 .36995 m .49518 .37101 L .54758 .37384 L p
1 g
F P
s
P
p
.002 w
.49518 .37101 m .48149 .36995 L .43418 .37822 L p
1 g
F P
s
P
p
.002 w
.48301 .84865 m .45564 .84953 L .49594 .85434 L p
1 g
F P
s
P
p
.002 w
.49594 .85434 m .51436 .85241 L .48301 .84865 L p
1 g
F P
s
P
p
.002 w
.27893 .54622 m .28129 .51764 L .26211 .56427 L p
1 g
F P
s
P
p
.002 w
.26211 .56427 m .25855 .5955 L .27893 .54622 L p
1 g
F P
s
P
p
.002 w
.43805 .381 m .43418 .37822 L .38855 .39622 L p
1 g
F P
s
P
p
.002 w
.38855 .39622 m .38294 .40274 L .43805 .381 L p
1 g
F P
s
P
p
.002 w
.28751 .6903 m .27134 .65942 L .27593 .70502 L p
1 g
F P
s
P
p
.002 w
.27593 .70502 m .29178 .73445 L .28751 .6903 L p
1 g
F P
s
P
p
.002 w
.43418 .37822 m .43805 .381 L .49518 .37101 L p
1 g
F P
s
P
p
.002 w
.56917 .38195 m .54758 .37384 L .49518 .37101 L p
1 g
F P
s
P
p
.002 w
.66653 .78829 m .64752 .80086 L .62033 .8216 L p
1 g
F P
s
P
p
.002 w
.64752 .80086 m .66653 .78829 L .68962 .75887 L p
1 g
F P
s
P
p
.002 w
.70836 .73592 m .68962 .75887 L .66653 .78829 L p
1 g
F P
s
P
p
.002 w
.72613 .52917 m .71428 .49813 L .67882 .46405 L p
1 g
F P
s
P
p
.002 w
.66217 .43716 m .67882 .46405 L .71428 .49813 L p
1 g
F P
s
P
p
.002 w
.37242 .80102 m .34065 .78319 L .36463 .81304 L p
1 g
F P
s
P
p
.002 w
.36463 .81304 m .39328 .82721 L .37242 .80102 L p
1 g
F P
s
P
p
.002 w
.68962 .75887 m .70836 .73592 L .71884 .70084 L p
1 g
F P
s
P
p
.002 w
.73322 .66983 m .71884 .70084 L .70836 .73592 L p
1 g
F P
s
P
p
.002 w
.73322 .66983 m .74107 .63752 L .73116 .59807 L p
1 g
F P
s
P
p
.002 w
.73184 .56279 m .73116 .59807 L .74107 .63752 L p
1 g
F P
s
P
p
.002 w
.55724 .84129 m .55016 .84876 L .58672 .83812 L p
1 g
F P
s
P
p
.002 w
.58672 .83812 m .5824 .83397 L .55724 .84129 L p
1 g
F P
s
P
p
.002 w
.5824 .83397 m .58672 .83812 L .62033 .8216 L p
1 g
F P
s
P
p
.002 w
.53265 .84379 m .51436 .85241 L .55016 .84876 L p
1 g
F P
s
P
p
.002 w
.55016 .84876 m .55724 .84129 L .53265 .84379 L p
1 g
F P
s
P
p
.002 w
.32248 .47218 m .32706 .45053 L .28961 .492 L p
1 g
F P
s
P
p
.002 w
.28961 .492 m .28129 .51764 L .32248 .47218 L p
1 g
F P
s
P
p
.002 w
.28273 .57698 m .27893 .54622 L .25855 .5955 L p
1 g
F P
s
P
p
.002 w
.25855 .5955 m .26162 .62752 L .28273 .57698 L p
1 g
F P
s
P
p
.002 w
.66217 .43716 m .64125 .41537 L .58915 .39656 L p
1 g
F P
s
P
p
.002 w
.56917 .38195 m .58915 .39656 L .64125 .41537 L p
1 g
F P
s
P
p
.002 w
.38049 .41517 m .38294 .40274 L .33633 .43362 L p
1 g
F P
s
P
p
.002 w
.33633 .43362 m .32706 .45053 L .38049 .41517 L p
1 g
F P
s
P
p
.002 w
.62033 .8216 m .6055 .82261 L .5824 .83397 L p
1 g
F P
s
P
p
.002 w
.6055 .82261 m .62033 .8216 L .64752 .80086 L p
1 g
F P
s
P
p
.002 w
.45946 .83778 m .42517 .83556 L .45564 .84953 L p
1 g
F P
s
P
p
.002 w
.45564 .84953 m .48301 .84865 L .45946 .83778 L p
1 g
F P
s
P
p
.002 w
.30977 .71924 m .28751 .6903 L .29178 .73445 L p
1 g
F P
s
P
p
.002 w
.29178 .73445 m .31353 .76076 L .30977 .71924 L p
1 g
F P
s
P
p
.002 w
.5112 .84118 m .48301 .84865 L .51436 .85241 L p
1 g
F P
s
P
p
.002 w
.51436 .85241 m .53265 .84379 L .5112 .84118 L p
1 g
F P
s
P
p
.002 w
.49518 .37101 m .50922 .37876 L .56917 .38195 L p
1 g
F P
s
P
p
.002 w
.50922 .37876 m .49518 .37101 L .43805 .381 L p
1 g
F P
s
P
p
.002 w
.73184 .56279 m .72613 .52917 L .69066 .49534 L p
1 g
F P
s
P
p
.002 w
.67882 .46405 m .69066 .49534 L .72613 .52917 L p
1 g
F P
s
P
p
.002 w
.40798 .8137 m .37242 .80102 L .39328 .82721 L p
1 g
F P
s
P
p
.002 w
.39328 .82721 m .42517 .83556 L .40798 .8137 L p
1 g
F P
s
P
p
.002 w
.71884 .70084 m .73322 .66983 L .72403 .63401 L p
1 g
F P
s
P
p
.002 w
.73116 .59807 m .72403 .63401 L .73322 .66983 L p
1 g
F P
s
P
p
.002 w
.58915 .39656 m .56917 .38195 L .50922 .37876 L p
1 g
F P
s
P
p
.002 w
.68962 .75887 m .6654 .77801 L .64752 .80086 L p
1 g
F P
s
P
p
.002 w
.6654 .77801 m .68962 .75887 L .69825 .72965 L p
1 g
F P
s
P
p
.002 w
.71884 .70084 m .69825 .72965 L .68962 .75887 L p
1 g
F P
s
P
p
.002 w
.64752 .80086 m .62414 .80836 L .6055 .82261 L p
1 g
F P
s
P
p
.002 w
.62414 .80836 m .64752 .80086 L .6654 .77801 L p
1 g
F P
s
P
p
.002 w
.44372 .39024 m .43805 .381 L .38294 .40274 L p
1 g
F P
s
P
p
.002 w
.38294 .40274 m .38049 .41517 L .44372 .39024 L p
1 g
F P
s
P
p
.002 w
.43805 .381 m .44372 .39024 L .50922 .37876 L p
1 g
F P
s
P
p
.002 w
.29268 .60904 m .28273 .57698 L .26162 .62752 L p
1 g
F P
s
P
p
.002 w
.26162 .62752 m .27134 .65942 L .29268 .60904 L p
1 g
F P
s
P
p
.002 w
.33752 .74538 m .30977 .71924 L .31353 .76076 L p
1 g
F P
s
P
p
.002 w
.31353 .76076 m .34065 .78319 L .33752 .74538 L p
1 g
F P
s
P
p
.002 w
.67882 .46405 m .66217 .43716 L .6069 .41737 L p
1 g
F P
s
P
p
.002 w
.58915 .39656 m .6069 .41737 L .66217 .43716 L p
1 g
F P
s
P
p
.002 w
.3228 .49805 m .32248 .47218 L .28129 .51764 L p
1 g
F P
s
P
p
.002 w
.28129 .51764 m .27893 .54622 L .3228 .49805 L p
1 g
F P
s
P
p
.002 w
.49518 .8337 m .45946 .83778 L .48301 .84865 L p
1 g
F P
s
P
p
.002 w
.48301 .84865 m .5112 .84118 L .49518 .8337 L p
1 g
F P
s
P
p
.002 w
.73116 .59807 m .73184 .56279 L .69726 .53019 L p
1 g
F P
s
P
p
.002 w
.69066 .49534 m .69726 .53019 L .73184 .56279 L p
1 g
F P
s
P
p
.002 w
.56285 .8273 m .55724 .84129 L .5824 .83397 L p
1 g
F P
s
P
p
.002 w
.5824 .83397 m .5757 .82356 L .56285 .8273 L p
1 g
F P
s
P
p
.002 w
.5757 .82356 m .5824 .83397 L .6055 .82261 L p
1 g
F P
s
P
p
.002 w
.5503 .82856 m .53265 .84379 L .55724 .84129 L p
1 g
F P
s
P
p
.002 w
.55724 .84129 m .56285 .8273 L .5503 .82856 L p
1 g
F P
s
P
p
.002 w
.38134 .43332 m .38049 .41517 L .32706 .45053 L p
1 g
F P
s
P
p
.002 w
.32706 .45053 m .32248 .47218 L .38134 .43332 L p
1 g
F P
s
P
p
.002 w
.69825 .72965 m .71884 .70084 L .71058 .66959 L p
1 g
F P
s
P
p
.002 w
.72403 .63401 m .71058 .66959 L .71884 .70084 L p
1 g
F P
s
P
p
.002 w
.44634 .82081 m .40798 .8137 L .42517 .83556 L p
1 g
F P
s
P
p
.002 w
.42517 .83556 m .45946 .83778 L .44634 .82081 L p
1 g
F P
s
P
p
.002 w
.6055 .82261 m .5875 .81775 L .5757 .82356 L p
1 g
F P
s
P
p
.002 w
.5875 .81775 m .6055 .82261 L .62414 .80836 L p
1 g
F P
s
P
p
.002 w
.6654 .77801 m .63632 .79272 L .62414 .80836 L p
1 g
F P
s
P
p
.002 w
.63632 .79272 m .6654 .77801 L .67196 .7554 L p
1 g
F P
s
P
p
.002 w
.69825 .72965 m .67196 .7554 L .6654 .77801 L p
1 g
F P
s
P
p
.002 w
.53939 .8272 m .5112 .84118 L .53265 .84379 L p
1 g
F P
s
P
p
.002 w
.53265 .84379 m .5503 .82856 L .53939 .8272 L p
1 g
F P
s
P
p
.002 w
.37 .7679 m .33752 .74538 L .34065 .78319 L p
1 g
F P
s
P
p
.002 w
.34065 .78319 m .37242 .80102 L .37 .7679 L p
1 g
F P
s
P
p
.002 w
.30856 .64147 m .29268 .60904 L .27134 .65942 L p
1 g
F P
s
P
p
.002 w
.27134 .65942 m .28751 .6903 L .30856 .64147 L p
1 g
F P
s
P
p
.002 w
.50922 .37876 m .52322 .39314 L .58915 .39656 L p
1 g
F P
s
P
p
.002 w
.52322 .39314 m .50922 .37876 L .44372 .39024 L p
1 g
F P
s
P
p
.002 w
.6069 .41737 m .58915 .39656 L .52322 .39314 L p
1 g
F P
s
P
p
.002 w
.62414 .80836 m .59699 .81048 L .5875 .81775 L p
1 g
F P
s
P
p
.002 w
.59699 .81048 m .62414 .80836 L .63632 .79272 L p
1 g
F P
s
P
p
.002 w
.69066 .49534 m .67882 .46405 L .62187 .44389 L p
1 g
F P
s
P
p
.002 w
.6069 .41737 m .62187 .44389 L .67882 .46405 L p
1 g
F P
s
P
p
.002 w
.72403 .63401 m .73116 .59807 L .69837 .56761 L p
1 g
F P
s
P
p
.002 w
.69726 .53019 m .69837 .56761 L .73116 .59807 L p
1 g
F P
s
P
p
.002 w
.67196 .7554 m .69825 .72965 L .69115 .70376 L p
1 g
F P
s
P
p
.002 w
.71058 .66959 m .69115 .70376 L .69825 .72965 L p
1 g
F P
s
P
p
.002 w
.32814 .52746 m .3228 .49805 L .27893 .54622 L p
1 g
F P
s
P
p
.002 w
.27893 .54622 m .28273 .57698 L .32814 .52746 L p
1 g
F P
s
P
p
.002 w
.45106 .40585 m .44372 .39024 L .38049 .41517 L p
1 g
F P
s
P
p
.002 w
.38049 .41517 m .38134 .43332 L .45106 .40585 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.5112 .84118 m .52307 .83067 L .50768 .83234 L 1 g
F
P
p
.002 w
.49518 .8337 m .49688 .83449 L p
.50768 .83234 L 1 g
F P
s
P
p
.002 w
.49688 .83449 m .5112 .84118 L p
.50768 .83234 L 1 g
F P
s
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51258 .83136 L p
1 g
F P
s
P
p
.53597 .82325 m .51258 .83136 L .52413 .82906 L 1 g
F
P
p
.002 w
.51258 .83136 m .51242 .82869 L p
.49731 .83226 L 1 g
F P
s
P
p
.49731 .83226 m .50056 .83216 L .51258 .83136 L 1 g
F
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.49416 .83236 m .49518 .8337 L p
.49803 .83224 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48741 .83159 L p
1 g
F P
s
P
p
.002 w
.45946 .83778 m .49518 .8337 L .49504 .83351 L p
1 g
F P
s
P
p
.002 w
.49504 .83351 m .49416 .83236 L p
.49187 .83271 L 1 g
F P
s
P
p
.45946 .83778 m .49504 .83351 L .49187 .83271 L 1 g
F
P
p
.45946 .83778 m .49416 .83236 L .47289 .82994 L 1 g
F
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.44634 .82081 m .44676 .82136 L p
.45389 .82149 L 1 g
F P
s
P
p
.002 w
.45276 .82101 m .44634 .82081 L p
.45389 .82149 L 1 g
F P
s
P
p
.002 w
.44676 .82136 m .45946 .83778 L p
.4753 .82854 L 1 g
F P
s
P
p
.002 w
.46363 .8256 m .46403 .82325 L p
.45178 .82048 L 1 g
F P
s
P
p
.002 w
.44634 .82081 m .45276 .82101 L p
.45006 .81956 L 1 g
F P
s
P
p
.45178 .82048 m .45119 .82035 L .45276 .82101 L 1 g
F
P
p
.45178 .82048 m .45276 .82101 L .46363 .8256 L 1 g
F
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44353 .81559 L p
1 g
F P
s
P
p
.002 w
.40798 .8137 m .44634 .82081 L .44622 .81852 L p
1 g
F P
s
P
p
.002 w
.44622 .81852 m .44617 .81745 L p
.44516 .81735 L 1 g
F P
s
P
p
.40798 .8137 m .44622 .81852 L .44516 .81735 L 1 g
F
P
p
.002 w
.44353 .81559 m .44427 .81291 L p
.43751 .80905 L 1 g
F P
s
P
p
.46403 .82325 m .44353 .81559 L .44617 .81745 L 1 g
F
P
p
.002 w
.44617 .81745 m .44634 .82081 L p
.45006 .81956 L 1 g
F P
s
P
p
.44789 .81838 m .44617 .81745 L .44718 .81817 L 1 g
F
P
p
.46403 .82325 m .44617 .81745 L .44789 .81838 L 1 g
F
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.48584 .80753 m .44528 .79947 L .44617 .81745 L p
1 g
F P
s
P
p
.40798 .8137 m .44617 .81745 L .42933 .80556 L 1 g
F
P
p
.46403 .82325 m .44315 .81695 L .45119 .82035 L 1 g
F
P
p
.45006 .81956 m .48584 .80753 L .44617 .81745 L 1 g
F
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42973 .80059 L p
1 g
F P
s
P
p
.44427 .81291 m .42973 .80059 L .43751 .80905 L 1 g
F
P
p
.002 w
.44617 .81745 m .44528 .79947 L p
.43301 .80415 L 1 g
F P
s
P
p
.42933 .80556 m .44353 .81559 L .43301 .80415 L 1 g
F
P
p
.44353 .81559 m .44617 .81745 L .43301 .80415 L 1 g
F
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.40628 .78612 m .40798 .8137 L p
.43165 .80467 L 1 g
F P
s
P
p
.002 w
.42973 .80059 m .43042 .79874 L p
.42603 .79268 L 1 g
F P
s
P
p
.002 w
.40628 .78612 m .42245 .79166 L p
.42288 .78279 L 1 g
F P
s
P
p
.002 w
.42245 .79166 m .42611 .79291 L p
.42324 .78391 L 1 g
F P
s
P
p
.42245 .79166 m .42324 .78391 L .42288 .78279 L 1 g
F
P
p
.002 w
.42324 .78391 m .424 .78222 L p
.4239 .77749 L 1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42324 .78391 L p
1 g
F P
s
P
p
.002 w
.42324 .78391 m .42189 .78694 L p
.42603 .79268 L 1 g
F P
s
P
p
.43042 .79874 m .42324 .78391 L .42603 .79268 L 1 g
F
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .42579 .76511 L .42499 .76677 L p
1 g
F P
s
P
p
.424 .78222 m .42499 .76677 L .4239 .77749 L 1 g
F
P
p
.42288 .78279 m .45664 .77603 L .42524 .76638 L 1 g
F
P
p
.42017 .77428 m .42524 .76638 L .41683 .76379 L 1 g
F
P
p
.42288 .78279 m .42524 .76638 L .42017 .77428 L 1 g
F
P
p
.002 w
.42499 .76677 m .42372 .76938 L p
.4239 .77749 L 1 g
F P
s
P
p
.002 w
.42499 .76677 m .42579 .76511 L p
.43004 .75882 L 1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.42903 .76046 m .45664 .77603 L p
.43225 .75521 L 1 g
F P
s
P
p
.43004 .75882 m .43092 .75752 L .42903 .76046 L 1 g
F
P
p
.43004 .75882 m .42903 .76046 L .42499 .76677 L 1 g
F
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.45664 .77603 m .47936 .75309 L p
.43225 .75521 L 1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.42503 .76631 m .42524 .76638 L .42582 .75865 L 1 g
F
P
p
.002 w
.45664 .77603 m .42903 .76046 L p
.42524 .76638 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43501 .75072 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.47936 .75309 m .46001 .73531 L p
.43225 .75521 L 1 g
F P
s
P
p
.43225 .75521 m .46001 .73531 L .45321 .73752 L 1 g
F
P
p
.002 w
.45215 .73786 m .45268 .73647 L p
.46313 .73402 L 1 g
F P
s
P
p
.002 w
.46001 .73531 m .47936 .75309 L p
.47531 .72916 L 1 g
F P
s
P
p
.002 w
.47471 .72922 m .47494 .72815 L p
.48406 .72826 L 1 g
F P
s
P
p
.47471 .72922 m .47531 .72916 L .47528 .72899 L 1 g
F
P
p
.46001 .73531 m .47531 .72916 L .47471 .72922 L 1 g
F
P
p
.002 w
.47936 .75309 m .511 .73327 L p
.47528 .72899 L 1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47471 .72922 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72661 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.511 .73327 m .50775 .72798 L p
.47608 .72908 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52539 .72968 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52099 .72939 m .511 .73327 L p
.53238 .73225 L 1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54789 .73798 L p
1 g
F P
s
P
p
.52506 .72815 m .54789 .73798 L .53572 .73349 L 1 g
F
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.53238 .73225 m .52539 .72968 L .52099 .72939 L 1 g
F
P
p
.002 w
.55599 .75289 m .55355 .74249 L p
.511 .73327 L 1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56529 .75137 L p
1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.56498 .75115 m .55599 .75289 L p
.56909 .75742 L 1 g
F P
s
P
p
.002 w
.5503 .82856 m .56322 .81167 L p
.56018 .8134 L 1 g
F P
s
P
p
.002 w
.55645 .81552 m .55573 .81291 L p
.54545 .82175 L 1 g
F P
s
P
p
.002 w
.53741 .82627 m .53939 .8272 L .55116 .81853 L p
1 g
F P
s
P
p
.54545 .82175 m .54532 .82185 L .55116 .81853 L 1 g
F
P
p
.54545 .82175 m .55116 .81853 L .55645 .81552 L 1 g
F
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55645 .81552 L p
1 g
F P
s
P
p
.56958 .79874 m .55645 .81552 L .5617 .81083 L 1 g
F
P
p
.002 w
.5429 .82764 m .5503 .82856 L p
.56208 .81049 L 1 g
F P
s
P
p
.56958 .79874 m .5617 .81083 L .56244 .81017 L 1 g
F
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53653 .82659 L p
1 g
F P
s
P
p
.002 w
.5112 .84118 m .53939 .8272 L .53763 .82637 L p
1 g
F P
s
P
p
.002 w
.53763 .82637 m .53741 .82627 L p
.53703 .82649 L 1 g
F P
s
P
p
.5112 .84118 m .53763 .82637 L .53703 .82649 L 1 g
F
P
p
.002 w
.53653 .82659 m .53597 .82325 L p
.52413 .82906 L 1 g
F P
s
P
p
.55573 .81291 m .53653 .82659 L .54221 .82453 L 1 g
F
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.53741 .82627 m .5313 .82337 L p
.52154 .83202 L 1 g
F P
s
P
p
.5112 .84118 m .53741 .82627 L .52154 .83202 L 1 g
F
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53653 .82659 L p
1 g
F P
s
P
p
.002 w
.5313 .82337 m .50056 .83216 L p
.51258 .83136 L 1 g
F P
s
P
p
.52307 .83067 m .5251 .82887 L .51258 .83136 L 1 g
F
P
p
.5251 .82887 m .5313 .82337 L .51258 .83136 L 1 g
F
P
p
.002 w
.50056 .83216 m .49518 .8337 L p
.52307 .83067 L 1 g
F P
s
P
p
.52413 .82906 m .51276 .83464 L .53653 .82659 L 1 g
F
P
p
.002 w
.53653 .82659 m .53695 .82905 L p
.54221 .82453 L 1 g
F P
s
P
p
.002 w
.55116 .81853 m .56208 .81049 L p
.53741 .82627 L 1 g
F P
s
P
p
.002 w
.56208 .81049 m .56677 .80703 L p
.56364 .80908 L 1 g
F P
s
P
p
.5776 .79278 m .57005 .80271 L .57762 .79284 L 1 g
F
P
p
.002 w
.56677 .80703 m .57003 .80276 L p
.57005 .80271 L 1 g
F P
s
P
p
.002 w
.57003 .80276 m .57762 .79284 L p
.57005 .80271 L 1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57057 .80139 L p
1 g
F P
s
P
p
.576 .78222 m .57057 .80139 L .57368 .79342 L 1 g
F
P
p
.56958 .79874 m .56244 .81017 L .56502 .80784 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.52692 .81745 m .5313 .82337 L .56502 .80784 L p
1 g
F P
s
P
p
.002 w
.56502 .80784 m .56677 .80703 L .56555 .80735 L p
1 g
F P
s
P
p
.56958 .79874 m .56502 .80784 L .56555 .80735 L 1 g
F
P
p
.56958 .79874 m .56555 .80735 L .56581 .8071 L 1 g
F
P
p
.002 w
.56599 .80692 m .56677 .80703 L .56615 .80675 L p
1 g
F P
s
P
p
.56613 .80678 m .56581 .8071 L .56612 .80681 L 1 g
F
P
p
.56958 .79874 m .56581 .8071 L .56607 .80684 L 1 g
F
P
p
.56958 .79874 m .56607 .80684 L .56613 .80677 L 1 g
F
P
p
.002 w
.57057 .80139 m .56958 .79874 L p
.56612 .80679 L 1 g
F P
s
P
p
.56612 .80679 m .56647 .80638 L .57057 .80139 L 1 g
F
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.5623 .78255 m .54962 .78746 L .56634 .80654 L p
1 g
F P
s
P
p
.002 w
.56634 .80654 m .56677 .80703 L .56662 .80621 L p
1 g
F P
s
P
p
.56611 .80683 m .56729 .80541 L .57057 .80139 L 1 g
F
P
p
.002 w
.56662 .80621 m .5623 .78255 L p
.56634 .80654 L 1 g
F P
s
P
p
.002 w
.56615 .80675 m .56677 .80703 L .56634 .80654 L p
1 g
F P
s
P
p
.56612 .80679 m .56611 .80683 L .56647 .80638 L 1 g
F
P
p
.56611 .80683 m .56608 .80688 L .56729 .80541 L 1 g
F
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57535 .78001 m .5623 .78255 L .56662 .80621 L p
1 g
F P
s
P
p
.002 w
.56662 .80621 m .56677 .80703 L .56729 .80541 L p
1 g
F P
s
P
p
.002 w
.56729 .80541 m .57535 .78001 L p
.56662 .80621 L 1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .78746 m .53874 .7942 L .56615 .80675 L p
1 g
F P
s
P
p
.002 w
.56634 .80654 m .54962 .78746 L p
.56615 .80675 L 1 g
F P
s
P
p
.56613 .80677 m .56607 .80684 L .56613 .80678 L 1 g
F
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53082 .80203 m .52675 .81007 L .56581 .8071 L p
1 g
F P
s
P
p
.002 w
.56581 .8071 m .56677 .80703 L .56599 .80692 L p
1 g
F P
s
P
p
.002 w
.56599 .80692 m .53082 .80203 L p
.56581 .8071 L 1 g
F P
s
P
p
.002 w
.53874 .7942 m .53082 .80203 L .56599 .80692 L p
1 g
F P
s
P
p
.002 w
.56615 .80675 m .53874 .7942 L p
.56599 .80692 L 1 g
F P
s
P
p
.56612 .80681 m .5659 .80701 L .5661 .80684 L 1 g
F
P
p
.002 w
.56555 .80735 m .56677 .80703 L .56581 .8071 L p
1 g
F P
s
P
p
.5659 .80701 m .56555 .80735 L .56581 .80711 L 1 g
F
P
p
.5659 .80701 m .56581 .80711 L .5661 .80684 L 1 g
F
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.52675 .81007 m .52692 .81745 L .56555 .80735 L p
1 g
F P
s
P
p
.002 w
.56581 .8071 m .52675 .81007 L p
.56555 .80735 L 1 g
F P
s
P
p
.002 w
.56555 .80735 m .52692 .81745 L p
.56502 .80784 L 1 g
F P
s
P
p
.5661 .80684 m .56502 .80784 L .56608 .80688 L 1 g
F
P
p
.002 w
.56729 .80541 m .56677 .80703 L p
.57005 .80271 L 1 g
F P
s
P
p
.57057 .80139 m .57005 .80271 L .5776 .79278 L 1 g
F
P
p
.56729 .80541 m .57005 .80271 L .57057 .80139 L 1 g
F
P
p
.002 w
.57709 .78467 m .576 .78222 L p
.57368 .79342 L 1 g
F P
s
P
p
.002 w
.57535 .78001 m .56729 .80541 L p
.5776 .79278 L 1 g
F P
s
P
p
.002 w
.57762 .79284 m .58734 .78012 L .5768 .78002 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57709 .78467 L p
1 g
F P
s
P
p
.57421 .76511 m .57709 .78467 L .5769 .78165 L 1 g
F
P
p
.002 w
.5768 .78002 m .58734 .78012 L p
.57625 .77556 L 1 g
F P
s
P
p
.57663 .77868 m .57756 .78572 L .57671 .77911 L 1 g
F
P
p
.57421 .76511 m .57728 .78401 L .57663 .77868 L 1 g
F
P
p
.57728 .78401 m .57756 .78572 L .57663 .77868 L 1 g
F
P
p
.002 w
.58188 .74789 m .57625 .77556 L p
.58734 .78012 L 1 g
F P
s
P
p
.57414 .75916 m .57516 .76707 L .57923 .76092 L 1 g
F
P
p
.002 w
.57625 .77556 m .57729 .77046 L p
.57516 .76707 L 1 g
F P
s
P
p
.002 w
.57729 .77046 m .57923 .76092 L p
.57516 .76707 L 1 g
F P
s
P
p
.002 w
.57443 .76636 m .57628 .76938 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57445 .76646 L p
.57811 .78694 L 1 g
F P
s
P
p
.002 w
.56529 .75137 m .56431 .74928 L p
.57032 .75937 L 1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57516 .76707 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.55599 .75289 m .57625 .77556 L .57516 .76707 L 1 g
F
P
p
.56431 .74928 m .57516 .76707 L .57032 .75937 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.56909 .75742 m .57516 .76707 L .57414 .75916 L 1 g
F
P
p
.55599 .75289 m .57516 .76707 L .56909 .75742 L 1 g
F
P
p
.56909 .75742 m .56529 .75137 L .56498 .75115 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56529 .75137 L p
1 g
F P
s
P
p
.57032 .75937 m .57628 .76938 L .56529 .75137 L 1 g
F
P
p
.002 w
.57625 .77556 m .57535 .78001 L .5768 .78002 L p
1 g
F P
s
P
p
.002 w
.5768 .78002 m .57535 .78001 L p
.57762 .79284 L 1 g
F P
s
P
p
.002 w
.60315 .78791 m .59695 .78285 L .56907 .80519 L p
1 g
F P
s
P
p
.002 w
.56907 .80519 m .56677 .80703 L .56874 .806 L p
1 g
F P
s
P
p
.002 w
.56874 .806 m .60315 .78791 L p
.56907 .80519 L 1 g
F P
s
P
p
.57057 .80139 m .56608 .80688 L .56617 .8068 L 1 g
F
P
p
.002 w
.59695 .78285 m .58782 .78025 L p
.57003 .80276 L 1 g
F P
s
P
p
.002 w
.57852 .79166 m .57003 .80276 L p
.58782 .78025 L 1 g
F P
s
P
p
.002 w
.57003 .80276 m .56677 .80703 L .56907 .80519 L p
1 g
F P
s
P
p
.002 w
.56907 .80519 m .59695 .78285 L p
.57003 .80276 L 1 g
F P
s
P
p
.002 w
.57097 .80248 m .57057 .8014 L p
.56617 .8068 L 1 g
F P
s
P
p
.002 w
.57057 .8014 m .57057 .80139 L p
.56617 .8068 L 1 g
F P
s
P
p
.002 w
.58782 .78025 m .58734 .78012 L .57852 .79166 L p
1 g
F P
s
P
p
.57368 .79342 m .57361 .79376 L .57709 .78467 L 1 g
F
P
p
.57361 .79376 m .5715 .8039 L .57675 .78585 L 1 g
F
P
p
.57361 .79376 m .57675 .78585 L .57709 .78467 L 1 g
F
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57732 .78517 L p
1 g
F P
s
P
p
.002 w
.57732 .78517 m .57709 .78467 L p
.57606 .78822 L 1 g
F P
s
P
p
.57606 .78822 m .5715 .8039 L .57732 .78517 L 1 g
F
P
p
.002 w
.57057 .80139 m .5715 .8039 L p
.57368 .79342 L 1 g
F P
s
P
p
.56208 .81049 m .56364 .80908 L .53741 .82627 L 1 g
F
P
p
.002 w
.56322 .81167 m .56677 .80703 L p
.56018 .8134 L 1 g
F P
s
P
p
.002 w
.5757 .82356 m .56677 .80703 L .56285 .8273 L closepath p
1 g
F P
s
P
p
.002 w
.5875 .81775 m .56677 .80703 L .5757 .82356 L closepath p
1 g
F P
s
P
p
.002 w
.56285 .8273 m .56677 .80703 L .5503 .82856 L closepath p
1 g
F P
s
P
p
.002 w
.59699 .81048 m .56677 .80703 L .5875 .81775 L closepath p
1 g
F P
s
P
p
.002 w
.60314 .80251 m .56677 .80703 L .59699 .81048 L closepath p
1 g
F P
s
P
p
.002 w
.60528 .79471 m .56677 .80703 L .60314 .80251 L closepath p
1 g
F P
s
P
p
.002 w
.60315 .78791 m .56677 .80703 L .60528 .79471 L closepath p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57097 .80248 L p
1 g
F P
s
P
p
.002 w
.56677 .80703 m .56502 .80784 L p
.56364 .80908 L 1 g
F P
s
P
p
.002 w
.56677 .80703 m .56208 .81049 L p
.56018 .8134 L 1 g
F P
s
P
p
.56244 .81017 m .55726 .81844 L .57097 .80248 L 1 g
F
P
p
.56244 .81017 m .5571 .81788 L .55928 .81521 L 1 g
F
P
p
.5617 .81083 m .5571 .81788 L .56244 .81017 L 1 g
F
P
p
.002 w
.5313 .82337 m .53741 .82627 L p
.56364 .80908 L 1 g
F P
s
P
p
.002 w
.56502 .80784 m .5313 .82337 L p
.56364 .80908 L 1 g
F P
s
P
p
.002 w
.56208 .81049 m .53939 .8272 L .5429 .82764 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55645 .81552 L p
1 g
F P
s
P
p
.54532 .82185 m .53695 .82905 L .55645 .81552 L 1 g
F
P
p
.002 w
.55645 .81552 m .5571 .81788 L p
.5617 .81083 L 1 g
F P
s
P
p
.002 w
.5571 .81788 m .55726 .81844 L p
.55928 .81521 L 1 g
F P
s
P
p
.002 w
.57709 .78467 m .57756 .78572 L p
.5769 .78165 L 1 g
F P
s
P
p
.002 w
.57756 .78572 m .57811 .78694 L p
.57671 .77911 L 1 g
F P
s
P
p
.002 w
.57535 .78001 m .57625 .77556 L p
.55599 .75289 L 1 g
F P
s
P
p
.56909 .75742 m .57923 .76092 L .56529 .75137 L 1 g
F
P
p
.002 w
.57516 .76707 m .57628 .76938 L p
.57032 .75937 L 1 g
F P
s
P
p
.002 w
.55355 .74249 m .55599 .75289 L .56498 .75115 L p
1 g
F P
s
P
p
.54732 .73647 m .56529 .75137 L .56254 .74948 L 1 g
F
P
p
.54732 .73647 m .56566 .75215 L .55923 .74702 L 1 g
F
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.511 .73327 m .55355 .74249 L .54956 .73931 L 1 g
F
P
p
.002 w
.54789 .73798 m .54732 .73647 L p
.55923 .74702 L 1 g
F P
s
P
p
.511 .73327 m .55293 .73983 L .53238 .73225 L 1 g
F
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54789 .73798 L p
1 g
F P
s
P
p
.55923 .74702 m .56611 .75311 L .54789 .73798 L 1 g
F
P
p
.002 w
.55293 .73983 m .55094 .73137 L p
.54025 .73188 L 1 g
F P
s
P
p
.002 w
.52539 .72968 m .52506 .72815 L p
.53572 .73349 L 1 g
F P
s
P
p
.53238 .73225 m .54789 .73798 L .54025 .73188 L 1 g
F
P
p
.54789 .73798 m .55293 .73983 L .54025 .73188 L 1 g
F
P
p
.002 w
.54801 .71888 m .55355 .74249 L p
.58188 .74789 L 1 g
F P
s
P
p
.002 w
.56498 .75115 m .58188 .74789 L p
.55355 .74249 L 1 g
F P
s
P
p
.56254 .74948 m .56498 .75115 L .56566 .75215 L 1 g
F
P
p
.002 w
.56529 .75137 m .56531 .75141 L p
.56498 .75115 L 1 g
F P
s
P
p
.002 w
.56531 .75141 m .56566 .75215 L p
.56498 .75115 L 1 g
F P
s
P
p
.002 w
.57923 .76092 m .58188 .74789 L .56498 .75115 L p
1 g
F P
s
P
p
.002 w
.55355 .74249 m .55293 .73983 L p
.54956 .73931 L 1 g
F P
s
P
p
.002 w
.56566 .75215 m .56611 .75311 L p
.55923 .74702 L 1 g
F P
s
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52539 .72968 L p
1 g
F P
s
P
p
.53572 .73349 m .54864 .73996 L .52539 .72968 L 1 g
F
P
p
.53238 .73225 m .55094 .73137 L .52539 .72968 L 1 g
F
P
p
.002 w
.54789 .73798 m .54864 .73996 L p
.53572 .73349 L 1 g
F P
s
P
p
.002 w
.50775 .72798 m .511 .73327 L .52099 .72939 L p
1 g
F P
s
P
p
.5 .72527 m .52539 .72968 L .51684 .72911 L 1 g
F
P
p
.5 .72527 m .5257 .73114 L .52152 .7304 L 1 g
F
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.47608 .72908 m .50775 .72798 L .5 .72661 L 1 g
F
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72661 L p
1 g
F P
s
P
p
.002 w
.5 .72661 m .5 .72527 L p
.52152 .7304 L 1 g
F P
s
P
p
.52152 .7304 m .52576 .73141 L .5 .72661 L 1 g
F
P
p
.002 w
.5065 .72594 m .50166 .71806 L p
.48709 .72434 L 1 g
F P
s
P
p
.47494 .72815 m .5 .72661 L .48406 .72826 L 1 g
F
P
p
.47608 .72908 m .5 .72661 L .48709 .72434 L 1 g
F
P
p
.5 .72661 m .5065 .72594 L .48709 .72434 L 1 g
F
P
p
.002 w
.49068 .70018 m .50775 .72798 L p
.54801 .71888 L 1 g
F P
s
P
p
.002 w
.52099 .72939 m .54801 .71888 L p
.50775 .72798 L 1 g
F P
s
P
p
.51684 .72911 m .52099 .72939 L .5257 .73114 L 1 g
F
P
p
.002 w
.52539 .72968 m .52543 .72986 L p
.52099 .72939 L 1 g
F P
s
P
p
.002 w
.52543 .72986 m .5257 .73114 L p
.52099 .72939 L 1 g
F P
s
P
p
.002 w
.55094 .73137 m .54801 .71888 L .52099 .72939 L p
1 g
F P
s
P
p
.002 w
.50775 .72798 m .5065 .72594 L p
.5 .72661 L 1 g
F P
s
P
p
.002 w
.5257 .73114 m .52576 .73141 L p
.52152 .7304 L 1 g
F P
s
P
p
.002 w
.5 .72661 m .5 .72845 L p
.48406 .72826 L 1 g
F P
s
P
p
.47528 .72899 m .47608 .72908 L .50166 .71806 L 1 g
F
P
p
.002 w
.49068 .70018 m .44981 .72593 L p
.47528 .72899 L 1 g
F P
s
P
p
.002 w
.50166 .71806 m .49068 .70018 L p
.47528 .72899 L 1 g
F P
s
P
p
.002 w
.47471 .72922 m .47424 .73141 L p
.46313 .73402 L 1 g
F P
s
P
p
.45268 .73647 m .47471 .72922 L .46313 .73402 L 1 g
F
P
p
.002 w
.5 .72845 m .47424 .73141 L .47471 .72922 L p
1 g
F P
s
P
p
.48406 .72826 m .5 .72845 L .47471 .72922 L 1 g
F
P
p
.46313 .73402 m .46623 .73329 L .46001 .73531 L 1 g
F
P
p
.46313 .73402 m .46001 .73531 L .45215 .73786 L 1 g
F
P
p
.002 w
.44981 .72593 m .46001 .73531 L p
.47528 .72899 L 1 g
F P
s
P
p
.43225 .75521 m .45801 .73347 L .43501 .75072 L 1 g
F
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45215 .73786 L p
1 g
F P
s
P
p
.46623 .73329 m .47424 .73141 L .45215 .73786 L 1 g
F
P
p
.002 w
.46001 .73531 m .45801 .73347 L p
.45321 .73752 L 1 g
F P
s
P
p
.002 w
.43501 .75072 m .43569 .74928 L p
.44171 .74569 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45215 .73786 L p
1 g
F P
s
P
p
.002 w
.45215 .73786 m .45136 .73996 L p
.44171 .74569 L 1 g
F P
s
P
p
.43569 .74928 m .45215 .73786 L .44171 .74569 L 1 g
F
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.44981 .72593 m .42064 .75573 L p
.42882 .75536 L 1 g
F P
s
P
p
.42579 .76511 m .43501 .75072 L .43118 .75696 L 1 g
F
P
p
.42882 .75536 m .43225 .75521 L .43489 .75081 L 1 g
F
P
p
.42882 .75536 m .43489 .75081 L .44981 .72593 L 1 g
F
P
p
.002 w
.45801 .73347 m .45008 .72618 L p
.43501 .75072 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43501 .75072 L p
1 g
F P
s
P
p
.44171 .74569 m .45136 .73996 L .43501 .75072 L 1 g
F
P
p
.002 w
.43501 .75072 m .4343 .75224 L p
.43118 .75696 L 1 g
F P
s
P
p
.002 w
.45008 .72618 m .44981 .72593 L p
.43225 .75521 L 1 g
F P
s
P
p
.42579 .76511 m .4343 .75224 L .43092 .75752 L 1 g
F
P
p
.002 w
.42903 .76046 m .42582 .75865 L p
.42524 .76638 L 1 g
F P
s
P
p
.002 w
.4343 .75224 m .43389 .75311 L p
.43092 .75752 L 1 g
F P
s
P
p
.002 w
.42064 .75573 m .42903 .76046 L p
.43225 .75521 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42499 .76677 L p
1 g
F P
s
P
p
.43092 .75752 m .43389 .75311 L .42499 .76677 L 1 g
F
P
p
.002 w
.42064 .75573 m .41683 .76379 L p
.42503 .76631 L 1 g
F P
s
P
p
.002 w
.42582 .75865 m .42064 .75573 L p
.42503 .76631 L 1 g
F P
s
P
p
.002 w
.41683 .76379 m .40628 .78612 L p
.42288 .78279 L 1 g
F P
s
P
p
.002 w
.44528 .79947 m .45664 .77603 L p
.42288 .78279 L 1 g
F P
s
P
p
.42603 .79268 m .42611 .79291 L .42973 .80059 L 1 g
F
P
p
.002 w
.42611 .79291 m .44528 .79947 L p
.42288 .78279 L 1 g
F P
s
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42324 .78391 L p
1 g
F P
s
P
p
.4239 .77749 m .42372 .76938 L .42324 .78391 L 1 g
F
P
p
.42603 .79268 m .42593 .79254 L .42611 .79291 L 1 g
F
P
p
.002 w
.44528 .79947 m .42611 .79291 L p
.43165 .80467 L 1 g
F P
s
P
p
.002 w
.42611 .79291 m .40628 .78612 L p
.43165 .80467 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42973 .80059 L p
1 g
F P
s
P
p
.42593 .79254 m .42189 .78694 L .42973 .80059 L 1 g
F
P
p
.002 w
.42973 .80059 m .4285 .8039 L p
.43751 .80905 L 1 g
F P
s
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44353 .81559 L p
1 g
F P
s
P
p
.43751 .80905 m .4285 .8039 L .44353 .81559 L 1 g
F
P
p
.002 w
.44353 .81559 m .44315 .81695 L p
.44718 .81817 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .46363 .8256 L p
1 g
F P
s
P
p
.48758 .82869 m .46363 .8256 L .47654 .82885 L 1 g
F
P
p
.4753 .82854 m .48638 .82208 L .45389 .82149 L 1 g
F
P
p
.46363 .8256 m .45389 .82149 L .44676 .82136 L 1 g
F
P
p
.4753 .82854 m .45389 .82149 L .46363 .8256 L 1 g
F
P
p
.002 w
.44315 .81695 m .44274 .81844 L p
.45119 .82035 L 1 g
F P
s
P
p
.002 w
.48638 .82208 m .48584 .80753 L p
.45006 .81956 L 1 g
F P
s
P
p
.002 w
.45276 .82101 m .48638 .82208 L p
.45006 .81956 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46363 .8256 L p
1 g
F P
s
P
p
.45119 .82035 m .44274 .81844 L .46363 .8256 L 1 g
F
P
p
.002 w
.48638 .82208 m .45276 .82101 L p
.45389 .82149 L 1 g
F P
s
P
p
.002 w
.48741 .83159 m .48758 .82869 L p
.47654 .82885 L 1 g
F P
s
P
p
.51242 .82869 m .48741 .83159 L .49601 .83257 L 1 g
F
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.49416 .83236 m .48638 .82208 L p
.47289 .82994 L 1 g
F P
s
P
p
.002 w
.46363 .8256 m .46305 .82905 L p
.47654 .82885 L 1 g
F P
s
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48741 .83159 L p
1 g
F P
s
P
p
.47654 .82885 m .46305 .82905 L .48741 .83159 L 1 g
F
P
p
.002 w
.48741 .83159 m .48724 .83464 L p
.49601 .83257 L 1 g
F P
s
P
p
.002 w
.5313 .82337 m .52692 .81745 L p
.49803 .83224 L 1 g
F P
s
P
p
.002 w
.49518 .8337 m .50056 .83216 L p
.49803 .83224 L 1 g
F P
s
P
p
.002 w
.50056 .83216 m .5313 .82337 L p
.49803 .83224 L 1 g
F P
s
P
p
.002 w
.48724 .83464 m .51276 .83464 L .5126 .83179 L p
1 g
F P
s
P
p
.002 w
.5126 .83179 m .51258 .83136 L p
.50824 .83192 L 1 g
F P
s
P
p
.50824 .83192 m .48724 .83464 L .5126 .83179 L 1 g
F
P
p
.49731 .83226 m .49664 .83242 L .50056 .83216 L 1 g
F
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.52692 .81745 m .48638 .82208 L .49416 .83236 L p
1 g
F P
s
P
p
.49803 .83224 m .52692 .81745 L .49416 .83236 L 1 g
F
P
p
.002 w
.51258 .83136 m .51276 .83464 L p
.52413 .82906 L 1 g
F P
s
P
p
.49664 .83242 m .48724 .83464 L .51258 .83136 L 1 g
F
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.004 w
.5 .6118 m
.53497 .71404 L
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.44372 .39024 m .45106 .40585 L .52322 .39314 L p
1 g
F P
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.40628 .78612 m .37 .7679 L .37242 .80102 L p
1 g
F P
s
P
p
.002 w
.37242 .80102 m .40798 .8137 L .40628 .78612 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.63632 .79272 m .60314 .80251 L .59699 .81048 L p
1 g
F P
s
P
p
.002 w
.60314 .80251 m .63632 .79272 L .64068 .77732 L p
1 g
F P
s
P
p
.002 w
.67196 .7554 m .64068 .77732 L .63632 .79272 L p
1 g
F P
s
P
p
.002 w
.32998 .6733 m .30856 .64147 L .28751 .6903 L p
1 g
F P
s
P
p
.002 w
.28751 .6903 m .30977 .71924 L .32998 .6733 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.38556 .45677 m .38134 .43332 L .32248 .47218 L p
1 g
F P
s
P
p
.002 w
.32248 .47218 m .3228 .49805 L .38556 .45677 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.71058 .66959 m .72403 .63401 L .69389 .60651 L p
1 g
F P
s
P
p
.002 w
.69837 .56761 m .69389 .60651 L .72403 .63401 L p
1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.64068 .77732 m .67196 .7554 L .66627 .73548 L p
1 g
F P
s
P
p
.002 w
.69115 .70376 m .66627 .73548 L .67196 .7554 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.004 w
.5469 .74892 m
.55286 .76637 L
s
P
p
.002 w
.69726 .53019 m .69066 .49534 L .63356 .47544 L p
1 g
F P
s
P
p
.002 w
.62187 .44389 m .63356 .47544 L .69066 .49534 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.62187 .44389 m .6069 .41737 L .53677 .41389 L p
1 g
F P
s
P
p
.002 w
.52322 .39314 m .53677 .41389 L .6069 .41737 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.33841 .55958 m .32814 .52746 L .28273 .57698 L p
1 g
F P
s
P
p
.002 w
.28273 .57698 m .29268 .60904 L .33841 .55958 L p
1 g
F P
s
P
p
.002 w
.53677 .41389 m .52322 .39314 L .45106 .40585 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.35634 .70357 m .32998 .6733 L .30977 .71924 L p
1 g
F P
s
P
p
.002 w
.30977 .71924 m .33752 .74538 L .35634 .70357 L p
1 g
F P
s
P
p
.002 w
.69115 .70376 m .71058 .66959 L .68391 .64574 L p
1 g
F P
s
P
p
.002 w
.69389 .60651 m .68391 .64574 L .71058 .66959 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.64068 .77732 m .60528 .79471 L .60314 .80251 L p
1 g
F P
s
P
p
.002 w
.60528 .79471 m .64068 .77732 L .63665 .76382 L p
1 g
F P
s
P
p
.002 w
.66627 .73548 m .63665 .76382 L .64068 .77732 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.45989 .42752 m .45106 .40585 L .38134 .43332 L p
1 g
F P
s
P
p
.002 w
.38134 .43332 m .38556 .45677 L .45989 .42752 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.69837 .56761 m .69726 .53019 L .64157 .51115 L p
1 g
F P
s
P
p
.002 w
.63356 .47544 m .64157 .51115 L .69726 .53019 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.66627 .73548 m .69115 .70376 L .6687 .68412 L p
1 g
F P
s
P
p
.002 w
.68391 .64574 m .6687 .68412 L .69115 .70376 L p
1 g
F P
s
P
p
.002 w
.45106 .40585 m .45989 .42752 L .53677 .41389 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.63665 .76382 m .60315 .78791 L .60528 .79471 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.52675 .81007 m .48584 .80753 L .48638 .82208 L p
1 g
F P
s
P
p
.002 w
.48638 .82208 m .52692 .81745 L .52675 .81007 L p
1 g
F P
s
P
p
.002 w
.39308 .48493 m .38556 .45677 L .3228 .49805 L p
1 g
F P
s
P
p
.002 w
.3228 .49805 m .32814 .52746 L .39308 .48493 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.38686 .73133 m .35634 .70357 L .33752 .74538 L p
1 g
F P
s
P
p
.002 w
.33752 .74538 m .37 .7679 L .38686 .73133 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.63356 .47544 m .62187 .44389 L .54945 .44051 L p
1 g
F P
s
P
p
.002 w
.53677 .41389 m .54945 .44051 L .62187 .44389 L p
1 g
F P
s
P
p
.002 w
.35337 .59349 m .33841 .55958 L .29268 .60904 L p
1 g
F P
s
P
p
.002 w
.29268 .60904 m .30856 .64147 L .35337 .59349 L p
1 g
F P
s
P
p
.002 w
.63665 .76382 m .66627 .73548 L .64871 .72048 L p
1 g
F P
s
P
p
.002 w
.6687 .68412 m .64871 .72048 L .66627 .73548 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.60315 .78791 m .63665 .76382 L .62455 .75372 L p
1 g
F P
s
P
p
.002 w
.64871 .72048 m .62455 .75372 L .63665 .76382 L p
1 g
F P
s
P
p
.002 w
.62455 .75372 m .59695 .78285 L .60315 .78791 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.69389 .60651 m .69837 .56761 L .64561 .54997 L p
1 g
F P
s
P
p
.002 w
.64157 .51115 m .64561 .54997 L .69837 .56761 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.42064 .75573 m .38686 .73133 L .37 .7679 L p
1 g
F P
s
P
p
.002 w
.37 .7679 m .40628 .78612 L .42064 .75573 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.54945 .44051 m .53677 .41389 L .45989 .42752 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.48584 .80753 m .52675 .81007 L .53082 .80203 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.59695 .78285 m .62455 .75372 L .60561 .74819 L p
1 g
F P
s
P
p
.002 w
.60561 .74819 m .58734 .78012 L .59695 .78285 L p
1 g
F P
s
P
p
.002 w
.53082 .80203 m .49374 .79161 L .48584 .80753 L p
1 g
F P
s
P
p
.002 w
.44528 .79947 m .48584 .80753 L .49374 .79161 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.49374 .79161 m .45664 .77603 L .44528 .79947 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.68391 .64574 m .69389 .60651 L .64552 .59074 L p
1 g
F P
s
P
p
.002 w
.64561 .54997 m .64552 .59074 L .69389 .60651 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.37262 .62814 m .35337 .59349 L .30856 .64147 L p
1 g
F P
s
P
p
.002 w
.30856 .64147 m .32998 .6733 L .37262 .62814 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.49374 .79161 m .53082 .80203 L .53874 .7942 L p
1 g
F P
s
P
p
.002 w
.46997 .4547 m .45989 .42752 L .38556 .45677 L p
1 g
F P
s
P
p
.002 w
.38556 .45677 m .39308 .48493 L .46997 .4547 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.40374 .51703 m .39308 .48493 L .32814 .52746 L p
1 g
F P
s
P
p
.002 w
.32814 .52746 m .33841 .55958 L .40374 .51703 L p
1 g
F P
s
P
p
.002 w
.64157 .51115 m .63356 .47544 L .56087 .4723 L p
1 g
F P
s
P
p
.002 w
.54945 .44051 m .56087 .4723 L .63356 .47544 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.58734 .78012 m .60561 .74819 L .58188 .74789 L p
1 g
F P
s
P
p
.002 w
.62455 .75372 m .64871 .72048 L .62101 .71216 L p
1 g
F P
s
P
p
.002 w
.62101 .71216 m .60561 .74819 L .62455 .75372 L p
1 g
F P
s
P
p
.002 w
.45989 .42752 m .46997 .4547 L .54945 .44051 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.6687 .68412 m .68391 .64574 L .64129 .63221 L p
1 g
F P
s
P
p
.002 w
.64552 .59074 m .64129 .63221 L .68391 .64574 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.53874 .7942 m .5093 .77606 L .49374 .79161 L p
1 g
F P
s
P
p
.002 w
.5093 .77606 m .53874 .7942 L .54962 .78746 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.55599 .75289 m .5623 .78255 L .57535 .78001 L p
1 g
F P
s
P
p
.002 w
.64871 .72048 m .6687 .68412 L .63303 .6731 L p
1 g
F P
s
P
p
.002 w
.63303 .6731 m .62101 .71216 L .64871 .72048 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.004 w
.58722 .86682 m
.59143 .87911 L
s
P
p
.004 w
.59143 .87911 m
.60169 .90913 L
s
P
p
.002 w
.64129 .63221 m .63303 .6731 L .6687 .68412 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.53085 .76265 m .54962 .78746 L .5623 .78255 L p
1 g
F P
s
P
p
.002 w
.54962 .78746 m .53085 .76265 L .5093 .77606 L p
1 g
F P
s
P
p
.002 w
.5623 .78255 m .55599 .75289 L .53085 .76265 L p
1 g
F P
s
P
p
.002 w
.3956 .66247 m .37262 .62814 L .32998 .6733 L p
1 g
F P
s
P
p
.002 w
.32998 .6733 m .35634 .70357 L .3956 .66247 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.45664 .77603 m .49374 .79161 L .5093 .77606 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.56087 .4723 m .54945 .44051 L .46997 .4547 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.64561 .54997 m .64157 .51115 L .57065 .50836 L p
1 g
F P
s
P
p
.002 w
.56087 .4723 m .57065 .50836 L .64157 .51115 L p
1 g
F P
s
P
p
.002 w
.60561 .74819 m .62101 .71216 L .58614 .71157 L p
1 g
F P
s
P
p
.002 w
.58614 .71157 m .58188 .74789 L .60561 .74819 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.4216 .69541 m .3956 .66247 L .35634 .70357 L p
1 g
F P
s
P
p
.002 w
.35634 .70357 m .38686 .73133 L .4216 .69541 L p
1 g
F P
s
P
p
.002 w
.5093 .77606 m .47936 .75309 L .45664 .77603 L p
1 g
F P
s
P
p
.002 w
.41725 .55213 m .40374 .51703 L .33841 .55958 L p
1 g
F P
s
P
p
.002 w
.33841 .55958 m .35337 .59349 L .41725 .55213 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.48103 .48669 m .46997 .4547 L .39308 .48493 L p
1 g
F P
s
P
p
.002 w
.39308 .48493 m .40374 .51703 L .48103 .48669 L p
1 g
F P
s
P
p
.002 w
.44981 .72593 m .4216 .69541 L .38686 .73133 L p
1 g
F P
s
P
p
.002 w
.38686 .73133 m .42064 .75573 L .44981 .72593 L p
1 g
F P
s
P
p
.002 w
.47936 .75309 m .5093 .77606 L .53085 .76265 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.46997 .4547 m .48103 .48669 L .56087 .4723 L p
1 g
F P
s
P
p
.002 w
.58188 .74789 m .58614 .71157 L .54801 .71888 L p
1 g
F P
s
P
p
.002 w
.64552 .59074 m .64561 .54997 L .57847 .54762 L p
1 g
F P
s
P
p
.002 w
.57065 .50836 m .57847 .54762 L .64561 .54997 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.62101 .71216 m .63303 .6731 L .58796 .67215 L p
1 g
F P
s
P
p
.002 w
.58796 .67215 m .58614 .71157 L .62101 .71216 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.511 .73327 m .53085 .76265 L .55599 .75289 L p
1 g
F P
s
P
p
.002 w
.53085 .76265 m .511 .73327 L .47936 .75309 L p
1 g
F P
s
P
p
.002 w
.57065 .50836 m .56087 .4723 L .48103 .48669 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.43322 .58916 m .41725 .55213 L .35337 .59349 L p
1 g
F P
s
P
p
.002 w
.35337 .59349 m .37262 .62814 L .43322 .58916 L p
1 g
F P
s
P
p
.002 w
.64129 .63221 m .64552 .59074 L .58407 .58887 L p
1 g
F P
s
P
p
.002 w
.57847 .54762 m .58407 .58887 L .64552 .59074 L p
1 g
F P
s
P
p
.002 w
.63303 .6731 m .64129 .63221 L .58727 .63082 L p
1 g
F P
s
P
p
.002 w
.58727 .63082 m .58796 .67215 L .63303 .6731 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.58407 .58887 m .58727 .63082 L .64129 .63221 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.49273 .52254 m .48103 .48669 L .40374 .51703 L p
1 g
F P
s
P
p
.002 w
.40374 .51703 m .41725 .55213 L .49273 .52254 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.58614 .71157 m .58796 .67215 L .53859 .68152 L p
1 g
F P
s
P
p
.002 w
.53859 .68152 m .54801 .71888 L .58614 .71157 L p
1 g
F P
s
P
p
.002 w
.45116 .62697 m .43322 .58916 L .37262 .62814 L p
1 g
F P
s
P
p
.002 w
.37262 .62814 m .3956 .66247 L .45116 .62697 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.48103 .48669 m .49273 .52254 L .57065 .50836 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57847 .54762 m .57065 .50836 L .49273 .52254 L p
1 g
F P
s
P
p
.002 w
.4216 .69541 m .44981 .72593 L .49068 .70018 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.54801 .71888 m .53859 .68152 L .49068 .70018 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.47052 .66437 m .45116 .62697 L .3956 .66247 L p
1 g
F P
s
P
p
.002 w
.3956 .66247 m .4216 .69541 L .47052 .66437 L p
1 g
F P
s
P
p
.002 w
.49068 .70018 m .47052 .66437 L .4216 .69541 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.58796 .67215 m .58727 .63082 L .52801 .64195 L p
1 g
F P
s
P
p
.002 w
.52801 .64195 m .53859 .68152 L .58796 .67215 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.50471 .56118 m .49273 .52254 L .41725 .55213 L p
1 g
F P
s
P
p
.002 w
.41725 .55213 m .43322 .58916 L .50471 .56118 L p
1 g
F P
s
P
p
.002 w
.58407 .58887 m .57847 .54762 L .50471 .56118 L p
1 g
F P
s
P
p
.002 w
.49273 .52254 m .50471 .56118 L .57847 .54762 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.58727 .63082 m .58407 .58887 L .5166 .60141 L p
1 g
F P
s
P
p
.002 w
.5166 .60141 m .52801 .64195 L .58727 .63082 L p
1 g
F P
s
P
p
.002 w
.47052 .66437 m .49068 .70018 L .53859 .68152 L p
1 g
F P
s
P
p
.002 w
.50471 .56118 m .5166 .60141 L .58407 .58887 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.53859 .68152 m .52801 .64195 L .47052 .66437 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.5166 .60141 m .50471 .56118 L .43322 .58916 L p
1 g
F P
s
P
p
.002 w
.43322 .58916 m .45116 .62697 L .5166 .60141 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.45116 .62697 m .47052 .66437 L .52801 .64195 L p
1 g
F P
s
P
p
.002 w
.52801 .64195 m .5166 .60141 L .45116 .62697 L p
1 g
F P
s
P
p
.004 w
.46718 .63707 m
.4784 .62844 L
s
P
p
.004 w
.4784 .62844 m
.4788 .62812 L
s
P
p
.004 w
.4788 .62812 m
.47896 .628 L
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .46718 .63707 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .60169 .90913 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.21)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.21)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.45936 .6655 m .45898 .62779 L .52832 .62357 L p
1 g
F P
s
P
p
.002 w
.52832 .62357 m .53284 .66101 L .45936 .6655 L p
1 g
F P
s
P
p
.002 w
.52306 .58587 m .52832 .62357 L .45898 .62779 L p
1 g
F P
s
P
p
.002 w
.53284 .66101 m .52832 .62357 L .59424 .60919 L p
1 g
F P
s
P
p
.002 w
.52832 .62357 m .52306 .58587 L .5833 .57259 L p
1 g
F P
s
P
p
.002 w
.5833 .57259 m .59424 .60919 L .52832 .62357 L p
1 g
F P
s
P
p
.002 w
.45898 .62779 m .45966 .58971 L .52306 .58587 L p
1 g
F P
s
P
p
.002 w
.51719 .54879 m .52306 .58587 L .45966 .58971 L p
1 g
F P
s
P
p
.002 w
.52306 .58587 m .51719 .54879 L .57017 .53699 L p
1 g
F P
s
P
p
.002 w
.57017 .53699 m .5833 .57259 L .52306 .58587 L p
1 g
F P
s
P
p
.002 w
.38928 .65894 m .39288 .62143 L .45898 .62779 L p
1 g
F P
s
P
p
.002 w
.45898 .62779 m .45936 .6655 L .38928 .65894 L p
1 g
F P
s
P
p
.002 w
.45966 .58971 m .45898 .62779 L .39288 .62143 L p
1 g
F P
s
P
p
.002 w
.39288 .62143 m .39926 .58373 L .45966 .58971 L p
1 g
F P
s
P
p
.002 w
.4614 .55215 m .45966 .58971 L .39926 .58373 L p
1 g
F P
s
P
p
.002 w
.45966 .58971 m .4614 .55215 L .51719 .54879 L p
1 g
F P
s
P
p
.002 w
.4608 .70195 m .45936 .6655 L .53284 .66101 L p
1 g
F P
s
P
p
.002 w
.53284 .66101 m .53653 .6973 L .4608 .70195 L p
1 g
F P
s
P
p
.002 w
.53653 .6973 m .53284 .66101 L .60275 .64591 L p
1 g
F P
s
P
p
.002 w
.59424 .60919 m .60275 .64591 L .53284 .66101 L p
1 g
F P
s
P
p
.002 w
.51086 .51319 m .51719 .54879 L .4614 .55215 L p
1 g
F P
s
P
p
.002 w
.51719 .54879 m .51086 .51319 L .55516 .50322 L p
1 g
F P
s
P
p
.002 w
.55516 .50322 m .57017 .53699 L .51719 .54879 L p
1 g
F P
s
P
p
.002 w
.38857 .69538 m .38928 .65894 L .45936 .6655 L p
1 g
F P
s
P
p
.002 w
.45936 .6655 m .4608 .70195 L .38857 .69538 L p
1 g
F P
s
P
p
.002 w
.39926 .58373 m .40828 .54675 L .4614 .55215 L p
1 g
F P
s
P
p
.002 w
.46415 .51599 m .4614 .55215 L .40828 .54675 L p
1 g
F P
s
P
p
.002 w
.4614 .55215 m .46415 .51599 L .51086 .51319 L p
1 g
F P
s
P
p
.002 w
.59424 .60919 m .5833 .57259 L .63445 .55108 L p
1 g
F P
s
P
p
.002 w
.5833 .57259 m .57017 .53699 L .61505 .51786 L p
1 g
F P
s
P
p
.002 w
.61505 .51786 m .63445 .55108 L .5833 .57259 L p
1 g
F P
s
P
p
.002 w
.46327 .73627 m .4608 .70195 L .53653 .6973 L p
1 g
F P
s
P
p
.002 w
.53653 .6973 m .53929 .73159 L .46327 .73627 L p
1 g
F P
s
P
p
.002 w
.53929 .73159 m .53653 .6973 L .60861 .6819 L p
1 g
F P
s
P
p
.002 w
.60275 .64591 m .60861 .6819 L .53653 .6973 L p
1 g
F P
s
P
p
.002 w
.60275 .64591 m .59424 .60919 L .65033 .58592 L p
1 g
F P
s
P
p
.002 w
.63445 .55108 m .65033 .58592 L .59424 .60919 L p
1 g
F P
s
P
p
.002 w
.39078 .72986 m .38857 .69538 L .4608 .70195 L p
1 g
F P
s
P
p
.002 w
.4608 .70195 m .46327 .73627 L .39078 .72986 L p
1 g
F P
s
P
p
.002 w
.50419 .47992 m .51086 .51319 L .46415 .51599 L p
1 g
F P
s
P
p
.002 w
.51086 .51319 m .50419 .47992 L .53863 .47211 L p
1 g
F P
s
P
p
.002 w
.53863 .47211 m .55516 .50322 L .51086 .51319 L p
1 g
F P
s
P
p
.002 w
.40828 .54675 m .41971 .51135 L .46415 .51599 L p
1 g
F P
s
P
p
.002 w
.46785 .4821 m .46415 .51599 L .41971 .51135 L p
1 g
F P
s
P
p
.002 w
.46415 .51599 m .46785 .4821 L .50419 .47992 L p
1 g
F P
s
P
p
.002 w
.57017 .53699 m .55516 .50322 L .5926 .48705 L p
1 g
F P
s
P
p
.002 w
.5926 .48705 m .61505 .51786 L .57017 .53699 L p
1 g
F P
s
P
p
.002 w
.3365 .60495 m .34782 .56839 L .39926 .58373 L p
1 g
F P
s
P
p
.002 w
.39926 .58373 m .39288 .62143 L .3365 .60495 L p
1 g
F P
s
P
p
.002 w
.40828 .54675 m .39926 .58373 L .34782 .56839 L p
1 g
F P
s
P
p
.002 w
.32944 .64181 m .3365 .60495 L .39288 .62143 L p
1 g
F P
s
P
p
.002 w
.39288 .62143 m .38928 .65894 L .32944 .64181 L p
1 g
F P
s
P
p
.002 w
.60861 .6819 m .60275 .64591 L .66231 .62154 L p
1 g
F P
s
P
p
.002 w
.65033 .58592 m .66231 .62154 L .60275 .64591 L p
1 g
F P
s
P
p
.002 w
.34782 .56839 m .36314 .53301 L .40828 .54675 L p
1 g
F P
s
P
p
.002 w
.41971 .51135 m .40828 .54675 L .36314 .53301 L p
1 g
F P
s
P
p
.002 w
.32686 .67806 m .32944 .64181 L .38928 .65894 L p
1 g
F P
s
P
p
.002 w
.38928 .65894 m .38857 .69538 L .32686 .67806 L p
1 g
F P
s
P
p
.002 w
.55516 .50322 m .53863 .47211 L .56763 .45942 L p
1 g
F P
s
P
p
.002 w
.56763 .45942 m .5926 .48705 L .55516 .50322 L p
1 g
F P
s
P
p
.002 w
.46673 .76762 m .46327 .73627 L .53929 .73159 L p
1 g
F P
s
P
p
.002 w
.53929 .73159 m .54104 .76303 L .46673 .76762 L p
1 g
F P
s
P
p
.002 w
.54104 .76303 m .53929 .73159 L .61165 .71627 L p
1 g
F P
s
P
p
.002 w
.60861 .6819 m .61165 .71627 L .53929 .73159 L p
1 g
F P
s
P
p
.002 w
.36314 .53301 m .38206 .49967 L .41971 .51135 L p
1 g
F P
s
P
p
.002 w
.43332 .47841 m .41971 .51135 L .38206 .49967 L p
1 g
F P
s
P
p
.002 w
.41971 .51135 m .43332 .47841 L .46785 .4821 L p
1 g
F P
s
P
p
.002 w
.61165 .71627 m .60861 .6819 L .67007 .65708 L p
1 g
F P
s
P
p
.002 w
.66231 .62154 m .67007 .65708 L .60861 .6819 L p
1 g
F P
s
P
p
.002 w
.3959 .76151 m .39078 .72986 L .46327 .73627 L p
1 g
F P
s
P
p
.002 w
.46327 .73627 m .46673 .76762 L .3959 .76151 L p
1 g
F P
s
P
p
.002 w
.49735 .44982 m .50419 .47992 L .46785 .4821 L p
1 g
F P
s
P
p
.002 w
.50419 .47992 m .49735 .44982 L .52094 .44443 L p
1 g
F P
s
P
p
.002 w
.52094 .44443 m .53863 .47211 L .50419 .47992 L p
1 g
F P
s
P
p
.002 w
.47244 .45131 m .46785 .4821 L .43332 .47841 L p
1 g
F P
s
P
p
.002 w
.46785 .4821 m .47244 .45131 L .49735 .44982 L p
1 g
F P
s
P
p
.002 w
.32886 .7128 m .32686 .67806 L .38857 .69538 L p
1 g
F P
s
P
p
.002 w
.38857 .69538 m .39078 .72986 L .32886 .7128 L p
1 g
F P
s
P
p
.002 w
.53863 .47211 m .52094 .44443 L .54075 .43567 L p
1 g
F P
s
P
p
.002 w
.54075 .43567 m .56763 .45942 L .53863 .47211 L p
1 g
F P
s
P
p
.002 w
.65033 .58592 m .63445 .55108 L .6712 .52332 L p
1 g
F P
s
P
p
.002 w
.63445 .55108 m .61505 .51786 L .64714 .49319 L p
1 g
F P
s
P
p
.002 w
.64714 .49319 m .6712 .52332 L .63445 .55108 L p
1 g
F P
s
P
p
.002 w
.61505 .51786 m .5926 .48705 L .61922 .46623 L p
1 g
F P
s
P
p
.002 w
.61922 .46623 m .64714 .49319 L .61505 .51786 L p
1 g
F P
s
P
p
.002 w
.38206 .49967 m .40415 .46919 L .43332 .47841 L p
1 g
F P
s
P
p
.002 w
.44879 .44873 m .43332 .47841 L .40415 .46919 L p
1 g
F P
s
P
p
.002 w
.43332 .47841 m .44879 .44873 L .47244 .45131 L p
1 g
F P
s
P
p
.002 w
.66231 .62154 m .65033 .58592 L .69079 .55588 L p
1 g
F P
s
P
p
.002 w
.6712 .52332 m .69079 .55588 L .65033 .58592 L p
1 g
F P
s
P
p
.002 w
.61165 .71627 m .61178 .74819 L .54104 .76303 L p
1 g
F P
s
P
p
.002 w
.61178 .74819 m .61165 .71627 L .67337 .69166 L p
1 g
F P
s
P
p
.002 w
.67007 .65708 m .67337 .69166 L .61165 .71627 L p
1 g
F P
s
P
p
.002 w
.5926 .48705 m .56763 .45942 L .58813 .44312 L p
1 g
F P
s
P
p
.002 w
.58813 .44312 m .61922 .46623 L .5926 .48705 L p
1 g
F P
s
P
p
.002 w
.47111 .7952 m .46673 .76762 L .54104 .76303 L p
1 g
F P
s
P
p
.002 w
.54104 .76303 m .54173 .79082 L .47111 .7952 L p
1 g
F P
s
P
p
.002 w
.54173 .79082 m .54104 .76303 L .61178 .74819 L p
1 g
F P
s
P
p
.002 w
.31074 .54502 m .33073 .51217 L .36314 .53301 L p
1 g
F P
s
P
p
.002 w
.36314 .53301 m .34782 .56839 L .31074 .54502 L p
1 g
F P
s
P
p
.002 w
.38206 .49967 m .36314 .53301 L .33073 .51217 L p
1 g
F P
s
P
p
.002 w
.29571 .57976 m .31074 .54502 L .34782 .56839 L p
1 g
F P
s
P
p
.002 w
.34782 .56839 m .3365 .60495 L .29571 .57976 L p
1 g
F P
s
P
p
.002 w
.40383 .78953 m .3959 .76151 L .46673 .76762 L p
1 g
F P
s
P
p
.002 w
.46673 .76762 m .47111 .7952 L .40383 .78953 L p
1 g
F P
s
P
p
.002 w
.33543 .74514 m .32886 .7128 L .39078 .72986 L p
1 g
F P
s
P
p
.002 w
.39078 .72986 m .3959 .76151 L .33543 .74514 L p
1 g
F P
s
P
p
.002 w
.49051 .42367 m .49735 .44982 L .47244 .45131 L p
1 g
F P
s
P
p
.002 w
.49735 .44982 m .49051 .42367 L .50253 .4209 L p
1 g
F P
s
P
p
.002 w
.50253 .4209 m .52094 .44443 L .49735 .44982 L p
1 g
F P
s
P
p
.002 w
.67007 .65708 m .66231 .62154 L .70538 .59008 L p
1 g
F P
s
P
p
.002 w
.69079 .55588 m .70538 .59008 L .66231 .62154 L p
1 g
F P
s
P
p
.002 w
.33073 .51217 m .35517 .48203 L .38206 .49967 L p
1 g
F P
s
P
p
.002 w
.40415 .46919 m .38206 .49967 L .35517 .48203 L p
1 g
F P
s
P
p
.002 w
.4778 .42442 m .47244 .45131 L .44879 .44873 L p
1 g
F P
s
P
p
.002 w
.47244 .45131 m .4778 .42442 L .49051 .42367 L p
1 g
F P
s
P
p
.002 w
.28606 .61553 m .29571 .57976 L .3365 .60495 L p
1 g
F P
s
P
p
.002 w
.3365 .60495 m .32944 .64181 L .28606 .61553 L p
1 g
F P
s
P
p
.002 w
.56763 .45942 m .54075 .43567 L .55464 .42444 L p
1 g
F P
s
P
p
.002 w
.55464 .42444 m .58813 .44312 L .56763 .45942 L p
1 g
F P
s
P
p
.002 w
.52094 .44443 m .50253 .4209 L .51258 .41641 L p
1 g
F P
s
P
p
.002 w
.51258 .41641 m .54075 .43567 L .52094 .44443 L p
1 g
F P
s
P
p
.002 w
.40415 .46919 m .42887 .44233 L .44879 .44873 L p
1 g
F P
s
P
p
.002 w
.46575 .42308 m .44879 .44873 L .42887 .44233 L p
1 g
F P
s
P
p
.002 w
.44879 .44873 m .46575 .42308 L .4778 .42442 L p
1 g
F P
s
P
p
.002 w
.35517 .48203 m .38344 .45533 L .40415 .46919 L p
1 g
F P
s
P
p
.002 w
.42887 .44233 m .40415 .46919 L .38344 .45533 L p
1 g
F P
s
P
p
.002 w
.28208 .65141 m .28606 .61553 L .32944 .64181 L p
1 g
F P
s
P
p
.002 w
.32944 .64181 m .32686 .67806 L .28208 .65141 L p
1 g
F P
s
P
p
.002 w
.67337 .69166 m .67007 .65708 L .71459 .62506 L p
1 g
F P
s
P
p
.002 w
.70538 .59008 m .71459 .62506 L .67007 .65708 L p
1 g
F P
s
P
p
.002 w
.61178 .74819 m .60894 .77683 L .54173 .79082 L p
1 g
F P
s
P
p
.002 w
.60894 .77683 m .61178 .74819 L .67209 .7244 L p
1 g
F P
s
P
p
.002 w
.67337 .69166 m .67209 .7244 L .61178 .74819 L p
1 g
F P
s
P
p
.002 w
.54075 .43567 m .51258 .41641 L .51959 .41066 L p
1 g
F P
s
P
p
.002 w
.51959 .41066 m .55464 .42444 L .54075 .43567 L p
1 g
F P
s
P
p
.002 w
.34648 .77422 m .33543 .74514 L .3959 .76151 L p
1 g
F P
s
P
p
.002 w
.3959 .76151 m .40383 .78953 L .34648 .77422 L p
1 g
F P
s
P
p
.002 w
.38344 .45533 m .41483 .43276 L .42887 .44233 L p
1 g
F P
s
P
p
.002 w
.45565 .41979 m .42887 .44233 L .41483 .43276 L p
1 g
F P
s
P
p
.002 w
.42887 .44233 m .45565 .41979 L .46575 .42308 L p
1 g
F P
s
P
p
.002 w
.47631 .81825 m .47111 .7952 L .54173 .79082 L p
1 g
F P
s
P
p
.002 w
.54173 .79082 m .54131 .81421 L .47631 .81825 L p
1 g
F P
s
P
p
.002 w
.54131 .81421 m .54173 .79082 L .60894 .77683 L p
1 g
F P
s
P
p
.002 w
.28393 .68649 m .28208 .65141 L .32686 .67806 L p
1 g
F P
s
P
p
.002 w
.32686 .67806 m .32886 .7128 L .28393 .68649 L p
1 g
F P
s
P
p
.002 w
.41443 .81313 m .40383 .78953 L .47111 .7952 L p
1 g
F P
s
P
p
.002 w
.47111 .7952 m .47631 .81825 L .41443 .81313 L p
1 g
F P
s
P
p
.002 w
.64714 .49319 m .61922 .46623 L .63201 .44285 L p
1 g
F P
s
P
p
.002 w
.61922 .46623 m .58813 .44312 L .59782 .42487 L p
1 g
F P
s
P
p
.002 w
.59782 .42487 m .63201 .44285 L .61922 .46623 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .49051 .42367 L .4778 .42442 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .50253 .4209 L .49051 .42367 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .4778 .42442 L .46575 .42308 L closepath p
1 g
F P
s
P
p
.002 w
.6712 .52332 m .64714 .49319 L .66278 .4654 L p
1 g
F P
s
P
p
.002 w
.63201 .44285 m .66278 .4654 L .64714 .49319 L p
1 g
F P
s
P
p
.002 w
.58813 .44312 m .55464 .42444 L .56109 .41191 L p
1 g
F P
s
P
p
.002 w
.56109 .41191 m .59782 .42487 L .58813 .44312 L p
1 g
F P
s
P
p
.002 w
.67209 .7244 m .67337 .69166 L .7181 .65993 L p
1 g
F P
s
P
p
.002 w
.71459 .62506 m .7181 .65993 L .67337 .69166 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .51258 .41641 L .50253 .4209 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .46575 .42308 L .45565 .41979 L closepath p
1 g
F P
s
P
p
.002 w
.69079 .55588 m .6712 .52332 L .68933 .49198 L p
1 g
F P
s
P
p
.002 w
.66278 .4654 m .68933 .49198 L .6712 .52332 L p
1 g
F P
s
P
p
.002 w
.31479 .48622 m .34212 .46014 L .35517 .48203 L p
1 g
F P
s
P
p
.002 w
.35517 .48203 m .33073 .51217 L .31479 .48622 L p
1 g
F P
s
P
p
.002 w
.38344 .45533 m .35517 .48203 L .34212 .46014 L p
1 g
F P
s
P
p
.002 w
.34212 .46014 m .37354 .43822 L .38344 .45533 L p
1 g
F P
s
P
p
.002 w
.41483 .43276 m .38344 .45533 L .37354 .43822 L p
1 g
F P
s
P
p
.002 w
.55464 .42444 m .51959 .41066 L .52277 .40428 L p
1 g
F P
s
P
p
.002 w
.52277 .40428 m .56109 .41191 L .55464 .42444 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .51959 .41066 L .51258 .41641 L closepath p
1 g
F P
s
P
p
.002 w
.29231 .51581 m .31479 .48622 L .33073 .51217 L p
1 g
F P
s
P
p
.002 w
.33073 .51217 m .31074 .54502 L .29231 .51581 L p
1 g
F P
s
P
p
.002 w
.41483 .43276 m .44858 .41488 L .45565 .41979 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .45565 .41979 L .44858 .41488 L closepath p
1 g
F P
s
P
p
.002 w
.60894 .77683 m .60316 .80142 L .54131 .81421 L p
1 g
F P
s
P
p
.002 w
.60316 .80142 m .60894 .77683 L .6662 .75447 L p
1 g
F P
s
P
p
.002 w
.67209 .7244 m .6662 .75447 L .60894 .77683 L p
1 g
F P
s
P
p
.002 w
.37354 .43822 m .40823 .42099 L .41483 .43276 L p
1 g
F P
s
P
p
.002 w
.44858 .41488 m .41483 .43276 L .40823 .42099 L p
1 g
F P
s
P
p
.002 w
.29163 .71984 m .28393 .68649 L .32886 .7128 L p
1 g
F P
s
P
p
.002 w
.32886 .7128 m .33543 .74514 L .29163 .71984 L p
1 g
F P
s
P
p
.002 w
.70538 .59008 m .69079 .55588 L .71094 .52193 L p
1 g
F P
s
P
p
.002 w
.68933 .49198 m .71094 .52193 L .69079 .55588 L p
1 g
F P
s
P
p
.002 w
.27528 .54817 m .29231 .51581 L .31074 .54502 L p
1 g
F P
s
P
p
.002 w
.31074 .54502 m .29571 .57976 L .27528 .54817 L p
1 g
F P
s
P
p
.002 w
.36179 .79925 m .34648 .77422 L .40383 .78953 L p
1 g
F P
s
P
p
.002 w
.40383 .78953 m .41443 .81313 L .36179 .79925 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .52277 .40428 L .51959 .41066 L closepath p
1 g
F P
s
P
p
.002 w
.40823 .42099 m .44531 .40888 L .44858 .41488 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .44858 .41488 L .44531 .40888 L closepath p
1 g
F P
s
P
p
.002 w
.6662 .75447 m .67209 .7244 L .71578 .6938 L p
1 g
F P
s
P
p
.002 w
.7181 .65993 m .71578 .6938 L .67209 .7244 L p
1 g
F P
s
P
p
.002 w
.71459 .62506 m .70538 .59008 L .727 .55449 L p
1 g
F P
s
P
p
.002 w
.71094 .52193 m .727 .55449 L .70538 .59008 L p
1 g
F P
s
P
p
.002 w
.48222 .83609 m .47631 .81825 L .54131 .81421 L p
1 g
F P
s
P
p
.002 w
.54131 .81421 m .53978 .83251 L .48222 .83609 L p
1 g
F P
s
P
p
.002 w
.53978 .83251 m .54131 .81421 L .60316 .80142 L p
1 g
F P
s
P
p
.002 w
.26422 .58247 m .27528 .54817 L .29571 .57976 L p
1 g
F P
s
P
p
.002 w
.29571 .57976 m .28606 .61553 L .26422 .58247 L p
1 g
F P
s
P
p
.002 w
.42749 .83164 m .41443 .81313 L .47631 .81825 L p
1 g
F P
s
P
p
.002 w
.47631 .81825 m .48222 .83609 L .42749 .83164 L p
1 g
F P
s
P
p
.002 w
.56109 .41191 m .52277 .40428 L .52177 .39794 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .52177 .39794 L .52277 .40428 L closepath p
1 g
F P
s
P
p
.002 w
.59782 .42487 m .56109 .41191 L .5593 .39941 L p
1 g
F P
s
P
p
.002 w
.52177 .39794 m .5593 .39941 L .56109 .41191 L p
1 g
F P
s
P
p
.002 w
.40989 .40827 m .44624 .40242 L .44531 .40888 L p
1 g
F P
s
P
p
.002 w
.44531 .40888 m .40823 .42099 L .40989 .40827 L p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .44531 .40888 L .44624 .40242 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .45129 .39621 L .45992 .39093 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .44624 .40242 L .45129 .39621 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .51666 .39233 L .52177 .39794 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .50797 .38808 L .51666 .39233 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .49665 .38566 L .50797 .38808 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .48393 .38534 L .49665 .38566 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .47122 .38717 L .48393 .38534 L closepath p
1 g
F P
s
P
p
.002 w
.48383 .40218 m .45992 .39093 L .47122 .38717 L closepath p
1 g
F P
s
P
p
.002 w
.63201 .44285 m .59782 .42487 L .59544 .40658 L p
1 g
F P
s
P
p
.002 w
.5593 .39941 m .59544 .40658 L .59782 .42487 L p
1 g
F P
s
P
p
.002 w
.37573 .41963 m .40989 .40827 L .40823 .42099 L p
1 g
F P
s
P
p
.002 w
.40823 .42099 m .37354 .43822 L .37573 .41963 L p
1 g
F P
s
P
p
.002 w
.30504 .75056 m .29163 .71984 L .33543 .74514 L p
1 g
F P
s
P
p
.002 w
.33543 .74514 m .34648 .77422 L .30504 .75056 L p
1 g
F P
s
P
p
.002 w
.25948 .61783 m .26422 .58247 L .28606 .61553 L p
1 g
F P
s
P
p
.002 w
.28606 .61553 m .28208 .65141 L .25948 .61783 L p
1 g
F P
s
P
p
.002 w
.66278 .4654 m .63201 .44285 L .62924 .41933 L p
1 g
F P
s
P
p
.002 w
.59544 .40658 m .62924 .41933 L .63201 .44285 L p
1 g
F P
s
P
p
.002 w
.34466 .43626 m .37573 .41963 L .37354 .43822 L p
1 g
F P
s
P
p
.002 w
.37354 .43822 m .34212 .46014 L .34466 .43626 L p
1 g
F P
s
P
p
.002 w
.5593 .39941 m .52177 .39794 L .51666 .39233 L p
1 g
F P
s
P
p
.002 w
.7181 .65993 m .71459 .62506 L .73702 .58884 L p
1 g
F P
s
P
p
.002 w
.727 .55449 m .73702 .58884 L .71459 .62506 L p
1 g
F P
s
P
p
.002 w
.60316 .80142 m .59452 .82125 L .53978 .83251 L p
1 g
F P
s
P
p
.002 w
.59452 .82125 m .60316 .80142 L .65577 .78103 L p
1 g
F P
s
P
p
.002 w
.6662 .75447 m .65577 .78103 L .60316 .80142 L p
1 g
F P
s
P
p
.002 w
.41974 .39598 m .45129 .39621 L .44624 .40242 L p
1 g
F P
s
P
p
.002 w
.44624 .40242 m .40989 .40827 L .41974 .39598 L p
1 g
F P
s
P
p
.002 w
.38103 .8195 m .36179 .79925 L .41443 .81313 L p
1 g
F P
s
P
p
.002 w
.41443 .81313 m .42749 .83164 L .38103 .8195 L p
1 g
F P
s
P
p
.002 w
.31756 .45778 m .34466 .43626 L .34212 .46014 L p
1 g
F P
s
P
p
.002 w
.34212 .46014 m .31479 .48622 L .31756 .45778 L p
1 g
F P
s
P
p
.002 w
.68933 .49198 m .66278 .4654 L .6598 .43737 L p
1 g
F P
s
P
p
.002 w
.62924 .41933 m .6598 .43737 L .66278 .4654 L p
1 g
F P
s
P
p
.002 w
.65577 .78103 m .6662 .75447 L .7076 .72575 L p
1 g
F P
s
P
p
.002 w
.71578 .6938 m .7076 .72575 L .6662 .75447 L p
1 g
F P
s
P
p
.002 w
.51666 .39233 m .54934 .3883 L .5593 .39941 L p
1 g
F P
s
P
p
.002 w
.54934 .3883 m .51666 .39233 L .50797 .38808 L p
1 g
F P
s
P
p
.002 w
.59544 .40658 m .5593 .39941 L .54934 .3883 L p
1 g
F P
s
P
p
.002 w
.43678 .38549 m .45992 .39093 L .45129 .39621 L p
1 g
F P
s
P
p
.002 w
.45129 .39621 m .41974 .39598 L .43678 .38549 L p
1 g
F P
s
P
p
.002 w
.26127 .65329 m .25948 .61783 L .28208 .65141 L p
1 g
F P
s
P
p
.002 w
.28208 .65141 m .28393 .68649 L .26127 .65329 L p
1 g
F P
s
P
p
.002 w
.39002 .40159 m .41974 .39598 L .40989 .40827 L p
1 g
F P
s
P
p
.002 w
.40989 .40827 m .37573 .41963 L .39002 .40159 L p
1 g
F P
s
P
p
.002 w
.71578 .6938 m .7181 .65993 L .74068 .62408 L p
1 g
F P
s
P
p
.002 w
.73702 .58884 m .74068 .62408 L .7181 .65993 L p
1 g
F P
s
P
p
.002 w
.32389 .77779 m .30504 .75056 L .34648 .77422 L p
1 g
F P
s
P
p
.002 w
.34648 .77422 m .36179 .79925 L .32389 .77779 L p
1 g
F P
s
P
p
.002 w
.29518 .48368 m .31756 .45778 L .31479 .48622 L p
1 g
F P
s
P
p
.002 w
.31479 .48622 m .29231 .51581 L .29518 .48368 L p
1 g
F P
s
P
p
.002 w
.50797 .38808 m .53221 .37985 L .54934 .3883 L p
1 g
F P
s
P
p
.002 w
.53221 .37985 m .50797 .38808 L .49665 .38566 L p
1 g
F P
s
P
p
.002 w
.71094 .52193 m .68933 .49198 L .68626 .4603 L p
1 g
F P
s
P
p
.002 w
.6598 .43737 m .68626 .4603 L .68933 .49198 L p
1 g
F P
s
P
p
.002 w
.48871 .84816 m .48222 .83609 L .53978 .83251 L p
1 g
F P
s
P
p
.002 w
.53978 .83251 m .53715 .84514 L .48871 .84816 L p
1 g
F P
s
P
p
.002 w
.53715 .84514 m .53978 .83251 L .59452 .82125 L p
1 g
F P
s
P
p
.002 w
.45919 .378 m .47122 .38717 L .45992 .39093 L p
1 g
F P
s
P
p
.002 w
.45992 .39093 m .43678 .38549 L .45919 .378 L p
1 g
F P
s
P
p
.002 w
.44269 .84445 m .42749 .83164 L .48222 .83609 L p
1 g
F P
s
P
p
.002 w
.48222 .83609 m .48871 .84816 L .44269 .84445 L p
1 g
F P
s
P
p
.002 w
.49665 .38566 m .50975 .37501 L .53221 .37985 L p
1 g
F P
s
P
p
.002 w
.50975 .37501 m .49665 .38566 L .48393 .38534 L p
1 g
F P
s
P
p
.002 w
.62924 .41933 m .59544 .40658 L .581 .39027 L p
1 g
F P
s
P
p
.002 w
.54934 .3883 m .581 .39027 L .59544 .40658 L p
1 g
F P
s
P
p
.002 w
.48446 .37437 m .48393 .38534 L .47122 .38717 L p
1 g
F P
s
P
p
.002 w
.47122 .38717 m .45919 .378 L .48446 .37437 L p
1 g
F P
s
P
p
.002 w
.48393 .38534 m .48446 .37437 L .50975 .37501 L p
1 g
F P
s
P
p
.002 w
.26961 .6879 m .26127 .65329 L .28393 .68649 L p
1 g
F P
s
P
p
.002 w
.28393 .68649 m .29163 .71984 L .26961 .6879 L p
1 g
F P
s
P
p
.002 w
.27821 .51332 m .29518 .48368 L .29231 .51581 L p
1 g
F P
s
P
p
.002 w
.29231 .51581 m .27528 .54817 L .27821 .51332 L p
1 g
F P
s
P
p
.002 w
.36295 .41299 m .39002 .40159 L .37573 .41963 L p
1 g
F P
s
P
p
.002 w
.37573 .41963 m .34466 .43626 L .36295 .41299 L p
1 g
F P
s
P
p
.002 w
.581 .39027 m .54934 .3883 L .53221 .37985 L p
1 g
F P
s
P
p
.002 w
.727 .55449 m .71094 .52193 L .70786 .48754 L p
1 g
F P
s
P
p
.002 w
.68626 .4603 m .70786 .48754 L .71094 .52193 L p
1 g
F P
s
P
p
.002 w
.59452 .82125 m .58319 .8357 L .53715 .84514 L p
1 g
F P
s
P
p
.002 w
.58319 .8357 m .59452 .82125 L .641 .80335 L p
1 g
F P
s
P
p
.002 w
.65577 .78103 m .641 .80335 L .59452 .82125 L p
1 g
F P
s
P
p
.002 w
.641 .80335 m .65577 .78103 L .6937 .75493 L p
1 g
F P
s
P
p
.002 w
.7076 .72575 m .6937 .75493 L .65577 .78103 L p
1 g
F P
s
P
p
.002 w
.41503 .38614 m .43678 .38549 L .41974 .39598 L p
1 g
F P
s
P
p
.002 w
.41974 .39598 m .39002 .40159 L .41503 .38614 L p
1 g
F P
s
P
p
.002 w
.7076 .72575 m .71578 .6938 L .73779 .65926 L p
1 g
F P
s
P
p
.002 w
.74068 .62408 m .73779 .65926 L .71578 .6938 L p
1 g
F P
s
P
p
.002 w
.40376 .83433 m .38103 .8195 L .42749 .83164 L p
1 g
F P
s
P
p
.002 w
.42749 .83164 m .44269 .84445 L .40376 .83433 L p
1 g
F P
s
P
p
.002 w
.6598 .43737 m .62924 .41933 L .6108 .39828 L p
1 g
F P
s
P
p
.002 w
.581 .39027 m .6108 .39828 L .62924 .41933 L p
1 g
F P
s
P
p
.002 w
.34775 .80073 m .32389 .77779 L .36179 .79925 L p
1 g
F P
s
P
p
.002 w
.36179 .79925 m .38103 .8195 L .34775 .80073 L p
1 g
F P
s
P
p
.002 w
.26717 .54592 m .27821 .51332 L .27528 .54817 L p
1 g
F P
s
P
p
.002 w
.27528 .54817 m .26422 .58247 L .26717 .54592 L p
1 g
F P
s
P
p
.002 w
.73702 .58884 m .727 .55449 L .72396 .51842 L p
1 g
F P
s
P
p
.002 w
.70786 .48754 m .72396 .51842 L .727 .55449 L p
1 g
F P
s
P
p
.002 w
.53221 .37985 m .5559 .3778 L .581 .39027 L p
1 g
F P
s
P
p
.002 w
.5559 .3778 m .53221 .37985 L .50975 .37501 L p
1 g
F P
s
P
p
.002 w
.33932 .42995 m .36295 .41299 L .34466 .43626 L p
1 g
F P
s
P
p
.002 w
.34466 .43626 m .31756 .45778 L .33932 .42995 L p
1 g
F P
s
P
p
.002 w
.28434 .72069 m .26961 .6879 L .29163 .71984 L p
1 g
F P
s
P
p
.002 w
.29163 .71984 m .30504 .75056 L .28434 .72069 L p
1 g
F P
s
P
p
.002 w
.44808 .37506 m .45919 .378 L .43678 .38549 L p
1 g
F P
s
P
p
.002 w
.43678 .38549 m .41503 .38614 L .44808 .37506 L p
1 g
F P
s
P
p
.002 w
.6108 .39828 m .581 .39027 L .5559 .3778 L p
1 g
F P
s
P
p
.002 w
.49561 .85398 m .48871 .84816 L .53715 .84514 L p
1 g
F P
s
P
p
.002 w
.53715 .84514 m .53347 .85162 L .49561 .85398 L p
1 g
F P
s
P
p
.002 w
.53347 .85162 m .53715 .84514 L .58319 .8357 L p
1 g
F P
s
P
p
.002 w
.68626 .4603 m .6598 .43737 L .63791 .4122 L p
1 g
F P
s
P
p
.002 w
.6108 .39828 m .63791 .4122 L .6598 .43737 L p
1 g
F P
s
P
p
.002 w
.4597 .8511 m .44269 .84445 L .48871 .84816 L p
1 g
F P
s
P
p
.002 w
.48871 .84816 m .49561 .85398 L .4597 .8511 L p
1 g
F P
s
P
p
.002 w
.6937 .75493 m .7076 .72575 L .72837 .69343 L p
1 g
F P
s
P
p
.002 w
.73779 .65926 m .72837 .69343 L .7076 .72575 L p
1 g
F P
s
P
p
.002 w
.50975 .37501 m .5228 .37065 L .5559 .3778 L p
1 g
F P
s
P
p
.002 w
.5228 .37065 m .50975 .37501 L .48446 .37437 L p
1 g
F P
s
P
p
.002 w
.39529 .39297 m .41503 .38614 L .39002 .40159 L p
1 g
F P
s
P
p
.002 w
.39002 .40159 m .36295 .41299 L .39529 .39297 L p
1 g
F P
s
P
p
.002 w
.48543 .36969 m .48446 .37437 L .45919 .378 L p
1 g
F P
s
P
p
.002 w
.45919 .378 m .44808 .37506 L .48543 .36969 L p
1 g
F P
s
P
p
.002 w
.26246 .58063 m .26717 .54592 L .26422 .58247 L p
1 g
F P
s
P
p
.002 w
.26422 .58247 m .25948 .61783 L .26246 .58063 L p
1 g
F P
s
P
p
.002 w
.641 .80335 m .62219 .82074 L .58319 .8357 L p
1 g
F P
s
P
p
.002 w
.62219 .82074 m .641 .80335 L .67437 .78049 L p
1 g
F P
s
P
p
.002 w
.6937 .75493 m .67437 .78049 L .641 .80335 L p
1 g
F P
s
P
p
.002 w
.48446 .37437 m .48543 .36969 L .5228 .37065 L p
1 g
F P
s
P
p
.002 w
.74068 .62408 m .73702 .58884 L .73404 .55212 L p
1 g
F P
s
P
p
.002 w
.72396 .51842 m .73404 .55212 L .73702 .58884 L p
1 g
F P
s
P
p
.002 w
.31983 .45213 m .33932 .42995 L .31756 .45778 L p
1 g
F P
s
P
p
.002 w
.31756 .45778 m .29518 .48368 L .31983 .45213 L p
1 g
F P
s
P
p
.002 w
.58319 .8357 m .56942 .84426 L .53347 .85162 L p
1 g
F P
s
P
p
.002 w
.56942 .84426 m .58319 .8357 L .62219 .82074 L p
1 g
F P
s
P
p
.002 w
.30514 .75073 m .28434 .72069 L .30504 .75056 L p
1 g
F P
s
P
p
.002 w
.30504 .75056 m .32389 .77779 L .30514 .75073 L p
1 g
F P
s
P
p
.002 w
.37602 .81871 m .34775 .80073 L .38103 .8195 L p
1 g
F P
s
P
p
.002 w
.38103 .8195 m .40376 .83433 L .37602 .81871 L p
1 g
F P
s
P
p
.002 w
.42942 .84323 m .40376 .83433 L .44269 .84445 L p
1 g
F P
s
P
p
.002 w
.44269 .84445 m .4597 .8511 L .42942 .84323 L p
1 g
F P
s
P
p
.002 w
.63791 .4122 m .66153 .43177 L .68626 .4603 L p
1 g
F P
s
P
p
.002 w
.70786 .48754 m .68626 .4603 L .66153 .43177 L p
1 g
F P
s
P
p
.002 w
.5559 .3778 m .57839 .38213 L .6108 .39828 L p
1 g
F P
s
P
p
.002 w
.63791 .4122 m .6108 .39828 L .57839 .38213 L p
1 g
F P
s
P
p
.002 w
.57839 .38213 m .5559 .3778 L .5228 .37065 L p
1 g
F P
s
P
p
.002 w
.26428 .61648 m .26246 .58063 L .25948 .61783 L p
1 g
F P
s
P
p
.002 w
.25948 .61783 m .26127 .65329 L .26428 .61648 L p
1 g
F P
s
P
p
.002 w
.72837 .69343 m .71259 .72562 L .6937 .75493 L p
1 g
F P
s
P
p
.002 w
.67437 .78049 m .6937 .75493 L .71259 .72562 L p
1 g
F P
s
P
p
.002 w
.73404 .55212 m .73774 .58775 L .74068 .62408 L p
1 g
F P
s
P
p
.002 w
.73779 .65926 m .74068 .62408 L .73774 .58775 L p
1 g
F P
s
P
p
.002 w
.43821 .37859 m .44808 .37506 L .41503 .38614 L p
1 g
F P
s
P
p
.002 w
.41503 .38614 m .39529 .39297 L .43821 .37859 L p
1 g
F P
s
P
p
.002 w
.37815 .40594 m .39529 .39297 L .36295 .41299 L p
1 g
F P
s
P
p
.002 w
.36295 .41299 m .33932 .42995 L .37815 .40594 L p
1 g
F P
s
P
p
.002 w
.30511 .47898 m .31983 .45213 L .29518 .48368 L p
1 g
F P
s
P
p
.002 w
.29518 .48368 m .27821 .51332 L .30511 .47898 L p
1 g
F P
s
P
p
.002 w
.33147 .77713 m .30514 .75073 L .32389 .77779 L p
1 g
F P
s
P
p
.002 w
.32389 .77779 m .34775 .80073 L .33147 .77713 L p
1 g
F P
s
P
p
.002 w
.62219 .82074 m .59978 .83262 L .56942 .84426 L p
1 g
F P
s
P
p
.002 w
.67437 .78049 m .65005 .80169 L .62219 .82074 L p
1 g
F P
s
P
p
.002 w
.59978 .83262 m .62219 .82074 L .65005 .80169 L p
1 g
F P
s
P
p
.002 w
.50275 .85324 m .49561 .85398 L .53347 .85162 L p
1 g
F P
s
P
p
.002 w
.53347 .85162 m .5288 .85161 L .50275 .85324 L p
1 g
F P
s
P
p
.002 w
.5288 .85161 m .53347 .85162 L .56942 .84426 L p
1 g
F P
s
P
p
.002 w
.72396 .51842 m .70786 .48754 L .68095 .45652 L p
1 g
F P
s
P
p
.002 w
.66153 .43177 m .68095 .45652 L .70786 .48754 L p
1 g
F P
s
P
p
.002 w
.47808 .85126 m .4597 .8511 L .49561 .85398 L p
1 g
F P
s
P
p
.002 w
.49561 .85398 m .50275 .85324 L .47808 .85126 L p
1 g
F P
s
P
p
.002 w
.5228 .37065 m .53544 .37284 L .57839 .38213 L p
1 g
F P
s
P
p
.002 w
.53544 .37284 m .5228 .37065 L .48543 .36969 L p
1 g
F P
s
P
p
.002 w
.27267 .65248 m .26428 .61648 L .26127 .65329 L p
1 g
F P
s
P
p
.002 w
.26127 .65329 m .26961 .6879 L .27267 .65248 L p
1 g
F P
s
P
p
.002 w
.48682 .3716 m .48543 .36969 L .44808 .37506 L p
1 g
F P
s
P
p
.002 w
.44808 .37506 m .43821 .37859 L .48682 .3716 L p
1 g
F P
s
P
p
.002 w
.40798 .83113 m .37602 .81871 L .40376 .83433 L p
1 g
F P
s
P
p
.002 w
.40376 .83433 m .42942 .84323 L .40798 .83113 L p
1 g
F P
s
P
p
.002 w
.72837 .69343 m .73779 .65926 L .73489 .62432 L p
1 g
F P
s
P
p
.002 w
.73774 .58775 m .73489 .62432 L .73779 .65926 L p
1 g
F P
s
P
p
.002 w
.48543 .36969 m .48682 .3716 L .53544 .37284 L p
1 g
F P
s
P
p
.002 w
.56942 .84426 m .55351 .84655 L .5288 .85161 L p
1 g
F P
s
P
p
.002 w
.55351 .84655 m .56942 .84426 L .59978 .83262 L p
1 g
F P
s
P
p
.002 w
.66153 .43177 m .63791 .4122 L .59904 .39284 L p
1 g
F P
s
P
p
.002 w
.57839 .38213 m .59904 .39284 L .63791 .4122 L p
1 g
F P
s
P
p
.002 w
.65005 .80169 m .67437 .78049 L .69082 .75492 L p
1 g
F P
s
P
p
.002 w
.71259 .72562 m .69082 .75492 L .67437 .78049 L p
1 g
F P
s
P
p
.002 w
.45735 .84586 m .42942 .84323 L .4597 .8511 L p
1 g
F P
s
P
p
.002 w
.4597 .8511 m .47808 .85126 L .45735 .84586 L p
1 g
F P
s
P
p
.002 w
.29565 .50983 m .30511 .47898 L .27821 .51332 L p
1 g
F P
s
P
p
.002 w
.27821 .51332 m .26717 .54592 L .29565 .50983 L p
1 g
F P
s
P
p
.002 w
.59904 .39284 m .57839 .38213 L .53544 .37284 L p
1 g
F P
s
P
p
.002 w
.36415 .42482 m .37815 .40594 L .33932 .42995 L p
1 g
F P
s
P
p
.002 w
.33932 .42995 m .31983 .45213 L .36415 .42482 L p
1 g
F P
s
P
p
.002 w
.73404 .55212 m .72396 .51842 L .69555 .48584 L p
1 g
F P
s
P
p
.002 w
.68095 .45652 m .69555 .48584 L .72396 .51842 L p
1 g
F P
s
P
p
.002 w
.36266 .79911 m .33147 .77713 L .34775 .80073 L p
1 g
F P
s
P
p
.002 w
.34775 .80073 m .37602 .81871 L .36266 .79911 L p
1 g
F P
s
P
p
.002 w
.28745 .68759 m .27267 .65248 L .26961 .6879 L p
1 g
F P
s
P
p
.002 w
.26961 .6879 m .28434 .72069 L .28745 .68759 L p
1 g
F P
s
P
p
.002 w
.42989 .38864 m .43821 .37859 L .39529 .39297 L p
1 g
F P
s
P
p
.002 w
.39529 .39297 m .37815 .40594 L .42989 .38864 L p
1 g
F P
s
P
p
.002 w
.71259 .72562 m .72837 .69343 L .72548 .6608 L p
1 g
F P
s
P
p
.002 w
.73489 .62432 m .72548 .6608 L .72837 .69343 L p
1 g
F P
s
P
p
.002 w
.59978 .83262 m .57431 .83857 L .55351 .84655 L p
1 g
F P
s
P
p
.002 w
.57431 .83857 m .59978 .83262 L .62134 .81786 L p
1 g
F P
s
P
p
.002 w
.65005 .80169 m .62134 .81786 L .59978 .83262 L p
1 g
F P
s
P
p
.002 w
.62134 .81786 m .65005 .80169 L .66361 .78046 L p
1 g
F P
s
P
p
.002 w
.69082 .75492 m .66361 .78046 L .65005 .80169 L p
1 g
F P
s
P
p
.002 w
.2918 .54383 m .29565 .50983 L .26717 .54592 L p
1 g
F P
s
P
p
.002 w
.26717 .54592 m .26246 .58063 L .2918 .54383 L p
1 g
F P
s
P
p
.002 w
.44279 .83758 m .40798 .83113 L .42942 .84323 L p
1 g
F P
s
P
p
.002 w
.42942 .84323 m .45735 .84586 L .44279 .83758 L p
1 g
F P
s
P
p
.002 w
.68095 .45652 m .66153 .43177 L .61723 .40978 L p
1 g
F P
s
P
p
.002 w
.59904 .39284 m .61723 .40978 L .66153 .43177 L p
1 g
F P
s
P
p
.002 w
.30826 .72078 m .28745 .68759 L .28434 .72069 L p
1 g
F P
s
P
p
.002 w
.28434 .72069 m .30514 .75073 L .30826 .72078 L p
1 g
F P
s
P
p
.002 w
.53544 .37284 m .5473 .38169 L .59904 .39284 L p
1 g
F P
s
P
p
.002 w
.5473 .38169 m .53544 .37284 L .48682 .3716 L p
1 g
F P
s
P
p
.002 w
.50994 .84579 m .50275 .85324 L .5288 .85161 L p
1 g
F P
s
P
p
.002 w
.5288 .85161 m .52325 .84496 L .50994 .84579 L p
1 g
F P
s
P
p
.002 w
.52325 .84496 m .5288 .85161 L .55351 .84655 L p
1 g
F P
s
P
p
.002 w
.73774 .58775 m .73404 .55212 L .70484 .51897 L p
1 g
F P
s
P
p
.002 w
.69555 .48584 m .70484 .51897 L .73404 .55212 L p
1 g
F P
s
P
p
.002 w
.49734 .84477 m .47808 .85126 L .50275 .85324 L p
1 g
F P
s
P
p
.002 w
.50275 .85324 m .50994 .84579 L .49734 .84477 L p
1 g
F P
s
P
p
.002 w
.4886 .38021 m .48682 .3716 L .43821 .37859 L p
1 g
F P
s
P
p
.002 w
.43821 .37859 m .42989 .38864 L .4886 .38021 L p
1 g
F P
s
P
p
.002 w
.39783 .816 m .36266 .79911 L .37602 .81871 L p
1 g
F P
s
P
p
.002 w
.37602 .81871 m .40798 .83113 L .39783 .816 L p
1 g
F P
s
P
p
.002 w
.69082 .75492 m .71259 .72562 L .70974 .69613 L p
1 g
F P
s
P
p
.002 w
.72548 .6608 m .70974 .69613 L .71259 .72562 L p
1 g
F P
s
P
p
.002 w
.55351 .84655 m .53587 .84237 L .52325 .84496 L p
1 g
F P
s
P
p
.002 w
.53587 .84237 m .55351 .84655 L .57431 .83857 L p
1 g
F P
s
P
p
.002 w
.35375 .44918 m .36415 .42482 L .31983 .45213 L p
1 g
F P
s
P
p
.002 w
.31983 .45213 m .30511 .47898 L .35375 .44918 L p
1 g
F P
s
P
p
.002 w
.48682 .3716 m .4886 .38021 L .5473 .38169 L p
1 g
F P
s
P
p
.002 w
.4868 .84201 m .45735 .84586 L .47808 .85126 L p
1 g
F P
s
P
p
.002 w
.47808 .85126 m .49734 .84477 L .4868 .84201 L p
1 g
F P
s
P
p
.002 w
.61723 .40978 m .59904 .39284 L .5473 .38169 L p
1 g
F P
s
P
p
.002 w
.29377 .58004 m .2918 .54383 L .26246 .58063 L p
1 g
F P
s
P
p
.002 w
.26246 .58063 m .26428 .61648 L .29377 .58004 L p
1 g
F P
s
P
p
.002 w
.33452 .75106 m .30826 .72078 L .30514 .75073 L p
1 g
F P
s
P
p
.002 w
.30514 .75073 m .33147 .77713 L .33452 .75106 L p
1 g
F P
s
P
p
.002 w
.4234 .40509 m .42989 .38864 L .37815 .40594 L p
1 g
F P
s
P
p
.002 w
.37815 .40594 m .36415 .42482 L .4234 .40509 L p
1 g
F P
s
P
p
.002 w
.62134 .81786 m .58899 .82848 L .57431 .83857 L p
1 g
F P
s
P
p
.002 w
.58899 .82848 m .62134 .81786 L .63167 .80148 L p
1 g
F P
s
P
p
.002 w
.66361 .78046 m .63167 .80148 L .62134 .81786 L p
1 g
F P
s
P
p
.002 w
.73489 .62432 m .73774 .58775 L .70848 .55497 L p
1 g
F P
s
P
p
.002 w
.70484 .51897 m .70848 .55497 L .73774 .58775 L p
1 g
F P
s
P
p
.002 w
.57431 .83857 m .54646 .83829 L .53587 .84237 L p
1 g
F P
s
P
p
.002 w
.54646 .83829 m .57431 .83857 L .58899 .82848 L p
1 g
F P
s
P
p
.002 w
.66361 .78046 m .69082 .75492 L .68806 .72928 L p
1 g
F P
s
P
p
.002 w
.70974 .69613 m .68806 .72928 L .69082 .75492 L p
1 g
F P
s
P
p
.002 w
.69555 .48584 m .68095 .45652 L .63239 .43258 L p
1 g
F P
s
P
p
.002 w
.61723 .40978 m .63239 .43258 L .68095 .45652 L p
1 g
F P
s
P
p
.002 w
.47946 .83779 m .44279 .83758 L .45735 .84586 L p
1 g
F P
s
P
p
.002 w
.45735 .84586 m .4868 .84201 L .47946 .83779 L p
1 g
F P
s
P
p
.002 w
.43602 .82726 m .39783 .816 L .40798 .83113 L p
1 g
F P
s
P
p
.002 w
.40798 .83113 m .44279 .83758 L .43602 .82726 L p
1 g
F P
s
P
p
.002 w
.3655 .77753 m .33452 .75106 L .33147 .77713 L p
1 g
F P
s
P
p
.002 w
.33147 .77713 m .36266 .79911 L .3655 .77753 L p
1 g
F P
s
P
p
.002 w
.34734 .47843 m .35375 .44918 L .30511 .47898 L p
1 g
F P
s
P
p
.002 w
.30511 .47898 m .29565 .50983 L .34734 .47843 L p
1 g
F P
s
P
p
.002 w
.30157 .61742 m .29377 .58004 L .26428 .61648 L p
1 g
F P
s
P
p
.002 w
.26428 .61648 m .27267 .65248 L .30157 .61742 L p
1 g
F P
s
P
p
.002 w
.72548 .6608 m .73489 .62432 L .70628 .59285 L p
1 g
F P
s
P
p
.002 w
.70848 .55497 m .70628 .59285 L .73489 .62432 L p
1 g
F P
s
P
p
.002 w
.63167 .80148 m .66361 .78046 L .66104 .75926 L p
1 g
F P
s
P
p
.002 w
.68806 .72928 m .66104 .75926 L .66361 .78046 L p
1 g
F P
s
P
p
.002 w
.5473 .38169 m .55802 .3971 L .61723 .40978 L p
1 g
F P
s
P
p
.002 w
.55802 .3971 m .5473 .38169 L .4886 .38021 L p
1 g
F P
s
P
p
.002 w
.52325 .84496 m .51696 .83168 L .50994 .84579 L closepath p
1 g
F P
s
P
p
.002 w
.53587 .84237 m .51696 .83168 L .52325 .84496 L closepath p
1 g
F P
s
P
p
.002 w
.58899 .82848 m .55387 .83316 L .54646 .83829 L p
1 g
F P
s
P
p
.002 w
.55387 .83316 m .58899 .82848 L .5959 .81732 L p
1 g
F P
s
P
p
.002 w
.63167 .80148 m .5959 .81732 L .58899 .82848 L p
1 g
F P
s
P
p
.002 w
.51652 .83198 m .49734 .84477 L p
.51682 .83197 L 1 g
F P
s
P
p
.002 w
.49734 .84477 m .51696 .83168 L .4868 .84201 L closepath p
1 g
F P
s
P
p
.002 w
.4868 .84201 m .51696 .83168 L .47946 .83779 L closepath p
1 g
F P
s
P
p
.002 w
.47612 .83255 m .47946 .83779 L .50328 .83391 L p
1 g
F P
s
P
p
.50328 .83391 m .49206 .83232 L .47612 .83255 L 1 g
F
P
p
.002 w
.50713 .83189 m .47612 .83255 L p
.51198 .83203 L 1 g
F P
s
P
p
.5151 .83199 m .51261 .83196 L .51198 .83203 L 1 g
F
P
p
.51261 .83196 m .50713 .83189 L .51198 .83203 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51261 .83196 L p
1 g
F P
s
P
p
.002 w
.50328 .83391 m .5151 .83199 L p
.49206 .83232 L 1 g
F P
s
P
p
.002 w
.55729 .8275 m .55633 .82194 L .53221 .82791 L p
1 g
F P
s
P
p
.002 w
.53221 .82791 m .51696 .83168 L .52589 .83076 L p
1 g
F P
s
P
p
.002 w
.52589 .83076 m .55729 .8275 L p
.53221 .82791 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53643 .82596 L p
1 g
F P
s
P
p
.55573 .81291 m .53643 .82596 L .53667 .82584 L 1 g
F
P
p
.002 w
.53221 .82791 m .55633 .82194 L .55503 .82074 L p
1 g
F P
s
P
p
.002 w
.55503 .82074 m .55258 .81848 L p
.53643 .82596 L 1 g
F P
s
P
p
.53643 .82596 m .53221 .82791 L .55503 .82074 L 1 g
F
P
p
.002 w
.53643 .82596 m .53597 .82325 L p
.52248 .82987 L 1 g
F P
s
P
p
.54536 .82183 m .53644 .82601 L .54496 .82216 L 1 g
F
P
p
.55573 .81291 m .53667 .82584 L .54536 .82183 L 1 g
F
P
p
.53667 .82584 m .53644 .82601 L .54536 .82183 L 1 g
F
P
p
.53597 .82325 m .51261 .83196 L .51448 .83174 L 1 g
F
P
p
.002 w
.47612 .83255 m .4914 .83223 L p
.48741 .83162 L 1 g
F P
s
P
p
.002 w
.47659 .82998 m .47632 .83147 L p
.48741 .83162 L 1 g
F P
s
P
p
.002 w
.47632 .83147 m .47612 .83255 L p
.48741 .83162 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48741 .83162 L p
1 g
F P
s
P
p
.51242 .82869 m .48741 .83162 L .49932 .83179 L 1 g
F
P
p
.002 w
.48741 .83162 m .48758 .82869 L p
.47314 .8289 L 1 g
F P
s
P
p
.46572 .82698 m .47659 .82998 L .46691 .82696 L 1 g
F
P
p
.43602 .82726 m .4711 .82961 L .46572 .82698 L 1 g
F
P
p
.4711 .82961 m .47659 .82998 L .46572 .82698 L 1 g
F
P
p
.002 w
.46358 .82593 m .46403 .82325 L p
.45303 .82076 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .46358 .82593 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44347 .81583 L p
1 g
F P
s
P
p
.46403 .82325 m .44347 .81583 L .44486 .81656 L 1 g
F
P
p
.44459 .8168 m .45032 .81944 L .44553 .81691 L 1 g
F
P
p
.002 w
.43789 .816 m .44636 .81834 L p
.44459 .8168 L 1 g
F P
s
P
p
.002 w
.44636 .81834 m .45032 .81944 L p
.44459 .8168 L 1 g
F P
s
P
p
.002 w
.43789 .816 m .43759 .81784 L p
.45531 .82188 L 1 g
F P
s
P
p
.002 w
.45032 .81944 m .43789 .816 L p
.45531 .82188 L 1 g
F P
s
P
p
.002 w
.44347 .81583 m .44427 .81291 L p
.43617 .80828 L 1 g
F P
s
P
p
.4003 .7994 m .4405 .81325 L .43162 .80306 L 1 g
F
P
p
.43617 .80828 m .43213 .80598 L .4405 .81325 L 1 g
F
P
p
.43617 .80828 m .4405 .81325 L .44347 .81583 L 1 g
F
P
p
.002 w
.4003 .7994 m .43789 .816 L .4405 .81325 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42965 .8008 L p
1 g
F P
s
P
p
.002 w
.41479 .78376 m .4003 .7994 L p
.43058 .80294 L 1 g
F P
s
P
p
.43058 .80294 m .43162 .80306 L .42965 .8008 L 1 g
F
P
p
.43058 .80294 m .42965 .8008 L .41479 .78376 L 1 g
F
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.41538 .78313 m .41479 .78376 L p
.42507 .79028 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42296 .78455 L p
1 g
F P
s
P
p
.42292 .78497 m .42464 .78929 L .42313 .78502 L 1 g
F
P
p
.002 w
.41538 .78313 m .42265 .78797 L p
.42292 .78497 L 1 g
F P
s
P
p
.002 w
.42265 .78797 m .42464 .78929 L p
.42292 .78497 L 1 g
F P
s
P
p
.002 w
.42296 .78455 m .424 .78222 L p
.42386 .77579 L 1 g
F P
s
P
p
.38469 .75632 m .41901 .7762 L .42519 .76537 L 1 g
F
P
p
.41901 .7762 m .42348 .77879 L .42502 .76671 L 1 g
F
P
p
.41901 .7762 m .42502 .76671 L .42519 .76537 L 1 g
F
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .42579 .76511 L .42502 .76671 L p
1 g
F P
s
P
p
.002 w
.42502 .76671 m .42446 .76785 L p
.42432 .77216 L 1 g
F P
s
P
p
.424 .78222 m .42502 .76671 L .42432 .77216 L 1 g
F
P
p
.002 w
.41845 .7379 m .38469 .75632 L p
.42519 .76537 L 1 g
F P
s
P
p
.002 w
.42502 .76671 m .42579 .76511 L p
.42956 .75953 L 1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.44162 .76905 m .43185 .75591 L p
.42578 .76551 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43498 .75079 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43185 .75591 m .44162 .76905 L p
.43881 .74788 L 1 g
F P
s
P
p
.002 w
.43498 .75079 m .43569 .74928 L p
.44156 .74579 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45222 .73768 L p
1 g
F P
s
P
p
.43569 .74928 m .45222 .73768 L .44156 .74579 L 1 g
F
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.46316 .72445 m .41845 .7379 L p
.43426 .74362 L 1 g
F P
s
P
p
.002 w
.47621 .75877 m .4664 .73298 L p
.43426 .74362 L 1 g
F P
s
P
p
.002 w
.45222 .73768 m .45268 .73647 L p
.46363 .7339 L 1 g
F P
s
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47465 .7295 L p
1 g
F P
s
P
p
.002 w
.47621 .75877 m .51523 .75354 L p
.47325 .73009 L 1 g
F P
s
P
p
.002 w
.4664 .73298 m .47621 .75877 L p
.47325 .73009 L 1 g
F P
s
P
p
.45268 .73647 m .47465 .7295 L .46499 .73358 L 1 g
F
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.47465 .7295 m .47494 .72815 L p
.48487 .72827 L 1 g
F P
s
P
p
.002 w
.51523 .75354 m .51419 .72861 L p
.47263 .72974 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52532 .72934 L p
1 g
F P
s
P
p
.002 w
.51419 .72861 m .51523 .75354 L p
.52669 .72985 L 1 g
F P
s
P
p
.002 w
.52532 .72934 m .52506 .72815 L p
.53363 .73244 L 1 g
F P
s
P
p
.52532 .72934 m .52669 .72985 L .52689 .72944 L 1 g
F
P
p
.51419 .72861 m .52669 .72985 L .52532 .72934 L 1 g
F
P
p
.002 w
.51523 .75354 m .55419 .75396 L p
.52689 .72944 L 1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .5478 .73773 L p
1 g
F P
s
P
p
.002 w
.55419 .75396 m .55672 .74493 L p
.54195 .73555 L 1 g
F P
s
P
p
.52781 .73027 m .55419 .75396 L .54195 .73555 L 1 g
F
P
p
.52506 .72815 m .5478 .73773 L .53363 .73244 L 1 g
F
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52301 .71774 m .51373 .71762 L p
.55672 .74493 L 1 g
F P
s
P
p
.002 w
.5478 .73773 m .54864 .73996 L p
.53363 .73244 L 1 g
F P
s
P
p
.51373 .71762 m .52781 .73027 L .54195 .73555 L 1 g
F
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56511 .75097 L p
1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55672 .74493 m .55419 .75396 L .56848 .75645 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57695 .78435 L p
1 g
F P
s
P
p
.002 w
.57784 .79411 m .58394 .7966 L p
.57803 .78099 L 1 g
F P
s
P
p
.57621 .77617 m .57695 .78435 L .57803 .78099 L 1 g
F
P
p
.57695 .78435 m .57784 .79411 L .57803 .78099 L 1 g
F
P
p
.002 w
.57695 .78435 m .576 .78222 L p
.57345 .79451 L 1 g
F P
s
P
p
.002 w
.56806 .80649 m .58394 .7966 L .57721 .79385 L p
1 g
F P
s
P
p
.002 w
.57721 .79385 m .57429 .79266 L p
.57047 .80113 L 1 g
F P
s
P
p
.57047 .80113 m .56806 .80649 L .57721 .79385 L 1 g
F
P
p
.002 w
.57047 .80113 m .56958 .79874 L p
.56314 .80904 L 1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.57997 .80024 m .55654 .81585 L .55633 .82194 L 1 g
F
P
p
.002 w
.55258 .81848 m .5533 .81915 L p
.55654 .81585 L 1 g
F P
s
P
p
.002 w
.5533 .81915 m .55633 .82194 L p
.55654 .81585 L 1 g
F P
s
P
p
.002 w
.55654 .81585 m .55573 .81291 L p
.53778 .82834 L 1 g
F P
s
P
p
.002 w
.58394 .7966 m .56202 .81025 L p
.55693 .81545 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55654 .81585 L p
1 g
F P
s
P
p
.58394 .7966 m .55693 .81545 L .57997 .80024 L 1 g
F
P
p
.55693 .81545 m .55654 .81585 L .57997 .80024 L 1 g
F
P
p
.002 w
.56202 .81025 m .56806 .80649 L p
.56778 .80403 L 1 g
F P
s
P
p
.56958 .79874 m .55654 .81585 L .56202 .81025 L 1 g
F
P
p
.56314 .80904 m .56202 .81025 L .56303 .80922 L 1 g
F
P
p
.56958 .79874 m .56202 .81025 L .56314 .80904 L 1 g
F
P
p
.57345 .79451 m .57429 .79266 L .57695 .78435 L 1 g
F
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57106 .80271 L p
1 g
F P
s
P
p
.576 .78222 m .57106 .80271 L .57301 .79662 L 1 g
F
P
p
.57421 .76511 m .57695 .78435 L .57623 .77644 L 1 g
F
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.58861 .75996 m .57621 .77617 L p
.58394 .7966 L 1 g
F P
s
P
p
.002 w
.57509 .76693 m .57421 .76511 L p
.57626 .77659 L 1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57509 .76693 L p
1 g
F P
s
P
p
.002 w
.57621 .77617 m .57879 .7728 L p
.57509 .76693 L 1 g
F P
s
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57509 .76693 L p
1 g
F P
s
P
p
.57626 .77659 m .57811 .78694 L .57509 .76693 L 1 g
F
P
p
.56431 .74928 m .57509 .76693 L .57188 .76185 L 1 g
F
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.55419 .75396 m .57621 .77617 L .57509 .76693 L 1 g
F
P
p
.56431 .74928 m .57188 .76185 L .57031 .75936 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56848 .75645 m .55419 .75396 L p
.57509 .76693 L 1 g
F P
s
P
p
.55672 .74493 m .56848 .75645 L .56511 .75097 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56511 .75097 L p
1 g
F P
s
P
p
.002 w
.56511 .75097 m .56431 .74928 L p
.57163 .76157 L 1 g
F P
s
P
p
.57163 .76157 m .57628 .76938 L .56511 .75097 L 1 g
F
P
p
.002 w
.57406 .75743 m .58861 .75996 L p
.56329 .74803 L 1 g
F P
s
P
p
.54732 .73647 m .56511 .75097 L .55991 .74722 L 1 g
F
P
p
.54732 .73647 m .56565 .75212 L .55832 .74622 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54732 .73647 L p
1 g
F P
s
P
p
.55672 .74493 m .56511 .75097 L .56329 .74803 L 1 g
F
P
p
.56511 .75097 m .57406 .75743 L .56329 .74803 L 1 g
F
P
p
.002 w
.57394 .7574 m .56848 .75645 L p
.57509 .76693 L 1 g
F P
s
P
p
.57031 .75936 m .57569 .76817 L .57163 .76157 L 1 g
F
P
p
.57188 .76185 m .57569 .76817 L .57031 .75936 L 1 g
F
P
p
.002 w
.57509 .76693 m .57569 .76817 L p
.57188 .76185 L 1 g
F P
s
P
p
.002 w
.58861 .75996 m .57394 .7574 L p
.57509 .76693 L 1 g
F P
s
P
p
.002 w
.57879 .7728 m .58861 .75996 L p
.57509 .76693 L 1 g
F P
s
P
p
.002 w
.56614 .78933 m .57621 .77617 L p
.55419 .75396 L 1 g
F P
s
P
p
.002 w
.57621 .77617 m .56614 .78933 L .57429 .79266 L p
1 g
F P
s
P
p
.002 w
.57429 .79266 m .57784 .79411 L p
.57695 .78435 L 1 g
F P
s
P
p
.57621 .77617 m .57429 .79266 L .57695 .78435 L 1 g
F
P
p
.002 w
.57106 .80271 m .5715 .8039 L p
.57301 .79662 L 1 g
F P
s
P
p
.002 w
.57429 .79266 m .56614 .78933 L p
.56778 .80403 L 1 g
F P
s
P
p
.56778 .80403 m .56806 .80649 L .57047 .80113 L 1 g
F
P
p
.56778 .80403 m .57047 .80113 L .57429 .79266 L 1 g
F
P
p
.002 w
.55106 .81708 m .56202 .81025 L p
.56614 .78933 L 1 g
F P
s
P
p
.56614 .78933 m .56202 .81025 L .56778 .80403 L 1 g
F
P
p
.56303 .80922 m .56202 .81025 L .55726 .81844 L 1 g
F
P
p
.002 w
.55654 .81585 m .55661 .81609 L p
.56202 .81025 L 1 g
F P
s
P
p
.002 w
.55661 .81609 m .55726 .81844 L p
.56202 .81025 L 1 g
F P
s
P
p
.55693 .81545 m .55258 .81848 L .55654 .81585 L 1 g
F
P
p
.002 w
.55106 .81708 m .55258 .81848 L p
.55693 .81545 L 1 g
F P
s
P
p
.002 w
.56202 .81025 m .55106 .81708 L p
.55693 .81545 L 1 g
F P
s
P
p
.56314 .80904 m .56303 .80922 L .57047 .80113 L 1 g
F
P
p
.56303 .80922 m .55726 .81844 L .56876 .80336 L 1 g
F
P
p
.56303 .80922 m .56876 .80336 L .57047 .80113 L 1 g
F
P
p
.002 w
.55726 .81844 m .5715 .8039 L .5706 .80149 L p
1 g
F P
s
P
p
.002 w
.5706 .80149 m .57047 .80113 L p
.56876 .80336 L 1 g
F P
s
P
p
.56876 .80336 m .55726 .81844 L .5706 .80149 L 1 g
F
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55654 .81585 L p
1 g
F P
s
P
p
.53778 .82834 m .53695 .82905 L .55654 .81585 L 1 g
F
P
p
.57345 .79451 m .57301 .79662 L .57429 .79266 L 1 g
F
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57695 .78435 L p
1 g
F P
s
P
p
.57301 .79662 m .5715 .8039 L .57695 .78435 L 1 g
F
P
p
.002 w
.57695 .78435 m .57811 .78694 L p
.57623 .77644 L 1 g
F P
s
P
p
.002 w
.56848 .75645 m .57406 .75743 L p
.56511 .75097 L 1 g
F P
s
P
p
.002 w
.57569 .76817 m .57628 .76938 L p
.57163 .76157 L 1 g
F P
s
P
p
.002 w
.56511 .75097 m .56565 .75212 L p
.55991 .74722 L 1 g
F P
s
P
p
.002 w
.56421 .71824 m .55672 .74493 L p
.58861 .75996 L 1 g
F P
s
P
p
.002 w
.55672 .74493 m .56421 .71824 L .52301 .71774 L p
1 g
F P
s
P
p
.002 w
.56565 .75212 m .56611 .75311 L p
.55832 .74622 L 1 g
F P
s
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52532 .72934 L p
1 g
F P
s
P
p
.53363 .73244 m .54864 .73996 L .52532 .72934 L 1 g
F
P
p
.002 w
.52532 .72934 m .52553 .73034 L p
.51814 .72887 L 1 g
F P
s
P
p
.5 .72527 m .52532 .72934 L .51814 .72887 L 1 g
F
P
p
.5 .72527 m .52553 .73034 L .51373 .72854 L 1 g
F
P
p
.002 w
.51373 .71762 m .51419 .72861 L p
.52689 .72944 L 1 g
F P
s
P
p
.47263 .72974 m .51419 .72861 L .5 .72645 L 1 g
F
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72645 L p
1 g
F P
s
P
p
.002 w
.5 .72645 m .5 .72527 L p
.51373 .72854 L 1 g
F P
s
P
p
.51373 .72854 m .52576 .73141 L .5 .72645 L 1 g
F
P
p
.002 w
.51403 .72476 m .51373 .71762 L p
.48931 .72482 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72645 L p
1 g
F P
s
P
p
.002 w
.5 .72645 m .5 .72845 L p
.48487 .72827 L 1 g
F P
s
P
p
.47494 .72815 m .5 .72645 L .48487 .72827 L 1 g
F
P
p
.47263 .72974 m .5 .72645 L .48931 .72482 L 1 g
F
P
p
.5 .72645 m .51403 .72476 L .48931 .72482 L 1 g
F
P
p
.002 w
.51419 .72861 m .51403 .72476 L p
.5 .72645 L 1 g
F P
s
P
p
.002 w
.52553 .73034 m .52576 .73141 L p
.51373 .72854 L 1 g
F P
s
P
p
.002 w
.51373 .71762 m .46316 .72445 L p
.47263 .72974 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47465 .7295 L p
1 g
F P
s
P
p
.48487 .72827 m .5 .72845 L .47465 .7295 L 1 g
F
P
p
.002 w
.47465 .7295 m .47424 .73141 L p
.46499 .73358 L 1 g
F P
s
P
p
.002 w
.46316 .72445 m .4664 .73298 L p
.47325 .73009 L 1 g
F P
s
P
p
.002 w
.4664 .73298 m .46316 .72445 L p
.43426 .74362 L 1 g
F P
s
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45222 .73768 L p
1 g
F P
s
P
p
.46363 .7339 m .47424 .73141 L .45222 .73768 L 1 g
F
P
p
.002 w
.45222 .73768 m .45136 .73996 L p
.44156 .74579 L 1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44162 .76905 m .47621 .75877 L p
.44114 .7461 L 1 g
F P
s
P
p
.43844 .74513 m .43881 .74788 L .44114 .7461 L 1 g
F
P
p
.43881 .74788 m .44162 .76905 L .44114 .7461 L 1 g
F
P
p
.43498 .75079 m .43881 .74788 L .43844 .74513 L 1 g
F
P
p
.43185 .75591 m .43881 .74788 L .43498 .75079 L 1 g
F
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43498 .75079 L p
1 g
F P
s
P
p
.44156 .74579 m .45136 .73996 L .43498 .75079 L 1 g
F
P
p
.002 w
.43498 .75079 m .43389 .75311 L p
.43039 .7583 L 1 g
F P
s
P
p
.42579 .76511 m .43498 .75079 L .43039 .7583 L 1 g
F
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.41845 .7379 m .43185 .75591 L p
.43844 .74513 L 1 g
F P
s
P
p
.42519 .76537 m .42578 .76551 L .42719 .74965 L 1 g
F
P
p
.002 w
.43185 .75591 m .42719 .74965 L p
.42578 .76551 L 1 g
F P
s
P
p
.002 w
.42719 .74965 m .41845 .7379 L p
.42519 .76537 L 1 g
F P
s
P
p
.424 .78222 m .42446 .76785 L .42384 .77478 L 1 g
F
P
p
.42386 .77579 m .42348 .77879 L .42296 .78455 L 1 g
F
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.46627 .79552 m .44162 .76905 L .42348 .77879 L p
1 g
F P
s
P
p
.002 w
.42348 .77879 m .41538 .78313 L p
.42292 .78497 L 1 g
F P
s
P
p
.43042 .79874 m .42296 .78455 L .42372 .7867 L 1 g
F
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.42292 .78497 m .46627 .79552 L .42348 .77879 L 1 g
F
P
p
.002 w
.42446 .76785 m .42372 .76938 L p
.42384 .77478 L 1 g
F P
s
P
p
.002 w
.42348 .77879 m .44162 .76905 L p
.42519 .76537 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42502 .76671 L p
1 g
F P
s
P
p
.42956 .75953 m .43389 .75311 L .42502 .76671 L 1 g
F
P
p
.42386 .77579 m .42384 .77478 L .42348 .77879 L 1 g
F
P
p
.002 w
.38469 .75632 m .41538 .78313 L .42348 .77879 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42296 .78455 L p
1 g
F P
s
P
p
.42384 .77478 m .42372 .76938 L .42296 .78455 L 1 g
F
P
p
.002 w
.42296 .78455 m .42277 .78498 L p
.42372 .7867 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.44833 .80501 m .46627 .79552 L p
.42313 .78502 L 1 g
F P
s
P
p
.43042 .79874 m .42277 .78498 L .42624 .79296 L 1 g
F
P
p
.002 w
.42464 .78929 m .44833 .80501 L p
.42313 .78502 L 1 g
F P
s
P
p
.002 w
.44833 .80501 m .42464 .78929 L p
.42507 .79028 L 1 g
F P
s
P
p
.002 w
.42464 .78929 m .41538 .78313 L p
.42507 .79028 L 1 g
F P
s
P
p
.002 w
.42965 .8008 m .43042 .79874 L p
.42624 .79296 L 1 g
F P
s
P
p
.44427 .81291 m .42965 .8008 L .43516 .80712 L 1 g
F
P
p
.43162 .80306 m .44833 .80501 L .41479 .78376 L 1 g
F
P
p
.002 w
.42277 .78498 m .42189 .78694 L p
.42624 .79296 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42965 .8008 L p
1 g
F P
s
P
p
.42624 .79296 m .42189 .78694 L .42965 .8008 L 1 g
F
P
p
.002 w
.42965 .8008 m .4288 .80308 L p
.43516 .80712 L 1 g
F P
s
P
p
.44427 .81291 m .4288 .80308 L .43213 .80598 L 1 g
F
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.48253 .82134 m .44833 .80501 L .4405 .81325 L p
1 g
F P
s
P
p
.46403 .82325 m .44486 .81656 L .45303 .82076 L 1 g
F
P
p
.44486 .81656 m .45032 .81944 L .45303 .82076 L 1 g
F
P
p
.44347 .81583 m .48253 .82134 L .4405 .81325 L 1 g
F
P
p
.44459 .8168 m .44553 .81691 L .44347 .81583 L 1 g
F
P
p
.44553 .81691 m .48253 .82134 L .44347 .81583 L 1 g
F
P
p
.43789 .816 m .44459 .8168 L .44347 .81583 L 1 g
F
P
p
.002 w
.4434 .81605 m .44274 .81844 L p
.45269 .82069 L 1 g
F P
s
P
p
.45303 .82076 m .45032 .81944 L .45269 .82069 L 1 g
F
P
p
.45032 .81944 m .4434 .81605 L .45269 .82069 L 1 g
F
P
p
.44486 .81656 m .4434 .81605 L .45032 .81944 L 1 g
F
P
p
.002 w
.4405 .81325 m .43986 .81393 L p
.44347 .81583 L 1 g
F P
s
P
p
.002 w
.43986 .81393 m .43789 .816 L p
.44347 .81583 L 1 g
F P
s
P
p
.002 w
.4288 .80308 m .4285 .8039 L p
.43213 .80598 L 1 g
F P
s
P
p
.002 w
.4405 .81325 m .44833 .80501 L p
.43162 .80306 L 1 g
F P
s
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44347 .81583 L p
1 g
F P
s
P
p
.43213 .80598 m .4285 .8039 L .44347 .81583 L 1 g
F
P
p
.002 w
.47717 .82686 m .48253 .82134 L p
.44553 .81691 L 1 g
F P
s
P
p
.002 w
.45032 .81944 m .47717 .82686 L p
.44553 .81691 L 1 g
F P
s
P
p
.002 w
.44347 .81583 m .4434 .81605 L p
.44486 .81656 L 1 g
F P
s
P
p
.002 w
.47717 .82686 m .45032 .81944 L p
.45531 .82188 L 1 g
F P
s
P
p
.002 w
.43759 .81784 m .43602 .82726 L p
.46691 .82696 L 1 g
F P
s
P
p
.48758 .82869 m .46358 .82593 L .47314 .8289 L 1 g
F
P
p
.46691 .82696 m .47717 .82686 L .43759 .81784 L 1 g
F
P
p
.002 w
.46358 .82593 m .46305 .82905 L p
.47314 .8289 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46358 .82593 L p
1 g
F P
s
P
p
.45303 .82076 m .44274 .81844 L .46358 .82593 L 1 g
F
P
p
.47314 .8289 m .46984 .82895 L .47659 .82998 L 1 g
F
P
p
.47314 .8289 m .47659 .82998 L .48741 .83162 L 1 g
F
P
p
.002 w
.43602 .82726 m .47612 .83255 L .47659 .82998 L p
1 g
F P
s
P
p
.002 w
.47659 .82998 m .47717 .82686 L p
.46691 .82696 L 1 g
F P
s
P
p
.002 w
.51261 .83196 m .51242 .82869 L p
.49932 .83179 L 1 g
F P
s
P
p
.48741 .83162 m .51448 .83174 L .47659 .82998 L 1 g
F
P
p
.002 w
.4914 .83223 m .50713 .83189 L p
.48741 .83162 L 1 g
F P
s
P
p
.49932 .83179 m .50713 .83189 L .51261 .83196 L 1 g
F
P
p
.002 w
.50713 .83189 m .51448 .83174 L p
.48741 .83162 L 1 g
F P
s
P
p
.49932 .83179 m .49925 .8318 L .50713 .83189 L 1 g
F
P
p
.002 w
.48741 .83162 m .48724 .83464 L p
.49932 .83179 L 1 g
F P
s
P
p
.002 w
.48741 .83166 m .48741 .83162 L p
.46842 .82897 L 1 g
F P
s
P
p
.46984 .82895 m .46842 .82897 L .48741 .83162 L 1 g
F
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.47717 .82686 m .47659 .82998 L p
.51448 .83174 L 1 g
F P
s
P
p
.002 w
.51448 .83174 m .51696 .83168 L .51592 .83156 L p
1 g
F P
s
P
p
.53597 .82325 m .51448 .83174 L .51592 .83156 L 1 g
F
P
p
.002 w
.48253 .82134 m .47717 .82686 L .51592 .83156 L p
1 g
F P
s
P
p
.002 w
.51592 .83156 m .51696 .83168 L .51635 .8315 L p
1 g
F P
s
P
p
.53597 .82325 m .51592 .83156 L .51619 .83152 L 1 g
F
P
p
.53597 .82325 m .51617 .83153 L .51659 .83146 L 1 g
F
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.50352 .81312 m .49164 .81658 L .51659 .83146 L p
1 g
F P
s
P
p
.002 w
.51659 .83146 m .51696 .83168 L .51678 .83143 L p
1 g
F P
s
P
p
.53597 .82325 m .51659 .83146 L .5167 .83144 L 1 g
F
P
p
.53597 .82325 m .51669 .83145 L .5168 .83142 L 1 g
F
P
p
.002 w
.51678 .83143 m .50352 .81312 L p
.51659 .83146 L 1 g
F P
s
P
p
.5167 .83144 m .51659 .83146 L .51669 .83145 L 1 g
F
P
p
.5168 .83142 m .51669 .83145 L .51678 .83143 L 1 g
F
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.51686 .81135 m .50352 .81312 L .51678 .83143 L p
1 g
F P
s
P
p
.002 w
.51678 .83143 m .51696 .83168 L .51696 .83139 L p
1 g
F P
s
P
p
.53597 .82325 m .51678 .83143 L .5169 .8314 L 1 g
F
P
p
.53597 .82325 m .51687 .83142 L .51693 .8314 L 1 g
F
P
p
.002 w
.51696 .83139 m .51686 .81135 L p
.51678 .83143 L 1 g
F P
s
P
p
.002 w
.53018 .81147 m .51686 .81135 L .51696 .83139 L p
1 g
F P
s
P
p
.002 w
.51696 .83139 m .51696 .83168 L .51719 .83133 L p
1 g
F P
s
P
p
.53597 .82325 m .51687 .83143 L .52248 .82987 L 1 g
F
P
p
.002 w
.51719 .83133 m .51696 .83168 L .51759 .83123 L p
1 g
F P
s
P
p
.51687 .83143 m .51678 .83147 L .51879 .8309 L 1 g
F
P
p
.51687 .83143 m .51879 .8309 L .52248 .82987 L 1 g
F
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55106 .81708 m .54201 .81345 L .51759 .83123 L p
1 g
F P
s
P
p
.002 w
.51759 .83123 m .51696 .83168 L .51879 .8309 L p
1 g
F P
s
P
p
.002 w
.51879 .8309 m .55106 .81708 L p
.51759 .83123 L 1 g
F P
s
P
p
.002 w
.51719 .83133 m .53018 .81147 L p
.51696 .83139 L 1 g
F P
s
P
p
.5169 .8314 m .51678 .83143 L .51687 .83142 L 1 g
F
P
p
.51693 .8314 m .51687 .83142 L .51691 .83141 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.54201 .81345 m .53018 .81147 L .51719 .83133 L p
1 g
F P
s
P
p
.002 w
.51759 .83123 m .54201 .81345 L p
.51719 .83133 L 1 g
F P
s
P
p
.002 w
.51635 .8315 m .48253 .82134 L p
.51592 .83156 L 1 g
F P
s
P
p
.51619 .83152 m .51592 .83156 L .51617 .83153 L 1 g
F
P
p
.51691 .83141 m .51617 .83153 L .51683 .83145 L 1 g
F
P
p
.002 w
.49164 .81658 m .48253 .82134 L .51635 .8315 L p
1 g
F P
s
P
p
.002 w
.51635 .8315 m .51696 .83168 L .51659 .83146 L p
1 g
F P
s
P
p
.002 w
.51659 .83146 m .49164 .81658 L p
.51635 .8315 L 1 g
F P
s
P
p
.002 w
.51592 .83156 m .47717 .82686 L p
.51448 .83174 L 1 g
F P
s
P
p
.51683 .83145 m .51448 .83174 L .51678 .83147 L 1 g
F
P
p
.002 w
.51696 .83168 m .53221 .82791 L p
.53482 .82641 L 1 g
F P
s
P
p
.002 w
.51879 .8309 m .51696 .83168 L p
.53482 .82641 L 1 g
F P
s
P
p
.52248 .82987 m .51678 .83147 L .52 .83109 L 1 g
F
P
p
.002 w
.55106 .81708 m .51879 .8309 L p
.53482 .82641 L 1 g
F P
s
P
p
.002 w
.55258 .81848 m .55106 .81708 L p
.53221 .82791 L 1 g
F P
s
P
p
.002 w
.49734 .84477 m .50994 .84579 L .51682 .83197 L p
1 g
F P
s
P
p
.002 w
.54646 .83829 m .51696 .83168 L .53587 .84237 L closepath p
1 g
F P
s
P
p
.002 w
.55387 .83316 m .51696 .83168 L .54646 .83829 L closepath p
1 g
F P
s
P
p
.002 w
.55729 .8275 m .51696 .83168 L .55387 .83316 L closepath p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53643 .82596 L p
1 g
F P
s
P
p
.52248 .82987 m .51276 .83464 L .53643 .82596 L 1 g
F
P
p
.002 w
.53643 .82596 m .53644 .82601 L p
.53667 .82584 L 1 g
F P
s
P
p
.002 w
.53644 .82601 m .53695 .82905 L p
.54496 .82216 L 1 g
F P
s
P
p
.002 w
.5151 .83199 m .51696 .83168 L .50713 .83189 L p
1 g
F P
s
P
p
.002 w
.51682 .83197 m .51696 .83168 L .51652 .83198 L p
1 g
F P
s
P
p
.002 w
.51261 .83196 m .51276 .83464 L p
.52 .83109 L 1 g
F P
s
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48741 .83166 L p
1 g
F P
s
P
p
.46842 .82897 m .46305 .82905 L .48741 .83166 L 1 g
F
P
p
.002 w
.51262 .83213 m .51261 .83196 L p
.49509 .83279 L 1 g
F P
s
P
p
.49925 .8318 m .49509 .83279 L .51261 .83196 L 1 g
F
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51262 .83213 L p
1 g
F P
s
P
p
.49509 .83279 m .48724 .83464 L .51262 .83213 L 1 g
F
P
p
.004 w
.5 .6118 m
.50785 .71352 L
s
P
p
.002 w
.49072 .39545 m .4886 .38021 L .42989 .38864 L p
1 g
F P
s
P
p
.002 w
.42989 .38864 m .4234 .40509 L .49072 .39545 L p
1 g
F P
s
P
p
.002 w
.63239 .43258 m .61723 .40978 L .55802 .3971 L p
1 g
F P
s
P
p
.002 w
.47612 .83255 m .43602 .82726 L .44279 .83758 L p
1 g
F P
s
P
p
.002 w
.44279 .83758 m .47946 .83779 L .47612 .83255 L p
1 g
F P
s
P
p
.002 w
.70484 .51897 m .69555 .48584 L .64402 .46069 L p
1 g
F P
s
P
p
.002 w
.63239 .43258 m .64402 .46069 L .69555 .48584 L p
1 g
F P
s
P
p
.002 w
.4003 .7994 m .3655 .77753 L .36266 .79911 L p
1 g
F P
s
P
p
.002 w
.36266 .79911 m .39783 .816 L .4003 .7994 L p
1 g
F P
s
P
p
.002 w
.4886 .38021 m .49072 .39545 L .55802 .3971 L p
1 g
F P
s
P
p
.002 w
.41897 .4276 m .4234 .40509 L .36415 .42482 L p
1 g
F P
s
P
p
.002 w
.36415 .42482 m .35375 .44918 L .41897 .4276 L p
1 g
F P
s
P
p
.002 w
.31501 .65484 m .30157 .61742 L .27267 .65248 L p
1 g
F P
s
P
p
.002 w
.27267 .65248 m .28745 .68759 L .31501 .65484 L p
1 g
F P
s
P
p
.002 w
.5959 .81732 m .63167 .80148 L .62944 .78519 L p
1 g
F P
s
P
p
.002 w
.66104 .75926 m .62944 .78519 L .63167 .80148 L p
1 g
F P
s
P
p
.002 w
.70974 .69613 m .72548 .6608 L .69827 .63148 L p
1 g
F P
s
P
p
.002 w
.70628 .59285 m .69827 .63148 L .72548 .6608 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.004 w
.51098 .75411 m
.51348 .78651 L
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.34517 .51177 m .34734 .47843 L .29565 .50983 L p
1 g
F P
s
P
p
.002 w
.29565 .50983 m .2918 .54383 L .34517 .51177 L p
1 g
F P
s
P
p
.002 w
.43789 .816 m .4003 .7994 L .39783 .816 L p
1 g
F P
s
P
p
.002 w
.39783 .816 m .43602 .82726 L .43789 .816 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.5959 .81732 m .55729 .8275 L .55387 .83316 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.55729 .8275 m .5959 .81732 L .5942 .80629 L p
1 g
F P
s
P
p
.002 w
.62944 .78519 m .5942 .80629 L .5959 .81732 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.68806 .72928 m .70974 .69613 L .68463 .66971 L p
1 g
F P
s
P
p
.002 w
.69827 .63148 m .68463 .66971 L .70974 .69613 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.33373 .69119 m .31501 .65484 L .28745 .68759 L p
1 g
F P
s
P
p
.002 w
.28745 .68759 m .30826 .72078 L .33373 .69119 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.70848 .55497 m .70484 .51897 L .65171 .49337 L p
1 g
F P
s
P
p
.002 w
.64402 .46069 m .65171 .49337 L .70484 .51897 L p
1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5942 .80629 m .55633 .82194 L .55729 .8275 L p
1 g
F P
s
P
p
.002 w
.64402 .46069 m .63239 .43258 L .56727 .41878 L p
1 g
F P
s
P
p
.002 w
.55802 .3971 m .56727 .41878 L .63239 .43258 L p
1 g
F P
s
P
p
.002 w
.56727 .41878 m .55802 .3971 L .49072 .39545 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.66104 .75926 m .68806 .72928 L .66574 .7064 L p
1 g
F P
s
P
p
.002 w
.68463 .66971 m .66574 .7064 L .68806 .72928 L p
1 g
F P
s
P
p
.002 w
.35719 .72537 m .33373 .69119 L .30826 .72078 L p
1 g
F P
s
P
p
.002 w
.30826 .72078 m .33452 .75106 L .35719 .72537 L p
1 g
F P
s
P
p
.002 w
.49314 .41702 m .49072 .39545 L .4234 .40509 L p
1 g
F P
s
P
p
.002 w
.4234 .40509 m .41897 .4276 L .49314 .41702 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.34739 .54825 m .34517 .51177 L .2918 .54383 L p
1 g
F P
s
P
p
.002 w
.2918 .54383 m .29377 .58004 L .34739 .54825 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.41677 .45564 m .41897 .4276 L .35375 .44918 L p
1 g
F P
s
P
p
.002 w
.35375 .44918 m .34734 .47843 L .41677 .45564 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.62944 .78519 m .66104 .75926 L .64217 .74044 L p
1 g
F P
s
P
p
.002 w
.66574 .7064 m .64217 .74044 L .66104 .75926 L p
1 g
F P
s
P
p
.002 w
.55633 .82194 m .5942 .80629 L .58394 .7966 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.49072 .39545 m .49314 .41702 L .56727 .41878 L p
1 g
F P
s
P
p
.002 w
.5942 .80629 m .62944 .78519 L .61462 .77081 L p
1 g
F P
s
P
p
.002 w
.64217 .74044 m .61462 .77081 L .62944 .78519 L p
1 g
F P
s
P
p
.002 w
.38469 .75632 m .35719 .72537 L .33452 .75106 L p
1 g
F P
s
P
p
.002 w
.33452 .75106 m .3655 .77753 L .38469 .75632 L p
1 g
F P
s
P
p
.002 w
.61462 .77081 m .58394 .7966 L .5942 .80629 L p
1 g
F P
s
P
p
.002 w
.70628 .59285 m .70848 .55497 L .65517 .52971 L p
1 g
F P
s
P
p
.002 w
.65171 .49337 m .65517 .52971 L .70848 .55497 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.41538 .78313 m .38469 .75632 L .3655 .77753 L p
1 g
F P
s
P
p
.002 w
.3655 .77753 m .4003 .7994 L .41538 .78313 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.56614 .78933 m .54201 .81345 L .55106 .81708 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.44833 .80501 m .48253 .82134 L .49164 .81658 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.65171 .49337 m .64402 .46069 L .57475 .44621 L p
1 g
F P
s
P
p
.002 w
.56727 .41878 m .57475 .44621 L .64402 .46069 L p
1 g
F P
s
P
p
.002 w
.35396 .58681 m .34739 .54825 L .29377 .58004 L p
1 g
F P
s
P
p
.002 w
.29377 .58004 m .30157 .61742 L .35396 .58681 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.69827 .63148 m .70628 .59285 L .65425 .56864 L p
1 g
F P
s
P
p
.002 w
.65517 .52971 m .65425 .56864 L .70628 .59285 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.54201 .81345 m .56614 .78933 L .54272 .78533 L p
1 g
F P
s
P
p
.002 w
.54272 .78533 m .53018 .81147 L .54201 .81345 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.49164 .81658 m .46627 .79552 L .44833 .80501 L p
1 g
F P
s
P
p
.002 w
.46627 .79552 m .49164 .81658 L .50352 .81312 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.57475 .44621 m .56727 .41878 L .49314 .41702 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.58394 .7966 m .61462 .77081 L .58861 .75996 L p
1 g
F P
s
P
p
.002 w
.41692 .48845 m .41677 .45564 L .34734 .47843 L p
1 g
F P
s
P
p
.002 w
.34734 .47843 m .34517 .51177 L .41692 .48845 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.53018 .81147 m .54272 .78533 L .51628 .78508 L p
1 g
F P
s
P
p
.002 w
.51628 .78508 m .51686 .81135 L .53018 .81147 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.4898 .78861 m .50352 .81312 L .51686 .81135 L p
1 g
F P
s
P
p
.002 w
.50352 .81312 m .4898 .78861 L .46627 .79552 L p
1 g
F P
s
P
p
.002 w
.49579 .44442 m .49314 .41702 L .41897 .4276 L p
1 g
F P
s
P
p
.002 w
.41897 .4276 m .41677 .45564 L .49579 .44442 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.004 w
.52217 .89922 m
.52576 .94571 L
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.51686 .81135 m .51628 .78508 L .4898 .78861 L p
1 g
F P
s
P
p
.002 w
.68463 .66971 m .69827 .63148 L .64893 .60899 L p
1 g
F P
s
P
p
.002 w
.65425 .56864 m .64893 .60899 L .69827 .63148 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.36473 .62626 m .35396 .58681 L .30157 .61742 L p
1 g
F P
s
P
p
.002 w
.30157 .61742 m .31501 .65484 L .36473 .62626 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.61462 .77081 m .64217 .74044 L .60871 .72619 L p
1 g
F P
s
P
p
.002 w
.60871 .72619 m .58861 .75996 L .61462 .77081 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.49314 .41702 m .49579 .44442 L .57475 .44621 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.66574 .7064 m .68463 .66971 L .63935 .64952 L p
1 g
F P
s
P
p
.002 w
.64893 .60899 m .63935 .64952 L .68463 .66971 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.65517 .52971 m .65171 .49337 L .58018 .47867 L p
1 g
F P
s
P
p
.002 w
.57475 .44621 m .58018 .47867 L .65171 .49337 L p
1 g
F P
s
P
p
.002 w
.64217 .74044 m .66574 .7064 L .6258 .689 L p
1 g
F P
s
P
p
.002 w
.6258 .689 m .60871 .72619 L .64217 .74044 L p
1 g
F P
s
P
p
.002 w
.63935 .64952 m .6258 .689 L .66574 .7064 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.37939 .6654 m .36473 .62626 L .31501 .65484 L p
1 g
F P
s
P
p
.002 w
.31501 .65484 m .33373 .69119 L .37939 .6654 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.55419 .75396 m .54272 .78533 L .56614 .78933 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.44162 .76905 m .46627 .79552 L .4898 .78861 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.35719 .72537 m .38469 .75632 L .41845 .7379 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.41944 .5251 m .41692 .48845 L .34517 .51177 L p
1 g
F P
s
P
p
.002 w
.34517 .51177 m .34739 .54825 L .41944 .5251 L p
1 g
F P
s
P
p
.002 w
.39748 .703 m .37939 .6654 L .33373 .69119 L p
1 g
F P
s
P
p
.002 w
.33373 .69119 m .35719 .72537 L .39748 .703 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.41845 .7379 m .39748 .703 L .35719 .72537 L p
1 g
F P
s
P
p
.002 w
.58018 .47867 m .57475 .44621 L .49579 .44442 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.54272 .78533 m .55419 .75396 L .51523 .75354 L p
1 g
F P
s
P
p
.002 w
.51523 .75354 m .51628 .78508 L .54272 .78533 L p
1 g
F P
s
P
p
.002 w
.47621 .75877 m .4898 .78861 L .51628 .78508 L p
1 g
F P
s
P
p
.002 w
.4898 .78861 m .47621 .75877 L .44162 .76905 L p
1 g
F P
s
P
p
.002 w
.49859 .47692 m .49579 .44442 L .41677 .45564 L p
1 g
F P
s
P
p
.002 w
.41677 .45564 m .41692 .48845 L .49859 .47692 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.65425 .56864 m .65517 .52971 L .58338 .51524 L p
1 g
F P
s
P
p
.002 w
.58018 .47867 m .58338 .51524 L .65517 .52971 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.51628 .78508 m .51523 .75354 L .47621 .75877 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.58861 .75996 m .60871 .72619 L .56421 .71824 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.49579 .44442 m .49859 .47692 L .58018 .47867 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.42429 .56449 m .41944 .5251 L .34739 .54825 L p
1 g
F P
s
P
p
.002 w
.34739 .54825 m .35396 .58681 L .42429 .56449 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.64893 .60899 m .65425 .56864 L .5842 .55483 L p
1 g
F P
s
P
p
.002 w
.58338 .51524 m .5842 .55483 L .65425 .56864 L p
1 g
F P
s
P
p
.002 w
.60871 .72619 m .6258 .689 L .57246 .67923 L p
1 g
F P
s
P
p
.002 w
.57246 .67923 m .56421 .71824 L .60871 .72619 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58338 .51524 m .58018 .47867 L .49859 .47692 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.39748 .703 m .41845 .7379 L .46316 .72445 L p
1 g
F P
s
P
p
.002 w
.63935 .64952 m .64893 .60899 L .58262 .59622 L p
1 g
F P
s
P
p
.002 w
.5842 .55483 m .58262 .59622 L .64893 .60899 L p
1 g
F P
s
P
p
.002 w
.50146 .51359 m .49859 .47692 L .41692 .48845 L p
1 g
F P
s
P
p
.002 w
.41692 .48845 m .41944 .5251 L .50146 .51359 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.43133 .6054 m .42429 .56449 L .35396 .58681 L p
1 g
F P
s
P
p
.002 w
.35396 .58681 m .36473 .62626 L .43133 .6054 L p
1 g
F P
s
P
p
.002 w
.6258 .689 m .63935 .64952 L .57867 .63813 L p
1 g
F P
s
P
p
.002 w
.57867 .63813 m .57246 .67923 L .6258 .689 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.58262 .59622 m .57867 .63813 L .63935 .64952 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.46316 .72445 m .45109 .68666 L .39748 .703 L p
1 g
F P
s
P
p
.002 w
.37939 .6654 m .39748 .703 L .45109 .68666 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.44036 .64656 m .43133 .6054 L .36473 .62626 L p
1 g
F P
s
P
p
.002 w
.36473 .62626 m .37939 .6654 L .44036 .64656 L p
1 g
F P
s
P
p
.002 w
.49859 .47692 m .50146 .51359 L .58338 .51524 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.45109 .68666 m .44036 .64656 L .37939 .6654 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.5842 .55483 m .58338 .51524 L .50146 .51359 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.56421 .71824 m .57246 .67923 L .51182 .6784 L p
1 g
F P
s
P
p
.002 w
.51182 .6784 m .51373 .71762 L .56421 .71824 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.45109 .68666 m .46316 .72445 L .51373 .71762 L p
1 g
F P
s
P
p
.002 w
.5043 .55335 m .50146 .51359 L .41944 .5251 L p
1 g
F P
s
P
p
.002 w
.41944 .5251 m .42429 .56449 L .5043 .55335 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.51373 .71762 m .51182 .6784 L .45109 .68666 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.58262 .59622 m .5842 .55483 L .5043 .55335 L p
1 g
F P
s
P
p
.002 w
.50146 .51359 m .5043 .55335 L .5842 .55483 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.57246 .67923 m .57867 .63813 L .50957 .63707 L p
1 g
F P
s
P
p
.002 w
.50957 .63707 m .51182 .6784 L .57246 .67923 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.44036 .64656 m .45109 .68666 L .51182 .6784 L p
1 g
F P
s
P
p
.002 w
.50703 .59494 m .5043 .55335 L .42429 .56449 L p
1 g
F P
s
P
p
.002 w
.42429 .56449 m .43133 .6054 L .50703 .59494 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.57867 .63813 m .58262 .59622 L .50703 .59494 L p
1 g
F P
s
P
p
.002 w
.5043 .55335 m .50703 .59494 L .58262 .59622 L p
1 g
F P
s
P
p
.002 w
.50703 .59494 m .50957 .63707 L .57867 .63813 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.51182 .6784 m .50957 .63707 L .44036 .64656 L p
1 g
F P
s
P
p
.004 w
.47678 .64157 m
.5 .6118 L
s
P
p
.004 w
.46628 .65502 m
.46717 .65389 L
s
P
p
.004 w
.44881 .67742 m
.46628 .65502 L
s
P
p
.002 w
.43133 .6054 m .44036 .64656 L .50957 .63707 L p
1 g
F P
s
P
p
.002 w
.50957 .63707 m .50703 .59494 L .43133 .6054 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .44881 .67742 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .52576 .94571 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.28)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.28)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.45796 .62641 m .46936 .5901 L .53126 .60432 L p
1 g
F P
s
P
p
.002 w
.53126 .60432 m .5257 .64197 L .45796 .62641 L p
1 g
F P
s
P
p
.002 w
.53602 .56684 m .53126 .60432 L .46936 .5901 L p
1 g
F P
s
P
p
.002 w
.5257 .64197 m .53126 .60432 L .59268 .60777 L p
1 g
F P
s
P
p
.002 w
.53126 .60432 m .53602 .56684 L .59005 .56975 L p
1 g
F P
s
P
p
.002 w
.59005 .56975 m .59268 .60777 L .53126 .60432 L p
1 g
F P
s
P
p
.002 w
.3962 .60073 m .41298 .56649 L .46936 .5901 L p
1 g
F P
s
P
p
.002 w
.46936 .5901 m .45796 .62641 L .3962 .60073 L p
1 g
F P
s
P
p
.002 w
.48156 .55432 m .46936 .5901 L .41298 .56649 L p
1 g
F P
s
P
p
.002 w
.46936 .5901 m .48156 .55432 L .53602 .56684 L p
1 g
F P
s
P
p
.002 w
.44764 .66242 m .45796 .62641 L .5257 .64197 L p
1 g
F P
s
P
p
.002 w
.5257 .64197 m .51946 .6789 L .44764 .66242 L p
1 g
F P
s
P
p
.002 w
.51946 .6789 m .5257 .64197 L .5929 .6459 L p
1 g
F P
s
P
p
.002 w
.59268 .60777 m .5929 .6459 L .5257 .64197 L p
1 g
F P
s
P
p
.002 w
.38209 .63534 m .3962 .60073 L .45796 .62641 L p
1 g
F P
s
P
p
.002 w
.45796 .62641 m .44764 .66242 L .38209 .63534 L p
1 g
F P
s
P
p
.002 w
.53985 .53039 m .53602 .56684 L .48156 .55432 L p
1 g
F P
s
P
p
.002 w
.53602 .56684 m .53985 .53039 L .58505 .53273 L p
1 g
F P
s
P
p
.002 w
.58505 .53273 m .59005 .56975 L .53602 .56684 L p
1 g
F P
s
P
p
.002 w
.41298 .56649 m .43202 .53343 L .48156 .55432 L p
1 g
F P
s
P
p
.002 w
.49428 .51991 m .48156 .55432 L .43202 .53343 L p
1 g
F P
s
P
p
.002 w
.48156 .55432 m .49428 .51991 L .53985 .53039 L p
1 g
F P
s
P
p
.002 w
.43863 .69726 m .44764 .66242 L .51946 .6789 L p
1 g
F P
s
P
p
.002 w
.51946 .6789 m .51268 .71425 L .43863 .69726 L p
1 g
F P
s
P
p
.002 w
.51268 .71425 m .51946 .6789 L .5907 .68323 L p
1 g
F P
s
P
p
.002 w
.5929 .6459 m .5907 .68323 L .51946 .6789 L p
1 g
F P
s
P
p
.002 w
.371 .66951 m .38209 .63534 L .44764 .66242 L p
1 g
F P
s
P
p
.002 w
.44764 .66242 m .43863 .69726 L .371 .66951 L p
1 g
F P
s
P
p
.002 w
.54267 .49585 m .53985 .53039 L .49428 .51991 L p
1 g
F P
s
P
p
.002 w
.53985 .53039 m .54267 .49585 L .57781 .4976 L p
1 g
F P
s
P
p
.002 w
.57781 .4976 m .58505 .53273 L .53985 .53039 L p
1 g
F P
s
P
p
.002 w
.43202 .53343 m .45289 .50234 L .49428 .51991 L p
1 g
F P
s
P
p
.002 w
.50723 .4877 m .49428 .51991 L .45289 .50234 L p
1 g
F P
s
P
p
.002 w
.49428 .51991 m .50723 .4877 L .54267 .49585 L p
1 g
F P
s
P
p
.002 w
.5929 .6459 m .59268 .60777 L .64757 .60001 L p
1 g
F P
s
P
p
.002 w
.59268 .60777 m .59005 .56975 L .63825 .56269 L p
1 g
F P
s
P
p
.002 w
.63825 .56269 m .64757 .60001 L .59268 .60777 L p
1 g
F P
s
P
p
.002 w
.34652 .56729 m .36775 .5357 L .41298 .56649 L p
1 g
F P
s
P
p
.002 w
.41298 .56649 m .3962 .60073 L .34652 .56729 L p
1 g
F P
s
P
p
.002 w
.43202 .53343 m .41298 .56649 L .36775 .5357 L p
1 g
F P
s
P
p
.002 w
.5907 .68323 m .5929 .6459 L .65302 .63769 L p
1 g
F P
s
P
p
.002 w
.64757 .60001 m .65302 .63769 L .5929 .6459 L p
1 g
F P
s
P
p
.002 w
.59005 .56975 m .58505 .53273 L .62531 .52663 L p
1 g
F P
s
P
p
.002 w
.62531 .52663 m .63825 .56269 L .59005 .56975 L p
1 g
F P
s
P
p
.002 w
.43117 .73011 m .43863 .69726 L .51268 .71425 L p
1 g
F P
s
P
p
.002 w
.51268 .71425 m .50553 .74716 L .43117 .73011 L p
1 g
F P
s
P
p
.002 w
.50553 .74716 m .51268 .71425 L .58612 .71887 L p
1 g
F P
s
P
p
.002 w
.5907 .68323 m .58612 .71887 L .51268 .71425 L p
1 g
F P
s
P
p
.002 w
.36775 .5357 m .39241 .50617 L .43202 .53343 L p
1 g
F P
s
P
p
.002 w
.45289 .50234 m .43202 .53343 L .39241 .50617 L p
1 g
F P
s
P
p
.002 w
.32925 .60016 m .34652 .56729 L .3962 .60073 L p
1 g
F P
s
P
p
.002 w
.3962 .60073 m .38209 .63534 L .32925 .60016 L p
1 g
F P
s
P
p
.002 w
.36322 .70241 m .371 .66951 L .43863 .69726 L p
1 g
F P
s
P
p
.002 w
.43863 .69726 m .43117 .73011 L .36322 .70241 L p
1 g
F P
s
P
p
.002 w
.58612 .71887 m .5907 .68323 L .65447 .67483 L p
1 g
F P
s
P
p
.002 w
.65302 .63769 m .65447 .67483 L .5907 .68323 L p
1 g
F P
s
P
p
.002 w
.58505 .53273 m .57781 .4976 L .60903 .49272 L p
1 g
F P
s
P
p
.002 w
.60903 .49272 m .62531 .52663 L .58505 .53273 L p
1 g
F P
s
P
p
.002 w
.39241 .50617 m .41991 .47939 L .45289 .50234 L p
1 g
F P
s
P
p
.002 w
.47509 .47397 m .45289 .50234 L .41991 .47939 L p
1 g
F P
s
P
p
.002 w
.45289 .50234 m .47509 .47397 L .50723 .4877 L p
1 g
F P
s
P
p
.002 w
.3164 .63353 m .32925 .60016 L .38209 .63534 L p
1 g
F P
s
P
p
.002 w
.38209 .63534 m .371 .66951 L .3164 .63353 L p
1 g
F P
s
P
p
.002 w
.54439 .46407 m .54267 .49585 L .50723 .4877 L p
1 g
F P
s
P
p
.002 w
.54267 .49585 m .54439 .46407 L .56846 .46522 L p
1 g
F P
s
P
p
.002 w
.56846 .46522 m .57781 .4976 L .54267 .49585 L p
1 g
F P
s
P
p
.002 w
.52009 .45847 m .50723 .4877 L .47509 .47397 L p
1 g
F P
s
P
p
.002 w
.50723 .4877 m .52009 .45847 L .54439 .46407 L p
1 g
F P
s
P
p
.002 w
.42545 .76016 m .43117 .73011 L .50553 .74716 L p
1 g
F P
s
P
p
.002 w
.50553 .74716 m .49816 .77683 L .42545 .76016 L p
1 g
F P
s
P
p
.002 w
.49816 .77683 m .50553 .74716 L .57923 .75195 L p
1 g
F P
s
P
p
.002 w
.58612 .71887 m .57923 .75195 L .50553 .74716 L p
1 g
F P
s
P
p
.002 w
.35899 .73322 m .36322 .70241 L .43117 .73011 L p
1 g
F P
s
P
p
.002 w
.43117 .73011 m .42545 .76016 L .35899 .73322 L p
1 g
F P
s
P
p
.002 w
.57923 .75195 m .58612 .71887 L .65185 .71052 L p
1 g
F P
s
P
p
.002 w
.65447 .67483 m .65185 .71052 L .58612 .71887 L p
1 g
F P
s
P
p
.002 w
.57781 .4976 m .56846 .46522 L .5898 .46179 L p
1 g
F P
s
P
p
.002 w
.5898 .46179 m .60903 .49272 L .57781 .4976 L p
1 g
F P
s
P
p
.002 w
.41991 .47939 m .44958 .45604 L .47509 .47397 L p
1 g
F P
s
P
p
.002 w
.4981 .44902 m .47509 .47397 L .44958 .45604 L p
1 g
F P
s
P
p
.002 w
.47509 .47397 m .4981 .44902 L .52009 .45847 L p
1 g
F P
s
P
p
.002 w
.30833 .66657 m .3164 .63353 L .371 .66951 L p
1 g
F P
s
P
p
.002 w
.371 .66951 m .36322 .70241 L .30833 .66657 L p
1 g
F P
s
P
p
.002 w
.64757 .60001 m .63825 .56269 L .67565 .54618 L p
1 g
F P
s
P
p
.002 w
.63825 .56269 m .62531 .52663 L .65641 .51259 L p
1 g
F P
s
P
p
.002 w
.65641 .51259 m .67565 .54618 L .63825 .56269 L p
1 g
F P
s
P
p
.002 w
.65302 .63769 m .64757 .60001 L .69027 .58157 L p
1 g
F P
s
P
p
.002 w
.67565 .54618 m .69027 .58157 L .64757 .60001 L p
1 g
F P
s
P
p
.002 w
.33846 .50069 m .36694 .47518 L .39241 .50617 L p
1 g
F P
s
P
p
.002 w
.39241 .50617 m .36775 .5357 L .33846 .50069 L p
1 g
F P
s
P
p
.002 w
.41991 .47939 m .39241 .50617 L .36694 .47518 L p
1 g
F P
s
P
p
.002 w
.62531 .52663 m .60903 .49272 L .63304 .48165 L p
1 g
F P
s
P
p
.002 w
.63304 .48165 m .65641 .51259 L .62531 .52663 L p
1 g
F P
s
P
p
.002 w
.31417 .52925 m .33846 .50069 L .36775 .5357 L p
1 g
F P
s
P
p
.002 w
.36775 .5357 m .34652 .56729 L .31417 .52925 L p
1 g
F P
s
P
p
.002 w
.54496 .43584 m .54439 .46407 L .52009 .45847 L p
1 g
F P
s
P
p
.002 w
.54439 .46407 m .54496 .43584 L .55722 .4364 L p
1 g
F P
s
P
p
.002 w
.55722 .4364 m .56846 .46522 L .54439 .46407 L p
1 g
F P
s
P
p
.002 w
.53257 .43299 m .52009 .45847 L .4981 .44902 L p
1 g
F P
s
P
p
.002 w
.52009 .45847 m .53257 .43299 L .54496 .43584 L p
1 g
F P
s
P
p
.002 w
.36694 .47518 m .39886 .45334 L .41991 .47939 L p
1 g
F P
s
P
p
.002 w
.44958 .45604 m .41991 .47939 L .39886 .45334 L p
1 g
F P
s
P
p
.002 w
.65447 .67483 m .65302 .63769 L .6999 .61789 L p
1 g
F P
s
P
p
.002 w
.69027 .58157 m .6999 .61789 L .65302 .63769 L p
1 g
F P
s
P
p
.002 w
.2947 .56016 m .31417 .52925 L .34652 .56729 L p
1 g
F P
s
P
p
.002 w
.34652 .56729 m .32925 .60016 L .2947 .56016 L p
1 g
F P
s
P
p
.002 w
.57923 .75195 m .57019 .78163 L .49816 .77683 L p
1 g
F P
s
P
p
.002 w
.57019 .78163 m .57923 .75195 L .64518 .74385 L p
1 g
F P
s
P
p
.002 w
.65185 .71052 m .64518 .74385 L .57923 .75195 L p
1 g
F P
s
P
p
.002 w
.60903 .49272 m .5898 .46179 L .60612 .4541 L p
1 g
F P
s
P
p
.002 w
.60612 .4541 m .63304 .48165 L .60903 .49272 L p
1 g
F P
s
P
p
.002 w
.56846 .46522 m .55722 .4364 L .56806 .43462 L p
1 g
F P
s
P
p
.002 w
.56806 .43462 m .5898 .46179 L .56846 .46522 L p
1 g
F P
s
P
p
.002 w
.44958 .45604 m .48072 .43668 L .4981 .44902 L p
1 g
F P
s
P
p
.002 w
.52137 .42815 m .4981 .44902 L .48072 .43668 L p
1 g
F P
s
P
p
.002 w
.4981 .44902 m .52137 .42815 L .53257 .43299 L p
1 g
F P
s
P
p
.002 w
.39886 .45334 m .43345 .43571 L .44958 .45604 L p
1 g
F P
s
P
p
.002 w
.48072 .43668 m .44958 .45604 L .43345 .43571 L p
1 g
F P
s
P
p
.002 w
.30529 .69846 m .30833 .66657 L .36322 .70241 L p
1 g
F P
s
P
p
.002 w
.36322 .70241 m .35899 .73322 L .30529 .69846 L p
1 g
F P
s
P
p
.002 w
.42164 .78662 m .42545 .76016 L .49816 .77683 L p
1 g
F P
s
P
p
.002 w
.49816 .77683 m .49076 .80246 L .42164 .78662 L p
1 g
F P
s
P
p
.002 w
.49076 .80246 m .49816 .77683 L .57019 .78163 L p
1 g
F P
s
P
p
.002 w
.35846 .76114 m .35899 .73322 L .42545 .76016 L p
1 g
F P
s
P
p
.002 w
.42545 .76016 m .42164 .78662 L .35846 .76114 L p
1 g
F P
s
P
p
.002 w
.65185 .71052 m .65447 .67483 L .70426 .65424 L p
1 g
F P
s
P
p
.002 w
.6999 .61789 m .70426 .65424 L .65447 .67483 L p
1 g
F P
s
P
p
.002 w
.28059 .59267 m .2947 .56016 L .32925 .60016 L p
1 g
F P
s
P
p
.002 w
.32925 .60016 m .3164 .63353 L .28059 .59267 L p
1 g
F P
s
P
p
.002 w
.5898 .46179 m .56806 .43462 L .57631 .43066 L p
1 g
F P
s
P
p
.002 w
.57631 .43066 m .60612 .4541 L .5898 .46179 L p
1 g
F P
s
P
p
.002 w
.43345 .43571 m .46982 .42273 L .48072 .43668 L p
1 g
F P
s
P
p
.002 w
.51257 .42184 m .48072 .43668 L .46982 .42273 L p
1 g
F P
s
P
p
.002 w
.48072 .43668 m .51257 .42184 L .52137 .42815 L p
1 g
F P
s
P
p
.002 w
.64518 .74385 m .65185 .71052 L .70318 .68969 L p
1 g
F P
s
P
p
.002 w
.70426 .65424 m .70318 .68969 L .65185 .71052 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .54496 .43584 L .53257 .43299 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .55722 .4364 L .54496 .43584 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .53257 .43299 L .52137 .42815 L closepath p
1 g
F P
s
P
p
.002 w
.57019 .78163 m .55918 .80713 L .49076 .80246 L p
1 g
F P
s
P
p
.002 w
.55918 .80713 m .57019 .78163 L .63458 .77396 L p
1 g
F P
s
P
p
.002 w
.64518 .74385 m .63458 .77396 L .57019 .78163 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .56806 .43462 L .55722 .4364 L closepath p
1 g
F P
s
P
p
.002 w
.27227 .62595 m .28059 .59267 L .3164 .63353 L p
1 g
F P
s
P
p
.002 w
.3164 .63353 m .30833 .66657 L .27227 .62595 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .52137 .42815 L .51257 .42184 L closepath p
1 g
F P
s
P
p
.002 w
.67565 .54618 m .65641 .51259 L .67491 .49191 L p
1 g
F P
s
P
p
.002 w
.65641 .51259 m .63304 .48165 L .6472 .46544 L p
1 g
F P
s
P
p
.002 w
.6472 .46544 m .67491 .49191 L .65641 .51259 L p
1 g
F P
s
P
p
.002 w
.30744 .72835 m .30529 .69846 L .35899 .73322 L p
1 g
F P
s
P
p
.002 w
.35899 .73322 m .35846 .76114 L .30744 .72835 L p
1 g
F P
s
P
p
.002 w
.63304 .48165 m .60612 .4541 L .61565 .44294 L p
1 g
F P
s
P
p
.002 w
.61565 .44294 m .6472 .46544 L .63304 .48165 L p
1 g
F P
s
P
p
.002 w
.69027 .58157 m .67565 .54618 L .69806 .52169 L p
1 g
F P
s
P
p
.002 w
.67491 .49191 m .69806 .52169 L .67565 .54618 L p
1 g
F P
s
P
p
.002 w
.35863 .4436 m .39222 .42686 L .39886 .45334 L p
1 g
F P
s
P
p
.002 w
.39886 .45334 m .36694 .47518 L .35863 .4436 L p
1 g
F P
s
P
p
.002 w
.43345 .43571 m .39886 .45334 L .39222 .42686 L p
1 g
F P
s
P
p
.002 w
.39222 .42686 m .42854 .41511 L .43345 .43571 L p
1 g
F P
s
P
p
.002 w
.46982 .42273 m .43345 .43571 L .42854 .41511 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .57631 .43066 L .56806 .43462 L closepath p
1 g
F P
s
P
p
.002 w
.60612 .4541 m .57631 .43066 L .58107 .42495 L p
1 g
F P
s
P
p
.002 w
.58107 .42495 m .61565 .44294 L .60612 .4541 L p
1 g
F P
s
P
p
.002 w
.46982 .42273 m .5071 .41473 L .51257 .42184 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .51257 .42184 L .5071 .41473 L closepath p
1 g
F P
s
P
p
.002 w
.32864 .46495 m .35863 .4436 L .36694 .47518 L p
1 g
F P
s
P
p
.002 w
.36694 .47518 m .33846 .50069 L .32864 .46495 L p
1 g
F P
s
P
p
.002 w
.41986 .80878 m .42164 .78662 L .49076 .80246 L p
1 g
F P
s
P
p
.002 w
.49076 .80246 m .4835 .82336 L .41986 .80878 L p
1 g
F P
s
P
p
.002 w
.4835 .82336 m .49076 .80246 L .55918 .80713 L p
1 g
F P
s
P
p
.002 w
.42854 .41511 m .46665 .40863 L .46982 .42273 L p
1 g
F P
s
P
p
.002 w
.5071 .41473 m .46982 .42273 L .46665 .40863 L p
1 g
F P
s
P
p
.002 w
.36171 .78542 m .35846 .76114 L .42164 .78662 L p
1 g
F P
s
P
p
.002 w
.42164 .78662 m .41986 .80878 L .36171 .78542 L p
1 g
F P
s
P
p
.002 w
.6999 .61789 m .69027 .58157 L .71602 .55404 L p
1 g
F P
s
P
p
.002 w
.69806 .52169 m .71602 .55404 L .69027 .58157 L p
1 g
F P
s
P
p
.002 w
.30307 .49039 m .32864 .46495 L .33846 .50069 L p
1 g
F P
s
P
p
.002 w
.33846 .50069 m .31417 .52925 L .30307 .49039 L p
1 g
F P
s
P
p
.002 w
.63458 .77396 m .64518 .74385 L .69665 .72334 L p
1 g
F P
s
P
p
.002 w
.70318 .68969 m .69665 .72334 L .64518 .74385 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .58107 .42495 L .57631 .43066 L closepath p
1 g
F P
s
P
p
.002 w
.46665 .40863 m .50557 .40756 L .5071 .41473 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .5071 .41473 L .50557 .40756 L closepath p
1 g
F P
s
P
p
.002 w
.27001 .65914 m .27227 .62595 L .30833 .66657 L p
1 g
F P
s
P
p
.002 w
.30833 .66657 m .30529 .69846 L .27001 .65914 L p
1 g
F P
s
P
p
.002 w
.70426 .65424 m .6999 .61789 L .72828 .58815 L p
1 g
F P
s
P
p
.002 w
.71602 .55404 m .72828 .58815 L .6999 .61789 L p
1 g
F P
s
P
p
.002 w
.28263 .5193 m .30307 .49039 L .31417 .52925 L p
1 g
F P
s
P
p
.002 w
.31417 .52925 m .2947 .56016 L .28263 .5193 L p
1 g
F P
s
P
p
.002 w
.61565 .44294 m .58107 .42495 L .5818 .41808 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .5818 .41808 L .58107 .42495 L closepath p
1 g
F P
s
P
p
.002 w
.55918 .80713 m .54645 .82774 L .4835 .82336 L p
1 g
F P
s
P
p
.002 w
.54645 .82774 m .55918 .80713 L .62026 .80006 L p
1 g
F P
s
P
p
.002 w
.63458 .77396 m .62026 .80006 L .55918 .80713 L p
1 g
F P
s
P
p
.002 w
.47163 .39591 m .50819 .40113 L .50557 .40756 L p
1 g
F P
s
P
p
.002 w
.50557 .40756 m .46665 .40863 L .47163 .39591 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .50557 .40756 L .50819 .40113 L closepath p
1 g
F P
s
P
p
.002 w
.6472 .46544 m .61565 .44294 L .61725 .42944 L p
1 g
F P
s
P
p
.002 w
.5818 .41808 m .61725 .42944 L .61565 .44294 L p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .51468 .39613 L .52437 .39313 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .50819 .40113 L .51468 .39613 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .57839 .41081 L .5818 .41808 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .57119 .40391 L .57839 .41081 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .56098 .39816 L .57119 .40391 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .54887 .3942 L .56098 .39816 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .5362 .39246 L .54887 .3942 L closepath p
1 g
F P
s
P
p
.002 w
.54433 .41193 m .52437 .39313 L .5362 .39246 L closepath p
1 g
F P
s
P
p
.002 w
.31482 .75545 m .30744 .72835 L .35846 .76114 L p
1 g
F P
s
P
p
.002 w
.35846 .76114 m .36171 .78542 L .31482 .75545 L p
1 g
F P
s
P
p
.002 w
.43561 .39644 m .47163 .39591 L .46665 .40863 L p
1 g
F P
s
P
p
.002 w
.46665 .40863 m .42854 .41511 L .43561 .39644 L p
1 g
F P
s
P
p
.002 w
.67491 .49191 m .6472 .46544 L .64977 .44575 L p
1 g
F P
s
P
p
.002 w
.61725 .42944 m .64977 .44575 L .6472 .46544 L p
1 g
F P
s
P
p
.002 w
.70318 .68969 m .70426 .65424 L .73447 .62314 L p
1 g
F P
s
P
p
.002 w
.72828 .58815 m .73447 .62314 L .70426 .65424 L p
1 g
F P
s
P
p
.002 w
.40106 .40278 m .43561 .39644 L .42854 .41511 L p
1 g
F P
s
P
p
.002 w
.42854 .41511 m .39222 .42686 L .40106 .40278 L p
1 g
F P
s
P
p
.002 w
.61725 .42944 m .5818 .41808 L .57839 .41081 L p
1 g
F P
s
P
p
.002 w
.62026 .80006 m .63458 .77396 L .68476 .75428 L p
1 g
F P
s
P
p
.002 w
.69665 .72334 m .68476 .75428 L .63458 .77396 L p
1 g
F P
s
P
p
.002 w
.48435 .38598 m .51468 .39613 L .50819 .40113 L p
1 g
F P
s
P
p
.002 w
.50819 .40113 m .47163 .39591 L .48435 .38598 L p
1 g
F P
s
P
p
.002 w
.26793 .55095 m .28263 .5193 L .2947 .56016 L p
1 g
F P
s
P
p
.002 w
.2947 .56016 m .28059 .59267 L .26793 .55095 L p
1 g
F P
s
P
p
.002 w
.69806 .52169 m .67491 .49191 L .67849 .46665 L p
1 g
F P
s
P
p
.002 w
.64977 .44575 m .67849 .46665 L .67491 .49191 L p
1 g
F P
s
P
p
.002 w
.42022 .82597 m .41986 .80878 L .4835 .82336 L p
1 g
F P
s
P
p
.002 w
.4835 .82336 m .47658 .83888 L .42022 .82597 L p
1 g
F P
s
P
p
.002 w
.47658 .83888 m .4835 .82336 L .54645 .82774 L p
1 g
F P
s
P
p
.002 w
.36874 .80535 m .36171 .78542 L .41986 .80878 L p
1 g
F P
s
P
p
.002 w
.41986 .80878 m .42022 .82597 L .36874 .80535 L p
1 g
F P
s
P
p
.002 w
.27398 .69136 m .27001 .65914 L .30529 .69846 L p
1 g
F P
s
P
p
.002 w
.30529 .69846 m .30744 .72835 L .27398 .69136 L p
1 g
F P
s
P
p
.002 w
.3689 .41482 m .40106 .40278 L .39222 .42686 L p
1 g
F P
s
P
p
.002 w
.39222 .42686 m .35863 .4436 L .3689 .41482 L p
1 g
F P
s
P
p
.002 w
.57839 .41081 m .61065 .41507 L .61725 .42944 L p
1 g
F P
s
P
p
.002 w
.61065 .41507 m .57839 .41081 L .57119 .40391 L p
1 g
F P
s
P
p
.002 w
.50349 .37997 m .52437 .39313 L .51468 .39613 L p
1 g
F P
s
P
p
.002 w
.51468 .39613 m .48435 .38598 L .50349 .37997 L p
1 g
F P
s
P
p
.002 w
.64977 .44575 m .61725 .42944 L .61065 .41507 L p
1 g
F P
s
P
p
.002 w
.71602 .55404 m .69806 .52169 L .70262 .49163 L p
1 g
F P
s
P
p
.002 w
.67849 .46665 m .70262 .49163 L .69806 .52169 L p
1 g
F P
s
P
p
.002 w
.69665 .72334 m .70318 .68969 L .73436 .65809 L p
1 g
F P
s
P
p
.002 w
.73447 .62314 m .73436 .65809 L .70318 .68969 L p
1 g
F P
s
P
p
.002 w
.45413 .38181 m .48435 .38598 L .47163 .39591 L p
1 g
F P
s
P
p
.002 w
.47163 .39591 m .43561 .39644 L .45413 .38181 L p
1 g
F P
s
P
p
.002 w
.34001 .43231 m .3689 .41482 L .35863 .4436 L p
1 g
F P
s
P
p
.002 w
.35863 .4436 m .32864 .46495 L .34001 .43231 L p
1 g
F P
s
P
p
.002 w
.57119 .40391 m .59648 .40139 L .61065 .41507 L p
1 g
F P
s
P
p
.002 w
.59648 .40139 m .57119 .40391 L .56098 .39816 L p
1 g
F P
s
P
p
.002 w
.52696 .37861 m .5362 .39246 L .52437 .39313 L p
1 g
F P
s
P
p
.002 w
.52437 .39313 m .50349 .37997 L .52696 .37861 L p
1 g
F P
s
P
p
.002 w
.25944 .58453 m .26793 .55095 L .28059 .59267 L p
1 g
F P
s
P
p
.002 w
.28059 .59267 m .27227 .62595 L .25944 .58453 L p
1 g
F P
s
P
p
.002 w
.54645 .82774 m .53228 .84281 L .47658 .83888 L p
1 g
F P
s
P
p
.002 w
.53228 .84281 m .54645 .82774 L .60253 .82138 L p
1 g
F P
s
P
p
.002 w
.62026 .80006 m .60253 .82138 L .54645 .82774 L p
1 g
F P
s
P
p
.002 w
.32731 .77899 m .31482 .75545 L .36171 .78542 L p
1 g
F P
s
P
p
.002 w
.36171 .78542 m .36874 .80535 L .32731 .77899 L p
1 g
F P
s
P
p
.002 w
.56098 .39816 m .57623 .38996 L .59648 .40139 L p
1 g
F P
s
P
p
.002 w
.57623 .38996 m .56098 .39816 L .54887 .3942 L p
1 g
F P
s
P
p
.002 w
.55216 .38206 m .54887 .3942 L .5362 .39246 L p
1 g
F P
s
P
p
.002 w
.5362 .39246 m .52696 .37861 L .55216 .38206 L p
1 g
F P
s
P
p
.002 w
.54887 .3942 m .55216 .38206 L .57623 .38996 L p
1 g
F P
s
P
p
.002 w
.60253 .82138 m .62026 .80006 L .66774 .78165 L p
1 g
F P
s
P
p
.002 w
.68476 .75428 m .66774 .78165 L .62026 .80006 L p
1 g
F P
s
P
p
.002 w
.72828 .58815 m .71602 .55404 L .72145 .52008 L p
1 g
F P
s
P
p
.002 w
.70262 .49163 m .72145 .52008 L .71602 .55404 L p
1 g
F P
s
P
p
.002 w
.67849 .46665 m .64977 .44575 L .64026 .42468 L p
1 g
F P
s
P
p
.002 w
.61065 .41507 m .64026 .42468 L .64977 .44575 L p
1 g
F P
s
P
p
.002 w
.42481 .38384 m .45413 .38181 L .43561 .39644 L p
1 g
F P
s
P
p
.002 w
.43561 .39644 m .40106 .40278 L .42481 .38384 L p
1 g
F P
s
P
p
.002 w
.28415 .72175 m .27398 .69136 L .30744 .72835 L p
1 g
F P
s
P
p
.002 w
.30744 .72835 m .31482 .75545 L .28415 .72175 L p
1 g
F P
s
P
p
.002 w
.31522 .45487 m .34001 .43231 L .32864 .46495 L p
1 g
F P
s
P
p
.002 w
.32864 .46495 m .30307 .49039 L .31522 .45487 L p
1 g
F P
s
P
p
.002 w
.64026 .42468 m .61065 .41507 L .59648 .40139 L p
1 g
F P
s
P
p
.002 w
.68476 .75428 m .69665 .72334 L .72786 .69208 L p
1 g
F P
s
P
p
.002 w
.73436 .65809 m .72786 .69208 L .69665 .72334 L p
1 g
F P
s
P
p
.002 w
.48222 .37292 m .50349 .37997 L .48435 .38598 L p
1 g
F P
s
P
p
.002 w
.48435 .38598 m .45413 .38181 L .48222 .37292 L p
1 g
F P
s
P
p
.002 w
.25745 .61914 m .25944 .58453 L .27227 .62595 L p
1 g
F P
s
P
p
.002 w
.27227 .62595 m .27001 .65914 L .25745 .61914 L p
1 g
F P
s
P
p
.002 w
.42274 .83764 m .42022 .82597 L .47658 .83888 L p
1 g
F P
s
P
p
.002 w
.47658 .83888 m .47018 .8485 L .42274 .83764 L p
1 g
F P
s
P
p
.002 w
.47018 .8485 m .47658 .83888 L .53228 .84281 L p
1 g
F P
s
P
p
.002 w
.37944 .82033 m .36874 .80535 L .42022 .82597 L p
1 g
F P
s
P
p
.002 w
.42022 .82597 m .42274 .83764 L .37944 .82033 L p
1 g
F P
s
P
p
.002 w
.73447 .62314 m .72828 .58815 L .73442 .55129 L p
1 g
F P
s
P
p
.002 w
.72145 .52008 m .73442 .55129 L .72828 .58815 L p
1 g
F P
s
P
p
.002 w
.70262 .49163 m .67849 .46665 L .66638 .43947 L p
1 g
F P
s
P
p
.002 w
.64026 .42468 m .66638 .43947 L .67849 .46665 L p
1 g
F P
s
P
p
.002 w
.3972 .39211 m .42481 .38384 L .40106 .40278 L p
1 g
F P
s
P
p
.002 w
.40106 .40278 m .3689 .41482 L .3972 .39211 L p
1 g
F P
s
P
p
.002 w
.29527 .48194 m .31522 .45487 L .30307 .49039 L p
1 g
F P
s
P
p
.002 w
.30307 .49039 m .28263 .5193 L .29527 .48194 L p
1 g
F P
s
P
p
.002 w
.59648 .40139 m .61949 .40454 L .64026 .42468 L p
1 g
F P
s
P
p
.002 w
.61949 .40454 m .59648 .40139 L .57623 .38996 L p
1 g
F P
s
P
p
.002 w
.51684 .37088 m .52696 .37861 L .50349 .37997 L p
1 g
F P
s
P
p
.002 w
.50349 .37997 m .48222 .37292 L .51684 .37088 L p
1 g
F P
s
P
p
.002 w
.53228 .84281 m .51702 .85184 L .47018 .8485 L p
1 g
F P
s
P
p
.002 w
.51702 .85184 m .53228 .84281 L .5818 .83728 L p
1 g
F P
s
P
p
.002 w
.60253 .82138 m .5818 .83728 L .53228 .84281 L p
1 g
F P
s
P
p
.002 w
.66774 .78165 m .68476 .75428 L .71509 .72417 L p
1 g
F P
s
P
p
.002 w
.72786 .69208 m .71509 .72417 L .68476 .75428 L p
1 g
F P
s
P
p
.002 w
.5818 .83728 m .60253 .82138 L .64598 .80469 L p
1 g
F P
s
P
p
.002 w
.66774 .78165 m .64598 .80469 L .60253 .82138 L p
1 g
F P
s
P
p
.002 w
.66638 .43947 m .64026 .42468 L .61949 .40454 L p
1 g
F P
s
P
p
.002 w
.34469 .79826 m .32731 .77899 L .36874 .80535 L p
1 g
F P
s
P
p
.002 w
.36874 .80535 m .37944 .82033 L .34469 .79826 L p
1 g
F P
s
P
p
.002 w
.30033 .74943 m .28415 .72175 L .31482 .75545 L p
1 g
F P
s
P
p
.002 w
.31482 .75545 m .32731 .77899 L .30033 .74943 L p
1 g
F P
s
P
p
.002 w
.46114 .3723 m .48222 .37292 L .45413 .38181 L p
1 g
F P
s
P
p
.002 w
.45413 .38181 m .42481 .38384 L .46114 .3723 L p
1 g
F P
s
P
p
.002 w
.57623 .38996 m .58965 .38765 L .61949 .40454 L p
1 g
F P
s
P
p
.002 w
.58965 .38765 m .57623 .38996 L .55216 .38206 L p
1 g
F P
s
P
p
.002 w
.73436 .65809 m .73447 .62314 L .74109 .58444 L p
1 g
F P
s
P
p
.002 w
.73442 .55129 m .74109 .58444 L .73447 .62314 L p
1 g
F P
s
P
p
.002 w
.55408 .37598 m .55216 .38206 L .52696 .37861 L p
1 g
F P
s
P
p
.002 w
.52696 .37861 m .51684 .37088 L .55408 .37598 L p
1 g
F P
s
P
p
.002 w
.26211 .65385 m .25745 .61914 L .27001 .65914 L p
1 g
F P
s
P
p
.002 w
.27001 .65914 m .27398 .69136 L .26211 .65385 L p
1 g
F P
s
P
p
.002 w
.72145 .52008 m .70262 .49163 L .68827 .45913 L p
1 g
F P
s
P
p
.002 w
.66638 .43947 m .68827 .45913 L .70262 .49163 L p
1 g
F P
s
P
p
.002 w
.55216 .38206 m .55408 .37598 L .58965 .38765 L p
1 g
F P
s
P
p
.002 w
.28076 .51283 m .29527 .48194 L .28263 .5193 L p
1 g
F P
s
P
p
.002 w
.28263 .5193 m .26793 .55095 L .28076 .51283 L p
1 g
F P
s
P
p
.002 w
.37207 .40652 m .3972 .39211 L .3689 .41482 L p
1 g
F P
s
P
p
.002 w
.3689 .41482 m .34001 .43231 L .37207 .40652 L p
1 g
F P
s
P
p
.002 w
.42741 .84333 m .42274 .83764 L .47018 .8485 L p
1 g
F P
s
P
p
.002 w
.47018 .8485 m .46449 .85182 L .42741 .84333 L p
1 g
F P
s
P
p
.002 w
.46449 .85182 m .47018 .8485 L .51702 .85184 L p
1 g
F P
s
P
p
.002 w
.39361 .82983 m .37944 .82033 L .42274 .83764 L p
1 g
F P
s
P
p
.002 w
.42274 .83764 m .42741 .84333 L .39361 .82983 L p
1 g
F P
s
P
p
.002 w
.64598 .80469 m .66774 .78165 L .69629 .75345 L p
1 g
F P
s
P
p
.002 w
.71509 .72417 m .69629 .75345 L .66774 .78165 L p
1 g
F P
s
P
p
.002 w
.74109 .58444 m .74119 .61865 L .73436 .65809 L p
1 g
F P
s
P
p
.002 w
.72786 .69208 m .73436 .65809 L .74119 .61865 L p
1 g
F P
s
P
p
.002 w
.61949 .40454 m .63956 .4134 L .66638 .43947 L p
1 g
F P
s
P
p
.002 w
.63956 .4134 m .61949 .40454 L .58965 .38765 L p
1 g
F P
s
P
p
.002 w
.5061 .36964 m .51684 .37088 L .48222 .37292 L p
1 g
F P
s
P
p
.002 w
.48222 .37292 m .46114 .3723 L .5061 .36964 L p
1 g
F P
s
P
p
.002 w
.68827 .45913 m .66638 .43947 L .63956 .4134 L p
1 g
F P
s
P
p
.002 w
.27338 .68769 m .26211 .65385 L .27398 .69136 L p
1 g
F P
s
P
p
.002 w
.27398 .69136 m .28415 .72175 L .27338 .68769 L p
1 g
F P
s
P
p
.002 w
.68827 .45913 m .70525 .48321 L .72145 .52008 L p
1 g
F P
s
P
p
.002 w
.73442 .55129 m .72145 .52008 L .70525 .48321 L p
1 g
F P
s
P
p
.002 w
.5818 .83728 m .55855 .84724 L .51702 .85184 L p
1 g
F P
s
P
p
.002 w
.55855 .84724 m .5818 .83728 L .62 .82268 L p
1 g
F P
s
P
p
.002 w
.64598 .80469 m .62 .82268 L .5818 .83728 L p
1 g
F P
s
P
p
.002 w
.27219 .54674 m .28076 .51283 L .26793 .55095 L p
1 g
F P
s
P
p
.002 w
.26793 .55095 m .25944 .58453 L .27219 .54674 L p
1 g
F P
s
P
p
.002 w
.44081 .37826 m .46114 .3723 L .42481 .38384 L p
1 g
F P
s
P
p
.002 w
.42481 .38384 m .3972 .39211 L .44081 .37826 L p
1 g
F P
s
P
p
.002 w
.32219 .77361 m .30033 .74943 L .32731 .77899 L p
1 g
F P
s
P
p
.002 w
.32731 .77899 m .34469 .79826 L .32219 .77361 L p
1 g
F P
s
P
p
.002 w
.35019 .42677 m .37207 .40652 L .34001 .43231 L p
1 g
F P
s
P
p
.002 w
.34001 .43231 m .31522 .45487 L .35019 .42677 L p
1 g
F P
s
P
p
.002 w
.51702 .85184 m .50106 .85443 L .46449 .85182 L p
1 g
F P
s
P
p
.002 w
.50106 .85443 m .51702 .85184 L .55855 .84724 L p
1 g
F P
s
P
p
.002 w
.36657 .81265 m .34469 .79826 L .37944 .82033 L p
1 g
F P
s
P
p
.002 w
.37944 .82033 m .39361 .82983 L .36657 .81265 L p
1 g
F P
s
P
p
.002 w
.58965 .38765 m .60083 .39146 L .63956 .4134 L p
1 g
F P
s
P
p
.002 w
.60083 .39146 m .58965 .38765 L .55408 .37598 L p
1 g
F P
s
P
p
.002 w
.55455 .37627 m .55408 .37598 L .51684 .37088 L p
1 g
F P
s
P
p
.002 w
.51684 .37088 m .5061 .36964 L .55455 .37627 L p
1 g
F P
s
P
p
.002 w
.71509 .72417 m .72786 .69208 L .73463 .65297 L p
1 g
F P
s
P
p
.002 w
.74119 .61865 m .73463 .65297 L .72786 .69208 L p
1 g
F P
s
P
p
.002 w
.69629 .75345 m .67193 .77908 L .64598 .80469 L p
1 g
F P
s
P
p
.002 w
.62 .82268 m .64598 .80469 L .67193 .77908 L p
1 g
F P
s
P
p
.002 w
.55408 .37598 m .55455 .37627 L .60083 .39146 L p
1 g
F P
s
P
p
.002 w
.26988 .58275 m .27219 .54674 L .25944 .58453 L p
1 g
F P
s
P
p
.002 w
.25944 .58453 m .25745 .61914 L .26988 .58275 L p
1 g
F P
s
P
p
.002 w
.74109 .58444 m .73442 .55129 L .71676 .51112 L p
1 g
F P
s
P
p
.002 w
.70525 .48321 m .71676 .51112 L .73442 .55129 L p
1 g
F P
s
P
p
.002 w
.29101 .71968 m .27338 .68769 L .28415 .72175 L p
1 g
F P
s
P
p
.002 w
.28415 .72175 m .30033 .74943 L .29101 .71968 L p
1 g
F P
s
P
p
.002 w
.63956 .4134 m .65609 .42784 L .68827 .45913 L p
1 g
F P
s
P
p
.002 w
.70525 .48321 m .68827 .45913 L .65609 .42784 L p
1 g
F P
s
P
p
.002 w
.33222 .45239 m .35019 .42677 L .31522 .45487 L p
1 g
F P
s
P
p
.002 w
.31522 .45487 m .29527 .48194 L .33222 .45239 L p
1 g
F P
s
P
p
.002 w
.42183 .39078 m .44081 .37826 L .3972 .39211 L p
1 g
F P
s
P
p
.002 w
.3972 .39211 m .37207 .40652 L .42183 .39078 L p
1 g
F P
s
P
p
.002 w
.65609 .42784 m .63956 .4134 L .60083 .39146 L p
1 g
F P
s
P
p
.002 w
.55855 .84724 m .53339 .85086 L .50106 .85443 L p
1 g
F P
s
P
p
.002 w
.62 .82268 m .59043 .83506 L .55855 .84724 L p
1 g
F P
s
P
p
.002 w
.53339 .85086 m .55855 .84724 L .59043 .83506 L p
1 g
F P
s
P
p
.002 w
.43417 .84274 m .42741 .84333 L .46449 .85182 L p
1 g
F P
s
P
p
.002 w
.46449 .85182 m .45967 .84858 L .43417 .84274 L p
1 g
F P
s
P
p
.002 w
.45967 .84858 m .46449 .85182 L .50106 .85443 L p
1 g
F P
s
P
p
.002 w
.495 .37507 m .5061 .36964 L .46114 .3723 L p
1 g
F P
s
P
p
.002 w
.46114 .3723 m .44081 .37826 L .495 .37507 L p
1 g
F P
s
P
p
.002 w
.41094 .83345 m .39361 .82983 L .42741 .84333 L p
1 g
F P
s
P
p
.002 w
.42741 .84333 m .43417 .84274 L .41094 .83345 L p
1 g
F P
s
P
p
.002 w
.34918 .79355 m .32219 .77361 L .34469 .79826 L p
1 g
F P
s
P
p
.002 w
.34469 .79826 m .36657 .81265 L .34918 .79355 L p
1 g
F P
s
P
p
.002 w
.69629 .75345 m .71509 .72417 L .72151 .68645 L p
1 g
F P
s
P
p
.002 w
.73463 .65297 m .72151 .68645 L .71509 .72417 L p
1 g
F P
s
P
p
.002 w
.27396 .61983 m .26988 .58275 L .25745 .61914 L p
1 g
F P
s
P
p
.002 w
.25745 .61914 m .26211 .65385 L .27396 .61983 L p
1 g
F P
s
P
p
.002 w
.74119 .61865 m .74109 .58444 L .72238 .54214 L p
1 g
F P
s
P
p
.002 w
.71676 .51112 m .72238 .54214 L .74109 .58444 L p
1 g
F P
s
P
p
.002 w
.59043 .83506 m .62 .82268 L .64261 .80028 L p
1 g
F P
s
P
p
.002 w
.67193 .77908 m .64261 .80028 L .62 .82268 L p
1 g
F P
s
P
p
.002 w
.50106 .85443 m .48481 .85037 L .45967 .84858 L p
1 g
F P
s
P
p
.002 w
.48481 .85037 m .50106 .85443 L .53339 .85086 L p
1 g
F P
s
P
p
.002 w
.39243 .82168 m .36657 .81265 L .39361 .82983 L p
1 g
F P
s
P
p
.002 w
.39361 .82983 m .41094 .83345 L .39243 .82168 L p
1 g
F P
s
P
p
.002 w
.31458 .74891 m .29101 .71968 L .30033 .74943 L p
1 g
F P
s
P
p
.002 w
.30033 .74943 m .32219 .77361 L .31458 .74891 L p
1 g
F P
s
P
p
.002 w
.31874 .48274 m .33222 .45239 L .29527 .48194 L p
1 g
F P
s
P
p
.002 w
.29527 .48194 m .28076 .51283 L .31874 .48274 L p
1 g
F P
s
P
p
.002 w
.60083 .39146 m .60941 .40143 L .65609 .42784 L p
1 g
F P
s
P
p
.002 w
.60941 .40143 m .60083 .39146 L .55455 .37627 L p
1 g
F P
s
P
p
.002 w
.55351 .3831 m .55455 .37627 L .5061 .36964 L p
1 g
F P
s
P
p
.002 w
.5061 .36964 m .495 .37507 L .55351 .3831 L p
1 g
F P
s
P
p
.002 w
.71676 .51112 m .70525 .48321 L .66853 .44758 L p
1 g
F P
s
P
p
.002 w
.65609 .42784 m .66853 .44758 L .70525 .48321 L p
1 g
F P
s
P
p
.002 w
.67193 .77908 m .69629 .75345 L .70212 .71809 L p
1 g
F P
s
P
p
.002 w
.72151 .68645 m .70212 .71809 L .69629 .75345 L p
1 g
F P
s
P
p
.002 w
.40476 .40964 m .42183 .39078 L .37207 .40652 L p
1 g
F P
s
P
p
.002 w
.37207 .40652 m .35019 .42677 L .40476 .40964 L p
1 g
F P
s
P
p
.002 w
.55455 .37627 m .55351 .3831 L .60941 .40143 L p
1 g
F P
s
P
p
.002 w
.28438 .65692 m .27396 .61983 L .26211 .65385 L p
1 g
F P
s
P
p
.002 w
.26211 .65385 m .27338 .68769 L .28438 .65692 L p
1 g
F P
s
P
p
.002 w
.53339 .85086 m .50697 .84791 L .48481 .85037 L p
1 g
F P
s
P
p
.002 w
.50697 .84791 m .53339 .85086 L .55807 .8414 L p
1 g
F P
s
P
p
.002 w
.59043 .83506 m .55807 .8414 L .53339 .85086 L p
1 g
F P
s
P
p
.002 w
.73463 .65297 m .74119 .61865 L .72186 .57542 L p
1 g
F P
s
P
p
.002 w
.72238 .54214 m .72186 .57542 L .74119 .61865 L p
1 g
F P
s
P
p
.002 w
.66853 .44758 m .65609 .42784 L .60941 .40143 L p
1 g
F P
s
P
p
.002 w
.38062 .80862 m .34918 .79355 L .36657 .81265 L p
1 g
F P
s
P
p
.002 w
.36657 .81265 m .39243 .82168 L .38062 .80862 L p
1 g
F P
s
P
p
.002 w
.48387 .3872 m .495 .37507 L .44081 .37826 L p
1 g
F P
s
P
p
.002 w
.44081 .37826 m .42183 .39078 L .48387 .3872 L p
1 g
F P
s
P
p
.002 w
.55807 .8414 m .59043 .83506 L .60911 .81641 L p
1 g
F P
s
P
p
.002 w
.64261 .80028 m .60911 .81641 L .59043 .83506 L p
1 g
F P
s
P
p
.002 w
.31022 .51698 m .31874 .48274 L .28076 .51283 L p
1 g
F P
s
P
p
.002 w
.28076 .51283 m .27219 .54674 L .31022 .51698 L p
1 g
F P
s
P
p
.002 w
.34346 .7745 m .31458 .74891 L .32219 .77361 L p
1 g
F P
s
P
p
.002 w
.32219 .77361 m .34918 .79355 L .34346 .7745 L p
1 g
F P
s
P
p
.002 w
.44287 .83572 m .43417 .84274 L .45967 .84858 L p
1 g
F P
s
P
p
.002 w
.45967 .84858 m .4559 .83871 L .44287 .83572 L p
1 g
F P
s
P
p
.002 w
.4559 .83871 m .45967 .84858 L .48481 .85037 L p
1 g
F P
s
P
p
.002 w
.43101 .83097 m .41094 .83345 L .43417 .84274 L p
1 g
F P
s
P
p
.002 w
.43417 .84274 m .44287 .83572 L .43101 .83097 L p
1 g
F P
s
P
p
.002 w
.64261 .80028 m .67193 .77908 L .67696 .74698 L p
1 g
F P
s
P
p
.002 w
.70212 .71809 m .67696 .74698 L .67193 .77908 L p
1 g
F P
s
P
p
.002 w
.48481 .85037 m .46874 .83961 L .4559 .83871 L p
1 g
F P
s
P
p
.002 w
.46874 .83961 m .48481 .85037 L .50697 .84791 L p
1 g
F P
s
P
p
.002 w
.72238 .54214 m .71676 .51112 L .67645 .47218 L p
1 g
F P
s
P
p
.002 w
.66853 .44758 m .67645 .47218 L .71676 .51112 L p
1 g
F P
s
P
p
.002 w
.3009 .69294 m .28438 .65692 L .27338 .68769 L p
1 g
F P
s
P
p
.002 w
.27338 .68769 m .29101 .71968 L .3009 .69294 L p
1 g
F P
s
P
p
.002 w
.4216 .82496 m .39243 .82168 L .41094 .83345 L p
1 g
F P
s
P
p
.002 w
.41094 .83345 m .43101 .83097 L .4216 .82496 L p
1 g
F P
s
P
p
.002 w
.72151 .68645 m .73463 .65297 L .71512 .61004 L p
1 g
F P
s
P
p
.002 w
.72186 .57542 m .71512 .61004 L .73463 .65297 L p
1 g
F P
s
P
p
.002 w
.39015 .43442 m .40476 .40964 L .35019 .42677 L p
1 g
F P
s
P
p
.002 w
.35019 .42677 m .33222 .45239 L .39015 .43442 L p
1 g
F P
s
P
p
.002 w
.60941 .40143 m .61507 .41742 L .66853 .44758 L p
1 g
F P
s
P
p
.002 w
.61507 .41742 m .60941 .40143 L .55351 .3831 L p
1 g
F P
s
P
p
.002 w
.30697 .55418 m .31022 .51698 L .27219 .54674 L p
1 g
F P
s
P
p
.002 w
.27219 .54674 m .26988 .58275 L .30697 .55418 L p
1 g
F P
s
P
p
.002 w
.55807 .8414 m .52377 .84141 L .50697 .84791 L p
1 g
F P
s
P
p
.002 w
.52377 .84141 m .55807 .8414 L .57236 .82694 L p
1 g
F P
s
P
p
.002 w
.60911 .81641 m .57236 .82694 L .55807 .8414 L p
1 g
F P
s
P
p
.002 w
.55097 .39642 m .55351 .3831 L .495 .37507 L p
1 g
F P
s
P
p
.002 w
.495 .37507 m .48387 .3872 L .55097 .39642 L p
1 g
F P
s
P
p
.002 w
.60911 .81641 m .64261 .80028 L .64672 .77224 L p
1 g
F P
s
P
p
.002 w
.67696 .74698 m .64672 .77224 L .64261 .80028 L p
1 g
F P
s
P
p
.002 w
.50697 .84791 m .48001 .83834 L .46874 .83961 L p
1 g
F P
s
P
p
.002 w
.48001 .83834 m .50697 .84791 L .52377 .84141 L p
1 g
F P
s
P
p
.002 w
.37686 .79567 m .34346 .7745 L .34918 .79355 L p
1 g
F P
s
P
p
.002 w
.34918 .79355 m .38062 .80862 L .37686 .79567 L p
1 g
F P
s
P
p
.002 w
.41565 .81833 m .38062 .80862 L .39243 .82168 L p
1 g
F P
s
P
p
.002 w
.39243 .82168 m .4216 .82496 L .41565 .81833 L p
1 g
F P
s
P
p
.002 w
.67645 .47218 m .66853 .44758 L .61507 .41742 L p
1 g
F P
s
P
p
.002 w
.32306 .72682 m .3009 .69294 L .29101 .71968 L p
1 g
F P
s
P
p
.002 w
.29101 .71968 m .31458 .74891 L .32306 .72682 L p
1 g
F P
s
P
p
.002 w
.55351 .3831 m .55097 .39642 L .61507 .41742 L p
1 g
F P
s
P
p
.002 w
.47301 .40582 m .48387 .3872 L .42183 .39078 L p
1 g
F P
s
P
p
.002 w
.42183 .39078 m .40476 .40964 L .47301 .40582 L p
1 g
F P
s
P
p
.002 w
.70212 .71809 m .72151 .68645 L .70228 .64499 L p
1 g
F P
s
P
p
.002 w
.71512 .61004 m .70228 .64499 L .72151 .68645 L p
1 g
F P
s
P
p
.002 w
.72186 .57542 m .72238 .54214 L .67951 .501 L p
1 g
F P
s
P
p
.002 w
.67645 .47218 m .67951 .501 L .72238 .54214 L p
1 g
F P
s
P
p
.002 w
.30915 .59324 m .30697 .55418 L .26988 .58275 L p
1 g
F P
s
P
p
.002 w
.26988 .58275 m .27396 .61983 L .30915 .59324 L p
1 g
F P
s
P
p
.002 w
.57236 .82694 m .60911 .81641 L .61223 .79311 L p
1 g
F P
s
P
p
.002 w
.64672 .77224 m .61223 .79311 L .60911 .81641 L p
1 g
F P
s
P
p
.002 w
.37847 .46449 m .39015 .43442 L .33222 .45239 L p
1 g
F P
s
P
p
.002 w
.33222 .45239 m .31874 .48274 L .37847 .46449 L p
1 g
F P
s
P
p
.002 w
.4559 .83871 m .4533 .82232 L .44287 .83572 L closepath p
1 g
F P
s
P
p
.002 w
.46874 .83961 m .4533 .82232 L .4559 .83871 L closepath p
1 g
F P
s
P
p
.002 w
.44287 .83572 m .4533 .82232 L .43101 .83097 L closepath p
1 g
F P
s
P
p
.002 w
.52377 .84141 m .48851 .83501 L .48001 .83834 L p
1 g
F P
s
P
p
.002 w
.48851 .83501 m .52377 .84141 L .53338 .83152 L p
1 g
F P
s
P
p
.002 w
.57236 .82694 m .53338 .83152 L .52377 .84141 L p
1 g
F P
s
P
p
.002 w
.35025 .75755 m .32306 .72682 L .31458 .74891 L p
1 g
F P
s
P
p
.002 w
.31458 .74891 m .34346 .7745 L .35025 .75755 L p
1 g
F P
s
P
p
.002 w
.41383 .81177 m .37686 .79567 L .38062 .80862 L p
1 g
F P
s
P
p
.002 w
.38062 .80862 m .41565 .81833 L .41383 .81177 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.46874 .83961 m .48001 .83834 L .45678 .82441 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51258 .83143 L p
1 g
F P
s
P
p
.002 w
.53338 .83152 m .52139 .83106 L p
.49778 .8339 L 1 g
F P
s
P
p
.53338 .83152 m .49778 .8339 L .49338 .83464 L 1 g
F
P
p
.53597 .82325 m .51258 .83143 L .51602 .83085 L 1 g
F
P
p
.002 w
.51602 .83085 m .53338 .83152 L .53384 .82718 L p
1 g
F P
s
P
p
.52371 .82927 m .51602 .83085 L .52277 .82972 L 1 g
F
P
p
.53597 .82325 m .51602 .83085 L .52371 .82927 L 1 g
F
P
p
.002 w
.51258 .83143 m .51242 .82869 L p
.49832 .83202 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.49107 .83232 m .48851 .83501 L p
.52139 .83106 L 1 g
F P
s
P
p
.002 w
.48001 .83834 m .48851 .83501 L .47714 .83091 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48739 .83195 L p
1 g
F P
s
P
p
.002 w
.47714 .83091 m .48851 .83501 L .49067 .83275 L p
1 g
F P
s
P
p
.002 w
.49067 .83275 m .49107 .83232 L p
.48739 .83195 L 1 g
F P
s
P
p
.48739 .83195 m .47714 .83091 L .49067 .83275 L 1 g
F
P
p
.002 w
.48739 .83195 m .48758 .82869 L p
.47486 .82888 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .46355 .8261 L p
1 g
F P
s
P
p
.002 w
.46437 .82631 m .47714 .83091 L p
.48201 .83063 L 1 g
F P
s
P
p
.48758 .82869 m .46355 .8261 L .47463 .82888 L 1 g
F
P
p
.002 w
.4533 .82232 m .45678 .82441 L p
.46355 .8261 L 1 g
F P
s
P
p
.002 w
.46355 .8261 m .46403 .82325 L p
.46202 .82546 L 1 g
F P
s
P
p
.002 w
.46437 .82631 m .46202 .82546 L p
.46355 .8261 L 1 g
F P
s
P
p
.002 w
.46202 .82546 m .4533 .82232 L p
.46355 .8261 L 1 g
F P
s
P
p
.46403 .82325 m .45118 .82035 L .46202 .82546 L 1 g
F
P
p
.002 w
.4533 .82232 m .45204 .82088 L p
.44353 .8156 L 1 g
F P
s
P
p
.002 w
.44237 .81488 m .44376 .81582 L p
.44353 .8156 L 1 g
F P
s
P
p
.002 w
.44376 .81582 m .4533 .82232 L p
.44353 .8156 L 1 g
F P
s
P
p
.002 w
.44353 .8156 m .44427 .81291 L p
.43599 .80818 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.42298 .80168 m .44237 .81488 L p
.44176 .81385 L 1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42934 .80164 L p
1 g
F P
s
P
p
.44427 .81291 m .42934 .80164 L .43599 .80818 L 1 g
F
P
p
.002 w
.39461 .77554 m .42298 .80168 L .42866 .80031 L p
1 g
F P
s
P
p
.43042 .79874 m .42586 .79243 L .42595 .7927 L 1 g
F
P
p
.39461 .77554 m .42866 .80031 L .42695 .79551 L 1 g
F
P
p
.002 w
.42934 .80164 m .43042 .79874 L p
.42595 .7927 L 1 g
F P
s
P
p
.002 w
.41439 .77064 m .39461 .77554 L p
.42239 .79269 L 1 g
F P
s
P
p
.42239 .79269 m .42695 .79551 L .4228 .78728 L 1 g
F
P
p
.42239 .79269 m .4228 .78728 L .41439 .77064 L 1 g
F
P
p
.002 w
.42301 .78443 m .424 .78222 L p
.42385 .77531 L 1 g
F P
s
P
p
.002 w
.41439 .77064 m .42305 .78394 L p
.42351 .77899 L 1 g
F P
s
P
p
.42385 .77531 m .42305 .78394 L .42301 .78443 L 1 g
F
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.4243 .77042 m .41439 .77064 L p
.42351 .77899 L 1 g
F P
s
P
p
.002 w
.424 .78222 m .42579 .76511 L .42476 .76723 L p
1 g
F P
s
P
p
.002 w
.39805 .73726 m .41439 .77064 L .4243 .77042 L p
1 g
F P
s
P
p
.39805 .73726 m .42345 .76934 L .42586 .75964 L 1 g
F
P
p
.42345 .76934 m .4243 .77042 L .42476 .76723 L 1 g
F
P
p
.42345 .76934 m .42476 .76723 L .42586 .75964 L 1 g
F
P
p
.002 w
.42476 .76723 m .42372 .76938 L p
.42382 .7738 L 1 g
F P
s
P
p
.424 .78222 m .42476 .76723 L .42382 .7738 L 1 g
F
P
p
.002 w
.42476 .76723 m .42579 .76511 L p
.42965 .75939 L 1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.4243 .77042 m .43886 .77011 L p
.42828 .76159 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43486 .75104 L p
1 g
F P
s
P
p
.42579 .76511 m .43486 .75104 L .42965 .75939 L 1 g
F
P
p
.42586 .75964 m .42476 .76723 L .42828 .76159 L 1 g
F
P
p
.42476 .76723 m .4243 .77042 L .42828 .76159 L 1 g
F
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43403 .73636 m .39805 .73726 L p
.42427 .75837 L 1 g
F P
s
P
p
.002 w
.43886 .77011 m .43602 .75024 L p
.42427 .75837 L 1 g
F P
s
P
p
.002 w
.43486 .75104 m .43569 .74928 L p
.44336 .74471 L 1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43886 .77011 m .46527 .77403 L p
.44188 .74583 L 1 g
F P
s
P
p
.002 w
.43602 .75024 m .43886 .77011 L p
.44188 .74583 L 1 g
F P
s
P
p
.44336 .74471 m .43602 .75024 L .43486 .75104 L 1 g
F
P
p
.002 w
.46527 .77403 m .47295 .74211 L .45111 .73888 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.44188 .74583 m .46527 .77403 L .45111 .73888 L 1 g
F
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45206 .73811 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.45111 .73888 m .47295 .74211 L p
.46456 .73343 L 1 g
F P
s
P
p
.002 w
.45206 .73811 m .45268 .73647 L p
.46276 .73411 L 1 g
F P
s
P
p
.45206 .73811 m .45111 .73888 L .46456 .73343 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47461 .72967 L p
1 g
F P
s
P
p
.45268 .73647 m .47461 .72967 L .46276 .73411 L 1 g
F
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.48147 .70615 m .43105 .69876 L p
.46163 .73039 L 1 g
F P
s
P
p
.002 w
.47295 .74211 m .47591 .7296 L p
.46163 .73039 L 1 g
F P
s
P
p
.002 w
.47461 .72967 m .47494 .72815 L p
.48549 .72828 L 1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54778 .73769 L p
1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54186 .77023 m .56326 .74978 L p
.53254 .73229 L 1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56514 .75105 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56326 .74978 m .54186 .77023 L p
.56743 .75468 L 1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57691 .78427 L p
1 g
F P
s
P
p
.002 w
.59903 .76762 m .57835 .78044 L p
.57805 .80298 L 1 g
F P
s
P
p
.002 w
.57835 .78044 m .57674 .78144 L p
.57691 .78427 L 1 g
F P
s
P
p
.57835 .78044 m .57691 .78427 L .57805 .80298 L 1 g
F
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .5564 .81533 L p
1 g
F P
s
P
p
.002 w
.57236 .82694 m .57451 .80895 L p
.5444 .82548 L 1 g
F P
s
P
p
.56958 .79874 m .5564 .81533 L .55927 .81289 L 1 g
F
P
p
.002 w
.55927 .81289 m .56593 .81117 L p
.57045 .80134 L 1 g
F P
s
P
p
.002 w
.56593 .81117 m .57451 .80895 L .57047 .80138 L p
1 g
F P
s
P
p
.002 w
.57047 .80138 m .57045 .80134 L p
.56593 .81117 L 1 g
F P
s
P
p
.57805 .80298 m .57207 .79714 L .57451 .80895 L 1 g
F
P
p
.002 w
.576 .78222 m .56958 .79874 L .57052 .80126 L p
1 g
F P
s
P
p
.576 .78222 m .57052 .80126 L .57055 .80116 L 1 g
F
P
p
.002 w
.57047 .80138 m .57451 .80895 L p
.57241 .79879 L 1 g
F P
s
P
p
.57207 .79714 m .57052 .80126 L .57241 .79879 L 1 g
F
P
p
.57052 .80126 m .57047 .80138 L .57241 .79879 L 1 g
F
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.5444 .82548 m .54228 .82412 L .53338 .83152 L 1 g
F
P
p
.54228 .82412 m .53647 .82622 L .53338 .83152 L 1 g
F
P
p
.002 w
.53384 .82718 m .53378 .82769 L p
.53647 .82622 L 1 g
F P
s
P
p
.002 w
.53378 .82769 m .53338 .83152 L p
.53647 .82622 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53647 .82622 L p
1 g
F P
s
P
p
.55573 .81291 m .53647 .82622 L .54683 .82056 L 1 g
F
P
p
.51242 .82869 m .48739 .83195 L .49525 .83275 L 1 g
F
P
p
.002 w
.49331 .82998 m .49107 .83232 L p
.51258 .83143 L 1 g
F P
s
P
p
.002 w
.52139 .83106 m .51602 .83085 L p
.51258 .83143 L 1 g
F P
s
P
p
.002 w
.51602 .83085 m .49331 .82998 L p
.51258 .83143 L 1 g
F P
s
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53667 .8274 L p
1 g
F P
s
P
p
.002 w
.53667 .8274 m .53597 .82325 L p
.52277 .82972 L 1 g
F P
s
P
p
.52277 .82972 m .51276 .83464 L .53667 .8274 L 1 g
F
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.53466 .81927 m .53384 .82718 L p
.54228 .82412 L 1 g
F P
s
P
p
.002 w
.5564 .81533 m .55573 .81291 L p
.54683 .82056 L 1 g
F P
s
P
p
.002 w
.55927 .81289 m .53466 .81927 L p
.54137 .82354 L 1 g
F P
s
P
p
.5564 .81533 m .54137 .82354 L .5444 .82548 L 1 g
F
P
p
.55927 .81289 m .54137 .82354 L .5564 .81533 L 1 g
F
P
p
.002 w
.57451 .80895 m .55927 .81289 L p
.5444 .82548 L 1 g
F P
s
P
p
.002 w
.53695 .82905 m .55726 .81844 L .5564 .81533 L p
1 g
F P
s
P
p
.54683 .82056 m .53695 .82905 L .5564 .81533 L 1 g
F
P
p
.002 w
.53647 .82622 m .53695 .82905 L p
.54683 .82056 L 1 g
F P
s
P
p
.002 w
.53695 .82905 m .51392 .83437 L p
.5131 .84059 L 1 g
F P
s
P
p
.002 w
.51392 .83437 m .51276 .83464 L .51277 .83478 L p
1 g
F P
s
P
p
.002 w
.51277 .83478 m .5131 .84059 L p
.51392 .83437 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .55761 .81808 L p
.56252 .81014 L 1 g
F P
s
P
p
.56958 .79874 m .56237 .81028 L .56252 .81014 L 1 g
F
P
p
.56237 .81028 m .55726 .81844 L .56252 .81014 L 1 g
F
P
p
.002 w
.57052 .80126 m .56958 .79874 L p
.55761 .81808 L 1 g
F P
s
P
p
.576 .78222 m .57055 .80116 L .57394 .79217 L 1 g
F
P
p
.002 w
.57691 .78427 m .576 .78222 L p
.57394 .79217 L 1 g
F P
s
P
p
.57421 .76511 m .57691 .78427 L .57674 .78144 L 1 g
F
P
p
.002 w
.59903 .76762 m .57207 .74405 L p
.57487 .76647 L 1 g
F P
s
P
p
.002 w
.57674 .78144 m .58218 .77807 L p
.57487 .76647 L 1 g
F P
s
P
p
.002 w
.58218 .77807 m .59903 .76762 L p
.57487 .76647 L 1 g
F P
s
P
p
.57421 .76511 m .57674 .78144 L .57584 .77425 L 1 g
F
P
p
.002 w
.56514 .75105 m .56431 .74928 L p
.56915 .7574 L 1 g
F P
s
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57487 .76647 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.56404 .78932 m .57674 .78144 L p
.57419 .76539 L 1 g
F P
s
P
p
.56431 .74928 m .57487 .76647 L .56915 .7574 L 1 g
F
P
p
.57059 .74276 m .56864 .7566 L .57419 .76539 L 1 g
F
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.56864 .7566 m .56404 .78932 L .57419 .76539 L 1 g
F
P
p
.002 w
.57207 .74405 m .57059 .74276 L p
.57674 .78144 L 1 g
F P
s
P
p
.56326 .74978 m .56743 .75468 L .56514 .75105 L 1 g
F
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.54186 .77023 m .56404 .78932 L p
.56905 .75369 L 1 g
F P
s
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56514 .75105 L p
1 g
F P
s
P
p
.56915 .7574 m .57628 .76938 L .56514 .75105 L 1 g
F
P
p
.57584 .77425 m .57674 .78144 L .57654 .77818 L 1 g
F
P
p
.002 w
.57674 .78144 m .56404 .78932 L p
.57805 .80298 L 1 g
F P
s
P
p
.57394 .79217 m .57052 .80127 L .57329 .79532 L 1 g
F
P
p
.57055 .80116 m .57052 .80127 L .57394 .79217 L 1 g
F
P
p
.56958 .79874 m .55927 .81289 L .56339 .80864 L 1 g
F
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56404 .78932 m .57047 .80138 L p
.57207 .79714 L 1 g
F P
s
P
p
.002 w
.55761 .81808 m .5715 .8039 L .57052 .80126 L p
1 g
F P
s
P
p
.002 w
.57052 .80126 m .57052 .80127 L p
.57055 .80116 L 1 g
F P
s
P
p
.002 w
.57052 .80127 m .5715 .8039 L p
.57329 .79532 L 1 g
F P
s
P
p
.56339 .80864 m .55927 .81289 L .56237 .81028 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53466 .81927 m .55927 .81289 L p
.56404 .78932 L 1 g
F P
s
P
p
.002 w
.57045 .80134 m .56404 .78932 L p
.55927 .81289 L 1 g
F P
s
P
p
.002 w
.5564 .81533 m .55726 .81844 L p
.56237 .81028 L 1 g
F P
s
P
p
.002 w
.53338 .83152 m .53788 .83099 L p
.5444 .82548 L 1 g
F P
s
P
p
.002 w
.53788 .83099 m .57236 .82694 L p
.5444 .82548 L 1 g
F P
s
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57691 .78427 L p
1 g
F P
s
P
p
.57394 .79217 m .5715 .8039 L .57691 .78427 L 1 g
F
P
p
.002 w
.57691 .78427 m .57811 .78694 L p
.57654 .77818 L 1 g
F P
s
P
p
.56514 .75105 m .56743 .75468 L .56905 .75369 L 1 g
F
P
p
.002 w
.57487 .76647 m .57628 .76938 L p
.56915 .7574 L 1 g
F P
s
P
p
.002 w
.56514 .75105 m .56529 .75136 L p
.56389 .7502 L 1 g
F P
s
P
p
.54732 .73647 m .56514 .75105 L .56389 .7502 L 1 g
F
P
p
.54732 .73647 m .56529 .75136 L .55551 .74373 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.57059 .74276 m .56326 .74978 L p
.56905 .75369 L 1 g
F P
s
P
p
.53254 .73229 m .56326 .74978 L .54778 .73769 L 1 g
F
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54778 .73769 L p
1 g
F P
s
P
p
.002 w
.54778 .73769 m .54732 .73647 L p
.55551 .74373 L 1 g
F P
s
P
p
.55551 .74373 m .56611 .75311 L .54778 .73769 L 1 g
F
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.56829 .74496 m .57059 .74276 L p
.5454 .73583 L 1 g
F P
s
P
p
.52506 .72815 m .54778 .73769 L .53524 .73325 L 1 g
F
P
p
.002 w
.54864 .73996 m .54563 .73884 L p
.53409 .73284 L 1 g
F P
s
P
p
.52506 .72815 m .53524 .73325 L .53409 .73284 L 1 g
F
P
p
.53524 .73325 m .54864 .73996 L .53409 .73284 L 1 g
F
P
p
.002 w
.51032 .75386 m .54186 .77023 L p
.53254 .73229 L 1 g
F P
s
P
p
.53065 .73162 m .51032 .75386 L .53254 .73229 L 1 g
F
P
p
.002 w
.52541 .72976 m .52506 .72815 L p
.53409 .73284 L 1 g
F P
s
P
p
.002 w
.52486 .72973 m .51032 .75386 L p
.53201 .73013 L 1 g
F P
s
P
p
.002 w
.52542 .72981 m .52541 .72976 L p
.54563 .73884 L 1 g
F P
s
P
p
.53409 .73284 m .54563 .73884 L .52541 .72976 L 1 g
F
P
p
.002 w
.5 .72527 m .52506 .72815 L .52541 .72976 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.52987 .72143 m .52494 .7296 L p
.53201 .73013 L 1 g
F P
s
P
p
.002 w
.52494 .7296 m .52486 .72973 L p
.52541 .72976 L 1 g
F P
s
P
p
.52494 .7296 m .52541 .72976 L .53201 .73013 L 1 g
F
P
p
.53201 .73013 m .53065 .73162 L .53254 .73229 L 1 g
F
P
p
.002 w
.52541 .72976 m .52542 .72981 L p
.52504 .72974 L 1 g
F P
s
P
p
.5 .72527 m .52541 .72976 L .52504 .72974 L 1 g
F
P
p
.002 w
.51032 .75386 m .52486 .72973 L p
.49413 .72708 L 1 g
F P
s
P
p
.49413 .72708 m .52486 .72973 L .52241 .72939 L 1 g
F
P
p
.5 .72527 m .52542 .72981 L .51011 .72768 L 1 g
F
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.5 .72627 m .5 .72527 L p
.51011 .72768 L 1 g
F P
s
P
p
.5 .72627 m .52494 .7296 L .51334 .72442 L 1 g
F
P
p
.49413 .72708 m .52241 .72939 L .5 .72627 L 1 g
F
P
p
.52241 .72939 m .52494 .7296 L .5 .72627 L 1 g
F
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72627 L p
1 g
F P
s
P
p
.51011 .72768 m .52576 .73141 L .5 .72627 L 1 g
F
P
p
.002 w
.52542 .72981 m .52576 .73141 L p
.51011 .72768 L 1 g
F P
s
P
p
.002 w
.52486 .72973 m .52494 .7296 L p
.52241 .72939 L 1 g
F P
s
P
p
.002 w
.52494 .7296 m .52941 .7222 L p
.51334 .72442 L 1 g
F P
s
P
p
.002 w
.54563 .73884 m .52576 .73141 L .52542 .72981 L p
1 g
F P
s
P
p
.53254 .73229 m .54778 .73769 L .5454 .73583 L 1 g
F
P
p
.54778 .73769 m .56829 .74496 L .5454 .73583 L 1 g
F
P
p
.002 w
.56326 .74978 m .56829 .74496 L p
.54778 .73769 L 1 g
F P
s
P
p
.002 w
.56529 .75136 m .56611 .75311 L p
.55551 .74373 L 1 g
F P
s
P
p
.002 w
.54778 .73769 m .54864 .73996 L p
.53524 .73325 L 1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.57059 .74276 m .52987 .72143 L p
.53254 .73229 L 1 g
F P
s
P
p
.48549 .72828 m .47591 .7296 L .47461 .72967 L 1 g
F
P
p
.002 w
.47295 .74211 m .51032 .75386 L p
.49413 .72708 L 1 g
F P
s
P
p
.002 w
.47591 .7296 m .47295 .74211 L p
.49413 .72708 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.48147 .70615 m .47591 .7296 L p
.49413 .72708 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47459 .72979 L p
1 g
F P
s
P
p
.002 w
.47459 .72979 m .47461 .72967 L p
.47581 .72962 L 1 g
F P
s
P
p
.47581 .72962 m .5 .72845 L .47459 .72979 L 1 g
F
P
p
.48549 .72828 m .49729 .72842 L .47591 .7296 L 1 g
F
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.52987 .72143 m .48147 .70615 L p
.49413 .72708 L 1 g
F P
s
P
p
.002 w
.52941 .7222 m .52987 .72143 L p
.49413 .72708 L 1 g
F P
s
P
p
.002 w
.47591 .7296 m .48147 .70615 L p
.46163 .73039 L 1 g
F P
s
P
p
.49729 .72842 m .5 .72845 L .47461 .72967 L 1 g
F
P
p
.002 w
.47461 .72967 m .47424 .73141 L p
.46276 .73411 L 1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.43105 .69876 m .45094 .73853 L .46156 .73033 L 1 g
F
P
p
.43569 .74928 m .45206 .73811 L .44568 .74333 L 1 g
F
P
p
.45094 .73853 m .45111 .73888 L .45206 .73811 L 1 g
F
P
p
.45094 .73853 m .45206 .73811 L .46156 .73033 L 1 g
F
P
p
.46156 .73033 m .45206 .73811 L .46456 .73343 L 1 g
F
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45206 .73811 L p
1 g
F P
s
P
p
.46276 .73411 m .47424 .73141 L .45206 .73811 L 1 g
F
P
p
.002 w
.45206 .73811 m .45136 .73996 L p
.44568 .74333 L 1 g
F P
s
P
p
.002 w
.43105 .69876 m .43403 .73636 L .45111 .73888 L p
1 g
F P
s
P
p
.002 w
.45111 .73888 m .43403 .73636 L p
.44188 .74583 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43481 .75114 L p
1 g
F P
s
P
p
.002 w
.43481 .75114 m .43486 .75104 L p
.43572 .75046 L 1 g
F P
s
P
p
.43572 .75046 m .45136 .73996 L .43481 .75114 L 1 g
F
P
p
.44336 .74471 m .44783 .74206 L .43602 .75024 L 1 g
F
P
p
.002 w
.43403 .73636 m .43602 .75024 L p
.44188 .74583 L 1 g
F P
s
P
p
.002 w
.43602 .75024 m .43403 .73636 L p
.42427 .75837 L 1 g
F P
s
P
p
.44783 .74206 m .45136 .73996 L .43486 .75104 L 1 g
F
P
p
.002 w
.43486 .75104 m .43389 .75311 L p
.42965 .75939 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42476 .76723 L p
1 g
F P
s
P
p
.42965 .75939 m .43389 .75311 L .42476 .76723 L 1 g
F
P
p
.002 w
.44536 .79902 m .43886 .77011 L .4243 .77042 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.42351 .77899 m .44536 .79902 L .4243 .77042 L 1 g
F
P
p
.42595 .7927 m .42866 .80031 L .42934 .80164 L 1 g
F
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.42258 .78323 m .41439 .77064 L p
.42695 .79551 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.43301 .79925 m .42305 .78394 L p
.42695 .79551 L 1 g
F P
s
P
p
.002 w
.42305 .78394 m .42258 .78323 L p
.42301 .78443 L 1 g
F P
s
P
p
.42695 .79551 m .42305 .78394 L .42301 .78443 L 1 g
F
P
p
.002 w
.42372 .76938 m .42189 .78694 L .423 .78446 L p
1 g
F P
s
P
p
.002 w
.423 .78446 m .42301 .78443 L p
.42302 .78425 L 1 g
F P
s
P
p
.42302 .78425 m .42372 .76938 L .423 .78446 L 1 g
F
P
p
.42385 .77531 m .42382 .77377 L .42305 .78394 L 1 g
F
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.43301 .79925 m .44536 .79902 L p
.42351 .77899 L 1 g
F P
s
P
p
.002 w
.42305 .78394 m .43301 .79925 L p
.42351 .77899 L 1 g
F P
s
P
p
.42382 .77377 m .42372 .76938 L .42301 .78443 L 1 g
F
P
p
.42595 .7927 m .4221 .78749 L .42866 .80031 L 1 g
F
P
p
.002 w
.42866 .80031 m .43301 .79925 L p
.42695 .79551 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4221 .78749 L p
.42595 .7927 L 1 g
F P
s
P
p
.42586 .79243 m .42189 .78694 L .42595 .7927 L 1 g
F
P
p
.002 w
.42866 .80031 m .42812 .80044 L p
.42934 .80164 L 1 g
F P
s
P
p
.002 w
.42812 .80044 m .42298 .80168 L p
.44176 .81385 L 1 g
F P
s
P
p
.002 w
.4221 .78749 m .4285 .8039 L .42934 .80164 L p
1 g
F P
s
P
p
.002 w
.43301 .79925 m .42866 .80031 L p
.44176 .81385 L 1 g
F P
s
P
p
.42934 .80164 m .44176 .81385 L .42866 .80031 L 1 g
F
P
p
.002 w
.42934 .80164 m .4285 .8039 L p
.43599 .80818 L 1 g
F P
s
P
p
.45118 .82035 m .45204 .82088 L .46202 .82546 L 1 g
F
P
p
.002 w
.45204 .82088 m .4533 .82232 L .45302 .82147 L p
1 g
F P
s
P
p
.45204 .82088 m .45265 .82126 L .45271 .82129 L 1 g
F
P
p
.45204 .82088 m .45271 .82129 L .46202 .82546 L 1 g
F
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.41635 .80601 m .41383 .81177 L .44942 .82128 L p
1 g
F P
s
P
p
.002 w
.44942 .82128 m .4533 .82232 L .44807 .82001 L p
1 g
F P
s
P
p
.002 w
.44807 .82001 m .41635 .80601 L p
.44942 .82128 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44353 .8156 L p
1 g
F P
s
P
p
.002 w
.41635 .80601 m .4533 .82232 L .44237 .81488 L p
1 g
F P
s
P
p
.002 w
.44237 .81488 m .42298 .80168 L .42211 .80225 L p
1 g
F P
s
P
p
.002 w
.42211 .80225 m .41635 .80601 L p
.44237 .81488 L 1 g
F P
s
P
p
.002 w
.44353 .8156 m .44353 .8156 L p
.45118 .82035 L 1 g
F P
s
P
p
.002 w
.44353 .8156 m .44274 .81844 L p
.45113 .82033 L 1 g
F P
s
P
p
.45118 .82035 m .44353 .8156 L .45113 .82033 L 1 g
F
P
p
.46403 .82325 m .44353 .8156 L .45118 .82035 L 1 g
F
P
p
.002 w
.45204 .82088 m .43301 .79925 L p
.44176 .81385 L 1 g
F P
s
P
p
.44237 .81488 m .44353 .8156 L .44176 .81385 L 1 g
F
P
p
.44353 .8156 m .45204 .82088 L .44176 .81385 L 1 g
F
P
p
.002 w
.4285 .8039 m .44274 .81844 L .4435 .8157 L p
1 g
F P
s
P
p
.002 w
.4435 .8157 m .44353 .8156 L p
.44272 .81497 L 1 g
F P
s
P
p
.44272 .81497 m .4285 .8039 L .4435 .8157 L 1 g
F
P
p
.002 w
.44536 .79902 m .43301 .79925 L .45204 .82088 L p
1 g
F P
s
P
p
.45265 .82126 m .45311 .82153 L .46202 .82546 L 1 g
F
P
p
.002 w
.45302 .82147 m .44536 .79902 L p
.45204 .82088 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.45866 .80101 m .44536 .79902 L .45302 .82147 L p
1 g
F P
s
P
p
.002 w
.45302 .82147 m .4533 .82232 L .45345 .82173 L p
1 g
F P
s
P
p
.45301 .82149 m .4534 .8217 L .46202 .82546 L 1 g
F
P
p
.45326 .82164 m .45366 .82185 L .46202 .82546 L 1 g
F
P
p
.002 w
.45345 .82173 m .45866 .80101 L p
.45302 .82147 L 1 g
F P
s
P
p
.45265 .82126 m .45301 .82149 L .45311 .82153 L 1 g
F
P
p
.45301 .82149 m .45326 .82164 L .4534 .8217 L 1 g
F
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.47146 .805 m .45866 .80101 L .45345 .82173 L p
1 g
F P
s
P
p
.002 w
.45345 .82173 m .4533 .82232 L .45375 .82189 L p
1 g
F P
s
P
p
.45345 .82175 m .45387 .82196 L .46202 .82546 L 1 g
F
P
p
.002 w
.45375 .82189 m .47146 .805 L p
.45345 .82173 L 1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.48232 .81055 m .47146 .805 L .45375 .82189 L p
1 g
F P
s
P
p
.002 w
.45375 .82189 m .4533 .82232 L .45401 .82203 L p
1 g
F P
s
P
p
.45342 .82177 m .45564 .82277 L .46202 .82546 L 1 g
F
P
p
.44893 .81984 m .45473 .82237 L .45342 .82177 L 1 g
F
P
p
.45473 .82237 m .45564 .82277 L .45342 .82177 L 1 g
F
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.49385 .82377 m .49006 .81705 L .45431 .82217 L p
1 g
F P
s
P
p
.002 w
.45431 .82217 m .4533 .82232 L .45473 .82237 L p
1 g
F P
s
P
p
.002 w
.45473 .82237 m .49385 .82377 L p
.45431 .82217 L 1 g
F P
s
P
p
.002 w
.45401 .82203 m .48232 .81055 L p
.45375 .82189 L 1 g
F P
s
P
p
.45326 .82164 m .45345 .82175 L .45366 .82185 L 1 g
F
P
p
.45345 .82175 m .45357 .82183 L .45387 .82196 L 1 g
F
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.49006 .81705 m .48232 .81055 L .45401 .82203 L p
1 g
F P
s
P
p
.002 w
.45401 .82203 m .4533 .82232 L .45431 .82217 L p
1 g
F P
s
P
p
.002 w
.45431 .82217 m .49006 .81705 L p
.45401 .82203 L 1 g
F P
s
P
p
.43599 .80818 m .4285 .8039 L .44353 .8156 L 1 g
F
P
p
.45118 .82035 m .44893 .81984 L .45357 .82183 L 1 g
F
P
p
.002 w
.49331 .82998 m .49385 .82377 L .45473 .82237 L p
1 g
F P
s
P
p
.002 w
.45473 .82237 m .4533 .82232 L .45564 .82277 L p
1 g
F P
s
P
p
.002 w
.45564 .82277 m .49331 .82998 L p
.45473 .82237 L 1 g
F P
s
P
p
.44893 .81984 m .44847 .81973 L .45564 .82277 L 1 g
F
P
p
.002 w
.46355 .82611 m .46355 .8261 L p
.46202 .82546 L 1 g
F P
s
P
p
.002 w
.45678 .82441 m .48001 .83834 L p
.46437 .82631 L 1 g
F P
s
P
p
.002 w
.45678 .82441 m .4533 .82232 L .45467 .82384 L p
1 g
F P
s
P
p
.002 w
.45467 .82384 m .46874 .83961 L p
.45678 .82441 L 1 g
F P
s
P
p
.002 w
.43101 .83097 m .4533 .82232 L .4216 .82496 L closepath p
1 g
F P
s
P
p
.002 w
.4216 .82496 m .4533 .82232 L .41565 .81833 L closepath p
1 g
F P
s
P
p
.002 w
.41565 .81833 m .4533 .82232 L .41383 .81177 L closepath p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46355 .82611 L p
1 g
F P
s
P
p
.002 w
.45564 .82277 m .4533 .82232 L .46202 .82546 L p
1 g
F P
s
P
p
.44847 .81973 m .44274 .81844 L .46355 .82611 L 1 g
F
P
p
.002 w
.49331 .82998 m .45564 .82277 L p
.46437 .82631 L 1 g
F P
s
P
p
.002 w
.46202 .82546 m .46437 .82631 L p
.45564 .82277 L 1 g
F P
s
P
p
.49331 .82998 m .46437 .82631 L .48201 .83063 L 1 g
F
P
p
.002 w
.47714 .83091 m .46437 .82631 L p
.46917 .83 L 1 g
F P
s
P
p
.47463 .82888 m .46437 .82631 L .46305 .82905 L 1 g
F
P
p
.002 w
.46355 .8261 m .46355 .82611 L p
.46437 .82631 L 1 g
F P
s
P
p
.002 w
.46355 .82611 m .46305 .82905 L p
.46437 .82631 L 1 g
F P
s
P
p
.002 w
.49107 .83232 m .49331 .82998 L p
.47714 .83091 L 1 g
F P
s
P
p
.002 w
.48736 .8325 m .48739 .83195 L p
.47373 .82889 L 1 g
F P
s
P
p
.47486 .82888 m .47373 .82889 L .48739 .83195 L 1 g
F
P
p
.002 w
.48739 .83195 m .48724 .83464 L p
.49525 .83275 L 1 g
F P
s
P
p
.002 w
.49331 .82998 m .51602 .83085 L p
.53466 .81927 L 1 g
F P
s
P
p
.002 w
.53384 .82718 m .53466 .81927 L p
.51602 .83085 L 1 g
F P
s
P
p
.002 w
.51258 .83143 m .51276 .83464 L p
.52277 .82972 L 1 g
F P
s
P
p
.49338 .83464 m .49778 .8339 L .48851 .83501 L 1 g
F
P
p
.002 w
.51276 .83464 m .51258 .83143 L p
.49458 .8329 L 1 g
F P
s
P
p
.49832 .83202 m .49458 .8329 L .51258 .83143 L 1 g
F
P
p
.002 w
.48724 .83464 m .50977 .83464 L p
.49458 .8329 L 1 g
F P
s
P
p
.002 w
.50977 .83464 m .51276 .83464 L p
.49458 .8329 L 1 g
F P
s
P
p
.47714 .83091 m .46917 .83 L .48001 .83834 L 1 g
F
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48736 .8325 L p
1 g
F P
s
P
p
.47373 .82889 m .46305 .82905 L .48736 .8325 L 1 g
F
P
p
.004 w
.47915 .70579 m
.5 .6118 L
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.67696 .74698 m .70212 .71809 L .68366 .67922 L p
1 g
F P
s
P
p
.002 w
.70228 .64499 m .68366 .67922 L .70212 .71809 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.004 w
.46298 .77868 m
.46405 .77385 L
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.61223 .79311 m .57451 .80895 L .57236 .82694 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.31674 .633 m .30915 .59324 L .27396 .61983 L p
1 g
F P
s
P
p
.002 w
.27396 .61983 m .28438 .65692 L .31674 .633 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.61507 .41742 m .61759 .4391 L .67645 .47218 L p
1 g
F P
s
P
p
.002 w
.61759 .4391 m .61507 .41742 L .55097 .39642 L p
1 g
F P
s
P
p
.002 w
.38165 .78421 m .35025 .75755 L .34346 .7745 L p
1 g
F P
s
P
p
.002 w
.34346 .7745 m .37686 .79567 L .38165 .78421 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.54694 .41602 m .55097 .39642 L .48387 .3872 L p
1 g
F P
s
P
p
.002 w
.48387 .3872 m .47301 .40582 L .54694 .41602 L p
1 g
F P
s
P
p
.002 w
.67951 .501 m .67645 .47218 L .61759 .4391 L p
1 g
F P
s
P
p
.002 w
.71512 .61004 m .72186 .57542 L .67755 .53329 L p
1 g
F P
s
P
p
.002 w
.67951 .501 m .67755 .53329 L .72186 .57542 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.46277 .43052 m .47301 .40582 L .40476 .40964 L p
1 g
F P
s
P
p
.002 w
.40476 .40964 m .39015 .43442 L .46277 .43052 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.64672 .77224 m .67696 .74698 L .65975 .71172 L p
1 g
F P
s
P
p
.002 w
.68366 .67922 m .65975 .71172 L .67696 .74698 L p
1 g
F P
s
P
p
.002 w
.37012 .49904 m .37847 .46449 L .31874 .48274 L p
1 g
F P
s
P
p
.002 w
.31874 .48274 m .31022 .51698 L .37012 .49904 L p
1 g
F P
s
P
p
.002 w
.55097 .39642 m .54694 .41602 L .61759 .4391 L p
1 g
F P
s
P
p
.002 w
.41635 .80601 m .38165 .78421 L .37686 .79567 L p
1 g
F P
s
P
p
.002 w
.37686 .79567 m .41383 .81177 L .41635 .80601 L p
1 g
F P
s
P
p
.002 w
.32953 .67227 m .31674 .633 L .28438 .65692 L p
1 g
F P
s
P
p
.002 w
.28438 .65692 m .3009 .69294 L .32953 .67227 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.53466 .81927 m .49385 .82377 L .49331 .82998 L p
1 g
F P
s
P
p
.002 w
.61223 .79311 m .64672 .77224 L .63126 .74149 L p
1 g
F P
s
P
p
.002 w
.65975 .71172 m .63126 .74149 L .64672 .77224 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.70228 .64499 m .71512 .61004 L .67054 .56811 L p
1 g
F P
s
P
p
.002 w
.67755 .53329 m .67054 .56811 L .71512 .61004 L p
1 g
F P
s
P
p
.002 w
.34715 .70986 m .32953 .67227 L .3009 .69294 L p
1 g
F P
s
P
p
.002 w
.3009 .69294 m .32306 .72682 L .34715 .70986 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.57451 .80895 m .61223 .79311 L .59903 .76762 L p
1 g
F P
s
P
p
.002 w
.63126 .74149 m .59903 .76762 L .61223 .79311 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.3654 .53707 m .37012 .49904 L .31022 .51698 L p
1 g
F P
s
P
p
.002 w
.31022 .51698 m .30697 .55418 L .3654 .53707 L p
1 g
F P
s
P
p
.002 w
.49385 .82377 m .53466 .81927 L .52735 .80595 L p
1 g
F P
s
P
p
.002 w
.52735 .80595 m .49006 .81705 L .49385 .82377 L p
1 g
F P
s
P
p
.002 w
.38165 .78421 m .41635 .80601 L .42298 .80168 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.36907 .74463 m .34715 .70986 L .32306 .72682 L p
1 g
F P
s
P
p
.002 w
.32306 .72682 m .35025 .75755 L .36907 .74463 L p
1 g
F P
s
P
p
.002 w
.67755 .53329 m .67951 .501 L .61682 .46598 L p
1 g
F P
s
P
p
.002 w
.61759 .4391 m .61682 .46598 L .67951 .501 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56404 .78932 m .52735 .80595 L .53466 .81927 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.42298 .80168 m .39461 .77554 L .38165 .78421 L p
1 g
F P
s
P
p
.002 w
.35025 .75755 m .38165 .78421 L .39461 .77554 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.39461 .77554 m .36907 .74463 L .35025 .75755 L p
1 g
F P
s
P
p
.002 w
.61682 .46598 m .61759 .4391 L .54694 .41602 L p
1 g
F P
s
P
p
.002 w
.45346 .46067 m .46277 .43052 L .39015 .43442 L p
1 g
F P
s
P
p
.002 w
.39015 .43442 m .37847 .46449 L .45346 .46067 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.54154 .44145 m .54694 .41602 L .47301 .40582 L p
1 g
F P
s
P
p
.002 w
.47301 .40582 m .46277 .43052 L .54154 .44145 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.49006 .81705 m .52735 .80595 L .51214 .79304 L p
1 g
F P
s
P
p
.002 w
.51214 .79304 m .48232 .81055 L .49006 .81705 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.68366 .67922 m .70228 .64499 L .65862 .60445 L p
1 g
F P
s
P
p
.002 w
.67054 .56811 m .65862 .60445 L .70228 .64499 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.36449 .57744 m .3654 .53707 L .30697 .55418 L p
1 g
F P
s
P
p
.002 w
.30697 .55418 m .30915 .59324 L .36449 .57744 L p
1 g
F P
s
P
p
.002 w
.54694 .41602 m .54154 .44145 L .61682 .46598 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.48232 .81055 m .51214 .79304 L .49065 .78198 L p
1 g
F P
s
P
p
.002 w
.49065 .78198 m .47146 .805 L .48232 .81055 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.004 w
.42901 .93184 m
.43903 .88665 L
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.52735 .80595 m .56404 .78932 L .54186 .77023 L p
1 g
F P
s
P
p
.002 w
.54186 .77023 m .51214 .79304 L .52735 .80595 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.65975 .71172 m .68366 .67922 L .64212 .64121 L p
1 g
F P
s
P
p
.002 w
.65862 .60445 m .64212 .64121 L .68366 .67922 L p
1 g
F P
s
P
p
.002 w
.47146 .805 m .49065 .78198 L .46527 .77403 L p
1 g
F P
s
P
p
.002 w
.46527 .77403 m .45866 .80101 L .47146 .805 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.43886 .77011 m .44536 .79902 L .45866 .80101 L p
1 g
F P
s
P
p
.002 w
.36907 .74463 m .39461 .77554 L .41439 .77064 L p
1 g
F P
s
P
p
.002 w
.67054 .56811 m .67755 .53329 L .61273 .49732 L p
1 g
F P
s
P
p
.002 w
.61682 .46598 m .61273 .49732 L .67755 .53329 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.45866 .80101 m .46527 .77403 L .43886 .77011 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.36744 .61892 m .36449 .57744 L .30915 .59324 L p
1 g
F P
s
P
p
.002 w
.30915 .59324 m .31674 .633 L .36744 .61892 L p
1 g
F P
s
P
p
.002 w
.44539 .49545 m .45346 .46067 L .37847 .46449 L p
1 g
F P
s
P
p
.002 w
.37847 .46449 m .37012 .49904 L .44539 .49545 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.63126 .74149 m .65975 .71172 L .62151 .67725 L p
1 g
F P
s
P
p
.002 w
.64212 .64121 m .62151 .67725 L .65975 .71172 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.61273 .49732 m .61682 .46598 L .54154 .44145 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.41439 .77064 m .39805 .73726 L .36907 .74463 L p
1 g
F P
s
P
p
.002 w
.34715 .70986 m .36907 .74463 L .39805 .73726 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.53488 .47205 m .54154 .44145 L .46277 .43052 L p
1 g
F P
s
P
p
.002 w
.46277 .43052 m .45346 .46067 L .53488 .47205 L p
1 g
F P
s
P
p
.002 w
.59903 .76762 m .63126 .74149 L .59742 .71145 L p
1 g
F P
s
P
p
.002 w
.59742 .71145 m .57059 .74276 L .59903 .76762 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.62151 .67725 m .59742 .71145 L .63126 .74149 L p
1 g
F P
s
P
p
.002 w
.37418 .66023 m .36744 .61892 L .31674 .633 L p
1 g
F P
s
P
p
.002 w
.31674 .633 m .32953 .67227 L .37418 .66023 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.51214 .79304 m .54186 .77023 L .51032 .75386 L p
1 g
F P
s
P
p
.002 w
.51032 .75386 m .49065 .78198 L .51214 .79304 L p
1 g
F P
s
P
p
.002 w
.39805 .73726 m .3845 .70008 L .34715 .70986 L p
1 g
F P
s
P
p
.002 w
.32953 .67227 m .34715 .70986 L .3845 .70008 L p
1 g
F P
s
P
p
.002 w
.3845 .70008 m .37418 .66023 L .32953 .67227 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.65862 .60445 m .67054 .56811 L .60537 .53224 L p
1 g
F P
s
P
p
.002 w
.61273 .49732 m .60537 .53224 L .67054 .56811 L p
1 g
F P
s
P
p
.002 w
.54154 .44145 m .53488 .47205 L .61273 .49732 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43882 .53383 m .44539 .49545 L .37012 .49904 L p
1 g
F P
s
P
p
.002 w
.37012 .49904 m .3654 .53707 L .43882 .53383 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.49065 .78198 m .51032 .75386 L .47295 .74211 L p
1 g
F P
s
P
p
.002 w
.47295 .74211 m .46527 .77403 L .49065 .78198 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.3845 .70008 m .39805 .73726 L .43403 .73636 L p
1 g
F P
s
P
p
.002 w
.60537 .53224 m .61273 .49732 L .53488 .47205 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.64212 .64121 m .65862 .60445 L .59494 .56972 L p
1 g
F P
s
P
p
.002 w
.60537 .53224 m .59494 .56972 L .65862 .60445 L p
1 g
F P
s
P
p
.002 w
.52715 .50696 m .53488 .47205 L .45346 .46067 L p
1 g
F P
s
P
p
.002 w
.45346 .46067 m .44539 .49545 L .52715 .50696 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.43397 .57464 m .43882 .53383 L .3654 .53707 L p
1 g
F P
s
P
p
.002 w
.3654 .53707 m .36449 .57744 L .43397 .57464 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.57059 .74276 m .59742 .71145 L .54868 .68566 L p
1 g
F P
s
P
p
.002 w
.54868 .68566 m .52987 .72143 L .57059 .74276 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.43403 .73636 m .43105 .69876 L .3845 .70008 L p
1 g
F P
s
P
p
.002 w
.37418 .66023 m .3845 .70008 L .43105 .69876 L p
1 g
F P
s
P
p
.002 w
.62151 .67725 m .64212 .64121 L .58174 .60859 L p
1 g
F P
s
P
p
.002 w
.59494 .56972 m .58174 .60859 L .64212 .64121 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.53488 .47205 m .52715 .50696 L .60537 .53224 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.43101 .61662 m .43397 .57464 L .36449 .57744 L p
1 g
F P
s
P
p
.002 w
.36449 .57744 m .36744 .61892 L .43101 .61662 L p
1 g
F P
s
P
p
.002 w
.59742 .71145 m .62151 .67725 L .56615 .64765 L p
1 g
F P
s
P
p
.002 w
.56615 .64765 m .54868 .68566 L .59742 .71145 L p
1 g
F P
s
P
p
.002 w
.58174 .60859 m .56615 .64765 L .62151 .67725 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.43105 .69876 m .43002 .65843 L .37418 .66023 L p
1 g
F P
s
P
p
.002 w
.36744 .61892 m .37418 .66023 L .43002 .65843 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.43002 .65843 m .43101 .61662 L .36744 .61892 L p
1 g
F P
s
P
p
.002 w
.59494 .56972 m .60537 .53224 L .52715 .50696 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.51858 .54515 m .52715 .50696 L .44539 .49545 L p
1 g
F P
s
P
p
.002 w
.44539 .49545 m .43882 .53383 L .51858 .54515 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52987 .72143 m .54868 .68566 L .49059 .66723 L p
1 g
F P
s
P
p
.002 w
.49059 .66723 m .48147 .70615 L .52987 .72143 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.43002 .65843 m .43105 .69876 L .48147 .70615 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.52715 .50696 m .51858 .54515 L .59494 .56972 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.58174 .60859 m .59494 .56972 L .51858 .54515 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.50944 .58544 m .51858 .54515 L .43882 .53383 L p
1 g
F P
s
P
p
.002 w
.43882 .53383 m .43397 .57464 L .50944 .58544 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.48147 .70615 m .49059 .66723 L .43002 .65843 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.54868 .68566 m .56615 .64765 L .50001 .62657 L p
1 g
F P
s
P
p
.002 w
.50001 .62657 m .49059 .66723 L .54868 .68566 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.43101 .61662 m .43002 .65843 L .49059 .66723 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.56615 .64765 m .58174 .60859 L .50944 .58544 L p
1 g
F P
s
P
p
.002 w
.51858 .54515 m .50944 .58544 L .58174 .60859 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.50001 .62657 m .50944 .58544 L .43397 .57464 L p
1 g
F P
s
P
p
.002 w
.43397 .57464 m .43101 .61662 L .50001 .62657 L p
1 g
F P
s
P
p
.002 w
.50944 .58544 m .50001 .62657 L .56615 .64765 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.49059 .66723 m .50001 .62657 L .43101 .61662 L p
1 g
F P
s
P
p
.004 w
.42928 .64193 m
.45291 .63187 L
s
P
p
.004 w
.45291 .63187 m
.45465 .63113 L
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .42928 .64193 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .42901 .93184 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.35)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.35)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.42211 .59461 m .44542 .56451 L .49171 .59408 L p
1 g
F P
s
P
p
.002 w
.49171 .59408 m .47486 .62819 L .42211 .59461 L p
1 g
F P
s
P
p
.002 w
.5088 .5604 m .49171 .59408 L .44542 .56451 L p
1 g
F P
s
P
p
.002 w
.47486 .62819 m .49171 .59408 L .54397 .61347 L p
1 g
F P
s
P
p
.002 w
.49171 .59408 m .5088 .5604 L .55247 .57658 L p
1 g
F P
s
P
p
.002 w
.55247 .57658 m .54397 .61347 L .49171 .59408 L p
1 g
F P
s
P
p
.002 w
.40077 .62524 m .42211 .59461 L .47486 .62819 L p
1 g
F P
s
P
p
.002 w
.47486 .62819 m .45863 .66193 L .40077 .62524 L p
1 g
F P
s
P
p
.002 w
.45863 .66193 m .47486 .62819 L .53432 .65029 L p
1 g
F P
s
P
p
.002 w
.54397 .61347 m .53432 .65029 L .47486 .62819 L p
1 g
F P
s
P
p
.002 w
.53432 .65029 m .54397 .61347 L .59697 .62073 L p
1 g
F P
s
P
p
.002 w
.54397 .61347 m .55247 .57658 L .59677 .58253 L p
1 g
F P
s
P
p
.002 w
.59677 .58253 m .59697 .62073 L .54397 .61347 L p
1 g
F P
s
P
p
.002 w
.53432 .65029 m .52377 .68618 L .45863 .66193 L p
1 g
F P
s
P
p
.002 w
.52377 .68618 m .53432 .65029 L .59465 .65871 L p
1 g
F P
s
P
p
.002 w
.59697 .62073 m .59465 .65871 L .53432 .65029 L p
1 g
F P
s
P
p
.002 w
.44542 .56451 m .47015 .53563 L .5088 .5604 L p
1 g
F P
s
P
p
.002 w
.52571 .52794 m .5088 .5604 L .47015 .53563 L p
1 g
F P
s
P
p
.002 w
.5088 .5604 m .52571 .52794 L .55964 .5405 L p
1 g
F P
s
P
p
.002 w
.55964 .5405 m .55247 .57658 L .5088 .5604 L p
1 g
F P
s
P
p
.002 w
.55247 .57658 m .55964 .5405 L .59404 .54502 L p
1 g
F P
s
P
p
.002 w
.59404 .54502 m .59677 .58253 L .55247 .57658 L p
1 g
F P
s
P
p
.002 w
.38192 .65566 m .40077 .62524 L .45863 .66193 L p
1 g
F P
s
P
p
.002 w
.45863 .66193 m .4434 .69452 L .38192 .65566 L p
1 g
F P
s
P
p
.002 w
.4434 .69452 m .45863 .66193 L .52377 .68618 L p
1 g
F P
s
P
p
.002 w
.38135 .55281 m .40976 .52766 L .44542 .56451 L p
1 g
F P
s
P
p
.002 w
.44542 .56451 m .42211 .59461 L .38135 .55281 L p
1 g
F P
s
P
p
.002 w
.47015 .53563 m .44542 .56451 L .40976 .52766 L p
1 g
F P
s
P
p
.002 w
.52377 .68618 m .51254 .72029 L .4434 .69452 L p
1 g
F P
s
P
p
.002 w
.51254 .72029 m .52377 .68618 L .58984 .69557 L p
1 g
F P
s
P
p
.002 w
.59465 .65871 m .58984 .69557 L .52377 .68618 L p
1 g
F P
s
P
p
.002 w
.35594 .57959 m .38135 .55281 L .42211 .59461 L p
1 g
F P
s
P
p
.002 w
.42211 .59461 m .40077 .62524 L .35594 .57959 L p
1 g
F P
s
P
p
.002 w
.40976 .52766 m .4405 .50475 L .47015 .53563 L p
1 g
F P
s
P
p
.002 w
.49573 .50866 m .47015 .53563 L .4405 .50475 L p
1 g
F P
s
P
p
.002 w
.47015 .53563 m .49573 .50866 L .52571 .52794 L p
1 g
F P
s
P
p
.002 w
.54206 .49747 m .52571 .52794 L .49573 .50866 L p
1 g
F P
s
P
p
.002 w
.52571 .52794 m .54206 .49747 L .56529 .50606 L p
1 g
F P
s
P
p
.002 w
.56529 .50606 m .55964 .5405 L .52571 .52794 L p
1 g
F P
s
P
p
.002 w
.55964 .5405 m .56529 .50606 L .58883 .5091 L p
1 g
F P
s
P
p
.002 w
.58883 .5091 m .59404 .54502 L .55964 .5405 L p
1 g
F P
s
P
p
.002 w
.59465 .65871 m .59697 .62073 L .64539 .61498 L p
1 g
F P
s
P
p
.002 w
.59697 .62073 m .59677 .58253 L .63716 .57754 L p
1 g
F P
s
P
p
.002 w
.63716 .57754 m .64539 .61498 L .59697 .62073 L p
1 g
F P
s
P
p
.002 w
.33418 .60738 m .35594 .57959 L .40077 .62524 L p
1 g
F P
s
P
p
.002 w
.40077 .62524 m .38192 .65566 L .33418 .60738 L p
1 g
F P
s
P
p
.002 w
.36604 .68515 m .38192 .65566 L .4434 .69452 L p
1 g
F P
s
P
p
.002 w
.4434 .69452 m .42955 .72518 L .36604 .68515 L p
1 g
F P
s
P
p
.002 w
.42955 .72518 m .4434 .69452 L .51254 .72029 L p
1 g
F P
s
P
p
.002 w
.59677 .58253 m .59404 .54502 L .62534 .541 L p
1 g
F P
s
P
p
.002 w
.62534 .541 m .63716 .57754 L .59677 .58253 L p
1 g
F P
s
P
p
.002 w
.4405 .50475 m .47281 .48462 L .49573 .50866 L p
1 g
F P
s
P
p
.002 w
.52156 .48425 m .49573 .50866 L .47281 .48462 L p
1 g
F P
s
P
p
.002 w
.49573 .50866 m .52156 .48425 L .54206 .49747 L p
1 g
F P
s
P
p
.002 w
.58984 .69557 m .59465 .65871 L .64982 .65244 L p
1 g
F P
s
P
p
.002 w
.64539 .61498 m .64982 .65244 L .59465 .65871 L p
1 g
F P
s
P
p
.002 w
.51254 .72029 m .50091 .75181 L .42955 .72518 L p
1 g
F P
s
P
p
.002 w
.50091 .75181 m .51254 .72029 L .58266 .73044 L p
1 g
F P
s
P
p
.002 w
.58984 .69557 m .58266 .73044 L .51254 .72029 L p
1 g
F P
s
P
p
.002 w
.59404 .54502 m .58883 .5091 L .61021 .50625 L p
1 g
F P
s
P
p
.002 w
.61021 .50625 m .62534 .541 L .59404 .54502 L p
1 g
F P
s
P
p
.002 w
.55744 .46975 m .54206 .49747 L .52156 .48425 L p
1 g
F P
s
P
p
.002 w
.54206 .49747 m .55744 .46975 L .56928 .47412 L p
1 g
F P
s
P
p
.002 w
.56928 .47412 m .56529 .50606 L .54206 .49747 L p
1 g
F P
s
P
p
.002 w
.38854 .48718 m .42299 .47086 L .4405 .50475 L p
1 g
F P
s
P
p
.002 w
.4405 .50475 m .40976 .52766 L .38854 .48718 L p
1 g
F P
s
P
p
.002 w
.47281 .48462 m .4405 .50475 L .42299 .47086 L p
1 g
F P
s
P
p
.002 w
.58266 .73044 m .58984 .69557 L .65033 .68898 L p
1 g
F P
s
P
p
.002 w
.64982 .65244 m .65033 .68898 L .58984 .69557 L p
1 g
F P
s
P
p
.002 w
.3569 .50685 m .38854 .48718 L .40976 .52766 L p
1 g
F P
s
P
p
.002 w
.40976 .52766 m .38135 .55281 L .3569 .50685 L p
1 g
F P
s
P
p
.002 w
.56529 .50606 m .56928 .47412 L .58126 .47564 L p
1 g
F P
s
P
p
.002 w
.58126 .47564 m .58883 .5091 L .56529 .50606 L p
1 g
F P
s
P
p
.002 w
.31662 .6355 m .33418 .60738 L .38192 .65566 L p
1 g
F P
s
P
p
.002 w
.38192 .65566 m .36604 .68515 L .31662 .6355 L p
1 g
F P
s
P
p
.002 w
.47281 .48462 m .50595 .46775 L .52156 .48425 L p
1 g
F P
s
P
p
.002 w
.54701 .463 m .52156 .48425 L .50595 .46775 L p
1 g
F P
s
P
p
.002 w
.52156 .48425 m .54701 .463 L .55744 .46975 L p
1 g
F P
s
P
p
.002 w
.42299 .47086 m .45941 .45827 L .47281 .48462 L p
1 g
F P
s
P
p
.002 w
.50595 .46775 m .47281 .48462 L .45941 .45827 L p
1 g
F P
s
P
p
.002 w
.32887 .5294 m .3569 .50685 L .38135 .55281 L p
1 g
F P
s
P
p
.002 w
.38135 .55281 m .35594 .57959 L .32887 .5294 L p
1 g
F P
s
P
p
.002 w
.35353 .71299 m .36604 .68515 L .42955 .72518 L p
1 g
F P
s
P
p
.002 w
.42955 .72518 m .41742 .75314 L .35353 .71299 L p
1 g
F P
s
P
p
.002 w
.41742 .75314 m .42955 .72518 L .50091 .75181 L p
1 g
F P
s
P
p
.002 w
.58883 .5091 m .58126 .47564 L .59211 .47414 L p
1 g
F P
s
P
p
.002 w
.59211 .47414 m .61021 .50625 L .58883 .5091 L p
1 g
F P
s
P
p
.002 w
.50091 .75181 m .48914 .77994 L .41742 .75314 L p
1 g
F P
s
P
p
.002 w
.48914 .77994 m .50091 .75181 L .57325 .76244 L p
1 g
F P
s
P
p
.002 w
.58266 .73044 m .57325 .76244 L .50091 .75181 L p
1 g
F P
s
P
p
.002 w
.64539 .61498 m .63716 .57754 L .66941 .56197 L p
1 g
F P
s
P
p
.002 w
.63716 .57754 m .62534 .541 L .65024 .52875 L p
1 g
F P
s
P
p
.002 w
.65024 .52875 m .66941 .56197 L .63716 .57754 L p
1 g
F P
s
P
p
.002 w
.62534 .541 m .61021 .50625 L .62713 .49777 L p
1 g
F P
s
P
p
.002 w
.62713 .49777 m .65024 .52875 L .62534 .541 L p
1 g
F P
s
P
p
.002 w
.45941 .45827 m .4969 .44971 L .50595 .46775 L p
1 g
F P
s
P
p
.002 w
.5391 .45459 m .50595 .46775 L .4969 .44971 L p
1 g
F P
s
P
p
.002 w
.50595 .46775 m .5391 .45459 L .54701 .463 L p
1 g
F P
s
P
p
.002 w
.57325 .76244 m .58266 .73044 L .64687 .72373 L p
1 g
F P
s
P
p
.002 w
.65033 .68898 m .64687 .72373 L .58266 .73044 L p
1 g
F P
s
P
p
.002 w
.64982 .65244 m .64539 .61498 L .68416 .5966 L p
1 g
F P
s
P
p
.002 w
.66941 .56197 m .68416 .5966 L .64539 .61498 L p
1 g
F P
s
P
p
.002 w
.30519 .55431 m .32887 .5294 L .35594 .57959 L p
1 g
F P
s
P
p
.002 w
.35594 .57959 m .33418 .60738 L .30519 .55431 L p
1 g
F P
s
P
p
.002 w
.61021 .50625 m .59211 .47414 L .60067 .46978 L p
1 g
F P
s
P
p
.002 w
.60067 .46978 m .62713 .49777 L .61021 .50625 L p
1 g
F P
s
P
p
.002 w
.30376 .66327 m .31662 .6355 L .36604 .68515 L p
1 g
F P
s
P
p
.002 w
.36604 .68515 m .35353 .71299 L .30376 .66327 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .55744 .46975 L .54701 .463 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .56928 .47412 L .55744 .46975 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .58126 .47564 L .56928 .47412 L closepath p
1 g
F P
s
P
p
.002 w
.65033 .68898 m .64982 .65244 L .69411 .63181 L p
1 g
F P
s
P
p
.002 w
.68416 .5966 m .69411 .63181 L .64982 .65244 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .54701 .463 L .5391 .45459 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .59211 .47414 L .58126 .47564 L closepath p
1 g
F P
s
P
p
.002 w
.41969 .43745 m .45706 .43236 L .45941 .45827 L p
1 g
F P
s
P
p
.002 w
.45941 .45827 m .42299 .47086 L .41969 .43745 L p
1 g
F P
s
P
p
.002 w
.4969 .44971 m .45941 .45827 L .45706 .43236 L p
1 g
F P
s
P
p
.002 w
.38426 .44719 m .41969 .43745 L .42299 .47086 L p
1 g
F P
s
P
p
.002 w
.42299 .47086 m .38854 .48718 L .38426 .44719 L p
1 g
F P
s
P
p
.002 w
.4969 .44971 m .53457 .4454 L .5391 .45459 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .5391 .45459 L .53457 .4454 L closepath p
1 g
F P
s
P
p
.002 w
.45706 .43236 m .49545 .43202 L .4969 .44971 L p
1 g
F P
s
P
p
.002 w
.53457 .4454 m .4969 .44971 L .49545 .43202 L p
1 g
F P
s
P
p
.002 w
.34477 .73846 m .35353 .71299 L .41742 .75314 L p
1 g
F P
s
P
p
.002 w
.41742 .75314 m .40733 .77768 L .34477 .73846 L p
1 g
F P
s
P
p
.002 w
.40733 .77768 m .41742 .75314 L .48914 .77994 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .60067 .46978 L .59211 .47414 L closepath p
1 g
F P
s
P
p
.002 w
.2865 .58097 m .30519 .55431 L .33418 .60738 L p
1 g
F P
s
P
p
.002 w
.33418 .60738 m .31662 .6355 L .2865 .58097 L p
1 g
F P
s
P
p
.002 w
.35169 .46138 m .38426 .44719 L .38854 .48718 L p
1 g
F P
s
P
p
.002 w
.38854 .48718 m .3569 .50685 L .35169 .46138 L p
1 g
F P
s
P
p
.002 w
.57325 .76244 m .5618 .79077 L .48914 .77994 L p
1 g
F P
s
P
p
.002 w
.5618 .79077 m .57325 .76244 L .63947 .75579 L p
1 g
F P
s
P
p
.002 w
.64687 .72373 m .63947 .75579 L .57325 .76244 L p
1 g
F P
s
P
p
.002 w
.48914 .77994 m .47753 .80394 L .40733 .77768 L p
1 g
F P
s
P
p
.002 w
.47753 .80394 m .48914 .77994 L .5618 .79077 L p
1 g
F P
s
P
p
.002 w
.64687 .72373 m .65033 .68898 L .69896 .66672 L p
1 g
F P
s
P
p
.002 w
.69411 .63181 m .69896 .66672 L .65033 .68898 L p
1 g
F P
s
P
p
.002 w
.49545 .43202 m .53391 .43643 L .53457 .4454 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .53457 .4454 L .53391 .43643 L closepath p
1 g
F P
s
P
p
.002 w
.65024 .52875 m .62713 .49777 L .63775 .4845 L p
1 g
F P
s
P
p
.002 w
.62713 .49777 m .60067 .46978 L .60599 .463 L p
1 g
F P
s
P
p
.002 w
.60599 .463 m .63775 .4845 L .62713 .49777 L p
1 g
F P
s
P
p
.002 w
.66941 .56197 m .65024 .52875 L .66598 .50945 L p
1 g
F P
s
P
p
.002 w
.63775 .4845 m .66598 .50945 L .65024 .52875 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .60599 .463 L .60067 .46978 L closepath p
1 g
F P
s
P
p
.002 w
.68416 .5966 m .66941 .56197 L .68993 .53724 L p
1 g
F P
s
P
p
.002 w
.66598 .50945 m .68993 .53724 L .66941 .56197 L p
1 g
F P
s
P
p
.002 w
.32284 .47971 m .35169 .46138 L .3569 .50685 L p
1 g
F P
s
P
p
.002 w
.3569 .50685 m .32887 .5294 L .32284 .47971 L p
1 g
F P
s
P
p
.002 w
.29601 .68998 m .30376 .66327 L .35353 .71299 L p
1 g
F P
s
P
p
.002 w
.35353 .71299 m .34477 .73846 L .29601 .68998 L p
1 g
F P
s
P
p
.002 w
.50184 .4166 m .53722 .42864 L .53391 .43643 L p
1 g
F P
s
P
p
.002 w
.53391 .43643 m .49545 .43202 L .50184 .4166 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .53391 .43643 L .53722 .42864 L closepath p
1 g
F P
s
P
p
.002 w
.46622 .40968 m .50184 .4166 L .49545 .43202 L p
1 g
F P
s
P
p
.002 w
.49545 .43202 m .45706 .43236 L .46622 .40968 L p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .54416 .42289 L .554 .41981 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .53722 .42864 L .54416 .42289 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .60748 .45454 L .60599 .463 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .60496 .44529 L .60748 .45454 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .59868 .43627 L .60496 .44529 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .58932 .42847 L .59868 .43627 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .5779 .42276 L .58932 .42847 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .56568 .41976 L .5779 .42276 L closepath p
1 g
F P
s
P
p
.002 w
.57148 .44547 m .554 .41981 L .56568 .41976 L closepath p
1 g
F P
s
P
p
.002 w
.63775 .4845 m .60599 .463 L .60748 .45454 L p
1 g
F P
s
P
p
.002 w
.43125 .40811 m .46622 .40968 L .45706 .43236 L p
1 g
F P
s
P
p
.002 w
.45706 .43236 m .41969 .43745 L .43125 .40811 L p
1 g
F P
s
P
p
.002 w
.63947 .75579 m .64687 .72373 L .69853 .70044 L p
1 g
F P
s
P
p
.002 w
.69896 .66672 m .69853 .70044 L .64687 .72373 L p
1 g
F P
s
P
p
.002 w
.69411 .63181 m .68416 .5966 L .70897 .5672 L p
1 g
F P
s
P
p
.002 w
.68993 .53724 m .70897 .5672 L .68416 .5966 L p
1 g
F P
s
P
p
.002 w
.27335 .60873 m .2865 .58097 L .31662 .6355 L p
1 g
F P
s
P
p
.002 w
.31662 .6355 m .30376 .66327 L .27335 .60873 L p
1 g
F P
s
P
p
.002 w
.51546 .40515 m .54416 .42289 L .53722 .42864 L p
1 g
F P
s
P
p
.002 w
.53722 .42864 m .50184 .4166 L .51546 .40515 L p
1 g
F P
s
P
p
.002 w
.66598 .50945 m .63775 .4845 L .64084 .46783 L p
1 g
F P
s
P
p
.002 w
.60748 .45454 m .64084 .46783 L .63775 .4845 L p
1 g
F P
s
P
p
.002 w
.5618 .79077 m .54858 .81466 L .47753 .80394 L p
1 g
F P
s
P
p
.002 w
.54858 .81466 m .5618 .79077 L .62829 .78433 L p
1 g
F P
s
P
p
.002 w
.63947 .75579 m .62829 .78433 L .5618 .79077 L p
1 g
F P
s
P
p
.002 w
.29849 .50176 m .32284 .47971 L .32887 .5294 L p
1 g
F P
s
P
p
.002 w
.32887 .5294 m .30519 .55431 L .29849 .50176 L p
1 g
F P
s
P
p
.002 w
.34005 .76088 m .34477 .73846 L .40733 .77768 L p
1 g
F P
s
P
p
.002 w
.40733 .77768 m .39958 .79813 L .34005 .76088 L p
1 g
F P
s
P
p
.002 w
.39958 .79813 m .40733 .77768 L .47753 .80394 L p
1 g
F P
s
P
p
.002 w
.64084 .46783 m .60748 .45454 L .60496 .44529 L p
1 g
F P
s
P
p
.002 w
.39783 .41199 m .43125 .40811 L .41969 .43745 L p
1 g
F P
s
P
p
.002 w
.41969 .43745 m .38426 .44719 L .39783 .41199 L p
1 g
F P
s
P
p
.002 w
.47753 .80394 m .46636 .82314 L .39958 .79813 L p
1 g
F P
s
P
p
.002 w
.46636 .82314 m .47753 .80394 L .54858 .81466 L p
1 g
F P
s
P
p
.002 w
.5349 .39899 m .554 .41981 L .54416 .42289 L p
1 g
F P
s
P
p
.002 w
.54416 .42289 m .51546 .40515 L .5349 .39899 L p
1 g
F P
s
P
p
.002 w
.68993 .53724 m .66598 .50945 L .67069 .48506 L p
1 g
F P
s
P
p
.002 w
.64084 .46783 m .67069 .48506 L .66598 .50945 L p
1 g
F P
s
P
p
.002 w
.69896 .66672 m .69411 .63181 L .72256 .59859 L p
1 g
F P
s
P
p
.002 w
.70897 .5672 m .72256 .59859 L .69411 .63181 L p
1 g
F P
s
P
p
.002 w
.48607 .39278 m .51546 .40515 L .50184 .4166 L p
1 g
F P
s
P
p
.002 w
.50184 .4166 m .46622 .40968 L .48607 .39278 L p
1 g
F P
s
P
p
.002 w
.60496 .44529 m .63597 .44954 L .64084 .46783 L p
1 g
F P
s
P
p
.002 w
.63597 .44954 m .60496 .44529 L .59868 .43627 L p
1 g
F P
s
P
p
.002 w
.55804 .39884 m .56568 .41976 L .554 .41981 L p
1 g
F P
s
P
p
.002 w
.554 .41981 m .5349 .39899 L .55804 .39884 L p
1 g
F P
s
P
p
.002 w
.29364 .71493 m .29601 .68998 L .34477 .73846 L p
1 g
F P
s
P
p
.002 w
.34477 .73846 m .34005 .76088 L .29364 .71493 L p
1 g
F P
s
P
p
.002 w
.62829 .78433 m .63947 .75579 L .69276 .73209 L p
1 g
F P
s
P
p
.002 w
.69853 .70044 m .69276 .73209 L .63947 .75579 L p
1 g
F P
s
P
p
.002 w
.36685 .42129 m .39783 .41199 L .38426 .44719 L p
1 g
F P
s
P
p
.002 w
.38426 .44719 m .35169 .46138 L .36685 .42129 L p
1 g
F P
s
P
p
.002 w
.59868 .43627 m .62359 .43164 L .63597 .44954 L p
1 g
F P
s
P
p
.002 w
.62359 .43164 m .59868 .43627 L .58932 .42847 L p
1 g
F P
s
P
p
.002 w
.67069 .48506 m .64084 .46783 L .63597 .44954 L p
1 g
F P
s
P
p
.002 w
.26618 .63689 m .27335 .60873 L .30376 .66327 L p
1 g
F P
s
P
p
.002 w
.30376 .66327 m .29601 .68998 L .26618 .63689 L p
1 g
F P
s
P
p
.002 w
.58232 .40477 m .5779 .42276 L .56568 .41976 L p
1 g
F P
s
P
p
.002 w
.56568 .41976 m .55804 .39884 L .58232 .40477 L p
1 g
F P
s
P
p
.002 w
.27934 .527 m .29849 .50176 L .30519 .55431 L p
1 g
F P
s
P
p
.002 w
.30519 .55431 m .2865 .58097 L .27934 .527 L p
1 g
F P
s
P
p
.002 w
.58932 .42847 m .60502 .41613 L .62359 .43164 L p
1 g
F P
s
P
p
.002 w
.60502 .41613 m .58932 .42847 L .5779 .42276 L p
1 g
F P
s
P
p
.002 w
.70897 .5672 m .68993 .53724 L .69623 .50584 L p
1 g
F P
s
P
p
.002 w
.67069 .48506 m .69623 .50584 L .68993 .53724 L p
1 g
F P
s
P
p
.002 w
.5779 .42276 m .58232 .40477 L .60502 .41613 L p
1 g
F P
s
P
p
.002 w
.45675 .38616 m .48607 .39278 L .46622 .40968 L p
1 g
F P
s
P
p
.002 w
.46622 .40968 m .43125 .40811 L .45675 .38616 L p
1 g
F P
s
P
p
.002 w
.69853 .70044 m .69896 .66672 L .73028 .63062 L p
1 g
F P
s
P
p
.002 w
.72256 .59859 m .73028 .63062 L .69896 .66672 L p
1 g
F P
s
P
p
.002 w
.51461 .38362 m .5349 .39899 L .51546 .40515 L p
1 g
F P
s
P
p
.002 w
.51546 .40515 m .48607 .39278 L .51461 .38362 L p
1 g
F P
s
P
p
.002 w
.54858 .81466 m .53389 .83343 L .46636 .82314 L p
1 g
F P
s
P
p
.002 w
.53389 .83343 m .54858 .81466 L .61353 .80856 L p
1 g
F P
s
P
p
.002 w
.62829 .78433 m .61353 .80856 L .54858 .81466 L p
1 g
F P
s
P
p
.002 w
.33917 .43584 m .36685 .42129 L .35169 .46138 L p
1 g
F P
s
P
p
.002 w
.35169 .46138 m .32284 .47971 L .33917 .43584 L p
1 g
F P
s
P
p
.002 w
.33956 .77962 m .34005 .76088 L .39958 .79813 L p
1 g
F P
s
P
p
.002 w
.39958 .79813 m .39441 .81389 L .33956 .77962 L p
1 g
F P
s
P
p
.002 w
.39441 .81389 m .39958 .79813 L .46636 .82314 L p
1 g
F P
s
P
p
.002 w
.63597 .44954 m .66367 .45819 L .67069 .48506 L p
1 g
F P
s
P
p
.002 w
.66367 .45819 m .63597 .44954 L .62359 .43164 L p
1 g
F P
s
P
p
.002 w
.69623 .50584 m .67069 .48506 L .66367 .45819 L p
1 g
F P
s
P
p
.002 w
.72256 .59859 m .70897 .5672 L .71673 .52968 L p
1 g
F P
s
P
p
.002 w
.69623 .50584 m .71673 .52968 L .70897 .5672 L p
1 g
F P
s
P
p
.002 w
.46636 .82314 m .45593 .83694 L .39441 .81389 L p
1 g
F P
s
P
p
.002 w
.45593 .83694 m .46636 .82314 L .53389 .83343 L p
1 g
F P
s
P
p
.002 w
.42826 .38558 m .45675 .38616 L .43125 .40811 L p
1 g
F P
s
P
p
.002 w
.43125 .40811 m .39783 .41199 L .42826 .38558 L p
1 g
F P
s
P
p
.002 w
.61353 .80856 m .62829 .78433 L .68174 .76083 L p
1 g
F P
s
P
p
.002 w
.69276 .73209 m .68174 .76083 L .62829 .78433 L p
1 g
F P
s
P
p
.002 w
.54872 .38336 m .55804 .39884 L .5349 .39899 L p
1 g
F P
s
P
p
.002 w
.5349 .39899 m .51461 .38362 L .54872 .38336 L p
1 g
F P
s
P
p
.002 w
.26599 .55481 m .27934 .527 L .2865 .58097 L p
1 g
F P
s
P
p
.002 w
.2865 .58097 m .27335 .60873 L .26599 .55481 L p
1 g
F P
s
P
p
.002 w
.69276 .73209 m .69853 .70044 L .73185 .66246 L p
1 g
F P
s
P
p
.002 w
.73028 .63062 m .73185 .66246 L .69853 .70044 L p
1 g
F P
s
P
p
.002 w
.26526 .6647 m .26618 .63689 L .29601 .68998 L p
1 g
F P
s
P
p
.002 w
.29601 .68998 m .29364 .71493 L .26526 .6647 L p
1 g
F P
s
P
p
.002 w
.62359 .43164 m .64551 .4318 L .66367 .45819 L p
1 g
F P
s
P
p
.002 w
.64551 .4318 m .62359 .43164 L .60502 .41613 L p
1 g
F P
s
P
p
.002 w
.29684 .73743 m .29364 .71493 L .34005 .76088 L p
1 g
F P
s
P
p
.002 w
.34005 .76088 m .33956 .77962 L .29684 .73743 L p
1 g
F P
s
P
p
.002 w
.49365 .37422 m .51461 .38362 L .48607 .39278 L p
1 g
F P
s
P
p
.002 w
.48607 .39278 m .45675 .38616 L .49365 .37422 L p
1 g
F P
s
P
p
.002 w
.5846 .3921 m .58232 .40477 L .55804 .39884 L p
1 g
F P
s
P
p
.002 w
.55804 .39884 m .54872 .38336 L .5846 .3921 L p
1 g
F P
s
P
p
.002 w
.31556 .45534 m .33917 .43584 L .32284 .47971 L p
1 g
F P
s
P
p
.002 w
.32284 .47971 m .29849 .50176 L .31556 .45534 L p
1 g
F P
s
P
p
.002 w
.60502 .41613 m .61813 .40889 L .64551 .4318 L p
1 g
F P
s
P
p
.002 w
.61813 .40889 m .60502 .41613 L .58232 .40477 L p
1 g
F P
s
P
p
.002 w
.58232 .40477 m .5846 .3921 L .61813 .40889 L p
1 g
F P
s
P
p
.002 w
.73028 .63062 m .72256 .59859 L .73159 .55599 L p
1 g
F P
s
P
p
.002 w
.71673 .52968 m .73159 .55599 L .72256 .59859 L p
1 g
F P
s
P
p
.002 w
.71673 .52968 m .69623 .50584 L .68729 .47109 L p
1 g
F P
s
P
p
.002 w
.66367 .45819 m .68729 .47109 L .69623 .50584 L p
1 g
F P
s
P
p
.002 w
.53389 .83343 m .51807 .84647 L .45593 .83694 L p
1 g
F P
s
P
p
.002 w
.51807 .84647 m .53389 .83343 L .59552 .82778 L p
1 g
F P
s
P
p
.002 w
.61353 .80856 m .59552 .82778 L .53389 .83343 L p
1 g
F P
s
P
p
.002 w
.40137 .39114 m .42826 .38558 L .39783 .41199 L p
1 g
F P
s
P
p
.002 w
.39783 .41199 m .36685 .42129 L .40137 .39114 L p
1 g
F P
s
P
p
.002 w
.68729 .47109 m .66367 .45819 L .64551 .4318 L p
1 g
F P
s
P
p
.002 w
.25889 .58449 m .26599 .55481 L .27335 .60873 L p
1 g
F P
s
P
p
.002 w
.27335 .60873 m .26618 .63689 L .25889 .58449 L p
1 g
F P
s
P
p
.002 w
.59552 .82778 m .61353 .80856 L .66565 .78584 L p
1 g
F P
s
P
p
.002 w
.68174 .76083 m .66565 .78584 L .61353 .80856 L p
1 g
F P
s
P
p
.002 w
.68174 .76083 m .69276 .73209 L .72713 .69325 L p
1 g
F P
s
P
p
.002 w
.73185 .66246 m .72713 .69325 L .69276 .73209 L p
1 g
F P
s
P
p
.002 w
.34342 .79409 m .33956 .77962 L .39441 .81389 L p
1 g
F P
s
P
p
.002 w
.39441 .81389 m .39202 .82442 L .34342 .79409 L p
1 g
F P
s
P
p
.002 w
.39202 .82442 m .39441 .81389 L .45593 .83694 L p
1 g
F P
s
P
p
.002 w
.53794 .37384 m .54872 .38336 L .51461 .38362 L p
1 g
F P
s
P
p
.002 w
.51461 .38362 m .49365 .37422 L .53794 .37384 L p
1 g
F P
s
P
p
.002 w
.45593 .83694 m .44652 .84485 L .39202 .82442 L p
1 g
F P
s
P
p
.002 w
.44652 .84485 m .45593 .83694 L .51807 .84647 L p
1 g
F P
s
P
p
.002 w
.29674 .47935 m .31556 .45534 L .29849 .50176 L p
1 g
F P
s
P
p
.002 w
.29849 .50176 m .27934 .527 L .29674 .47935 L p
1 g
F P
s
P
p
.002 w
.47256 .37117 m .49365 .37422 L .45675 .38616 L p
1 g
F P
s
P
p
.002 w
.45675 .38616 m .42826 .38558 L .47256 .37117 L p
1 g
F P
s
P
p
.002 w
.27076 .69142 m .26526 .6647 L .29364 .71493 L p
1 g
F P
s
P
p
.002 w
.29364 .71493 m .29684 .73743 L .27076 .69142 L p
1 g
F P
s
P
p
.002 w
.73185 .66246 m .73028 .63062 L .74031 .58413 L p
1 g
F P
s
P
p
.002 w
.73159 .55599 m .74031 .58413 L .73028 .63062 L p
1 g
F P
s
P
p
.002 w
.64551 .4318 m .6638 .43684 L .68729 .47109 L p
1 g
F P
s
P
p
.002 w
.6638 .43684 m .64551 .4318 L .61813 .40889 L p
1 g
F P
s
P
p
.002 w
.73159 .55599 m .71673 .52968 L .70613 .48797 L p
1 g
F P
s
P
p
.002 w
.68729 .47109 m .70613 .48797 L .71673 .52968 L p
1 g
F P
s
P
p
.002 w
.30562 .75682 m .29684 .73743 L .33956 .77962 L p
1 g
F P
s
P
p
.002 w
.33956 .77962 m .34342 .79409 L .30562 .75682 L p
1 g
F P
s
P
p
.002 w
.37685 .40282 m .40137 .39114 L .36685 .42129 L p
1 g
F P
s
P
p
.002 w
.36685 .42129 m .33917 .43584 L .37685 .40282 L p
1 g
F P
s
P
p
.002 w
.5846 .3852 m .5846 .3921 L .54872 .38336 L p
1 g
F P
s
P
p
.002 w
.54872 .38336 m .53794 .37384 L .5846 .3852 L p
1 g
F P
s
P
p
.002 w
.70613 .48797 m .68729 .47109 L .6638 .43684 L p
1 g
F P
s
P
p
.002 w
.61813 .40889 m .62824 .40705 L .6638 .43684 L p
1 g
F P
s
P
p
.002 w
.62824 .40705 m .61813 .40889 L .5846 .3921 L p
1 g
F P
s
P
p
.002 w
.66565 .78584 m .68174 .76083 L .71615 .72215 L p
1 g
F P
s
P
p
.002 w
.72713 .69325 m .71615 .72215 L .68174 .76083 L p
1 g
F P
s
P
p
.002 w
.25833 .61525 m .25889 .58449 L .26618 .63689 L p
1 g
F P
s
P
p
.002 w
.26618 .63689 m .26526 .6647 L .25833 .61525 L p
1 g
F P
s
P
p
.002 w
.51807 .84647 m .50152 .85333 L .44652 .84485 L p
1 g
F P
s
P
p
.002 w
.50152 .85333 m .51807 .84647 L .57467 .84137 L p
1 g
F P
s
P
p
.002 w
.59552 .82778 m .57467 .84137 L .51807 .84647 L p
1 g
F P
s
P
p
.002 w
.5846 .3921 m .5846 .3852 L .62824 .40705 L p
1 g
F P
s
P
p
.002 w
.57467 .84137 m .59552 .82778 L .64485 .80639 L p
1 g
F P
s
P
p
.002 w
.66565 .78584 m .64485 .80639 L .59552 .82778 L p
1 g
F P
s
P
p
.002 w
.2833 .50727 m .29674 .47935 L .27934 .527 L p
1 g
F P
s
P
p
.002 w
.27934 .527 m .26599 .55481 L .2833 .50727 L p
1 g
F P
s
P
p
.002 w
.72713 .69325 m .73185 .66246 L .74255 .61336 L p
1 g
F P
s
P
p
.002 w
.74031 .58413 m .74255 .61336 L .73185 .66246 L p
1 g
F P
s
P
p
.002 w
.45192 .37467 m .47256 .37117 L .42826 .38558 L p
1 g
F P
s
P
p
.002 w
.42826 .38558 m .40137 .39114 L .45192 .37467 L p
1 g
F P
s
P
p
.002 w
.52594 .37068 m .53794 .37384 L .49365 .37422 L p
1 g
F P
s
P
p
.002 w
.49365 .37422 m .47256 .37117 L .52594 .37068 L p
1 g
F P
s
P
p
.002 w
.74031 .58413 m .73159 .55599 L .71959 .50848 L p
1 g
F P
s
P
p
.002 w
.70613 .48797 m .71959 .50848 L .73159 .55599 L p
1 g
F P
s
P
p
.002 w
.35541 .42041 m .37685 .40282 L .33917 .43584 L p
1 g
F P
s
P
p
.002 w
.33917 .43584 m .31556 .45534 L .35541 .42041 L p
1 g
F P
s
P
p
.002 w
.35163 .80381 m .34342 .79409 L .39202 .82442 L p
1 g
F P
s
P
p
.002 w
.39202 .82442 m .39254 .82933 L .35163 .80381 L p
1 g
F P
s
P
p
.002 w
.39254 .82933 m .39202 .82442 L .44652 .84485 L p
1 g
F P
s
P
p
.002 w
.28263 .71628 m .27076 .69142 L .29684 .73743 L p
1 g
F P
s
P
p
.002 w
.29684 .73743 m .30562 .75682 L .28263 .71628 L p
1 g
F P
s
P
p
.002 w
.44652 .84485 m .43842 .84653 L .39254 .82933 L p
1 g
F P
s
P
p
.002 w
.43842 .84653 m .44652 .84485 L .50152 .85333 L p
1 g
F P
s
P
p
.002 w
.6638 .43684 m .6779 .44675 L .70613 .48797 L p
1 g
F P
s
P
p
.002 w
.6779 .44675 m .6638 .43684 L .62824 .40705 L p
1 g
F P
s
P
p
.002 w
.71615 .72215 m .6991 .74833 L .66565 .78584 L p
1 g
F P
s
P
p
.002 w
.64485 .80639 m .66565 .78584 L .6991 .74833 L p
1 g
F P
s
P
p
.002 w
.31988 .77251 m .30562 .75682 L .34342 .79409 L p
1 g
F P
s
P
p
.002 w
.34342 .79409 m .35163 .80381 L .31988 .77251 L p
1 g
F P
s
P
p
.002 w
.71959 .50848 m .70613 .48797 L .6779 .44675 L p
1 g
F P
s
P
p
.002 w
.26444 .64625 m .25833 .61525 L .26526 .6647 L p
1 g
F P
s
P
p
.002 w
.26526 .6647 m .27076 .69142 L .26444 .64625 L p
1 g
F P
s
P
p
.002 w
.27573 .53838 m .2833 .50727 L .26599 .55481 L p
1 g
F P
s
P
p
.002 w
.26599 .55481 m .25889 .58449 L .27573 .53838 L p
1 g
F P
s
P
p
.002 w
.58229 .3844 m .5846 .3852 L .53794 .37384 L p
1 g
F P
s
P
p
.002 w
.53794 .37384 m .52594 .37068 L .58229 .3844 L p
1 g
F P
s
P
p
.002 w
.74255 .61336 m .73814 .64289 L .72713 .69325 L p
1 g
F P
s
P
p
.002 w
.71615 .72215 m .72713 .69325 L .73814 .64289 L p
1 g
F P
s
P
p
.002 w
.57467 .84137 m .55149 .84886 L .50152 .85333 L p
1 g
F P
s
P
p
.002 w
.64485 .80639 m .61983 .82184 L .57467 .84137 L p
1 g
F P
s
P
p
.002 w
.55149 .84886 m .57467 .84137 L .61983 .82184 L p
1 g
F P
s
P
p
.002 w
.50152 .85333 m .48467 .85367 L .43842 .84653 L p
1 g
F P
s
P
p
.002 w
.48467 .85367 m .50152 .85333 L .55149 .84886 L p
1 g
F P
s
P
p
.002 w
.62824 .40705 m .635 .4108 L .6779 .44675 L p
1 g
F P
s
P
p
.002 w
.635 .4108 m .62824 .40705 L .5846 .3852 L p
1 g
F P
s
P
p
.002 w
.4323 .38479 m .45192 .37467 L .40137 .39114 L p
1 g
F P
s
P
p
.002 w
.40137 .39114 m .37685 .40282 L .4323 .38479 L p
1 g
F P
s
P
p
.002 w
.33771 .44352 m .35541 .42041 L .31556 .45534 L p
1 g
F P
s
P
p
.002 w
.31556 .45534 m .29674 .47935 L .33771 .44352 L p
1 g
F P
s
P
p
.002 w
.5846 .3852 m .58229 .3844 L .635 .4108 L p
1 g
F P
s
P
p
.002 w
.71959 .50848 m .72719 .5321 L .74031 .58413 L p
1 g
F P
s
P
p
.002 w
.74255 .61336 m .74031 .58413 L .72719 .5321 L p
1 g
F P
s
P
p
.002 w
.51302 .37414 m .52594 .37068 L .47256 .37117 L p
1 g
F P
s
P
p
.002 w
.47256 .37117 m .45192 .37467 L .51302 .37414 L p
1 g
F P
s
P
p
.004 w
.38346 .883 m
.39529 .85547 L
s
P
p
.002 w
.30066 .73856 m .28263 .71628 L .30562 .75682 L p
1 g
F P
s
P
p
.002 w
.30562 .75682 m .31988 .77251 L .30066 .73856 L p
1 g
F P
s
P
p
.002 w
.61983 .82184 m .64485 .80639 L .67637 .77101 L p
1 g
F P
s
P
p
.002 w
.6991 .74833 m .67637 .77101 L .64485 .80639 L p
1 g
F P
s
P
p
.002 w
.36407 .80839 m .35163 .80381 L .39254 .82933 L p
1 g
F P
s
P
p
.002 w
.39254 .82933 m .39602 .82833 L .36407 .80839 L p
1 g
F P
s
P
p
.002 w
.39602 .82833 m .39254 .82933 L .43842 .84653 L p
1 g
F P
s
P
p
.002 w
.27431 .57186 m .27573 .53838 L .25889 .58449 L p
1 g
F P
s
P
p
.002 w
.25889 .58449 m .25833 .61525 L .27431 .57186 L p
1 g
F P
s
P
p
.002 w
.43842 .84653 m .43188 .84177 L .39602 .82833 L p
1 g
F P
s
P
p
.002 w
.43188 .84177 m .43842 .84653 L .48467 .85367 L p
1 g
F P
s
P
p
.002 w
.27716 .67662 m .26444 .64625 L .27076 .69142 L p
1 g
F P
s
P
p
.002 w
.27076 .69142 m .28263 .71628 L .27716 .67662 L p
1 g
F P
s
P
p
.002 w
.6779 .44675 m .68732 .46136 L .71959 .50848 L p
1 g
F P
s
P
p
.002 w
.68732 .46136 m .6779 .44675 L .635 .4108 L p
1 g
F P
s
P
p
.002 w
.72719 .5321 m .71959 .50848 L .68732 .46136 L p
1 g
F P
s
P
p
.002 w
.6991 .74833 m .71615 .72215 L .72707 .67189 L p
1 g
F P
s
P
p
.002 w
.73814 .64289 m .72707 .67189 L .71615 .72215 L p
1 g
F P
s
P
p
.002 w
.33934 .78398 m .31988 .77251 L .35163 .80381 L p
1 g
F P
s
P
p
.002 w
.35163 .80381 m .36407 .80839 L .33934 .78398 L p
1 g
F P
s
P
p
.002 w
.32434 .4716 m .33771 .44352 L .29674 .47935 L p
1 g
F P
s
P
p
.002 w
.29674 .47935 m .2833 .50727 L .32434 .4716 L p
1 g
F P
s
P
p
.002 w
.55149 .84886 m .52658 .84992 L .48467 .85367 L p
1 g
F P
s
P
p
.002 w
.52658 .84992 m .55149 .84886 L .59121 .83166 L p
1 g
F P
s
P
p
.002 w
.61983 .82184 m .59121 .83166 L .55149 .84886 L p
1 g
F P
s
P
p
.002 w
.41429 .40137 m .4323 .38479 L .37685 .40282 L p
1 g
F P
s
P
p
.002 w
.37685 .40282 m .35541 .42041 L .41429 .40137 L p
1 g
F P
s
P
p
.002 w
.73814 .64289 m .74255 .61336 L .72859 .55826 L p
1 g
F P
s
P
p
.002 w
.72719 .5321 m .72859 .55826 L .74255 .61336 L p
1 g
F P
s
P
p
.002 w
.57765 .38989 m .58229 .3844 L .52594 .37068 L p
1 g
F P
s
P
p
.002 w
.52594 .37068 m .51302 .37414 L .57765 .38989 L p
1 g
F P
s
P
p
.002 w
.48467 .85367 m .46798 .84733 L .43188 .84177 L p
1 g
F P
s
P
p
.002 w
.46798 .84733 m .48467 .85367 L .52658 .84992 L p
1 g
F P
s
P
p
.002 w
.635 .4108 m .63814 .42017 L .68732 .46136 L p
1 g
F P
s
P
p
.002 w
.63814 .42017 m .635 .4108 L .58229 .3844 L p
1 g
F P
s
P
p
.002 w
.49953 .38427 m .51302 .37414 L .45192 .37467 L p
1 g
F P
s
P
p
.002 w
.45192 .37467 m .4323 .38479 L .49953 .38427 L p
1 g
F P
s
P
p
.002 w
.58229 .3844 m .57765 .38989 L .63814 .42017 L p
1 g
F P
s
P
p
.002 w
.59121 .83166 m .61983 .82184 L .64851 .78951 L p
1 g
F P
s
P
p
.002 w
.67637 .77101 m .64851 .78951 L .61983 .82184 L p
1 g
F P
s
P
p
.002 w
.27918 .60676 m .27431 .57186 L .25833 .61525 L p
1 g
F P
s
P
p
.002 w
.25833 .61525 m .26444 .64625 L .27918 .60676 L p
1 g
F P
s
P
p
.002 w
.67637 .77101 m .6991 .74833 L .70956 .69953 L p
1 g
F P
s
P
p
.002 w
.72707 .67189 m .70956 .69953 L .6991 .74833 L p
1 g
F P
s
P
p
.002 w
.32446 .75758 m .30066 .73856 L .31988 .77251 L p
1 g
F P
s
P
p
.002 w
.31988 .77251 m .33934 .78398 L .32446 .75758 L p
1 g
F P
s
P
p
.002 w
.29622 .70547 m .27716 .67662 L .28263 .71628 L p
1 g
F P
s
P
p
.002 w
.28263 .71628 m .30066 .73856 L .29622 .70547 L p
1 g
F P
s
P
p
.002 w
.72859 .55826 m .72719 .5321 L .69169 .48037 L p
1 g
F P
s
P
p
.002 w
.68732 .46136 m .69169 .48037 L .72719 .5321 L p
1 g
F P
s
P
p
.002 w
.31574 .5039 m .32434 .4716 L .2833 .50727 L p
1 g
F P
s
P
p
.002 w
.2833 .50727 m .27573 .53838 L .31574 .5039 L p
1 g
F P
s
P
p
.002 w
.69169 .48037 m .68732 .46136 L .63814 .42017 L p
1 g
F P
s
P
p
.002 w
.3805 .80757 m .36407 .80839 L .39602 .82833 L p
1 g
F P
s
P
p
.002 w
.39602 .82833 m .40246 .82129 L .3805 .80757 L p
1 g
F P
s
P
p
.002 w
.40246 .82129 m .39602 .82833 L .43188 .84177 L p
1 g
F P
s
P
p
.002 w
.72707 .67189 m .73814 .64289 L .72364 .58624 L p
1 g
F P
s
P
p
.002 w
.72859 .55826 m .72364 .58624 L .73814 .64289 L p
1 g
F P
s
P
p
.002 w
.39844 .42407 m .41429 .40137 L .35541 .42041 L p
1 g
F P
s
P
p
.002 w
.35541 .42041 m .33771 .44352 L .39844 .42407 L p
1 g
F P
s
P
p
.002 w
.43188 .84177 m .42712 .83053 L .40246 .82129 L p
1 g
F P
s
P
p
.002 w
.42712 .83053 m .43188 .84177 L .46798 .84733 L p
1 g
F P
s
P
p
.002 w
.52658 .84992 m .50059 .84437 L .46798 .84733 L p
1 g
F P
s
P
p
.002 w
.50059 .84437 m .52658 .84992 L .55973 .83549 L p
1 g
F P
s
P
p
.002 w
.59121 .83166 m .55973 .83549 L .52658 .84992 L p
1 g
F P
s
P
p
.002 w
.36355 .7908 m .33934 .78398 L .36407 .80839 L p
1 g
F P
s
P
p
.002 w
.36407 .80839 m .3805 .80757 L .36355 .7908 L p
1 g
F P
s
P
p
.002 w
.29029 .64209 m .27918 .60676 L .26444 .64625 L p
1 g
F P
s
P
p
.002 w
.26444 .64625 m .27716 .67662 L .29029 .64209 L p
1 g
F P
s
P
p
.002 w
.55973 .83549 m .59121 .83166 L .61624 .80322 L p
1 g
F P
s
P
p
.002 w
.64851 .78951 m .61624 .80322 L .59121 .83166 L p
1 g
F P
s
P
p
.002 w
.57077 .40167 m .57765 .38989 L .51302 .37414 L p
1 g
F P
s
P
p
.002 w
.51302 .37414 m .49953 .38427 L .57077 .40167 L p
1 g
F P
s
P
p
.002 w
.46798 .84733 m .45193 .83433 L .42712 .83053 L p
1 g
F P
s
P
p
.002 w
.45193 .83433 m .46798 .84733 L .50059 .84437 L p
1 g
F P
s
P
p
.002 w
.64851 .78951 m .67637 .77101 L .68601 .72498 L p
1 g
F P
s
P
p
.002 w
.70956 .69953 m .68601 .72498 L .67637 .77101 L p
1 g
F P
s
P
p
.002 w
.48586 .40093 m .49953 .38427 L .4323 .38479 L p
1 g
F P
s
P
p
.002 w
.4323 .38479 m .41429 .40137 L .48586 .40093 L p
1 g
F P
s
P
p
.002 w
.32115 .73195 m .29622 .70547 L .30066 .73856 L p
1 g
F P
s
P
p
.002 w
.30066 .73856 m .32446 .75758 L .32115 .73195 L p
1 g
F P
s
P
p
.002 w
.63814 .42017 m .63748 .43505 L .69169 .48037 L p
1 g
F P
s
P
p
.002 w
.63748 .43505 m .63814 .42017 L .57765 .38989 L p
1 g
F P
s
P
p
.002 w
.31226 .53954 m .31574 .5039 L .27573 .53838 L p
1 g
F P
s
P
p
.002 w
.27573 .53838 m .27431 .57186 L .31226 .53954 L p
1 g
F P
s
P
p
.002 w
.35343 .77272 m .32446 .75758 L .33934 .78398 L p
1 g
F P
s
P
p
.002 w
.33934 .78398 m .36355 .7908 L .35343 .77272 L p
1 g
F P
s
P
p
.002 w
.57765 .38989 m .57077 .40167 L .63748 .43505 L p
1 g
F P
s
P
p
.002 w
.70956 .69953 m .72707 .67189 L .71236 .61527 L p
1 g
F P
s
P
p
.002 w
.72364 .58624 m .71236 .61527 L .72707 .67189 L p
1 g
F P
s
P
p
.002 w
.72364 .58624 m .72859 .55826 L .69076 .50333 L p
1 g
F P
s
P
p
.002 w
.69169 .48037 m .69076 .50333 L .72859 .55826 L p
1 g
F P
s
P
p
.002 w
.38527 .45234 m .39844 .42407 L .33771 .44352 L p
1 g
F P
s
P
p
.002 w
.33771 .44352 m .32434 .4716 L .38527 .45234 L p
1 g
F P
s
P
p
.002 w
.50059 .84437 m .47426 .83227 L .45193 .83433 L p
1 g
F P
s
P
p
.002 w
.47426 .83227 m .50059 .84437 L .52627 .83311 L p
1 g
F P
s
P
p
.002 w
.55973 .83549 m .52627 .83311 L .50059 .84437 L p
1 g
F P
s
P
p
.002 w
.69076 .50333 m .69169 .48037 L .63748 .43505 L p
1 g
F P
s
P
p
.002 w
.30737 .6768 m .29029 .64209 L .27716 .67662 L p
1 g
F P
s
P
p
.002 w
.27716 .67662 m .29622 .70547 L .30737 .6768 L p
1 g
F P
s
P
p
.002 w
.61624 .80322 m .64851 .78951 L .65704 .74747 L p
1 g
F P
s
P
p
.002 w
.68601 .72498 m .65704 .74747 L .64851 .78951 L p
1 g
F P
s
P
p
.002 w
.52627 .83311 m .55973 .83549 L .58045 .81168 L p
1 g
F P
s
P
p
.002 w
.61624 .80322 m .58045 .81168 L .55973 .83549 L p
1 g
F P
s
P
p
.002 w
.40052 .80126 m .3805 .80757 L .40246 .82129 L p
1 g
F P
s
P
p
.002 w
.40246 .82129 m .41173 .80827 L .40052 .80126 L p
1 g
F P
s
P
p
.002 w
.41173 .80827 m .40246 .82129 L .42712 .83053 L p
1 g
F P
s
P
p
.002 w
.42712 .83053 m .42433 .81299 L .41173 .80827 L p
1 g
F P
s
P
p
.002 w
.42433 .81299 m .42712 .83053 L .45193 .83433 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.3919 .7927 m .36355 .7908 L .3805 .80757 L p
1 g
F P
s
P
p
.002 w
.3805 .80757 m .40052 .80126 L .3919 .7927 L p
1 g
F P
s
P
p
.002 w
.31405 .57749 m .31226 .53954 L .27431 .57186 L p
1 g
F P
s
P
p
.002 w
.27431 .57186 m .27918 .60676 L .31405 .57749 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.35128 .75525 m .32115 .73195 L .32446 .75758 L p
1 g
F P
s
P
p
.002 w
.32446 .75758 m .35343 .77272 L .35128 .75525 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.45193 .83433 m .43699 .81491 L .42433 .81299 L p
1 g
F P
s
P
p
.002 w
.45193 .83433 m .47426 .83227 L p
.45463 .82313 L 1 g
F P
s
P
p
.002 w
.46691 .82704 m .47426 .83227 L .47873 .83029 L p
1 g
F P
s
P
p
.4771 .82984 m .47279 .82891 L .47606 .82995 L 1 g
F
P
p
.48758 .82869 m .47367 .8289 L .4771 .82984 L 1 g
F
P
p
.47367 .8289 m .47279 .82891 L .4771 .82984 L 1 g
F
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .46357 .82597 L p
1 g
F P
s
P
p
.002 w
.47426 .83227 m .46974 .82905 L p
.45463 .82313 L 1 g
F P
s
P
p
.002 w
.46974 .82905 m .46691 .82704 L p
.46357 .82597 L 1 g
F P
s
P
p
.46974 .82905 m .46357 .82597 L .45463 .82313 L 1 g
F
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.42433 .81299 m .43699 .81491 L .43012 .80185 L p
1 g
F P
s
P
p
.002 w
.42379 .79478 m .42433 .81299 L p
.42996 .80216 L 1 g
F P
s
P
p
.43012 .80185 m .42951 .80117 L .42996 .80216 L 1 g
F
P
p
.42951 .80117 m .42379 .79478 L .42996 .80216 L 1 g
F
P
p
.002 w
.42951 .80117 m .43042 .79874 L p
.42525 .7916 L 1 g
F P
s
P
p
.002 w
.42486 .79072 m .42363 .78951 L .42811 .79802 L p
1 g
F P
s
P
p
.42525 .7916 m .42523 .79156 L .42811 .79802 L 1 g
F
P
p
.42525 .7916 m .42811 .79802 L .42951 .80117 L 1 g
F
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42951 .80118 L p
1 g
F P
s
P
p
.002 w
.43699 .81491 m .44158 .81448 L p
.43083 .80263 L 1 g
F P
s
P
p
.44427 .81291 m .42951 .80118 L .43574 .80804 L 1 g
F
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.41861 .75934 m .42278 .78441 L p
.42296 .78397 L 1 g
F P
s
P
p
.002 w
.42541 .76111 m .41861 .75934 L p
.42103 .77307 L 1 g
F P
s
P
p
.42103 .77307 m .42296 .78397 L .42475 .76726 L 1 g
F
P
p
.42103 .77307 m .42475 .76726 L .42541 .76111 L 1 g
F
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .42579 .76511 L .42475 .76726 L p
1 g
F P
s
P
p
.002 w
.42475 .76726 m .42372 .76938 L p
.42386 .77561 L 1 g
F P
s
P
p
.424 .78222 m .42475 .76726 L .42386 .77561 L 1 g
F
P
p
.002 w
.42288 .78473 m .424 .78222 L p
.42386 .77561 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42288 .78473 L p
1 g
F P
s
P
p
.43042 .79874 m .42288 .78473 L .42293 .7849 L 1 g
F
P
p
.43042 .79874 m .42286 .78477 L .42297 .7851 L 1 g
F
P
p
.002 w
.42278 .78441 m .42363 .78951 L .42398 .78834 L p
1 g
F P
s
P
p
.42315 .78563 m .42283 .78485 L .42298 .78532 L 1 g
F
P
p
.43042 .79874 m .42303 .78521 L .42315 .78563 L 1 g
F
P
p
.42303 .78521 m .42283 .78485 L .42315 .78563 L 1 g
F
P
p
.002 w
.40632 .75897 m .42257 .78764 L p
.42278 .78441 L 1 g
F P
s
P
p
.002 w
.42278 .78441 m .41861 .75934 L .4152 .75924 L p
1 g
F P
s
P
p
.002 w
.4152 .75924 m .40632 .75897 L p
.42278 .78441 L 1 g
F P
s
P
p
.42278 .78441 m .42288 .78473 L .42296 .78397 L 1 g
F
P
p
.002 w
.40632 .75897 m .39608 .76166 L .4225 .78836 L p
1 g
F P
s
P
p
.002 w
.4225 .78836 m .42363 .78951 L .42257 .78764 L p
1 g
F P
s
P
p
.002 w
.42257 .78764 m .40632 .75897 L p
.4225 .78836 L 1 g
F P
s
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42286 .78477 L p
1 g
F P
s
P
p
.002 w
.42286 .78477 m .42288 .78473 L p
.4229 .7844 L 1 g
F P
s
P
p
.4229 .7844 m .42372 .76938 L .42286 .78477 L 1 g
F
P
p
.002 w
.42288 .78473 m .42288 .78473 L p
.42288 .78472 L 1 g
F P
s
P
p
.42288 .78472 m .42372 .76938 L .42288 .78473 L 1 g
F
P
p
.002 w
.42257 .78764 m .42363 .78951 L .42286 .78489 L p
1 g
F P
s
P
p
.002 w
.42286 .78489 m .42278 .78441 L p
.42257 .78764 L 1 g
F P
s
P
p
.43042 .79874 m .42278 .78496 L .42298 .78554 L 1 g
F
P
p
.43042 .79874 m .42272 .78508 L .42296 .78573 L 1 g
F
P
p
.43042 .79874 m .42266 .78521 L .42292 .78587 L 1 g
F
P
p
.43042 .79874 m .42261 .78533 L .42285 .78591 L 1 g
F
P
p
.002 w
.42398 .78834 m .42363 .78951 L .42417 .78896 L p
1 g
F P
s
P
p
.002 w
.42417 .78896 m .42363 .78951 L .42426 .78924 L p
1 g
F P
s
P
p
.43042 .79874 m .42257 .78543 L .42523 .79156 L 1 g
F
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.42398 .78834 m .43158 .76272 L p
.42296 .78397 L 1 g
F P
s
P
p
.42288 .78473 m .42398 .78834 L .42296 .78397 L 1 g
F
P
p
.002 w
.42475 .76726 m .42579 .76511 L p
.43049 .75816 L 1 g
F P
s
P
p
.002 w
.42821 .76185 m .43158 .76272 L p
.43001 .75893 L 1 g
F P
s
P
p
.43049 .75816 m .42821 .76185 L .42475 .76726 L 1 g
F
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.43158 .76272 m .4354 .75069 L p
.43001 .75893 L 1 g
F P
s
P
p
.002 w
.43483 .75111 m .43569 .74928 L p
.44356 .7446 L 1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.44241 .74546 m .4438 .76876 L .45325 .73789 L 1 g
F
P
p
.002 w
.45199 .7383 m .45268 .73647 L p
.46375 .73387 L 1 g
F P
s
P
p
.002 w
.4658 .74329 m .47665 .7295 L p
.46334 .73403 L 1 g
F P
s
P
p
.002 w
.47462 .72964 m .47494 .72815 L p
.48671 .72829 L 1 g
F P
s
P
p
.48798 .72814 m .48583 .75922 L .50378 .72727 L 1 g
F
P
p
.002 w
.5 .72527 m .52506 .72815 L .5254 .72971 L p
1 g
F P
s
P
p
.002 w
.51836 .73733 m .52704 .73042 L p
.51749 .72886 L 1 g
F P
s
P
p
.002 w
.5254 .72971 m .52506 .72815 L p
.53527 .73326 L 1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57701 .78448 L p
1 g
F P
s
P
p
.002 w
.58619 .78086 m .57765 .78297 L p
.57717 .78777 L 1 g
F P
s
P
p
.002 w
.57765 .78297 m .57694 .78314 L p
.57701 .78448 L 1 g
F P
s
P
p
.57765 .78297 m .57701 .78448 L .57717 .78777 L 1 g
F
P
p
.002 w
.57701 .78448 m .576 .78222 L p
.57415 .79117 L 1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .5702 .8004 L p
1 g
F P
s
P
p
.576 .78222 m .5702 .8004 L .57415 .79117 L 1 g
F
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.54636 .79069 m .54216 .81459 L p
.57484 .78955 L 1 g
F P
s
P
p
.57717 .78777 m .57554 .78792 L .57484 .78955 L 1 g
F
P
p
.57554 .78792 m .54636 .79069 L .57484 .78955 L 1 g
F
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53639 .82575 L p
1 g
F P
s
P
p
.002 w
.58045 .81168 m .57565 .81205 L p
.52627 .83311 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55638 .81527 L p
1 g
F P
s
P
p
.002 w
.57565 .81205 m .56029 .81321 L p
.55531 .81613 L 1 g
F P
s
P
p
.57565 .81205 m .55531 .81613 L .54869 .82146 L 1 g
F
P
p
.56958 .79874 m .55638 .81527 L .55878 .81333 L 1 g
F
P
p
.56958 .79874 m .55878 .81333 L .56453 .80683 L 1 g
F
P
p
.55573 .81291 m .53639 .82575 L .54768 .81983 L 1 g
F
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.54869 .82146 m .55531 .81613 L .54249 .82362 L 1 g
F
P
p
.57565 .81205 m .54249 .82362 L .52627 .83311 L 1 g
F
P
p
.002 w
.52946 .82939 m .52627 .83311 L p
.56029 .81321 L 1 g
F P
s
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.55878 .81333 m .58045 .81168 L .58585 .78268 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.54216 .81459 m .55878 .81333 L p
.58619 .78086 L 1 g
F P
s
P
p
.002 w
.58585 .78268 m .58619 .78086 L p
.55878 .81333 L 1 g
F P
s
P
p
.56453 .80683 m .55878 .81333 L .56216 .81061 L 1 g
F
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.52627 .83311 m .51703 .83081 L p
.5076 .832 L 1 g
F P
s
P
p
.002 w
.48742 .83138 m .48758 .82869 L p
.47606 .82995 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48742 .83138 L p
1 g
F P
s
P
p
.50195 .83271 m .48918 .83138 L .49746 .83264 L 1 g
F
P
p
.48918 .83138 m .48742 .83138 L .49746 .83264 L 1 g
F
P
p
.51242 .82869 m .48742 .83138 L .50107 .83137 L 1 g
F
P
p
.5076 .832 m .47873 .83029 L .50195 .83271 L 1 g
F
P
p
.5076 .832 m .50628 .83137 L .4971 .83138 L 1 g
F
P
p
.002 w
.47873 .83029 m .47426 .83227 L p
.49746 .83264 L 1 g
F P
s
P
p
.002 w
.48742 .83138 m .48724 .83464 L p
.50107 .83137 L 1 g
F P
s
P
p
.48918 .83138 m .47873 .83029 L .48742 .83138 L 1 g
F
P
p
.52627 .83311 m .5076 .832 L .50195 .83271 L 1 g
F
P
p
.002 w
.51703 .83081 m .52627 .83311 L .53095 .82765 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53683 .8283 L p
1 g
F P
s
P
p
.002 w
.53639 .82575 m .53597 .82325 L p
.52361 .82931 L 1 g
F P
s
P
p
.52361 .82931 m .5279 .82834 L .53639 .82575 L 1 g
F
P
p
.5218 .8302 m .52467 .82984 L .53639 .82575 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.56029 .81321 m .54216 .81459 L .53095 .82765 L p
1 g
F P
s
P
p
.002 w
.53095 .82765 m .52946 .82939 L p
.53639 .82575 L 1 g
F P
s
P
p
.56029 .81321 m .53095 .82765 L .53639 .82575 L 1 g
F
P
p
.002 w
.53683 .8283 m .53639 .82575 L p
.52595 .82968 L 1 g
F P
s
P
p
.52595 .82968 m .51276 .83464 L .53683 .8283 L 1 g
F
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51258 .83137 L p
1 g
F P
s
P
p
.002 w
.51258 .83137 m .51242 .82869 L p
.50107 .83137 L 1 g
F P
s
P
p
.002 w
.51703 .83081 m .49175 .8245 L p
.5076 .832 L 1 g
F P
s
P
p
.50107 .83137 m .48724 .83464 L .51258 .83137 L 1 g
F
P
p
.48758 .82869 m .46357 .82597 L .47279 .82891 L 1 g
F
P
p
.002 w
.49175 .8245 m .47873 .83029 L p
.4971 .83138 L 1 g
F P
s
P
p
.50628 .83137 m .49175 .8245 L .4971 .83138 L 1 g
F
P
p
.002 w
.49175 .8245 m .51703 .83081 L p
.54216 .81459 L 1 g
F P
s
P
p
.002 w
.53095 .82765 m .54216 .81459 L p
.51703 .83081 L 1 g
F P
s
P
p
.52361 .82931 m .5218 .8302 L .5279 .82834 L 1 g
F
P
p
.5218 .8302 m .51728 .83242 L .52467 .82984 L 1 g
F
P
p
.002 w
.55638 .81527 m .55726 .81844 L p
.56216 .81061 L 1 g
F P
s
P
p
.51728 .83242 m .51276 .83464 L .53639 .82575 L 1 g
F
P
p
.002 w
.53639 .82575 m .53695 .82905 L p
.54768 .81983 L 1 g
F P
s
P
p
.002 w
.5702 .8004 m .5715 .8039 L p
.57415 .79117 L 1 g
F P
s
P
p
.57421 .76511 m .57701 .78448 L .57694 .78314 L 1 g
F
P
p
.57421 .76511 m .57694 .78314 L .5759 .77457 L 1 g
F
P
p
.002 w
.57694 .78314 m .58423 .78134 L p
.57493 .7666 L 1 g
F P
s
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57493 .7666 L p
1 g
F P
s
P
p
.56431 .74928 m .57493 .7666 L .56948 .75796 L 1 g
F
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.54636 .79069 m .57694 .78314 L p
.57493 .7666 L 1 g
F P
s
P
p
.002 w
.53819 .76396 m .56526 .75127 L p
.54467 .73651 L 1 g
F P
s
P
p
.56431 .74928 m .56948 .75796 L .56526 .75127 L 1 g
F
P
p
.002 w
.5652 .75117 m .56431 .74928 L p
.56526 .75127 L 1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .5652 .75117 L p
1 g
F P
s
P
p
.54732 .73647 m .5652 .75117 L .55453 .74286 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.54467 .73651 m .56526 .75127 L .5652 .75117 L 1 g
F
P
p
.002 w
.54773 .73757 m .54732 .73647 L p
.55453 .74286 L 1 g
F P
s
P
p
.54773 .73757 m .5652 .75117 L .55939 .74159 L 1 g
F
P
p
.54467 .73651 m .5652 .75117 L .54773 .73757 L 1 g
F
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.53819 .76396 m .54636 .79069 L p
.57034 .75468 L 1 g
F P
s
P
p
.002 w
.57594 .74627 m .5653 .75125 L p
.57034 .75468 L 1 g
F P
s
P
p
.002 w
.5653 .75125 m .53819 .76396 L p
.57034 .75468 L 1 g
F P
s
P
p
.002 w
.5652 .75117 m .5652 .75118 L p
.55453 .74286 L 1 g
F P
s
P
p
.002 w
.5652 .75118 m .56611 .75311 L p
.55968 .74742 L 1 g
F P
s
P
p
.55453 .74286 m .5652 .75118 L .55968 .74742 L 1 g
F
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54773 .73757 L p
1 g
F P
s
P
p
.55453 .74286 m .56611 .75311 L .54773 .73757 L 1 g
F
P
p
.55939 .74159 m .5652 .75117 L .57466 .74686 L 1 g
F
P
p
.002 w
.56526 .75127 m .5653 .75125 L p
.5652 .75117 L 1 g
F P
s
P
p
.002 w
.5653 .75125 m .57466 .74686 L p
.5652 .75117 L 1 g
F P
s
P
p
.002 w
.5652 .75118 m .5652 .75117 L p
.56526 .75127 L 1 g
F P
s
P
p
.57299 .75069 m .56883 .75693 L .57493 .7666 L 1 g
F
P
p
.56883 .75693 m .54636 .79069 L .57493 .7666 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .5652 .75118 L p
1 g
F P
s
P
p
.56948 .75796 m .57628 .76938 L .5652 .75118 L 1 g
F
P
p
.002 w
.57493 .7666 m .57628 .76938 L p
.56948 .75796 L 1 g
F P
s
P
p
.57299 .75069 m .57493 .7666 L .58619 .78086 L 1 g
F
P
p
.002 w
.58423 .78134 m .58619 .78086 L p
.57493 .7666 L 1 g
F P
s
P
p
.5759 .77457 m .57694 .78314 L .57676 .77937 L 1 g
F
P
p
.002 w
.58619 .78086 m .57594 .74627 L p
.57299 .75069 L 1 g
F P
s
P
p
.002 w
.57694 .78314 m .54636 .79069 L p
.57717 .78777 L 1 g
F P
s
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57701 .78448 L p
1 g
F P
s
P
p
.57415 .79117 m .5715 .8039 L .57701 .78448 L 1 g
F
P
p
.002 w
.57701 .78448 m .57811 .78694 L p
.57676 .77937 L 1 g
F P
s
P
p
.53527 .73326 m .52704 .73042 L .5254 .72971 L 1 g
F
P
p
.002 w
.51836 .73733 m .53819 .76396 L p
.54467 .73651 L 1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52704 .73042 m .51836 .73733 L p
.54467 .73651 L 1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.55052 .71174 m .52704 .73042 L p
.54467 .73651 L 1 g
F P
s
P
p
.51749 .72886 m .52704 .73042 L .5254 .72971 L 1 g
F
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52543 .72987 L p
1 g
F P
s
P
p
.002 w
.52543 .72987 m .5254 .72971 L p
.52686 .73036 L 1 g
F P
s
P
p
.52686 .73036 m .54864 .73996 L .52543 .72987 L 1 g
F
P
p
.53527 .73326 m .54516 .73822 L .52704 .73042 L 1 g
F
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.57594 .74627 m .55052 .71174 L p
.54467 .73651 L 1 g
F P
s
P
p
.002 w
.57466 .74686 m .57594 .74627 L p
.54467 .73651 L 1 g
F P
s
P
p
.002 w
.52704 .73042 m .52763 .72995 L p
.5254 .72971 L 1 g
F P
s
P
p
.54516 .73822 m .54864 .73996 L .5254 .72971 L 1 g
F
P
p
.5 .72527 m .5254 .72971 L .51704 .72881 L 1 g
F
P
p
.5 .72527 m .51704 .72881 L .51308 .72839 L 1 g
F
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.50626 .72765 m .51836 .73733 L p
.51749 .72886 L 1 g
F P
s
P
p
.48798 .72814 m .50378 .72727 L .5 .7267 L 1 g
F
P
p
.002 w
.48583 .75922 m .51836 .73733 L .50626 .72765 L p
1 g
F P
s
P
p
.50378 .72727 m .48583 .75922 L .50626 .72765 L 1 g
F
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .7267 L p
1 g
F P
s
P
p
.002 w
.5 .7267 m .5 .72527 L p
.51658 .72922 L 1 g
F P
s
P
p
.51658 .72922 m .52576 .73141 L .5 .7267 L 1 g
F
P
p
.002 w
.50626 .72765 m .5044 .72617 L p
.50378 .72727 L 1 g
F P
s
P
p
.002 w
.51261 .68126 m .48897 .71384 L .50626 .72765 L p
1 g
F P
s
P
p
.51261 .68126 m .50626 .72765 L .51749 .72886 L 1 g
F
P
p
.51308 .72839 m .52559 .73059 L .51658 .72922 L 1 g
F
P
p
.51704 .72881 m .52559 .73059 L .51308 .72839 L 1 g
F
P
p
.002 w
.5254 .72971 m .52559 .73059 L p
.51704 .72881 L 1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.55052 .71174 m .51261 .68126 L p
.51749 .72886 L 1 g
F P
s
P
p
.002 w
.52763 .72995 m .55052 .71174 L p
.51749 .72886 L 1 g
F P
s
P
p
.5 .7267 m .50378 .72727 L .5044 .72617 L 1 g
F
P
p
.002 w
.52559 .73059 m .52576 .73141 L p
.51658 .72922 L 1 g
F P
s
P
p
.48671 .72829 m .47665 .7295 L .47462 .72964 L 1 g
F
P
p
.002 w
.4658 .74329 m .48583 .75922 L p
.48798 .72814 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47665 .7295 m .4658 .74329 L p
.48798 .72814 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72781 L p
1 g
F P
s
P
p
.002 w
.5 .72781 m .5 .72845 L p
.49243 .72836 L 1 g
F P
s
P
p
.47494 .72815 m .5 .72781 L .49243 .72836 L 1 g
F
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.46334 .73403 m .47665 .7295 L .47462 .72964 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47462 .72964 L p
1 g
F P
s
P
p
.002 w
.47462 .72964 m .47424 .73141 L p
.46375 .73387 L 1 g
F P
s
P
p
.45268 .73647 m .47462 .72964 L .46375 .73387 L 1 g
F
P
p
.46375 .73387 m .45423 .73758 L .45199 .7383 L 1 g
F
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.44241 .74546 m .45325 .73789 L .45199 .7383 L 1 g
F
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43158 .76272 m .4438 .76876 L p
.44241 .74546 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45199 .7383 L p
1 g
F P
s
P
p
.43569 .74928 m .45199 .7383 L .45034 .73953 L 1 g
F
P
p
.43569 .74928 m .45192 .73848 L .44962 .74039 L 1 g
F
P
p
.44498 .74375 m .44962 .74039 L .44708 .74251 L 1 g
F
P
p
.43569 .74928 m .44962 .74039 L .44498 .74375 L 1 g
F
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43483 .75111 L p
1 g
F P
s
P
p
.43001 .75893 m .4354 .75069 L .43483 .75111 L 1 g
F
P
p
.002 w
.43483 .75111 m .43389 .75311 L p
.43049 .75816 L 1 g
F P
s
P
p
.42579 .76511 m .43483 .75111 L .43049 .75816 L 1 g
F
P
p
.002 w
.43574 .74963 m .44156 .73132 L p
.43261 .75271 L 1 g
F P
s
P
p
.43001 .75893 m .43483 .75111 L .43261 .75271 L 1 g
F
P
p
.43483 .75111 m .43574 .74963 L .43261 .75271 L 1 g
F
P
p
.44356 .7446 m .4354 .75069 L .43483 .75111 L 1 g
F
P
p
.002 w
.44156 .73132 m .4354 .75069 L p
.44241 .74546 L 1 g
F P
s
P
p
.002 w
.4354 .75069 m .43158 .76272 L p
.44241 .74546 L 1 g
F P
s
P
p
.002 w
.45199 .7383 m .45192 .73848 L p
.45034 .73953 L 1 g
F P
s
P
p
.002 w
.45192 .73848 m .45136 .73996 L p
.44708 .74251 L 1 g
F P
s
P
p
.002 w
.45332 .69619 m .44156 .73132 L .45346 .7372 L p
1 g
F P
s
P
p
.002 w
.45346 .7372 m .45423 .73758 L p
.45421 .73657 L 1 g
F P
s
P
p
.45332 .69619 m .45346 .7372 L .45421 .73657 L 1 g
F
P
p
.002 w
.45423 .73758 m .4658 .74329 L p
.46334 .73403 L 1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.45332 .69619 m .45423 .73758 L .46334 .73403 L 1 g
F
P
p
.002 w
.47739 .72856 m .48897 .71384 L p
.46834 .73009 L 1 g
F P
s
P
p
.46334 .73403 m .47462 .72964 L .46834 .73009 L 1 g
F
P
p
.47462 .72964 m .47739 .72856 L .46834 .73009 L 1 g
F
P
p
.002 w
.48897 .71384 m .47665 .7295 L p
.48798 .72814 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .4746 .72974 L p
1 g
F P
s
P
p
.002 w
.4746 .72974 m .47462 .72964 L p
.47595 .72958 L 1 g
F P
s
P
p
.47595 .72958 m .5 .72845 L .4746 .72974 L 1 g
F
P
p
.48671 .72829 m .49243 .72836 L .47665 .7295 L 1 g
F
P
p
.002 w
.5044 .72617 m .48897 .71384 L p
.48798 .72814 L 1 g
F P
s
P
p
.002 w
.47665 .7295 m .47739 .72856 L p
.47462 .72964 L 1 g
F P
s
P
p
.49243 .72836 m .5 .72845 L .47462 .72964 L 1 g
F
P
p
.46375 .73387 m .47136 .73209 L .45423 .73758 L 1 g
F
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.48897 .71384 m .45332 .69619 L p
.46334 .73403 L 1 g
F P
s
P
p
.45199 .7383 m .45325 .73789 L .45346 .7372 L 1 g
F
P
p
.002 w
.4438 .76876 m .4658 .74329 L .45346 .7372 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45199 .7383 L p
1 g
F P
s
P
p
.47136 .73209 m .47424 .73141 L .45199 .7383 L 1 g
F
P
p
.44356 .7446 m .44498 .74375 L .4354 .75069 L 1 g
F
P
p
.002 w
.45346 .7372 m .44156 .73132 L p
.44241 .74546 L 1 g
F P
s
P
p
.002 w
.4354 .75069 m .43574 .74963 L p
.43483 .75111 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43483 .75111 L p
1 g
F P
s
P
p
.44498 .74375 m .45136 .73996 L .43483 .75111 L 1 g
F
P
p
.002 w
.44156 .73132 m .41584 .72464 L p
.43001 .75893 L 1 g
F P
s
P
p
.002 w
.43158 .76272 m .42821 .76185 L p
.42296 .78397 L 1 g
F P
s
P
p
.002 w
.42821 .76185 m .42541 .76111 L p
.42475 .76726 L 1 g
F P
s
P
p
.42475 .76726 m .42296 .78397 L .42821 .76185 L 1 g
F
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42428 .76822 L p
1 g
F P
s
P
p
.002 w
.42428 .76822 m .42475 .76726 L p
.42749 .76301 L 1 g
F P
s
P
p
.42749 .76301 m .43389 .75311 L .42428 .76822 L 1 g
F
P
p
.43049 .75816 m .43214 .7557 L .42821 .76185 L 1 g
F
P
p
.002 w
.41584 .72464 m .41861 .75934 L .42821 .76185 L p
1 g
F P
s
P
p
.41584 .72464 m .42821 .76185 L .43001 .75893 L 1 g
F
P
p
.43214 .7557 m .43389 .75311 L .42475 .76726 L 1 g
F
P
p
.42386 .77561 m .42372 .76938 L .42288 .78473 L 1 g
F
P
p
.002 w
.42288 .78473 m .42286 .78477 L p
.42293 .7849 L 1 g
F P
s
P
p
.002 w
.42286 .78477 m .42283 .78485 L p
.42297 .7851 L 1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.4438 .76876 m .43158 .76272 L .42398 .78834 L p
1 g
F P
s
P
p
.002 w
.42417 .78896 m .4438 .76876 L p
.42398 .78834 L 1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.45393 .77677 m .4438 .76876 L .42417 .78896 L p
1 g
F P
s
P
p
.002 w
.42426 .78924 m .45393 .77677 L p
.42417 .78896 L 1 g
F P
s
P
p
.002 w
.42283 .78485 m .42278 .78496 L p
.42298 .78532 L 1 g
F P
s
P
p
.002 w
.42278 .78496 m .42272 .78508 L p
.42298 .78554 L 1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.46086 .78588 m .45393 .77677 L .42426 .78924 L p
1 g
F P
s
P
p
.002 w
.42426 .78924 m .42363 .78951 L .42433 .78944 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.42433 .78944 m .46086 .78588 L p
.42426 .78924 L 1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.46384 .79508 m .46086 .78588 L .42433 .78944 L p
1 g
F P
s
P
p
.002 w
.42433 .78944 m .42363 .78951 L .4244 .78961 L p
1 g
F P
s
P
p
.002 w
.4244 .78961 m .46384 .79508 L p
.42433 .78944 L 1 g
F P
s
P
p
.002 w
.42272 .78508 m .42266 .78521 L p
.42296 .78573 L 1 g
F P
s
P
p
.002 w
.42266 .78521 m .42261 .78533 L p
.42292 .78587 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.46256 .80337 m .46384 .79508 L .4244 .78961 L p
1 g
F P
s
P
p
.002 w
.4244 .78961 m .42363 .78951 L .42447 .78981 L p
1 g
F P
s
P
p
.002 w
.42447 .78981 m .46256 .80337 L p
.4244 .78961 L 1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.4572 .80984 m .46256 .80337 L .42447 .78981 L p
1 g
F P
s
P
p
.002 w
.42447 .78981 m .42363 .78951 L .42459 .79009 L p
1 g
F P
s
P
p
.002 w
.42459 .79009 m .4572 .80984 L p
.42447 .78981 L 1 g
F P
s
P
p
.002 w
.42261 .78533 m .42257 .78543 L p
.42285 .78591 L 1 g
F P
s
P
p
.002 w
.42459 .79009 m .42363 .78951 L .42486 .79072 L p
1 g
F P
s
P
p
.002 w
.42257 .78543 m .42189 .78694 L p
.42523 .79156 L 1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.44835 .81383 m .4572 .80984 L .42459 .79009 L p
1 g
F P
s
P
p
.002 w
.42486 .79072 m .44835 .81383 L p
.42459 .79009 L 1 g
F P
s
P
p
.002 w
.42811 .79802 m .43012 .80185 L p
.42486 .79072 L 1 g
F P
s
P
p
.002 w
.43012 .80185 m .43699 .81491 L p
.43083 .80263 L 1 g
F P
s
P
p
.42486 .79072 m .43012 .80185 L .43083 .80263 L 1 g
F
P
p
.4496 .82078 m .44651 .81836 L .43699 .81491 L 1 g
F
P
p
.002 w
.44344 .81593 m .44427 .81291 L p
.42968 .80511 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44344 .81593 L p
1 g
F P
s
P
p
.46403 .82325 m .44344 .81593 L .4532 .8208 L 1 g
F
P
p
.002 w
.44835 .81383 m .44068 .81456 L p
.45299 .8207 L 1 g
F P
s
P
p
.002 w
.44068 .81456 m .43699 .81491 L p
.45299 .8207 L 1 g
F P
s
P
p
.002 w
.43699 .81491 m .43963 .81835 L p
.45463 .82313 L 1 g
F P
s
P
p
.002 w
.42968 .80511 m .44274 .81844 L .44331 .81638 L p
1 g
F P
s
P
p
.002 w
.44331 .81638 m .44344 .81593 L p
.44158 .81448 L 1 g
F P
s
P
p
.44158 .81448 m .42968 .80511 L .44331 .81638 L 1 g
F
P
p
.002 w
.42951 .80118 m .4285 .8039 L p
.43574 .80804 L 1 g
F P
s
P
p
.002 w
.44835 .81383 m .42486 .79072 L p
.43083 .80263 L 1 g
F P
s
P
p
.44427 .81291 m .43559 .80795 L .43613 .80856 L 1 g
F
P
p
.002 w
.44158 .81448 m .44835 .81383 L p
.43083 .80263 L 1 g
F P
s
P
p
.002 w
.43012 .80185 m .42363 .78951 L .42379 .79478 L p
1 g
F P
s
P
p
.002 w
.41173 .80827 m .42363 .78951 L .40052 .80126 L closepath p
1 g
F P
s
P
p
.002 w
.42433 .81299 m .42363 .78951 L .41173 .80827 L closepath p
1 g
F P
s
P
p
.002 w
.40052 .80126 m .42363 .78951 L .3919 .7927 L closepath p
1 g
F P
s
P
p
.002 w
.3919 .7927 m .42363 .78951 L .3868 .78349 L closepath p
1 g
F P
s
P
p
.002 w
.3868 .78349 m .42363 .78951 L .38578 .77464 L closepath p
1 g
F P
s
P
p
.002 w
.38578 .77464 m .42363 .78951 L .38898 .76708 L closepath p
1 g
F P
s
P
p
.002 w
.38898 .76708 m .42363 .78951 L .39608 .76166 L closepath p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42951 .80117 L p
1 g
F P
s
P
p
.42523 .79156 m .42189 .78694 L .42951 .80117 L 1 g
F
P
p
.002 w
.4285 .8039 m .42968 .80511 L p
.43613 .80856 L 1 g
F P
s
P
p
.43559 .80795 m .4285 .8039 L .43613 .80856 L 1 g
F
P
p
.45463 .82313 m .45299 .8207 L .44651 .81836 L 1 g
F
P
p
.45463 .82313 m .44651 .81836 L .4496 .82078 L 1 g
F
P
p
.002 w
.46357 .82597 m .46403 .82325 L p
.4532 .8208 L 1 g
F P
s
P
p
.002 w
.46691 .82704 m .44835 .81383 L p
.45463 .82313 L 1 g
F P
s
P
p
.002 w
.44344 .81593 m .44274 .81844 L p
.4532 .8208 L 1 g
F P
s
P
p
.002 w
.43963 .81835 m .45193 .83433 L p
.45463 .82313 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46357 .82597 L p
1 g
F P
s
P
p
.4532 .8208 m .44274 .81844 L .46357 .82597 L 1 g
F
P
p
.002 w
.46357 .82597 m .46305 .82905 L p
.47279 .82891 L 1 g
F P
s
P
p
.002 w
.44835 .81383 m .46691 .82704 L p
.49175 .8245 L 1 g
F P
s
P
p
.002 w
.47873 .83029 m .49175 .8245 L p
.46691 .82704 L 1 g
F P
s
P
p
.002 w
.4873 .83353 m .48742 .83138 L p
.47606 .82995 L 1 g
F P
s
P
p
.002 w
.46305 .82905 m .48724 .83464 L .4873 .83353 L p
1 g
F P
s
P
p
.47279 .82891 m .46305 .82905 L .4873 .83353 L 1 g
F
P
p
.002 w
.56178 .41954 m .57077 .40167 L .49953 .38427 L p
1 g
F P
s
P
p
.002 w
.49953 .38427 m .48586 .40093 L .56178 .41954 L p
1 g
F P
s
P
p
.002 w
.47238 .42379 m .48586 .40093 L .41429 .40137 L p
1 g
F P
s
P
p
.002 w
.41429 .40137 m .39844 .42407 L .47238 .42379 L p
1 g
F P
s
P
p
.002 w
.68601 .72498 m .70956 .69953 L .69498 .6445 L p
1 g
F P
s
P
p
.002 w
.71236 .61527 m .69498 .6445 L .70956 .69953 L p
1 g
F P
s
P
p
.004 w
.46191 .70044 m
.5 .6118 L
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.71236 .61527 m .72364 .58624 L .68445 .52967 L p
1 g
F P
s
P
p
.002 w
.69076 .50333 m .68445 .52967 L .72364 .58624 L p
1 g
F P
s
P
p
.002 w
.3868 .78349 m .35343 .77272 L .36355 .7908 L p
1 g
F P
s
P
p
.002 w
.36355 .7908 m .3919 .7927 L .3868 .78349 L p
1 g
F P
s
P
p
.002 w
.37521 .48541 m .38527 .45234 L .32434 .4716 L p
1 g
F P
s
P
p
.002 w
.32434 .4716 m .31574 .5039 L .37521 .48541 L p
1 g
F P
s
P
p
.002 w
.32997 .70986 m .30737 .6768 L .29622 .70547 L p
1 g
F P
s
P
p
.002 w
.29622 .70547 m .32115 .73195 L .32997 .70986 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.58045 .81168 m .61624 .80322 L .62345 .7663 L p
1 g
F P
s
P
p
.002 w
.65704 .74747 m .62345 .7663 L .61624 .80322 L p
1 g
F P
s
P
p
.002 w
.63748 .43505 m .63294 .45512 L .69076 .50333 L p
1 g
F P
s
P
p
.002 w
.63294 .45512 m .63748 .43505 L .57077 .40167 L p
1 g
F P
s
P
p
.002 w
.57077 .40167 m .56178 .41954 L .63294 .45512 L p
1 g
F P
s
P
p
.002 w
.32111 .61664 m .31405 .57749 L .27918 .60676 L p
1 g
F P
s
P
p
.002 w
.27918 .60676 m .29029 .64209 L .32111 .61664 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.68445 .52967 m .69076 .50333 L .63294 .45512 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.65704 .74747 m .68601 .72498 L .67192 .67307 L p
1 g
F P
s
P
p
.002 w
.69498 .6445 m .67192 .67307 L .68601 .72498 L p
1 g
F P
s
P
p
.002 w
.38578 .77464 m .35128 .75525 L .35343 .77272 L p
1 g
F P
s
P
p
.002 w
.35343 .77272 m .3868 .78349 L .38578 .77464 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.62345 .7663 m .58619 .78086 L .58045 .81168 L p
1 g
F P
s
P
p
.002 w
.35744 .74026 m .32997 .70986 L .32115 .73195 L p
1 g
F P
s
P
p
.002 w
.32115 .73195 m .35128 .75525 L .35744 .74026 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.3686 .52236 m .37521 .48541 L .31574 .5039 L p
1 g
F P
s
P
p
.002 w
.31574 .5039 m .31226 .53954 L .3686 .52236 L p
1 g
F P
s
P
p
.002 w
.45953 .45226 m .47238 .42379 L .39844 .42407 L p
1 g
F P
s
P
p
.002 w
.39844 .42407 m .38527 .45234 L .45953 .45226 L p
1 g
F P
s
P
p
.002 w
.49175 .8245 m .4572 .80984 L .44835 .81383 L p
1 g
F P
s
P
p
.002 w
.4572 .80984 m .49175 .8245 L .50247 .8118 L p
1 g
F P
s
P
p
.002 w
.54216 .81459 m .50247 .8118 L .49175 .8245 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.69498 .6445 m .71236 .61527 L .67284 .55864 L p
1 g
F P
s
P
p
.002 w
.68445 .52967 m .67284 .55864 L .71236 .61527 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.33327 .6558 m .32111 .61664 L .29029 .64209 L p
1 g
F P
s
P
p
.002 w
.29029 .64209 m .30737 .6768 L .33327 .6558 L p
1 g
F P
s
P
p
.002 w
.55092 .44312 m .56178 .41954 L .48586 .40093 L p
1 g
F P
s
P
p
.002 w
.48586 .40093 m .47238 .42379 L .55092 .44312 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.62345 .7663 m .65704 .74747 L .64383 .70011 L p
1 g
F P
s
P
p
.002 w
.67192 .67307 m .64383 .70011 L .65704 .74747 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.50247 .8118 m .54216 .81459 L .54636 .79069 L p
1 g
F P
s
P
p
.002 w
.38898 .76708 m .35744 .74026 L .35128 .75525 L p
1 g
F P
s
P
p
.002 w
.35128 .75525 m .38578 .77464 L .38898 .76708 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.63294 .45512 m .62457 .47992 L .68445 .52967 L p
1 g
F P
s
P
p
.002 w
.62457 .47992 m .63294 .45512 L .56178 .41954 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.35019 .69379 m .33327 .6558 L .30737 .6768 L p
1 g
F P
s
P
p
.002 w
.30737 .6768 m .32997 .70986 L .35019 .69379 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.50247 .8118 m .46256 .80337 L .4572 .80984 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.56178 .41954 m .55092 .44312 L .62457 .47992 L p
1 g
F P
s
P
p
.002 w
.67284 .55864 m .68445 .52967 L .62457 .47992 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.36571 .5621 m .3686 .52236 L .31226 .53954 L p
1 g
F P
s
P
p
.002 w
.31226 .53954 m .31405 .57749 L .36571 .5621 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.46256 .80337 m .50247 .8118 L .50516 .79548 L p
1 g
F P
s
P
p
.002 w
.54636 .79069 m .50516 .79548 L .50247 .8118 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.58619 .78086 m .62345 .7663 L .61151 .72476 L p
1 g
F P
s
P
p
.002 w
.64383 .70011 m .61151 .72476 L .62345 .7663 L p
1 g
F P
s
P
p
.002 w
.67192 .67307 m .69498 .6445 L .6562 .58943 L p
1 g
F P
s
P
p
.002 w
.67284 .55864 m .6562 .58943 L .69498 .6445 L p
1 g
F P
s
P
p
.002 w
.4477 .48558 m .45953 .45226 L .38527 .45234 L p
1 g
F P
s
P
p
.002 w
.38527 .45234 m .37521 .48541 L .4477 .48558 L p
1 g
F P
s
P
p
.002 w
.37134 .72943 m .35019 .69379 L .32997 .70986 L p
1 g
F P
s
P
p
.002 w
.32997 .70986 m .35744 .74026 L .37134 .72943 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.50516 .79548 m .46384 .79508 L .46256 .80337 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.39608 .76166 m .37134 .72943 L .35744 .74026 L p
1 g
F P
s
P
p
.002 w
.35744 .74026 m .38898 .76708 L .39608 .76166 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.53848 .4718 m .55092 .44312 L .47238 .42379 L p
1 g
F P
s
P
p
.002 w
.47238 .42379 m .45953 .45226 L .53848 .4718 L p
1 g
F P
s
P
p
.002 w
.61151 .72476 m .57594 .74627 L .58619 .78086 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.36663 .6034 m .36571 .5621 L .31405 .57749 L p
1 g
F P
s
P
p
.002 w
.31405 .57749 m .32111 .61664 L .36663 .6034 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.46384 .79508 m .50516 .79548 L .49943 .77729 L p
1 g
F P
s
P
p
.002 w
.49943 .77729 m .46086 .78588 L .46384 .79508 L p
1 g
F P
s
P
p
.002 w
.50516 .79548 m .54636 .79069 L .53819 .76396 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.53819 .76396 m .49943 .77729 L .50516 .79548 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.64383 .70011 m .67192 .67307 L .63497 .62111 L p
1 g
F P
s
P
p
.002 w
.6562 .58943 m .63497 .62111 L .67192 .67307 L p
1 g
F P
s
P
p
.002 w
.37134 .72943 m .39608 .76166 L .40632 .75897 L p
1 g
F P
s
P
p
.002 w
.62457 .47992 m .61256 .50877 L .67284 .55864 L p
1 g
F P
s
P
p
.002 w
.61256 .50877 m .62457 .47992 L .55092 .44312 L p
1 g
F P
s
P
p
.002 w
.6562 .58943 m .67284 .55864 L .61256 .50877 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.37136 .64501 m .36663 .6034 L .32111 .61664 L p
1 g
F P
s
P
p
.002 w
.32111 .61664 m .33327 .6558 L .37136 .64501 L p
1 g
F P
s
P
p
.002 w
.46086 .78588 m .49943 .77729 L .48583 .75922 L p
1 g
F P
s
P
p
.002 w
.48583 .75922 m .45393 .77677 L .46086 .78588 L p
1 g
F P
s
P
p
.002 w
.43727 .52278 m .4477 .48558 L .37521 .48541 L p
1 g
F P
s
P
p
.002 w
.37521 .48541 m .3686 .52236 L .43727 .52278 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.55092 .44312 m .53848 .4718 L .61256 .50877 L p
1 g
F P
s
P
p
.002 w
.40632 .75897 m .39154 .72401 L .37134 .72943 L p
1 g
F P
s
P
p
.002 w
.39154 .72401 m .40632 .75897 L .41861 .75934 L p
1 g
F P
s
P
p
.002 w
.35019 .69379 m .37134 .72943 L .39154 .72401 L p
1 g
F P
s
P
p
.002 w
.37975 .68563 m .37136 .64501 L .33327 .6558 L p
1 g
F P
s
P
p
.002 w
.33327 .6558 m .35019 .69379 L .37975 .68563 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.45393 .77677 m .48583 .75922 L .4658 .74329 L p
1 g
F P
s
P
p
.002 w
.4658 .74329 m .4438 .76876 L .45393 .77677 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.39154 .72401 m .37975 .68563 L .35019 .69379 L p
1 g
F P
s
P
p
.002 w
.61151 .72476 m .64383 .70011 L .60975 .65271 L p
1 g
F P
s
P
p
.002 w
.63497 .62111 m .60975 .65271 L .64383 .70011 L p
1 g
F P
s
P
p
.002 w
.41861 .75934 m .41584 .72464 L .39154 .72401 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.004 w
.39529 .85547 m
.40026 .8439 L
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.49943 .77729 m .53819 .76396 L .51836 .73733 L p
1 g
F P
s
P
p
.002 w
.51836 .73733 m .48583 .75922 L .49943 .77729 L p
1 g
F P
s
P
p
.002 w
.5248 .50478 m .53848 .4718 L .45953 .45226 L p
1 g
F P
s
P
p
.002 w
.45953 .45226 m .4477 .48558 L .5248 .50478 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.42859 .56273 m .43727 .52278 L .3686 .52236 L p
1 g
F P
s
P
p
.002 w
.3686 .52236 m .36571 .5621 L .42859 .56273 L p
1 g
F P
s
P
p
.002 w
.57594 .74627 m .61151 .72476 L .58131 .68324 L p
1 g
F P
s
P
p
.002 w
.60975 .65271 m .58131 .68324 L .61151 .72476 L p
1 g
F P
s
P
p
.002 w
.63497 .62111 m .6562 .58943 L .59721 .54087 L p
1 g
F P
s
P
p
.002 w
.61256 .50877 m .59721 .54087 L .6562 .58943 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.37975 .68563 m .39154 .72401 L .41584 .72464 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.58131 .68324 m .55052 .71174 L .57594 .74627 L p
1 g
F P
s
P
p
.002 w
.59721 .54087 m .61256 .50877 L .53848 .4718 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.53848 .4718 m .5248 .50478 L .59721 .54087 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.42193 .60419 m .42859 .56273 L .36571 .5621 L p
1 g
F P
s
P
p
.002 w
.36571 .5621 m .36663 .6034 L .42193 .60419 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.41584 .72464 m .41547 .68643 L .37975 .68563 L p
1 g
F P
s
P
p
.002 w
.37136 .64501 m .37975 .68563 L .41547 .68643 L p
1 g
F P
s
P
p
.002 w
.41547 .68643 m .41584 .72464 L .44156 .73132 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.51031 .54109 m .5248 .50478 L .4477 .48558 L p
1 g
F P
s
P
p
.002 w
.4477 .48558 m .43727 .52278 L .51031 .54109 L p
1 g
F P
s
P
p
.002 w
.60975 .65271 m .63497 .62111 L .57894 .57525 L p
1 g
F P
s
P
p
.002 w
.59721 .54087 m .57894 .57525 L .63497 .62111 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.41751 .64586 m .42193 .60419 L .36663 .6034 L p
1 g
F P
s
P
p
.002 w
.36663 .6034 m .37136 .64501 L .41751 .64586 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.44156 .73132 m .45332 .69619 L .41547 .68643 L p
1 g
F P
s
P
p
.002 w
.41547 .68643 m .41751 .64586 L .37136 .64501 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.57894 .57525 m .59721 .54087 L .5248 .50478 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.58131 .68324 m .60975 .65271 L .55832 .61086 L p
1 g
F P
s
P
p
.002 w
.57894 .57525 m .55832 .61086 L .60975 .65271 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.41751 .64586 m .41547 .68643 L .45332 .69619 L p
1 g
F P
s
P
p
.002 w
.55052 .71174 m .58131 .68324 L .53598 .64657 L p
1 g
F P
s
P
p
.002 w
.53598 .64657 m .51261 .68126 L .55052 .71174 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.5248 .50478 m .51031 .54109 L .57894 .57525 L p
1 g
F P
s
P
p
.002 w
.49544 .57961 m .51031 .54109 L .43727 .52278 L p
1 g
F P
s
P
p
.002 w
.43727 .52278 m .42859 .56273 L .49544 .57961 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55832 .61086 m .53598 .64657 L .58131 .68324 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.48897 .71384 m .51261 .68126 L .46649 .65841 L p
1 g
F P
s
P
p
.002 w
.46649 .65841 m .45332 .69619 L .48897 .71384 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.45332 .69619 m .46649 .65841 L .41751 .64586 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.42193 .60419 m .41751 .64586 L .46649 .65841 L p
1 g
F P
s
P
p
.002 w
.55832 .61086 m .57894 .57525 L .51031 .54109 L p
1 g
F P
s
P
p
.002 w
.48068 .61913 m .49544 .57961 L .42859 .56273 L p
1 g
F P
s
P
p
.004 w
.48664 .60318 m
.5 .6118 L
s
P
p
.002 w
.42859 .56273 m .42193 .60419 L .48068 .61913 L p
1 g
F P
s
P
p
.004 w
.44807 .5783 m
.4496 .57929 L
s
P
p
.004 w
.42202 .5615 m
.44807 .5783 L
s
P
p
.004 w
.4496 .57929 m
.44998 .57953 L
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.46649 .65841 m .48068 .61913 L .42193 .60419 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.51031 .54109 m .49544 .57961 L .55832 .61086 L p
1 g
F P
s
P
p
.002 w
.51261 .68126 m .53598 .64657 L .48068 .61913 L p
1 g
F P
s
P
p
.002 w
.48068 .61913 m .46649 .65841 L .51261 .68126 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.53598 .64657 m .55832 .61086 L .49544 .57961 L p
1 g
F P
s
P
p
.002 w
.49544 .57961 m .48068 .61913 L .53598 .64657 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .42202 .5615 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .38346 .883 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.42)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.42)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.44188 .61257 m .46566 .58295 L .50497 .60764 L p
1 g
F P
s
P
p
.002 w
.50497 .60764 m .48901 .64213 L .44188 .61257 L p
1 g
F P
s
P
p
.002 w
.5208 .57324 m .50497 .60764 L .46566 .58295 L p
1 g
F P
s
P
p
.002 w
.48901 .64213 m .50497 .60764 L .54917 .6215 L p
1 g
F P
s
P
p
.002 w
.50497 .60764 m .5208 .57324 L .55508 .58396 L p
1 g
F P
s
P
p
.002 w
.55508 .58396 m .54917 .6215 L .50497 .60764 L p
1 g
F P
s
P
p
.002 w
.41955 .64226 m .44188 .61257 L .48901 .64213 L p
1 g
F P
s
P
p
.002 w
.48901 .64213 m .47331 .67591 L .41955 .64226 L p
1 g
F P
s
P
p
.002 w
.47331 .67591 m .48901 .64213 L .54197 .6588 L p
1 g
F P
s
P
p
.002 w
.54917 .6215 m .54197 .6588 L .48901 .64213 L p
1 g
F P
s
P
p
.002 w
.46566 .58295 m .49033 .55407 L .5208 .57324 L p
1 g
F P
s
P
p
.002 w
.53614 .53974 m .5208 .57324 L .49033 .55407 L p
1 g
F P
s
P
p
.002 w
.5208 .57324 m .53614 .53974 L .55958 .54705 L p
1 g
F P
s
P
p
.002 w
.55958 .54705 m .55508 .58396 L .5208 .57324 L p
1 g
F P
s
P
p
.002 w
.40537 .57308 m .43528 .54993 L .46566 .58295 L p
1 g
F P
s
P
p
.002 w
.46566 .58295 m .44188 .61257 L .40537 .57308 L p
1 g
F P
s
P
p
.002 w
.49033 .55407 m .46566 .58295 L .43528 .54993 L p
1 g
F P
s
P
p
.002 w
.54197 .6588 m .54917 .6215 L .59374 .62308 L p
1 g
F P
s
P
p
.002 w
.54917 .6215 m .55508 .58396 L .58963 .58509 L p
1 g
F P
s
P
p
.002 w
.58963 .58509 m .59374 .62308 L .54917 .6215 L p
1 g
F P
s
P
p
.002 w
.37781 .59732 m .40537 .57308 L .44188 .61257 L p
1 g
F P
s
P
p
.002 w
.44188 .61257 m .41955 .64226 L .37781 .59732 L p
1 g
F P
s
P
p
.002 w
.43528 .54993 m .46685 .52842 L .49033 .55407 L p
1 g
F P
s
P
p
.002 w
.51532 .52662 m .49033 .55407 L .46685 .52842 L p
1 g
F P
s
P
p
.002 w
.49033 .55407 m .51532 .52662 L .53614 .53974 L p
1 g
F P
s
P
p
.002 w
.55508 .58396 m .55958 .54705 L .58319 .54776 L p
1 g
F P
s
P
p
.002 w
.58319 .54776 m .58963 .58509 L .55508 .58396 L p
1 g
F P
s
P
p
.002 w
.54197 .6588 m .53367 .69497 L .47331 .67591 L p
1 g
F P
s
P
p
.002 w
.53367 .69497 m .54197 .6588 L .5954 .66083 L p
1 g
F P
s
P
p
.002 w
.59374 .62308 m .5954 .66083 L .54197 .6588 L p
1 g
F P
s
P
p
.002 w
.39921 .6713 m .41955 .64226 L .47331 .67591 L p
1 g
F P
s
P
p
.002 w
.47331 .67591 m .45822 .70819 L .39921 .6713 L p
1 g
F P
s
P
p
.002 w
.45822 .70819 m .47331 .67591 L .53367 .69497 L p
1 g
F P
s
P
p
.002 w
.55062 .50793 m .53614 .53974 L .51532 .52662 L p
1 g
F P
s
P
p
.002 w
.53614 .53974 m .55062 .50793 L .56255 .51163 L p
1 g
F P
s
P
p
.002 w
.56255 .51163 m .55958 .54705 L .53614 .53974 L p
1 g
F P
s
P
p
.002 w
.35329 .6221 m .37781 .59732 L .41955 .64226 L p
1 g
F P
s
P
p
.002 w
.41955 .64226 m .39921 .6713 L .35329 .6221 L p
1 g
F P
s
P
p
.002 w
.46685 .52842 m .49931 .50905 L .51532 .52662 L p
1 g
F P
s
P
p
.002 w
.54004 .50125 m .51532 .52662 L .49931 .50905 L p
1 g
F P
s
P
p
.002 w
.51532 .52662 m .54004 .50125 L .55062 .50793 L p
1 g
F P
s
P
p
.002 w
.55958 .54705 m .56255 .51163 L .57454 .51196 L p
1 g
F P
s
P
p
.002 w
.57454 .51196 m .58319 .54776 L .55958 .54705 L p
1 g
F P
s
P
p
.002 w
.38333 .52759 m .41706 .51193 L .43528 .54993 L p
1 g
F P
s
P
p
.002 w
.43528 .54993 m .40537 .57308 L .38333 .52759 L p
1 g
F P
s
P
p
.002 w
.46685 .52842 m .43528 .54993 L .41706 .51193 L p
1 g
F P
s
P
p
.002 w
.53367 .69497 m .52444 .72916 L .45822 .70819 L p
1 g
F P
s
P
p
.002 w
.52444 .72916 m .53367 .69497 L .59458 .69744 L p
1 g
F P
s
P
p
.002 w
.5954 .66083 m .59458 .69744 L .53367 .69497 L p
1 g
F P
s
P
p
.002 w
.41706 .51193 m .45286 .49893 L .46685 .52842 L p
1 g
F P
s
P
p
.002 w
.49931 .50905 m .46685 .52842 L .45286 .49893 L p
1 g
F P
s
P
p
.002 w
.59374 .62308 m .58963 .58509 L .62083 .57644 L p
1 g
F P
s
P
p
.002 w
.58963 .58509 m .58319 .54776 L .60445 .54176 L p
1 g
F P
s
P
p
.002 w
.60445 .54176 m .62083 .57644 L .58963 .58509 L p
1 g
F P
s
P
p
.002 w
.5954 .66083 m .59374 .62308 L .63406 .61209 L p
1 g
F P
s
P
p
.002 w
.62083 .57644 m .63406 .61209 L .59374 .62308 L p
1 g
F P
s
P
p
.002 w
.35248 .54556 m .38333 .52759 L .40537 .57308 L p
1 g
F P
s
P
p
.002 w
.40537 .57308 m .37781 .59732 L .35248 .54556 L p
1 g
F P
s
P
p
.002 w
.45286 .49893 m .48985 .48889 L .49931 .50905 L p
1 g
F P
s
P
p
.002 w
.53192 .4923 m .49931 .50905 L .48985 .48889 L p
1 g
F P
s
P
p
.002 w
.49931 .50905 m .53192 .4923 L .54004 .50125 L p
1 g
F P
s
P
p
.002 w
.58319 .54776 m .57454 .51196 L .58532 .50888 L p
1 g
F P
s
P
p
.002 w
.58532 .50888 m .60445 .54176 L .58319 .54776 L p
1 g
F P
s
P
p
.002 w
.38135 .699 m .39921 .6713 L .45822 .70819 L p
1 g
F P
s
P
p
.002 w
.45822 .70819 m .44412 .73819 L .38135 .699 L p
1 g
F P
s
P
p
.002 w
.44412 .73819 m .45822 .70819 L .52444 .72916 L p
1 g
F P
s
P
p
.002 w
.59458 .69744 m .5954 .66083 L .64382 .64785 L p
1 g
F P
s
P
p
.002 w
.63406 .61209 m .64382 .64785 L .5954 .66083 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .55062 .50793 L .54004 .50125 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .56255 .51163 L .55062 .50793 L closepath p
1 g
F P
s
P
p
.002 w
.33244 .64681 m .35329 .6221 L .39921 .6713 L p
1 g
F P
s
P
p
.002 w
.39921 .6713 m .38135 .699 L .33244 .64681 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .54004 .50125 L .53192 .4923 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .57454 .51196 L .56255 .51163 L closepath p
1 g
F P
s
P
p
.002 w
.52444 .72916 m .5145 .76054 L .44412 .73819 L p
1 g
F P
s
P
p
.002 w
.5145 .76054 m .52444 .72916 L .59128 .73203 L p
1 g
F P
s
P
p
.002 w
.59458 .69744 m .59128 .73203 L .52444 .72916 L p
1 g
F P
s
P
p
.002 w
.41307 .47288 m .44993 .46868 L .45286 .49893 L p
1 g
F P
s
P
p
.002 w
.45286 .49893 m .41706 .51193 L .41307 .47288 L p
1 g
F P
s
P
p
.002 w
.48985 .48889 m .45286 .49893 L .44993 .46868 L p
1 g
F P
s
P
p
.002 w
.3253 .5654 m .35248 .54556 L .37781 .59732 L p
1 g
F P
s
P
p
.002 w
.37781 .59732 m .35329 .6221 L .3253 .5654 L p
1 g
F P
s
P
p
.002 w
.44993 .46868 m .48797 .46824 L .48985 .48889 L p
1 g
F P
s
P
p
.002 w
.52716 .48204 m .48985 .48889 L .48797 .46824 L p
1 g
F P
s
P
p
.002 w
.48985 .48889 m .52716 .48204 L .53192 .4923 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .53192 .4923 L .52716 .48204 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .58532 .50888 L .57454 .51196 L closepath p
1 g
F P
s
P
p
.002 w
.62083 .57644 m .60445 .54176 L .62109 .52966 L p
1 g
F P
s
P
p
.002 w
.60445 .54176 m .58532 .50888 L .59372 .50269 L p
1 g
F P
s
P
p
.002 w
.59372 .50269 m .62109 .52966 L .60445 .54176 L p
1 g
F P
s
P
p
.002 w
.63406 .61209 m .62083 .57644 L .64533 .55883 L p
1 g
F P
s
P
p
.002 w
.62109 .52966 m .64533 .55883 L .62083 .57644 L p
1 g
F P
s
P
p
.002 w
.59128 .73203 m .59458 .69744 L .64986 .68286 L p
1 g
F P
s
P
p
.002 w
.64382 .64785 m .64986 .68286 L .59458 .69744 L p
1 g
F P
s
P
p
.002 w
.3783 .48077 m .41307 .47288 L .41706 .51193 L p
1 g
F P
s
P
p
.002 w
.41706 .51193 m .38333 .52759 L .3783 .48077 L p
1 g
F P
s
P
p
.002 w
.48797 .46824 m .52627 .47157 L .52716 .48204 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .52716 .48204 L .52627 .47157 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .59372 .50269 L .58532 .50888 L closepath p
1 g
F P
s
P
p
.002 w
.64382 .64785 m .63406 .61209 L .66584 .58951 L p
1 g
F P
s
P
p
.002 w
.64533 .55883 m .66584 .58951 L .63406 .61209 L p
1 g
F P
s
P
p
.002 w
.36644 .72469 m .38135 .699 L .44412 .73819 L p
1 g
F P
s
P
p
.002 w
.44412 .73819 m .43135 .76515 L .36644 .72469 L p
1 g
F P
s
P
p
.002 w
.43135 .76515 m .44412 .73819 L .5145 .76054 L p
1 g
F P
s
P
p
.002 w
.49395 .44934 m .52936 .46201 L .52627 .47157 L p
1 g
F P
s
P
p
.002 w
.52627 .47157 m .48797 .46824 L .49395 .44934 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .52627 .47157 L .52936 .46201 L closepath p
1 g
F P
s
P
p
.002 w
.62109 .52966 m .59372 .50269 L .59883 .49406 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .59883 .49406 L .59372 .50269 L closepath p
1 g
F P
s
P
p
.002 w
.34649 .49219 m .3783 .48077 L .38333 .52759 L p
1 g
F P
s
P
p
.002 w
.38333 .52759 m .35248 .54556 L .34649 .49219 L p
1 g
F P
s
P
p
.002 w
.45854 .44089 m .49395 .44934 L .48797 .46824 L p
1 g
F P
s
P
p
.002 w
.48797 .46824 m .44993 .46868 L .45854 .44089 L p
1 g
F P
s
P
p
.002 w
.64533 .55883 m .62109 .52966 L .63127 .51268 L p
1 g
F P
s
P
p
.002 w
.59883 .49406 m .63127 .51268 L .62109 .52966 L p
1 g
F P
s
P
p
.002 w
.3025 .58666 m .3253 .5654 L .35329 .6221 L p
1 g
F P
s
P
p
.002 w
.35329 .6221 m .33244 .64681 L .3025 .58666 L p
1 g
F P
s
P
p
.002 w
.3158 .67084 m .33244 .64681 L .38135 .699 L p
1 g
F P
s
P
p
.002 w
.38135 .699 m .36644 .72469 L .3158 .67084 L p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .53612 .45441 L .54583 .44961 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .52936 .46201 L .53612 .45441 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .60006 .48391 L .59883 .49406 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .59728 .47333 L .60006 .48391 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .59076 .4635 L .59728 .47333 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .58122 .45548 L .59076 .4635 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .56969 .45016 L .58122 .45548 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .55744 .44813 L .56969 .45016 L closepath p
1 g
F P
s
P
p
.002 w
.5639 .47858 m .54583 .44961 L .55744 .44813 L closepath p
1 g
F P
s
P
p
.002 w
.64986 .68286 m .64382 .64785 L .68209 .62097 L p
1 g
F P
s
P
p
.002 w
.66584 .58951 m .68209 .62097 L .64382 .64785 L p
1 g
F P
s
P
p
.002 w
.5145 .76054 m .50407 .7883 L .43135 .76515 L p
1 g
F P
s
P
p
.002 w
.50407 .7883 m .5145 .76054 L .58553 .76375 L p
1 g
F P
s
P
p
.002 w
.59128 .73203 m .58553 .76375 L .5145 .76054 L p
1 g
F P
s
P
p
.002 w
.58553 .76375 m .59128 .73203 L .65198 .71627 L p
1 g
F P
s
P
p
.002 w
.64986 .68286 m .65198 .71627 L .59128 .73203 L p
1 g
F P
s
P
p
.002 w
.42399 .43691 m .45854 .44089 L .44993 .46868 L p
1 g
F P
s
P
p
.002 w
.44993 .46868 m .41307 .47288 L .42399 .43691 L p
1 g
F P
s
P
p
.002 w
.50722 .43425 m .53612 .45441 L .52936 .46201 L p
1 g
F P
s
P
p
.002 w
.52936 .46201 m .49395 .44934 L .50722 .43425 L p
1 g
F P
s
P
p
.002 w
.63127 .51268 m .59883 .49406 L .60006 .48391 L p
1 g
F P
s
P
p
.002 w
.66584 .58951 m .64533 .55883 L .66042 .53402 L p
1 g
F P
s
P
p
.002 w
.63127 .51268 m .66042 .53402 L .64533 .55883 L p
1 g
F P
s
P
p
.002 w
.52639 .42466 m .54583 .44961 L .53612 .45441 L p
1 g
F P
s
P
p
.002 w
.53612 .45441 m .50722 .43425 L .52639 .42466 L p
1 g
F P
s
P
p
.002 w
.31847 .5069 m .34649 .49219 L .35248 .54556 L p
1 g
F P
s
P
p
.002 w
.35248 .54556 m .3253 .5654 L .31847 .5069 L p
1 g
F P
s
P
p
.002 w
.60006 .48391 m .63383 .49264 L .63127 .51268 L p
1 g
F P
s
P
p
.002 w
.63383 .49264 m .60006 .48391 L .59728 .47333 L p
1 g
F P
s
P
p
.002 w
.4779 .41863 m .50722 .43425 L .49395 .44934 L p
1 g
F P
s
P
p
.002 w
.49395 .44934 m .45854 .44089 L .4779 .41863 L p
1 g
F P
s
P
p
.002 w
.39116 .43755 m .42399 .43691 L .41307 .47288 L p
1 g
F P
s
P
p
.002 w
.41307 .47288 m .3783 .48077 L .39116 .43755 L p
1 g
F P
s
P
p
.002 w
.66042 .53402 m .63127 .51268 L .63383 .49264 L p
1 g
F P
s
P
p
.002 w
.65198 .71627 m .64986 .68286 L .69364 .65243 L p
1 g
F P
s
P
p
.002 w
.68209 .62097 m .69364 .65243 L .64986 .68286 L p
1 g
F P
s
P
p
.002 w
.68209 .62097 m .66584 .58951 L .68552 .55757 L p
1 g
F P
s
P
p
.002 w
.66042 .53402 m .68552 .55757 L .66584 .58951 L p
1 g
F P
s
P
p
.002 w
.3549 .74768 m .36644 .72469 L .43135 .76515 L p
1 g
F P
s
P
p
.002 w
.43135 .76515 m .42024 .78837 L .3549 .74768 L p
1 g
F P
s
P
p
.002 w
.42024 .78837 m .43135 .76515 L .50407 .7883 L p
1 g
F P
s
P
p
.002 w
.5494 .42168 m .55744 .44813 L .54583 .44961 L p
1 g
F P
s
P
p
.002 w
.54583 .44961 m .52639 .42466 L .5494 .42168 L p
1 g
F P
s
P
p
.002 w
.59728 .47333 m .6284 .4717 L .63383 .49264 L p
1 g
F P
s
P
p
.002 w
.6284 .4717 m .59728 .47333 L .59076 .4635 L p
1 g
F P
s
P
p
.002 w
.28471 .60883 m .3025 .58666 L .33244 .64681 L p
1 g
F P
s
P
p
.002 w
.33244 .64681 m .3158 .67084 L .28471 .60883 L p
1 g
F P
s
P
p
.002 w
.5737 .42568 m .56969 .45016 L .55744 .44813 L p
1 g
F P
s
P
p
.002 w
.55744 .44813 m .5494 .42168 L .5737 .42568 L p
1 g
F P
s
P
p
.002 w
.59076 .4635 m .61553 .45217 L .6284 .4717 L p
1 g
F P
s
P
p
.002 w
.61553 .45217 m .59076 .4635 L .58122 .45548 L p
1 g
F P
s
P
p
.002 w
.58553 .76375 m .57746 .79177 L .50407 .7883 L p
1 g
F P
s
P
p
.002 w
.57746 .79177 m .58553 .76375 L .65008 .74722 L p
1 g
F P
s
P
p
.002 w
.65198 .71627 m .65008 .74722 L .58553 .76375 L p
1 g
F P
s
P
p
.002 w
.30388 .6936 m .3158 .67084 L .36644 .72469 L p
1 g
F P
s
P
p
.002 w
.36644 .72469 m .3549 .74768 L .30388 .6936 L p
1 g
F P
s
P
p
.002 w
.44889 .40801 m .4779 .41863 L .45854 .44089 L p
1 g
F P
s
P
p
.002 w
.45854 .44089 m .42399 .43691 L .44889 .40801 L p
1 g
F P
s
P
p
.002 w
.5966 .43624 m .58122 .45548 L .56969 .45016 L p
1 g
F P
s
P
p
.002 w
.56969 .45016 m .5737 .42568 L .5966 .43624 L p
1 g
F P
s
P
p
.002 w
.58122 .45548 m .5966 .43624 L .61553 .45217 L p
1 g
F P
s
P
p
.002 w
.50407 .7883 m .49342 .81172 L .42024 .78837 L p
1 g
F P
s
P
p
.002 w
.49342 .81172 m .50407 .7883 L .57746 .79177 L p
1 g
F P
s
P
p
.002 w
.50604 .40443 m .52639 .42466 L .50722 .43425 L p
1 g
F P
s
P
p
.002 w
.50722 .43425 m .4779 .41863 L .50604 .40443 L p
1 g
F P
s
P
p
.002 w
.68552 .55757 m .66042 .53402 L .66432 .50461 L p
1 g
F P
s
P
p
.002 w
.63383 .49264 m .66432 .50461 L .66042 .53402 L p
1 g
F P
s
P
p
.002 w
.36092 .44285 m .39116 .43755 L .3783 .48077 L p
1 g
F P
s
P
p
.002 w
.3783 .48077 m .34649 .49219 L .36092 .44285 L p
1 g
F P
s
P
p
.002 w
.66432 .50461 m .63383 .49264 L .6284 .4717 L p
1 g
F P
s
P
p
.002 w
.29501 .52459 m .31847 .5069 L .3253 .5654 L p
1 g
F P
s
P
p
.002 w
.3253 .5654 m .3025 .58666 L .29501 .52459 L p
1 g
F P
s
P
p
.002 w
.69364 .65243 m .68209 .62097 L .70591 .58277 L p
1 g
F P
s
P
p
.002 w
.68552 .55757 m .70591 .58277 L .68209 .62097 L p
1 g
F P
s
P
p
.002 w
.65008 .74722 m .65198 .71627 L .70013 .6831 L p
1 g
F P
s
P
p
.002 w
.69364 .65243 m .70013 .6831 L .65198 .71627 L p
1 g
F P
s
P
p
.002 w
.53993 .39997 m .5494 .42168 L .52639 .42466 L p
1 g
F P
s
P
p
.002 w
.52639 .42466 m .50604 .40443 L .53993 .39997 L p
1 g
F P
s
P
p
.002 w
.6284 .4717 m .65645 .47379 L .66432 .50461 L p
1 g
F P
s
P
p
.002 w
.65645 .47379 m .6284 .4717 L .61553 .45217 L p
1 g
F P
s
P
p
.002 w
.42091 .40273 m .44889 .40801 L .42399 .43691 L p
1 g
F P
s
P
p
.002 w
.42399 .43691 m .39116 .43755 L .42091 .40273 L p
1 g
F P
s
P
p
.002 w
.70591 .58277 m .68552 .55757 L .69074 .51956 L p
1 g
F P
s
P
p
.002 w
.66432 .50461 m .69074 .51956 L .68552 .55757 L p
1 g
F P
s
P
p
.002 w
.27249 .63136 m .28471 .60883 L .3158 .67084 L p
1 g
F P
s
P
p
.002 w
.3158 .67084 m .30388 .6936 L .27249 .63136 L p
1 g
F P
s
P
p
.002 w
.34708 .76736 m .3549 .74768 L .42024 .78837 L p
1 g
F P
s
P
p
.002 w
.42024 .78837 m .41111 .80719 L .34708 .76736 L p
1 g
F P
s
P
p
.002 w
.41111 .80719 m .42024 .78837 L .49342 .81172 L p
1 g
F P
s
P
p
.002 w
.48528 .3895 m .50604 .40443 L .4779 .41863 L p
1 g
F P
s
P
p
.002 w
.4779 .41863 m .44889 .40801 L .48528 .3895 L p
1 g
F P
s
P
p
.002 w
.33407 .45276 m .36092 .44285 L .34649 .49219 L p
1 g
F P
s
P
p
.002 w
.34649 .49219 m .31847 .5069 L .33407 .45276 L p
1 g
F P
s
P
p
.002 w
.57746 .79177 m .56723 .81532 L .49342 .81172 L p
1 g
F P
s
P
p
.002 w
.56723 .81532 m .57746 .79177 L .64415 .77489 L p
1 g
F P
s
P
p
.002 w
.65008 .74722 m .64415 .77489 L .57746 .79177 L p
1 g
F P
s
P
p
.002 w
.69074 .51956 m .66432 .50461 L .65645 .47379 L p
1 g
F P
s
P
p
.002 w
.5758 .40583 m .5737 .42568 L .5494 .42168 L p
1 g
F P
s
P
p
.002 w
.5494 .42168 m .53993 .39997 L .5758 .40583 L p
1 g
F P
s
P
p
.002 w
.61553 .45217 m .63753 .44497 L .65645 .47379 L p
1 g
F P
s
P
p
.002 w
.63753 .44497 m .61553 .45217 L .5966 .43624 L p
1 g
F P
s
P
p
.002 w
.70013 .6831 m .69364 .65243 L .72099 .609 L p
1 g
F P
s
P
p
.002 w
.70591 .58277 m .72099 .609 L .69364 .65243 L p
1 g
F P
s
P
p
.002 w
.29705 .71447 m .30388 .6936 L .3549 .74768 L p
1 g
F P
s
P
p
.002 w
.3549 .74768 m .34708 .76736 L .29705 .71447 L p
1 g
F P
s
P
p
.002 w
.2768 .54483 m .29501 .52459 L .3025 .58666 L p
1 g
F P
s
P
p
.002 w
.3025 .58666 m .28471 .60883 L .2768 .54483 L p
1 g
F P
s
P
p
.002 w
.49342 .81172 m .48279 .83011 L .41111 .80719 L p
1 g
F P
s
P
p
.002 w
.48279 .83011 m .49342 .81172 L .56723 .81532 L p
1 g
F P
s
P
p
.002 w
.60961 .42142 m .5966 .43624 L .5737 .42568 L p
1 g
F P
s
P
p
.002 w
.5737 .42568 m .5758 .40583 L .60961 .42142 L p
1 g
F P
s
P
p
.002 w
.5966 .43624 m .60961 .42142 L .63753 .44497 L p
1 g
F P
s
P
p
.002 w
.64415 .77489 m .65008 .74722 L .70133 .7122 L p
1 g
F P
s
P
p
.002 w
.70013 .6831 m .70133 .7122 L .65008 .74722 L p
1 g
F P
s
P
p
.002 w
.39473 .40302 m .42091 .40273 L .39116 .43755 L p
1 g
F P
s
P
p
.002 w
.39116 .43755 m .36092 .44285 L .39473 .40302 L p
1 g
F P
s
P
p
.002 w
.52925 .38364 m .53993 .39997 L .50604 .40443 L p
1 g
F P
s
P
p
.002 w
.50604 .40443 m .48528 .3895 L .52925 .38364 L p
1 g
F P
s
P
p
.002 w
.72099 .609 m .70591 .58277 L .71235 .53715 L p
1 g
F P
s
P
p
.002 w
.69074 .51956 m .71235 .53715 L .70591 .58277 L p
1 g
F P
s
P
p
.002 w
.65645 .47379 m .68066 .47959 L .69074 .51956 L p
1 g
F P
s
P
p
.002 w
.68066 .47959 m .65645 .47379 L .63753 .44497 L p
1 g
F P
s
P
p
.002 w
.31139 .46709 m .33407 .45276 L .31847 .5069 L p
1 g
F P
s
P
p
.002 w
.31847 .5069 m .29501 .52459 L .31139 .46709 L p
1 g
F P
s
P
p
.002 w
.46463 .38037 m .48528 .3895 L .44889 .40801 L p
1 g
F P
s
P
p
.002 w
.44889 .40801 m .42091 .40273 L .46463 .38037 L p
1 g
F P
s
P
p
.002 w
.71235 .53715 m .69074 .51956 L .68066 .47959 L p
1 g
F P
s
P
p
.002 w
.70133 .7122 m .70013 .6831 L .7303 .63561 L p
1 g
F P
s
P
p
.002 w
.72099 .609 m .7303 .63561 L .70013 .6831 L p
1 g
F P
s
P
p
.002 w
.26626 .65366 m .27249 .63136 L .30388 .6936 L p
1 g
F P
s
P
p
.002 w
.30388 .6936 m .29705 .71447 L .26626 .65366 L p
1 g
F P
s
P
p
.002 w
.56723 .81532 m .55505 .83374 L .48279 .83011 L p
1 g
F P
s
P
p
.002 w
.55505 .83374 m .56723 .81532 L .63427 .79853 L p
1 g
F P
s
P
p
.002 w
.64415 .77489 m .63427 .79853 L .56723 .81532 L p
1 g
F P
s
P
p
.002 w
.34326 .78314 m .34708 .76736 L .41111 .80719 L p
1 g
F P
s
P
p
.002 w
.41111 .80719 m .40424 .82105 L .34326 .78314 L p
1 g
F P
s
P
p
.002 w
.40424 .82105 m .41111 .80719 L .48279 .83011 L p
1 g
F P
s
P
p
.002 w
.2644 .56715 m .2768 .54483 L .28471 .60883 L p
1 g
F P
s
P
p
.002 w
.28471 .60883 m .27249 .63136 L .2644 .56715 L p
1 g
F P
s
P
p
.002 w
.57589 .39123 m .5758 .40583 L .53993 .39997 L p
1 g
F P
s
P
p
.002 w
.53993 .39997 m .52925 .38364 L .57589 .39123 L p
1 g
F P
s
P
p
.002 w
.63753 .44497 m .65616 .44214 L .68066 .47959 L p
1 g
F P
s
P
p
.002 w
.65616 .44214 m .63753 .44497 L .60961 .42142 L p
1 g
F P
s
P
p
.002 w
.63427 .79853 m .64415 .77489 L .69711 .73895 L p
1 g
F P
s
P
p
.002 w
.70133 .7122 m .69711 .73895 L .64415 .77489 L p
1 g
F P
s
P
p
.002 w
.29562 .73287 m .29705 .71447 L .34708 .76736 L p
1 g
F P
s
P
p
.002 w
.34708 .76736 m .34326 .78314 L .29562 .73287 L p
1 g
F P
s
P
p
.002 w
.37105 .40899 m .39473 .40302 L .36092 .44285 L p
1 g
F P
s
P
p
.002 w
.36092 .44285 m .33407 .45276 L .37105 .40899 L p
1 g
F P
s
P
p
.002 w
.48279 .83011 m .47247 .84289 L .40424 .82105 L p
1 g
F P
s
P
p
.002 w
.47247 .84289 m .48279 .83011 L .55505 .83374 L p
1 g
F P
s
P
p
.002 w
.61987 .41151 m .60961 .42142 L .5758 .40583 L p
1 g
F P
s
P
p
.002 w
.5758 .40583 m .57589 .39123 L .61987 .41151 L p
1 g
F P
s
P
p
.002 w
.60961 .42142 m .61987 .41151 L .65616 .44214 L p
1 g
F P
s
P
p
.002 w
.7303 .63561 m .72099 .609 L .7285 .55698 L p
1 g
F P
s
P
p
.002 w
.71235 .53715 m .7285 .55698 L .72099 .609 L p
1 g
F P
s
P
p
.002 w
.29355 .48555 m .31139 .46709 L .29501 .52459 L p
1 g
F P
s
P
p
.002 w
.29501 .52459 m .2768 .54483 L .29355 .48555 L p
1 g
F P
s
P
p
.002 w
.51761 .37324 m .52925 .38364 L .48528 .3895 L p
1 g
F P
s
P
p
.002 w
.48528 .3895 m .46463 .38037 L .51761 .37324 L p
1 g
F P
s
P
p
.002 w
.44463 .37739 m .46463 .38037 L .42091 .40273 L p
1 g
F P
s
P
p
.002 w
.42091 .40273 m .39473 .40302 L .44463 .37739 L p
1 g
F P
s
P
p
.002 w
.68066 .47959 m .70032 .48905 L .71235 .53715 L p
1 g
F P
s
P
p
.002 w
.70032 .48905 m .68066 .47959 L .65616 .44214 L p
1 g
F P
s
P
p
.002 w
.69711 .73895 m .70133 .7122 L .73348 .66191 L p
1 g
F P
s
P
p
.002 w
.7303 .63561 m .73348 .66191 L .70133 .7122 L p
1 g
F P
s
P
p
.002 w
.7285 .55698 m .71235 .53715 L .70032 .48905 L p
1 g
F P
s
P
p
.002 w
.26631 .67514 m .26626 .65366 L .29705 .71447 L p
1 g
F P
s
P
p
.002 w
.29705 .71447 m .29562 .73287 L .26631 .67514 L p
1 g
F P
s
P
p
.002 w
.25828 .591 m .2644 .56715 L .27249 .63136 L p
1 g
F P
s
P
p
.002 w
.27249 .63136 m .26626 .65366 L .25828 .591 L p
1 g
F P
s
P
p
.002 w
.55505 .83374 m .54119 .84641 L .47247 .84289 L p
1 g
F P
s
P
p
.002 w
.54119 .84641 m .55505 .83374 L .62062 .81743 L p
1 g
F P
s
P
p
.002 w
.63427 .79853 m .62062 .81743 L .55505 .83374 L p
1 g
F P
s
P
p
.002 w
.35057 .42058 m .37105 .40899 L .33407 .45276 L p
1 g
F P
s
P
p
.002 w
.33407 .45276 m .31139 .46709 L .35057 .42058 L p
1 g
F P
s
P
p
.002 w
.62062 .81743 m .63427 .79853 L .68748 .76258 L p
1 g
F P
s
P
p
.002 w
.69711 .73895 m .68748 .76258 L .63427 .79853 L p
1 g
F P
s
P
p
.002 w
.57392 .38238 m .57589 .39123 L .52925 .38364 L p
1 g
F P
s
P
p
.002 w
.52925 .38364 m .51761 .37324 L .57392 .38238 L p
1 g
F P
s
P
p
.002 w
.34363 .79453 m .34326 .78314 L .40424 .82105 L p
1 g
F P
s
P
p
.002 w
.40424 .82105 m .39984 .82946 L .34363 .79453 L p
1 g
F P
s
P
p
.002 w
.39984 .82946 m .40424 .82105 L .47247 .84289 L p
1 g
F P
s
P
p
.002 w
.65616 .44214 m .67084 .44388 L .70032 .48905 L p
1 g
F P
s
P
p
.002 w
.67084 .44388 m .65616 .44214 L .61987 .41151 L p
1 g
F P
s
P
p
.002 w
.73348 .66191 m .7303 .63561 L .73866 .57857 L p
1 g
F P
s
P
p
.002 w
.7285 .55698 m .73866 .57857 L .7303 .63561 L p
1 g
F P
s
P
p
.002 w
.29974 .74826 m .29562 .73287 L .34326 .78314 L p
1 g
F P
s
P
p
.002 w
.34326 .78314 m .34363 .79453 L .29974 .74826 L p
1 g
F P
s
P
p
.002 w
.47247 .84289 m .46272 .84961 L .39984 .82946 L p
1 g
F P
s
P
p
.002 w
.46272 .84961 m .47247 .84289 L .54119 .84641 L p
1 g
F P
s
P
p
.002 w
.28114 .50772 m .29355 .48555 L .2768 .54483 L p
1 g
F P
s
P
p
.002 w
.2768 .54483 m .2644 .56715 L .28114 .50772 L p
1 g
F P
s
P
p
.002 w
.62704 .40687 m .61987 .41151 L .57589 .39123 L p
1 g
F P
s
P
p
.002 w
.57589 .39123 m .57392 .38238 L .62704 .40687 L p
1 g
F P
s
P
p
.002 w
.61987 .41151 m .62704 .40687 L .67084 .44388 L p
1 g
F P
s
P
p
.002 w
.42586 .38078 m .44463 .37739 L .39473 .40302 L p
1 g
F P
s
P
p
.002 w
.39473 .40302 m .37105 .40899 L .42586 .38078 L p
1 g
F P
s
P
p
.002 w
.5053 .36919 m .51761 .37324 L .46463 .38037 L p
1 g
F P
s
P
p
.002 w
.46463 .38037 m .44463 .37739 L .5053 .36919 L p
1 g
F P
s
P
p
.002 w
.68748 .76258 m .69711 .73895 L .73034 .68719 L p
1 g
F P
s
P
p
.002 w
.73348 .66191 m .73034 .68719 L .69711 .73895 L p
1 g
F P
s
P
p
.002 w
.70032 .48905 m .71484 .50199 L .7285 .55698 L p
1 g
F P
s
P
p
.002 w
.71484 .50199 m .70032 .48905 L .67084 .44388 L p
1 g
F P
s
P
p
.002 w
.73866 .57857 m .7285 .55698 L .71484 .50199 L p
1 g
F P
s
P
p
.002 w
.25872 .61574 m .25828 .591 L .26626 .65366 L p
1 g
F P
s
P
p
.002 w
.26626 .65366 m .26631 .67514 L .25872 .61574 L p
1 g
F P
s
P
p
.002 w
.27278 .6952 m .26631 .67514 L .29562 .73287 L p
1 g
F P
s
P
p
.002 w
.29562 .73287 m .29974 .74826 L .27278 .6952 L p
1 g
F P
s
P
p
.002 w
.33392 .4376 m .35057 .42058 L .31139 .46709 L p
1 g
F P
s
P
p
.002 w
.31139 .46709 m .29355 .48555 L .33392 .4376 L p
1 g
F P
s
P
p
.002 w
.54119 .84641 m .526 .85288 L .46272 .84961 L p
1 g
F P
s
P
p
.002 w
.526 .85288 m .54119 .84641 L .60348 .83099 L p
1 g
F P
s
P
p
.002 w
.62062 .81743 m .60348 .83099 L .54119 .84641 L p
1 g
F P
s
P
p
.002 w
.60348 .83099 m .62062 .81743 L .6726 .78241 L p
1 g
F P
s
P
p
.002 w
.68748 .76258 m .6726 .78241 L .62062 .81743 L p
1 g
F P
s
P
p
.002 w
.73034 .68719 m .73348 .66191 L .74243 .60137 L p
1 g
F P
s
P
p
.002 w
.73866 .57857 m .74243 .60137 L .73348 .66191 L p
1 g
F P
s
P
p
.002 w
.56988 .37968 m .57392 .38238 L .51761 .37324 L p
1 g
F P
s
P
p
.002 w
.51761 .37324 m .5053 .36919 L .56988 .37968 L p
1 g
F P
s
P
p
.002 w
.67084 .44388 m .68108 .45023 L .71484 .50199 L p
1 g
F P
s
P
p
.002 w
.68108 .45023 m .67084 .44388 L .62704 .40687 L p
1 g
F P
s
P
p
.002 w
.3483 .80111 m .34363 .79453 L .39984 .82946 L p
1 g
F P
s
P
p
.002 w
.39984 .82946 m .39812 .83206 L .3483 .80111 L p
1 g
F P
s
P
p
.002 w
.39812 .83206 m .39984 .82946 L .46272 .84961 L p
1 g
F P
s
P
p
.002 w
.2746 .53306 m .28114 .50772 L .2644 .56715 L p
1 g
F P
s
P
p
.002 w
.2644 .56715 m .25828 .591 L .2746 .53306 L p
1 g
F P
s
P
p
.002 w
.40884 .3906 m .42586 .38078 L .37105 .40899 L p
1 g
F P
s
P
p
.002 w
.37105 .40899 m .35057 .42058 L .40884 .3906 L p
1 g
F P
s
P
p
.002 w
.30943 .76014 m .29974 .74826 L .34363 .79453 L p
1 g
F P
s
P
p
.002 w
.34363 .79453 m .3483 .80111 L .30943 .76014 L p
1 g
F P
s
P
p
.002 w
.73034 .68719 m .72083 .71073 L .68748 .76258 L p
1 g
F P
s
P
p
.002 w
.6726 .78241 m .68748 .76258 L .72083 .71073 L p
1 g
F P
s
P
p
.002 w
.46272 .84961 m .45384 .84992 L .39812 .83206 L p
1 g
F P
s
P
p
.002 w
.45384 .84992 m .46272 .84961 L .526 .85288 L p
1 g
F P
s
P
p
.002 w
.49265 .37177 m .5053 .36919 L .44463 .37739 L p
1 g
F P
s
P
p
.002 w
.44463 .37739 m .42586 .38078 L .49265 .37177 L p
1 g
F P
s
P
p
.002 w
.71484 .50199 m .72368 .51813 L .73866 .57857 L p
1 g
F P
s
P
p
.002 w
.74243 .60137 m .73866 .57857 L .72368 .51813 L p
1 g
F P
s
P
p
.002 w
.63085 .40778 m .62704 .40687 L .57392 .38238 L p
1 g
F P
s
P
p
.002 w
.57392 .38238 m .56988 .37968 L .63085 .40778 L p
1 g
F P
s
P
p
.002 w
.62704 .40687 m .63085 .40778 L .68108 .45023 L p
1 g
F P
s
P
p
.002 w
.72368 .51813 m .71484 .50199 L .68108 .45023 L p
1 g
F P
s
P
p
.002 w
.32165 .45968 m .33392 .4376 L .29355 .48555 L p
1 g
F P
s
P
p
.002 w
.29355 .48555 m .28114 .50772 L .32165 .45968 L p
1 g
F P
s
P
p
.002 w
.26585 .6407 m .25872 .61574 L .26631 .67514 L p
1 g
F P
s
P
p
.002 w
.26631 .67514 m .27278 .6952 L .26585 .6407 L p
1 g
F P
s
P
p
.002 w
.28562 .71324 m .27278 .6952 L .29974 .74826 L p
1 g
F P
s
P
p
.002 w
.29974 .74826 m .30943 .76014 L .28562 .71324 L p
1 g
F P
s
P
p
.002 w
.74243 .60137 m .73957 .62478 L .73034 .68719 L p
1 g
F P
s
P
p
.002 w
.72083 .71073 m .73034 .68719 L .73957 .62478 L p
1 g
F P
s
P
p
.002 w
.60348 .83099 m .58325 .83872 L .526 .85288 L p
1 g
F P
s
P
p
.002 w
.6726 .78241 m .65276 .79781 L .60348 .83099 L p
1 g
F P
s
P
p
.002 w
.58325 .83872 m .60348 .83099 L .65276 .79781 L p
1 g
F P
s
P
p
.002 w
.526 .85288 m .50985 .85282 L .45384 .84992 L p
1 g
F P
s
P
p
.002 w
.50985 .85282 m .526 .85288 L .58325 .83872 L p
1 g
F P
s
P
p
.002 w
.27424 .56091 m .2746 .53306 L .25828 .591 L p
1 g
F P
s
P
p
.002 w
.25828 .591 m .25872 .61574 L .27424 .56091 L p
1 g
F P
s
P
p
.002 w
.56385 .38334 m .56988 .37968 L .5053 .36919 L p
1 g
F P
s
P
p
.002 w
.5053 .36919 m .49265 .37177 L .56385 .38334 L p
1 g
F P
s
P
p
.002 w
.39411 .40672 m .40884 .3906 L .35057 .42058 L p
1 g
F P
s
P
p
.002 w
.35057 .42058 m .33392 .4376 L .39411 .40672 L p
1 g
F P
s
P
p
.002 w
.68108 .45023 m .68651 .46115 L .72368 .51813 L p
1 g
F P
s
P
p
.002 w
.68651 .46115 m .68108 .45023 L .63085 .40778 L p
1 g
F P
s
P
p
.002 w
.65276 .79781 m .6726 .78241 L .70509 .73186 L p
1 g
F P
s
P
p
.002 w
.72083 .71073 m .70509 .73186 L .6726 .78241 L p
1 g
F P
s
P
p
.002 w
.35723 .80257 m .3483 .80111 L .39812 .83206 L p
1 g
F P
s
P
p
.002 w
.39812 .83206 m .39917 .82863 L .35723 .80257 L p
1 g
F P
s
P
p
.002 w
.39917 .82863 m .39812 .83206 L .45384 .84992 L p
1 g
F P
s
P
p
.002 w
.73957 .62478 m .74243 .60137 L .72648 .53711 L p
1 g
F P
s
P
p
.002 w
.72368 .51813 m .72648 .53711 L .74243 .60137 L p
1 g
F P
s
P
p
.002 w
.47999 .38105 m .49265 .37177 L .42586 .38078 L p
1 g
F P
s
P
p
.002 w
.42586 .38078 m .40884 .3906 L .47999 .38105 L p
1 g
F P
s
P
p
.002 w
.32456 .7681 m .30943 .76014 L .3483 .80111 L p
1 g
F P
s
P
p
.002 w
.3483 .80111 m .35723 .80257 L .32456 .7681 L p
1 g
F P
s
P
p
.002 w
.45384 .84992 m .44608 .84366 L .39917 .82863 L p
1 g
F P
s
P
p
.002 w
.44608 .84366 m .45384 .84992 L .50985 .85282 L p
1 g
F P
s
P
p
.002 w
.72648 .53711 m .72368 .51813 L .68651 .46115 L p
1 g
F P
s
P
p
.002 w
.63111 .41435 m .63085 .40778 L .56988 .37968 L p
1 g
F P
s
P
p
.002 w
.56988 .37968 m .56385 .38334 L .63111 .41435 L p
1 g
F P
s
P
p
.002 w
.63085 .40778 m .63111 .41435 L .68651 .46115 L p
1 g
F P
s
P
p
.002 w
.31419 .4863 m .32165 .45968 L .28114 .50772 L p
1 g
F P
s
P
p
.002 w
.28114 .50772 m .2746 .53306 L .31419 .4863 L p
1 g
F P
s
P
p
.002 w
.27959 .66518 m .26585 .6407 L .27278 .6952 L p
1 g
F P
s
P
p
.002 w
.27278 .6952 m .28562 .71324 L .27959 .66518 L p
1 g
F P
s
P
p
.002 w
.70509 .73186 m .72083 .71073 L .73002 .64816 L p
1 g
F P
s
P
p
.002 w
.73957 .62478 m .73002 .64816 L .72083 .71073 L p
1 g
F P
s
P
p
.002 w
.58325 .83872 m .56043 .84028 L .50985 .85282 L p
1 g
F P
s
P
p
.002 w
.56043 .84028 m .58325 .83872 L .62842 .80825 L p
1 g
F P
s
P
p
.002 w
.65276 .79781 m .62842 .80825 L .58325 .83872 L p
1 g
F P
s
P
p
.002 w
.30462 .72872 m .28562 .71324 L .30943 .76014 L p
1 g
F P
s
P
p
.002 w
.30943 .76014 m .32456 .7681 L .30462 .72872 L p
1 g
F P
s
P
p
.002 w
.28018 .59052 m .27424 .56091 L .25872 .61574 L p
1 g
F P
s
P
p
.002 w
.25872 .61574 m .26585 .6407 L .28018 .59052 L p
1 g
F P
s
P
p
.002 w
.50985 .85282 m .49318 .84607 L .44608 .84366 L p
1 g
F P
s
P
p
.002 w
.49318 .84607 m .50985 .85282 L .56043 .84028 L p
1 g
F P
s
P
p
.002 w
.62842 .80825 m .65276 .79781 L .68344 .74991 L p
1 g
F P
s
P
p
.002 w
.70509 .73186 m .68344 .74991 L .65276 .79781 L p
1 g
F P
s
P
p
.002 w
.38213 .4288 m .39411 .40672 L .33392 .4376 L p
1 g
F P
s
P
p
.002 w
.33392 .4376 m .32165 .45968 L .38213 .4288 L p
1 g
F P
s
P
p
.002 w
.55593 .39344 m .56385 .38334 L .49265 .37177 L p
1 g
F P
s
P
p
.002 w
.49265 .37177 m .47999 .38105 L .55593 .39344 L p
1 g
F P
s
P
p
.002 w
.73002 .64816 m .73957 .62478 L .72303 .55844 L p
1 g
F P
s
P
p
.002 w
.72648 .53711 m .72303 .55844 L .73957 .62478 L p
1 g
F P
s
P
p
.002 w
.68651 .46115 m .68684 .47643 L .72648 .53711 L p
1 g
F P
s
P
p
.002 w
.68684 .47643 m .68651 .46115 L .63111 .41435 L p
1 g
F P
s
P
p
.002 w
.4677 .39693 m .47999 .38105 L .40884 .3906 L p
1 g
F P
s
P
p
.002 w
.40884 .3906 m .39411 .40672 L .4677 .39693 L p
1 g
F P
s
P
p
.002 w
.37029 .79873 m .35723 .80257 L .39917 .82863 L p
1 g
F P
s
P
p
.002 w
.39917 .82863 m .40305 .8191 L .37029 .79873 L p
1 g
F P
s
P
p
.002 w
.40305 .8191 m .39917 .82863 L .44608 .84366 L p
1 g
F P
s
P
p
.002 w
.31185 .51676 m .31419 .4863 L .2746 .53306 L p
1 g
F P
s
P
p
.002 w
.2746 .53306 m .27424 .56091 L .31185 .51676 L p
1 g
F P
s
P
p
.002 w
.72303 .55844 m .72648 .53711 L .68684 .47643 L p
1 g
F P
s
P
p
.002 w
.34481 .77182 m .32456 .7681 L .35723 .80257 L p
1 g
F P
s
P
p
.002 w
.35723 .80257 m .37029 .79873 L .34481 .77182 L p
1 g
F P
s
P
p
.002 w
.44608 .84366 m .43969 .83083 L .40305 .8191 L p
1 g
F P
s
P
p
.002 w
.43969 .83083 m .44608 .84366 L .49318 .84607 L p
1 g
F P
s
P
p
.002 w
.68344 .74991 m .70509 .73186 L .71392 .67082 L p
1 g
F P
s
P
p
.002 w
.73002 .64816 m .71392 .67082 L .70509 .73186 L p
1 g
F P
s
P
p
.002 w
.62772 .42653 m .63111 .41435 L .56385 .38334 L p
1 g
F P
s
P
p
.002 w
.56385 .38334 m .55593 .39344 L .62772 .42653 L p
1 g
F P
s
P
p
.002 w
.29967 .68846 m .27959 .66518 L .28562 .71324 L p
1 g
F P
s
P
p
.002 w
.28562 .71324 m .30462 .72872 L .29967 .68846 L p
1 g
F P
s
P
p
.002 w
.63111 .41435 m .62772 .42653 L .68684 .47643 L p
1 g
F P
s
P
p
.002 w
.56043 .84028 m .5356 .83551 L .49318 .84607 L p
1 g
F P
s
P
p
.002 w
.5356 .83551 m .56043 .84028 L .6002 .81336 L p
1 g
F P
s
P
p
.002 w
.62842 .80825 m .6002 .81336 L .56043 .84028 L p
1 g
F P
s
P
p
.002 w
.29236 .62105 m .28018 .59052 L .26585 .6407 L p
1 g
F P
s
P
p
.002 w
.26585 .6407 m .27959 .66518 L .29236 .62105 L p
1 g
F P
s
P
p
.002 w
.32934 .74112 m .30462 .72872 L .32456 .7681 L p
1 g
F P
s
P
p
.002 w
.32456 .7681 m .34481 .77182 L .32934 .74112 L p
1 g
F P
s
P
p
.002 w
.6002 .81336 m .62842 .80825 L .6564 .76432 L p
1 g
F P
s
P
p
.002 w
.68344 .74991 m .6564 .76432 L .62842 .80825 L p
1 g
F P
s
P
p
.002 w
.37331 .45632 m .38213 .4288 L .32165 .45968 L p
1 g
F P
s
P
p
.002 w
.32165 .45968 m .31419 .4863 L .37331 .45632 L p
1 g
F P
s
P
p
.002 w
.49318 .84607 m .47644 .83268 L .43969 .83083 L p
1 g
F P
s
P
p
.002 w
.47644 .83268 m .49318 .84607 L .5356 .83551 L p
1 g
F P
s
P
p
.002 w
.71392 .67082 m .73002 .64816 L .71328 .58158 L p
1 g
F P
s
P
p
.002 w
.72303 .55844 m .71328 .58158 L .73002 .64816 L p
1 g
F P
s
P
p
.002 w
.54632 .40983 m .55593 .39344 L .47999 .38105 L p
1 g
F P
s
P
p
.002 w
.47999 .38105 m .4677 .39693 L .54632 .40983 L p
1 g
F P
s
P
p
.002 w
.31479 .55023 m .31185 .51676 L .27424 .56091 L p
1 g
F P
s
P
p
.002 w
.27424 .56091 m .28018 .59052 L .31479 .55023 L p
1 g
F P
s
P
p
.002 w
.45614 .4191 m .4677 .39693 L .39411 .40672 L p
1 g
F P
s
P
p
.002 w
.39411 .40672 m .38213 .4288 L .45614 .4191 L p
1 g
F P
s
P
p
.002 w
.68684 .47643 m .68194 .49574 L .72303 .55844 L p
1 g
F P
s
P
p
.002 w
.68194 .49574 m .68684 .47643 L .62772 .42653 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.6564 .76432 m .68344 .74991 L .69162 .6921 L p
1 g
F P
s
P
p
.002 w
.71392 .67082 m .69162 .6921 L .68344 .74991 L p
1 g
F P
s
P
p
.002 w
.71328 .58158 m .72303 .55844 L .68194 .49574 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.38719 .7896 m .37029 .79873 L .40305 .8191 L p
1 g
F P
s
P
p
.002 w
.40305 .8191 m .40971 .80361 L .38719 .7896 L p
1 g
F P
s
P
p
.002 w
.40971 .80361 m .40305 .8191 L .43969 .83083 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.32561 .70983 m .29967 .68846 L .30462 .72872 L p
1 g
F P
s
P
p
.002 w
.30462 .72872 m .32934 .74112 L .32561 .70983 L p
1 g
F P
s
P
p
.002 w
.36972 .7711 m .34481 .77182 L .37029 .79873 L p
1 g
F P
s
P
p
.002 w
.37029 .79873 m .38719 .7896 L .36972 .7711 L p
1 g
F P
s
P
p
.002 w
.43969 .83083 m .4349 .81166 L .40971 .80361 L p
1 g
F P
s
P
p
.002 w
.43969 .83083 m .47644 .83268 L p
.46082 .82478 L 1 g
F P
s
P
p
.002 w
.48742 .83143 m .48758 .82869 L p
.47999 .83029 L 1 g
F P
s
P
p
.002 w
.47322 .82878 m .47644 .83268 L .48315 .831 L p
1 g
F P
s
P
p
.47999 .83029 m .47874 .83056 L .48315 .831 L 1 g
F
P
p
.47999 .83029 m .48315 .831 L .48742 .83143 L 1 g
F
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .46362 .82568 L p
1 g
F P
s
P
p
.002 w
.47644 .83268 m .47572 .83181 L p
.46082 .82478 L 1 g
F P
s
P
p
.002 w
.47572 .83181 m .47322 .82878 L p
.46362 .82568 L 1 g
F P
s
P
p
.47572 .83181 m .46362 .82568 L .46082 .82478 L 1 g
F
P
p
.002 w
.46362 .82568 m .46403 .82325 L p
.45463 .82112 L 1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.44532 .81693 m .44466 .8164 L .4349 .81166 L 1 g
F
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.43431 .80672 m .4349 .81166 L .43899 .81186 L p
1 g
F P
s
P
p
.002 w
.40971 .80361 m .43378 .8113 L p
.42845 .7998 L 1 g
F P
s
P
p
.002 w
.43378 .8113 m .4349 .81166 L p
.4308 .80412 L 1 g
F P
s
P
p
.4308 .80412 m .42845 .7998 L .43378 .8113 L 1 g
F
P
p
.002 w
.41902 .78246 m .41722 .78653 L p
.42845 .7998 L 1 g
F P
s
P
p
.002 w
.41722 .78653 m .40971 .80361 L p
.42845 .7998 L 1 g
F P
s
P
p
.002 w
.42954 .80109 m .43042 .79874 L p
.42607 .79273 L 1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42954 .80109 L p
1 g
F P
s
P
p
.002 w
.4349 .81166 m .43431 .80672 L p
.42845 .7998 L 1 g
F P
s
P
p
.002 w
.42954 .80109 m .4285 .8039 L p
.43512 .80769 L 1 g
F P
s
P
p
.44427 .81291 m .42954 .80109 L .43512 .80769 L 1 g
F
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42281 .78488 L p
1 g
F P
s
P
p
.002 w
.42224 .78349 m .41902 .78246 L p
.42263 .78864 L 1 g
F P
s
P
p
.42866 .79897 m .42281 .78488 L .42263 .78864 L 1 g
F
P
p
.42281 .78488 m .42224 .78349 L .42263 .78864 L 1 g
F
P
p
.002 w
.40753 .77531 m .41902 .78246 L .42444 .77033 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.42561 .76041 m .40753 .77531 L p
.4224 .77093 L 1 g
F P
s
P
p
.42444 .77033 m .42482 .76712 L .4224 .77093 L 1 g
F
P
p
.42482 .76712 m .42561 .76041 L .4224 .77093 L 1 g
F
P
p
.002 w
.42567 .76627 m .42474 .76776 L p
.424 .78222 L 1 g
F P
s
P
p
.424 .78222 m .42474 .76776 L .42385 .77533 L 1 g
F
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43188 .78656 m .43081 .75768 L p
.42444 .77033 L 1 g
F P
s
P
p
.002 w
.42836 .76154 m .42444 .77033 L p
.43081 .75768 L 1 g
F P
s
P
p
.002 w
.42572 .76572 m .42579 .76511 L p
.42482 .76712 L 1 g
F P
s
P
p
.002 w
.42482 .76712 m .42579 .76511 L p
.43082 .75766 L 1 g
F P
s
P
p
.43082 .75766 m .43085 .75762 L .43033 .75844 L 1 g
F
P
p
.43082 .75766 m .43033 .75844 L .42482 .76712 L 1 g
F
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43188 .78656 m .44474 .78717 L .43117 .75711 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.43081 .75768 m .43188 .78656 L p
.43117 .75711 L 1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.45623 .78421 m .4651 .77799 L .43147 .75664 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.47039 .76916 m .47149 .75866 L .43171 .75624 L p
1 g
F P
s
P
p
.002 w
.46828 .74763 m .46108 .73729 L .43236 .75518 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43475 .75127 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43236 .75518 m .46108 .73729 L p
.44327 .74484 L 1 g
F P
s
P
p
.002 w
.43475 .75127 m .43569 .74928 L p
.44375 .74448 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .452 .73825 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.46108 .73729 m .45936 .73588 L p
.44327 .74484 L 1 g
F P
s
P
p
.002 w
.452 .73825 m .45268 .73647 L p
.46516 .73354 L 1 g
F P
s
P
p
.46516 .73354 m .46478 .7337 L .452 .73825 L 1 g
F
P
p
.002 w
.46108 .73729 m .46781 .73248 L p
.46174 .73492 L 1 g
F P
s
P
p
.002 w
.45936 .73588 m .46108 .73729 L p
.46174 .73492 L 1 g
F P
s
P
p
.4653 .73351 m .46027 .73559 L .45936 .73588 L 1 g
F
P
p
.46478 .7337 m .45936 .73588 L .452 .73825 L 1 g
F
P
p
.4653 .73351 m .45936 .73588 L .46478 .7337 L 1 g
F
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.46108 .73729 m .46828 .74763 L p
.48221 .72886 L 1 g
F P
s
P
p
.002 w
.47461 .72967 m .47494 .72815 L p
.48749 .7283 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72697 L p
1 g
F P
s
P
p
.47494 .72815 m .5 .72697 L .48749 .7283 L 1 g
F
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.46828 .74763 m .50692 .73515 L .50143 .72721 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52538 .72961 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54793 .73807 L p
1 g
F P
s
P
p
.52506 .72815 m .54793 .73807 L .53576 .73351 L 1 g
F
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.51315 .75695 m .55443 .75112 L .5516 .74102 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56513 .75102 L p
1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.56236 .74916 m .55443 .75112 L p
.56804 .75564 L 1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57691 .78425 L p
1 g
F P
s
P
p
.002 w
.5778 .79852 m .58914 .78037 L p
.57703 .78628 L 1 g
F P
s
P
p
.57421 .76511 m .57691 .78425 L .57668 .78071 L 1 g
F
P
p
.57403 .75989 m .57487 .76647 L .58914 .78037 L 1 g
F
P
p
.002 w
.57668 .78071 m .58372 .78051 L p
.57487 .76647 L 1 g
F P
s
P
p
.002 w
.58372 .78051 m .58914 .78037 L p
.57487 .76647 L 1 g
F P
s
P
p
.57421 .76511 m .57668 .78071 L .57591 .77461 L 1 g
F
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57028 .80061 L p
1 g
F P
s
P
p
.576 .78222 m .57028 .80061 L .5742 .79093 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.56883 .81287 m .5778 .79852 L p
.57094 .79984 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55636 .8152 L p
1 g
F P
s
P
p
.002 w
.5356 .83551 m .56883 .81287 L p
.55622 .81532 L 1 g
F P
s
P
p
.56958 .79874 m .55636 .8152 L .55939 .81273 L 1 g
F
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .5363 .82522 L p
1 g
F P
s
P
p
.002 w
.52486 .83094 m .53286 .83434 L p
.54857 .82149 L 1 g
F P
s
P
p
.55607 .81535 m .5363 .82522 L .54857 .82149 L 1 g
F
P
p
.5363 .82522 m .52486 .83094 L .54857 .82149 L 1 g
F
P
p
.002 w
.5363 .82522 m .53597 .82325 L p
.52482 .82872 L 1 g
F P
s
P
p
.55573 .81291 m .5363 .82522 L .54848 .81914 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51255 .83093 L p
1 g
F P
s
P
p
.002 w
.5356 .83551 m .5243 .8307 L p
.50108 .83254 L 1 g
F P
s
P
p
.002 w
.5243 .8307 m .5218 .82964 L p
.51255 .83093 L 1 g
F P
s
P
p
.5243 .8307 m .51255 .83093 L .50108 .83254 L 1 g
F
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48742 .83143 L p
1 g
F P
s
P
p
.49405 .83352 m .48519 .83147 L .47644 .83268 L 1 g
F
P
p
.5 .83269 m .48315 .831 L .49405 .83352 L 1 g
F
P
p
.51242 .82869 m .48742 .83143 L .50206 .83114 L 1 g
F
P
p
.002 w
.51255 .83093 m .51242 .82869 L p
.50206 .83114 L 1 g
F P
s
P
p
.002 w
.50945 .82439 m .48315 .831 L p
.50108 .83254 L 1 g
F P
s
P
p
.5356 .83551 m .48315 .831 L .52121 .83482 L 1 g
F
P
p
.002 w
.48742 .83143 m .48724 .83464 L p
.50206 .83114 L 1 g
F P
s
P
p
.002 w
.48315 .831 m .48094 .83156 L p
.48519 .83147 L 1 g
F P
s
P
p
.002 w
.48094 .83156 m .47644 .83268 L p
.48519 .83147 L 1 g
F P
s
P
p
.52121 .83482 m .5 .83269 L .49405 .83352 L 1 g
F
P
p
.002 w
.5218 .82964 m .52486 .83094 L p
.5363 .82522 L 1 g
F P
s
P
p
.002 w
.51264 .83243 m .51276 .83464 L p
.5234 .82942 L 1 g
F P
s
P
p
.52482 .82872 m .5218 .82964 L .5234 .82942 L 1 g
F
P
p
.5218 .82964 m .51264 .83243 L .5234 .82942 L 1 g
F
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51255 .83093 L p
1 g
F P
s
P
p
.53597 .82325 m .51255 .83093 L .51858 .83009 L 1 g
F
P
p
.53597 .82325 m .51264 .83243 L .52482 .82872 L 1 g
F
P
p
.002 w
.5218 .82964 m .50945 .82439 L p
.50108 .83254 L 1 g
F P
s
P
p
.50206 .83114 m .48724 .83464 L .51255 .83093 L 1 g
F
P
p
.002 w
.51255 .83093 m .51264 .83243 L p
.51858 .83009 L 1 g
F P
s
P
p
.55622 .81532 m .55607 .81535 L .53286 .83434 L 1 g
F
P
p
.002 w
.56883 .81287 m .56098 .81144 L p
.55622 .81532 L 1 g
F P
s
P
p
.002 w
.55636 .8152 m .55573 .81291 L p
.54848 .81914 L 1 g
F P
s
P
p
.56958 .79874 m .5567 .81643 L .56341 .80861 L 1 g
F
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56098 .81144 m .5352 .80671 L p
.55622 .81532 L 1 g
F P
s
P
p
.002 w
.53286 .83434 m .5356 .83551 L p
.55622 .81532 L 1 g
F P
s
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55636 .8152 L p
1 g
F P
s
P
p
.55622 .81532 m .55617 .8153 L .55607 .81535 L 1 g
F
P
p
.54848 .81914 m .53695 .82905 L .55636 .8152 L 1 g
F
P
p
.002 w
.5352 .80671 m .50945 .82439 L p
.55607 .81535 L 1 g
F P
s
P
p
.55617 .8153 m .5352 .80671 L .55607 .81535 L 1 g
F
P
p
.002 w
.50945 .82439 m .5218 .82964 L p
.55607 .81535 L 1 g
F P
s
P
p
.55607 .81535 m .5218 .82964 L .5363 .82522 L 1 g
F
P
p
.002 w
.51276 .83464 m .53695 .82905 L .5363 .82522 L p
1 g
F P
s
P
p
.52482 .82872 m .51276 .83464 L .5363 .82522 L 1 g
F
P
p
.002 w
.5363 .82522 m .53695 .82905 L p
.54848 .81914 L 1 g
F P
s
P
p
.002 w
.56098 .81144 m .56883 .81287 L p
.57094 .79984 L 1 g
F P
s
P
p
.002 w
.5567 .81643 m .55726 .81844 L p
.56232 .81034 L 1 g
F P
s
P
p
.56341 .80861 m .56098 .81144 L .56232 .81034 L 1 g
F
P
p
.56098 .81144 m .5567 .81643 L .56232 .81034 L 1 g
F
P
p
.002 w
.55636 .8152 m .5567 .81643 L p
.55939 .81273 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57028 .80061 L p
1 g
F P
s
P
p
.002 w
.57028 .80061 m .56958 .79874 L p
.56341 .80861 L 1 g
F P
s
P
p
.56341 .80861 m .55726 .81844 L .57028 .80061 L 1 g
F
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.57703 .78628 m .57585 .78686 L .57094 .79984 L 1 g
F
P
p
.57741 .7923 m .57094 .79984 L .5778 .79852 L 1 g
F
P
p
.57703 .78628 m .57094 .79984 L .57741 .7923 L 1 g
F
P
p
.57703 .78628 m .57615 .78612 L .57585 .78686 L 1 g
F
P
p
.002 w
.58914 .78037 m .57668 .78071 L p
.57703 .78628 L 1 g
F P
s
P
p
.002 w
.57691 .78425 m .576 .78222 L p
.5742 .79093 L 1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.57668 .78071 m .55081 .78141 L p
.57703 .78628 L 1 g
F P
s
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57691 .78425 L p
1 g
F P
s
P
p
.57585 .78686 m .57056 .79991 L .57094 .79984 L 1 g
F
P
p
.5742 .79093 m .5715 .8039 L .57691 .78425 L 1 g
F
P
p
.57585 .78686 m .5352 .80671 L .57056 .79991 L 1 g
F
P
p
.002 w
.5352 .80671 m .56098 .81144 L p
.57094 .79984 L 1 g
F P
s
P
p
.002 w
.57028 .80061 m .5715 .8039 L p
.5742 .79093 L 1 g
F P
s
P
p
.002 w
.55081 .78141 m .5352 .80671 L p
.57585 .78686 L 1 g
F P
s
P
p
.57615 .78612 m .55081 .78141 L .57585 .78686 L 1 g
F
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57593 .76867 L p
1 g
F P
s
P
p
.002 w
.57593 .76867 m .57421 .76511 L p
.57652 .77802 L 1 g
F P
s
P
p
.57652 .77802 m .57811 .78694 L .57593 .76867 L 1 g
F
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57487 .76647 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.55081 .78141 m .57668 .78071 L p
.57487 .76647 L 1 g
F P
s
P
p
.56431 .74928 m .57487 .76647 L .56911 .75733 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.57403 .75989 m .57194 .76183 L .57487 .76647 L 1 g
F
P
p
.57194 .76183 m .55081 .78141 L .57487 .76647 L 1 g
F
P
p
.56236 .74916 m .56804 .75564 L .56513 .75102 L 1 g
F
P
p
.002 w
.56513 .75102 m .56431 .74928 L p
.56911 .75733 L 1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.55443 .75112 m .55081 .78141 L p
.57583 .75823 L 1 g
F P
s
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56513 .75102 L p
1 g
F P
s
P
p
.56911 .75733 m .57628 .76938 L .56513 .75102 L 1 g
F
P
p
.57591 .77461 m .57668 .78071 L .57652 .77802 L 1 g
F
P
p
.002 w
.58914 .78037 m .59406 .74134 L p
.57403 .75989 L 1 g
F P
s
P
p
.002 w
.57691 .78425 m .57811 .78694 L p
.57652 .77802 L 1 g
F P
s
P
p
.56513 .75102 m .56804 .75564 L .57583 .75823 L 1 g
F
P
p
.002 w
.57487 .76647 m .57628 .76938 L p
.56911 .75733 L 1 g
F P
s
P
p
.002 w
.55443 .75112 m .56236 .74916 L p
.55753 .74551 L 1 g
F P
s
P
p
.54732 .73647 m .56513 .75102 L .56236 .74916 L 1 g
F
P
p
.5596 .74707 m .56236 .74916 L .56081 .74811 L 1 g
F
P
p
.54732 .73647 m .56236 .74916 L .5596 .74707 L 1 g
F
P
p
.002 w
.5516 .74102 m .55443 .75112 L p
.55753 .74551 L 1 g
F P
s
P
p
.54732 .73647 m .56577 .7524 L .56072 .74834 L 1 g
F
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.54793 .73807 m .51315 .75695 L .5516 .74102 L 1 g
F
P
p
.002 w
.52538 .72961 m .52506 .72815 L p
.53576 .73351 L 1 g
F P
s
P
p
.53687 .72919 m .5338 .73277 L .54793 .73807 L 1 g
F
P
p
.5338 .73277 m .51315 .75695 L .54793 .73807 L 1 g
F
P
p
.002 w
.50692 .73515 m .51315 .75695 L p
.5338 .73277 L 1 g
F P
s
P
p
.52999 .73134 m .50692 .73515 L .5338 .73277 L 1 g
F
P
p
.002 w
.521 .7293 m .50692 .73515 L p
.52999 .73134 L 1 g
F P
s
P
p
.52538 .72961 m .52999 .73134 L .53585 .73038 L 1 g
F
P
p
.521 .7293 m .52999 .73134 L .52538 .72961 L 1 g
F
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52538 .72961 L p
1 g
F P
s
P
p
.53576 .73351 m .54864 .73996 L .52538 .72961 L 1 g
F
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.58274 .7 m .54548 .71911 L .5516 .74102 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.58274 .7 m .5516 .74102 L .55753 .74551 L 1 g
F
P
p
.002 w
.59406 .74134 m .58274 .7 L p
.55753 .74551 L 1 g
F P
s
P
p
.002 w
.56236 .74916 m .59406 .74134 L p
.55753 .74551 L 1 g
F P
s
P
p
.56081 .74811 m .56236 .74916 L .56577 .7524 L 1 g
F
P
p
.002 w
.56513 .75102 m .5653 .75138 L p
.56236 .74916 L 1 g
F P
s
P
p
.002 w
.5653 .75138 m .56577 .7524 L p
.56236 .74916 L 1 g
F P
s
P
p
.002 w
.59406 .74134 m .56236 .74916 L p
.57583 .75823 L 1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.5516 .74102 m .54548 .71911 L p
.53687 .72919 L 1 g
F P
s
P
p
.002 w
.56577 .7524 m .56611 .75311 L p
.56072 .74834 L 1 g
F P
s
P
p
.002 w
.54793 .73807 m .54864 .73996 L p
.53576 .73351 L 1 g
F P
s
P
p
.53585 .73038 m .52999 .73134 L .5338 .73277 L 1 g
F
P
p
.002 w
.50692 .73515 m .521 .7293 L p
.50965 .72809 L 1 g
F P
s
P
p
.5 .72527 m .52538 .72961 L .521 .7293 L 1 g
F
P
p
.51403 .72855 m .521 .7293 L .5155 .7289 L 1 g
F
P
p
.5 .72527 m .521 .7293 L .51403 .72855 L 1 g
F
P
p
.5 .72527 m .52574 .7313 L .52419 .73104 L 1 g
F
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.50143 .72721 m .50692 .73515 L p
.50965 .72809 L 1 g
F P
s
P
p
.48543 .72452 m .46828 .74763 L .50143 .72721 L 1 g
F
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.52479 .68895 m .49275 .71465 L .50143 .72721 L p
1 g
F P
s
P
p
.52479 .68895 m .50143 .72721 L .50965 .72809 L 1 g
F
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.54548 .71911 m .52479 .68895 L p
.50965 .72809 L 1 g
F P
s
P
p
.002 w
.521 .7293 m .54548 .71911 L p
.50965 .72809 L 1 g
F P
s
P
p
.5155 .7289 m .521 .7293 L .52574 .7313 L 1 g
F
P
p
.002 w
.52538 .72961 m .52541 .72977 L p
.521 .7293 L 1 g
F P
s
P
p
.002 w
.52541 .72977 m .52574 .7313 L p
.521 .7293 L 1 g
F P
s
P
p
.002 w
.54548 .71911 m .521 .7293 L p
.53585 .73038 L 1 g
F P
s
P
p
.002 w
.50143 .72721 m .49275 .71465 L p
.48543 .72452 L 1 g
F P
s
P
p
.002 w
.52574 .7313 m .52576 .73141 L p
.52419 .73104 L 1 g
F P
s
P
p
.002 w
.5 .72697 m .5 .72845 L p
.48749 .7283 L 1 g
F P
s
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47461 .72967 L p
1 g
F P
s
P
p
.47683 .72943 m .46108 .73729 L .48221 .72886 L 1 g
F
P
p
.002 w
.46781 .73248 m .46108 .73729 L p
.48469 .72551 L 1 g
F P
s
P
p
.002 w
.47461 .72967 m .47424 .73141 L p
.4653 .73351 L 1 g
F P
s
P
p
.45268 .73647 m .47461 .72967 L .4653 .73351 L 1 g
F
P
p
.002 w
.49275 .71465 m .47123 .73003 L p
.48469 .72551 L 1 g
F P
s
P
p
.002 w
.47123 .73003 m .46781 .73248 L p
.47461 .72967 L 1 g
F P
s
P
p
.47123 .73003 m .47461 .72967 L .48469 .72551 L 1 g
F
P
p
.48469 .72551 m .47683 .72943 L .48221 .72886 L 1 g
F
P
p
.002 w
.5 .72845 m .47424 .73141 L .47461 .72967 L p
1 g
F P
s
P
p
.48749 .7283 m .5 .72845 L .47461 .72967 L 1 g
F
P
p
.002 w
.47217 .69774 m .45066 .72876 L .45936 .73588 L p
1 g
F P
s
P
p
.47217 .69774 m .45936 .73588 L .46174 .73492 L 1 g
F
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.49275 .71465 m .47217 .69774 L p
.46174 .73492 L 1 g
F P
s
P
p
.002 w
.46781 .73248 m .49275 .71465 L p
.46174 .73492 L 1 g
F P
s
P
p
.46516 .73354 m .4653 .73351 L .46478 .7337 L 1 g
F
P
p
.4653 .73351 m .47042 .73231 L .46027 .73559 L 1 g
F
P
p
.002 w
.45936 .73588 m .45734 .73423 L p
.452 .73825 L 1 g
F P
s
P
p
.452 .73825 m .44327 .74484 L .45936 .73588 L 1 g
F
P
p
.002 w
.47424 .73141 m .45136 .73996 L .452 .73825 L p
1 g
F P
s
P
p
.47042 .73231 m .47424 .73141 L .452 .73825 L 1 g
F
P
p
.002 w
.452 .73825 m .45136 .73996 L p
.44375 .74448 L 1 g
F P
s
P
p
.43569 .74928 m .452 .73825 L .44375 .74448 L 1 g
F
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.45066 .72876 m .43708 .74747 L p
.44327 .74484 L 1 g
F P
s
P
p
.002 w
.45734 .73423 m .45066 .72876 L p
.44327 .74484 L 1 g
F P
s
P
p
.43708 .74747 m .43475 .75127 L .44327 .74484 L 1 g
F
P
p
.43475 .75127 m .43236 .75518 L .44327 .74484 L 1 g
F
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43475 .75127 L p
1 g
F P
s
P
p
.44375 .74448 m .45136 .73996 L .43475 .75127 L 1 g
F
P
p
.002 w
.43475 .75127 m .43474 .75131 L p
.43465 .75144 L 1 g
F P
s
P
p
.42579 .76511 m .43475 .75127 L .43465 .75144 L 1 g
F
P
p
.42579 .76511 m .43474 .75131 L .43452 .75167 L 1 g
F
P
p
.42579 .76511 m .4347 .75138 L .43438 .7519 L 1 g
F
P
p
.42579 .76511 m .43466 .75148 L .43425 .75213 L 1 g
F
P
p
.42579 .76511 m .4346 .7516 L .43415 .75233 L 1 g
F
P
p
.42579 .76511 m .43454 .75172 L .43408 .75246 L 1 g
F
P
p
.42579 .76511 m .43449 .75184 L .4337 .75308 L 1 g
F
P
p
.002 w
.43191 .75592 m .46828 .74763 L p
.43236 .75518 L 1 g
F P
s
P
p
.002 w
.47149 .75866 m .46828 .74763 L .43191 .75592 L p
1 g
F P
s
P
p
.002 w
.43171 .75624 m .47149 .75866 L p
.43191 .75592 L 1 g
F P
s
P
p
.002 w
.43158 .75645 m .47039 .76916 L p
.43171 .75624 L 1 g
F P
s
P
p
.002 w
.4651 .77799 m .47039 .76916 L .43158 .75645 L p
1 g
F P
s
P
p
.002 w
.43147 .75664 m .4651 .77799 L p
.43158 .75645 L 1 g
F P
s
P
p
.002 w
.43134 .75683 m .45623 .78421 L p
.43147 .75664 L 1 g
F P
s
P
p
.002 w
.44474 .78717 m .45623 .78421 L .43134 .75683 L p
1 g
F P
s
P
p
.002 w
.43117 .75711 m .44474 .78717 L p
.43134 .75683 L 1 g
F P
s
P
p
.42579 .76511 m .4344 .75202 L .43085 .75762 L 1 g
F
P
p
.002 w
.43708 .74747 m .43075 .75618 L .43236 .75518 L p
1 g
F P
s
P
p
.002 w
.43236 .75518 m .43075 .75618 L .43191 .75592 L p
1 g
F P
s
P
p
.002 w
.43474 .75131 m .4347 .75138 L p
.43452 .75167 L 1 g
F P
s
P
p
.002 w
.4347 .75138 m .43466 .75148 L p
.43438 .7519 L 1 g
F P
s
P
p
.002 w
.43191 .75592 m .43075 .75618 L .43171 .75624 L p
1 g
F P
s
P
p
.002 w
.43171 .75624 m .43075 .75618 L .43158 .75645 L p
1 g
F P
s
P
p
.002 w
.43466 .75148 m .4346 .7516 L p
.43425 .75213 L 1 g
F P
s
P
p
.002 w
.4346 .7516 m .43454 .75172 L p
.43415 .75233 L 1 g
F P
s
P
p
.002 w
.43158 .75645 m .43075 .75618 L .43147 .75664 L p
1 g
F P
s
P
p
.002 w
.43147 .75664 m .43075 .75618 L .43134 .75683 L p
1 g
F P
s
P
p
.002 w
.43454 .75172 m .43449 .75184 L p
.43408 .75246 L 1 g
F P
s
P
p
.002 w
.43449 .75184 m .4344 .75202 L p
.4337 .75308 L 1 g
F P
s
P
p
.002 w
.43134 .75683 m .43075 .75618 L .43117 .75711 L p
1 g
F P
s
P
p
.002 w
.43075 .75618 m .42561 .76041 L p
.42482 .76712 L 1 g
F P
s
P
p
.002 w
.42444 .77033 m .42836 .76154 L p
.42482 .76712 L 1 g
F P
s
P
p
.002 w
.42836 .76154 m .43075 .75618 L p
.42482 .76712 L 1 g
F P
s
P
p
.002 w
.4344 .75202 m .43389 .75311 L p
.43085 .75762 L 1 g
F P
s
P
p
.002 w
.43117 .75711 m .43075 .75618 L .43081 .75768 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42481 .76714 L p
1 g
F P
s
P
p
.002 w
.42481 .76714 m .42482 .76712 L p
.42494 .76693 L 1 g
F P
s
P
p
.42494 .76693 m .43389 .75311 L .42481 .76714 L 1 g
F
P
p
.002 w
.43081 .75768 m .43075 .75618 L .42836 .76154 L p
1 g
F P
s
P
p
.002 w
.42444 .77033 m .41902 .78246 L .42287 .78369 L p
1 g
F P
s
P
p
.424 .78222 m .42385 .77526 L .4237 .77655 L 1 g
F
P
p
.002 w
.42281 .78488 m .424 .78222 L p
.42345 .77198 L 1 g
F P
s
P
p
.002 w
.42287 .78369 m .43188 .78656 L p
.42444 .77033 L 1 g
F P
s
P
p
.002 w
.42474 .76776 m .42372 .76938 L p
.42385 .77533 L 1 g
F P
s
P
p
.43085 .75762 m .43389 .75311 L .42482 .76712 L 1 g
F
P
p
.002 w
.42372 .76938 m .42345 .77198 L p
.4237 .77655 L 1 g
F P
s
P
p
.42385 .77526 m .42372 .76938 L .4237 .77655 L 1 g
F
P
p
.43042 .79874 m .42281 .78488 L .42607 .79273 L 1 g
F
P
p
.002 w
.43188 .78656 m .42287 .78369 L p
.42866 .79897 L 1 g
F P
s
P
p
.002 w
.42287 .78369 m .42224 .78349 L p
.42281 .78488 L 1 g
F P
s
P
p
.42866 .79897 m .42287 .78369 L .42281 .78488 L 1 g
F
P
p
.002 w
.42189 .78694 m .42345 .77198 L p
.42166 .77365 L 1 g
F P
s
P
p
.002 w
.42345 .77198 m .42372 .76938 L .42357 .7697 L p
1 g
F P
s
P
p
.002 w
.42357 .7697 m .42166 .77365 L p
.42345 .77198 L 1 g
F P
s
P
p
.002 w
.42345 .77198 m .42189 .78694 L .42281 .78488 L p
1 g
F P
s
P
p
.002 w
.42281 .78488 m .42189 .78694 L p
.42607 .79273 L 1 g
F P
s
P
p
.42845 .7998 m .42866 .79897 L .41902 .78246 L 1 g
F
P
p
.002 w
.43431 .80672 m .43188 .78656 L p
.42845 .7998 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42954 .80109 L p
1 g
F P
s
P
p
.42607 .79273 m .42189 .78694 L .42954 .80109 L 1 g
F
P
p
.002 w
.43188 .78656 m .43431 .80672 L p
.46013 .8129 L 1 g
F P
s
P
p
.002 w
.44355 .81552 m .44427 .81291 L p
.43526 .80776 L 1 g
F P
s
P
p
.43526 .80776 m .43553 .80807 L .44355 .81552 L 1 g
F
P
p
.43512 .80769 m .43795 .81103 L .44355 .81552 L 1 g
F
P
p
.002 w
.43899 .81186 m .46013 .8129 L p
.43431 .80672 L 1 g
F P
s
P
p
.43526 .80776 m .43512 .80769 L .43553 .80807 L 1 g
F
P
p
.43512 .80769 m .43047 .80502 L .43795 .81103 L 1 g
F
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44355 .81552 L p
1 g
F P
s
P
p
.46403 .82325 m .44355 .81552 L .45463 .82112 L 1 g
F
P
p
.002 w
.46013 .8129 m .43605 .81172 L p
.46079 .82425 L 1 g
F P
s
P
p
.002 w
.43605 .81172 m .4349 .81166 L p
.46079 .82425 L 1 g
F P
s
P
p
.002 w
.4349 .81166 m .4362 .81684 L p
.46082 .82478 L 1 g
F P
s
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44355 .81552 L p
1 g
F P
s
P
p
.43047 .80502 m .4285 .8039 L .44355 .81552 L 1 g
F
P
p
.46082 .82478 m .46079 .82425 L .44466 .8164 L 1 g
F
P
p
.46082 .82478 m .44466 .8164 L .44532 .81693 L 1 g
F
P
p
.002 w
.44355 .81552 m .44274 .81844 L p
.45463 .82112 L 1 g
F P
s
P
p
.48758 .82869 m .46362 .82568 L .47359 .8289 L 1 g
F
P
p
.002 w
.47322 .82878 m .46013 .8129 L p
.46082 .82478 L 1 g
F P
s
P
p
.002 w
.4362 .81684 m .43969 .83083 L p
.46082 .82478 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46362 .82568 L p
1 g
F P
s
P
p
.45463 .82112 m .44274 .81844 L .46362 .82568 L 1 g
F
P
p
.002 w
.46362 .82568 m .46305 .82905 L p
.47359 .8289 L 1 g
F P
s
P
p
.002 w
.46013 .8129 m .47322 .82878 L p
.50945 .82439 L 1 g
F P
s
P
p
.48758 .82869 m .47359 .8289 L .47874 .83056 L 1 g
F
P
p
.002 w
.48315 .831 m .50945 .82439 L p
.47322 .82878 L 1 g
F P
s
P
p
.002 w
.48731 .83332 m .48742 .83143 L p
.47874 .83056 L 1 g
F P
s
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48731 .83332 L p
1 g
F P
s
P
p
.47359 .8289 m .46305 .82905 L .48731 .83332 L 1 g
F
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.31052 .65162 m .29236 .62105 L .27959 .66518 L p
1 g
F P
s
P
p
.002 w
.27959 .66518 m .29967 .68846 L .31052 .65162 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.6002 .81336 m .56883 .81287 L .5356 .83551 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.62068 .44411 m .62772 .42653 L .55593 .39344 L p
1 g
F P
s
P
p
.002 w
.55593 .39344 m .54632 .40983 L .62068 .44411 L p
1 g
F P
s
P
p
.002 w
.56883 .81287 m .6002 .81336 L .62468 .77459 L p
1 g
F P
s
P
p
.002 w
.6564 .76432 m .62468 .77459 L .6002 .81336 L p
1 g
F P
s
P
p
.002 w
.62772 .42653 m .62068 .44411 L .68194 .49574 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.36797 .48855 m .37331 .45632 L .31419 .4863 L p
1 g
F P
s
P
p
.002 w
.31419 .4863 m .31185 .51676 L .36797 .48855 L p
1 g
F P
s
P
p
.002 w
.35917 .75003 m .32934 .74112 L .34481 .77182 L p
1 g
F P
s
P
p
.002 w
.34481 .77182 m .36972 .7711 L .35917 .75003 L p
1 g
F P
s
P
p
.002 w
.69162 .6921 m .71392 .67082 L .69739 .60587 L p
1 g
F P
s
P
p
.002 w
.71328 .58158 m .69739 .60587 L .71392 .67082 L p
1 g
F P
s
P
p
.002 w
.323 .58575 m .31479 .55023 L .28018 .59052 L p
1 g
F P
s
P
p
.002 w
.28018 .59052 m .29236 .62105 L .323 .58575 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.62468 .77459 m .6564 .76432 L .66367 .71134 L p
1 g
F P
s
P
p
.002 w
.69162 .6921 m .66367 .71134 L .6564 .76432 L p
1 g
F P
s
P
p
.002 w
.44567 .44702 m .45614 .4191 L .38213 .4288 L p
1 g
F P
s
P
p
.002 w
.38213 .4288 m .37331 .45632 L .44567 .44702 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.53525 .43217 m .54632 .40983 L .4677 .39693 L p
1 g
F P
s
P
p
.002 w
.4677 .39693 m .45614 .4191 L .53525 .43217 L p
1 g
F P
s
P
p
.002 w
.68194 .49574 m .67185 .5186 L .71328 .58158 L p
1 g
F P
s
P
p
.002 w
.67185 .5186 m .68194 .49574 L .62068 .44411 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.69739 .60587 m .71328 .58158 L .67185 .5186 L p
1 g
F P
s
P
p
.002 w
.33418 .6813 m .31052 .65162 L .29967 .68846 L p
1 g
F P
s
P
p
.002 w
.29967 .68846 m .32561 .70983 L .33418 .6813 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.35671 .72863 m .32561 .70983 L .32934 .74112 L p
1 g
F P
s
P
p
.002 w
.32934 .74112 m .35917 .75003 L .35671 .72863 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.50945 .82439 m .48273 .80716 L .46013 .8129 L p
1 g
F P
s
P
p
.002 w
.48273 .80716 m .50945 .82439 L .5352 .80671 L p
1 g
F P
s
P
p
.002 w
.62468 .77459 m .58914 .78037 L .56883 .81287 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.40753 .77531 m .38719 .7896 L .40971 .80361 L p
1 g
F P
s
P
p
.002 w
.40971 .80361 m .41902 .78246 L .40753 .77531 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.36634 .5246 m .36797 .48855 L .31185 .51676 L p
1 g
F P
s
P
p
.002 w
.31185 .51676 m .31479 .55023 L .36634 .5246 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.39863 .76586 m .36972 .7711 L .38719 .7896 L p
1 g
F P
s
P
p
.002 w
.38719 .7896 m .40753 .77531 L .39863 .76586 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.3363 .62226 m .323 .58575 L .29236 .62105 L p
1 g
F P
s
P
p
.002 w
.29236 .62105 m .31052 .65162 L .3363 .62226 L p
1 g
F P
s
P
p
.002 w
.66367 .71134 m .69162 .6921 L .67573 .6306 L p
1 g
F P
s
P
p
.002 w
.69739 .60587 m .67573 .6306 L .69162 .6921 L p
1 g
F P
s
P
p
.002 w
.61012 .4667 m .62068 .44411 L .54632 .40983 L p
1 g
F P
s
P
p
.002 w
.54632 .40983 m .53525 .43217 L .61012 .4667 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.62068 .44411 m .61012 .4667 L .67185 .5186 L p
1 g
F P
s
P
p
.002 w
.3933 .75512 m .35917 .75003 L .36972 .7711 L p
1 g
F P
s
P
p
.002 w
.36972 .7711 m .39863 .76586 L .3933 .75512 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.58914 .78037 m .62468 .77459 L .63084 .72793 L p
1 g
F P
s
P
p
.002 w
.66367 .71134 m .63084 .72793 L .62468 .77459 L p
1 g
F P
s
P
p
.002 w
.46013 .8129 m .44474 .78717 L .43188 .78656 L p
1 g
F P
s
P
p
.002 w
.44474 .78717 m .46013 .8129 L .48273 .80716 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.43664 .47994 m .44567 .44702 L .37331 .45632 L p
1 g
F P
s
P
p
.002 w
.37331 .45632 m .36797 .48855 L .43664 .47994 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.36269 .70918 m .33418 .6813 L .32561 .70983 L p
1 g
F P
s
P
p
.002 w
.32561 .70983 m .35671 .72863 L .36269 .70918 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.5352 .80671 m .50027 .79499 L .48273 .80716 L p
1 g
F P
s
P
p
.002 w
.50027 .79499 m .5352 .80671 L .55081 .78141 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.52305 .45991 m .53525 .43217 L .45614 .4191 L p
1 g
F P
s
P
p
.002 w
.45614 .4191 m .44567 .44702 L .52305 .45991 L p
1 g
F P
s
P
p
.002 w
.67573 .6306 m .69739 .60587 L .65674 .54439 L p
1 g
F P
s
P
p
.002 w
.67185 .5186 m .65674 .54439 L .69739 .60587 L p
1 g
F P
s
P
p
.002 w
.39211 .74425 m .35671 .72863 L .35917 .75003 L p
1 g
F P
s
P
p
.002 w
.35917 .75003 m .3933 .75512 L .39211 .74425 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.48273 .80716 m .45623 .78421 L .44474 .78717 L p
1 g
F P
s
P
p
.002 w
.45623 .78421 m .48273 .80716 L .50027 .79499 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.65674 .54439 m .67185 .5186 L .61012 .4667 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.36851 .5634 m .36634 .5246 L .31479 .55023 L p
1 g
F P
s
P
p
.002 w
.31479 .55023 m .323 .58575 L .36851 .5634 L p
1 g
F P
s
P
p
.002 w
.35432 .65866 m .3363 .62226 L .31052 .65162 L p
1 g
F P
s
P
p
.002 w
.31052 .65162 m .33418 .6813 L .35432 .65866 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.63084 .72793 m .66367 .71134 L .64887 .65503 L p
1 g
F P
s
P
p
.002 w
.67573 .6306 m .64887 .65503 L .66367 .71134 L p
1 g
F P
s
P
p
.002 w
.63084 .72793 m .59406 .74134 L .58914 .78037 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.40753 .77531 m .43075 .75618 L .39863 .76586 L closepath p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.39521 .73441 m .36269 .70918 L .35671 .72863 L p
1 g
F P
s
P
p
.002 w
.35671 .72863 m .39211 .74425 L .39521 .73441 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.39863 .76586 m .43075 .75618 L .3933 .75512 L closepath p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.50027 .79499 m .4651 .77799 L .45623 .78421 L p
1 g
F P
s
P
p
.002 w
.4651 .77799 m .50027 .79499 L .51082 .77765 L p
1 g
F P
s
P
p
.002 w
.55081 .78141 m .51082 .77765 L .50027 .79499 L p
1 g
F P
s
P
p
.002 w
.5963 .4937 m .61012 .4667 L .53525 .43217 L p
1 g
F P
s
P
p
.002 w
.53525 .43217 m .52305 .45991 L .5963 .4937 L p
1 g
F P
s
P
p
.002 w
.61012 .4667 m .5963 .4937 L .65674 .54439 L p
1 g
F P
s
P
p
.002 w
.42934 .51691 m .43664 .47994 L .36797 .48855 L p
1 g
F P
s
P
p
.002 w
.36797 .48855 m .36634 .5246 L .42934 .51691 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.37654 .69383 m .35432 .65866 L .33418 .6813 L p
1 g
F P
s
P
p
.002 w
.33418 .6813 m .36269 .70918 L .37654 .69383 L p
1 g
F P
s
P
p
.002 w
.37444 .60379 m .36851 .5634 L .323 .58575 L p
1 g
F P
s
P
p
.002 w
.323 .58575 m .3363 .62226 L .37444 .60379 L p
1 g
F P
s
P
p
.002 w
.3933 .75512 m .43075 .75618 L .39211 .74425 L closepath p
1 g
F P
s
P
p
.002 w
.51082 .77765 m .55081 .78141 L .55443 .75112 L p
1 g
F P
s
P
p
.002 w
.64887 .65503 m .67573 .6306 L .63701 .57239 L p
1 g
F P
s
P
p
.002 w
.65674 .54439 m .63701 .57239 L .67573 .6306 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59406 .74134 m .63084 .72793 L .61756 .67841 L p
1 g
F P
s
P
p
.002 w
.64887 .65503 m .61756 .67841 L .63084 .72793 L p
1 g
F P
s
P
p
.002 w
.51005 .49229 m .52305 .45991 L .44567 .44702 L p
1 g
F P
s
P
p
.002 w
.44567 .44702 m .43664 .47994 L .51005 .49229 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.39211 .74425 m .43075 .75618 L .39521 .73441 L closepath p
1 g
F P
s
P
p
.002 w
.63701 .57239 m .65674 .54439 L .5963 .4937 L p
1 g
F P
s
P
p
.002 w
.51082 .77765 m .47039 .76916 L .4651 .77799 L p
1 g
F P
s
P
p
.002 w
.40228 .72667 m .37654 .69383 L .36269 .70918 L p
1 g
F P
s
P
p
.002 w
.36269 .70918 m .39521 .73441 L .40228 .72667 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.47039 .76916 m .51082 .77765 L .51315 .75695 L p
1 g
F P
s
P
p
.002 w
.55443 .75112 m .51315 .75695 L .51082 .77765 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.38398 .6445 m .37444 .60379 L .3363 .62226 L p
1 g
F P
s
P
p
.002 w
.3363 .62226 m .35432 .65866 L .38398 .6445 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.39521 .73441 m .43075 .75618 L .40228 .72667 L closepath p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.40228 .72667 m .43075 .75618 L .41259 .72189 L closepath p
1 g
F P
s
P
p
.002 w
.43818 .72299 m .43075 .75618 L .45066 .72876 L closepath p
1 g
F P
s
P
p
.004 w
.44513 .7262 m
.5 .6118 L
s
P
p
.002 w
.42501 .72062 m .43075 .75618 L .43818 .72299 L closepath p
1 g
F P
s
P
p
.002 w
.41259 .72189 m .43075 .75618 L .42501 .72062 L closepath p
1 g
F P
s
P
p
.002 w
.51315 .75695 m .47149 .75866 L .47039 .76916 L p
1 g
F P
s
P
p
.002 w
.61756 .67841 m .58274 .7 L .59406 .74134 L p
1 g
F P
s
P
p
.002 w
.42402 .55683 m .42934 .51691 L .36634 .5246 L p
1 g
F P
s
P
p
.002 w
.36634 .5246 m .36851 .5634 L .42402 .55683 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.61756 .67841 m .64887 .65503 L .61319 .60176 L p
1 g
F P
s
P
p
.002 w
.63701 .57239 m .61319 .60176 L .64887 .65503 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.57958 .52437 m .5963 .4937 L .52305 .45991 L p
1 g
F P
s
P
p
.002 w
.52305 .45991 m .51005 .49229 L .57958 .52437 L p
1 g
F P
s
P
p
.002 w
.39683 .68428 m .38398 .6445 L .35432 .65866 L p
1 g
F P
s
P
p
.002 w
.35432 .65866 m .37654 .69383 L .39683 .68428 L p
1 g
F P
s
P
p
.002 w
.5963 .4937 m .57958 .52437 L .63701 .57239 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.37654 .69383 m .40228 .72667 L .41259 .72189 L p
1 g
F P
s
P
p
.002 w
.47149 .75866 m .51315 .75695 L .50692 .73515 L p
1 g
F P
s
P
p
.002 w
.50692 .73515 m .46828 .74763 L .47149 .75866 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.41259 .72189 m .39683 .68428 L .37654 .69383 L p
1 g
F P
s
P
p
.002 w
.49665 .52836 m .51005 .49229 L .43664 .47994 L p
1 g
F P
s
P
p
.002 w
.43664 .47994 m .42934 .51691 L .49665 .52836 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.004 w
.42436 .76951 m
.43075 .75618 L
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.61319 .60176 m .63701 .57239 L .57958 .52437 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.39683 .68428 m .41259 .72189 L .42501 .72062 L p
1 g
F P
s
P
p
.002 w
.42086 .59847 m .42402 .55683 L .36851 .5634 L p
1 g
F P
s
P
p
.002 w
.36851 .5634 m .37444 .60379 L .42086 .59847 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.58274 .7 m .61756 .67841 L .58597 .6316 L p
1 g
F P
s
P
p
.002 w
.61319 .60176 m .58597 .6316 L .61756 .67841 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.42137 .68167 m .42501 .72062 L .43818 .72299 L p
1 g
F P
s
P
p
.002 w
.42501 .72062 m .42137 .68167 L .39683 .68428 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.44745 .68632 m .43818 .72299 L .45066 .72876 L p
1 g
F P
s
P
p
.002 w
.43818 .72299 m .44745 .68632 L .42137 .68167 L p
1 g
F P
s
P
p
.002 w
.45066 .72876 m .47217 .69774 L .44745 .68632 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.38398 .6445 m .39683 .68428 L .42137 .68167 L p
1 g
F P
s
P
p
.002 w
.41997 .64053 m .42086 .59847 L .37444 .60379 L p
1 g
F P
s
P
p
.002 w
.37444 .60379 m .38398 .6445 L .41997 .64053 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.54548 .71911 m .58274 .7 L .5562 .66097 L p
1 g
F P
s
P
p
.002 w
.58597 .6316 m .5562 .66097 L .58274 .7 L p
1 g
F P
s
P
p
.002 w
.42137 .68167 m .41997 .64053 L .38398 .6445 L p
1 g
F P
s
P
p
.002 w
.56043 .5578 m .57958 .52437 L .51005 .49229 L p
1 g
F P
s
P
p
.002 w
.51005 .49229 m .49665 .52836 L .56043 .5578 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.48328 .56703 m .49665 .52836 L .42934 .51691 L p
1 g
F P
s
P
p
.004 w
.45938 .54482 m
.5 .6118 L
s
P
p
.002 w
.42934 .51691 m .42402 .55683 L .48328 .56703 L p
1 g
F P
s
P
p
.004 w
.4473 .52491 m
.45088 .5308 L
s
P
p
.004 w
.4241 .48666 m
.4473 .52491 L
s
P
p
.004 w
.45088 .5308 m
.45125 .53142 L
s
P
p
.002 w
.57958 .52437 m .56043 .5578 L .61319 .60176 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.5562 .66097 m .52479 .68895 L .54548 .71911 L p
1 g
F P
s
P
p
.002 w
.58597 .6316 m .61319 .60176 L .56043 .5578 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.41997 .64053 m .42137 .68167 L .44745 .68632 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.49275 .71465 m .52479 .68895 L .4946 .66405 L p
1 g
F P
s
P
p
.002 w
.4946 .66405 m .47217 .69774 L .49275 .71465 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.004 w
.39391 .83301 m
.40479 .81032 L
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.47036 .6071 m .48328 .56703 L .42402 .55683 L p
1 g
F P
s
P
p
.002 w
.42402 .55683 m .42086 .59847 L .47036 .6071 L p
1 g
F P
s
P
p
.002 w
.45829 .64728 m .44745 .68632 L .47217 .69774 L p
1 g
F P
s
P
p
.002 w
.44745 .68632 m .45829 .64728 L .41997 .64053 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.47217 .69774 m .4946 .66405 L .45829 .64728 L p
1 g
F P
s
P
p
.002 w
.5562 .66097 m .58597 .6316 L .53944 .59296 L p
1 g
F P
s
P
p
.002 w
.56043 .5578 m .53944 .59296 L .58597 .6316 L p
1 g
F P
s
P
p
.002 w
.42086 .59847 m .41997 .64053 L .45829 .64728 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.53944 .59296 m .56043 .5578 L .49665 .52836 L p
1 g
F P
s
P
p
.002 w
.49665 .52836 m .48328 .56703 L .53944 .59296 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.52479 .68895 m .5562 .66097 L .51727 .62876 L p
1 g
F P
s
P
p
.002 w
.51727 .62876 m .4946 .66405 L .52479 .68895 L p
1 g
F P
s
P
p
.002 w
.45829 .64728 m .47036 .6071 L .42086 .59847 L p
1 g
F P
s
P
p
.002 w
.53944 .59296 m .51727 .62876 L .5562 .66097 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.47036 .6071 m .45829 .64728 L .4946 .66405 L p
1 g
F P
s
P
p
.002 w
.4946 .66405 m .51727 .62876 L .47036 .6071 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.51727 .62876 m .53944 .59296 L .48328 .56703 L p
1 g
F P
s
P
p
.002 w
.48328 .56703 m .47036 .6071 L .51727 .62876 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.004 w
.40479 .81032 m
.42436 .76951 L
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .4241 .48666 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .39391 .83301 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.49)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.49)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.44658 .62209 m .46728 .59025 L .49976 .60572 L p
1 g
F P
s
P
p
.002 w
.49976 .60572 m .48854 .64202 L .44658 .62209 L p
1 g
F P
s
P
p
.002 w
.511 .56955 m .49976 .60572 L .46728 .59025 L p
1 g
F P
s
P
p
.002 w
.48854 .64202 m .49976 .60572 L .53534 .61134 L p
1 g
F P
s
P
p
.002 w
.49976 .60572 m .511 .56955 L .53529 .57338 L p
1 g
F P
s
P
p
.002 w
.53529 .57338 m .53534 .61134 L .49976 .60572 L p
1 g
F P
s
P
p
.002 w
.42721 .65374 m .44658 .62209 L .48854 .64202 L p
1 g
F P
s
P
p
.002 w
.48854 .64202 m .47758 .67763 L .42721 .65374 L p
1 g
F P
s
P
p
.002 w
.47758 .67763 m .48854 .64202 L .53447 .6493 L p
1 g
F P
s
P
p
.002 w
.53534 .61134 m .53447 .6493 L .48854 .64202 L p
1 g
F P
s
P
p
.002 w
.53447 .6493 m .53534 .61134 L .57029 .6065 L p
1 g
F P
s
P
p
.002 w
.53534 .61134 m .53529 .57338 L .55914 .57003 L p
1 g
F P
s
P
p
.002 w
.55914 .57003 m .57029 .6065 L .53534 .61134 L p
1 g
F P
s
P
p
.002 w
.41297 .59153 m .44131 .56655 L .46728 .59025 L p
1 g
F P
s
P
p
.002 w
.46728 .59025 m .44658 .62209 L .41297 .59153 L p
1 g
F P
s
P
p
.002 w
.48883 .55898 m .46728 .59025 L .44131 .56655 L p
1 g
F P
s
P
p
.002 w
.46728 .59025 m .48883 .55898 L .511 .56955 L p
1 g
F P
s
P
p
.002 w
.52199 .53438 m .511 .56955 L .48883 .55898 L p
1 g
F P
s
P
p
.002 w
.511 .56955 m .52199 .53438 L .53433 .53631 L p
1 g
F P
s
P
p
.002 w
.53433 .53631 m .53529 .57338 L .511 .56955 L p
1 g
F P
s
P
p
.002 w
.53447 .6493 m .5327 .6864 L .47758 .67763 L p
1 g
F P
s
P
p
.002 w
.5327 .6864 m .53447 .6493 L .57962 .64315 L p
1 g
F P
s
P
p
.002 w
.57029 .6065 m .57962 .64315 L .53447 .6493 L p
1 g
F P
s
P
p
.002 w
.53529 .57338 m .53433 .53631 L .54643 .53459 L p
1 g
F P
s
P
p
.002 w
.54643 .53459 m .55914 .57003 L .53529 .57338 L p
1 g
F P
s
P
p
.002 w
.44131 .56655 m .47114 .54277 L .48883 .55898 L p
1 g
F P
s
P
p
.002 w
.51073 .529 m .48883 .55898 L .47114 .54277 L p
1 g
F P
s
P
p
.002 w
.48883 .55898 m .51073 .529 L .52199 .53438 L p
1 g
F P
s
P
p
.002 w
.3868 .61714 m .41297 .59153 L .44658 .62209 L p
1 g
F P
s
P
p
.002 w
.44658 .62209 m .42721 .65374 L .3868 .61714 L p
1 g
F P
s
P
p
.002 w
.40965 .68446 m .42721 .65374 L .47758 .67763 L p
1 g
F P
s
P
p
.002 w
.47758 .67763 m .46716 .71169 L .40965 .68446 L p
1 g
F P
s
P
p
.002 w
.46716 .71169 m .47758 .67763 L .5327 .6864 L p
1 g
F P
s
P
p
.002 w
.57962 .64315 m .57029 .6065 L .60092 .59168 L p
1 g
F P
s
P
p
.002 w
.57029 .6065 m .55914 .57003 L .58 .55986 L p
1 g
F P
s
P
p
.002 w
.58 .55986 m .60092 .59168 L .57029 .6065 L p
1 g
F P
s
P
p
.002 w
.55914 .57003 m .54643 .53459 L .557 .5294 L p
1 g
F P
s
P
p
.002 w
.557 .5294 m .58 .55986 L .55914 .57003 L p
1 g
F P
s
P
p
.002 w
.39129 .55349 m .42462 .53705 L .44131 .56655 L p
1 g
F P
s
P
p
.002 w
.44131 .56655 m .41297 .59153 L .39129 .55349 L p
1 g
F P
s
P
p
.002 w
.47114 .54277 m .44131 .56655 L .42462 .53705 L p
1 g
F P
s
P
p
.002 w
.42462 .53705 m .45983 .52262 L .47114 .54277 L p
1 g
F P
s
P
p
.002 w
.50176 .52075 m .47114 .54277 L .45983 .52262 L p
1 g
F P
s
P
p
.002 w
.47114 .54277 m .50176 .52075 L .51073 .529 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .52199 .53438 L .51073 .529 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .53433 .53631 L .52199 .53438 L closepath p
1 g
F P
s
P
p
.002 w
.5327 .6864 m .53007 .72174 L .46716 .71169 L p
1 g
F P
s
P
p
.002 w
.53007 .72174 m .5327 .6864 L .58691 .67911 L p
1 g
F P
s
P
p
.002 w
.57962 .64315 m .58691 .67911 L .5327 .6864 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .54643 .53459 L .53433 .53631 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .51073 .529 L .50176 .52075 L closepath p
1 g
F P
s
P
p
.002 w
.36343 .64277 m .3868 .61714 L .42721 .65374 L p
1 g
F P
s
P
p
.002 w
.42721 .65374 m .40965 .68446 L .36343 .64277 L p
1 g
F P
s
P
p
.002 w
.58691 .67911 m .57962 .64315 L .61926 .62411 L p
1 g
F P
s
P
p
.002 w
.60092 .59168 m .61926 .62411 L .57962 .64315 L p
1 g
F P
s
P
p
.002 w
.36062 .57154 m .39129 .55349 L .41297 .59153 L p
1 g
F P
s
P
p
.002 w
.41297 .59153 m .3868 .61714 L .36062 .57154 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .557 .5294 L .54643 .53459 L closepath p
1 g
F P
s
P
p
.002 w
.45983 .52262 m .49606 .51051 L .50176 .52075 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .50176 .52075 L .49606 .51051 L closepath p
1 g
F P
s
P
p
.002 w
.60092 .59168 m .58 .55986 L .59562 .5439 L p
1 g
F P
s
P
p
.002 w
.58 .55986 m .557 .5294 L .56489 .52128 L p
1 g
F P
s
P
p
.002 w
.56489 .52128 m .59562 .5439 L .58 .55986 L p
1 g
F P
s
P
p
.002 w
.41908 .50486 m .45613 .50066 L .45983 .52262 L p
1 g
F P
s
P
p
.002 w
.45983 .52262 m .42462 .53705 L .41908 .50486 L p
1 g
F P
s
P
p
.002 w
.49606 .51051 m .45983 .52262 L .45613 .50066 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .56489 .52128 L .557 .5294 L closepath p
1 g
F P
s
P
p
.002 w
.45613 .50066 m .49423 .49938 L .49606 .51051 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .49606 .51051 L .49423 .49938 L closepath p
1 g
F P
s
P
p
.002 w
.61926 .62411 m .60092 .59168 L .62394 .56835 L p
1 g
F P
s
P
p
.002 w
.59562 .5439 m .62394 .56835 L .60092 .59168 L p
1 g
F P
s
P
p
.002 w
.39431 .71351 m .40965 .68446 L .46716 .71169 L p
1 g
F P
s
P
p
.002 w
.46716 .71169 m .45752 .74339 L .39431 .71351 L p
1 g
F P
s
P
p
.002 w
.45752 .74339 m .46716 .71169 L .53007 .72174 L p
1 g
F P
s
P
p
.002 w
.38395 .51189 m .41908 .50486 L .42462 .53705 L p
1 g
F P
s
P
p
.002 w
.42462 .53705 m .39129 .55349 L .38395 .51189 L p
1 g
F P
s
P
p
.002 w
.58691 .67911 m .59197 .71352 L .53007 .72174 L p
1 g
F P
s
P
p
.002 w
.59197 .71352 m .58691 .67911 L .63458 .65639 L p
1 g
F P
s
P
p
.002 w
.61926 .62411 m .63458 .65639 L .58691 .67911 L p
1 g
F P
s
P
p
.002 w
.59562 .5439 m .56489 .52128 L .56923 .5111 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .56923 .5111 L .56489 .52128 L closepath p
1 g
F P
s
P
p
.002 w
.46052 .47926 m .4965 .48855 L .49423 .49938 L p
1 g
F P
s
P
p
.002 w
.49423 .49938 m .45613 .50066 L .46052 .47926 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .49423 .49938 L .4965 .48855 L closepath p
1 g
F P
s
P
p
.002 w
.3334 .59078 m .36062 .57154 L .3868 .61714 L p
1 g
F P
s
P
p
.002 w
.3868 .61714 m .36343 .64277 L .3334 .59078 L p
1 g
F P
s
P
p
.002 w
.53007 .72174 m .52663 .75446 L .45752 .74339 L p
1 g
F P
s
P
p
.002 w
.52663 .75446 m .53007 .72174 L .59197 .71352 L p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .50263 .47921 L .51198 .47237 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .4965 .48855 L .50263 .47921 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .56955 .49995 L .56923 .5111 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .5658 .48905 L .56955 .49995 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .55837 .47959 L .5658 .48905 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .54806 .47261 L .55837 .47959 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .536 .46887 L .54806 .47261 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .52352 .46879 L .536 .46887 L closepath p
1 g
F P
s
P
p
.002 w
.53246 .50102 m .51198 .47237 L .52352 .46879 L closepath p
1 g
F P
s
P
p
.002 w
.34346 .6678 m .36343 .64277 L .40965 .68446 L p
1 g
F P
s
P
p
.002 w
.40965 .68446 m .39431 .71351 L .34346 .6678 L p
1 g
F P
s
P
p
.002 w
.62394 .56835 m .59562 .5439 L .6043 .52383 L p
1 g
F P
s
P
p
.002 w
.56923 .5111 m .6043 .52383 L .59562 .5439 L p
1 g
F P
s
P
p
.002 w
.42538 .47341 m .46052 .47926 L .45613 .50066 L p
1 g
F P
s
P
p
.002 w
.45613 .50066 m .41908 .50486 L .42538 .47341 L p
1 g
F P
s
P
p
.002 w
.63458 .65639 m .61926 .62411 L .64915 .59407 L p
1 g
F P
s
P
p
.002 w
.62394 .56835 m .64915 .59407 L .61926 .62411 L p
1 g
F P
s
P
p
.002 w
.6043 .52383 m .56923 .5111 L .56955 .49995 L p
1 g
F P
s
P
p
.002 w
.47257 .46074 m .50263 .47921 L .4965 .48855 L p
1 g
F P
s
P
p
.002 w
.4965 .48855 m .46052 .47926 L .47257 .46074 L p
1 g
F P
s
P
p
.002 w
.35163 .52161 m .38395 .51189 L .39129 .55349 L p
1 g
F P
s
P
p
.002 w
.39129 .55349 m .36062 .57154 L .35163 .52161 L p
1 g
F P
s
P
p
.002 w
.64915 .59407 m .62394 .56835 L .63681 .53895 L p
1 g
F P
s
P
p
.002 w
.6043 .52383 m .63681 .53895 L .62394 .56835 L p
1 g
F P
s
P
p
.002 w
.56955 .49995 m .60503 .50181 L .6043 .52383 L p
1 g
F P
s
P
p
.002 w
.60503 .50181 m .56955 .49995 L .5658 .48905 L p
1 g
F P
s
P
p
.002 w
.49101 .44715 m .51198 .47237 L .50263 .47921 L p
1 g
F P
s
P
p
.002 w
.50263 .47921 m .47257 .46074 L .49101 .44715 L p
1 g
F P
s
P
p
.002 w
.39195 .47116 m .42538 .47341 L .41908 .50486 L p
1 g
F P
s
P
p
.002 w
.41908 .50486 m .38395 .51189 L .39195 .47116 L p
1 g
F P
s
P
p
.002 w
.63681 .53895 m .6043 .52383 L .60503 .50181 L p
1 g
F P
s
P
p
.002 w
.59197 .71352 m .59465 .74555 L .52663 .75446 L p
1 g
F P
s
P
p
.002 w
.59465 .74555 m .59197 .71352 L .64646 .68773 L p
1 g
F P
s
P
p
.002 w
.63458 .65639 m .64646 .68773 L .59197 .71352 L p
1 g
F P
s
P
p
.002 w
.38161 .74018 m .39431 .71351 L .45752 .74339 L p
1 g
F P
s
P
p
.002 w
.45752 .74339 m .4489 .77194 L .38161 .74018 L p
1 g
F P
s
P
p
.002 w
.4489 .77194 m .45752 .74339 L .52663 .75446 L p
1 g
F P
s
P
p
.002 w
.44299 .44612 m .47257 .46074 L .46052 .47926 L p
1 g
F P
s
P
p
.002 w
.46052 .47926 m .42538 .47341 L .44299 .44612 L p
1 g
F P
s
P
p
.002 w
.5658 .48905 m .59767 .48022 L .60503 .50181 L p
1 g
F P
s
P
p
.002 w
.59767 .48022 m .5658 .48905 L .55837 .47959 L p
1 g
F P
s
P
p
.002 w
.51387 .44002 m .52352 .46879 L .51198 .47237 L p
1 g
F P
s
P
p
.002 w
.51198 .47237 m .49101 .44715 L .51387 .44002 L p
1 g
F P
s
P
p
.002 w
.31032 .61077 m .3334 .59078 L .36343 .64277 L p
1 g
F P
s
P
p
.002 w
.36343 .64277 m .34346 .6678 L .31032 .61077 L p
1 g
F P
s
P
p
.002 w
.64646 .68773 m .63458 .65639 L .6706 .62043 L p
1 g
F P
s
P
p
.002 w
.64915 .59407 m .6706 .62043 L .63458 .65639 L p
1 g
F P
s
P
p
.002 w
.55837 .47959 m .58298 .46145 L .59767 .48022 L p
1 g
F P
s
P
p
.002 w
.58298 .46145 m .55837 .47959 L .54806 .47261 L p
1 g
F P
s
P
p
.002 w
.53863 .44016 m .536 .46887 L .52352 .46879 L p
1 g
F P
s
P
p
.002 w
.52352 .46879 m .51387 .44002 L .53863 .44016 L p
1 g
F P
s
P
p
.002 w
.32294 .5338 m .35163 .52161 L .36062 .57154 L p
1 g
F P
s
P
p
.002 w
.36062 .57154 m .3334 .59078 L .32294 .5338 L p
1 g
F P
s
P
p
.002 w
.52663 .75446 m .52246 .78376 L .4489 .77194 L p
1 g
F P
s
P
p
.002 w
.52246 .78376 m .52663 .75446 L .59465 .74555 L p
1 g
F P
s
P
p
.002 w
.32742 .69161 m .34346 .6678 L .39431 .71351 L p
1 g
F P
s
P
p
.002 w
.39431 .71351 m .38161 .74018 L .32742 .69161 L p
1 g
F P
s
P
p
.002 w
.54806 .47261 m .56255 .44757 L .58298 .46145 L p
1 g
F P
s
P
p
.002 w
.56255 .44757 m .54806 .47261 L .536 .46887 L p
1 g
F P
s
P
p
.002 w
.536 .46887 m .53863 .44016 L .56255 .44757 L p
1 g
F P
s
P
p
.002 w
.6706 .62043 m .64915 .59407 L .66595 .55609 L p
1 g
F P
s
P
p
.002 w
.63681 .53895 m .66595 .55609 L .64915 .59407 L p
1 g
F P
s
P
p
.002 w
.60503 .50181 m .638 .50658 L .63681 .53895 L p
1 g
F P
s
P
p
.002 w
.638 .50658 m .60503 .50181 L .59767 .48022 L p
1 g
F P
s
P
p
.002 w
.36106 .47262 m .39195 .47116 L .38395 .51189 L p
1 g
F P
s
P
p
.002 w
.38395 .51189 m .35163 .52161 L .36106 .47262 L p
1 g
F P
s
P
p
.002 w
.47008 .42604 m .49101 .44715 L .47257 .46074 L p
1 g
F P
s
P
p
.002 w
.47257 .46074 m .44299 .44612 L .47008 .42604 L p
1 g
F P
s
P
p
.002 w
.66595 .55609 m .63681 .53895 L .638 .50658 L p
1 g
F P
s
P
p
.002 w
.41462 .43574 m .44299 .44612 L .42538 .47341 L p
1 g
F P
s
P
p
.002 w
.42538 .47341 m .39195 .47116 L .41462 .43574 L p
1 g
F P
s
P
p
.002 w
.59465 .74555 m .59486 .77438 L .52246 .78376 L p
1 g
F P
s
P
p
.002 w
.59486 .77438 m .59465 .74555 L .65459 .71737 L p
1 g
F P
s
P
p
.002 w
.64646 .68773 m .65459 .71737 L .59465 .74555 L p
1 g
F P
s
P
p
.002 w
.59767 .48022 m .62727 .47478 L .638 .50658 L p
1 g
F P
s
P
p
.002 w
.62727 .47478 m .59767 .48022 L .58298 .46145 L p
1 g
F P
s
P
p
.002 w
.50374 .41546 m .51387 .44002 L .49101 .44715 L p
1 g
F P
s
P
p
.002 w
.49101 .44715 m .47008 .42604 L .50374 .41546 L p
1 g
F P
s
P
p
.002 w
.65459 .71737 m .64646 .68773 L .68774 .64681 L p
1 g
F P
s
P
p
.002 w
.6706 .62043 m .68774 .64681 L .64646 .68773 L p
1 g
F P
s
P
p
.002 w
.29202 .63102 m .31032 .61077 L .34346 .6678 L p
1 g
F P
s
P
p
.002 w
.34346 .6678 m .32742 .69161 L .29202 .63102 L p
1 g
F P
s
P
p
.002 w
.29864 .54821 m .32294 .5338 L .3334 .59078 L p
1 g
F P
s
P
p
.002 w
.3334 .59078 m .31032 .61077 L .29864 .54821 L p
1 g
F P
s
P
p
.002 w
.37189 .76376 m .38161 .74018 L .4489 .77194 L p
1 g
F P
s
P
p
.002 w
.4489 .77194 m .44153 .79658 L .37189 .76376 L p
1 g
F P
s
P
p
.002 w
.44153 .79658 m .4489 .77194 L .52246 .78376 L p
1 g
F P
s
P
p
.002 w
.68774 .64681 m .6706 .62043 L .69096 .57487 L p
1 g
F P
s
P
p
.002 w
.66595 .55609 m .69096 .57487 L .6706 .62043 L p
1 g
F P
s
P
p
.002 w
.58298 .46145 m .60568 .44707 L .62727 .47478 L p
1 g
F P
s
P
p
.002 w
.60568 .44707 m .58298 .46145 L .56255 .44757 L p
1 g
F P
s
P
p
.002 w
.54027 .41564 m .53863 .44016 L .51387 .44002 L p
1 g
F P
s
P
p
.002 w
.51387 .44002 m .50374 .41546 L .54027 .41564 L p
1 g
F P
s
P
p
.002 w
.52246 .78376 m .51763 .80885 L .44153 .79658 L p
1 g
F P
s
P
p
.002 w
.51763 .80885 m .52246 .78376 L .59486 .77438 L p
1 g
F P
s
P
p
.002 w
.638 .50658 m .66764 .51418 L .66595 .55609 L p
1 g
F P
s
P
p
.002 w
.66764 .51418 m .638 .50658 L .62727 .47478 L p
1 g
F P
s
P
p
.002 w
.33353 .47781 m .36106 .47262 L .35163 .52161 L p
1 g
F P
s
P
p
.002 w
.35163 .52161 m .32294 .5338 L .33353 .47781 L p
1 g
F P
s
P
p
.002 w
.31577 .71359 m .32742 .69161 L .38161 .74018 L p
1 g
F P
s
P
p
.002 w
.38161 .74018 m .37189 .76376 L .31577 .71359 L p
1 g
F P
s
P
p
.002 w
.69096 .57487 m .66595 .55609 L .66764 .51418 L p
1 g
F P
s
P
p
.002 w
.44969 .40962 m .47008 .42604 L .44299 .44612 L p
1 g
F P
s
P
p
.002 w
.44299 .44612 m .41462 .43574 L .44969 .40962 L p
1 g
F P
s
P
p
.002 w
.56255 .44757 m .57556 .42658 L .60568 .44707 L p
1 g
F P
s
P
p
.002 w
.57556 .42658 m .56255 .44757 L .53863 .44016 L p
1 g
F P
s
P
p
.002 w
.53863 .44016 m .54027 .41564 L .57556 .42658 L p
1 g
F P
s
P
p
.002 w
.38821 .42994 m .41462 .43574 L .39195 .47116 L p
1 g
F P
s
P
p
.002 w
.39195 .47116 m .36106 .47262 L .38821 .42994 L p
1 g
F P
s
P
p
.002 w
.62727 .47478 m .65383 .47292 L .66764 .51418 L p
1 g
F P
s
P
p
.002 w
.65383 .47292 m .62727 .47478 L .60568 .44707 L p
1 g
F P
s
P
p
.002 w
.65459 .71737 m .65869 .74453 L .59486 .77438 L p
1 g
F P
s
P
p
.002 w
.65869 .74453 m .65459 .71737 L .70006 .67254 L p
1 g
F P
s
P
p
.002 w
.68774 .64681 m .70006 .67254 L .65459 .71737 L p
1 g
F P
s
P
p
.002 w
.49338 .39582 m .50374 .41546 L .47008 .42604 L p
1 g
F P
s
P
p
.002 w
.47008 .42604 m .44969 .40962 L .49338 .39582 L p
1 g
F P
s
P
p
.002 w
.59486 .77438 m .59254 .79923 L .51763 .80885 L p
1 g
F P
s
P
p
.002 w
.59254 .79923 m .59486 .77438 L .65869 .74453 L p
1 g
F P
s
P
p
.002 w
.27944 .5645 m .29864 .54821 L .31032 .61077 L p
1 g
F P
s
P
p
.002 w
.31032 .61077 m .29202 .63102 L .27944 .5645 L p
1 g
F P
s
P
p
.002 w
.27906 .65101 m .29202 .63102 L .32742 .69161 L p
1 g
F P
s
P
p
.002 w
.32742 .69161 m .31577 .71359 L .27906 .65101 L p
1 g
F P
s
P
p
.002 w
.70006 .67254 m .68774 .64681 L .71115 .59484 L p
1 g
F P
s
P
p
.002 w
.69096 .57487 m .71115 .59484 L .68774 .64681 L p
1 g
F P
s
P
p
.002 w
.31012 .48666 m .33353 .47781 L .32294 .5338 L p
1 g
F P
s
P
p
.002 w
.32294 .5338 m .29864 .54821 L .31012 .48666 L p
1 g
F P
s
P
p
.002 w
.36547 .7836 m .37189 .76376 L .44153 .79658 L p
1 g
F P
s
P
p
.002 w
.44153 .79658 m .43563 .81664 L .36547 .7836 L p
1 g
F P
s
P
p
.002 w
.43563 .81664 m .44153 .79658 L .51763 .80885 L p
1 g
F P
s
P
p
.002 w
.66764 .51418 m .69315 .52448 L .69096 .57487 L p
1 g
F P
s
P
p
.002 w
.69315 .52448 m .66764 .51418 L .65383 .47292 L p
1 g
F P
s
P
p
.002 w
.71115 .59484 m .69096 .57487 L .69315 .52448 L p
1 g
F P
s
P
p
.002 w
.43038 .39839 m .44969 .40962 L .41462 .43574 L p
1 g
F P
s
P
p
.002 w
.41462 .43574 m .38821 .42994 L .43038 .39839 L p
1 g
F P
s
P
p
.002 w
.60568 .44707 m .62585 .43691 L .65383 .47292 L p
1 g
F P
s
P
p
.002 w
.62585 .43691 m .60568 .44707 L .57556 .42658 L p
1 g
F P
s
P
p
.002 w
.54085 .39602 m .54027 .41564 L .50374 .41546 L p
1 g
F P
s
P
p
.002 w
.50374 .41546 m .49338 .39582 L .54085 .39602 L p
1 g
F P
s
P
p
.002 w
.36445 .42894 m .38821 .42994 L .36106 .47262 L p
1 g
F P
s
P
p
.002 w
.36106 .47262 m .33353 .47781 L .36445 .42894 L p
1 g
F P
s
P
p
.002 w
.51763 .80885 m .51227 .82901 L .43563 .81664 L p
1 g
F P
s
P
p
.002 w
.51227 .82901 m .51763 .80885 L .59254 .79923 L p
1 g
F P
s
P
p
.002 w
.30891 .73315 m .31577 .71359 L .37189 .76376 L p
1 g
F P
s
P
p
.002 w
.37189 .76376 m .36547 .7836 L .30891 .73315 L p
1 g
F P
s
P
p
.002 w
.57556 .42658 m .58674 .41025 L .62585 .43691 L p
1 g
F P
s
P
p
.002 w
.58674 .41025 m .57556 .42658 L .54027 .41564 L p
1 g
F P
s
P
p
.002 w
.54027 .41564 m .54085 .39602 L .58674 .41025 L p
1 g
F P
s
P
p
.002 w
.65869 .74453 m .6586 .76849 L .59254 .79923 L p
1 g
F P
s
P
p
.002 w
.6586 .76849 m .65869 .74453 L .70717 .69697 L p
1 g
F P
s
P
p
.002 w
.70006 .67254 m .70717 .69697 L .65869 .74453 L p
1 g
F P
s
P
p
.002 w
.65383 .47292 m .67662 .47476 L .69315 .52448 L p
1 g
F P
s
P
p
.002 w
.67662 .47476 m .65383 .47292 L .62585 .43691 L p
1 g
F P
s
P
p
.002 w
.48304 .3817 m .49338 .39582 L .44969 .40962 L p
1 g
F P
s
P
p
.002 w
.44969 .40962 m .43038 .39839 L .48304 .3817 L p
1 g
F P
s
P
p
.002 w
.26594 .5823 m .27944 .5645 L .29202 .63102 L p
1 g
F P
s
P
p
.002 w
.29202 .63102 m .27906 .65101 L .26594 .5823 L p
1 g
F P
s
P
p
.002 w
.59254 .79923 m .58771 .81941 L .51227 .82901 L p
1 g
F P
s
P
p
.002 w
.58771 .81941 m .59254 .79923 L .6586 .76849 L p
1 g
F P
s
P
p
.002 w
.70717 .69697 m .70006 .67254 L .72594 .61551 L p
1 g
F P
s
P
p
.002 w
.71115 .59484 m .72594 .61551 L .70006 .67254 L p
1 g
F P
s
P
p
.002 w
.27189 .67023 m .27906 .65101 L .31577 .71359 L p
1 g
F P
s
P
p
.002 w
.31577 .71359 m .30891 .73315 L .27189 .67023 L p
1 g
F P
s
P
p
.002 w
.29152 .49902 m .31012 .48666 L .29864 .54821 L p
1 g
F P
s
P
p
.002 w
.29864 .54821 m .27944 .5645 L .29152 .49902 L p
1 g
F P
s
P
p
.002 w
.72594 .61551 m .71115 .59484 L .7138 .53725 L p
1 g
F P
s
P
p
.002 w
.69315 .52448 m .7138 .53725 L .71115 .59484 L p
1 g
F P
s
P
p
.002 w
.7138 .53725 m .69315 .52448 L .67662 .47476 L p
1 g
F P
s
P
p
.002 w
.41266 .39277 m .43038 .39839 L .38821 .42994 L p
1 g
F P
s
P
p
.002 w
.38821 .42994 m .36445 .42894 L .41266 .39277 L p
1 g
F P
s
P
p
.002 w
.34402 .43288 m .36445 .42894 L .33353 .47781 L p
1 g
F P
s
P
p
.002 w
.33353 .47781 m .31012 .48666 L .34402 .43288 L p
1 g
F P
s
P
p
.002 w
.36257 .79912 m .36547 .7836 L .43563 .81664 L p
1 g
F P
s
P
p
.002 w
.43563 .81664 m .43136 .83149 L .36257 .79912 L p
1 g
F P
s
P
p
.002 w
.43136 .83149 m .43563 .81664 L .51227 .82901 L p
1 g
F P
s
P
p
.002 w
.62585 .43691 m .64294 .4313 L .67662 .47476 L p
1 g
F P
s
P
p
.002 w
.64294 .4313 m .62585 .43691 L .58674 .41025 L p
1 g
F P
s
P
p
.002 w
.54034 .38191 m .54085 .39602 L .49338 .39582 L p
1 g
F P
s
P
p
.002 w
.49338 .39582 m .48304 .3817 L .54034 .38191 L p
1 g
F P
s
P
p
.002 w
.51227 .82901 m .5065 .84364 L .43136 .83149 L p
1 g
F P
s
P
p
.002 w
.5065 .84364 m .51227 .82901 L .58771 .81941 L p
1 g
F P
s
P
p
.002 w
.30711 .74973 m .30891 .73315 L .36547 .7836 L p
1 g
F P
s
P
p
.002 w
.36547 .7836 m .36257 .79912 L .30711 .74973 L p
1 g
F P
s
P
p
.002 w
.58674 .41025 m .59575 .3991 L .64294 .4313 L p
1 g
F P
s
P
p
.002 w
.59575 .3991 m .58674 .41025 L .54085 .39602 L p
1 g
F P
s
P
p
.002 w
.54085 .39602 m .54034 .38191 L .59575 .3991 L p
1 g
F P
s
P
p
.002 w
.6586 .76849 m .65423 .78856 L .58771 .81941 L p
1 g
F P
s
P
p
.002 w
.65423 .78856 m .6586 .76849 L .70879 .71943 L p
1 g
F P
s
P
p
.002 w
.70717 .69697 m .70879 .71943 L .6586 .76849 L p
1 g
F P
s
P
p
.002 w
.67662 .47476 m .69498 .48032 L .7138 .53725 L p
1 g
F P
s
P
p
.002 w
.69498 .48032 m .67662 .47476 L .64294 .4313 L p
1 g
F P
s
P
p
.002 w
.70879 .71943 m .70717 .69697 L .73482 .63637 L p
1 g
F P
s
P
p
.002 w
.72594 .61551 m .73482 .63637 L .70717 .69697 L p
1 g
F P
s
P
p
.002 w
.25861 .60116 m .26594 .5823 L .27906 .65101 L p
1 g
F P
s
P
p
.002 w
.27906 .65101 m .27189 .67023 L .25861 .60116 L p
1 g
F P
s
P
p
.002 w
.473 .3736 m .48304 .3817 L .43038 .39839 L p
1 g
F P
s
P
p
.002 w
.43038 .39839 m .41266 .39277 L .473 .3736 L p
1 g
F P
s
P
p
.002 w
.58771 .81941 m .58043 .83428 L .5065 .84364 L p
1 g
F P
s
P
p
.002 w
.58043 .83428 m .58771 .81941 L .65423 .78856 L p
1 g
F P
s
P
p
.002 w
.27834 .51464 m .29152 .49902 L .27944 .5645 L p
1 g
F P
s
P
p
.002 w
.27944 .5645 m .26594 .5823 L .27834 .51464 L p
1 g
F P
s
P
p
.002 w
.73482 .63637 m .72594 .61551 L .72897 .55222 L p
1 g
F P
s
P
p
.002 w
.7138 .53725 m .72897 .55222 L .72594 .61551 L p
1 g
F P
s
P
p
.002 w
.27081 .68815 m .27189 .67023 L .30891 .73315 L p
1 g
F P
s
P
p
.002 w
.30891 .73315 m .30711 .74973 L .27081 .68815 L p
1 g
F P
s
P
p
.002 w
.72897 .55222 m .7138 .53725 L .69498 .48032 L p
1 g
F P
s
P
p
.002 w
.32753 .44176 m .34402 .43288 L .31012 .48666 L p
1 g
F P
s
P
p
.002 w
.31012 .48666 m .29152 .49902 L .32753 .44176 L p
1 g
F P
s
P
p
.002 w
.39704 .39302 m .41266 .39277 L .36445 .42894 L p
1 g
F P
s
P
p
.002 w
.36445 .42894 m .34402 .43288 L .39704 .39302 L p
1 g
F P
s
P
p
.002 w
.36336 .80981 m .36257 .79912 L .43136 .83149 L p
1 g
F P
s
P
p
.002 w
.43136 .83149 m .42889 .84062 L .36336 .80981 L p
1 g
F P
s
P
p
.002 w
.42889 .84062 m .43136 .83149 L .5065 .84364 L p
1 g
F P
s
P
p
.002 w
.64294 .4313 m .65643 .43049 L .69498 .48032 L p
1 g
F P
s
P
p
.002 w
.65643 .43049 m .64294 .4313 L .59575 .3991 L p
1 g
F P
s
P
p
.002 w
.53872 .37382 m .54034 .38191 L .48304 .3817 L p
1 g
F P
s
P
p
.002 w
.48304 .3817 m .473 .3736 L .53872 .37382 L p
1 g
F P
s
P
p
.002 w
.5065 .84364 m .50046 .85221 L .42889 .84062 L p
1 g
F P
s
P
p
.002 w
.50046 .85221 m .5065 .84364 L .58043 .83428 L p
1 g
F P
s
P
p
.002 w
.31054 .76281 m .30711 .74973 L .36257 .79912 L p
1 g
F P
s
P
p
.002 w
.36257 .79912 m .36336 .80981 L .31054 .76281 L p
1 g
F P
s
P
p
.002 w
.59575 .3991 m .6023 .39355 L .65643 .43049 L p
1 g
F P
s
P
p
.002 w
.6023 .39355 m .59575 .3991 L .54034 .38191 L p
1 g
F P
s
P
p
.002 w
.54034 .38191 m .53872 .37382 L .6023 .39355 L p
1 g
F P
s
P
p
.002 w
.65423 .78856 m .64559 .80413 L .58043 .83428 L p
1 g
F P
s
P
p
.002 w
.64559 .80413 m .65423 .78856 L .70476 .73929 L p
1 g
F P
s
P
p
.002 w
.70879 .71943 m .70476 .73929 L .65423 .78856 L p
1 g
F P
s
P
p
.002 w
.70476 .73929 m .70879 .71943 L .73744 .65687 L p
1 g
F P
s
P
p
.002 w
.73482 .63637 m .73744 .65687 L .70879 .71943 L p
1 g
F P
s
P
p
.002 w
.69498 .48032 m .70831 .48955 L .72897 .55222 L p
1 g
F P
s
P
p
.002 w
.70831 .48955 m .69498 .48032 L .65643 .43049 L p
1 g
F P
s
P
p
.002 w
.25779 .62059 m .25861 .60116 L .27189 .67023 L p
1 g
F P
s
P
p
.002 w
.27189 .67023 m .27081 .68815 L .25779 .62059 L p
1 g
F P
s
P
p
.002 w
.46353 .37187 m .473 .3736 L .41266 .39277 L p
1 g
F P
s
P
p
.002 w
.41266 .39277 m .39704 .39302 L .46353 .37187 L p
1 g
F P
s
P
p
.002 w
.27104 .53315 m .27834 .51464 L .26594 .5823 L p
1 g
F P
s
P
p
.002 w
.26594 .5823 m .25861 .60116 L .27104 .53315 L p
1 g
F P
s
P
p
.002 w
.73744 .65687 m .73482 .63637 L .73812 .56903 L p
1 g
F P
s
P
p
.002 w
.72897 .55222 m .73812 .56903 L .73482 .63637 L p
1 g
F P
s
P
p
.002 w
.58043 .83428 m .57085 .84333 L .50046 .85221 L p
1 g
F P
s
P
p
.002 w
.57085 .84333 m .58043 .83428 L .64559 .80413 L p
1 g
F P
s
P
p
.002 w
.73812 .56903 m .72897 .55222 L .70831 .48955 L p
1 g
F P
s
P
p
.002 w
.31553 .45544 m .32753 .44176 L .29152 .49902 L p
1 g
F P
s
P
p
.002 w
.29152 .49902 m .27834 .51464 L .31553 .45544 L p
1 g
F P
s
P
p
.002 w
.276 .70426 m .27081 .68815 L .30711 .74973 L p
1 g
F P
s
P
p
.002 w
.30711 .74973 m .31054 .76281 L .276 .70426 L p
1 g
F P
s
P
p
.002 w
.384 .39929 m .39704 .39302 L .34402 .43288 L p
1 g
F P
s
P
p
.002 w
.34402 .43288 m .32753 .44176 L .384 .39929 L p
1 g
F P
s
P
p
.002 w
.65643 .43049 m .66585 .43463 L .70831 .48955 L p
1 g
F P
s
P
p
.002 w
.66585 .43463 m .65643 .43049 L .6023 .39355 L p
1 g
F P
s
P
p
.002 w
.3679 .81525 m .36336 .80981 L .42889 .84062 L p
1 g
F P
s
P
p
.002 w
.42889 .84062 m .42831 .84365 L .3679 .81525 L p
1 g
F P
s
P
p
.002 w
.42831 .84365 m .42889 .84062 L .50046 .85221 L p
1 g
F P
s
P
p
.002 w
.53602 .37212 m .53872 .37382 L .473 .3736 L p
1 g
F P
s
P
p
.002 w
.473 .3736 m .46353 .37187 L .53602 .37212 L p
1 g
F P
s
P
p
.002 w
.50046 .85221 m .4943 .85434 L .42831 .84365 L p
1 g
F P
s
P
p
.002 w
.4943 .85434 m .50046 .85221 L .57085 .84333 L p
1 g
F P
s
P
p
.002 w
.31924 .77195 m .31054 .76281 L .36336 .80981 L p
1 g
F P
s
P
p
.002 w
.36336 .80981 m .3679 .81525 L .31924 .77195 L p
1 g
F P
s
P
p
.002 w
.6023 .39355 m .60617 .39388 L .66585 .43463 L p
1 g
F P
s
P
p
.002 w
.60617 .39388 m .6023 .39355 L .53872 .37382 L p
1 g
F P
s
P
p
.002 w
.53872 .37382 m .53602 .37212 L .60617 .39388 L p
1 g
F P
s
P
p
.002 w
.70476 .73929 m .69505 .75596 L .64559 .80413 L p
1 g
F P
s
P
p
.002 w
.73744 .65687 m .73358 .67643 L .70476 .73929 L p
1 g
F P
s
P
p
.002 w
.69505 .75596 m .70476 .73929 L .73358 .67643 L p
1 g
F P
s
P
p
.002 w
.64559 .80413 m .63283 .81467 L .57085 .84333 L p
1 g
F P
s
P
p
.002 w
.63283 .81467 m .64559 .80413 L .69505 .75596 L p
1 g
F P
s
P
p
.002 w
.70831 .48955 m .71614 .50228 L .73812 .56903 L p
1 g
F P
s
P
p
.002 w
.71614 .50228 m .70831 .48955 L .66585 .43463 L p
1 g
F P
s
P
p
.002 w
.26365 .64008 m .25779 .62059 L .27081 .68815 L p
1 g
F P
s
P
p
.002 w
.27081 .68815 m .276 .70426 L .26365 .64008 L p
1 g
F P
s
P
p
.002 w
.26996 .55412 m .27104 .53315 L .25861 .60116 L p
1 g
F P
s
P
p
.002 w
.25861 .60116 m .25779 .62059 L .26996 .55412 L p
1 g
F P
s
P
p
.002 w
.73812 .56903 m .74088 .58727 L .73744 .65687 L p
1 g
F P
s
P
p
.002 w
.73358 .67643 m .73744 .65687 L .74088 .58727 L p
1 g
F P
s
P
p
.002 w
.4549 .37674 m .46353 .37187 L .39704 .39302 L p
1 g
F P
s
P
p
.002 w
.39704 .39302 m .384 .39929 L .4549 .37674 L p
1 g
F P
s
P
p
.002 w
.74088 .58727 m .73812 .56903 L .71614 .50228 L p
1 g
F P
s
P
p
.002 w
.30845 .47366 m .31553 .45544 L .27834 .51464 L p
1 g
F P
s
P
p
.002 w
.27834 .51464 m .27104 .53315 L .30845 .47366 L p
1 g
F P
s
P
p
.002 w
.57085 .84333 m .55916 .84616 L .4943 .85434 L p
1 g
F P
s
P
p
.002 w
.55916 .84616 m .57085 .84333 L .63283 .81467 L p
1 g
F P
s
P
p
.002 w
.37395 .41153 m .384 .39929 L .32753 .44176 L p
1 g
F P
s
P
p
.002 w
.32753 .44176 m .31553 .45544 L .37395 .41153 L p
1 g
F P
s
P
p
.002 w
.28747 .71806 m .276 .70426 L .31054 .76281 L p
1 g
F P
s
P
p
.002 w
.31054 .76281 m .31924 .77195 L .28747 .71806 L p
1 g
F P
s
P
p
.002 w
.66585 .43463 m .67087 .44373 L .71614 .50228 L p
1 g
F P
s
P
p
.002 w
.67087 .44373 m .66585 .43463 L .60617 .39388 L p
1 g
F P
s
P
p
.002 w
.53227 .37702 m .53602 .37212 L .46353 .37187 L p
1 g
F P
s
P
p
.002 w
.46353 .37187 m .4549 .37674 L .53227 .37702 L p
1 g
F P
s
P
p
.002 w
.37617 .81516 m .3679 .81525 L .42831 .84365 L p
1 g
F P
s
P
p
.002 w
.42831 .84365 m .42971 .84034 L .37617 .81516 L p
1 g
F P
s
P
p
.002 w
.42971 .84034 m .42831 .84365 L .4943 .85434 L p
1 g
F P
s
P
p
.002 w
.4943 .85434 m .4882 .8498 L .42971 .84034 L p
1 g
F P
s
P
p
.002 w
.4882 .8498 m .4943 .85434 L .55916 .84616 L p
1 g
F P
s
P
p
.002 w
.33309 .7768 m .31924 .77195 L .3679 .81525 L p
1 g
F P
s
P
p
.002 w
.3679 .81525 m .37617 .81516 L .33309 .7768 L p
1 g
F P
s
P
p
.002 w
.69505 .75596 m .67981 .7689 L .63283 .81467 L p
1 g
F P
s
P
p
.002 w
.67981 .7689 m .69505 .75596 L .72321 .6945 L p
1 g
F P
s
P
p
.002 w
.73358 .67643 m .72321 .6945 L .69505 .75596 L p
1 g
F P
s
P
p
.002 w
.63283 .81467 m .6162 .81977 L .55916 .84616 L p
1 g
F P
s
P
p
.002 w
.6162 .81977 m .63283 .81467 L .67981 .7689 L p
1 g
F P
s
P
p
.002 w
.60617 .39388 m .60716 .40025 L .67087 .44373 L p
1 g
F P
s
P
p
.002 w
.60716 .40025 m .60617 .39388 L .53602 .37212 L p
1 g
F P
s
P
p
.002 w
.53602 .37212 m .53227 .37702 L .60716 .40025 L p
1 g
F P
s
P
p
.002 w
.27527 .57699 m .26996 .55412 L .25779 .62059 L p
1 g
F P
s
P
p
.002 w
.25779 .62059 m .26365 .64008 L .27527 .57699 L p
1 g
F P
s
P
p
.002 w
.72321 .6945 m .73358 .67643 L .73702 .60647 L p
1 g
F P
s
P
p
.002 w
.74088 .58727 m .73702 .60647 L .73358 .67643 L p
1 g
F P
s
P
p
.002 w
.27617 .65906 m .26365 .64008 L .276 .70426 L p
1 g
F P
s
P
p
.002 w
.276 .70426 m .28747 .71806 L .27617 .65906 L p
1 g
F P
s
P
p
.002 w
.71614 .50228 m .71813 .51824 L .74088 .58727 L p
1 g
F P
s
P
p
.002 w
.71813 .51824 m .71614 .50228 L .67087 .44373 L p
1 g
F P
s
P
p
.002 w
.73702 .60647 m .74088 .58727 L .71813 .51824 L p
1 g
F P
s
P
p
.002 w
.44739 .38823 m .4549 .37674 L .384 .39929 L p
1 g
F P
s
P
p
.002 w
.384 .39929 m .37395 .41153 L .44739 .38823 L p
1 g
F P
s
P
p
.002 w
.30661 .496 m .30845 .47366 L .27104 .53315 L p
1 g
F P
s
P
p
.002 w
.27104 .53315 m .26996 .55412 L .30661 .496 L p
1 g
F P
s
P
p
.002 w
.36727 .42955 m .37395 .41153 L .31553 .45544 L p
1 g
F P
s
P
p
.002 w
.31553 .45544 m .30845 .47366 L .36727 .42955 L p
1 g
F P
s
P
p
.002 w
.55916 .84616 m .54564 .84254 L .4882 .8498 L p
1 g
F P
s
P
p
.002 w
.54564 .84254 m .55916 .84616 L .6162 .81977 L p
1 g
F P
s
P
p
.002 w
.30502 .72912 m .28747 .71806 L .31924 .77195 L p
1 g
F P
s
P
p
.002 w
.31924 .77195 m .33309 .7768 L .30502 .72912 L p
1 g
F P
s
P
p
.002 w
.67087 .44373 m .67121 .45765 L .71813 .51824 L p
1 g
F P
s
P
p
.002 w
.67121 .45765 m .67087 .44373 L .60716 .40025 L p
1 g
F P
s
P
p
.002 w
.52756 .38854 m .53227 .37702 L .4549 .37674 L p
1 g
F P
s
P
p
.002 w
.4549 .37674 m .44739 .38823 L .52756 .38854 L p
1 g
F P
s
P
p
.002 w
.38803 .80941 m .37617 .81516 L .42971 .84034 L p
1 g
F P
s
P
p
.002 w
.42971 .84034 m .43309 .83061 L .38803 .80941 L p
1 g
F P
s
P
p
.002 w
.43309 .83061 m .42971 .84034 L .4882 .8498 L p
1 g
F P
s
P
p
.002 w
.67981 .7689 m .65935 .77766 L .6162 .81977 L p
1 g
F P
s
P
p
.002 w
.65935 .77766 m .67981 .7689 L .70649 .71053 L p
1 g
F P
s
P
p
.002 w
.72321 .6945 m .70649 .71053 L .67981 .7689 L p
1 g
F P
s
P
p
.002 w
.4882 .8498 m .48232 .83857 L .43309 .83061 L p
1 g
F P
s
P
p
.002 w
.48232 .83857 m .4882 .8498 L .54564 .84254 L p
1 g
F P
s
P
p
.002 w
.6162 .81977 m .59608 .81917 L .54564 .84254 L p
1 g
F P
s
P
p
.002 w
.59608 .81917 m .6162 .81977 L .65935 .77766 L p
1 g
F P
s
P
p
.002 w
.35182 .77712 m .33309 .7768 L .37617 .81516 L p
1 g
F P
s
P
p
.002 w
.37617 .81516 m .38803 .80941 L .35182 .77712 L p
1 g
F P
s
P
p
.002 w
.70649 .71053 m .72321 .6945 L .7265 .62611 L p
1 g
F P
s
P
p
.002 w
.73702 .60647 m .7265 .62611 L .72321 .6945 L p
1 g
F P
s
P
p
.002 w
.28696 .60115 m .27527 .57699 L .26365 .64008 L p
1 g
F P
s
P
p
.002 w
.26365 .64008 m .27617 .65906 L .28696 .60115 L p
1 g
F P
s
P
p
.002 w
.29514 .67699 m .27617 .65906 L .28747 .71806 L p
1 g
F P
s
P
p
.002 w
.28747 .71806 m .30502 .72912 L .29514 .67699 L p
1 g
F P
s
P
p
.002 w
.71813 .51824 m .71406 .53706 L .73702 .60647 L p
1 g
F P
s
P
p
.002 w
.71406 .53706 m .71813 .51824 L .67121 .45765 L p
1 g
F P
s
P
p
.002 w
.31016 .5219 m .30661 .496 L .26996 .55412 L p
1 g
F P
s
P
p
.002 w
.26996 .55412 m .27527 .57699 L .31016 .5219 L p
1 g
F P
s
P
p
.002 w
.60716 .40025 m .60518 .41262 L .67121 .45765 L p
1 g
F P
s
P
p
.002 w
.60518 .41262 m .60716 .40025 L .53227 .37702 L p
1 g
F P
s
P
p
.002 w
.7265 .62611 m .73702 .60647 L .71406 .53706 L p
1 g
F P
s
P
p
.002 w
.53227 .37702 m .52756 .38854 L .60518 .41262 L p
1 g
F P
s
P
p
.002 w
.44123 .40616 m .44739 .38823 L .37395 .41153 L p
1 g
F P
s
P
p
.002 w
.37395 .41153 m .36727 .42955 L .44123 .40616 L p
1 g
F P
s
P
p
.002 w
.36421 .45294 m .36727 .42955 L .30845 .47366 L p
1 g
F P
s
P
p
.002 w
.30845 .47366 m .30661 .496 L .36421 .45294 L p
1 g
F P
s
P
p
.002 w
.54564 .84254 m .53063 .83243 L .48232 .83857 L p
1 g
F P
s
P
p
.002 w
.53063 .83243 m .54564 .84254 L .59608 .81917 L p
1 g
F P
s
P
p
.002 w
.3283 .73704 m .30502 .72912 L .33309 .7768 L p
1 g
F P
s
P
p
.002 w
.33309 .7768 m .35182 .77712 L .3283 .73704 L p
1 g
F P
s
P
p
.002 w
.67121 .45765 m .66677 .4761 L .71406 .53706 L p
1 g
F P
s
P
p
.002 w
.66677 .4761 m .67121 .45765 L .60518 .41262 L p
1 g
F P
s
P
p
.002 w
.65935 .77766 m .63414 .78191 L .59608 .81917 L p
1 g
F P
s
P
p
.002 w
.63414 .78191 m .65935 .77766 L .68375 .72401 L p
1 g
F P
s
P
p
.002 w
.70649 .71053 m .68375 .72401 L .65935 .77766 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.522 .40653 m .52756 .38854 L .44739 .38823 L p
1 g
F P
s
P
p
.002 w
.44739 .38823 m .44123 .40616 L .522 .40653 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.68375 .72401 m .70649 .71053 L .70948 .64561 L p
1 g
F P
s
P
p
.002 w
.7265 .62611 m .70948 .64561 L .70649 .71053 L p
1 g
F P
s
P
p
.002 w
.40322 .79802 m .38803 .80941 L .43309 .83061 L p
1 g
F P
s
P
p
.002 w
.43309 .83061 m .4384 .81458 L .40322 .79802 L p
1 g
F P
s
P
p
.002 w
.43309 .83061 m .48232 .83857 L p
.45111 .82152 L 1 g
F P
s
P
p
.48758 .82869 m .47596 .82886 L .47966 .82996 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51255 .83083 L p
1 g
F P
s
P
p
.002 w
.48232 .83857 m .51378 .83457 L p
.5 .83271 L 1 g
F P
s
P
p
.53597 .82325 m .51255 .83083 L .524 .82912 L 1 g
F
P
p
.002 w
.51255 .83083 m .51242 .82869 L p
.50308 .8309 L 1 g
F P
s
P
p
.002 w
.48744 .83101 m .48758 .82869 L p
.47966 .82996 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.45111 .82152 m .45121 .82152 L .4384 .81458 L 1 g
F
P
p
.45121 .82152 m .45542 .8214 L .44576 .81753 L 1 g
F
P
p
.45121 .82152 m .44576 .81753 L .4384 .81458 L 1 g
F
P
p
.002 w
.40322 .79802 m .4384 .81458 L p
.43382 .80561 L 1 g
F P
s
P
p
.002 w
.41662 .78559 m .40322 .79802 L p
.43145 .80502 L 1 g
F P
s
P
p
.43382 .80561 m .42966 .80077 L .43145 .80502 L 1 g
F
P
p
.42966 .80077 m .41662 .78559 L .43145 .80502 L 1 g
F
P
p
.002 w
.42966 .80077 m .43042 .79874 L p
.42658 .79343 L 1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42966 .80077 L p
1 g
F P
s
P
p
.44427 .81291 m .42966 .80077 L .43606 .80822 L 1 g
F
P
p
.44427 .81291 m .43606 .80822 L .4375 .8099 L 1 g
F
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .4229 .78468 L p
1 g
F P
s
P
p
.43042 .79874 m .4229 .78468 L .42658 .79343 L 1 g
F
P
p
.002 w
.42136 .7812 m .41662 .78559 L p
.42252 .79246 L 1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.42136 .7812 m .42336 .77908 L p
.42406 .77351 L 1 g
F P
s
P
p
.002 w
.424 .78222 m .42579 .76511 L .42488 .767 L p
1 g
F P
s
P
p
.002 w
.40201 .76386 m .42136 .7812 L p
.42406 .77351 L 1 g
F P
s
P
p
.002 w
.42664 .75293 m .40201 .76386 L p
.42148 .77238 L 1 g
F P
s
P
p
.42406 .77351 m .42488 .767 L .42148 .77238 L 1 g
F
P
p
.42488 .767 m .42664 .75293 L .42148 .77238 L 1 g
F
P
p
.002 w
.42488 .767 m .42372 .76938 L p
.42385 .7752 L 1 g
F P
s
P
p
.424 .78222 m .42488 .767 L .42385 .7752 L 1 g
F
P
p
.002 w
.42488 .767 m .42579 .76511 L p
.43008 .75876 L 1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.43213 .75049 m .42664 .75293 L p
.42488 .767 L 1 g
F P
s
P
p
.42406 .77351 m .42818 .76177 L .42488 .767 L 1 g
F
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43465 .7515 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43415 .75231 m .44198 .75934 L p
.43742 .74937 L 1 g
F P
s
P
p
.002 w
.43465 .7515 m .43569 .74928 L p
.44395 .74436 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45205 .73814 L p
1 g
F P
s
P
p
.43569 .74928 m .45205 .73814 L .45187 .73828 L 1 g
F
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.44198 .75934 m .4543 .76516 L .46415 .73408 L p
1 g
F P
s
P
p
.002 w
.46777 .76732 m .48095 .7656 L .46487 .73382 L p
1 g
F P
s
P
p
.002 w
.49243 .76017 m .50096 .7516 L .46551 .73357 L p
1 g
F P
s
P
p
.002 w
.50562 .74081 m .50588 .72895 L .46753 .73274 L p
1 g
F P
s
P
p
.002 w
.46607 .73334 m .50562 .74081 L p
.46753 .73274 L 1 g
F P
s
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47459 .72978 L p
1 g
F P
s
P
p
.45268 .73647 m .47459 .72978 L .46906 .7321 L 1 g
F
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54803 .73835 L p
1 g
F P
s
P
p
.52506 .72815 m .54803 .73835 L .5473 .73812 L 1 g
F
P
p
.002 w
.54672 .73794 m .54653 .74488 L p
.55134 .74085 L 1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56505 .75086 L p
1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55675 .74495 m .54653 .74488 L p
.56584 .75212 L 1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57681 .78404 L p
1 g
F P
s
P
p
.002 w
.60483 .78141 m .57949 .77729 L p
.5772 .79064 L 1 g
F P
s
P
p
.002 w
.57949 .77729 m .57639 .77679 L p
.57681 .78404 L 1 g
F P
s
P
p
.57949 .77729 m .57681 .78404 L .5772 .79064 L 1 g
F
P
p
.002 w
.57681 .78404 m .576 .78222 L p
.57432 .79032 L 1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57026 .80056 L p
1 g
F P
s
P
p
.576 .78222 m .57026 .80056 L .57432 .79032 L 1 g
F
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57222 .77611 m .54751 .80056 L p
.57374 .7918 L 1 g
F P
s
P
p
.5772 .79064 m .57581 .78658 L .57374 .7918 L 1 g
F
P
p
.57581 .78658 m .57222 .77611 L .57374 .7918 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.57298 .81274 m .60483 .78141 L p
.57885 .79009 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55629 .81496 L p
1 g
F P
s
P
p
.002 w
.54267 .82683 m .57298 .81274 L p
.559 .81351 L 1 g
F P
s
P
p
.559 .81351 m .55788 .81357 L .55629 .81496 L 1 g
F
P
p
.559 .81351 m .55629 .81496 L .54267 .82683 L 1 g
F
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.53063 .83243 m .54267 .82683 L p
.53806 .82505 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .4637 .82524 L p
1 g
F P
s
P
p
.48758 .82869 m .4637 .82524 L .47596 .82886 L 1 g
F
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48744 .83101 L p
1 g
F P
s
P
p
.5089 .83138 m .50737 .83087 L .49958 .83092 L 1 g
F
P
p
.5 .83271 m .48744 .83101 L .48475 .83499 L 1 g
F
P
p
.5 .83271 m .48475 .83499 L .48232 .83857 L 1 g
F
P
p
.51242 .82869 m .48744 .83101 L .50308 .8309 L 1 g
F
P
p
.002 w
.51378 .83457 m .53063 .83243 L p
.5089 .83138 L 1 g
F P
s
P
p
.5089 .83138 m .47966 .82996 L .5 .83271 L 1 g
F
P
p
.5089 .83138 m .5 .83271 L .51378 .83457 L 1 g
F
P
p
.53063 .83243 m .51887 .82989 L .5089 .83138 L 1 g
F
P
p
.53806 .82505 m .53637 .8256 L .53063 .83243 L 1 g
F
P
p
.002 w
.52696 .82868 m .52821 .82996 L p
.53637 .8256 L 1 g
F P
s
P
p
.002 w
.52821 .82996 m .53063 .83243 L p
.53637 .8256 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53637 .8256 L p
1 g
F P
s
P
p
.55573 .81291 m .53637 .8256 L .54851 .81911 L 1 g
F
P
p
.002 w
.53637 .8256 m .53597 .82325 L p
.524 .82912 L 1 g
F P
s
P
p
.524 .82912 m .52696 .82868 L .53637 .8256 L 1 g
F
P
p
.002 w
.51453 .81597 m .52696 .82868 L p
.53806 .82505 L 1 g
F P
s
P
p
.002 w
.55629 .81496 m .55573 .81291 L p
.54851 .81911 L 1 g
F P
s
P
p
.56958 .79874 m .55629 .81496 L .56123 .81066 L 1 g
F
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.55788 .81357 m .51453 .81597 L .54267 .82683 L 1 g
F
P
p
.002 w
.53637 .8256 m .53695 .82905 L p
.54851 .81911 L 1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.51453 .81597 m .47684 .82079 L p
.51887 .82989 L 1 g
F P
s
P
p
.002 w
.53063 .83243 m .52696 .82868 L p
.51887 .82989 L 1 g
F P
s
P
p
.002 w
.52696 .82868 m .51453 .81597 L p
.51887 .82989 L 1 g
F P
s
P
p
.5208 .83069 m .51276 .83464 L .52921 .82834 L 1 g
F
P
p
.52696 .82868 m .52921 .82834 L .53637 .8256 L 1 g
F
P
p
.5208 .83069 m .52921 .82834 L .52696 .82868 L 1 g
F
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53664 .82723 L p
1 g
F P
s
P
p
.002 w
.53664 .82723 m .53637 .8256 L p
.52921 .82834 L 1 g
F P
s
P
p
.52921 .82834 m .51276 .83464 L .53664 .82723 L 1 g
F
P
p
.002 w
.48744 .83101 m .48724 .83464 L p
.50308 .8309 L 1 g
F P
s
P
p
.002 w
.47684 .82079 m .47966 .82996 L p
.49958 .83092 L 1 g
F P
s
P
p
.50737 .83087 m .47684 .82079 L .49958 .83092 L 1 g
F
P
p
.51887 .82989 m .47684 .82079 L .5089 .83138 L 1 g
F
P
p
.524 .82912 m .5208 .83069 L .52696 .82868 L 1 g
F
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55629 .81496 L p
1 g
F P
s
P
p
.54851 .81911 m .53695 .82905 L .55629 .81496 L 1 g
F
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.54751 .80056 m .51453 .81597 L p
.55788 .81357 L 1 g
F P
s
P
p
.002 w
.57298 .81274 m .56385 .80837 L p
.55788 .81357 L 1 g
F P
s
P
p
.56958 .79874 m .56123 .81066 L .56321 .80892 L 1 g
F
P
p
.002 w
.56385 .80837 m .57298 .81274 L p
.57885 .79009 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56385 .80837 m .54751 .80056 L p
.55788 .81357 L 1 g
F P
s
P
p
.56321 .80892 m .55684 .81691 L .56264 .80984 L 1 g
F
P
p
.56123 .81066 m .55684 .81691 L .56321 .80892 L 1 g
F
P
p
.002 w
.55629 .81496 m .55684 .81691 L p
.56123 .81066 L 1 g
F P
s
P
p
.002 w
.54751 .80056 m .56385 .80837 L p
.57885 .79009 L 1 g
F P
s
P
p
.002 w
.55684 .81691 m .55726 .81844 L p
.56264 .80984 L 1 g
F P
s
P
p
.002 w
.57026 .80056 m .5715 .8039 L p
.57432 .79032 L 1 g
F P
s
P
p
.57421 .76511 m .57681 .78404 L .57643 .77756 L 1 g
F
P
p
.002 w
.60483 .78141 m .62263 .74164 L p
.57601 .77352 L 1 g
F P
s
P
p
.002 w
.57639 .77679 m .60483 .78141 L p
.57601 .77352 L 1 g
F P
s
P
p
.57421 .76511 m .57656 .77829 L .57546 .7688 L 1 g
F
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.53725 .76609 m .57222 .77611 L .57546 .7688 L p
1 g
F P
s
P
p
.002 w
.57546 .7688 m .57577 .76809 L p
.57523 .76722 L 1 g
F P
s
P
p
.002 w
.56505 .75086 m .56431 .74928 L p
.5697 .75833 L 1 g
F P
s
P
p
.002 w
.57523 .76722 m .57421 .76511 L p
.57546 .7688 L 1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57523 .76722 L p
1 g
F P
s
P
p
.57523 .76722 m .53725 .76609 L .57546 .7688 L 1 g
F
P
p
.56431 .74928 m .57523 .76722 L .5697 .75833 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.57291 .75075 m .56666 .75344 L .57523 .76722 L 1 g
F
P
p
.56666 .75344 m .53725 .76609 L .57523 .76722 L 1 g
F
P
p
.002 w
.57528 .76733 m .57523 .76722 L p
.57546 .7688 L 1 g
F P
s
P
p
.002 w
.62263 .74164 m .58593 .74515 L .57577 .76809 L p
1 g
F P
s
P
p
.002 w
.57577 .76809 m .57222 .77611 L p
.57826 .77198 L 1 g
F P
s
P
p
.62263 .74164 m .57577 .76809 L .57826 .77198 L 1 g
F
P
p
.002 w
.57537 .76792 m .57628 .76938 L .57528 .76733 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57537 .76793 L p
.57811 .78694 L 1 g
F P
s
P
p
.57656 .77829 m .57811 .78694 L .57528 .76733 L 1 g
F
P
p
.002 w
.54653 .74488 m .53725 .76609 L p
.56792 .7529 L 1 g
F P
s
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56593 .75272 L p
1 g
F P
s
P
p
.55675 .74495 m .56584 .75212 L .56505 .75086 L 1 g
F
P
p
.002 w
.56593 .75272 m .56505 .75086 L p
.57068 .76014 L 1 g
F P
s
P
p
.57068 .76014 m .57628 .76938 L .56593 .75272 L 1 g
F
P
p
.5697 .75833 m .57628 .76938 L .56505 .75086 L 1 g
F
P
p
.58593 .74515 m .57291 .75075 L .57523 .76722 L 1 g
F
P
p
.002 w
.57577 .76809 m .58593 .74515 L p
.57523 .76722 L 1 g
F P
s
P
p
.002 w
.57222 .77611 m .57639 .77679 L p
.57601 .77352 L 1 g
F P
s
P
p
.002 w
.57639 .77679 m .57222 .77611 L p
.5772 .79064 L 1 g
F P
s
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57681 .78404 L p
1 g
F P
s
P
p
.57432 .79032 m .5715 .8039 L .57681 .78404 L 1 g
F
P
p
.002 w
.57681 .78404 m .57811 .78694 L p
.57643 .77756 L 1 g
F P
s
P
p
.56505 .75086 m .56584 .75212 L .56792 .7529 L 1 g
F
P
p
.002 w
.57523 .76722 m .57628 .76938 L p
.5697 .75833 L 1 g
F P
s
P
p
.002 w
.56505 .75086 m .56532 .75143 L p
.56213 .74877 L 1 g
F P
s
P
p
.54732 .73647 m .56505 .75086 L .56213 .74877 L 1 g
F
P
p
.54732 .73647 m .56532 .75143 L .55767 .74564 L 1 g
F
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.54803 .73835 m .54672 .73794 L .55134 .74085 L 1 g
F
P
p
.002 w
.54803 .73835 m .54732 .73647 L p
.55767 .74564 L 1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54653 .74488 m .58593 .74515 L .58701 .71095 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54803 .73835 L p
1 g
F P
s
P
p
.55767 .74564 m .56611 .75311 L .54803 .73835 L 1 g
F
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.58701 .71095 m .54716 .72151 L .54673 .73737 L p
1 g
F P
s
P
p
.52506 .72815 m .5473 .73812 L .53717 .73421 L 1 g
F
P
p
.5473 .73812 m .54808 .73847 L .54672 .73794 L 1 g
F
P
p
.5473 .73812 m .54672 .73794 L .53717 .73421 L 1 g
F
P
p
.002 w
.54673 .73737 m .54672 .73794 L p
.54713 .73767 L 1 g
F P
s
P
p
.58701 .71095 m .54673 .73737 L .54713 .73767 L 1 g
F
P
p
.002 w
.58593 .74515 m .55675 .74495 L p
.56792 .7529 L 1 g
F P
s
P
p
.55261 .73978 m .54803 .73835 L .55134 .74085 L 1 g
F
P
p
.002 w
.56532 .75143 m .56611 .75311 L p
.55767 .74564 L 1 g
F P
s
P
p
.58701 .71095 m .54672 .73794 L .55261 .73978 L 1 g
F
P
p
.002 w
.54803 .73835 m .54808 .73847 L p
.5473 .73812 L 1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.50562 .74081 m .54653 .74488 L .54672 .73794 L p
1 g
F P
s
P
p
.002 w
.52538 .72961 m .52506 .72815 L p
.53717 .73421 L 1 g
F P
s
P
p
.002 w
.54672 .73794 m .54716 .72151 L p
.52773 .73053 L 1 g
F P
s
P
p
.52773 .73053 m .50562 .74081 L .54672 .73794 L 1 g
F
P
p
.002 w
.50588 .72895 m .50562 .74081 L p
.52773 .73053 L 1 g
F P
s
P
p
.52582 .72979 m .50588 .72895 L .52773 .73053 L 1 g
F
P
p
.002 w
.50956 .72829 m .50588 .72895 L p
.52905 .72992 L 1 g
F P
s
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52538 .72961 L p
1 g
F P
s
P
p
.53717 .73421 m .54864 .73996 L .52538 .72961 L 1 g
F
P
p
.002 w
.54808 .73847 m .54864 .73996 L p
.53717 .73421 L 1 g
F P
s
P
p
.52905 .72992 m .52582 .72979 L .52773 .73053 L 1 g
F
P
p
.002 w
.5 .72527 m .52506 .72815 L .52538 .72961 L p
1 g
F P
s
P
p
.5 .72527 m .52538 .72961 L .51474 .72872 L 1 g
F
P
p
.51475 .72878 m .52574 .7313 L .52422 .73104 L 1 g
F
P
p
.5 .72527 m .51519 .72883 L .51475 .72878 L 1 g
F
P
p
.51519 .72883 m .52574 .7313 L .51475 .72878 L 1 g
F
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.50588 .72895 m .50956 .72829 L p
.50688 .72803 L 1 g
F P
s
P
p
.002 w
.46753 .73274 m .50588 .72895 L .50551 .7279 L p
1 g
F P
s
P
p
.50086 .72712 m .46753 .73274 L .50551 .7279 L 1 g
F
P
p
.002 w
.5 .72697 m .5 .72527 L p
.51475 .72878 L 1 g
F P
s
P
p
.002 w
.50551 .7279 m .50588 .72895 L p
.50688 .72803 L 1 g
F P
s
P
p
.51475 .72878 m .52422 .73104 L .50551 .7279 L 1 g
F
P
p
.51475 .72878 m .50551 .7279 L .5 .72697 L 1 g
F
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.539 .69852 m .5017 .71732 L .50551 .7279 L p
1 g
F P
s
P
p
.539 .69852 m .50551 .7279 L .50688 .72803 L 1 g
F
P
p
.47459 .72978 m .46753 .73274 L .50498 .72643 L 1 g
F
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72697 L p
1 g
F P
s
P
p
.52422 .73104 m .52576 .73141 L .5 .72697 L 1 g
F
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72697 L p
1 g
F P
s
P
p
.002 w
.5 .72697 m .5 .72845 L p
.48793 .7283 L 1 g
F P
s
P
p
.47494 .72815 m .5 .72697 L .48793 .7283 L 1 g
F
P
p
.46618 .7333 m .4744 .73067 L .46732 .73304 L 1 g
F
P
p
.45268 .73647 m .46906 .7321 L .46618 .7333 L 1 g
F
P
p
.46906 .7321 m .4744 .73067 L .46618 .7333 L 1 g
F
P
p
.002 w
.46447 .73304 m .46753 .73274 L p
.47394 .72985 L 1 g
F P
s
P
p
.002 w
.47459 .72978 m .47494 .72815 L p
.48793 .7283 L 1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5017 .71732 m .47137 .73013 L p
.47394 .72985 L 1 g
F P
s
P
p
.002 w
.47137 .73013 m .46447 .73304 L p
.47394 .72985 L 1 g
F P
s
P
p
.002 w
.50498 .72643 m .50204 .71826 L p
.48662 .72473 L 1 g
F P
s
P
p
.48662 .72473 m .47459 .72978 L .5 .72697 L 1 g
F
P
p
.48662 .72473 m .5 .72697 L .50498 .72643 L 1 g
F
P
p
.002 w
.54716 .72151 m .539 .69852 L p
.50688 .72803 L 1 g
F P
s
P
p
.002 w
.50956 .72829 m .54716 .72151 L p
.50688 .72803 L 1 g
F P
s
P
p
.002 w
.54716 .72151 m .50956 .72829 L p
.52905 .72992 L 1 g
F P
s
P
p
.002 w
.52538 .72961 m .52574 .7313 L p
.51474 .72872 L 1 g
F P
s
P
p
.002 w
.52574 .7313 m .52576 .73141 L p
.52422 .73104 L 1 g
F P
s
P
p
.002 w
.50551 .7279 m .50498 .72643 L p
.50086 .72712 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47459 .72978 L p
1 g
F P
s
P
p
.48793 .7283 m .5 .72845 L .47459 .72978 L 1 g
F
P
p
.002 w
.50204 .71826 m .5017 .71732 L p
.46753 .73274 L 1 g
F P
s
P
p
.002 w
.47459 .72978 m .4744 .73067 L p
.46906 .7321 L 1 g
F P
s
P
p
.002 w
.4744 .73067 m .47424 .73141 L p
.46732 .73304 L 1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.45705 .73429 m .42582 .73955 L p
.43941 .74237 L 1 g
F P
s
P
p
.43569 .74928 m .45187 .73828 L .44395 .74436 L 1 g
F
P
p
.002 w
.44504 .74353 m .45987 .73553 L p
.45205 .73814 L 1 g
F P
s
P
p
.45187 .73828 m .45204 .73816 L .44504 .74353 L 1 g
F
P
p
.45187 .73828 m .44504 .74353 L .44395 .74436 L 1 g
F
P
p
.44504 .74353 m .45205 .73814 L .43941 .74237 L 1 g
F
P
p
.002 w
.45205 .73814 m .45268 .73647 L p
.46615 .73331 L 1 g
F P
s
P
p
.45205 .73814 m .45705 .73429 L .43941 .74237 L 1 g
F
P
p
.002 w
.46753 .73274 m .46447 .73304 L .46607 .73334 L p
1 g
F P
s
P
p
.46615 .73331 m .46615 .73331 L .46614 .73331 L 1 g
F
P
p
.46615 .73331 m .46614 .73331 L .45205 .73814 L 1 g
F
P
p
.46615 .73331 m .4662 .7333 L .46608 .73334 L 1 g
F
P
p
.46615 .73331 m .46608 .73334 L .45205 .73814 L 1 g
F
P
p
.002 w
.50096 .7516 m .50562 .74081 L .46607 .73334 L p
1 g
F P
s
P
p
.4662 .7333 m .46601 .73337 L .45205 .73814 L 1 g
F
P
p
.002 w
.46551 .73357 m .50096 .7516 L p
.46607 .73334 L 1 g
F P
s
P
p
.4663 .73328 m .46591 .73342 L .45205 .73814 L 1 g
F
P
p
.002 w
.46516 .73371 m .49243 .76017 L p
.46551 .73357 L 1 g
F P
s
P
p
.46645 .73324 m .46569 .73352 L .45205 .73814 L 1 g
F
P
p
.002 w
.46607 .73334 m .46447 .73304 L .46551 .73357 L p
1 g
F P
s
P
p
.002 w
.48095 .7656 m .49243 .76017 L .46516 .73371 L p
1 g
F P
s
P
p
.002 w
.46487 .73382 m .48095 .7656 L p
.46516 .73371 L 1 g
F P
s
P
p
.46665 .73319 m .4652 .73371 L .45205 .73814 L 1 g
F
P
p
.002 w
.46551 .73357 m .46447 .73304 L .46516 .73371 L p
1 g
F P
s
P
p
.4662 .7333 m .4663 .73328 L .46601 .73337 L 1 g
F
P
p
.4663 .73328 m .46645 .73324 L .46591 .73342 L 1 g
F
P
p
.002 w
.46516 .73371 m .46447 .73304 L .46487 .73382 L p
1 g
F P
s
P
p
.002 w
.46456 .73393 m .46777 .76732 L p
.46487 .73382 L 1 g
F P
s
P
p
.4669 .73313 m .46394 .73415 L .45205 .73814 L 1 g
F
P
p
.002 w
.46487 .73382 m .46447 .73304 L .46456 .73393 L p
1 g
F P
s
P
p
.46645 .73324 m .46665 .73319 L .46569 .73352 L 1 g
F
P
p
.46665 .73319 m .4669 .73313 L .4652 .73371 L 1 g
F
P
p
.002 w
.4543 .76516 m .46777 .76732 L .46456 .73393 L p
1 g
F P
s
P
p
.002 w
.46456 .73393 m .46447 .73304 L .46415 .73408 L p
1 g
F P
s
P
p
.002 w
.46415 .73408 m .4543 .76516 L p
.46456 .73393 L 1 g
F P
s
P
p
.002 w
.46415 .73408 m .46447 .73304 L .46335 .73435 L p
1 g
F P
s
P
p
.002 w
.46335 .73435 m .44198 .75934 L p
.46415 .73408 L 1 g
F P
s
P
p
.4669 .73313 m .46714 .73308 L .46394 .73415 L 1 g
F
P
p
.002 w
.44198 .75934 m .46335 .73435 L p
.44504 .74353 L 1 g
F P
s
P
p
.46714 .73308 m .46732 .73304 L .45987 .73553 L 1 g
F
P
p
.46714 .73308 m .45987 .73553 L .45205 .73814 L 1 g
F
P
p
.002 w
.46335 .73435 m .46447 .73304 L .45987 .73553 L p
1 g
F P
s
P
p
.002 w
.45987 .73553 m .44504 .74353 L p
.46335 .73435 L 1 g
F P
s
P
p
.002 w
.46447 .73304 m .45705 .73429 L p
.45205 .73814 L 1 g
F P
s
P
p
.002 w
.45987 .73553 m .46447 .73304 L p
.45205 .73814 L 1 g
F P
s
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45205 .73814 L p
1 g
F P
s
P
p
.46732 .73304 m .47424 .73141 L .45205 .73814 L 1 g
F
P
p
.002 w
.42582 .73955 m .43213 .75049 L .44504 .74353 L p
1 g
F P
s
P
p
.002 w
.45205 .73814 m .45204 .73816 L p
.45187 .73828 L 1 g
F P
s
P
p
.44198 .75934 m .44504 .74353 L .43742 .74937 L 1 g
F
P
p
.002 w
.45204 .73816 m .45136 .73996 L p
.44395 .74436 L 1 g
F P
s
P
p
.002 w
.44504 .74353 m .43679 .74798 L p
.43742 .74937 L 1 g
F P
s
P
p
.43742 .74937 m .43679 .74798 L .43465 .7515 L 1 g
F
P
p
.43742 .74937 m .43465 .7515 L .43415 .75231 L 1 g
F
P
p
.42579 .76511 m .43465 .7515 L .43436 .75197 L 1 g
F
P
p
.42579 .76511 m .4346 .7516 L .43008 .75876 L 1 g
F
P
p
.002 w
.44198 .75934 m .43389 .75208 L p
.42406 .77351 L 1 g
F P
s
P
p
.002 w
.43389 .75208 m .43213 .75049 L p
.43087 .7541 L 1 g
F P
s
P
p
.42406 .77351 m .43389 .75208 L .43087 .7541 L 1 g
F
P
p
.002 w
.45136 .73996 m .44614 .74389 L p
.43465 .7515 L 1 g
F P
s
P
p
.002 w
.44614 .74389 m .43389 .75311 L .4346 .7516 L p
1 g
F P
s
P
p
.002 w
.4346 .7516 m .43465 .7515 L p
.44614 .74389 L 1 g
F P
s
P
p
.44395 .74436 m .45136 .73996 L .43465 .7515 L 1 g
F
P
p
.002 w
.43465 .7515 m .4346 .7516 L p
.43436 .75197 L 1 g
F P
s
P
p
.002 w
.43679 .74798 m .43213 .75049 L .43415 .75231 L p
1 g
F P
s
P
p
.42818 .76177 m .43213 .75049 L .42488 .767 L 1 g
F
P
p
.002 w
.4346 .7516 m .43389 .75311 L p
.43008 .75876 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42488 .767 L p
1 g
F P
s
P
p
.43008 .75876 m .43389 .75311 L .42488 .767 L 1 g
F
P
p
.002 w
.4229 .78468 m .424 .78222 L p
.42376 .77591 L 1 g
F P
s
P
p
.42376 .77591 m .42363 .77695 L .4229 .78468 L 1 g
F
P
p
.42375 .77566 m .42303 .78198 L .4229 .78468 L 1 g
F
P
p
.002 w
.42372 .76938 m .42357 .77088 L p
.424 .78222 L 1 g
F P
s
P
p
.002 w
.42336 .77908 m .44198 .75934 L p
.42406 .77351 L 1 g
F P
s
P
p
.42376 .77591 m .42375 .77566 L .42363 .77695 L 1 g
F
P
p
.002 w
.42336 .77908 m .42136 .7812 L .42303 .78198 L p
1 g
F P
s
P
p
.42375 .77566 m .42357 .77088 L .42303 .78198 L 1 g
F
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44198 .75934 m .42336 .77908 L p
.44553 .79259 L 1 g
F P
s
P
p
.002 w
.42303 .78198 m .44553 .79259 L p
.42336 .77908 L 1 g
F P
s
P
p
.43382 .80561 m .42292 .78425 L .42252 .79246 L 1 g
F
P
p
.42292 .78425 m .42136 .7812 L .42252 .79246 L 1 g
F
P
p
.002 w
.44553 .79259 m .42303 .78198 L p
.43382 .80561 L 1 g
F P
s
P
p
.002 w
.42303 .78198 m .42145 .78124 L p
.42293 .78414 L 1 g
F P
s
P
p
.43382 .80561 m .42303 .78198 L .42293 .78414 L 1 g
F
P
p
.43382 .80561 m .42145 .78124 L .42176 .78198 L 1 g
F
P
p
.002 w
.42189 .78694 m .42357 .77088 L p
.42166 .77365 L 1 g
F P
s
P
p
.002 w
.42357 .77088 m .42372 .76938 L .42363 .76957 L p
1 g
F P
s
P
p
.002 w
.42363 .76957 m .42166 .77365 L p
.42357 .77088 L 1 g
F P
s
P
p
.002 w
.42357 .77088 m .42189 .78694 L .4229 .78468 L p
1 g
F P
s
P
p
.002 w
.4229 .78468 m .42189 .78694 L p
.42658 .79343 L 1 g
F P
s
P
p
.002 w
.42145 .78124 m .42136 .7812 L p
.42176 .78198 L 1 g
F P
s
P
p
.002 w
.4384 .81458 m .43925 .81194 L p
.43382 .80561 L 1 g
F P
s
P
p
.002 w
.44346 .81585 m .44427 .81291 L p
.43688 .80962 L 1 g
F P
s
P
p
.002 w
.43925 .81194 m .4384 .81458 L .44267 .81527 L p
1 g
F P
s
P
p
.43688 .80962 m .43195 .80742 L .44267 .81527 L 1 g
F
P
p
.43688 .80962 m .44267 .81527 L .44346 .81585 L 1 g
F
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.44198 .81516 m .4384 .81458 L p
.45542 .8214 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44346 .81585 L p
1 g
F P
s
P
p
.002 w
.4384 .81458 m .43744 .81749 L p
.45111 .82152 L 1 g
F P
s
P
p
.002 w
.44346 .81585 m .44274 .81844 L p
.45502 .82121 L 1 g
F P
s
P
p
.46403 .82325 m .44346 .81585 L .45502 .82121 L 1 g
F
P
p
.002 w
.4637 .82524 m .46403 .82325 L p
.45502 .82121 L 1 g
F P
s
P
p
.002 w
.47966 .82996 m .47684 .82079 L p
.45542 .8214 L 1 g
F P
s
P
p
.4637 .82524 m .45542 .8214 L .45111 .82152 L 1 g
F
P
p
.47966 .82996 m .45542 .8214 L .4637 .82524 L 1 g
F
P
p
.002 w
.44553 .79259 m .43925 .81194 L p
.47684 .82079 L 1 g
F P
s
P
p
.002 w
.44267 .81527 m .47684 .82079 L p
.43925 .81194 L 1 g
F P
s
P
p
.002 w
.43925 .81194 m .44553 .79259 L p
.43382 .80561 L 1 g
F P
s
P
p
.002 w
.43195 .80742 m .44274 .81844 L .44325 .81659 L p
1 g
F P
s
P
p
.002 w
.47684 .82079 m .44198 .81516 L p
.45542 .8214 L 1 g
F P
s
P
p
.002 w
.44325 .81659 m .44346 .81585 L p
.44118 .81418 L 1 g
F P
s
P
p
.44118 .81418 m .43195 .80742 L .44325 .81659 L 1 g
F
P
p
.002 w
.42966 .80077 m .4285 .8039 L p
.43606 .80822 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42966 .80077 L p
1 g
F P
s
P
p
.42658 .79343 m .42189 .78694 L .42966 .80077 L 1 g
F
P
p
.002 w
.4285 .8039 m .43195 .80742 L p
.4375 .8099 L 1 g
F P
s
P
p
.43606 .80822 m .4285 .8039 L .4375 .8099 L 1 g
F
P
p
.002 w
.48232 .83857 m .47966 .82996 L p
.45111 .82152 L 1 g
F P
s
P
p
.002 w
.43744 .81749 m .43309 .83061 L p
.45111 .82152 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .4637 .82524 L p
1 g
F P
s
P
p
.45502 .82121 m .44274 .81844 L .4637 .82524 L 1 g
F
P
p
.002 w
.4637 .82524 m .46305 .82905 L p
.47596 .82886 L 1 g
F P
s
P
p
.002 w
.51255 .83083 m .51276 .83464 L p
.524 .82912 L 1 g
F P
s
P
p
.002 w
.47966 .82996 m .48 .83106 L p
.48744 .83101 L 1 g
F P
s
P
p
.002 w
.48 .83106 m .48232 .83857 L p
.48744 .83101 L 1 g
F P
s
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51255 .83083 L p
1 g
F P
s
P
p
.50308 .8309 m .48724 .83464 L .51255 .83083 L 1 g
F
P
p
.002 w
.48737 .83223 m .48744 .83101 L p
.47966 .82996 L 1 g
F P
s
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48737 .83223 L p
1 g
F P
s
P
p
.47596 .82886 m .46305 .82905 L .48737 .83223 L 1 g
F
P
p
.002 w
.30479 .62591 m .28696 .60115 L .27617 .65906 L p
1 g
F P
s
P
p
.002 w
.27617 .65906 m .29514 .67699 L .30479 .62591 L p
1 g
F P
s
P
p
.002 w
.59608 .81917 m .57298 .81274 L .53063 .83243 L p
1 g
F P
s
P
p
.002 w
.57298 .81274 m .59608 .81917 L .63414 .78191 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.32011 .6933 m .29514 .67699 L .30502 .72912 L p
1 g
F P
s
P
p
.002 w
.30502 .72912 m .3283 .73704 L .32011 .6933 L p
1 g
F P
s
P
p
.002 w
.31912 .55067 m .31016 .5219 L .27527 .57699 L p
1 g
F P
s
P
p
.002 w
.27527 .57699 m .28696 .60115 L .31912 .55067 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.37499 .7728 m .35182 .77712 L .38803 .80941 L p
1 g
F P
s
P
p
.002 w
.38803 .80941 m .40322 .79802 L .37499 .7728 L p
1 g
F P
s
P
p
.002 w
.70948 .64561 m .7265 .62611 L .70394 .55825 L p
1 g
F P
s
P
p
.002 w
.71406 .53706 m .70394 .55825 L .7265 .62611 L p
1 g
F P
s
P
p
.002 w
.70394 .55825 m .71406 .53706 L .66677 .4761 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.43664 .43016 m .44123 .40616 L .36727 .42955 L p
1 g
F P
s
P
p
.002 w
.36727 .42955 m .36421 .45294 L .43664 .43016 L p
1 g
F P
s
P
p
.002 w
.36495 .48115 m .36421 .45294 L .30661 .496 L p
1 g
F P
s
P
p
.002 w
.30661 .496 m .31016 .5219 L .36495 .48115 L p
1 g
F P
s
P
p
.002 w
.60518 .41262 m .60022 .43079 L .66677 .4761 L p
1 g
F P
s
P
p
.002 w
.60022 .43079 m .60518 .41262 L .52756 .38854 L p
1 g
F P
s
P
p
.002 w
.52756 .38854 m .522 .40653 L .60022 .43079 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.35673 .74153 m .3283 .73704 L .35182 .77712 L p
1 g
F P
s
P
p
.002 w
.35182 .77712 m .37499 .7728 L .35673 .74153 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.63414 .78191 m .60483 .78141 L .57298 .81274 L p
1 g
F P
s
P
p
.002 w
.60483 .78141 m .63414 .78191 L .65554 .73451 L p
1 g
F P
s
P
p
.002 w
.68375 .72401 m .65554 .73451 L .63414 .78191 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.65554 .73451 m .68375 .72401 L .68633 .66441 L p
1 g
F P
s
P
p
.002 w
.70948 .64561 m .68633 .66441 L .68375 .72401 L p
1 g
F P
s
P
p
.002 w
.66677 .4761 m .65756 .49866 L .70394 .55825 L p
1 g
F P
s
P
p
.002 w
.65756 .49866 m .66677 .4761 L .60022 .43079 L p
1 g
F P
s
P
p
.002 w
.32835 .65054 m .30479 .62591 L .29514 .67699 L p
1 g
F P
s
P
p
.002 w
.29514 .67699 m .32011 .6933 L .32835 .65054 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.51574 .43058 m .522 .40653 L .44123 .40616 L p
1 g
F P
s
P
p
.002 w
.44123 .40616 m .43664 .43016 L .51574 .43058 L p
1 g
F P
s
P
p
.002 w
.33332 .58148 m .31912 .55067 L .28696 .60115 L p
1 g
F P
s
P
p
.002 w
.28696 .60115 m .30479 .62591 L .33332 .58148 L p
1 g
F P
s
P
p
.002 w
.35046 .70749 m .32011 .6933 L .3283 .73704 L p
1 g
F P
s
P
p
.002 w
.3283 .73704 m .35673 .74153 L .35046 .70749 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.68633 .66441 m .70948 .64561 L .68791 .58124 L p
1 g
F P
s
P
p
.002 w
.70394 .55825 m .68791 .58124 L .70948 .64561 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.68791 .58124 m .70394 .55825 L .65756 .49866 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.47684 .82079 m .47194 .79684 L .44553 .79259 L p
1 g
F P
s
P
p
.002 w
.47194 .79684 m .47684 .82079 L .51453 .81597 L p
1 g
F P
s
P
p
.002 w
.36953 .51339 m .36495 .48115 L .31016 .5219 L p
1 g
F P
s
P
p
.002 w
.31016 .5219 m .31912 .55067 L .36953 .51339 L p
1 g
F P
s
P
p
.002 w
.40201 .76386 m .37499 .7728 L .40322 .79802 L p
1 g
F P
s
P
p
.002 w
.40322 .79802 m .42136 .7812 L .40201 .76386 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.43379 .45963 m .43664 .43016 L .36421 .45294 L p
1 g
F P
s
P
p
.002 w
.36421 .45294 m .36495 .48115 L .43379 .45963 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.60022 .43079 m .59235 .45434 L .65756 .49866 L p
1 g
F P
s
P
p
.002 w
.59235 .45434 m .60022 .43079 L .522 .40653 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.522 .40653 m .51574 .43058 L .59235 .45434 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.51453 .81597 m .49781 .7935 L .47194 .79684 L p
1 g
F P
s
P
p
.002 w
.49781 .7935 m .51453 .81597 L .54751 .80056 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.38954 .7424 m .35673 .74153 L .37499 .7728 L p
1 g
F P
s
P
p
.002 w
.37499 .7728 m .40201 .76386 L .38954 .7424 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.65554 .73451 m .62263 .74164 L .60483 .78141 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.62263 .74164 m .65554 .73451 L .65765 .68193 L p
1 g
F P
s
P
p
.002 w
.68633 .66441 m .65765 .68193 L .65554 .73451 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.357 .67428 m .32835 .65054 L .32011 .6933 L p
1 g
F P
s
P
p
.002 w
.32011 .6933 m .35046 .70749 L .357 .67428 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.35238 .61343 m .33332 .58148 L .30479 .62591 L p
1 g
F P
s
P
p
.002 w
.30479 .62591 m .32835 .65054 L .35238 .61343 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.54751 .80056 m .52039 .78289 L .49781 .7935 L p
1 g
F P
s
P
p
.002 w
.52039 .78289 m .54751 .80056 L .57222 .77611 L p
1 g
F P
s
P
p
.002 w
.65756 .49866 m .64375 .52472 L .68791 .58124 L p
1 g
F P
s
P
p
.002 w
.64375 .52472 m .65756 .49866 L .59235 .45434 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.65765 .68193 m .68633 .66441 L .66637 .60536 L p
1 g
F P
s
P
p
.002 w
.68791 .58124 m .66637 .60536 L .68633 .66441 L p
1 g
F P
s
P
p
.002 w
.38534 .71908 m .35046 .70749 L .35673 .74153 L p
1 g
F P
s
P
p
.002 w
.35673 .74153 m .38954 .7424 L .38534 .71908 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.50895 .4601 m .51574 .43058 L .43664 .43016 L p
1 g
F P
s
P
p
.002 w
.43664 .43016 m .43379 .45963 L .50895 .4601 L p
1 g
F P
s
P
p
.002 w
.37788 .54875 m .36953 .51339 L .31912 .55067 L p
1 g
F P
s
P
p
.002 w
.31912 .55067 m .33332 .58148 L .37788 .54875 L p
1 g
F P
s
P
p
.002 w
.66637 .60536 m .68791 .58124 L .64375 .52472 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.44553 .79259 m .4543 .76516 L .44198 .75934 L p
1 g
F P
s
P
p
.002 w
.4543 .76516 m .44553 .79259 L .47194 .79684 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.43279 .49376 m .43379 .45963 L .36495 .48115 L p
1 g
F P
s
P
p
.002 w
.36495 .48115 m .36953 .51339 L .43279 .49376 L p
1 g
F P
s
P
p
.002 w
.47194 .79684 m .46777 .76732 L .4543 .76516 L p
1 g
F P
s
P
p
.002 w
.46777 .76732 m .47194 .79684 L .49781 .7935 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.59235 .45434 m .58175 .48268 L .64375 .52472 L p
1 g
F P
s
P
p
.002 w
.58175 .48268 m .59235 .45434 L .51574 .43058 L p
1 g
F P
s
P
p
.002 w
.51574 .43058 m .50895 .4601 L .58175 .48268 L p
1 g
F P
s
P
p
.002 w
.49781 .7935 m .48095 .7656 L .46777 .76732 L p
1 g
F P
s
P
p
.002 w
.48095 .7656 m .49781 .7935 L .52039 .78289 L p
1 g
F P
s
P
p
.002 w
.42582 .73955 m .38954 .7424 L .40201 .76386 L p
1 g
F P
s
P
p
.002 w
.40201 .76386 m .43213 .75049 L .42582 .73955 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.57222 .77611 m .53725 .76609 L .52039 .78289 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.58593 .74515 m .62263 .74164 L .62422 .69761 L p
1 g
F P
s
P
p
.002 w
.65765 .68193 m .62422 .69761 L .62263 .74164 L p
1 g
F P
s
P
p
.002 w
.38991 .6964 m .357 .67428 L .35046 .70749 L p
1 g
F P
s
P
p
.002 w
.35046 .70749 m .38534 .71908 L .38991 .6964 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.37578 .64555 m .35238 .61343 L .32835 .65054 L p
1 g
F P
s
P
p
.002 w
.32835 .65054 m .357 .67428 L .37578 .64555 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.62422 .69761 m .65765 .68193 L .63987 .62991 L p
1 g
F P
s
P
p
.002 w
.66637 .60536 m .63987 .62991 L .65765 .68193 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.52039 .78289 m .49243 .76017 L .48095 .7656 L p
1 g
F P
s
P
p
.002 w
.49243 .76017 m .52039 .78289 L .53725 .76609 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.42373 .7277 m .38534 .71908 L .38954 .7424 L p
1 g
F P
s
P
p
.002 w
.38954 .7424 m .42582 .73955 L .42373 .7277 L p
1 g
F P
s
P
p
.002 w
.38978 .58617 m .37788 .54875 L .33332 .58148 L p
1 g
F P
s
P
p
.002 w
.33332 .58148 m .35238 .61343 L .38978 .58617 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.64375 .52472 m .6257 .55355 L .66637 .60536 L p
1 g
F P
s
P
p
.002 w
.6257 .55355 m .64375 .52472 L .58175 .48268 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.63987 .62991 m .66637 .60536 L .6257 .55355 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.50183 .49428 m .50895 .4601 L .43379 .45963 L p
1 g
F P
s
P
p
.002 w
.43379 .45963 m .43279 .49376 L .50183 .49428 L p
1 g
F P
s
P
p
.004 w
.43309 .44405 m
.45 .48643 L
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.43372 .53158 m .43279 .49376 L .36953 .51339 L p
1 g
F P
s
P
p
.002 w
.36953 .51339 m .37788 .54875 L .43372 .53158 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.53725 .76609 m .50096 .7516 L .49243 .76017 L p
1 g
F P
s
P
p
.002 w
.50096 .7516 m .53725 .76609 L .54653 .74488 L p
1 g
F P
s
P
p
.002 w
.62422 .69761 m .58701 .71095 L .58593 .74515 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.42611 .7162 m .38991 .6964 L .38534 .71908 L p
1 g
F P
s
P
p
.002 w
.38534 .71908 m .42373 .7277 L .42611 .7162 L p
1 g
F P
s
P
p
.002 w
.40284 .67683 m .37578 .64555 L .357 .67428 L p
1 g
F P
s
P
p
.002 w
.357 .67428 m .38991 .6964 L .40284 .67683 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.58175 .48268 m .5687 .51501 L .6257 .55355 L p
1 g
F P
s
P
p
.002 w
.5687 .51501 m .58175 .48268 L .50895 .4601 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.50895 .4601 m .50183 .49428 L .5687 .51501 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.58701 .71095 m .62422 .69761 L .60917 .65412 L p
1 g
F P
s
P
p
.002 w
.63987 .62991 m .60917 .65412 L .62422 .69761 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.42582 .73955 m .46447 .73304 L .42373 .7277 L closepath p
1 g
F P
s
P
p
.002 w
.4049 .6245 m .38978 .58617 L .35238 .61343 L p
1 g
F P
s
P
p
.002 w
.35238 .61343 m .37578 .64555 L .4049 .6245 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.60917 .65412 m .63987 .62991 L .60388 .5843 L p
1 g
F P
s
P
p
.002 w
.6257 .55355 m .60388 .5843 L .63987 .62991 L p
1 g
F P
s
P
p
.002 w
.54653 .74488 m .50562 .74081 L .50096 .7516 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.43271 .7063 m .40284 .67683 L .38991 .6964 L p
1 g
F P
s
P
p
.002 w
.38991 .6964 m .42611 .7162 L .43271 .7063 L p
1 g
F P
s
P
p
.002 w
.42373 .7277 m .46447 .73304 L .42611 .7162 L closepath p
1 g
F P
s
P
p
.002 w
.60388 .5843 m .6257 .55355 L .5687 .51501 L p
1 g
F P
s
P
p
.002 w
.43655 .57192 m .43372 .53158 L .37788 .54875 L p
1 g
F P
s
P
p
.002 w
.37788 .54875 m .38978 .58617 L .43655 .57192 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.49459 .53211 m .50183 .49428 L .43279 .49376 L p
1 g
F P
s
P
p
.004 w
.45954 .51036 m
.5 .6118 L
s
P
p
.002 w
.43279 .49376 m .43372 .53158 L .49459 .53211 L p
1 g
F P
s
P
p
.004 w
.45664 .50309 m
.45697 .50391 L
s
P
p
.004 w
.45 .48643 m
.45664 .50309 L
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.54716 .72151 m .58701 .71095 L .5752 .67723 L p
1 g
F P
s
P
p
.002 w
.60917 .65412 m .5752 .67723 L .58701 .71095 L p
1 g
F P
s
P
p
.002 w
.42277 .66254 m .4049 .6245 L .37578 .64555 L p
1 g
F P
s
P
p
.002 w
.37578 .64555 m .40284 .67683 L .42277 .66254 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.42611 .7162 m .46447 .73304 L .43271 .7063 L closepath p
1 g
F P
s
P
p
.002 w
.43271 .7063 m .46447 .73304 L .44284 .6991 L closepath p
1 g
F P
s
P
p
.002 w
.49351 .70719 m .46447 .73304 L .5017 .71732 L closepath p
1 g
F P
s
P
p
.002 w
.48221 .69967 m .46447 .73304 L .49351 .70719 L closepath p
1 g
F P
s
P
p
.002 w
.46902 .69558 m .46447 .73304 L .48221 .69967 L closepath p
1 g
F P
s
P
p
.004 w
.47492 .69741 m
.5 .6118 L
s
P
p
.002 w
.4554 .69539 m .46447 .73304 L .46902 .69558 L closepath p
1 g
F P
s
P
p
.002 w
.44284 .6991 m .46447 .73304 L .4554 .69539 L closepath p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.5752 .67723 m .539 .69852 L .54716 .72151 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5687 .51501 m .55357 .55038 L .60388 .5843 L p
1 g
F P
s
P
p
.002 w
.55357 .55038 m .5687 .51501 L .50183 .49428 L p
1 g
F P
s
P
p
.002 w
.50183 .49428 m .49459 .53211 L .55357 .55038 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5752 .67723 m .60917 .65412 L .57895 .61604 L p
1 g
F P
s
P
p
.002 w
.60388 .5843 m .57895 .61604 L .60917 .65412 L p
1 g
F P
s
P
p
.002 w
.44284 .6991 m .42277 .66254 L .40284 .67683 L p
1 g
F P
s
P
p
.002 w
.40284 .67683 m .43271 .7063 L .44284 .6991 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.44121 .61355 m .43655 .57192 L .38978 .58617 L p
1 g
F P
s
P
p
.002 w
.38978 .58617 m .4049 .6245 L .44121 .61355 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57895 .61604 m .60388 .5843 L .55357 .55038 L p
1 g
F P
s
P
p
.002 w
.5017 .71732 m .539 .69852 L .52288 .67846 L p
1 g
F P
s
P
p
.002 w
.52288 .67846 m .49351 .70719 L .5017 .71732 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.42277 .66254 m .44284 .6991 L .4554 .69539 L p
1 g
F P
s
P
p
.002 w
.48748 .57243 m .49459 .53211 L .43372 .53158 L p
1 g
F P
s
P
p
.002 w
.43372 .53158 m .43655 .57192 L .48748 .57243 L p
1 g
F P
s
P
p
.002 w
.539 .69852 m .5752 .67723 L .55167 .64776 L p
1 g
F P
s
P
p
.002 w
.57895 .61604 m .55167 .64776 L .5752 .67723 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.004 w
.46118 .74429 m
.46447 .73304 L
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.44756 .65514 m .44121 .61355 L .4049 .6245 L p
1 g
F P
s
P
p
.002 w
.4049 .6245 m .42277 .66254 L .44756 .65514 L p
1 g
F P
s
P
p
.002 w
.49351 .70719 m .52288 .67846 L .50056 .66356 L p
1 g
F P
s
P
p
.002 w
.50056 .66356 m .48221 .69967 L .49351 .70719 L p
1 g
F P
s
P
p
.002 w
.55167 .64776 m .52288 .67846 L .539 .69852 L p
1 g
F P
s
P
p
.002 w
.44756 .65514 m .4554 .69539 L .46902 .69558 L p
1 g
F P
s
P
p
.002 w
.4554 .69539 m .44756 .65514 L .42277 .66254 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.48221 .69967 m .50056 .66356 L .47449 .65549 L p
1 g
F P
s
P
p
.002 w
.47449 .65549 m .46902 .69558 L .48221 .69967 L p
1 g
F P
s
P
p
.002 w
.46902 .69558 m .47449 .65549 L .44756 .65514 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.55357 .55038 m .53681 .58772 L .57895 .61604 L p
1 g
F P
s
P
p
.002 w
.53681 .58772 m .55357 .55038 L .49459 .53211 L p
1 g
F P
s
P
p
.002 w
.49459 .53211 m .48748 .57243 L .53681 .58772 L p
1 g
F P
s
P
p
.002 w
.55167 .64776 m .57895 .61604 L .53681 .58772 L p
1 g
F P
s
P
p
.002 w
.4807 .614 m .48748 .57243 L .43655 .57192 L p
1 g
F P
s
P
p
.002 w
.43655 .57192 m .44121 .61355 L .4807 .614 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.52288 .67846 m .55167 .64776 L .51896 .62585 L p
1 g
F P
s
P
p
.002 w
.51896 .62585 m .50056 .66356 L .52288 .67846 L p
1 g
F P
s
P
p
.002 w
.44121 .61355 m .44756 .65514 L .47449 .65549 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.53681 .58772 m .51896 .62585 L .55167 .64776 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.47449 .65549 m .4807 .614 L .44121 .61355 L p
1 g
F P
s
P
p
.002 w
.50056 .66356 m .51896 .62585 L .4807 .614 L p
1 g
F P
s
P
p
.002 w
.4807 .614 m .47449 .65549 L .50056 .66356 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.51896 .62585 m .53681 .58772 L .48748 .57243 L p
1 g
F P
s
P
p
.002 w
.48748 .57243 m .4807 .614 L .51896 .62585 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.004 w
.44542 .79806 m
.46118 .74429 L
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .43309 .44405 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .44542 .79806 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.56)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.56)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.46655 .6533 m .47112 .61572 L .50718 .61524 L p
1 g
F P
s
P
p
.002 w
.50718 .61524 m .51313 .65265 L .46655 .6533 L p
1 g
F P
s
P
p
.002 w
.50105 .57774 m .50718 .61524 L .47112 .61572 L p
1 g
F P
s
P
p
.002 w
.51313 .65265 m .50718 .61524 L .54142 .60435 L p
1 g
F P
s
P
p
.002 w
.50718 .61524 m .50105 .57774 L .52441 .57029 L p
1 g
F P
s
P
p
.002 w
.52441 .57029 m .54142 .60435 L .50718 .61524 L p
1 g
F P
s
P
p
.002 w
.42248 .64047 m .43702 .60574 L .47112 .61572 L p
1 g
F P
s
P
p
.002 w
.47112 .61572 m .46655 .6533 L .42248 .64047 L p
1 g
F P
s
P
p
.002 w
.47643 .57806 m .47112 .61572 L .43702 .60574 L p
1 g
F P
s
P
p
.002 w
.47112 .61572 m .47643 .57806 L .50105 .57774 L p
1 g
F P
s
P
p
.002 w
.49487 .54104 m .50105 .57774 L .47643 .57806 L p
1 g
F P
s
P
p
.002 w
.50105 .57774 m .49487 .54104 L .50674 .53725 L p
1 g
F P
s
P
p
.002 w
.50674 .53725 m .52441 .57029 L .50105 .57774 L p
1 g
F P
s
P
p
.002 w
.43702 .60574 m .45318 .57122 L .47643 .57806 L p
1 g
F P
s
P
p
.002 w
.48237 .5412 m .47643 .57806 L .45318 .57122 L p
1 g
F P
s
P
p
.002 w
.47643 .57806 m .48237 .5412 L .49487 .54104 L p
1 g
F P
s
P
p
.002 w
.54142 .60435 m .55737 .63862 L .51313 .65265 L p
1 g
F P
s
P
p
.002 w
.55737 .63862 m .54142 .60435 L .57025 .58417 L p
1 g
F P
s
P
p
.002 w
.54142 .60435 m .52441 .57029 L .54405 .55649 L p
1 g
F P
s
P
p
.002 w
.54405 .55649 m .57025 .58417 L .54142 .60435 L p
1 g
F P
s
P
p
.002 w
.46283 .68991 m .46655 .6533 L .51313 .65265 L p
1 g
F P
s
P
p
.002 w
.51313 .65265 m .51875 .68912 L .46283 .68991 L p
1 g
F P
s
P
p
.002 w
.51875 .68912 m .51313 .65265 L .55737 .63862 L p
1 g
F P
s
P
p
.002 w
.52441 .57029 m .50674 .53725 L .51669 .53023 L p
1 g
F P
s
P
p
.002 w
.51669 .53023 m .54405 .55649 L .52441 .57029 L p
1 g
F P
s
P
p
.002 w
.4099 .6746 m .42248 .64047 L .46655 .6533 L p
1 g
F P
s
P
p
.002 w
.46655 .6533 m .46283 .68991 L .4099 .6746 L p
1 g
F P
s
P
p
.002 w
.40851 .5863 m .43377 .55791 L .45318 .57122 L p
1 g
F P
s
P
p
.002 w
.45318 .57122 m .43702 .60574 L .40851 .5863 L p
1 g
F P
s
P
p
.002 w
.47058 .53771 m .45318 .57122 L .43377 .55791 L p
1 g
F P
s
P
p
.002 w
.45318 .57122 m .47058 .53771 L .48237 .5412 L p
1 g
F P
s
P
p
.002 w
.38556 .61545 m .40851 .5863 L .43702 .60574 L p
1 g
F P
s
P
p
.002 w
.43702 .60574 m .42248 .64047 L .38556 .61545 L p
1 g
F P
s
P
p
.002 w
.55737 .63862 m .57188 .67232 L .51875 .68912 L p
1 g
F P
s
P
p
.002 w
.57188 .67232 m .55737 .63862 L .59467 .61263 L p
1 g
F P
s
P
p
.002 w
.57025 .58417 m .59467 .61263 L .55737 .63862 L p
1 g
F P
s
P
p
.002 w
.57025 .58417 m .54405 .55649 L .55784 .53779 L p
1 g
F P
s
P
p
.002 w
.54405 .55649 m .51669 .53023 L .52365 .52072 L p
1 g
F P
s
P
p
.002 w
.52365 .52072 m .55784 .53779 L .54405 .55649 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .49487 .54104 L .48237 .5412 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .50674 .53725 L .49487 .54104 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .48237 .5412 L .47058 .53771 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .51669 .53023 L .50674 .53725 L closepath p
1 g
F P
s
P
p
.002 w
.59467 .61263 m .57025 .58417 L .59056 .5568 L p
1 g
F P
s
P
p
.002 w
.55784 .53779 m .59056 .5568 L .57025 .58417 L p
1 g
F P
s
P
p
.002 w
.46007 .7247 m .46283 .68991 L .51875 .68912 L p
1 g
F P
s
P
p
.002 w
.51875 .68912 m .52391 .72377 L .46007 .7247 L p
1 g
F P
s
P
p
.002 w
.52391 .72377 m .51875 .68912 L .57188 .67232 L p
1 g
F P
s
P
p
.002 w
.43377 .55791 m .46075 .53093 L .47058 .53771 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .47058 .53771 L .46075 .53093 L closepath p
1 g
F P
s
P
p
.002 w
.36548 .64465 m .38556 .61545 L .42248 .64047 L p
1 g
F P
s
P
p
.002 w
.42248 .64047 m .4099 .6746 L .36548 .64465 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .52365 .52072 L .51669 .53023 L closepath p
1 g
F P
s
P
p
.002 w
.38865 .5594 m .4203 .53953 L .43377 .55791 L p
1 g
F P
s
P
p
.002 w
.43377 .55791 m .40851 .5863 L .38865 .5594 L p
1 g
F P
s
P
p
.002 w
.46075 .53093 m .43377 .55791 L .4203 .53953 L p
1 g
F P
s
P
p
.002 w
.3996 .7073 m .4099 .6746 L .46283 .68991 L p
1 g
F P
s
P
p
.002 w
.46283 .68991 m .46007 .7247 L .3996 .7073 L p
1 g
F P
s
P
p
.002 w
.4203 .53953 m .45396 .52159 L .46075 .53093 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .46075 .53093 L .45396 .52159 L closepath p
1 g
F P
s
P
p
.002 w
.59056 .5568 m .55784 .53779 L .56429 .51616 L p
1 g
F P
s
P
p
.002 w
.55784 .53779 m .52365 .52072 L .52688 .50975 L p
1 g
F P
s
P
p
.002 w
.52688 .50975 m .56429 .51616 L .55784 .53779 L p
1 g
F P
s
P
p
.002 w
.57188 .67232 m .5846 .70464 L .52391 .72377 L p
1 g
F P
s
P
p
.002 w
.5846 .70464 m .57188 .67232 L .61673 .6412 L p
1 g
F P
s
P
p
.002 w
.59467 .61263 m .61673 .6412 L .57188 .67232 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .52688 .50975 L .52365 .52072 L closepath p
1 g
F P
s
P
p
.002 w
.61673 .6412 m .59467 .61263 L .62104 .57733 L p
1 g
F P
s
P
p
.002 w
.59056 .5568 m .62104 .57733 L .59467 .61263 L p
1 g
F P
s
P
p
.002 w
.35976 .58075 m .38865 .5594 L .40851 .5863 L p
1 g
F P
s
P
p
.002 w
.40851 .5863 m .38556 .61545 L .35976 .58075 L p
1 g
F P
s
P
p
.002 w
.41426 .51803 m .45094 .51069 L .45396 .52159 L p
1 g
F P
s
P
p
.002 w
.45396 .52159 m .4203 .53953 L .41426 .51803 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .45396 .52159 L .45094 .51069 L closepath p
1 g
F P
s
P
p
.002 w
.56429 .51616 m .52688 .50975 L .526 .4985 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .526 .4985 L .52688 .50975 L closepath p
1 g
F P
s
P
p
.002 w
.62104 .57733 m .59056 .5568 L .60014 .5251 L p
1 g
F P
s
P
p
.002 w
.56429 .51616 m .60014 .5251 L .59056 .5568 L p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .45715 .48896 L .46573 .4805 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .45204 .49941 L .45715 .48896 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .45094 .51069 L .45204 .49941 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .52109 .48818 L .526 .4985 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .51268 .47993 L .52109 .48818 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .50168 .47465 L .51268 .47993 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .48928 .47293 L .50168 .47465 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .47684 .47495 L .48928 .47293 L closepath p
1 g
F P
s
P
p
.002 w
.4888 .50601 m .46573 .4805 L .47684 .47495 L closepath p
1 g
F P
s
P
p
.002 w
.37965 .52787 m .41426 .51803 L .4203 .53953 L p
1 g
F P
s
P
p
.002 w
.4203 .53953 m .38865 .5594 L .37965 .52787 L p
1 g
F P
s
P
p
.002 w
.34879 .67322 m .36548 .64465 L .4099 .6746 L p
1 g
F P
s
P
p
.002 w
.4099 .6746 m .3996 .7073 L .34879 .67322 L p
1 g
F P
s
P
p
.002 w
.41635 .49572 m .45204 .49941 L .45094 .51069 L p
1 g
F P
s
P
p
.002 w
.45094 .51069 m .41426 .51803 L .41635 .49572 L p
1 g
F P
s
P
p
.002 w
.33435 .60306 m .35976 .58075 L .38556 .61545 L p
1 g
F P
s
P
p
.002 w
.38556 .61545 m .36548 .64465 L .33435 .60306 L p
1 g
F P
s
P
p
.002 w
.45832 .75682 m .46007 .7247 L .52391 .72377 L p
1 g
F P
s
P
p
.002 w
.52391 .72377 m .5285 .75577 L .45832 .75682 L p
1 g
F P
s
P
p
.002 w
.5285 .75577 m .52391 .72377 L .5846 .70464 L p
1 g
F P
s
P
p
.002 w
.60014 .5251 m .56429 .51616 L .56264 .49393 L p
1 g
F P
s
P
p
.002 w
.526 .4985 m .56264 .49393 L .56429 .51616 L p
1 g
F P
s
P
p
.002 w
.56264 .49393 m .526 .4985 L .52109 .48818 L p
1 g
F P
s
P
p
.002 w
.39184 .73778 m .3996 .7073 L .46007 .7247 L p
1 g
F P
s
P
p
.002 w
.46007 .7247 m .45832 .75682 L .39184 .73778 L p
1 g
F P
s
P
p
.002 w
.61673 .6412 m .63588 .66919 L .5846 .70464 L p
1 g
F P
s
P
p
.002 w
.63588 .66919 m .61673 .6412 L .64852 .59888 L p
1 g
F P
s
P
p
.002 w
.62104 .57733 m .64852 .59888 L .61673 .6412 L p
1 g
F P
s
P
p
.002 w
.4264 .47502 m .45715 .48896 L .45204 .49941 L p
1 g
F P
s
P
p
.002 w
.45204 .49941 m .41635 .49572 L .4264 .47502 L p
1 g
F P
s
P
p
.002 w
.34796 .53998 m .37965 .52787 L .38865 .5594 L p
1 g
F P
s
P
p
.002 w
.38865 .5594 m .35976 .58075 L .34796 .53998 L p
1 g
F P
s
P
p
.002 w
.52109 .48818 m .55301 .4735 L .56264 .49393 L p
1 g
F P
s
P
p
.002 w
.55301 .4735 m .52109 .48818 L .51268 .47993 L p
1 g
F P
s
P
p
.002 w
.5846 .70464 m .59521 .73479 L .5285 .75577 L p
1 g
F P
s
P
p
.002 w
.59521 .73479 m .5846 .70464 L .63588 .66919 L p
1 g
F P
s
P
p
.002 w
.64852 .59888 m .62104 .57733 L .63358 .53636 L p
1 g
F P
s
P
p
.002 w
.60014 .5251 m .63358 .53636 L .62104 .57733 L p
1 g
F P
s
P
p
.002 w
.3826 .49506 m .41635 .49572 L .41426 .51803 L p
1 g
F P
s
P
p
.002 w
.41426 .51803 m .37965 .52787 L .3826 .49506 L p
1 g
F P
s
P
p
.002 w
.44335 .45823 m .46573 .4805 L .45715 .48896 L p
1 g
F P
s
P
p
.002 w
.45715 .48896 m .4264 .47502 L .44335 .45823 L p
1 g
F P
s
P
p
.002 w
.63358 .53636 m .60014 .5251 L .59784 .49243 L p
1 g
F P
s
P
p
.002 w
.56264 .49393 m .59784 .49243 L .60014 .5251 L p
1 g
F P
s
P
p
.002 w
.51268 .47993 m .53642 .45712 L .55301 .4735 L p
1 g
F P
s
P
p
.002 w
.53642 .45712 m .51268 .47993 L .50168 .47465 L p
1 g
F P
s
P
p
.002 w
.59784 .49243 m .56264 .49393 L .55301 .4735 L p
1 g
F P
s
P
p
.002 w
.46538 .4472 m .47684 .47495 L .46573 .4805 L p
1 g
F P
s
P
p
.002 w
.46573 .4805 m .44335 .45823 L .46538 .4472 L p
1 g
F P
s
P
p
.002 w
.50168 .47465 m .51463 .44662 L .53642 .45712 L p
1 g
F P
s
P
p
.002 w
.51463 .44662 m .50168 .47465 L .48928 .47293 L p
1 g
F P
s
P
p
.002 w
.31308 .62582 m .33435 .60306 L .36548 .64465 L p
1 g
F P
s
P
p
.002 w
.36548 .64465 m .34879 .67322 L .31308 .62582 L p
1 g
F P
s
P
p
.002 w
.33593 .70044 m .34879 .67322 L .3996 .7073 L p
1 g
F P
s
P
p
.002 w
.3996 .7073 m .39184 .73778 L .33593 .70044 L p
1 g
F P
s
P
p
.002 w
.49005 .44318 m .48928 .47293 L .47684 .47495 L p
1 g
F P
s
P
p
.002 w
.47684 .47495 m .46538 .4472 L .49005 .44318 L p
1 g
F P
s
P
p
.002 w
.48928 .47293 m .49005 .44318 L .51463 .44662 L p
1 g
F P
s
P
p
.002 w
.3973 .46456 m .4264 .47502 L .41635 .49572 L p
1 g
F P
s
P
p
.002 w
.41635 .49572 m .3826 .49506 L .3973 .46456 L p
1 g
F P
s
P
p
.002 w
.32 .5541 m .34796 .53998 L .35976 .58075 L p
1 g
F P
s
P
p
.002 w
.35976 .58075 m .33435 .60306 L .32 .5541 L p
1 g
F P
s
P
p
.002 w
.35164 .49748 m .3826 .49506 L .37965 .52787 L p
1 g
F P
s
P
p
.002 w
.37965 .52787 m .34796 .53998 L .35164 .49748 L p
1 g
F P
s
P
p
.002 w
.45767 .78544 m .45832 .75682 L .5285 .75577 L p
1 g
F P
s
P
p
.002 w
.5285 .75577 m .53237 .78431 L .45767 .78544 L p
1 g
F P
s
P
p
.002 w
.53237 .78431 m .5285 .75577 L .59521 .73479 L p
1 g
F P
s
P
p
.002 w
.63588 .66919 m .65162 .69593 L .59521 .73479 L p
1 g
F P
s
P
p
.002 w
.65162 .69593 m .63588 .66919 L .67232 .62095 L p
1 g
F P
s
P
p
.002 w
.64852 .59888 m .67232 .62095 L .63588 .66919 L p
1 g
F P
s
P
p
.002 w
.55301 .4735 m .58379 .46234 L .59784 .49243 L p
1 g
F P
s
P
p
.002 w
.58379 .46234 m .55301 .4735 L .53642 .45712 L p
1 g
F P
s
P
p
.002 w
.67232 .62095 m .64852 .59888 L .66375 .5497 L p
1 g
F P
s
P
p
.002 w
.63358 .53636 m .66375 .5497 L .64852 .59888 L p
1 g
F P
s
P
p
.002 w
.38687 .76526 m .39184 .73778 L .45832 .75682 L p
1 g
F P
s
P
p
.002 w
.45832 .75682 m .45767 .78544 L .38687 .76526 L p
1 g
F P
s
P
p
.002 w
.66375 .5497 m .63358 .53636 L .63075 .49406 L p
1 g
F P
s
P
p
.002 w
.59784 .49243 m .63075 .49406 L .63358 .53636 L p
1 g
F P
s
P
p
.002 w
.63075 .49406 m .59784 .49243 L .58379 .46234 L p
1 g
F P
s
P
p
.002 w
.42223 .43977 m .44335 .45823 L .4264 .47502 L p
1 g
F P
s
P
p
.002 w
.4264 .47502 m .3973 .46456 L .42223 .43977 L p
1 g
F P
s
P
p
.002 w
.59521 .73479 m .60341 .76201 L .53237 .78431 L p
1 g
F P
s
P
p
.002 w
.60341 .76201 m .59521 .73479 L .65162 .69593 L p
1 g
F P
s
P
p
.002 w
.53642 .45712 m .55942 .43817 L .58379 .46234 L p
1 g
F P
s
P
p
.002 w
.55942 .43817 m .53642 .45712 L .51463 .44662 L p
1 g
F P
s
P
p
.002 w
.29655 .64845 m .31308 .62582 L .34879 .67322 L p
1 g
F P
s
P
p
.002 w
.34879 .67322 m .33593 .70044 L .29655 .64845 L p
1 g
F P
s
P
p
.002 w
.45469 .42348 m .46538 .4472 L .44335 .45823 L p
1 g
F P
s
P
p
.002 w
.44335 .45823 m .42223 .43977 L .45469 .42348 L p
1 g
F P
s
P
p
.002 w
.3706 .45789 m .3973 .46456 L .3826 .49506 L p
1 g
F P
s
P
p
.002 w
.3826 .49506 m .35164 .49748 L .3706 .45789 L p
1 g
F P
s
P
p
.002 w
.51463 .44662 m .52734 .42264 L .55942 .43817 L p
1 g
F P
s
P
p
.002 w
.52734 .42264 m .51463 .44662 L .49005 .44318 L p
1 g
F P
s
P
p
.002 w
.29653 .56992 m .32 .5541 L .33435 .60306 L p
1 g
F P
s
P
p
.002 w
.33435 .60306 m .31308 .62582 L .29653 .56992 L p
1 g
F P
s
P
p
.002 w
.32728 .72563 m .33593 .70044 L .39184 .73778 L p
1 g
F P
s
P
p
.002 w
.39184 .73778 m .38687 .76526 L .32728 .72563 L p
1 g
F P
s
P
p
.002 w
.32429 .50297 m .35164 .49748 L .34796 .53998 L p
1 g
F P
s
P
p
.002 w
.34796 .53998 m .32 .5541 L .32429 .50297 L p
1 g
F P
s
P
p
.002 w
.49108 .41755 m .49005 .44318 L .46538 .4472 L p
1 g
F P
s
P
p
.002 w
.46538 .4472 m .45469 .42348 L .49108 .41755 L p
1 g
F P
s
P
p
.002 w
.49005 .44318 m .49108 .41755 L .52734 .42264 L p
1 g
F P
s
P
p
.002 w
.58379 .46234 m .61267 .45503 L .63075 .49406 L p
1 g
F P
s
P
p
.002 w
.61267 .45503 m .58379 .46234 L .55942 .43817 L p
1 g
F P
s
P
p
.002 w
.67232 .62095 m .6918 .643 L .65162 .69593 L p
1 g
F P
s
P
p
.002 w
.6918 .643 m .67232 .62095 L .68989 .56482 L p
1 g
F P
s
P
p
.002 w
.66375 .5497 m .68989 .56482 L .67232 .62095 L p
1 g
F P
s
P
p
.002 w
.65162 .69593 m .66352 .72073 L .60341 .76201 L p
1 g
F P
s
P
p
.002 w
.66352 .72073 m .65162 .69593 L .6918 .643 L p
1 g
F P
s
P
p
.002 w
.68989 .56482 m .66375 .5497 L .66052 .49883 L p
1 g
F P
s
P
p
.002 w
.63075 .49406 m .66052 .49883 L .66375 .5497 L p
1 g
F P
s
P
p
.002 w
.45812 .80981 m .45767 .78544 L .53237 .78431 L p
1 g
F P
s
P
p
.002 w
.53237 .78431 m .53544 .80862 L .45812 .80981 L p
1 g
F P
s
P
p
.002 w
.53544 .80862 m .53237 .78431 L .60341 .76201 L p
1 g
F P
s
P
p
.002 w
.66052 .49883 m .63075 .49406 L .61267 .45503 L p
1 g
F P
s
P
p
.002 w
.38485 .789 m .38687 .76526 L .45767 .78544 L p
1 g
F P
s
P
p
.002 w
.45767 .78544 m .45812 .80981 L .38485 .789 L p
1 g
F P
s
P
p
.002 w
.40291 .42566 m .42223 .43977 L .3973 .46456 L p
1 g
F P
s
P
p
.002 w
.3973 .46456 m .3706 .45789 L .40291 .42566 L p
1 g
F P
s
P
p
.002 w
.60341 .76201 m .60897 .78559 L .53544 .80862 L p
1 g
F P
s
P
p
.002 w
.60897 .78559 m .60341 .76201 L .66352 .72073 L p
1 g
F P
s
P
p
.002 w
.55942 .43817 m .58112 .42361 L .61267 .45503 L p
1 g
F P
s
P
p
.002 w
.58112 .42361 m .55942 .43817 L .52734 .42264 L p
1 g
F P
s
P
p
.002 w
.28526 .67039 m .29655 .64845 L .33593 .70044 L p
1 g
F P
s
P
p
.002 w
.33593 .70044 m .32728 .72563 L .28526 .67039 L p
1 g
F P
s
P
p
.002 w
.34702 .45525 m .3706 .45789 L .35164 .49748 L p
1 g
F P
s
P
p
.002 w
.35164 .49748 m .32429 .50297 L .34702 .45525 L p
1 g
F P
s
P
p
.002 w
.27821 .58706 m .29653 .56992 L .31308 .62582 L p
1 g
F P
s
P
p
.002 w
.31308 .62582 m .29655 .64845 L .27821 .58706 L p
1 g
F P
s
P
p
.002 w
.44507 .40446 m .45469 .42348 L .42223 .43977 L p
1 g
F P
s
P
p
.002 w
.42223 .43977 m .40291 .42566 L .44507 .40446 L p
1 g
F P
s
P
p
.002 w
.30129 .51144 m .32429 .50297 L .32 .5541 L p
1 g
F P
s
P
p
.002 w
.32 .5541 m .29653 .56992 L .30129 .51144 L p
1 g
F P
s
P
p
.002 w
.32314 .7481 m .32728 .72563 L .38687 .76526 L p
1 g
F P
s
P
p
.002 w
.38687 .76526 m .38485 .789 L .32314 .7481 L p
1 g
F P
s
P
p
.002 w
.52734 .42264 m .53949 .40339 L .58112 .42361 L p
1 g
F P
s
P
p
.002 w
.53949 .40339 m .52734 .42264 L .49108 .41755 L p
1 g
F P
s
P
p
.002 w
.61267 .45503 m .63888 .4518 L .66052 .49883 L p
1 g
F P
s
P
p
.002 w
.63888 .4518 m .61267 .45503 L .58112 .42361 L p
1 g
F P
s
P
p
.002 w
.49237 .39675 m .49108 .41755 L .45469 .42348 L p
1 g
F P
s
P
p
.002 w
.45469 .42348 m .44507 .40446 L .49237 .39675 L p
1 g
F P
s
P
p
.002 w
.6918 .643 m .70639 .66449 L .66352 .72073 L p
1 g
F P
s
P
p
.002 w
.70639 .66449 m .6918 .643 L .71126 .58137 L p
1 g
F P
s
P
p
.002 w
.68989 .56482 m .71126 .58137 L .6918 .643 L p
1 g
F P
s
P
p
.002 w
.49108 .41755 m .49237 .39675 L .53949 .40339 L p
1 g
F P
s
P
p
.002 w
.71126 .58137 m .68989 .56482 L .68635 .50667 L p
1 g
F P
s
P
p
.002 w
.66052 .49883 m .68635 .50667 L .68989 .56482 L p
1 g
F P
s
P
p
.002 w
.68635 .50667 m .66052 .49883 L .63888 .4518 L p
1 g
F P
s
P
p
.002 w
.66352 .72073 m .67121 .74295 L .60897 .78559 L p
1 g
F P
s
P
p
.002 w
.67121 .74295 m .66352 .72073 L .70639 .66449 L p
1 g
F P
s
P
p
.002 w
.45971 .82923 m .45812 .80981 L .53544 .80862 L p
1 g
F P
s
P
p
.002 w
.53544 .80862 m .5376 .82802 L .45971 .82923 L p
1 g
F P
s
P
p
.002 w
.5376 .82802 m .53544 .80862 L .60897 .78559 L p
1 g
F P
s
P
p
.002 w
.38592 .41634 m .40291 .42566 L .3706 .45789 L p
1 g
F P
s
P
p
.002 w
.3706 .45789 m .34702 .45525 L .38592 .41634 L p
1 g
F P
s
P
p
.002 w
.38589 .80833 m .38485 .789 L .45812 .80981 L p
1 g
F P
s
P
p
.002 w
.45812 .80981 m .45971 .82923 L .38589 .80833 L p
1 g
F P
s
P
p
.002 w
.58112 .42361 m .60095 .41389 L .63888 .4518 L p
1 g
F P
s
P
p
.002 w
.60095 .41389 m .58112 .42361 L .53949 .40339 L p
1 g
F P
s
P
p
.002 w
.60897 .78559 m .61168 .80484 L .5376 .82802 L p
1 g
F P
s
P
p
.002 w
.61168 .80484 m .60897 .78559 L .67121 .74295 L p
1 g
F P
s
P
p
.002 w
.32721 .45679 m .34702 .45525 L .32429 .50297 L p
1 g
F P
s
P
p
.002 w
.32429 .50297 m .30129 .51144 L .32721 .45679 L p
1 g
F P
s
P
p
.002 w
.26563 .6051 m .27821 .58706 L .29655 .64845 L p
1 g
F P
s
P
p
.002 w
.29655 .64845 m .28526 .67039 L .26563 .6051 L p
1 g
F P
s
P
p
.002 w
.27961 .69105 m .28526 .67039 L .32728 .72563 L p
1 g
F P
s
P
p
.002 w
.32728 .72563 m .32314 .7481 L .27961 .69105 L p
1 g
F P
s
P
p
.002 w
.28332 .52274 m .30129 .51144 L .29653 .56992 L p
1 g
F P
s
P
p
.002 w
.29653 .56992 m .27821 .58706 L .28332 .52274 L p
1 g
F P
s
P
p
.002 w
.43678 .39073 m .44507 .40446 L .40291 .42566 L p
1 g
F P
s
P
p
.002 w
.40291 .42566 m .38592 .41634 L .43678 .39073 L p
1 g
F P
s
P
p
.002 w
.32372 .76722 m .32314 .7481 L .38485 .789 L p
1 g
F P
s
P
p
.002 w
.38485 .789 m .38589 .80833 L .32372 .76722 L p
1 g
F P
s
P
p
.002 w
.63888 .4518 m .66172 .45284 L .68635 .50667 L p
1 g
F P
s
P
p
.002 w
.66172 .45284 m .63888 .4518 L .60095 .41389 L p
1 g
F P
s
P
p
.002 w
.53949 .40339 m .55076 .38946 L .60095 .41389 L p
1 g
F P
s
P
p
.002 w
.55076 .38946 m .53949 .40339 L .49237 .39675 L p
1 g
F P
s
P
p
.002 w
.70639 .66449 m .71565 .68486 L .67121 .74295 L p
1 g
F P
s
P
p
.002 w
.71565 .68486 m .70639 .66449 L .72724 .59895 L p
1 g
F P
s
P
p
.002 w
.71126 .58137 m .72724 .59895 L .70639 .66449 L p
1 g
F P
s
P
p
.002 w
.72724 .59895 m .71126 .58137 L .70752 .51744 L p
1 g
F P
s
P
p
.002 w
.68635 .50667 m .70752 .51744 L .71126 .58137 L p
1 g
F P
s
P
p
.002 w
.70752 .51744 m .68635 .50667 L .66172 .45284 L p
1 g
F P
s
P
p
.002 w
.49389 .38141 m .49237 .39675 L .44507 .40446 L p
1 g
F P
s
P
p
.002 w
.44507 .40446 m .43678 .39073 L .49389 .38141 L p
1 g
F P
s
P
p
.002 w
.49237 .39675 m .49389 .38141 L .55076 .38946 L p
1 g
F P
s
P
p
.002 w
.67121 .74295 m .67441 .76196 L .61168 .80484 L p
1 g
F P
s
P
p
.002 w
.67441 .76196 m .67121 .74295 L .71565 .68486 L p
1 g
F P
s
P
p
.002 w
.37175 .41217 m .38592 .41634 L .34702 .45525 L p
1 g
F P
s
P
p
.002 w
.34702 .45525 m .32721 .45679 L .37175 .41217 L p
1 g
F P
s
P
p
.002 w
.4624 .84309 m .45971 .82923 L .5376 .82802 L p
1 g
F P
s
P
p
.002 w
.5376 .82802 m .53878 .84188 L .4624 .84309 L p
1 g
F P
s
P
p
.002 w
.53878 .84188 m .5376 .82802 L .61168 .80484 L p
1 g
F P
s
P
p
.002 w
.39003 .82263 m .38589 .80833 L .45971 .82923 L p
1 g
F P
s
P
p
.002 w
.45971 .82923 m .4624 .84309 L .39003 .82263 L p
1 g
F P
s
P
p
.002 w
.60095 .41389 m .61834 .40936 L .66172 .45284 L p
1 g
F P
s
P
p
.002 w
.61834 .40936 m .60095 .41389 L .55076 .38946 L p
1 g
F P
s
P
p
.002 w
.25922 .62359 m .26563 .6051 L .28526 .67039 L p
1 g
F P
s
P
p
.002 w
.28526 .67039 m .27961 .69105 L .25922 .62359 L p
1 g
F P
s
P
p
.002 w
.3118 .46256 m .32721 .45679 L .30129 .51144 L p
1 g
F P
s
P
p
.002 w
.30129 .51144 m .28332 .52274 L .3118 .46256 L p
1 g
F P
s
P
p
.002 w
.61168 .80484 m .61142 .81919 L .53878 .84188 L p
1 g
F P
s
P
p
.002 w
.61142 .81919 m .61168 .80484 L .67441 .76196 L p
1 g
F P
s
P
p
.002 w
.27098 .53664 m .28332 .52274 L .27821 .58706 L p
1 g
F P
s
P
p
.002 w
.27821 .58706 m .26563 .6051 L .27098 .53664 L p
1 g
F P
s
P
p
.002 w
.27986 .70987 m .27961 .69105 L .32314 .7481 L p
1 g
F P
s
P
p
.002 w
.32314 .7481 m .32372 .76722 L .27986 .70987 L p
1 g
F P
s
P
p
.002 w
.43007 .38277 m .43678 .39073 L .38592 .41634 L p
1 g
F P
s
P
p
.002 w
.38592 .41634 m .37175 .41217 L .43007 .38277 L p
1 g
F P
s
P
p
.002 w
.66172 .45284 m .68051 .45818 L .70752 .51744 L p
1 g
F P
s
P
p
.002 w
.68051 .45818 m .66172 .45284 L .61834 .40936 L p
1 g
F P
s
P
p
.002 w
.32911 .78241 m .32372 .76722 L .38589 .80833 L p
1 g
F P
s
P
p
.002 w
.38589 .80833 m .39003 .82263 L .32911 .78241 L p
1 g
F P
s
P
p
.002 w
.72724 .59895 m .7373 .61713 L .71565 .68486 L p
1 g
F P
s
P
p
.002 w
.7373 .61713 m .72724 .59895 L .72337 .53092 L p
1 g
F P
s
P
p
.002 w
.70752 .51744 m .72337 .53092 L .72724 .59895 L p
1 g
F P
s
P
p
.002 w
.71565 .68486 m .7192 .70355 L .67441 .76196 L p
1 g
F P
s
P
p
.002 w
.7192 .70355 m .71565 .68486 L .7373 .61713 L p
1 g
F P
s
P
p
.002 w
.72337 .53092 m .70752 .51744 L .68051 .45818 L p
1 g
F P
s
P
p
.002 w
.55076 .38946 m .56083 .38132 L .61834 .40936 L p
1 g
F P
s
P
p
.002 w
.56083 .38132 m .55076 .38946 L .49389 .38141 L p
1 g
F P
s
P
p
.002 w
.4956 .37207 m .49389 .38141 L .43678 .39073 L p
1 g
F P
s
P
p
.002 w
.43678 .39073 m .43007 .38277 L .4956 .37207 L p
1 g
F P
s
P
p
.002 w
.67441 .76196 m .67293 .7772 L .61142 .81919 L p
1 g
F P
s
P
p
.002 w
.67293 .7772 m .67441 .76196 L .7192 .70355 L p
1 g
F P
s
P
p
.002 w
.49389 .38141 m .4956 .37207 L .56083 .38132 L p
1 g
F P
s
P
p
.002 w
.36085 .41337 m .37175 .41217 L .32721 .45679 L p
1 g
F P
s
P
p
.002 w
.32721 .45679 m .3118 .46256 L .36085 .41337 L p
1 g
F P
s
P
p
.002 w
.46617 .85088 m .4624 .84309 L .53878 .84188 L p
1 g
F P
s
P
p
.002 w
.53878 .84188 m .53893 .84973 L .46617 .85088 L p
1 g
F P
s
P
p
.002 w
.53893 .84973 m .53878 .84188 L .61142 .81919 L p
1 g
F P
s
P
p
.002 w
.25932 .64204 m .25922 .62359 L .27961 .69105 L p
1 g
F P
s
P
p
.002 w
.27961 .69105 m .27986 .70987 L .25932 .64204 L p
1 g
F P
s
P
p
.002 w
.30128 .47251 m .3118 .46256 L .28332 .52274 L p
1 g
F P
s
P
p
.002 w
.28332 .52274 m .27098 .53664 L .30128 .47251 L p
1 g
F P
s
P
p
.002 w
.39724 .83142 m .39003 .82263 L .4624 .84309 L p
1 g
F P
s
P
p
.002 w
.4624 .84309 m .46617 .85088 L .39724 .83142 L p
1 g
F P
s
P
p
.002 w
.26473 .5528 m .27098 .53664 L .26563 .6051 L p
1 g
F P
s
P
p
.002 w
.26563 .6051 m .25922 .62359 L .26473 .5528 L p
1 g
F P
s
P
p
.002 w
.61834 .40936 m .63279 .41028 L .68051 .45818 L p
1 g
F P
s
P
p
.002 w
.63279 .41028 m .61834 .40936 L .56083 .38132 L p
1 g
F P
s
P
p
.002 w
.28615 .7263 m .27986 .70987 L .32372 .76722 L p
1 g
F P
s
P
p
.002 w
.32372 .76722 m .32911 .78241 L .28615 .7263 L p
1 g
F P
s
P
p
.002 w
.61142 .81919 m .60813 .82812 L .53893 .84973 L p
1 g
F P
s
P
p
.002 w
.60813 .82812 m .61142 .81919 L .67293 .7772 L p
1 g
F P
s
P
p
.002 w
.68051 .45818 m .69468 .46779 L .72337 .53092 L p
1 g
F P
s
P
p
.002 w
.69468 .46779 m .68051 .45818 L .63279 .41028 L p
1 g
F P
s
P
p
.002 w
.42516 .38094 m .43007 .38277 L .37175 .41217 L p
1 g
F P
s
P
p
.002 w
.37175 .41217 m .36085 .41337 L .42516 .38094 L p
1 g
F P
s
P
p
.002 w
.7373 .61713 m .74104 .63544 L .7192 .70355 L p
1 g
F P
s
P
p
.002 w
.74104 .63544 m .7373 .61713 L .73338 .5468 L p
1 g
F P
s
P
p
.002 w
.72337 .53092 m .73338 .5468 L .7373 .61713 L p
1 g
F P
s
P
p
.002 w
.73338 .5468 m .72337 .53092 L .69468 .46779 L p
1 g
F P
s
P
p
.002 w
.7192 .70355 m .71683 .72002 L .67293 .7772 L p
1 g
F P
s
P
p
.002 w
.71683 .72002 m .7192 .70355 L .74104 .63544 L p
1 g
F P
s
P
p
.002 w
.33927 .79316 m .32911 .78241 L .39003 .82263 L p
1 g
F P
s
P
p
.002 w
.39003 .82263 m .39724 .83142 L .33927 .79316 L p
1 g
F P
s
P
p
.002 w
.56083 .38132 m .56941 .37935 L .63279 .41028 L p
1 g
F P
s
P
p
.002 w
.56941 .37935 m .56083 .38132 L .4956 .37207 L p
1 g
F P
s
P
p
.002 w
.67293 .7772 m .66669 .78817 L .60813 .82812 L p
1 g
F P
s
P
p
.002 w
.66669 .78817 m .67293 .7772 L .71683 .72002 L p
1 g
F P
s
P
p
.002 w
.49745 .36914 m .4956 .37207 L .43007 .38277 L p
1 g
F P
s
P
p
.002 w
.43007 .38277 m .42516 .38094 L .49745 .36914 L p
1 g
F P
s
P
p
.002 w
.4956 .37207 m .49745 .36914 L .56941 .37935 L p
1 g
F P
s
P
p
.002 w
.35359 .42005 m .36085 .41337 L .3118 .46256 L p
1 g
F P
s
P
p
.002 w
.3118 .46256 m .30128 .47251 L .35359 .42005 L p
1 g
F P
s
P
p
.002 w
.26607 .65994 m .25932 .64204 L .27986 .70987 L p
1 g
F P
s
P
p
.002 w
.27986 .70987 m .28615 .7263 L .26607 .65994 L p
1 g
F P
s
P
p
.002 w
.29608 .48646 m .30128 .47251 L .27098 .53664 L p
1 g
F P
s
P
p
.002 w
.27098 .53664 m .26473 .5528 L .29608 .48646 L p
1 g
F P
s
P
p
.002 w
.26487 .57085 m .26473 .5528 L .25922 .62359 L p
1 g
F P
s
P
p
.002 w
.25922 .62359 m .25932 .64204 L .26487 .57085 L p
1 g
F P
s
P
p
.002 w
.47093 .85224 m .46617 .85088 L .53893 .84973 L p
1 g
F P
s
P
p
.002 w
.53893 .84973 m .53801 .85118 L .47093 .85224 L p
1 g
F P
s
P
p
.002 w
.53801 .85118 m .53893 .84973 L .60813 .82812 L p
1 g
F P
s
P
p
.002 w
.63279 .41028 m .64383 .41673 L .69468 .46779 L p
1 g
F P
s
P
p
.002 w
.64383 .41673 m .63279 .41028 L .56941 .37935 L p
1 g
F P
s
P
p
.002 w
.40741 .83431 m .39724 .83142 L .46617 .85088 L p
1 g
F P
s
P
p
.002 w
.46617 .85088 m .47093 .85224 L .40741 .83431 L p
1 g
F P
s
P
p
.002 w
.29844 .73981 m .28615 .7263 L .32911 .78241 L p
1 g
F P
s
P
p
.002 w
.32911 .78241 m .33927 .79316 L .29844 .73981 L p
1 g
F P
s
P
p
.002 w
.60813 .82812 m .60181 .83126 L .53801 .85118 L p
1 g
F P
s
P
p
.002 w
.60181 .83126 m .60813 .82812 L .66669 .78817 L p
1 g
F P
s
P
p
.002 w
.69468 .46779 m .70372 .48152 L .73338 .5468 L p
1 g
F P
s
P
p
.002 w
.70372 .48152 m .69468 .46779 L .64383 .41673 L p
1 g
F P
s
P
p
.002 w
.74104 .63544 m .73822 .65338 L .71683 .72002 L p
1 g
F P
s
P
p
.002 w
.73338 .5468 m .73712 .56472 L .74104 .63544 L p
1 g
F P
s
P
p
.002 w
.73822 .65338 m .74104 .63544 L .73712 .56472 L p
1 g
F P
s
P
p
.002 w
.73712 .56472 m .73338 .5468 L .70372 .48152 L p
1 g
F P
s
P
p
.002 w
.71683 .72002 m .70845 .73378 L .66669 .78817 L p
1 g
F P
s
P
p
.002 w
.70845 .73378 m .71683 .72002 L .73822 .65338 L p
1 g
F P
s
P
p
.002 w
.42223 .38545 m .42516 .38094 L .36085 .41337 L p
1 g
F P
s
P
p
.002 w
.36085 .41337 m .35359 .42005 L .42223 .38545 L p
1 g
F P
s
P
p
.002 w
.35403 .79907 m .33927 .79316 L .39724 .83142 L p
1 g
F P
s
P
p
.002 w
.39724 .83142 m .40741 .83431 L .35403 .79907 L p
1 g
F P
s
P
p
.002 w
.56941 .37935 m .57622 .38374 L .64383 .41673 L p
1 g
F P
s
P
p
.002 w
.57622 .38374 m .56941 .37935 L .49745 .36914 L p
1 g
F P
s
P
p
.002 w
.66669 .78817 m .65576 .79445 L .60181 .83126 L p
1 g
F P
s
P
p
.002 w
.65576 .79445 m .66669 .78817 L .70845 .73378 L p
1 g
F P
s
P
p
.002 w
.49941 .37285 m .49745 .36914 L .42516 .38094 L p
1 g
F P
s
P
p
.002 w
.42516 .38094 m .42223 .38545 L .49941 .37285 L p
1 g
F P
s
P
p
.002 w
.49745 .36914 m .49941 .37285 L .57622 .38374 L p
1 g
F P
s
P
p
.002 w
.35027 .43216 m .35359 .42005 L .30128 .47251 L p
1 g
F P
s
P
p
.002 w
.30128 .47251 m .29608 .48646 L .35027 .43216 L p
1 g
F P
s
P
p
.002 w
.27942 .67677 m .26607 .65994 L .28615 .7263 L p
1 g
F P
s
P
p
.002 w
.28615 .7263 m .29844 .73981 L .27942 .67677 L p
1 g
F P
s
P
p
.002 w
.27155 .59031 m .26487 .57085 L .25932 .64204 L p
1 g
F P
s
P
p
.002 w
.25932 .64204 m .26607 .65994 L .27155 .59031 L p
1 g
F P
s
P
p
.002 w
.29647 .50412 m .29608 .48646 L .26473 .5528 L p
1 g
F P
s
P
p
.002 w
.26473 .5528 m .26487 .57085 L .29647 .50412 L p
1 g
F P
s
P
p
.002 w
.47657 .84698 m .47093 .85224 L .53801 .85118 L p
1 g
F P
s
P
p
.002 w
.53801 .85118 m .53603 .84604 L .47657 .84698 L p
1 g
F P
s
P
p
.002 w
.53603 .84604 m .53801 .85118 L .60181 .83126 L p
1 g
F P
s
P
p
.002 w
.64383 .41673 m .65108 .42868 L .70372 .48152 L p
1 g
F P
s
P
p
.002 w
.65108 .42868 m .64383 .41673 L .57622 .38374 L p
1 g
F P
s
P
p
.002 w
.31652 .74998 m .29844 .73981 L .33927 .79316 L p
1 g
F P
s
P
p
.002 w
.33927 .79316 m .35403 .79907 L .31652 .74998 L p
1 g
F P
s
P
p
.002 w
.4203 .83107 m .40741 .83431 L .47093 .85224 L p
1 g
F P
s
P
p
.002 w
.47093 .85224 m .47657 .84698 L .4203 .83107 L p
1 g
F P
s
P
p
.002 w
.60181 .83126 m .59256 .82838 L .53603 .84604 L p
1 g
F P
s
P
p
.002 w
.59256 .82838 m .60181 .83126 L .65576 .79445 L p
1 g
F P
s
P
p
.002 w
.73822 .65338 m .72876 .67045 L .70845 .73378 L p
1 g
F P
s
P
p
.002 w
.72876 .67045 m .73822 .65338 L .73435 .58421 L p
1 g
F P
s
P
p
.002 w
.73712 .56472 m .73435 .58421 L .73822 .65338 L p
1 g
F P
s
P
p
.002 w
.70372 .48152 m .70726 .49906 L .73712 .56472 L p
1 g
F P
s
P
p
.002 w
.70726 .49906 m .70372 .48152 L .65108 .42868 L p
1 g
F P
s
P
p
.002 w
.73435 .58421 m .73712 .56472 L .70726 .49906 L p
1 g
F P
s
P
p
.002 w
.70845 .73378 m .69418 .74438 L .65576 .79445 L p
1 g
F P
s
P
p
.002 w
.69418 .74438 m .70845 .73378 L .72876 .67045 L p
1 g
F P
s
P
p
.002 w
.42141 .39633 m .42223 .38545 L .35359 .42005 L p
1 g
F P
s
P
p
.002 w
.35359 .42005 m .35027 .43216 L .42141 .39633 L p
1 g
F P
s
P
p
.002 w
.37309 .79985 m .35403 .79907 L .40741 .83431 L p
1 g
F P
s
P
p
.002 w
.40741 .83431 m .4203 .83107 L .37309 .79985 L p
1 g
F P
s
P
p
.002 w
.57622 .38374 m .58103 .39454 L .65108 .42868 L p
1 g
F P
s
P
p
.002 w
.58103 .39454 m .57622 .38374 L .49941 .37285 L p
1 g
F P
s
P
p
.002 w
.65576 .79445 m .64032 .79576 L .59256 .82838 L p
1 g
F P
s
P
p
.002 w
.64032 .79576 m .65576 .79445 L .69418 .74438 L p
1 g
F P
s
P
p
.002 w
.35108 .44949 m .35027 .43216 L .29608 .48646 L p
1 g
F P
s
P
p
.002 w
.29608 .48646 m .29647 .50412 L .35108 .44949 L p
1 g
F P
s
P
p
.002 w
.50142 .38328 m .49941 .37285 L .42223 .38545 L p
1 g
F P
s
P
p
.002 w
.42223 .38545 m .42141 .39633 L .50142 .38328 L p
1 g
F P
s
P
p
.002 w
.49941 .37285 m .50142 .38328 L .58103 .39454 L p
1 g
F P
s
P
p
.002 w
.28473 .61065 m .27155 .59031 L .26607 .65994 L p
1 g
F P
s
P
p
.002 w
.26607 .65994 m .27942 .67677 L .28473 .61065 L p
1 g
F P
s
P
p
.002 w
.29913 .69201 m .27942 .67677 L .29844 .73981 L p
1 g
F P
s
P
p
.002 w
.29844 .73981 m .31652 .74998 L .29913 .69201 L p
1 g
F P
s
P
p
.002 w
.30256 .52505 m .29647 .50412 L .26487 .57085 L p
1 g
F P
s
P
p
.002 w
.26487 .57085 m .27155 .59031 L .30256 .52505 L p
1 g
F P
s
P
p
.002 w
.34 .75641 m .31652 .74998 L .35403 .79907 L p
1 g
F P
s
P
p
.002 w
.35403 .79907 m .37309 .79985 L .34 .75641 L p
1 g
F P
s
P
p
.002 w
.65108 .42868 m .65423 .44593 L .70726 .49906 L p
1 g
F P
s
P
p
.002 w
.65423 .44593 m .65108 .42868 L .58103 .39454 L p
1 g
F P
s
P
p
.002 w
.48296 .83506 m .47657 .84698 L .53603 .84604 L p
1 g
F P
s
P
p
.002 w
.53603 .84604 m .533 .83428 L .48296 .83506 L p
1 g
F P
s
P
p
.002 w
.533 .83428 m .53603 .84604 L .59256 .82838 L p
1 g
F P
s
P
p
.002 w
.43564 .82166 m .4203 .83107 L .47657 .84698 L p
1 g
F P
s
P
p
.002 w
.47657 .84698 m .48296 .83506 L .43564 .82166 L p
1 g
F P
s
P
p
.002 w
.72876 .67045 m .71279 .68613 L .69418 .74438 L p
1 g
F P
s
P
p
.002 w
.71279 .68613 m .72876 .67045 L .72501 .60476 L p
1 g
F P
s
P
p
.002 w
.73435 .58421 m .72501 .60476 L .72876 .67045 L p
1 g
F P
s
P
p
.002 w
.72501 .60476 m .73435 .58421 L .70507 .52002 L p
1 g
F P
s
P
p
.002 w
.70726 .49906 m .70507 .52002 L .73435 .58421 L p
1 g
F P
s
P
p
.002 w
.70507 .52002 m .70726 .49906 L .65423 .44593 L p
1 g
F P
s
P
p
.002 w
.59256 .82838 m .58057 .8194 L .533 .83428 L p
1 g
F P
s
P
p
.002 w
.58057 .8194 m .59256 .82838 L .64032 .79576 L p
1 g
F P
s
P
p
.002 w
.69418 .74438 m .67426 .75144 L .64032 .79576 L p
1 g
F P
s
P
p
.002 w
.67426 .75144 m .69418 .74438 L .71279 .68613 L p
1 g
F P
s
P
p
.002 w
.42278 .41343 m .42141 .39633 L .35027 .43216 L p
1 g
F P
s
P
p
.002 w
.35027 .43216 m .35108 .44949 L .42278 .41343 L p
1 g
F P
s
P
p
.002 w
.396 .79538 m .37309 .79985 L .4203 .83107 L p
1 g
F P
s
P
p
.002 w
.4203 .83107 m .43564 .82166 L .396 .79538 L p
1 g
F P
s
P
p
.002 w
.58103 .39454 m .58365 .4116 L .65423 .44593 L p
1 g
F P
s
P
p
.002 w
.58365 .4116 m .58103 .39454 L .50142 .38328 L p
1 g
F P
s
P
p
.002 w
.64032 .79576 m .62072 .79194 L .58057 .8194 L p
1 g
F P
s
P
p
.002 w
.62072 .79194 m .64032 .79576 L .67426 .75144 L p
1 g
F P
s
P
p
.002 w
.3561 .47164 m .35108 .44949 L .29647 .50412 L p
1 g
F P
s
P
p
.002 w
.29647 .50412 m .30256 .52505 L .3561 .47164 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.30415 .6313 m .28473 .61065 L .27942 .67677 L p
1 g
F P
s
P
p
.002 w
.27942 .67677 m .29913 .69201 L .30415 .6313 L p
1 g
F P
s
P
p
.002 w
.32476 .7052 m .29913 .69201 L .31652 .74998 L p
1 g
F P
s
P
p
.002 w
.31652 .74998 m .34 .75641 L .32476 .7052 L p
1 g
F P
s
P
p
.002 w
.31431 .54873 m .30256 .52505 L .27155 .59031 L p
1 g
F P
s
P
p
.002 w
.27155 .59031 m .28473 .61065 L .31431 .54873 L p
1 g
F P
s
P
p
.002 w
.50342 .40028 m .50142 .38328 L .42141 .39633 L p
1 g
F P
s
P
p
.002 w
.42141 .39633 m .42278 .41343 L .50342 .40028 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.50142 .38328 m .50342 .40028 L .58365 .4116 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.36829 .75886 m .34 .75641 L .37309 .79985 L p
1 g
F P
s
P
p
.002 w
.37309 .79985 m .396 .79538 L .36829 .75886 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.65423 .44593 m .65311 .46809 L .70507 .52002 L p
1 g
F P
s
P
p
.002 w
.65311 .46809 m .65423 .44593 L .58365 .4116 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.71279 .68613 m .69062 .69995 L .67426 .75144 L p
1 g
F P
s
P
p
.002 w
.69062 .69995 m .71279 .68613 L .70923 .62579 L p
1 g
F P
s
P
p
.002 w
.72501 .60476 m .70923 .62579 L .71279 .68613 L p
1 g
F P
s
P
p
.002 w
.70923 .62579 m .72501 .60476 L .6971 .54385 L p
1 g
F P
s
P
p
.002 w
.70507 .52002 m .6971 .54385 L .72501 .60476 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51254 .83072 L p
1 g
F P
s
P
p
.002 w
.48864 .83497 m .51424 .83457 L p
.5 .83295 L 1 g
F P
s
P
p
.53597 .82325 m .51254 .83072 L .52539 .82844 L 1 g
F
P
p
.002 w
.51254 .83072 m .51242 .82869 L p
.50246 .83105 L 1 g
F P
s
P
p
.002 w
.48742 .83152 m .48758 .82869 L p
.47637 .82886 L 1 g
F P
s
P
p
.002 w
.43564 .82166 m .48296 .83506 L p
.47659 .82892 L 1 g
F P
s
P
p
.002 w
.43951 .81821 m .43564 .82166 L p
.4684 .82747 L 1 g
F P
s
P
p
.47659 .82892 m .4637 .8252 L .4684 .82747 L 1 g
F
P
p
.4637 .8252 m .43951 .81821 L .4684 .82747 L 1 g
F
P
p
.002 w
.4637 .8252 m .46403 .82325 L p
.45583 .8214 L 1 g
F P
s
P
p
.47637 .82886 m .48443 .83119 L .48742 .83152 L 1 g
F
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .4637 .8252 L p
1 g
F P
s
P
p
.002 w
.4637 .8252 m .46305 .82905 L p
.47637 .82886 L 1 g
F P
s
P
p
.48758 .82869 m .4637 .8252 L .47637 .82886 L 1 g
F
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.48993 .81668 m .45301 .80619 L p
.47659 .82892 L 1 g
F P
s
P
p
.002 w
.48296 .83506 m .48443 .83119 L p
.47659 .82892 L 1 g
F P
s
P
p
.002 w
.48443 .83119 m .48993 .81668 L p
.47659 .82892 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44356 .81547 L p
1 g
F P
s
P
p
.46403 .82325 m .44356 .81547 L .45583 .8214 L 1 g
F
P
p
.002 w
.44305 .81506 m .44293 .81516 L p
.44344 .81537 L 1 g
F P
s
P
p
.002 w
.44293 .81516 m .43951 .81821 L p
.4637 .8252 L 1 g
F P
s
P
p
.002 w
.44356 .81547 m .44427 .81291 L p
.43764 .80912 L 1 g
F P
s
P
p
.002 w
.43564 .82166 m .43841 .81919 L p
.42626 .79663 L 1 g
F P
s
P
p
.002 w
.43841 .81919 m .44305 .81506 L p
.42977 .80048 L 1 g
F P
s
P
p
.43841 .81919 m .42977 .80048 L .42626 .79663 L 1 g
F
P
p
.002 w
.42977 .80048 m .43042 .79874 L p
.42639 .79317 L 1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.40065 .75718 m .42214 .78565 L p
.42292 .78375 L 1 g
F P
s
P
p
.424 .78222 m .42386 .77601 L .42342 .7797 L 1 g
F
P
p
.002 w
.42668 .75289 m .40065 .75718 L p
.41798 .77785 L 1 g
F P
s
P
p
.42292 .78375 m .42499 .76676 L .41798 .77785 L 1 g
F
P
p
.42499 .76676 m .42668 .75289 L .41798 .77785 L 1 g
F
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .42579 .76511 L .42499 .76676 L p
1 g
F P
s
P
p
.002 w
.42499 .76676 m .42372 .76938 L p
.42386 .77601 L 1 g
F P
s
P
p
.424 .78222 m .42499 .76676 L .42386 .77601 L 1 g
F
P
p
.002 w
.42214 .78565 m .42273 .78535 L p
.42292 .78375 L 1 g
F P
s
P
p
.002 w
.42269 .78515 m .42277 .78497 L p
.42289 .7774 L 1 g
F P
s
P
p
.002 w
.42277 .78497 m .424 .78222 L p
.42342 .7797 L 1 g
F P
s
P
p
.42342 .7797 m .42289 .7774 L .42277 .78497 L 1 g
F
P
p
.002 w
.43042 .79874 m .424 .78222 L .42277 .78497 L p
1 g
F P
s
P
p
.002 w
.42273 .78535 m .42286 .78528 L p
.42277 .78497 L 1 g
F P
s
P
p
.43042 .79874 m .42277 .78497 L .42295 .78562 L 1 g
F
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.45081 .77088 m .42286 .78528 L p
.45301 .80619 L 1 g
F P
s
P
p
.002 w
.42286 .78528 m .42214 .78565 L .42326 .7864 L p
1 g
F P
s
P
p
.43042 .79874 m .42269 .78515 L .42639 .79317 L 1 g
F
P
p
.002 w
.42326 .7864 m .45301 .80619 L p
.42286 .78528 L 1 g
F P
s
P
p
.42295 .78562 m .42286 .78528 L .42269 .78515 L 1 g
F
P
p
.002 w
.42277 .78497 m .42276 .785 L p
.42286 .78528 L 1 g
F P
s
P
p
.002 w
.42276 .785 m .42269 .78515 L p
.42286 .78528 L 1 g
F P
s
P
p
.42277 .78497 m .45081 .77088 L .42292 .78375 L 1 g
F
P
p
.002 w
.42286 .78528 m .45081 .77088 L p
.42277 .78497 L 1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.45081 .77088 m .43615 .75133 L p
.42292 .78375 L 1 g
F P
s
P
p
.002 w
.42499 .76676 m .42579 .76511 L p
.42967 .75937 L 1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.43615 .75133 m .43459 .75159 L p
.42292 .78375 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43465 .7515 L p
1 g
F P
s
P
p
.002 w
.43459 .75159 m .43615 .75133 L .43594 .75059 L p
1 g
F P
s
P
p
.002 w
.43465 .7515 m .43569 .74928 L p
.44389 .7444 L 1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.4521 .738 m .45268 .73647 L p
.46473 .73364 L 1 g
F P
s
P
p
.002 w
.47375 .74147 m .51052 .72846 L p
.47894 .72942 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .5254 .72973 L p
1 g
F P
s
P
p
.5 .72527 m .5254 .72973 L .52183 .72946 L 1 g
F
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .5651 .75096 L p
1 g
F P
s
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.56355 .74984 m .54241 .75052 L .56937 .75786 L 1 g
F
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55625 .81481 L p
1 g
F P
s
P
p
.002 w
.53369 .83406 m .58057 .8194 L p
.55296 .81762 L 1 g
F P
s
P
p
.56958 .79874 m .55625 .81481 L .56328 .80882 L 1 g
F
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53637 .82563 L p
1 g
F P
s
P
p
.55573 .81291 m .53637 .82563 L .54878 .81888 L 1 g
F
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.58057 .8194 m .5693 .80772 L p
.55625 .81481 L 1 g
F P
s
P
p
.55296 .81762 m .55625 .81481 L .55129 .81751 L 1 g
F
P
p
.58057 .8194 m .55625 .81481 L .55296 .81762 L 1 g
F
P
p
.002 w
.58057 .8194 m .62072 .79194 L p
.56857 .80389 L 1 g
F P
s
P
p
.56958 .79874 m .56328 .80882 L .56716 .80551 L 1 g
F
P
p
.56958 .79874 m .56716 .80551 L .56852 .80395 L 1 g
F
P
p
.002 w
.56716 .80551 m .58057 .8194 L p
.56857 .80389 L 1 g
F P
s
P
p
.62072 .79194 m .57095 .80115 L .57062 .80153 L 1 g
F
P
p
.56965 .80364 m .57062 .80153 L .56857 .80389 L 1 g
F
P
p
.62072 .79194 m .57062 .80153 L .56965 .80364 L 1 g
F
P
p
.002 w
.576 .78222 m .56958 .79874 L .57062 .80153 L p
1 g
F P
s
P
p
.002 w
.62072 .79194 m .59743 .78299 L .57095 .80115 L p
1 g
F P
s
P
p
.576 .78222 m .57062 .80153 L .57072 .8013 L 1 g
F
P
p
.576 .78222 m .57072 .8013 L .57391 .79232 L 1 g
F
P
p
.57543 .79533 m .57319 .79434 L .57095 .80115 L 1 g
F
P
p
.002 w
.57062 .80153 m .56958 .79874 L p
.56852 .80395 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.57319 .79434 m .54962 .78383 L .57082 .80104 L 1 g
F
P
p
.57319 .79434 m .57082 .80104 L .57095 .80115 L 1 g
F
P
p
.002 w
.57072 .8013 m .57095 .80115 L p
.57082 .80104 L 1 g
F P
s
P
p
.56857 .80389 m .57062 .80153 L .56614 .80445 L 1 g
F
P
p
.002 w
.57095 .80115 m .57072 .8013 L p
.57062 .80153 L 1 g
F P
s
P
p
.002 w
.57072 .8013 m .56614 .80445 L p
.57062 .80153 L 1 g
F P
s
P
p
.002 w
.57095 .80115 m .57785 .79641 L p
.57543 .79533 L 1 g
F P
s
P
p
.57313 .79609 m .57072 .8013 L .5715 .8039 L 1 g
F
P
p
.002 w
.57062 .80153 m .57063 .80156 L p
.57072 .8013 L 1 g
F P
s
P
p
.002 w
.57063 .80156 m .5715 .8039 L p
.57072 .8013 L 1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57683 .78408 L p
1 g
F P
s
P
p
.57421 .76511 m .57683 .78408 L .57644 .77942 L 1 g
F
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.57683 .78408 m .576 .78222 L p
.57391 .79232 L 1 g
F P
s
P
p
.57677 .78335 m .54962 .78383 L .57319 .79434 L 1 g
F
P
p
.57683 .78408 m .57319 .79434 L .57785 .79641 L 1 g
F
P
p
.57677 .78335 m .57319 .79434 L .57683 .78408 L 1 g
F
P
p
.002 w
.57785 .79641 m .59743 .78299 L p
.57677 .78335 L 1 g
F P
s
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57683 .78408 L p
1 g
F P
s
P
p
.57391 .79232 m .5715 .8039 L .57683 .78408 L 1 g
F
P
p
.57391 .79232 m .57072 .8013 L .57313 .79609 L 1 g
F
P
p
.002 w
.54962 .78383 m .56614 .80445 L .57072 .8013 L p
1 g
F P
s
P
p
.57082 .80104 m .54962 .78383 L .57072 .8013 L 1 g
F
P
p
.002 w
.57063 .80156 m .57062 .80153 L p
.56842 .80444 L 1 g
F P
s
P
p
.56852 .80395 m .56842 .80444 L .57062 .80153 L 1 g
F
P
p
.002 w
.56614 .80445 m .56716 .80551 L p
.56857 .80389 L 1 g
F P
s
P
p
.56852 .80395 m .56716 .80551 L .56842 .80444 L 1 g
F
P
p
.002 w
.57091 .80231 m .57063 .80156 L p
.56842 .80444 L 1 g
F P
s
P
p
.002 w
.55625 .81481 m .55573 .81291 L p
.54878 .81888 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48742 .83152 L p
1 g
F P
s
P
p
.50322 .83238 m .5021 .83106 L .48898 .83147 L 1 g
F
P
p
.51242 .82869 m .48742 .83152 L .50246 .83105 L 1 g
F
P
p
.52074 .82927 m .48993 .81668 L .50322 .83238 L 1 g
F
P
p
.002 w
.48296 .83506 m .48864 .83497 L p
.48742 .83152 L 1 g
F P
s
P
p
.5 .83295 m .48742 .83152 L .48864 .83497 L 1 g
F
P
p
.002 w
.51424 .83457 m .533 .83428 L p
.48443 .83119 L 1 g
F P
s
P
p
.002 w
.48742 .83152 m .48724 .83464 L p
.50246 .83105 L 1 g
F P
s
P
p
.002 w
.48993 .81668 m .48443 .83119 L p
.48898 .83147 L 1 g
F P
s
P
p
.5021 .83106 m .48993 .81668 L .48898 .83147 L 1 g
F
P
p
.533 .83428 m .52074 .82927 L .50322 .83238 L 1 g
F
P
p
.002 w
.53637 .82563 m .53597 .82325 L p
.52539 .82844 L 1 g
F P
s
P
p
.52539 .82844 m .53148 .82736 L .53637 .82563 L 1 g
F
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.529 .81607 m .48993 .81668 L p
.52074 .82927 L 1 g
F P
s
P
p
.002 w
.533 .83428 m .53148 .82736 L p
.52074 .82927 L 1 g
F P
s
P
p
.002 w
.53148 .82736 m .529 .81607 L p
.52074 .82927 L 1 g
F P
s
P
p
.54865 .8213 m .53191 .82721 L .53369 .83406 L 1 g
F
P
p
.002 w
.529 .81607 m .533 .83428 L .53369 .83406 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53651 .82646 L p
1 g
F P
s
P
p
.002 w
.53651 .82646 m .53637 .82563 L p
.53217 .82724 L 1 g
F P
s
P
p
.53217 .82724 m .51276 .83464 L .53651 .82646 L 1 g
F
P
p
.52539 .82844 m .51764 .83225 L .53148 .82736 L 1 g
F
P
p
.55296 .81762 m .529 .81607 L .53191 .82721 L 1 g
F
P
p
.55296 .81762 m .53191 .82721 L .54865 .8213 L 1 g
F
P
p
.51764 .83225 m .51276 .83464 L .53637 .82563 L 1 g
F
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55625 .81481 L p
1 g
F P
s
P
p
.54878 .81888 m .53695 .82905 L .55625 .81481 L 1 g
F
P
p
.002 w
.5693 .80772 m .56614 .80445 L p
.55129 .81751 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57091 .80231 L p
1 g
F P
s
P
p
.56328 .80882 m .55726 .81844 L .57091 .80231 L 1 g
F
P
p
.002 w
.56614 .80445 m .529 .81607 L p
.55129 .81751 L 1 g
F P
s
P
p
.002 w
.53637 .82563 m .53695 .82905 L p
.54878 .81888 L 1 g
F P
s
P
p
.002 w
.55625 .81481 m .55726 .81844 L p
.56328 .80882 L 1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.57108 .76907 m .54962 .78383 L p
.57677 .78335 L 1 g
F P
s
P
p
.002 w
.59743 .78299 m .57579 .77156 L p
.57677 .78335 L 1 g
F P
s
P
p
.57421 .76511 m .57644 .77942 L .57616 .77604 L 1 g
F
P
p
.5755 .76769 m .57535 .76774 L .57911 .77332 L 1 g
F
P
p
.002 w
.57579 .77156 m .57911 .77332 L p
.57535 .76774 L 1 g
F P
s
P
p
.61954 .75392 m .57493 .76399 L .57531 .76739 L 1 g
F
P
p
.5755 .76769 m .57531 .76739 L .57535 .76774 L 1 g
F
P
p
.61954 .75392 m .57531 .76739 L .5755 .76769 L 1 g
F
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57531 .76739 L p
1 g
F P
s
P
p
.002 w
.57531 .76739 m .57421 .76511 L p
.57655 .7782 L 1 g
F P
s
P
p
.57655 .7782 m .57811 .78694 L .57531 .76739 L 1 g
F
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57531 .76739 L p
1 g
F P
s
P
p
.56431 .74928 m .57531 .76739 L .57456 .76621 L 1 g
F
P
p
.57535 .76774 m .57531 .76739 L .57108 .76907 L 1 g
F
P
p
.56431 .74928 m .57456 .76621 L .57074 .76007 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.57493 .76399 m .57395 .76527 L p
.57531 .76739 L 1 g
F P
s
P
p
.002 w
.57395 .76527 m .57108 .76907 L p
.57531 .76739 L 1 g
F P
s
P
p
.57456 .76621 m .57549 .76774 L .57395 .76527 L 1 g
F
P
p
.57456 .76621 m .57395 .76527 L .57074 .76007 L 1 g
F
P
p
.002 w
.57108 .76907 m .57579 .77156 L p
.57535 .76774 L 1 g
F P
s
P
p
.002 w
.54241 .75052 m .57108 .76907 L .57395 .76527 L p
1 g
F P
s
P
p
.002 w
.5651 .75096 m .56431 .74928 L p
.57074 .76007 L 1 g
F P
s
P
p
.002 w
.57395 .76527 m .57782 .76016 L p
.56937 .75786 L 1 g
F P
s
P
p
.56937 .75786 m .54241 .75052 L .57395 .76527 L 1 g
F
P
p
.56355 .74984 m .56937 .75786 L .5651 .75096 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .5651 .75096 L p
1 g
F P
s
P
p
.57074 .76007 m .57628 .76938 L .5651 .75096 L 1 g
F
P
p
.002 w
.57549 .76774 m .57628 .76938 L p
.57224 .7626 L 1 g
F P
s
P
p
.57074 .76007 m .57395 .76527 L .57224 .7626 L 1 g
F
P
p
.57395 .76527 m .57549 .76774 L .57224 .7626 L 1 g
F
P
p
.002 w
.61954 .75392 m .58618 .74911 L .57493 .76399 L p
1 g
F P
s
P
p
.002 w
.57579 .77156 m .57108 .76907 L p
.57677 .78335 L 1 g
F P
s
P
p
.57616 .77604 m .57735 .78525 L .57655 .7782 L 1 g
F
P
p
.57644 .77942 m .57735 .78525 L .57616 .77604 L 1 g
F
P
p
.002 w
.57683 .78408 m .57735 .78525 L p
.57644 .77942 L 1 g
F P
s
P
p
.002 w
.57735 .78525 m .57811 .78694 L p
.57655 .7782 L 1 g
F P
s
P
p
.002 w
.57531 .76739 m .57549 .76774 L p
.57456 .76621 L 1 g
F P
s
P
p
.002 w
.59743 .78299 m .61954 .75392 L p
.5755 .76769 L 1 g
F P
s
P
p
.002 w
.57911 .77332 m .59743 .78299 L p
.5755 .76769 L 1 g
F P
s
P
p
.5651 .75096 m .56937 .75786 L .57782 .76016 L 1 g
F
P
p
.54732 .73647 m .5651 .75096 L .55737 .74537 L 1 g
F
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.55007 .74034 m .54241 .75052 L p
.56355 .74984 L 1 g
F P
s
P
p
.002 w
.51578 .729 m .55007 .74034 L .55013 .74013 L p
1 g
F P
s
P
p
.54732 .73647 m .55737 .74537 L .55058 .74047 L 1 g
F
P
p
.002 w
.55007 .74034 m .55058 .74047 L p
.55031 .74026 L 1 g
F P
s
P
p
.5502 .74018 m .55058 .74047 L .55021 .7402 L 1 g
F
P
p
.54732 .73647 m .55058 .74047 L .5502 .74018 L 1 g
F
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.58618 .74911 m .59329 .72604 L p
.55031 .74026 L 1 g
F P
s
P
p
.002 w
.55058 .74047 m .58618 .74911 L p
.55031 .74026 L 1 g
F P
s
P
p
.002 w
.54807 .73844 m .54732 .73647 L p
.5502 .74018 L 1 g
F P
s
P
p
.002 w
.55013 .74013 m .55007 .74034 L p
.55031 .74026 L 1 g
F P
s
P
p
.5502 .74018 m .55021 .7402 L .55013 .74013 L 1 g
F
P
p
.5502 .74018 m .55013 .74013 L .54807 .73844 L 1 g
F
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.59329 .72604 m .55363 .7286 L .55013 .74013 L p
1 g
F P
s
P
p
.59329 .72604 m .55013 .74013 L .55031 .74026 L 1 g
F
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54807 .73844 L p
1 g
F P
s
P
p
.52506 .72815 m .54807 .73844 L .5375 .73438 L 1 g
F
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.54807 .73844 m .51578 .729 L .55013 .74013 L 1 g
F
P
p
.002 w
.5254 .72973 m .52506 .72815 L p
.5375 .73438 L 1 g
F P
s
P
p
.53864 .73073 m .5254 .72973 L .54807 .73844 L 1 g
F
P
p
.5254 .72973 m .51578 .729 L .54807 .73844 L 1 g
F
P
p
.51824 .72919 m .52549 .73016 L .51983 .72954 L 1 g
F
P
p
.5 .72527 m .52202 .72949 L .51824 .72919 L 1 g
F
P
p
.52202 .72949 m .52549 .73016 L .51824 .72919 L 1 g
F
P
p
.002 w
.54241 .75052 m .55007 .74034 L .51578 .729 L p
1 g
F P
s
P
p
.002 w
.51359 .72883 m .54241 .75052 L p
.51578 .729 L 1 g
F P
s
P
p
.5159 .72906 m .52563 .73079 L .51863 .72971 L 1 g
F
P
p
.002 w
.53149 .75806 m .54241 .75052 L .51359 .72883 L p
1 g
F P
s
P
p
.5 .72527 m .51851 .72925 L .51569 .72901 L 1 g
F
P
p
.002 w
.51287 .72876 m .53149 .75806 L p
.51359 .72883 L 1 g
F P
s
P
p
.002 w
.5185 .76214 m .53149 .75806 L .51287 .72876 L p
1 g
F P
s
P
p
.002 w
.51244 .72872 m .5185 .76214 L p
.51287 .72876 L 1 g
F P
s
P
p
.002 w
.50481 .76235 m .5185 .76214 L .51244 .72872 L p
1 g
F P
s
P
p
.002 w
.5121 .72868 m .50481 .76235 L p
.51244 .72872 L 1 g
F P
s
P
p
.002 w
.50783 .72805 m .47894 .72942 L p
.51052 .72846 L 1 g
F P
s
P
p
.002 w
.49191 .75865 m .50481 .76235 L .5121 .72868 L p
1 g
F P
s
P
p
.002 w
.51175 .72864 m .49191 .75865 L p
.5121 .72868 L 1 g
F P
s
P
p
.002 w
.48116 .75143 m .49191 .75865 L .51175 .72864 L p
1 g
F P
s
P
p
.5 .72527 m .51673 .72926 L .51175 .72864 L 1 g
F
P
p
.5 .72527 m .51175 .72864 L .51131 .72858 L 1 g
F
P
p
.002 w
.51052 .72846 m .47375 .74147 L p
.51131 .72858 L 1 g
F P
s
P
p
.002 w
.47455 .72996 m .47494 .72815 L p
.48798 .72831 L 1 g
F P
s
P
p
.48798 .72831 m .47894 .72942 L .47455 .72996 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47455 .72996 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47894 .72942 m .50783 .72805 L p
.5 .72682 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72682 L p
1 g
F P
s
P
p
.002 w
.5 .72682 m .5 .72845 L p
.48798 .72831 L 1 g
F P
s
P
p
.47494 .72815 m .5 .72682 L .48798 .72831 L 1 g
F
P
p
.5 .72527 m .51131 .72858 L .50971 .72835 L 1 g
F
P
p
.002 w
.5 .72692 m .5 .72682 L p
.50971 .72835 L 1 g
F P
s
P
p
.002 w
.5 .72682 m .5 .72527 L p
.50971 .72835 L 1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.002 w
.4717 .71775 m .47123 .72232 L p
.50247 .72652 L 1 g
F P
s
P
p
.002 w
.51228 .72784 m .50548 .72615 L p
.50247 .72652 L 1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.50548 .72615 m .4717 .71775 L p
.50247 .72652 L 1 g
F P
s
P
p
.002 w
.47123 .72232 m .47047 .72982 L .47894 .72942 L p
1 g
F P
s
P
p
.47894 .72942 m .5 .72682 L .47123 .72232 L 1 g
F
P
p
.48798 .72831 m .48806 .72831 L .47894 .72942 L 1 g
F
P
p
.002 w
.50783 .72805 m .51228 .72784 L p
.47123 .72232 L 1 g
F P
s
P
p
.002 w
.5 .72704 m .5 .72692 L p
.50971 .72835 L 1 g
F P
s
P
p
.50971 .72835 m .51131 .72858 L .51052 .72847 L 1 g
F
P
p
.50971 .72835 m .51052 .72847 L .5 .72704 L 1 g
F
P
p
.002 w
.47375 .74147 m .48116 .75143 L .51131 .72858 L p
1 g
F P
s
P
p
.002 w
.51131 .72858 m .51228 .72784 L .51052 .72846 L p
1 g
F P
s
P
p
.002 w
.51175 .72864 m .51228 .72784 L .51131 .72858 L p
1 g
F P
s
P
p
.002 w
.51131 .72858 m .48116 .75143 L p
.51175 .72864 L 1 g
F P
s
P
p
.002 w
.5 .72719 m .5 .72704 L p
.51175 .72864 L 1 g
F P
s
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72719 L p
1 g
F P
s
P
p
.51673 .72926 m .52576 .73141 L .5 .72719 L 1 g
F
P
p
.002 w
.5121 .72868 m .51228 .72784 L .51175 .72864 L p
1 g
F P
s
P
p
.002 w
.51359 .72883 m .51228 .72784 L .51287 .72876 L p
1 g
F P
s
P
p
.51569 .72901 m .51903 .72936 L .5159 .72906 L 1 g
F
P
p
.51851 .72925 m .51903 .72936 L .51569 .72901 L 1 g
F
P
p
.51903 .72936 m .52563 .73079 L .5159 .72906 L 1 g
F
P
p
.002 w
.51287 .72876 m .51228 .72784 L .51244 .72872 L p
1 g
F P
s
P
p
.002 w
.51578 .729 m .51228 .72784 L .51359 .72883 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .52576 .73141 L .5254 .72973 L p
1 g
F P
s
P
p
.5375 .73438 m .54864 .73996 L .5254 .72973 L 1 g
F
P
p
.002 w
.54807 .73844 m .54864 .73996 L p
.5375 .73438 L 1 g
F P
s
P
p
.55266 .73179 m .53864 .73073 L .54807 .73844 L 1 g
F
P
p
.002 w
.55013 .74013 m .55037 .73933 L p
.54807 .73844 L 1 g
F P
s
P
p
.002 w
.55037 .73933 m .55266 .73179 L p
.54807 .73844 L 1 g
F P
s
P
p
.002 w
.54817 .73872 m .54807 .73844 L p
.55021 .7402 L 1 g
F P
s
P
p
.002 w
.58618 .74911 m .55058 .74047 L p
.56355 .74984 L 1 g
F P
s
P
p
.002 w
.55058 .74047 m .55007 .74034 L p
.56355 .74984 L 1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54817 .73872 L p
1 g
F P
s
P
p
.55737 .74537 m .56611 .75311 L .54817 .73872 L 1 g
F
P
p
.002 w
.5651 .75096 m .56611 .75311 L p
.55737 .74537 L 1 g
F P
s
P
p
.002 w
.57782 .76016 m .58618 .74911 L p
.56355 .74984 L 1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.55363 .7286 m .51228 .72784 L .51578 .729 L p
1 g
F P
s
P
p
.002 w
.55266 .73179 m .55363 .7286 L p
.51578 .729 L 1 g
F P
s
P
p
.002 w
.5254 .72973 m .52549 .73016 L p
.52183 .72946 L 1 g
F P
s
P
p
.002 w
.52549 .73016 m .52563 .73079 L p
.51983 .72954 L 1 g
F P
s
P
p
.002 w
.51244 .72872 m .51228 .72784 L .5121 .72868 L p
1 g
F P
s
P
p
.002 w
.51052 .72846 m .51228 .72784 L .50783 .72805 L p
1 g
F P
s
P
p
.002 w
.52563 .73079 m .52576 .73141 L p
.51863 .72971 L 1 g
F P
s
P
p
.47375 .74147 m .47894 .72942 L .47537 .72986 L 1 g
F
P
p
.002 w
.47094 .7315 m .47375 .74147 L p
.47541 .72959 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47455 .72996 L p
1 g
F P
s
P
p
.48806 .72831 m .5 .72845 L .47455 .72996 L 1 g
F
P
p
.002 w
.47894 .72942 m .47541 .72959 L p
.47537 .72986 L 1 g
F P
s
P
p
.45268 .73647 m .47455 .72996 L .47244 .73086 L 1 g
F
P
p
.45268 .73647 m .47448 .73028 L .46473 .73364 L 1 g
F
P
p
.002 w
.47541 .72959 m .47047 .72982 L .47094 .7315 L p
1 g
F P
s
P
p
.002 w
.47455 .72996 m .47448 .73028 L p
.47244 .73086 L 1 g
F P
s
P
p
.002 w
.43615 .75133 m .47375 .74147 L .47047 .72982 L p
1 g
F P
s
P
p
.002 w
.47448 .73028 m .47424 .73141 L p
.46473 .73364 L 1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.46293 .72956 m .4296 .72843 L .43412 .74421 L p
1 g
F P
s
P
p
.44389 .7444 m .43594 .75059 L .43465 .7515 L 1 g
F
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.43615 .75133 m .46393 .73392 L .45288 .73773 L 1 g
F
P
p
.002 w
.43594 .75059 m .43615 .75133 L p
.46293 .72956 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.43412 .74421 m .43594 .75059 L p
.4521 .738 L 1 g
F P
s
P
p
.4521 .738 m .46293 .72956 L .43412 .74421 L 1 g
F
P
p
.002 w
.47047 .72982 m .46293 .72956 L p
.45288 .73773 L 1 g
F P
s
P
p
.46393 .73392 m .47047 .72982 L .45288 .73773 L 1 g
F
P
p
.002 w
.47424 .73141 m .45136 .73996 L .4521 .738 L p
1 g
F P
s
P
p
.46473 .73364 m .47424 .73141 L .4521 .738 L 1 g
F
P
p
.44389 .7444 m .45013 .74069 L .43594 .75059 L 1 g
F
P
p
.002 w
.43594 .75059 m .43571 .74978 L p
.43465 .7515 L 1 g
F P
s
P
p
.43459 .75159 m .43594 .75059 L .43465 .7515 L 1 g
F
P
p
.42292 .78375 m .43459 .75159 L .42499 .76676 L 1 g
F
P
p
.002 w
.47375 .74147 m .43615 .75133 L .45081 .77088 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43465 .7515 L p
1 g
F P
s
P
p
.45013 .74069 m .45136 .73996 L .43465 .7515 L 1 g
F
P
p
.002 w
.43465 .7515 m .43464 .7515 L p
.43462 .75154 L 1 g
F P
s
P
p
.42579 .76511 m .43465 .7515 L .43462 .75154 L 1 g
F
P
p
.42579 .76511 m .43464 .7515 L .42967 .75937 L 1 g
F
P
p
.002 w
.40065 .75718 m .43459 .75159 L p
.4296 .72843 L 1 g
F P
s
P
p
.002 w
.43571 .74978 m .4296 .72843 L p
.43459 .75159 L 1 g
F P
s
P
p
.002 w
.43459 .75159 m .42668 .75289 L p
.42499 .76676 L 1 g
F P
s
P
p
.002 w
.43464 .7515 m .43389 .75311 L p
.42967 .75937 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42499 .76676 L p
1 g
F P
s
P
p
.42967 .75937 m .43389 .75311 L .42499 .76676 L 1 g
F
P
p
.002 w
.42372 .76938 m .42289 .7774 L p
.42342 .7797 L 1 g
F P
s
P
p
.42386 .77601 m .42372 .76938 L .42342 .7797 L 1 g
F
P
p
.002 w
.42326 .7864 m .42214 .78565 L p
.42833 .79737 L 1 g
F P
s
P
p
.002 w
.396 .79538 m .43564 .82166 L p
.42626 .79663 L 1 g
F P
s
P
p
.002 w
.42214 .78565 m .41775 .78729 L p
.42626 .79663 L 1 g
F P
s
P
p
.002 w
.41775 .78729 m .396 .79538 L p
.42626 .79663 L 1 g
F P
s
P
p
.43764 .80912 m .44305 .81506 L .44356 .81547 L 1 g
F
P
p
.47659 .82892 m .44344 .81537 L .4637 .8252 L 1 g
F
P
p
.44344 .81537 m .44293 .81516 L .44356 .81547 L 1 g
F
P
p
.44344 .81537 m .44356 .81547 L .4637 .8252 L 1 g
F
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44353 .81559 L p
1 g
F P
s
P
p
.002 w
.44353 .81559 m .44356 .81547 L p
.44309 .81511 L 1 g
F P
s
P
p
.44309 .81511 m .4285 .8039 L .44353 .81559 L 1 g
F
P
p
.002 w
.396 .79538 m .42214 .78565 L .40065 .75718 L p
1 g
F P
s
P
p
.002 w
.42289 .7774 m .42189 .78694 L .42269 .78515 L p
1 g
F P
s
P
p
.42626 .79663 m .42833 .79737 L .42265 .78662 L 1 g
F
P
p
.42264 .78698 m .42265 .78662 L .42214 .78565 L 1 g
F
P
p
.42626 .79663 m .42265 .78662 L .42264 .78698 L 1 g
F
P
p
.002 w
.45301 .80619 m .42326 .7864 L p
.42833 .79737 L 1 g
F P
s
P
p
.002 w
.42269 .78515 m .42189 .78694 L p
.42639 .79317 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.44305 .81506 m .45301 .80619 L p
.42626 .79663 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42977 .80048 L p
1 g
F P
s
P
p
.42639 .79317 m .42189 .78694 L .42977 .80048 L 1 g
F
P
p
.43764 .80912 m .43038 .80498 L .44305 .81506 L 1 g
F
P
p
.43038 .80498 m .4285 .8039 L .44356 .81547 L 1 g
F
P
p
.002 w
.45301 .80619 m .44305 .81506 L p
.47659 .82892 L 1 g
F P
s
P
p
.47659 .82892 m .44305 .81506 L .44344 .81537 L 1 g
F
P
p
.002 w
.44356 .81547 m .44274 .81844 L p
.45583 .8214 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .4637 .8252 L p
1 g
F P
s
P
p
.45583 .8214 m .44274 .81844 L .4637 .8252 L 1 g
F
P
p
.47637 .82886 m .46532 .82902 L .48443 .83119 L 1 g
F
P
p
.002 w
.51254 .83072 m .51276 .83464 L p
.52539 .82844 L 1 g
F P
s
P
p
.002 w
.48443 .83119 m .48426 .83162 L p
.48742 .83152 L 1 g
F P
s
P
p
.002 w
.48426 .83162 m .48296 .83506 L p
.48742 .83152 L 1 g
F P
s
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51254 .83072 L p
1 g
F P
s
P
p
.50246 .83105 m .48724 .83464 L .51254 .83072 L 1 g
F
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48742 .83152 L p
1 g
F P
s
P
p
.46532 .82902 m .46305 .82905 L .48742 .83152 L 1 g
F
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.6971 .54385 m .70507 .52002 L .65311 .46809 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.67426 .75144 m .64917 .75468 L .62072 .79194 L p
1 g
F P
s
P
p
.002 w
.64917 .75468 m .67426 .75144 L .69062 .69995 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.42635 .43639 m .42278 .41343 L .35108 .44949 L p
1 g
F P
s
P
p
.002 w
.35108 .44949 m .3561 .47164 L .42635 .43639 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.58365 .4116 m .58395 .43455 L .65311 .46809 L p
1 g
F P
s
P
p
.002 w
.58395 .43455 m .58365 .4116 L .50342 .40028 L p
1 g
F P
s
P
p
.002 w
.59743 .78299 m .62072 .79194 L .64917 .75468 L p
1 g
F P
s
P
p
.002 w
.32935 .65163 m .30415 .6313 L .29913 .69201 L p
1 g
F P
s
P
p
.002 w
.29913 .69201 m .32476 .7052 L .32935 .65163 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.35565 .71589 m .32476 .7052 L .34 .75641 L p
1 g
F P
s
P
p
.002 w
.34 .75641 m .36829 .75886 L .35565 .71589 L p
1 g
F P
s
P
p
.002 w
.36526 .49807 m .3561 .47164 L .30256 .52505 L p
1 g
F P
s
P
p
.002 w
.30256 .52505 m .31431 .54873 L .36526 .49807 L p
1 g
F P
s
P
p
.002 w
.33146 .57449 m .31431 .54873 L .28473 .61065 L p
1 g
F P
s
P
p
.002 w
.28473 .61065 m .30415 .6313 L .33146 .57449 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.50535 .42351 m .50342 .40028 L .42278 .41343 L p
1 g
F P
s
P
p
.002 w
.42278 .41343 m .42635 .43639 L .50535 .42351 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.50342 .40028 m .50535 .42351 L .58395 .43455 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.40065 .75718 m .36829 .75886 L .396 .79538 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.69062 .69995 m .66279 .71145 L .64917 .75468 L p
1 g
F P
s
P
p
.002 w
.66279 .71145 m .69062 .69995 L .68734 .64669 L p
1 g
F P
s
P
p
.002 w
.70923 .62579 m .68734 .64669 L .69062 .69995 L p
1 g
F P
s
P
p
.002 w
.65311 .46809 m .64764 .49461 L .6971 .54385 L p
1 g
F P
s
P
p
.002 w
.64764 .49461 m .65311 .46809 L .58395 .43455 L p
1 g
F P
s
P
p
.002 w
.68734 .64669 m .70923 .62579 L .68345 .5699 L p
1 g
F P
s
P
p
.002 w
.6971 .54385 m .68345 .5699 L .70923 .62579 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.68345 .5699 m .6971 .54385 L .64764 .49461 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.64917 .75468 m .61954 .75392 L .59743 .78299 L p
1 g
F P
s
P
p
.002 w
.61954 .75392 m .64917 .75468 L .66279 .71145 L p
1 g
F P
s
P
p
.002 w
.49729 .79224 m .48993 .81668 L .529 .81607 L p
1 g
F P
s
P
p
.002 w
.529 .81607 m .52413 .79183 L .49729 .79224 L p
1 g
F P
s
P
p
.002 w
.52413 .79183 m .529 .81607 L .56614 .80445 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.47195 .78501 m .45301 .80619 L .48993 .81668 L p
1 g
F P
s
P
p
.002 w
.48993 .81668 m .49729 .79224 L .47195 .78501 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56614 .80445 m .54962 .78383 L .52413 .79183 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.43207 .46463 m .42635 .43639 L .3561 .47164 L p
1 g
F P
s
P
p
.002 w
.3561 .47164 m .36526 .49807 L .43207 .46463 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.45301 .80619 m .47195 .78501 L .45081 .77088 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.35965 .67103 m .32935 .65163 L .32476 .7052 L p
1 g
F P
s
P
p
.002 w
.32476 .7052 m .35565 .71589 L .35965 .67103 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.39094 .72373 m .35565 .71589 L .36829 .75886 L p
1 g
F P
s
P
p
.002 w
.36829 .75886 m .40065 .75718 L .39094 .72373 L p
1 g
F P
s
P
p
.002 w
.35359 .60158 m .33146 .57449 L .30415 .6313 L p
1 g
F P
s
P
p
.002 w
.30415 .6313 m .32935 .65163 L .35359 .60158 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.58395 .43455 m .58187 .46285 L .64764 .49461 L p
1 g
F P
s
P
p
.002 w
.58187 .46285 m .58395 .43455 L .50535 .42351 L p
1 g
F P
s
P
p
.002 w
.37836 .52805 m .36526 .49807 L .31431 .54873 L p
1 g
F P
s
P
p
.002 w
.31431 .54873 m .33146 .57449 L .37836 .52805 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.66279 .71145 m .63003 .72025 L .61954 .75392 L p
1 g
F P
s
P
p
.002 w
.63003 .72025 m .66279 .71145 L .65989 .66682 L p
1 g
F P
s
P
p
.002 w
.68734 .64669 m .65989 .66682 L .66279 .71145 L p
1 g
F P
s
P
p
.002 w
.65989 .66682 m .68734 .64669 L .66444 .59744 L p
1 g
F P
s
P
p
.002 w
.68345 .5699 m .66444 .59744 L .68734 .64669 L p
1 g
F P
s
P
p
.002 w
.50716 .45241 m .50535 .42351 L .42635 .43639 L p
1 g
F P
s
P
p
.002 w
.42635 .43639 m .43207 .46463 L .50716 .45241 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.64764 .49461 m .63791 .52479 L .68345 .5699 L p
1 g
F P
s
P
p
.002 w
.63791 .52479 m .64764 .49461 L .58187 .46285 L p
1 g
F P
s
P
p
.002 w
.50535 .42351 m .50716 .45241 L .58187 .46285 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.66444 .59744 m .68345 .5699 L .63791 .52479 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58618 .74911 m .61954 .75392 L .63003 .72025 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.50481 .76235 m .49729 .79224 L .52413 .79183 L p
1 g
F P
s
P
p
.002 w
.52413 .79183 m .5185 .76214 L .50481 .76235 L p
1 g
F P
s
P
p
.002 w
.5185 .76214 m .52413 .79183 L .54962 .78383 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.49191 .75865 m .47195 .78501 L .49729 .79224 L p
1 g
F P
s
P
p
.002 w
.49729 .79224 m .50481 .76235 L .49191 .75865 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.54962 .78383 m .53149 .75806 L .5185 .76214 L p
1 g
F P
s
P
p
.002 w
.53149 .75806 m .54962 .78383 L .57108 .76907 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.39418 .68889 m .35965 .67103 L .35565 .71589 L p
1 g
F P
s
P
p
.002 w
.35565 .71589 m .39094 .72373 L .39418 .68889 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.43979 .4974 m .43207 .46463 L .36526 .49807 L p
1 g
F P
s
P
p
.002 w
.36526 .49807 m .37836 .52805 L .43979 .4974 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.4296 .72843 m .39094 .72373 L .40065 .75718 L p
1 g
F P
s
P
p
.002 w
.48116 .75143 m .45081 .77088 L .47195 .78501 L p
1 g
F P
s
P
p
.002 w
.47195 .78501 m .49191 .75865 L .48116 .75143 L p
1 g
F P
s
P
p
.002 w
.38009 .62918 m .35359 .60158 L .32935 .65163 L p
1 g
F P
s
P
p
.002 w
.32935 .65163 m .35965 .67103 L .38009 .62918 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.39507 .56071 m .37836 .52805 L .33146 .57449 L p
1 g
F P
s
P
p
.002 w
.33146 .57449 m .35359 .60158 L .39507 .56071 L p
1 g
F P
s
P
p
.002 w
.57108 .76907 m .54241 .75052 L .53149 .75806 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.58187 .46285 m .57744 .49571 L .63791 .52479 L p
1 g
F P
s
P
p
.002 w
.57744 .49571 m .58187 .46285 L .50716 .45241 L p
1 g
F P
s
P
p
.002 w
.63003 .72025 m .59329 .72604 L .58618 .74911 L p
1 g
F P
s
P
p
.002 w
.59329 .72604 m .63003 .72025 L .62766 .68557 L p
1 g
F P
s
P
p
.002 w
.65989 .66682 m .62766 .68557 L .63003 .72025 L p
1 g
F P
s
P
p
.002 w
.62766 .68557 m .65989 .66682 L .64057 .62565 L p
1 g
F P
s
P
p
.002 w
.66444 .59744 m .64057 .62565 L .65989 .66682 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.45081 .77088 m .48116 .75143 L .47375 .74147 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.64057 .62565 m .66444 .59744 L .62415 .55775 L p
1 g
F P
s
P
p
.002 w
.63791 .52479 m .62415 .55775 L .66444 .59744 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.62415 .55775 m .63791 .52479 L .57744 .49571 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.50878 .48619 m .50716 .45241 L .43207 .46463 L p
1 g
F P
s
P
p
.002 w
.43207 .46463 m .43979 .4974 L .50878 .48619 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.50716 .45241 m .50878 .48619 L .57744 .49571 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.43192 .70463 m .39418 .68889 L .39094 .72373 L p
1 g
F P
s
P
p
.002 w
.39094 .72373 m .4296 .72843 L .43192 .70463 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.41018 .65645 m .38009 .62918 L .35965 .67103 L p
1 g
F P
s
P
p
.002 w
.35965 .67103 m .39418 .68889 L .41018 .65645 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.4493 .53374 m .43979 .4974 L .37836 .52805 L p
1 g
F P
s
P
p
.002 w
.37836 .52805 m .39507 .56071 L .4493 .53374 L p
1 g
F P
s
P
p
.002 w
.55363 .7286 m .59329 .72604 L .59156 .70233 L p
1 g
F P
s
P
p
.002 w
.62766 .68557 m .59156 .70233 L .59329 .72604 L p
1 g
F P
s
P
p
.002 w
.59156 .70233 m .62766 .68557 L .61252 .65364 L p
1 g
F P
s
P
p
.002 w
.64057 .62565 m .61252 .65364 L .62766 .68557 L p
1 g
F P
s
P
p
.002 w
.41491 .59506 m .39507 .56071 L .35359 .60158 L p
1 g
F P
s
P
p
.002 w
.35359 .60158 m .38009 .62918 L .41491 .59506 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.61252 .65364 m .64057 .62565 L .60673 .59252 L p
1 g
F P
s
P
p
.002 w
.62415 .55775 m .60673 .59252 L .64057 .62565 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.57744 .49571 m .57074 .53221 L .62415 .55775 L p
1 g
F P
s
P
p
.002 w
.57074 .53221 m .57744 .49571 L .50878 .48619 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.4717 .71775 m .43192 .70463 L .4296 .72843 L p
1 g
F P
s
P
p
.002 w
.4296 .72843 m .47047 .72982 L .4717 .71775 L p
1 g
F P
s
P
p
.002 w
.60673 .59252 m .62415 .55775 L .57074 .53221 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.44293 .68252 m .41018 .65645 L .39418 .68889 L p
1 g
F P
s
P
p
.002 w
.39418 .68889 m .43192 .70463 L .44293 .68252 L p
1 g
F P
s
P
p
.002 w
.51017 .52386 m .50878 .48619 L .43979 .4974 L p
1 g
F P
s
P
p
.004 w
.46774 .50791 m
.5 .6118 L
s
P
p
.002 w
.43979 .4974 m .4493 .53374 L .51017 .52386 L p
1 g
F P
s
P
p
.004 w
.46471 .49814 m
.46624 .50308 L
s
P
p
.004 w
.4475 .44274 m
.46471 .49814 L
s
P
p
.002 w
.59156 .70233 m .5527 .71657 L .55363 .7286 L p
1 g
F P
s
P
p
.002 w
.5527 .71657 m .59156 .70233 L .58113 .68056 L p
1 g
F P
s
P
p
.002 w
.61252 .65364 m .58113 .68056 L .59156 .70233 L p
1 g
F P
s
P
p
.002 w
.5527 .71657 m .51228 .72784 L .55363 .7286 L closepath p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.50878 .48619 m .51017 .52386 L .57074 .53221 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.43727 .63004 m .41491 .59506 L .38009 .62918 L p
1 g
F P
s
P
p
.002 w
.38009 .62918 m .41018 .65645 L .43727 .63004 L p
1 g
F P
s
P
p
.002 w
.58113 .68056 m .61252 .65364 L .58616 .62801 L p
1 g
F P
s
P
p
.002 w
.60673 .59252 m .58616 .62801 L .61252 .65364 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.54736 .70556 m .51228 .72784 L .5527 .71657 L closepath p
1 g
F P
s
P
p
.002 w
.58113 .68056 m .54736 .70556 L .5527 .71657 L p
1 g
F P
s
P
p
.002 w
.46033 .57256 m .4493 .53374 L .39507 .56071 L p
1 g
F P
s
P
p
.002 w
.39507 .56071 m .41491 .59506 L .46033 .57256 L p
1 g
F P
s
P
p
.002 w
.47732 .70656 m .51228 .72784 L .48674 .69749 L closepath p
1 g
F P
s
P
p
.002 w
.4717 .71775 m .51228 .72784 L .47732 .70656 L closepath p
1 g
F P
s
P
p
.002 w
.53818 .69675 m .51228 .72784 L .54736 .70556 L closepath p
1 g
F P
s
P
p
.002 w
.52614 .69113 m .51228 .72784 L .53818 .69675 L closepath p
1 g
F P
s
P
p
.002 w
.51256 .68932 m .51228 .72784 L .52614 .69113 L closepath p
1 g
F P
s
P
p
.002 w
.49893 .69152 m .51228 .72784 L .51256 .68932 L closepath p
1 g
F P
s
P
p
.004 w
.5 .6118 m
.50828 .69001 L
s
P
p
.002 w
.48674 .69749 m .51228 .72784 L .49893 .69152 L closepath p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.47732 .70656 m .44293 .68252 L .43192 .70463 L p
1 g
F P
s
P
p
.002 w
.43192 .70463 m .4717 .71775 L .47732 .70656 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.004 w
.51228 .72784 m
.51264 .73126 L
s
P
p
.002 w
.58616 .62801 m .60673 .59252 L .56198 .57124 L p
1 g
F P
s
P
p
.002 w
.57074 .53221 m .56198 .57124 L .60673 .59252 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.56198 .57124 m .57074 .53221 L .51017 .52386 L p
1 g
F P
s
P
p
.002 w
.54736 .70556 m .58113 .68056 L .56307 .66312 L p
1 g
F P
s
P
p
.002 w
.58616 .62801 m .56307 .66312 L .58113 .68056 L p
1 g
F P
s
P
p
.002 w
.56307 .66312 m .53818 .69675 L .54736 .70556 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.46147 .66454 m .43727 .63004 L .41018 .65645 L p
1 g
F P
s
P
p
.002 w
.41018 .65645 m .44293 .68252 L .46147 .66454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.44293 .68252 m .47732 .70656 L .48674 .69749 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.53818 .69675 m .56307 .66312 L .53932 .65197 L p
1 g
F P
s
P
p
.002 w
.53932 .65197 m .52614 .69113 L .53818 .69675 L p
1 g
F P
s
P
p
.002 w
.51127 .5643 m .51017 .52386 L .4493 .53374 L p
1 g
F P
s
P
p
.002 w
.4493 .53374 m .46033 .57256 L .51127 .5643 L p
1 g
F P
s
P
p
.002 w
.48674 .69749 m .46147 .66454 L .44293 .68252 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.51017 .52386 m .51127 .5643 L .56198 .57124 L p
1 g
F P
s
P
p
.002 w
.56307 .66312 m .58616 .62801 L .55139 .61158 L p
1 g
F P
s
P
p
.002 w
.56198 .57124 m .55139 .61158 L .58616 .62801 L p
1 g
F P
s
P
p
.002 w
.47254 .61264 m .46033 .57256 L .41491 .59506 L p
1 g
F P
s
P
p
.002 w
.41491 .59506 m .43727 .63004 L .47254 .61264 L p
1 g
F P
s
P
p
.002 w
.46147 .66454 m .48674 .69749 L .49893 .69152 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.52614 .69113 m .53932 .65197 L .51249 .64836 L p
1 g
F P
s
P
p
.002 w
.51249 .64836 m .51256 .68932 L .52614 .69113 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.55139 .61158 m .53932 .65197 L .56307 .66312 L p
1 g
F P
s
P
p
.002 w
.48554 .65272 m .49893 .69152 L .51256 .68932 L p
1 g
F P
s
P
p
.002 w
.49893 .69152 m .48554 .65272 L .46147 .66454 L p
1 g
F P
s
P
p
.002 w
.51256 .68932 m .51249 .64836 L .48554 .65272 L p
1 g
F P
s
P
p
.002 w
.55139 .61158 m .56198 .57124 L .51127 .5643 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.48554 .65272 m .47254 .61264 L .43727 .63004 L p
1 g
F P
s
P
p
.002 w
.43727 .63004 m .46147 .66454 L .48554 .65272 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.53932 .65197 m .55139 .61158 L .51205 .60625 L p
1 g
F P
s
P
p
.002 w
.51205 .60625 m .51249 .64836 L .53932 .65197 L p
1 g
F P
s
P
p
.002 w
.51205 .60625 m .51127 .5643 L .46033 .57256 L p
1 g
F P
s
P
p
.002 w
.46033 .57256 m .47254 .61264 L .51205 .60625 L p
1 g
F P
s
P
p
.002 w
.51127 .5643 m .51205 .60625 L .55139 .61158 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.47254 .61264 m .48554 .65272 L .51249 .64836 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.51249 .64836 m .51205 .60625 L .47254 .61264 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
.004 w
.51264 .73126 m
.51888 .79018 L
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .4475 .44274 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .51888 .79018 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.63)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.63)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.45089 .6762 m .44783 .63877 L .49325 .63044 L p
1 g
F P
s
P
p
.002 w
.49325 .63044 m .50536 .66613 L .45089 .6762 L p
1 g
F P
s
P
p
.002 w
.48134 .5943 m .49325 .63044 L .44783 .63877 L p
1 g
F P
s
P
p
.002 w
.50536 .66613 m .49325 .63044 L .53506 .60993 L p
1 g
F P
s
P
p
.002 w
.49325 .63044 m .48134 .5943 L .51373 .57839 L p
1 g
F P
s
P
p
.002 w
.51373 .57839 m .53506 .60993 L .49325 .63044 L p
1 g
F P
s
P
p
.002 w
.44783 .63877 m .44613 .60071 L .48134 .5943 L p
1 g
F P
s
P
p
.002 w
.46989 .55855 m .48134 .5943 L .44613 .60071 L p
1 g
F P
s
P
p
.002 w
.48134 .5943 m .46989 .55855 L .49201 .54768 L p
1 g
F P
s
P
p
.002 w
.49201 .54768 m .51373 .57839 L .48134 .5943 L p
1 g
F P
s
P
p
.002 w
.53506 .60993 m .55551 .64155 L .50536 .66613 L p
1 g
F P
s
P
p
.002 w
.55551 .64155 m .53506 .60993 L .56893 .57934 L p
1 g
F P
s
P
p
.002 w
.53506 .60993 m .51373 .57839 L .53993 .55465 L p
1 g
F P
s
P
p
.002 w
.53993 .55465 m .56893 .57934 L .53506 .60993 L p
1 g
F P
s
P
p
.002 w
.51373 .57839 m .49201 .54768 L .50987 .53144 L p
1 g
F P
s
P
p
.002 w
.50987 .53144 m .53993 .55465 L .51373 .57839 L p
1 g
F P
s
P
p
.002 w
.45524 .7121 m .45089 .6762 L .50536 .66613 L p
1 g
F P
s
P
p
.002 w
.50536 .66613 m .51737 .70055 L .45524 .7121 L p
1 g
F P
s
P
p
.002 w
.51737 .70055 m .50536 .66613 L .55551 .64155 L p
1 g
F P
s
P
p
.002 w
.40348 .63402 m .41179 .59694 L .44613 .60071 L p
1 g
F P
s
P
p
.002 w
.44613 .60071 m .44783 .63877 L .40348 .63402 L p
1 g
F P
s
P
p
.002 w
.44583 .56291 m .44613 .60071 L .41179 .59694 L p
1 g
F P
s
P
p
.002 w
.44613 .60071 m .44583 .56291 L .46989 .55855 L p
1 g
F P
s
P
p
.002 w
.39766 .67063 m .40348 .63402 L .44783 .63877 L p
1 g
F P
s
P
p
.002 w
.44783 .63877 m .45089 .6762 L .39766 .67063 L p
1 g
F P
s
P
p
.002 w
.45917 .52405 m .46989 .55855 L .44583 .56291 L p
1 g
F P
s
P
p
.002 w
.46989 .55855 m .45917 .52405 L .47042 .51852 L p
1 g
F P
s
P
p
.002 w
.47042 .51852 m .49201 .54768 L .46989 .55855 L p
1 g
F P
s
P
p
.002 w
.55551 .64155 m .57459 .67252 L .51737 .70055 L p
1 g
F P
s
P
p
.002 w
.57459 .67252 m .55551 .64155 L .5962 .60494 L p
1 g
F P
s
P
p
.002 w
.56893 .57934 m .5962 .60494 L .55551 .64155 L p
1 g
F P
s
P
p
.002 w
.49201 .54768 m .47042 .51852 L .47948 .51025 L p
1 g
F P
s
P
p
.002 w
.47948 .51025 m .50987 .53144 L .49201 .54768 L p
1 g
F P
s
P
p
.002 w
.56893 .57934 m .53993 .55465 L .55715 .52552 L p
1 g
F P
s
P
p
.002 w
.53993 .55465 m .50987 .53144 L .52157 .51152 L p
1 g
F P
s
P
p
.002 w
.52157 .51152 m .55715 .52552 L .53993 .55465 L p
1 g
F P
s
P
p
.002 w
.41179 .59694 m .4224 .56027 L .44583 .56291 L p
1 g
F P
s
P
p
.002 w
.44694 .52625 m .44583 .56291 L .4224 .56027 L p
1 g
F P
s
P
p
.002 w
.44583 .56291 m .44694 .52625 L .45917 .52405 L p
1 g
F P
s
P
p
.002 w
.5962 .60494 m .56893 .57934 L .5913 .5418 L p
1 g
F P
s
P
p
.002 w
.55715 .52552 m .5913 .5418 L .56893 .57934 L p
1 g
F P
s
P
p
.002 w
.50987 .53144 m .47948 .51025 L .48538 .50012 L p
1 g
F P
s
P
p
.002 w
.48538 .50012 m .52157 .51152 L .50987 .53144 L p
1 g
F P
s
P
p
.002 w
.39449 .7059 m .39766 .67063 L .45089 .6762 L p
1 g
F P
s
P
p
.002 w
.45089 .6762 m .45524 .7121 L .39449 .7059 L p
1 g
F P
s
P
p
.002 w
.36483 .61656 m .38193 .58331 L .41179 .59694 L p
1 g
F P
s
P
p
.002 w
.41179 .59694 m .40348 .63402 L .36483 .61656 L p
1 g
F P
s
P
p
.002 w
.4224 .56027 m .41179 .59694 L .38193 .58331 L p
1 g
F P
s
P
p
.002 w
.46079 .74562 m .45524 .7121 L .51737 .70055 L p
1 g
F P
s
P
p
.002 w
.51737 .70055 m .529 .73287 L .46079 .74562 L p
1 g
F P
s
P
p
.002 w
.529 .73287 m .51737 .70055 L .57459 .67252 L p
1 g
F P
s
P
p
.002 w
.38193 .58331 m .40207 .55089 L .4224 .56027 L p
1 g
F P
s
P
p
.002 w
.43505 .52488 m .4224 .56027 L .40207 .55089 L p
1 g
F P
s
P
p
.002 w
.4224 .56027 m .43505 .52488 L .44694 .52625 L p
1 g
F P
s
P
p
.002 w
.57459 .67252 m .59184 .70211 L .529 .73287 L p
1 g
F P
s
P
p
.002 w
.59184 .70211 m .57459 .67252 L .62109 .63083 L p
1 g
F P
s
P
p
.002 w
.5962 .60494 m .62109 .63083 L .57459 .67252 L p
1 g
F P
s
P
p
.002 w
.62109 .63083 m .5962 .60494 L .62319 .55997 L p
1 g
F P
s
P
p
.002 w
.5913 .5418 m .62319 .55997 L .5962 .60494 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .45917 .52405 L .44694 .52625 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47042 .51852 L .45917 .52405 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47948 .51025 L .47042 .51852 L closepath p
1 g
F P
s
P
p
.002 w
.35119 .64985 m .36483 .61656 L .40348 .63402 L p
1 g
F P
s
P
p
.002 w
.40348 .63402 m .39766 .67063 L .35119 .64985 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .44694 .52625 L .43505 .52488 L closepath p
1 g
F P
s
P
p
.002 w
.55715 .52552 m .52157 .51152 L .52581 .49004 L p
1 g
F P
s
P
p
.002 w
.52157 .51152 m .48538 .50012 L .48748 .48921 L p
1 g
F P
s
P
p
.002 w
.48748 .48921 m .52581 .49004 L .52157 .51152 L p
1 g
F P
s
P
p
.002 w
.5913 .5418 m .55715 .52552 L .56351 .49405 L p
1 g
F P
s
P
p
.002 w
.52581 .49004 m .56351 .49405 L .55715 .52552 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .48538 .50012 L .47948 .51025 L closepath p
1 g
F P
s
P
p
.002 w
.40207 .55089 m .42475 .52008 L .43505 .52488 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .43505 .52488 L .42475 .52008 L closepath p
1 g
F P
s
P
p
.002 w
.39407 .73897 m .39449 .7059 L .45524 .7121 L p
1 g
F P
s
P
p
.002 w
.45524 .7121 m .46079 .74562 L .39407 .73897 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .48748 .48921 L .48538 .50012 L closepath p
1 g
F P
s
P
p
.002 w
.62319 .55997 m .5913 .5418 L .59969 .50116 L p
1 g
F P
s
P
p
.002 w
.56351 .49405 m .59969 .50116 L .5913 .5418 L p
1 g
F P
s
P
p
.002 w
.35978 .56116 m .38704 .53572 L .40207 .55089 L p
1 g
F P
s
P
p
.002 w
.40207 .55089 m .38193 .58331 L .35978 .56116 L p
1 g
F P
s
P
p
.002 w
.42475 .52008 m .40207 .55089 L .38704 .53572 L p
1 g
F P
s
P
p
.002 w
.34138 .68237 m .35119 .64985 L .39766 .67063 L p
1 g
F P
s
P
p
.002 w
.39766 .67063 m .39449 .7059 L .34138 .68237 L p
1 g
F P
s
P
p
.002 w
.38704 .53572 m .41718 .51235 L .42475 .52008 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .42475 .52008 L .41718 .51235 L closepath p
1 g
F P
s
P
p
.002 w
.33606 .58806 m .35978 .56116 L .38193 .58331 L p
1 g
F P
s
P
p
.002 w
.38193 .58331 m .36483 .61656 L .33606 .58806 L p
1 g
F P
s
P
p
.002 w
.62109 .63083 m .64298 .65641 L .59184 .70211 L p
1 g
F P
s
P
p
.002 w
.64298 .65641 m .62109 .63083 L .65204 .57961 L p
1 g
F P
s
P
p
.002 w
.62319 .55997 m .65204 .57961 L .62109 .63083 L p
1 g
F P
s
P
p
.002 w
.52581 .49004 m .48748 .48921 L .48554 .47871 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .48554 .47871 L .48748 .48921 L closepath p
1 g
F P
s
P
p
.002 w
.56351 .49405 m .52581 .49004 L .52208 .46928 L p
1 g
F P
s
P
p
.002 w
.48554 .47871 m .52208 .46928 L .52581 .49004 L p
1 g
F P
s
P
p
.002 w
.46743 .77593 m .46079 .74562 L .529 .73287 L p
1 g
F P
s
P
p
.002 w
.529 .73287 m .53998 .76229 L .46743 .77593 L p
1 g
F P
s
P
p
.002 w
.53998 .76229 m .529 .73287 L .59184 .70211 L p
1 g
F P
s
P
p
.002 w
.59184 .70211 m .60683 .72958 L .53998 .76229 L p
1 g
F P
s
P
p
.002 w
.60683 .72958 m .59184 .70211 L .64298 .65641 L p
1 g
F P
s
P
p
.002 w
.37899 .51635 m .41315 .50252 L .41718 .51235 L p
1 g
F P
s
P
p
.002 w
.41718 .51235 m .38704 .53572 L .37899 .51635 L p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41718 .51235 L .41315 .50252 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41713 .48091 L .42472 .47148 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41313 .49164 L .41713 .48091 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .41315 .50252 L .41313 .49164 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47974 .46974 L .48554 .47871 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .47071 .46329 L .47974 .46974 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .45942 .46008 L .47071 .46329 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .4471 .46047 L .45942 .46008 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .43509 .46441 L .4471 .46047 L closepath p
1 g
F P
s
P
p
.002 w
.44945 .4916 m .42472 .47148 L .43509 .46441 L closepath p
1 g
F P
s
P
p
.002 w
.65204 .57961 m .62319 .55997 L .63347 .51122 L p
1 g
F P
s
P
p
.002 w
.59969 .50116 m .63347 .51122 L .62319 .55997 L p
1 g
F P
s
P
p
.002 w
.59969 .50116 m .56351 .49405 L .5582 .46356 L p
1 g
F P
s
P
p
.002 w
.52208 .46928 m .5582 .46356 L .56351 .49405 L p
1 g
F P
s
P
p
.002 w
.52208 .46928 m .48554 .47871 L .47974 .46974 L p
1 g
F P
s
P
p
.002 w
.3165 .61579 m .33606 .58806 L .36483 .61656 L p
1 g
F P
s
P
p
.002 w
.36483 .61656 m .35119 .64985 L .3165 .61579 L p
1 g
F P
s
P
p
.002 w
.34782 .53278 m .37899 .51635 L .38704 .53572 L p
1 g
F P
s
P
p
.002 w
.38704 .53572 m .35978 .56116 L .34782 .53278 L p
1 g
F P
s
P
p
.002 w
.39645 .769 m .39407 .73897 L .46079 .74562 L p
1 g
F P
s
P
p
.002 w
.46079 .74562 m .46743 .77593 L .39645 .769 L p
1 g
F P
s
P
p
.002 w
.37885 .49485 m .41313 .49164 L .41315 .50252 L p
1 g
F P
s
P
p
.002 w
.41315 .50252 m .37899 .51635 L .37885 .49485 L p
1 g
F P
s
P
p
.002 w
.33568 .71333 m .34138 .68237 L .39449 .7059 L p
1 g
F P
s
P
p
.002 w
.39449 .7059 m .39407 .73897 L .33568 .71333 L p
1 g
F P
s
P
p
.002 w
.47974 .46974 m .51072 .45151 L .52208 .46928 L p
1 g
F P
s
P
p
.002 w
.51072 .45151 m .47974 .46974 L .47071 .46329 L p
1 g
F P
s
P
p
.002 w
.5582 .46356 m .52208 .46928 L .51072 .45151 L p
1 g
F P
s
P
p
.002 w
.3867 .47357 m .41713 .48091 L .41313 .49164 L p
1 g
F P
s
P
p
.002 w
.41313 .49164 m .37885 .49485 L .3867 .47357 L p
1 g
F P
s
P
p
.002 w
.63347 .51122 m .59969 .50116 L .59302 .46171 L p
1 g
F P
s
P
p
.002 w
.5582 .46356 m .59302 .46171 L .59969 .50116 L p
1 g
F P
s
P
p
.002 w
.32042 .55143 m .34782 .53278 L .35978 .56116 L p
1 g
F P
s
P
p
.002 w
.35978 .56116 m .33606 .58806 L .32042 .55143 L p
1 g
F P
s
P
p
.002 w
.64298 .65641 m .6613 .68105 L .60683 .72958 L p
1 g
F P
s
P
p
.002 w
.6613 .68105 m .64298 .65641 L .67711 .60026 L p
1 g
F P
s
P
p
.002 w
.65204 .57961 m .67711 .60026 L .64298 .65641 L p
1 g
F P
s
P
p
.002 w
.47071 .46329 m .49292 .43868 L .51072 .45151 L p
1 g
F P
s
P
p
.002 w
.49292 .43868 m .47071 .46329 L .45942 .46008 L p
1 g
F P
s
P
p
.002 w
.30164 .64367 m .3165 .61579 L .35119 .64985 L p
1 g
F P
s
P
p
.002 w
.35119 .64985 m .34138 .68237 L .30164 .64367 L p
1 g
F P
s
P
p
.002 w
.34748 .50119 m .37885 .49485 L .37899 .51635 L p
1 g
F P
s
P
p
.002 w
.37899 .51635 m .34782 .53278 L .34748 .50119 L p
1 g
F P
s
P
p
.002 w
.40172 .45486 m .42472 .47148 L .41713 .48091 L p
1 g
F P
s
P
p
.002 w
.41713 .48091 m .3867 .47357 L .40172 .45486 L p
1 g
F P
s
P
p
.002 w
.67711 .60026 m .65204 .57961 L .66398 .52403 L p
1 g
F P
s
P
p
.002 w
.63347 .51122 m .66398 .52403 L .65204 .57961 L p
1 g
F P
s
P
p
.002 w
.475 .80223 m .46743 .77593 L .53998 .76229 L p
1 g
F P
s
P
p
.002 w
.53998 .76229 m .55002 .78806 L .475 .80223 L p
1 g
F P
s
P
p
.002 w
.55002 .78806 m .53998 .76229 L .60683 .72958 L p
1 g
F P
s
P
p
.002 w
.45942 .46008 m .47056 .43226 L .49292 .43868 L p
1 g
F P
s
P
p
.002 w
.47056 .43226 m .45942 .46008 L .4471 .46047 L p
1 g
F P
s
P
p
.002 w
.60683 .72958 m .61917 .75425 L .55002 .78806 L p
1 g
F P
s
P
p
.002 w
.61917 .75425 m .60683 .72958 L .6613 .68105 L p
1 g
F P
s
P
p
.002 w
.42228 .44081 m .43509 .46441 L .42472 .47148 L p
1 g
F P
s
P
p
.002 w
.42472 .47148 m .40172 .45486 L .42228 .44081 L p
1 g
F P
s
P
p
.002 w
.59302 .46171 m .5582 .46356 L .54165 .43737 L p
1 g
F P
s
P
p
.002 w
.51072 .45151 m .54165 .43737 L .5582 .46356 L p
1 g
F P
s
P
p
.002 w
.4471 .46047 m .44612 .43299 L .47056 .43226 L p
1 g
F P
s
P
p
.002 w
.44612 .43299 m .4471 .46047 L .43509 .46441 L p
1 g
F P
s
P
p
.002 w
.54165 .43737 m .51072 .45151 L .49292 .43868 L p
1 g
F P
s
P
p
.002 w
.43509 .46441 m .42228 .44081 L .44612 .43299 L p
1 g
F P
s
P
p
.002 w
.3343 .74191 m .33568 .71333 L .39407 .73897 L p
1 g
F P
s
P
p
.002 w
.39407 .73897 m .39645 .769 L .3343 .74191 L p
1 g
F P
s
P
p
.002 w
.29753 .57187 m .32042 .55143 L .33606 .58806 L p
1 g
F P
s
P
p
.002 w
.33606 .58806 m .3165 .61579 L .29753 .57187 L p
1 g
F P
s
P
p
.002 w
.66398 .52403 m .63347 .51122 L .62566 .46382 L p
1 g
F P
s
P
p
.002 w
.59302 .46171 m .62566 .46382 L .63347 .51122 L p
1 g
F P
s
P
p
.002 w
.40161 .7952 m .39645 .769 L .46743 .77593 L p
1 g
F P
s
P
p
.002 w
.46743 .77593 m .475 .80223 L .40161 .7952 L p
1 g
F P
s
P
p
.002 w
.35894 .46983 m .3867 .47357 L .37885 .49485 L p
1 g
F P
s
P
p
.002 w
.37885 .49485 m .34748 .50119 L .35894 .46983 L p
1 g
F P
s
P
p
.002 w
.31983 .51053 m .34748 .50119 L .34782 .53278 L p
1 g
F P
s
P
p
.002 w
.34782 .53278 m .32042 .55143 L .31983 .51053 L p
1 g
F P
s
P
p
.002 w
.49292 .43868 m .51552 .41842 L .54165 .43737 L p
1 g
F P
s
P
p
.002 w
.51552 .41842 m .49292 .43868 L .47056 .43226 L p
1 g
F P
s
P
p
.002 w
.29191 .671 m .30164 .64367 L .34138 .68237 L p
1 g
F P
s
P
p
.002 w
.34138 .68237 m .33568 .71333 L .29191 .671 L p
1 g
F P
s
P
p
.002 w
.6613 .68105 m .67556 .70414 L .61917 .75425 L p
1 g
F P
s
P
p
.002 w
.67556 .70414 m .6613 .68105 L .69775 .62143 L p
1 g
F P
s
P
p
.002 w
.67711 .60026 m .69775 .62143 L .6613 .68105 L p
1 g
F P
s
P
p
.002 w
.62566 .46382 m .59302 .46171 L .57174 .42774 L p
1 g
F P
s
P
p
.002 w
.54165 .43737 m .57174 .42774 L .59302 .46171 L p
1 g
F P
s
P
p
.002 w
.69775 .62143 m .67711 .60026 L .69044 .5393 L p
1 g
F P
s
P
p
.002 w
.66398 .52403 m .69044 .5393 L .67711 .60026 L p
1 g
F P
s
P
p
.002 w
.38104 .44221 m .40172 .45486 L .3867 .47357 L p
1 g
F P
s
P
p
.002 w
.3867 .47357 m .35894 .46983 L .38104 .44221 L p
1 g
F P
s
P
p
.002 w
.57174 .42774 m .54165 .43737 L .51552 .41842 L p
1 g
F P
s
P
p
.002 w
.47056 .43226 m .48262 .40888 L .51552 .41842 L p
1 g
F P
s
P
p
.002 w
.48262 .40888 m .47056 .43226 L .44612 .43299 L p
1 g
F P
s
P
p
.002 w
.48334 .82379 m .475 .80223 L .55002 .78806 L p
1 g
F P
s
P
p
.002 w
.55002 .78806 m .55886 .80947 L .48334 .82379 L p
1 g
F P
s
P
p
.002 w
.55886 .80947 m .55002 .78806 L .61917 .75425 L p
1 g
F P
s
P
p
.002 w
.2798 .59361 m .29753 .57187 L .3165 .61579 L p
1 g
F P
s
P
p
.002 w
.3165 .61579 m .30164 .64367 L .2798 .59361 L p
1 g
F P
s
P
p
.002 w
.41138 .42145 m .42228 .44081 L .40172 .45486 L p
1 g
F P
s
P
p
.002 w
.40172 .45486 m .38104 .44221 L .41138 .42145 L p
1 g
F P
s
P
p
.002 w
.61917 .75425 m .6285 .77545 L .55886 .80947 L p
1 g
F P
s
P
p
.002 w
.6285 .77545 m .61917 .75425 L .67556 .70414 L p
1 g
F P
s
P
p
.002 w
.69044 .5393 m .66398 .52403 L .65528 .46989 L p
1 g
F P
s
P
p
.002 w
.62566 .46382 m .65528 .46989 L .66398 .52403 L p
1 g
F P
s
P
p
.002 w
.44612 .43299 m .44656 .40991 L .48262 .40888 L p
1 g
F P
s
P
p
.002 w
.44656 .40991 m .44612 .43299 L .42228 .44081 L p
1 g
F P
s
P
p
.002 w
.42228 .44081 m .41138 .42145 L .44656 .40991 L p
1 g
F P
s
P
p
.002 w
.33734 .76737 m .3343 .74191 L .39645 .769 L p
1 g
F P
s
P
p
.002 w
.39645 .769 m .40161 .7952 L .33734 .76737 L p
1 g
F P
s
P
p
.002 w
.33459 .46983 m .35894 .46983 L .34748 .50119 L p
1 g
F P
s
P
p
.002 w
.34748 .50119 m .31983 .51053 L .33459 .46983 L p
1 g
F P
s
P
p
.002 w
.29667 .52269 m .31983 .51053 L .32042 .55143 L p
1 g
F P
s
P
p
.002 w
.32042 .55143 m .29753 .57187 L .29667 .52269 L p
1 g
F P
s
P
p
.002 w
.40948 .81683 m .40161 .7952 L .475 .80223 L p
1 g
F P
s
P
p
.002 w
.475 .80223 m .48334 .82379 L .40948 .81683 L p
1 g
F P
s
P
p
.002 w
.28765 .69707 m .29191 .671 L .33568 .71333 L p
1 g
F P
s
P
p
.002 w
.33568 .71333 m .3343 .74191 L .28765 .69707 L p
1 g
F P
s
P
p
.002 w
.51552 .41842 m .53798 .40308 L .57174 .42774 L p
1 g
F P
s
P
p
.002 w
.53798 .40308 m .51552 .41842 L .48262 .40888 L p
1 g
F P
s
P
p
.002 w
.65528 .46989 m .62566 .46382 L .60025 .42291 L p
1 g
F P
s
P
p
.002 w
.57174 .42774 m .60025 .42291 L .62566 .46382 L p
1 g
F P
s
P
p
.002 w
.60025 .42291 m .57174 .42774 L .53798 .40308 L p
1 g
F P
s
P
p
.002 w
.69775 .62143 m .71335 .6426 L .67556 .70414 L p
1 g
F P
s
P
p
.002 w
.71335 .6426 m .69775 .62143 L .7121 .55667 L p
1 g
F P
s
P
p
.002 w
.69044 .5393 m .7121 .55667 L .69775 .62143 L p
1 g
F P
s
P
p
.002 w
.67556 .70414 m .68531 .72506 L .6285 .77545 L p
1 g
F P
s
P
p
.002 w
.68531 .72506 m .67556 .70414 L .71335 .6426 L p
1 g
F P
s
P
p
.002 w
.36325 .43392 m .38104 .44221 L .35894 .46983 L p
1 g
F P
s
P
p
.002 w
.35894 .46983 m .33459 .46983 L .36325 .43392 L p
1 g
F P
s
P
p
.002 w
.26778 .61612 m .2798 .59361 L .30164 .64367 L p
1 g
F P
s
P
p
.002 w
.30164 .64367 m .29191 .671 L .26778 .61612 L p
1 g
F P
s
P
p
.002 w
.48262 .40888 m .4953 .39062 L .53798 .40308 L p
1 g
F P
s
P
p
.002 w
.4953 .39062 m .48262 .40888 L .44656 .40991 L p
1 g
F P
s
P
p
.002 w
.7121 .55667 m .69044 .5393 L .68109 .47984 L p
1 g
F P
s
P
p
.002 w
.65528 .46989 m .68109 .47984 L .69044 .5393 L p
1 g
F P
s
P
p
.002 w
.49225 .83998 m .48334 .82379 L .55886 .80947 L p
1 g
F P
s
P
p
.002 w
.55886 .80947 m .56625 .8259 L .49225 .83998 L p
1 g
F P
s
P
p
.002 w
.56625 .8259 m .55886 .80947 L .6285 .77545 L p
1 g
F P
s
P
p
.002 w
.27868 .53743 m .29667 .52269 L .29753 .57187 L p
1 g
F P
s
P
p
.002 w
.29753 .57187 m .2798 .59361 L .27868 .53743 L p
1 g
F P
s
P
p
.002 w
.31436 .47365 m .33459 .46983 L .31983 .51053 L p
1 g
F P
s
P
p
.002 w
.31983 .51053 m .29667 .52269 L .31436 .47365 L p
1 g
F P
s
P
p
.002 w
.40269 .40691 m .41138 .42145 L .38104 .44221 L p
1 g
F P
s
P
p
.002 w
.38104 .44221 m .36325 .43392 L .40269 .40691 L p
1 g
F P
s
P
p
.002 w
.6285 .77545 m .63451 .79256 L .56625 .8259 L p
1 g
F P
s
P
p
.002 w
.63451 .79256 m .6285 .77545 L .68531 .72506 L p
1 g
F P
s
P
p
.002 w
.34482 .78896 m .33734 .76737 L .40161 .7952 L p
1 g
F P
s
P
p
.002 w
.40161 .7952 m .40948 .81683 L .34482 .78896 L p
1 g
F P
s
P
p
.002 w
.44656 .40991 m .44844 .39192 L .4953 .39062 L p
1 g
F P
s
P
p
.002 w
.44844 .39192 m .44656 .40991 L .41138 .42145 L p
1 g
F P
s
P
p
.002 w
.41138 .42145 m .40269 .40691 L .44844 .39192 L p
1 g
F P
s
P
p
.002 w
.68109 .47984 m .65528 .46989 L .62642 .42309 L p
1 g
F P
s
P
p
.002 w
.60025 .42291 m .62642 .42309 L .65528 .46989 L p
1 g
F P
s
P
p
.002 w
.28909 .72118 m .28765 .69707 L .3343 .74191 L p
1 g
F P
s
P
p
.002 w
.3343 .74191 m .33734 .76737 L .28909 .72118 L p
1 g
F P
s
P
p
.002 w
.53798 .40308 m .55971 .39314 L .60025 .42291 L p
1 g
F P
s
P
p
.002 w
.55971 .39314 m .53798 .40308 L .4953 .39062 L p
1 g
F P
s
P
p
.002 w
.41991 .83323 m .40948 .81683 L .48334 .82379 L p
1 g
F P
s
P
p
.002 w
.48334 .82379 m .49225 .83998 L .41991 .83323 L p
1 g
F P
s
P
p
.002 w
.62642 .42309 m .60025 .42291 L .55971 .39314 L p
1 g
F P
s
P
p
.002 w
.71335 .6426 m .72343 .66323 L .68531 .72506 L p
1 g
F P
s
P
p
.002 w
.72343 .66323 m .71335 .6426 L .72834 .57576 L p
1 g
F P
s
P
p
.002 w
.7121 .55667 m .72834 .57576 L .71335 .6426 L p
1 g
F P
s
P
p
.002 w
.26189 .63881 m .26778 .61612 L .29191 .671 L p
1 g
F P
s
P
p
.002 w
.29191 .671 m .28765 .69707 L .26189 .63881 L p
1 g
F P
s
P
p
.002 w
.68531 .72506 m .69021 .74324 L .63451 .79256 L p
1 g
F P
s
P
p
.002 w
.69021 .74324 m .68531 .72506 L .72343 .66323 L p
1 g
F P
s
P
p
.002 w
.34889 .43031 m .36325 .43392 L .33459 .46983 L p
1 g
F P
s
P
p
.002 w
.33459 .46983 m .31436 .47365 L .34889 .43031 L p
1 g
F P
s
P
p
.002 w
.72834 .57576 m .7121 .55667 L .70234 .49348 L p
1 g
F P
s
P
p
.002 w
.68109 .47984 m .70234 .49348 L .7121 .55667 L p
1 g
F P
s
P
p
.002 w
.26644 .55439 m .27868 .53743 L .2798 .59361 L p
1 g
F P
s
P
p
.002 w
.2798 .59361 m .26778 .61612 L .26644 .55439 L p
1 g
F P
s
P
p
.002 w
.4953 .39062 m .5083 .37805 L .55971 .39314 L p
1 g
F P
s
P
p
.002 w
.5083 .37805 m .4953 .39062 L .44844 .39192 L p
1 g
F P
s
P
p
.002 w
.29885 .48128 m .31436 .47365 L .29667 .52269 L p
1 g
F P
s
P
p
.002 w
.29667 .52269 m .27868 .53743 L .29885 .48128 L p
1 g
F P
s
P
p
.002 w
.70234 .49348 m .68109 .47984 L .64952 .42837 L p
1 g
F P
s
P
p
.002 w
.62642 .42309 m .64952 .42837 L .68109 .47984 L p
1 g
F P
s
P
p
.002 w
.50151 .85024 m .49225 .83998 L .56625 .8259 L p
1 g
F P
s
P
p
.002 w
.56625 .8259 m .57197 .83681 L .50151 .85024 L p
1 g
F P
s
P
p
.002 w
.57197 .83681 m .56625 .8259 L .63451 .79256 L p
1 g
F P
s
P
p
.002 w
.35663 .80605 m .34482 .78896 L .40948 .81683 L p
1 g
F P
s
P
p
.002 w
.40948 .81683 m .41991 .83323 L .35663 .80605 L p
1 g
F P
s
P
p
.002 w
.39649 .39768 m .40269 .40691 L .36325 .43392 L p
1 g
F P
s
P
p
.002 w
.36325 .43392 m .34889 .43031 L .39649 .39768 L p
1 g
F P
s
P
p
.002 w
.29629 .74264 m .28909 .72118 L .33734 .76737 L p
1 g
F P
s
P
p
.002 w
.33734 .76737 m .34482 .78896 L .29629 .74264 L p
1 g
F P
s
P
p
.002 w
.63451 .79256 m .63698 .80506 L .57197 .83681 L p
1 g
F P
s
P
p
.002 w
.63698 .80506 m .63451 .79256 L .69021 .74324 L p
1 g
F P
s
P
p
.002 w
.44844 .39192 m .45175 .37958 L .5083 .37805 L p
1 g
F P
s
P
p
.002 w
.45175 .37958 m .44844 .39192 L .40269 .40691 L p
1 g
F P
s
P
p
.002 w
.55971 .39314 m .58013 .38897 L .62642 .42309 L p
1 g
F P
s
P
p
.002 w
.58013 .38897 m .55971 .39314 L .5083 .37805 L p
1 g
F P
s
P
p
.002 w
.40269 .40691 m .39649 .39768 L .45175 .37958 L p
1 g
F P
s
P
p
.002 w
.64952 .42837 m .62642 .42309 L .58013 .38897 L p
1 g
F P
s
P
p
.002 w
.43268 .84387 m .41991 .83323 L .49225 .83998 L p
1 g
F P
s
P
p
.002 w
.49225 .83998 m .50151 .85024 L .43268 .84387 L p
1 g
F P
s
P
p
.002 w
.26243 .66109 m .26189 .63881 L .28765 .69707 L p
1 g
F P
s
P
p
.002 w
.28765 .69707 m .28909 .72118 L .26243 .66109 L p
1 g
F P
s
P
p
.002 w
.72343 .66323 m .7276 .68276 L .69021 .74324 L p
1 g
F P
s
P
p
.002 w
.7276 .68276 m .72343 .66323 L .7386 .59608 L p
1 g
F P
s
P
p
.002 w
.72834 .57576 m .7386 .59608 L .72343 .66323 L p
1 g
F P
s
P
p
.002 w
.7386 .59608 m .72834 .57576 L .71838 .51052 L p
1 g
F P
s
P
p
.002 w
.70234 .49348 m .71838 .51052 L .72834 .57576 L p
1 g
F P
s
P
p
.002 w
.69021 .74324 m .69003 .75814 L .63698 .80506 L p
1 g
F P
s
P
p
.002 w
.69003 .75814 m .69021 .74324 L .7276 .68276 L p
1 g
F P
s
P
p
.002 w
.33841 .43159 m .34889 .43031 L .31436 .47365 L p
1 g
F P
s
P
p
.002 w
.31436 .47365 m .29885 .48128 L .33841 .43159 L p
1 g
F P
s
P
p
.002 w
.26042 .57318 m .26644 .55439 L .26778 .61612 L p
1 g
F P
s
P
p
.002 w
.26778 .61612 m .26189 .63881 L .26042 .57318 L p
1 g
F P
s
P
p
.002 w
.2886 .4926 m .29885 .48128 L .27868 .53743 L p
1 g
F P
s
P
p
.002 w
.27868 .53743 m .26644 .55439 L .2886 .4926 L p
1 g
F P
s
P
p
.002 w
.5083 .37805 m .52128 .37164 L .58013 .38897 L p
1 g
F P
s
P
p
.002 w
.52128 .37164 m .5083 .37805 L .45175 .37958 L p
1 g
F P
s
P
p
.002 w
.71838 .51052 m .70234 .49348 L .66888 .43873 L p
1 g
F P
s
P
p
.002 w
.64952 .42837 m .66888 .43873 L .70234 .49348 L p
1 g
F P
s
P
p
.002 w
.37254 .81807 m .35663 .80605 L .41991 .83323 L p
1 g
F P
s
P
p
.002 w
.41991 .83323 m .43268 .84387 L .37254 .81807 L p
1 g
F P
s
P
p
.002 w
.30919 .76082 m .29629 .74264 L .34482 .78896 L p
1 g
F P
s
P
p
.002 w
.34482 .78896 m .35663 .80605 L .30919 .76082 L p
1 g
F P
s
P
p
.002 w
.39301 .39415 m .39649 .39768 L .34889 .43031 L p
1 g
F P
s
P
p
.002 w
.34889 .43031 m .33841 .43159 L .39301 .39415 L p
1 g
F P
s
P
p
.002 w
.51088 .85415 m .50151 .85024 L .57197 .83681 L p
1 g
F P
s
P
p
.002 w
.57197 .83681 m .57582 .84177 L .51088 .85415 L p
1 g
F P
s
P
p
.002 w
.57582 .84177 m .57197 .83681 L .63698 .80506 L p
1 g
F P
s
P
p
.002 w
.66888 .43873 m .64952 .42837 L .59868 .39081 L p
1 g
F P
s
P
p
.002 w
.58013 .38897 m .59868 .39081 L .64952 .42837 L p
1 g
F P
s
P
p
.002 w
.59868 .39081 m .58013 .38897 L .52128 .37164 L p
1 g
F P
s
P
p
.002 w
.63698 .80506 m .63576 .8125 L .57582 .84177 L p
1 g
F P
s
P
p
.002 w
.63576 .8125 m .63698 .80506 L .69003 .75814 L p
1 g
F P
s
P
p
.002 w
.45175 .37958 m .45642 .37338 L .52128 .37164 L p
1 g
F P
s
P
p
.002 w
.45642 .37338 m .45175 .37958 L .39649 .39768 L p
1 g
F P
s
P
p
.002 w
.26951 .68233 m .26243 .66109 L .28909 .72118 L p
1 g
F P
s
P
p
.002 w
.28909 .72118 m .29629 .74264 L .26951 .68233 L p
1 g
F P
s
P
p
.002 w
.39649 .39768 m .39301 .39415 L .45642 .37338 L p
1 g
F P
s
P
p
.002 w
.7276 .68276 m .72563 .70065 L .69003 .75814 L p
1 g
F P
s
P
p
.002 w
.72563 .70065 m .7276 .68276 L .7425 .61713 L p
1 g
F P
s
P
p
.002 w
.7386 .59608 m .7425 .61713 L .7276 .68276 L p
1 g
F P
s
P
p
.002 w
.4475 .8483 m .43268 .84387 L .50151 .85024 L p
1 g
F P
s
P
p
.002 w
.50151 .85024 m .51088 .85415 L .4475 .8483 L p
1 g
F P
s
P
p
.002 w
.7425 .61713 m .7386 .59608 L .72868 .53057 L p
1 g
F P
s
P
p
.002 w
.71838 .51052 m .72868 .53057 L .7386 .59608 L p
1 g
F P
s
P
p
.002 w
.26091 .59332 m .26042 .57318 L .26189 .63881 L p
1 g
F P
s
P
p
.002 w
.26189 .63881 m .26243 .66109 L .26091 .59332 L p
1 g
F P
s
P
p
.002 w
.33219 .43783 m .33841 .43159 L .29885 .48128 L p
1 g
F P
s
P
p
.002 w
.29885 .48128 m .2886 .4926 L .33219 .43783 L p
1 g
F P
s
P
p
.002 w
.69003 .75814 m .68465 .76928 L .63576 .8125 L p
1 g
F P
s
P
p
.002 w
.68465 .76928 m .69003 .75814 L .72563 .70065 L p
1 g
F P
s
P
p
.002 w
.28402 .50739 m .2886 .4926 L .26644 .55439 L p
1 g
F P
s
P
p
.002 w
.26644 .55439 m .26042 .57318 L .28402 .50739 L p
1 g
F P
s
P
p
.002 w
.66888 .43873 m .68388 .45398 L .71838 .51052 L p
1 g
F P
s
P
p
.002 w
.72868 .53057 m .71838 .51052 L .68388 .45398 L p
1 g
F P
s
P
p
.002 w
.52128 .37164 m .53389 .37171 L .59868 .39081 L p
1 g
F P
s
P
p
.002 w
.53389 .37171 m .52128 .37164 L .45642 .37338 L p
1 g
F P
s
P
p
.002 w
.32754 .77515 m .30919 .76082 L .35663 .80605 L p
1 g
F P
s
P
p
.002 w
.35663 .80605 m .37254 .81807 L .32754 .77515 L p
1 g
F P
s
P
p
.002 w
.39221 .82458 m .37254 .81807 L .43268 .84387 L p
1 g
F P
s
P
p
.002 w
.43268 .84387 m .4475 .8483 L .39221 .82458 L p
1 g
F P
s
P
p
.002 w
.59868 .39081 m .6148 .39874 L .66888 .43873 L p
1 g
F P
s
P
p
.002 w
.68388 .45398 m .66888 .43873 L .6148 .39874 L p
1 g
F P
s
P
p
.002 w
.6148 .39874 m .59868 .39081 L .53389 .37171 L p
1 g
F P
s
P
p
.002 w
.39242 .39654 m .39301 .39415 L .33841 .43159 L p
1 g
F P
s
P
p
.002 w
.33841 .43159 m .33219 .43783 L .39242 .39654 L p
1 g
F P
s
P
p
.002 w
.28308 .70192 m .26951 .68233 L .29629 .74264 L p
1 g
F P
s
P
p
.002 w
.29629 .74264 m .30919 .76082 L .28308 .70192 L p
1 g
F P
s
P
p
.002 w
.52011 .85146 m .51088 .85415 L .57582 .84177 L p
1 g
F P
s
P
p
.002 w
.57582 .84177 m .57765 .84049 L .52011 .85146 L p
1 g
F P
s
P
p
.002 w
.57765 .84049 m .57582 .84177 L .63576 .8125 L p
1 g
F P
s
P
p
.002 w
.63576 .8125 m .63078 .81455 L .57765 .84049 L p
1 g
F P
s
P
p
.002 w
.63078 .81455 m .63576 .8125 L .68465 .76928 L p
1 g
F P
s
P
p
.002 w
.45642 .37338 m .46238 .37362 L .53389 .37171 L p
1 g
F P
s
P
p
.002 w
.46238 .37362 m .45642 .37338 L .39301 .39415 L p
1 g
F P
s
P
p
.002 w
.72563 .70065 m .71741 .71638 L .68465 .76928 L p
1 g
F P
s
P
p
.002 w
.7425 .61713 m .73979 .63834 L .72563 .70065 L p
1 g
F P
s
P
p
.002 w
.71741 .71638 m .72563 .70065 L .73979 .63834 L p
1 g
F P
s
P
p
.002 w
.39301 .39415 m .39242 .39654 L .46238 .37362 L p
1 g
F P
s
P
p
.002 w
.72868 .53057 m .73281 .55314 L .7425 .61713 L p
1 g
F P
s
P
p
.002 w
.73979 .63834 m .7425 .61713 L .73281 .55314 L p
1 g
F P
s
P
p
.002 w
.46401 .84627 m .4475 .8483 L .51088 .85415 L p
1 g
F P
s
P
p
.002 w
.51088 .85415 m .52011 .85146 L .46401 .84627 L p
1 g
F P
s
P
p
.002 w
.26804 .61426 m .26091 .59332 L .26243 .66109 L p
1 g
F P
s
P
p
.002 w
.26243 .66109 m .26951 .68233 L .26804 .61426 L p
1 g
F P
s
P
p
.002 w
.33051 .44901 m .33219 .43783 L .2886 .4926 L p
1 g
F P
s
P
p
.002 w
.2886 .4926 m .28402 .50739 L .33051 .44901 L p
1 g
F P
s
P
p
.002 w
.68465 .76928 m .67409 .77626 L .63078 .81455 L p
1 g
F P
s
P
p
.002 w
.67409 .77626 m .68465 .76928 L .71741 .71638 L p
1 g
F P
s
P
p
.002 w
.73281 .55314 m .72868 .53057 L .69403 .47382 L p
1 g
F P
s
P
p
.002 w
.68388 .45398 m .69403 .47382 L .72868 .53057 L p
1 g
F P
s
P
p
.002 w
.28536 .52531 m .28402 .50739 L .26042 .57318 L p
1 g
F P
s
P
p
.002 w
.26042 .57318 m .26091 .59332 L .28536 .52531 L p
1 g
F P
s
P
p
.002 w
.35095 .78512 m .32754 .77515 L .37254 .81807 L p
1 g
F P
s
P
p
.002 w
.37254 .81807 m .39221 .82458 L .35095 .78512 L p
1 g
F P
s
P
p
.002 w
.53389 .37171 m .54576 .37842 L .6148 .39874 L p
1 g
F P
s
P
p
.002 w
.54576 .37842 m .53389 .37171 L .46238 .37362 L p
1 g
F P
s
P
p
.002 w
.69403 .47382 m .68388 .45398 L .62799 .41269 L p
1 g
F P
s
P
p
.002 w
.6148 .39874 m .62799 .41269 L .68388 .45398 L p
1 g
F P
s
P
p
.002 w
.41517 .82526 m .39221 .82458 L .4475 .8483 L p
1 g
F P
s
P
p
.002 w
.4475 .8483 m .46401 .84627 L .41517 .82526 L p
1 g
F P
s
P
p
.002 w
.30288 .71926 m .28308 .70192 L .30919 .76082 L p
1 g
F P
s
P
p
.002 w
.30919 .76082 m .32754 .77515 L .30288 .71926 L p
1 g
F P
s
P
p
.002 w
.62799 .41269 m .6148 .39874 L .54576 .37842 L p
1 g
F P
s
P
p
.002 w
.39481 .40495 m .39242 .39654 L .33219 .43783 L p
1 g
F P
s
P
p
.002 w
.33219 .43783 m .33051 .44901 L .39481 .40495 L p
1 g
F P
s
P
p
.002 w
.52893 .84207 m .52011 .85146 L .57765 .84049 L p
1 g
F P
s
P
p
.002 w
.57765 .84049 m .57737 .83284 L .52893 .84207 L p
1 g
F P
s
P
p
.002 w
.57737 .83284 m .57765 .84049 L .63078 .81455 L p
1 g
F P
s
P
p
.002 w
.63078 .81455 m .62209 .811 L .57737 .83284 L p
1 g
F P
s
P
p
.002 w
.62209 .811 m .63078 .81455 L .67409 .77626 L p
1 g
F P
s
P
p
.002 w
.71741 .71638 m .70305 .72944 L .67409 .77626 L p
1 g
F P
s
P
p
.002 w
.70305 .72944 m .71741 .71638 L .73039 .65912 L p
1 g
F P
s
P
p
.002 w
.73979 .63834 m .73039 .65912 L .71741 .71638 L p
1 g
F P
s
P
p
.002 w
.73039 .65912 m .73979 .63834 L .73055 .57766 L p
1 g
F P
s
P
p
.002 w
.73281 .55314 m .73055 .57766 L .73979 .63834 L p
1 g
F P
s
P
p
.002 w
.46238 .37362 m .46948 .38048 L .54576 .37842 L p
1 g
F P
s
P
p
.002 w
.46948 .38048 m .46238 .37362 L .39242 .39654 L p
1 g
F P
s
P
p
.002 w
.28176 .63544 m .26804 .61426 L .26951 .68233 L p
1 g
F P
s
P
p
.002 w
.26951 .68233 m .28308 .70192 L .28176 .63544 L p
1 g
F P
s
P
p
.002 w
.39242 .39654 m .39481 .40495 L .46948 .38048 L p
1 g
F P
s
P
p
.002 w
.48177 .83767 m .46401 .84627 L .52011 .85146 L p
1 g
F P
s
P
p
.002 w
.52011 .85146 m .52893 .84207 L .48177 .83767 L p
1 g
F P
s
P
p
.002 w
.73055 .57766 m .73281 .55314 L .69892 .49778 L p
1 g
F P
s
P
p
.002 w
.69403 .47382 m .69892 .49778 L .73281 .55314 L p
1 g
F P
s
P
p
.002 w
.33354 .46491 m .33051 .44901 L .28402 .50739 L p
1 g
F P
s
P
p
.002 w
.28402 .50739 m .28536 .52531 L .33354 .46491 L p
1 g
F P
s
P
p
.002 w
.29273 .54592 m .28536 .52531 L .26091 .59332 L p
1 g
F P
s
P
p
.002 w
.26091 .59332 m .26804 .61426 L .29273 .54592 L p
1 g
F P
s
P
p
.002 w
.67409 .77626 m .65852 .77877 L .62209 .811 L p
1 g
F P
s
P
p
.002 w
.65852 .77877 m .67409 .77626 L .70305 .72944 L p
1 g
F P
s
P
p
.002 w
.37884 .79037 m .35095 .78512 L .39221 .82458 L p
1 g
F P
s
P
p
.002 w
.39221 .82458 m .41517 .82526 L .37884 .79037 L p
1 g
F P
s
P
p
.002 w
.69892 .49778 m .69403 .47382 L .63782 .4324 L p
1 g
F P
s
P
p
.002 w
.62799 .41269 m .63782 .4324 L .69403 .47382 L p
1 g
F P
s
P
p
.002 w
.54576 .37842 m .55655 .39173 L .62799 .41269 L p
1 g
F P
s
P
p
.002 w
.55655 .39173 m .54576 .37842 L .46948 .38048 L p
1 g
F P
s
P
p
.002 w
.32847 .73381 m .30288 .71926 L .32754 .77515 L p
1 g
F P
s
P
p
.002 w
.32754 .77515 m .35095 .78512 L .32847 .73381 L p
1 g
F P
s
P
p
.002 w
.44081 .81997 m .41517 .82526 L .46401 .84627 L p
1 g
F P
s
P
p
.002 w
.46401 .84627 m .48177 .83767 L .44081 .81997 L p
1 g
F P
s
P
p
.002 w
.63782 .4324 m .62799 .41269 L .55655 .39173 L p
1 g
F P
s
P
p
.002 w
.73039 .65912 m .71444 .67887 L .70305 .72944 L p
1 g
F P
s
P
p
.002 w
.71444 .67887 m .73039 .65912 L .72182 .60346 L p
1 g
F P
s
P
p
.002 w
.73055 .57766 m .72182 .60346 L .73039 .65912 L p
1 g
F P
s
P
p
.002 w
.40018 .41929 m .39481 .40495 L .33051 .44901 L p
1 g
F P
s
P
p
.002 w
.33051 .44901 m .33354 .46491 L .40018 .41929 L p
1 g
F P
s
P
p
.002 w
.3018 .65622 m .28176 .63544 L .28308 .70192 L p
1 g
F P
s
P
p
.002 w
.28308 .70192 m .30288 .71926 L .3018 .65622 L p
1 g
F P
s
P
p
.002 w
.70305 .72944 m .6828 .73942 L .65852 .77877 L p
1 g
F P
s
P
p
.002 w
.6828 .73942 m .70305 .72944 L .71444 .67887 L p
1 g
F P
s
P
p
.002 w
.52893 .84207 m .57737 .83284 L p
.53789 .82622 L 1 g
F P
s
P
p
.002 w
.53685 .82656 m .52893 .84207 L p
.53789 .82622 L 1 g
F P
s
P
p
.002 w
.48177 .83767 m .52893 .84207 L p
.51221 .8307 L 1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.44081 .81997 m .48177 .83767 L p
.47926 .83222 L 1 g
F P
s
P
p
.47926 .83222 m .46497 .8258 L .44081 .81997 L 1 g
F
P
p
.002 w
.4637 .82523 m .46403 .82325 L p
.4545 .8211 L 1 g
F P
s
P
p
.48758 .82869 m .47758 .82884 L .47894 .82919 L 1 g
F
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.47926 .83222 m .47772 .82887 L .46497 .8258 L 1 g
F
P
p
.002 w
.44186 .81955 m .44081 .81997 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .4637 .82523 L p
1 g
F P
s
P
p
.002 w
.4637 .82523 m .46305 .82905 L p
.47758 .82884 L 1 g
F P
s
P
p
.48758 .82869 m .4637 .82523 L .47758 .82884 L 1 g
F
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.50031 .82261 m .46845 .80876 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48742 .8314 L p
1 g
F P
s
P
p
.002 w
.48177 .83767 m .48899 .83181 L p
.48742 .8314 L 1 g
F P
s
P
p
.51242 .82869 m .48742 .8314 L .48925 .83159 L 1 g
F
P
p
.51221 .8307 m .51215 .83066 L .48899 .83181 L 1 g
F
P
p
.002 w
.48925 .83159 m .48899 .83181 L p
.51215 .83066 L 1 g
F P
s
P
p
.51221 .8307 m .48899 .83181 L .5 .83275 L 1 g
F
P
p
.50241 .83106 m .48925 .83159 L .49672 .8324 L 1 g
F
P
p
.51242 .82869 m .48925 .83159 L .50241 .83106 L 1 g
F
P
p
.002 w
.48899 .83181 m .48465 .83533 L p
.5 .83275 L 1 g
F P
s
P
p
.002 w
.48465 .83533 m .48177 .83767 L p
.51221 .8307 L 1 g
F P
s
P
p
.002 w
.52893 .84207 m .53524 .82972 L p
.51253 .83064 L 1 g
F P
s
P
p
.51221 .8307 m .51253 .83064 L .51215 .83066 L 1 g
F
P
p
.52893 .84207 m .51253 .83064 L .51221 .8307 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51253 .83064 L p
1 g
F P
s
P
p
.53597 .82325 m .51253 .83064 L .52526 .82851 L 1 g
F
P
p
.002 w
.51253 .83064 m .51242 .82869 L p
.50241 .83106 L 1 g
F P
s
P
p
.002 w
.53654 .82661 m .53597 .82325 L p
.52526 .82851 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53654 .82661 L p
1 g
F P
s
P
p
.52572 .83011 m .53709 .82608 L .51215 .83066 L 1 g
F
P
p
.002 w
.53524 .82972 m .53688 .8265 L p
.52572 .83011 L 1 g
F P
s
P
p
.002 w
.53688 .8265 m .53709 .82608 L p
.52572 .83011 L 1 g
F P
s
P
p
.002 w
.57737 .83284 m .57491 .8189 L .53822 .82587 L p
1 g
F P
s
P
p
.57737 .83284 m .53822 .82587 L .53758 .82617 L 1 g
F
P
p
.55573 .81291 m .53654 .82661 L .53688 .8265 L 1 g
F
P
p
.53789 .82622 m .53758 .82617 L .53685 .82656 L 1 g
F
P
p
.002 w
.53688 .8265 m .53685 .82656 L p
.53758 .82617 L 1 g
F P
s
P
p
.57491 .8189 m .56121 .81214 L .55632 .81506 L 1 g
F
P
p
.002 w
.53822 .82587 m .54658 .82428 L p
.55632 .81506 L 1 g
F P
s
P
p
.002 w
.54658 .82428 m .57491 .8189 L p
.55632 .81506 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55632 .81506 L p
1 g
F P
s
P
p
.56958 .79874 m .55632 .81506 L .56381 .80797 L 1 g
F
P
p
.55573 .81291 m .53688 .8265 L .53822 .82587 L 1 g
F
P
p
.54618 .82111 m .53822 .82587 L .54358 .82335 L 1 g
F
P
p
.55573 .81291 m .53822 .82587 L .54618 .82111 L 1 g
F
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.57062 .80153 m .56958 .79874 L p
.56381 .80797 L 1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57062 .80153 L p
1 g
F P
s
P
p
.002 w
.57031 .7989 m .54432 .80382 L p
.56417 .8136 L 1 g
F P
s
P
p
.002 w
.57491 .8189 m .57083 .80114 L p
.56417 .8136 L 1 g
F P
s
P
p
.576 .78222 m .57062 .80153 L .57083 .80114 L 1 g
F
P
p
.002 w
.57491 .8189 m .60985 .80183 L p
.57182 .79901 L 1 g
F P
s
P
p
.002 w
.57083 .80114 m .57086 .8013 L p
.57182 .79901 L 1 g
F P
s
P
p
.002 w
.57086 .8013 m .57491 .8189 L p
.57198 .80004 L 1 g
F P
s
P
p
.57182 .79901 m .57086 .8013 L .57198 .80004 L 1 g
F
P
p
.002 w
.57083 .80114 m .57031 .7989 L p
.56417 .8136 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57063 .80156 L p
1 g
F P
s
P
p
.002 w
.57063 .80156 m .57062 .80153 L p
.57032 .80191 L 1 g
F P
s
P
p
.57032 .80191 m .55726 .81844 L .57063 .80156 L 1 g
F
P
p
.576 .78222 m .57083 .80114 L .57234 .79791 L 1 g
F
P
p
.59432 .78717 m .57839 .77997 L .57693 .7843 L 1 g
F
P
p
.002 w
.57234 .79791 m .5779 .79519 L p
.57693 .7843 L 1 g
F P
s
P
p
.002 w
.5779 .79519 m .59432 .78717 L p
.57693 .7843 L 1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57693 .7843 L p
1 g
F P
s
P
p
.57421 .76511 m .57693 .7843 L .57622 .77637 L 1 g
F
P
p
.576 .78222 m .57234 .79791 L .5734 .79476 L 1 g
F
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.60985 .80183 m .59432 .78717 L .57234 .79791 L p
1 g
F P
s
P
p
.002 w
.57234 .79791 m .57031 .7989 L p
.57182 .79901 L 1 g
F P
s
P
p
.60985 .80183 m .57234 .79791 L .57182 .79901 L 1 g
F
P
p
.002 w
.5715 .8039 m .57811 .78694 L .5778 .78625 L p
1 g
F P
s
P
p
.002 w
.5778 .78625 m .576 .78222 L p
.57307 .79634 L 1 g
F P
s
P
p
.57307 .79634 m .5715 .8039 L .5778 .78625 L 1 g
F
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.57693 .7843 m .56365 .77332 L .57234 .79791 L 1 g
F
P
p
.57839 .77997 m .57647 .7791 L .57693 .7843 L 1 g
F
P
p
.57647 .7791 m .56365 .77332 L .57693 .7843 L 1 g
F
P
p
.002 w
.57544 .76765 m .57421 .76511 L p
.57622 .77637 L 1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .57544 .76765 L p
1 g
F P
s
P
p
.56431 .74928 m .57544 .76765 L .57539 .76758 L 1 g
F
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.57343 .76441 m .55745 .74559 L p
.57539 .76758 L 1 g
F P
s
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56516 .75109 L p
1 g
F P
s
P
p
.56431 .74928 m .57539 .76758 L .57343 .76441 L 1 g
F
P
p
.002 w
.55745 .74559 m .57343 .76441 L p
.56516 .75109 L 1 g
F P
s
P
p
.57083 .76022 m .57343 .76441 L .57087 .76029 L 1 g
F
P
p
.56431 .74928 m .57343 .76441 L .57083 .76022 L 1 g
F
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.58125 .76257 m .58583 .75849 L p
.56344 .74831 L 1 g
F P
s
P
p
.54732 .73647 m .56516 .75109 L .56495 .75094 L 1 g
F
P
p
.54732 .73647 m .56518 .75113 L .55831 .7462 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.55745 .74559 m .55726 .74545 L .57539 .76758 L 1 g
F
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56365 .77332 m .57539 .76758 L p
.55726 .74545 L 1 g
F P
s
P
p
.002 w
.55548 .74418 m .56365 .77332 L p
.55726 .74545 L 1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55039 .77582 m .56365 .77332 L .55548 .74418 L p
1 g
F P
s
P
p
.54732 .73647 m .55831 .7462 L .55548 .74418 L 1 g
F
P
p
.54732 .73647 m .55548 .74418 L .55496 .7438 L 1 g
F
P
p
.002 w
.55467 .74359 m .53754 .77455 L p
.55496 .7438 L 1 g
F P
s
P
p
.002 w
.52647 .76966 m .53754 .77455 L .55467 .74359 L p
1 g
F P
s
P
p
.002 w
.55445 .74342 m .52647 .76966 L p
.55467 .74359 L 1 g
F P
s
P
p
.54732 .73647 m .55496 .7438 L .55456 .7435 L 1 g
F
P
p
.002 w
.51838 .76164 m .52647 .76966 L .55445 .74342 L p
1 g
F P
s
P
p
.002 w
.55423 .74326 m .51838 .76164 L p
.55445 .74342 L 1 g
F P
s
P
p
.002 w
.51416 .75135 m .51838 .76164 L .55423 .74326 L p
1 g
F P
s
P
p
.002 w
.55397 .74305 m .51416 .75135 L p
.55423 .74326 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52543 .72987 L p
1 g
F P
s
P
p
.5 .72527 m .52543 .72987 L .52529 .72986 L 1 g
F
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.52157 .72962 m .5523 .74171 L p
.54799 .73824 L 1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54799 .73824 L p
1 g
F P
s
P
p
.52506 .72815 m .54799 .73824 L .53725 .73426 L 1 g
F
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.52157 .72962 m .54799 .73824 L .52543 .72987 L 1 g
F
P
p
.002 w
.5143 .73989 m .55353 .7427 L p
.52145 .72961 L 1 g
F P
s
P
p
.002 w
.47299 .7333 m .5143 .73989 L .51843 .72941 L p
1 g
F P
s
P
p
.5 .72527 m .52543 .72988 L .51843 .72941 L 1 g
F
P
p
.5 .72527 m .51843 .72941 L .51562 .72899 L 1 g
F
P
p
.47299 .7333 m .51843 .72941 L .51507 .72891 L 1 g
F
P
p
.002 w
.51843 .72941 m .5143 .73989 L p
.52145 .72961 L 1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.47299 .7333 m .51507 .72891 L .5 .72668 L 1 g
F
P
p
.47299 .7333 m .5 .72668 L .47918 .7294 L 1 g
F
P
p
.002 w
.47454 .73001 m .47494 .72815 L p
.4876 .7283 L 1 g
F P
s
P
p
.002 w
.47422 .73015 m .47299 .7333 L p
.47918 .7294 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .72668 L p
1 g
F P
s
P
p
.47494 .72815 m .5 .72668 L .4876 .7283 L 1 g
F
P
p
.47918 .7294 m .48662 .7247 L .47454 .73001 L 1 g
F
P
p
.47918 .7294 m .47454 .73001 L .47422 .73015 L 1 g
F
P
p
.002 w
.5 .72668 m .5 .72845 L p
.4876 .7283 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47454 .73001 L p
1 g
F P
s
P
p
.4876 .7283 m .5 .72845 L .47454 .73001 L 1 g
F
P
p
.47918 .7294 m .5 .72668 L .48662 .7247 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47453 .73003 L p
1 g
F P
s
P
p
.45268 .73647 m .47453 .73003 L .47199 .73099 L 1 g
F
P
p
.002 w
.46871 .73224 m .47299 .7333 L .47422 .73015 L p
1 g
F P
s
P
p
.45268 .73647 m .47448 .73029 L .46422 .73376 L 1 g
F
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.43246 .72325 m .46871 .73224 L p
.48175 .71082 L 1 g
F P
s
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.47422 .73015 m .48175 .71082 L p
.46871 .73224 L 1 g
F P
s
P
p
.002 w
.47453 .73003 m .47448 .73029 L p
.47199 .73099 L 1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.47299 .7333 m .46871 .73224 L p
.43245 .75634 L 1 g
F P
s
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.43245 .75634 m .46871 .73224 L .45216 .73785 L 1 g
F
P
p
.43245 .75634 m .45216 .73785 L .43566 .75056 L 1 g
F
P
p
.002 w
.43477 .75124 m .43569 .74928 L p
.44284 .74502 L 1 g
F P
s
P
p
.002 w
.43245 .75505 m .43245 .75634 L p
.43566 .75056 L 1 g
F P
s
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45216 .73785 L p
1 g
F P
s
P
p
.43569 .74928 m .45216 .73785 L .44284 .74502 L 1 g
F
P
p
.43566 .75056 m .44052 .74179 L .43477 .75124 L 1 g
F
P
p
.43566 .75056 m .43477 .75124 L .43245 .75505 L 1 g
F
P
p
.002 w
.45216 .73785 m .45136 .73996 L p
.44284 .74502 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43477 .75124 L p
1 g
F P
s
P
p
.44284 .74502 m .45136 .73996 L .43477 .75124 L 1 g
F
P
p
.43566 .75056 m .45216 .73785 L .44052 .74179 L 1 g
F
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43466 .75147 L p
1 g
F P
s
P
p
.42579 .76511 m .43466 .75147 L .43284 .75442 L 1 g
F
P
p
.42579 .76511 m .43436 .75211 L .43048 .75816 L 1 g
F
P
p
.002 w
.39417 .75268 m .4317 .75626 L p
.43246 .72325 L 1 g
F P
s
P
p
.002 w
.4317 .75626 m .43245 .75634 L .43245 .75505 L p
1 g
F P
s
P
p
.002 w
.43245 .75505 m .43246 .72325 L p
.4317 .75626 L 1 g
F P
s
P
p
.002 w
.43466 .75147 m .43436 .75211 L p
.43284 .75442 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.41047 .79066 m .42489 .76814 L .425 .76712 L 1 g
F
P
p
.002 w
.424 .78222 m .42579 .76511 L .42505 .76664 L p
1 g
F P
s
P
p
.424 .78222 m .42505 .76664 L .42389 .77731 L 1 g
F
P
p
.002 w
.41014 .7899 m .41047 .79066 L p
.4317 .75626 L 1 g
F P
s
P
p
.002 w
.42315 .78411 m .424 .78222 L p
.42389 .77731 L 1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.44495 .78588 m .43245 .75634 L p
.42048 .77502 L 1 g
F P
s
P
p
.002 w
.41047 .79066 m .42451 .78871 L p
.42048 .77502 L 1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42281 .78489 L p
1 g
F P
s
P
p
.002 w
.41047 .79066 m .43665 .81595 L p
.42976 .8005 L 1 g
F P
s
P
p
.002 w
.42451 .78871 m .41954 .7894 L p
.42976 .8005 L 1 g
F P
s
P
p
.002 w
.41954 .7894 m .41047 .79066 L p
.42976 .8005 L 1 g
F P
s
P
p
.002 w
.44356 .81548 m .44427 .81291 L p
.43778 .8092 L 1 g
F P
s
P
p
.43042 .79874 m .42281 .78489 L .42667 .79356 L 1 g
F
P
p
.002 w
.42877 .80318 m .43042 .79874 L p
.42543 .79184 L 1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42976 .8005 L p
1 g
F P
s
P
p
.44427 .81291 m .42976 .8005 L .43778 .8092 L 1 g
F
P
p
.002 w
.44495 .78588 m .42451 .78871 L p
.43182 .80273 L 1 g
F P
s
P
p
.44081 .81997 m .44161 .81337 L .43182 .80273 L 1 g
F
P
p
.44161 .81337 m .44495 .78588 L .43182 .80273 L 1 g
F
P
p
.002 w
.43665 .81595 m .44081 .81997 L p
.42451 .78871 L 1 g
F P
s
P
p
.002 w
.42976 .8005 m .4285 .8039 L p
.43778 .8092 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.44081 .81997 m .44669 .81759 L p
.44152 .81411 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44339 .81611 L p
1 g
F P
s
P
p
.46403 .82325 m .44339 .81611 L .4545 .8211 L 1 g
F
P
p
.002 w
.46845 .80876 m .44669 .81759 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.44669 .81759 m .44186 .81955 L p
.4637 .82523 L 1 g
F P
s
P
p
.47772 .82887 m .44669 .81759 L .4637 .82523 L 1 g
F
P
p
.002 w
.44339 .81611 m .44274 .81844 L p
.4545 .8211 L 1 g
F P
s
P
p
.002 w
.46845 .80876 m .44495 .78588 L p
.44152 .81411 L 1 g
F P
s
P
p
.002 w
.44669 .81759 m .46845 .80876 L p
.44152 .81411 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46311 .82866 L p
1 g
F P
s
P
p
.002 w
.46311 .82866 m .4637 .82523 L p
.45278 .82169 L 1 g
F P
s
P
p
.45278 .82169 m .44274 .81844 L .46311 .82866 L 1 g
F
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44356 .81548 L p
1 g
F P
s
P
p
.43778 .8092 m .4285 .8039 L .44356 .81548 L 1 g
F
P
p
.002 w
.42281 .78489 m .42189 .78694 L p
.42667 .79356 L 1 g
F P
s
P
p
.002 w
.42451 .78871 m .44495 .78588 L p
.42048 .77502 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42877 .80318 L p
1 g
F P
s
P
p
.42543 .79184 m .42189 .78694 L .42877 .80318 L 1 g
F
P
p
.002 w
.42505 .76664 m .42372 .76938 L p
.42389 .77731 L 1 g
F P
s
P
p
.002 w
.39417 .75268 m .41014 .7899 L p
.42505 .76664 L 1 g
F P
s
P
p
.002 w
.4317 .75626 m .42623 .75574 L p
.42505 .76664 L 1 g
F P
s
P
p
.002 w
.42623 .75574 m .39417 .75268 L p
.42505 .76664 L 1 g
F P
s
P
p
.002 w
.43245 .75634 m .4317 .75626 L p
.425 .76712 L 1 g
F P
s
P
p
.42489 .76814 m .43245 .75634 L .425 .76712 L 1 g
F
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42315 .78411 L p
1 g
F P
s
P
p
.42389 .77731 m .42372 .76938 L .42315 .78411 L 1 g
F
P
p
.002 w
.43436 .75211 m .43389 .75311 L p
.43048 .75816 L 1 g
F P
s
P
p
.002 w
.43245 .74452 m .43245 .75505 L p
.44052 .74179 L 1 g
F P
s
P
p
.002 w
.42372 .76938 m .42579 .76511 L p
.43121 .75708 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .4238 .76925 L p
.43121 .75708 L 1 g
F P
s
P
p
.002 w
.4238 .76925 m .42372 .76938 L p
.43121 .75708 L 1 g
F P
s
P
p
.002 w
.47448 .73029 m .47424 .73141 L p
.46422 .73376 L 1 g
F P
s
P
p
.002 w
.45136 .73996 m .45268 .73647 L p
.468 .73288 L 1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.46871 .73224 m .43246 .72325 L .43245 .74452 L p
1 g
F P
s
P
p
.002 w
.4769 .72326 m .47422 .73015 L p
.48662 .7247 L 1 g
F P
s
P
p
.002 w
.47424 .73141 m .45475 .73869 L p
.468 .73288 L 1 g
F P
s
P
p
.002 w
.45475 .73869 m .45136 .73996 L p
.468 .73288 L 1 g
F P
s
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72668 L p
1 g
F P
s
P
p
.002 w
.5 .72668 m .5 .72527 L p
.51562 .72899 L 1 g
F P
s
P
p
.51562 .72899 m .52576 .73141 L .5 .72668 L 1 g
F
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.51878 .72852 m .48175 .71082 L .4769 .72326 L p
1 g
F P
s
P
p
.51507 .72891 m .51878 .72852 L .4769 .72326 L 1 g
F
P
p
.002 w
.51843 .72941 m .51878 .72852 L p
.51507 .72891 L 1 g
F P
s
P
p
.51562 .72899 m .51843 .72941 L .51694 .72931 L 1 g
F
P
p
.002 w
.5523 .74171 m .52157 .72962 L p
.55353 .7427 L 1 g
F P
s
P
p
.002 w
.52157 .72962 m .51878 .72852 L p
.52145 .72961 L 1 g
F P
s
P
p
.55353 .7427 m .52157 .72962 L .52145 .72961 L 1 g
F
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52543 .72987 L p
1 g
F P
s
P
p
.002 w
.52543 .72987 m .52506 .72815 L p
.53725 .73426 L 1 g
F P
s
P
p
.53725 .73426 m .54864 .73996 L .52543 .72987 L 1 g
F
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.52202 .7286 m .53863 .7307 L .52567 .72025 L 1 g
F
P
p
.52157 .72962 m .52543 .72987 L .52202 .7286 L 1 g
F
P
p
.52543 .72987 m .53863 .7307 L .52202 .7286 L 1 g
F
P
p
.52543 .72987 m .54799 .73824 L .53863 .7307 L 1 g
F
P
p
.002 w
.54799 .73824 m .54864 .73996 L p
.53725 .73426 L 1 g
F P
s
P
p
.002 w
.52567 .72025 m .51878 .72852 L .52157 .72962 L p
1 g
F P
s
P
p
.002 w
.52543 .72987 m .52543 .72988 L p
.52529 .72986 L 1 g
F P
s
P
p
.002 w
.52543 .72988 m .52576 .73141 L p
.51694 .72931 L 1 g
F P
s
P
p
.002 w
.51878 .72852 m .51843 .72941 L p
.52145 .72961 L 1 g
F P
s
P
p
.54732 .73647 m .55456 .7435 L .55411 .74316 L 1 g
F
P
p
.55395 .74304 m .55411 .74316 L .55397 .74306 L 1 g
F
P
p
.54732 .73647 m .55411 .74316 L .55395 .74304 L 1 g
F
P
p
.002 w
.5143 .73989 m .51416 .75135 L .55397 .74305 L p
1 g
F P
s
P
p
.002 w
.55353 .7427 m .5143 .73989 L p
.55397 .74305 L 1 g
F P
s
P
p
.54732 .73647 m .55397 .74306 L .55376 .74289 L 1 g
F
P
p
.002 w
.54799 .73824 m .54732 .73647 L p
.55379 .74292 L 1 g
F P
s
P
p
.002 w
.55397 .74305 m .5551 .74281 L .55353 .7427 L p
1 g
F P
s
P
p
.002 w
.55353 .7427 m .5551 .74281 L .5523 .74171 L p
1 g
F P
s
P
p
.55376 .74289 m .55397 .74306 L .55379 .74292 L 1 g
F
P
p
.002 w
.54811 .73857 m .54799 .73824 L p
.55379 .74292 L 1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.5551 .74281 m .52714 .71848 L .52567 .72025 L p
1 g
F P
s
P
p
.002 w
.5523 .74171 m .5551 .74281 L p
.52567 .72025 L 1 g
F P
s
P
p
.002 w
.55423 .74326 m .5551 .74281 L .55397 .74305 L p
1 g
F P
s
P
p
.002 w
.54822 .73883 m .54811 .73857 L p
.55423 .74326 L 1 g
F P
s
P
p
.55423 .74326 m .55456 .7435 L .55445 .74343 L 1 g
F
P
p
.55423 .74326 m .55445 .74343 L .54822 .73883 L 1 g
F
P
p
.002 w
.55445 .74342 m .5551 .74281 L .55423 .74326 L p
1 g
F P
s
P
p
.002 w
.55467 .74359 m .5551 .74281 L .55445 .74342 L p
1 g
F P
s
P
p
.002 w
.54826 .73894 m .54822 .73883 L p
.55467 .74359 L 1 g
F P
s
P
p
.55467 .74359 m .55496 .7438 L .5548 .74368 L 1 g
F
P
p
.55467 .74359 m .5548 .74368 L .54826 .73894 L 1 g
F
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.53754 .77455 m .55039 .77582 L .55496 .7438 L p
1 g
F P
s
P
p
.002 w
.55496 .7438 m .5551 .74281 L .55467 .74359 L p
1 g
F P
s
P
p
.002 w
.55548 .74418 m .5551 .74281 L .55496 .7438 L p
1 g
F P
s
P
p
.002 w
.55496 .7438 m .55039 .77582 L p
.55548 .74418 L 1 g
F P
s
P
p
.002 w
.54829 .73902 m .54826 .73894 L p
.55548 .74418 L 1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54829 .73902 L p
1 g
F P
s
P
p
.55831 .7462 m .56611 .75311 L .54829 .73902 L 1 g
F
P
p
.002 w
.5551 .74281 m .55548 .74418 L p
.55726 .74545 L 1 g
F P
s
P
p
.56344 .74831 m .55745 .74559 L .56516 .75109 L 1 g
F
P
p
.002 w
.57539 .76758 m .56365 .77332 L p
.58551 .78319 L 1 g
F P
s
P
p
.002 w
.57811 .78694 m .57628 .76938 L .57544 .76765 L p
1 g
F P
s
P
p
.57622 .77637 m .57811 .78694 L .57544 .76765 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56431 .74928 L p
1 g
F P
s
P
p
.56344 .74831 m .56516 .75109 L .58125 .76257 L 1 g
F
P
p
.002 w
.5759 .76733 m .58125 .76257 L p
.56516 .75109 L 1 g
F P
s
P
p
.002 w
.57343 .76441 m .5759 .76733 L p
.56516 .75109 L 1 g
F P
s
P
p
.57087 .76029 m .57343 .76441 L .57311 .76405 L 1 g
F
P
p
.57343 .76441 m .57539 .76758 L .57536 .76753 L 1 g
F
P
p
.57343 .76441 m .57536 .76753 L .57311 .76405 L 1 g
F
P
p
.002 w
.56516 .75109 m .56518 .75113 L p
.56495 .75094 L 1 g
F P
s
P
p
.002 w
.58583 .75849 m .5551 .74281 L .55745 .74559 L p
1 g
F P
s
P
p
.002 w
.55745 .74559 m .5551 .74281 L p
.55726 .74545 L 1 g
F P
s
P
p
.002 w
.56518 .75113 m .56611 .75311 L p
.55831 .7462 L 1 g
F P
s
P
p
.002 w
.57539 .76758 m .5759 .76733 L .57343 .76441 L p
1 g
F P
s
P
p
.002 w
.59432 .78717 m .5759 .76733 L .57539 .76758 L p
1 g
F P
s
P
p
.59432 .78717 m .57539 .76758 L .58551 .78319 L 1 g
F
P
p
.002 w
.57544 .76765 m .57628 .76938 L p
.57311 .76405 L 1 g
F P
s
P
p
.002 w
.57693 .7843 m .57811 .78694 L p
.57622 .77637 L 1 g
F P
s
P
p
.5734 .79476 m .57234 .79791 L .57307 .79634 L 1 g
F
P
p
.002 w
.56365 .77332 m .57031 .7989 L .57234 .79791 L p
1 g
F P
s
P
p
.57307 .79634 m .57083 .80114 L .57287 .79731 L 1 g
F
P
p
.002 w
.57031 .7989 m .57083 .80114 L p
.57182 .79901 L 1 g
F P
s
P
p
.002 w
.57062 .80153 m .5715 .8039 L p
.57287 .79731 L 1 g
F P
s
P
p
.56121 .81214 m .56002 .81156 L .55632 .81506 L 1 g
F
P
p
.56381 .80797 m .55726 .81844 L .57062 .80153 L 1 g
F
P
p
.55632 .81506 m .54432 .80382 L .53822 .82587 L 1 g
F
P
p
.56002 .81156 m .54432 .80382 L .55632 .81506 L 1 g
F
P
p
.002 w
.55632 .81506 m .55726 .81844 L p
.56381 .80797 L 1 g
F P
s
P
p
.002 w
.54432 .80382 m .53709 .82608 L .53822 .82587 L p
1 g
F P
s
P
p
.54358 .82335 m .53822 .82587 L .54175 .82492 L 1 g
F
P
p
.53822 .82587 m .53688 .8265 L .5375 .8263 L 1 g
F
P
p
.53822 .82587 m .5375 .8263 L .54175 .82492 L 1 g
F
P
p
.002 w
.53709 .82608 m .53688 .8265 L p
.53758 .82617 L 1 g
F P
s
P
p
.002 w
.53822 .82587 m .53709 .82608 L p
.53758 .82617 L 1 g
F P
s
P
p
.54175 .82492 m .53688 .8265 L .53695 .82905 L 1 g
F
P
p
.002 w
.53654 .82661 m .53655 .82666 L p
.53688 .8265 L 1 g
F P
s
P
p
.002 w
.53655 .82666 m .53695 .82905 L p
.53688 .8265 L 1 g
F P
s
P
p
.002 w
.51253 .83064 m .51276 .83464 L p
.52526 .82851 L 1 g
F P
s
P
p
.002 w
.48724 .83464 m .51276 .83464 L .51253 .83064 L p
1 g
F P
s
P
p
.50241 .83106 m .48724 .83464 L .51253 .83064 L 1 g
F
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.53709 .82608 m .50031 .82261 L p
.51215 .83066 L 1 g
F P
s
P
p
.002 w
.50031 .82261 m .48925 .83159 L p
.51215 .83066 L 1 g
F P
s
P
p
.47844 .83043 m .48742 .8314 L .47772 .82887 L 1 g
F
P
p
.48177 .83767 m .48742 .8314 L .47844 .83043 L 1 g
F
P
p
.002 w
.48741 .83167 m .48758 .82869 L p
.4667 .82989 L 1 g
F P
s
P
p
.002 w
.48899 .83181 m .50031 .82261 L p
.47772 .82887 L 1 g
F P
s
P
p
.002 w
.48742 .8314 m .48724 .83464 L p
.49672 .8324 L 1 g
F P
s
P
p
.4545 .8211 m .44274 .81844 L .4637 .82523 L 1 g
F
P
p
.002 w
.46305 .82905 m .4667 .82989 L p
.47894 .82919 L 1 g
F P
s
P
p
.47758 .82884 m .46305 .82905 L .47894 .82919 L 1 g
F
P
p
.002 w
.4667 .82989 m .48724 .83464 L .48741 .83167 L p
1 g
F P
s
P
p
.002 w
.53655 .82666 m .53654 .82661 L p
.51434 .83386 L 1 g
F P
s
P
p
.52526 .82851 m .51434 .83386 L .53654 .82661 L 1 g
F
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53655 .82666 L p
1 g
F P
s
P
p
.51434 .83386 m .51276 .83464 L .53655 .82666 L 1 g
F
P
p
.002 w
.57491 .8189 m .57737 .83284 L .62209 .811 L p
1 g
F P
s
P
p
.002 w
.62209 .811 m .60985 .80183 L .57491 .8189 L p
1 g
F P
s
P
p
.002 w
.60985 .80183 m .62209 .811 L .65852 .77877 L p
1 g
F P
s
P
p
.002 w
.46948 .38048 m .47755 .39392 L .55655 .39173 L p
1 g
F P
s
P
p
.002 w
.47755 .39392 m .46948 .38048 L .39481 .40495 L p
1 g
F P
s
P
p
.002 w
.72182 .60346 m .73055 .57766 L .6983 .52524 L p
1 g
F P
s
P
p
.002 w
.69892 .49778 m .6983 .52524 L .73055 .57766 L p
1 g
F P
s
P
p
.002 w
.39481 .40495 m .40018 .41929 L .47755 .39392 L p
1 g
F P
s
P
p
.002 w
.30604 .56868 m .29273 .54592 L .26804 .61426 L p
1 g
F P
s
P
p
.002 w
.26804 .61426 m .28176 .63544 L .30604 .56868 L p
1 g
F P
s
P
p
.002 w
.3413 .48519 m .33354 .46491 L .28536 .52531 L p
1 g
F P
s
P
p
.002 w
.28536 .52531 m .29273 .54592 L .3413 .48519 L p
1 g
F P
s
P
p
.002 w
.65852 .77877 m .63826 .77665 L .60985 .80183 L p
1 g
F P
s
P
p
.002 w
.63826 .77665 m .65852 .77877 L .6828 .73942 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.41047 .79066 m .37884 .79037 L .41517 .82526 L p
1 g
F P
s
P
p
.002 w
.41517 .82526 m .44081 .81997 L .41047 .79066 L p
1 g
F P
s
P
p
.002 w
.6983 .52524 m .69892 .49778 L .64392 .45742 L p
1 g
F P
s
P
p
.002 w
.63782 .4324 m .64392 .45742 L .69892 .49778 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.35918 .74508 m .32847 .73381 L .35095 .78512 L p
1 g
F P
s
P
p
.002 w
.35095 .78512 m .37884 .79037 L .35918 .74508 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.55655 .39173 m .56592 .41142 L .63782 .4324 L p
1 g
F P
s
P
p
.002 w
.56592 .41142 m .55655 .39173 L .47755 .39392 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.64392 .45742 m .63782 .4324 L .56592 .41142 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.71444 .67887 m .69227 .69699 L .6828 .73942 L p
1 g
F P
s
P
p
.002 w
.69227 .69699 m .71444 .67887 L .70675 .62981 L p
1 g
F P
s
P
p
.002 w
.72182 .60346 m .70675 .62981 L .71444 .67887 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.32767 .67598 m .3018 .65622 L .30288 .71926 L p
1 g
F P
s
P
p
.002 w
.30288 .71926 m .32847 .73381 L .32767 .67598 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.6828 .73942 m .65714 .74595 L .63826 .77665 L p
1 g
F P
s
P
p
.002 w
.65714 .74595 m .6828 .73942 L .69227 .69699 L p
1 g
F P
s
P
p
.002 w
.40845 .43928 m .40018 .41929 L .33354 .46491 L p
1 g
F P
s
P
p
.002 w
.33354 .46491 m .3413 .48519 L .40845 .43928 L p
1 g
F P
s
P
p
.002 w
.70675 .62981 m .72182 .60346 L .6921 .55548 L p
1 g
F P
s
P
p
.002 w
.6983 .52524 m .6921 .55548 L .72182 .60346 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.32501 .59294 m .30604 .56868 L .28176 .63544 L p
1 g
F P
s
P
p
.002 w
.28176 .63544 m .3018 .65622 L .32501 .59294 L p
1 g
F P
s
P
p
.002 w
.59432 .78717 m .60985 .80183 L .63826 .77665 L p
1 g
F P
s
P
p
.002 w
.47755 .39392 m .48638 .41371 L .56592 .41142 L p
1 g
F P
s
P
p
.002 w
.48638 .41371 m .47755 .39392 L .40018 .41929 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.35366 .50933 m .3413 .48519 L .29273 .54592 L p
1 g
F P
s
P
p
.002 w
.29273 .54592 m .30604 .56868 L .35366 .50933 L p
1 g
F P
s
P
p
.002 w
.51908 .8014 m .50031 .82261 L .53709 .82608 L p
1 g
F P
s
P
p
.002 w
.53709 .82608 m .54432 .80382 L .51908 .8014 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.40018 .41929 m .40845 .43928 L .48638 .41371 L p
1 g
F P
s
P
p
.002 w
.6921 .55548 m .6983 .52524 L .64603 .48711 L p
1 g
F P
s
P
p
.002 w
.64392 .45742 m .64603 .48711 L .6983 .52524 L p
1 g
F P
s
P
p
.002 w
.39417 .75268 m .35918 .74508 L .37884 .79037 L p
1 g
F P
s
P
p
.002 w
.37884 .79037 m .41047 .79066 L .39417 .75268 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.63826 .77665 m .61382 .76986 L .59432 .78717 L p
1 g
F P
s
P
p
.002 w
.61382 .76986 m .63826 .77665 L .65714 .74595 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.64603 .48711 m .64392 .45742 L .57356 .43704 L p
1 g
F P
s
P
p
.002 w
.56592 .41142 m .57356 .43704 L .64392 .45742 L p
1 g
F P
s
P
p
.002 w
.57356 .43704 m .56592 .41142 L .48638 .41371 L p
1 g
F P
s
P
p
.002 w
.49729 .79184 m .46845 .80876 L .50031 .82261 L p
1 g
F P
s
P
p
.002 w
.50031 .82261 m .51908 .8014 L .49729 .79184 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.35869 .69412 m .32767 .67598 L .32847 .73381 L p
1 g
F P
s
P
p
.002 w
.32847 .73381 m .35918 .74508 L .35869 .69412 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.69227 .69699 m .66441 .71292 L .65714 .74595 L p
1 g
F P
s
P
p
.002 w
.66441 .71292 m .69227 .69699 L .68568 .65594 L p
1 g
F P
s
P
p
.002 w
.70675 .62981 m .68568 .65594 L .69227 .69699 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.68568 .65594 m .70675 .62981 L .68039 .58763 L p
1 g
F P
s
P
p
.002 w
.6921 .55548 m .68039 .58763 L .70675 .62981 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.65714 .74595 m .62672 .74878 L .61382 .76986 L p
1 g
F P
s
P
p
.002 w
.62672 .74878 m .65714 .74595 L .66441 .71292 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.34916 .61799 m .32501 .59294 L .3018 .65622 L p
1 g
F P
s
P
p
.002 w
.3018 .65622 m .32767 .67598 L .34916 .61799 L p
1 g
F P
s
P
p
.002 w
.41943 .46444 m .40845 .43928 L .3413 .48519 L p
1 g
F P
s
P
p
.002 w
.3413 .48519 m .35366 .50933 L .41943 .46444 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.68039 .58763 m .6921 .55548 L .64402 .52067 L p
1 g
F P
s
P
p
.002 w
.64603 .48711 m .64402 .52067 L .6921 .55548 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.55039 .77582 m .54432 .80382 L .57031 .7989 L p
1 g
F P
s
P
p
.002 w
.57031 .7989 m .56365 .77332 L .55039 .77582 L p
1 g
F P
s
P
p
.002 w
.48129 .77613 m .44495 .78588 L .46845 .80876 L p
1 g
F P
s
P
p
.002 w
.46845 .80876 m .49729 .79184 L .48129 .77613 L p
1 g
F P
s
P
p
.002 w
.5759 .76733 m .59432 .78717 L .61382 .76986 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.37034 .53669 m .35366 .50933 L .30604 .56868 L p
1 g
F P
s
P
p
.002 w
.30604 .56868 m .32501 .59294 L .37034 .53669 L p
1 g
F P
s
P
p
.002 w
.48638 .41371 m .49572 .43938 L .57356 .43704 L p
1 g
F P
s
P
p
.002 w
.49572 .43938 m .48638 .41371 L .40845 .43928 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.53754 .77455 m .51908 .8014 L .54432 .80382 L p
1 g
F P
s
P
p
.002 w
.54432 .80382 m .55039 .77582 L .53754 .77455 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.40845 .43928 m .41943 .46444 L .49572 .43938 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.61382 .76986 m .58583 .75849 L .5759 .76733 L p
1 g
F P
s
P
p
.002 w
.58583 .75849 m .61382 .76986 L .62672 .74878 L p
1 g
F P
s
P
p
.002 w
.39397 .71004 m .35869 .69412 L .35918 .74508 L p
1 g
F P
s
P
p
.002 w
.35918 .74508 m .39417 .75268 L .39397 .71004 L p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.66441 .71292 m .63161 .72615 L .62672 .74878 L p
1 g
F P
s
P
p
.002 w
.63161 .72615 m .66441 .71292 L .65915 .68106 L p
1 g
F P
s
P
p
.002 w
.68568 .65594 m .65915 .68106 L .66441 .71292 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.64402 .52067 m .64603 .48711 L .5792 .46794 L p
1 g
F P
s
P
p
.002 w
.57356 .43704 m .5792 .46794 L .64603 .48711 L p
1 g
F P
s
P
p
.002 w
.65915 .68106 m .68568 .65594 L .66346 .62075 L p
1 g
F P
s
P
p
.002 w
.68039 .58763 m .66346 .62075 L .68568 .65594 L p
1 g
F P
s
P
p
.002 w
.52647 .76966 m .49729 .79184 L .51908 .8014 L p
1 g
F P
s
P
p
.002 w
.51908 .8014 m .53754 .77455 L .52647 .76966 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.5792 .46794 m .57356 .43704 L .49572 .43938 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.62672 .74878 m .59237 .74774 L .58583 .75849 L p
1 g
F P
s
P
p
.002 w
.59237 .74774 m .62672 .74878 L .63161 .72615 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.37782 .64307 m .34916 .61799 L .32767 .67598 L p
1 g
F P
s
P
p
.002 w
.32767 .67598 m .35869 .69412 L .37782 .64307 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.47286 .7559 m .43245 .75634 L .44495 .78588 L p
1 g
F P
s
P
p
.002 w
.44495 .78588 m .48129 .77613 L .47286 .7559 L p
1 g
F P
s
P
p
.002 w
.66346 .62075 m .68039 .58763 L .6379 .55713 L p
1 g
F P
s
P
p
.002 w
.64402 .52067 m .6379 .55713 L .68039 .58763 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.51838 .76164 m .48129 .77613 L .49729 .79184 L p
1 g
F P
s
P
p
.002 w
.49729 .79184 m .52647 .76966 L .51838 .76164 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.43284 .49411 m .41943 .46444 L .35366 .50933 L p
1 g
F P
s
P
p
.002 w
.35366 .50933 m .37034 .53669 L .43284 .49411 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.43246 .72325 m .39397 .71004 L .39417 .75268 L p
1 g
F P
s
P
p
.002 w
.39089 .56646 m .37034 .53669 L .32501 .59294 L p
1 g
F P
s
P
p
.002 w
.32501 .59294 m .34916 .61799 L .39089 .56646 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.63161 .72615 m .59481 .73623 L .59237 .74774 L p
1 g
F P
s
P
p
.002 w
.59481 .73623 m .63161 .72615 L .62791 .70439 L p
1 g
F P
s
P
p
.002 w
.65915 .68106 m .62791 .70439 L .63161 .72615 L p
1 g
F P
s
P
p
.002 w
.62791 .70439 m .65915 .68106 L .64176 .65383 L p
1 g
F P
s
P
p
.002 w
.66346 .62075 m .64176 .65383 L .65915 .68106 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.49572 .43938 m .50529 .47028 L .5792 .46794 L p
1 g
F P
s
P
p
.002 w
.50529 .47028 m .49572 .43938 L .41943 .46444 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.6379 .55713 m .64402 .52067 L .58265 .50325 L p
1 g
F P
s
P
p
.002 w
.5792 .46794 m .58265 .50325 L .64402 .52067 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.59237 .74774 m .5551 .74281 L .58583 .75849 L closepath p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.41943 .46444 m .43284 .49411 L .50529 .47028 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.51416 .75135 m .47286 .7559 L .48129 .77613 L p
1 g
F P
s
P
p
.002 w
.48129 .77613 m .51838 .76164 L .51416 .75135 L p
1 g
F P
s
P
p
.002 w
.59481 .73623 m .5551 .74281 L .59237 .74774 L closepath p
1 g
F P
s
P
p
.002 w
.58265 .50325 m .5792 .46794 L .50529 .47028 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.64176 .65383 m .66346 .62075 L .62779 .59539 L p
1 g
F P
s
P
p
.002 w
.6379 .55713 m .62779 .59539 L .66346 .62075 L p
1 g
F P
s
P
p
.002 w
.41015 .66741 m .37782 .64307 L .35869 .69412 L p
1 g
F P
s
P
p
.002 w
.35869 .69412 m .39397 .71004 L .41015 .66741 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.43245 .75634 m .47286 .7559 L .47299 .7333 L p
1 g
F P
s
P
p
.002 w
.62791 .70439 m .59287 .72519 L .59481 .73623 L p
1 g
F P
s
P
p
.002 w
.59287 .72519 m .62791 .70439 L .61593 .68586 L p
1 g
F P
s
P
p
.002 w
.64176 .65383 m .61593 .68586 L .62791 .70439 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.59287 .72519 m .5551 .74281 L .59481 .73623 L closepath p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.41472 .59775 m .39089 .56646 L .34916 .61799 L p
1 g
F P
s
P
p
.002 w
.34916 .61799 m .37782 .64307 L .41472 .59775 L p
1 g
F P
s
P
p
.002 w
.4483 .52743 m .43284 .49411 L .37034 .53669 L p
1 g
F P
s
P
p
.002 w
.37034 .53669 m .39089 .56646 L .4483 .52743 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.62779 .59539 m .6379 .55713 L .58375 .54196 L p
1 g
F P
s
P
p
.002 w
.58265 .50325 m .58375 .54196 L .6379 .55713 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.61593 .68586 m .64176 .65383 L .61399 .63429 L p
1 g
F P
s
P
p
.002 w
.62779 .59539 m .61399 .63429 L .64176 .65383 L p
1 g
F P
s
P
p
.002 w
.5143 .73989 m .47299 .7333 L .47286 .7559 L p
1 g
F P
s
P
p
.002 w
.47286 .7559 m .51416 .75135 L .5143 .73989 L p
1 g
F P
s
P
p
.002 w
.58674 .71583 m .5551 .74281 L .59287 .72519 L closepath p
1 g
F P
s
P
p
.002 w
.61593 .68586 m .58674 .71583 L .59287 .72519 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.44515 .69023 m .41015 .66741 L .39397 .71004 L p
1 g
F P
s
P
p
.002 w
.39397 .71004 m .43246 .72325 L .44515 .69023 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.57706 .70917 m .5551 .74281 L .58674 .71583 L closepath p
1 g
F P
s
P
p
.002 w
.56489 .70595 m .5551 .74281 L .57706 .70917 L closepath p
1 g
F P
s
P
p
.002 w
.55154 .70654 m .5551 .74281 L .56489 .70595 L closepath p
1 g
F P
s
P
p
.002 w
.53848 .71087 m .5551 .74281 L .55154 .70654 L closepath p
1 g
F P
s
P
p
.004 w
.5 .6118 m
.54127 .70994 L
s
P
p
.002 w
.52714 .71848 m .5551 .74281 L .53848 .71087 L closepath p
1 g
F P
s
P
p
.002 w
.50529 .47028 m .5148 .50553 L .58265 .50325 L p
1 g
F P
s
P
p
.002 w
.5148 .50553 m .50529 .47028 L .43284 .49411 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.58674 .71583 m .61593 .68586 L .5969 .67262 L p
1 g
F P
s
P
p
.002 w
.61399 .63429 m .5969 .67262 L .61593 .68586 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.004 w
.5551 .74281 m
.55671 .74666 L
s
P
p
.002 w
.58375 .54196 m .58265 .50325 L .5148 .50553 L p
1 g
F P
s
P
p
.002 w
.43284 .49411 m .4483 .52743 L .5148 .50553 L p
1 g
F P
s
P
p
.002 w
.5969 .67262 m .57706 .70917 L .58674 .71583 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.48175 .71082 m .44515 .69023 L .43246 .72325 L p
1 g
F P
s
P
p
.002 w
.61399 .63429 m .62779 .59539 L .58246 .58287 L p
1 g
F P
s
P
p
.002 w
.58375 .54196 m .58246 .58287 L .62779 .59539 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.44111 .62959 m .41472 .59775 L .37782 .64307 L p
1 g
F P
s
P
p
.002 w
.37782 .64307 m .41015 .66741 L .44111 .62959 L p
1 g
F P
s
P
p
.002 w
.57706 .70917 m .5969 .67262 L .57287 .66617 L p
1 g
F P
s
P
p
.002 w
.57287 .66617 m .56489 .70595 L .57706 .70917 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.48175 .71082 m .51878 .72852 L .52714 .71848 L p
1 g
F P
s
P
p
.002 w
.46536 .56341 m .4483 .52743 L .39089 .56646 L p
1 g
F P
s
P
p
.002 w
.39089 .56646 m .41472 .59775 L .46536 .56341 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.5969 .67262 m .61399 .63429 L .57879 .62471 L p
1 g
F P
s
P
p
.002 w
.58246 .58287 m .57879 .62471 L .61399 .63429 L p
1 g
F P
s
P
p
.002 w
.57879 .62471 m .57287 .66617 L .5969 .67262 L p
1 g
F P
s
P
p
.002 w
.56489 .70595 m .57287 .66617 L .54647 .66728 L p
1 g
F P
s
P
p
.002 w
.54647 .66728 m .55154 .70654 L .56489 .70595 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.52714 .71848 m .49822 .69092 L .48175 .71082 L p
1 g
F P
s
P
p
.002 w
.49822 .69092 m .52714 .71848 L .53848 .71087 L p
1 g
F P
s
P
p
.002 w
.58246 .58287 m .58375 .54196 L .52396 .54408 L p
1 g
F P
s
P
p
.002 w
.5148 .50553 m .52396 .54408 L .58375 .54196 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55154 .70654 m .54647 .66728 L .52063 .67584 L p
1 g
F P
s
P
p
.002 w
.52063 .67584 m .53848 .71087 L .55154 .70654 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.52396 .54408 m .5148 .50553 L .4483 .52743 L p
1 g
F P
s
P
p
.004 w
.4772 .53379 m
.5 .6118 L
s
P
p
.004 w
.46246 .48333 m
.47479 .52555 L
s
P
p
.002 w
.53848 .71087 m .52063 .67584 L .49822 .69092 L p
1 g
F P
s
P
p
.002 w
.46924 .66098 m .44111 .62959 L .41015 .66741 L p
1 g
F P
s
P
p
.002 w
.41015 .66741 m .44515 .69023 L .46924 .66098 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.44515 .69023 m .48175 .71082 L .49822 .69092 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.4483 .52743 m .46536 .56341 L .52396 .54408 L p
1 g
F P
s
P
p
.004 w
.47479 .52555 m
.47571 .52868 L
s
P
p
.004 w
.47571 .52868 m
.47589 .52931 L
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.49822 .69092 m .46924 .66098 L .44515 .69023 L p
1 g
F P
s
P
p
.002 w
.57287 .66617 m .57879 .62471 L .54005 .62625 L p
1 g
F P
s
P
p
.002 w
.54005 .62625 m .54647 .66728 L .57287 .66617 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.57879 .62471 m .58246 .58287 L .53246 .58475 L p
1 g
F P
s
P
p
.002 w
.52396 .54408 m .53246 .58475 L .58246 .58287 L p
1 g
F P
s
P
p
.002 w
.48348 .60093 m .46536 .56341 L .41472 .59775 L p
1 g
F P
s
P
p
.002 w
.41472 .59775 m .44111 .62959 L .48348 .60093 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.53246 .58475 m .54005 .62625 L .57879 .62471 L p
1 g
F P
s
P
p
.002 w
.46924 .66098 m .49822 .69092 L .52063 .67584 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.54647 .66728 m .54005 .62625 L .5021 .63881 L p
1 g
F P
s
P
p
.002 w
.5021 .63881 m .52063 .67584 L .54647 .66728 L p
1 g
F P
s
P
p
.002 w
.53246 .58475 m .52396 .54408 L .46536 .56341 L p
1 g
F P
s
P
p
.002 w
.52063 .67584 m .5021 .63881 L .46924 .66098 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.5021 .63881 m .48348 .60093 L .44111 .62959 L p
1 g
F P
s
P
p
.002 w
.44111 .62959 m .46924 .66098 L .5021 .63881 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.46536 .56341 m .48348 .60093 L .53246 .58475 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.54005 .62625 m .53246 .58475 L .48348 .60093 L p
1 g
F P
s
P
p
.002 w
.48348 .60093 m .5021 .63881 L .54005 .62625 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.004 w
.57584 .79214 m
.58455 .81284 L
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.004 w
.55671 .74666 m
.57584 .79214 L
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .46246 .48333 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .58455 .81284 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2236 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0826677 1.16534 0.0291334 1.16534 [
[(0.7)] .5 1.2236 0 -1.5 Msboxa
[ 0 0 0 0 ]
[ 1 1.2236 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(0.7)] .5 1.2236 0 -1.5 Mshowa
0 0 m
1 0 L
1 1.2236 L
0 1.2236 L
closepath
clip
newpath
p
P
p
.002 w
.45343 .67667 m .44529 .63983 L .49813 .62344 L p
1 g
F P
s
P
p
.002 w
.49813 .62344 m .5136 .65793 L .45343 .67667 L p
1 g
F P
s
P
p
.002 w
.48272 .58868 m .49813 .62344 L .44529 .63983 L p
1 g
F P
s
P
p
.002 w
.5136 .65793 m .49813 .62344 L .54597 .59506 L p
1 g
F P
s
P
p
.002 w
.49813 .62344 m .48272 .58868 L .52265 .56495 L p
1 g
F P
s
P
p
.002 w
.52265 .56495 m .54597 .59506 L .49813 .62344 L p
1 g
F P
s
P
p
.002 w
.44529 .63983 m .43858 .6023 L .48272 .58868 L p
1 g
F P
s
P
p
.002 w
.46772 .55444 m .48272 .58868 L .43858 .6023 L p
1 g
F P
s
P
p
.002 w
.48272 .58868 m .46772 .55444 L .4987 .536 L p
1 g
F P
s
P
p
.002 w
.4987 .536 m .52265 .56495 L .48272 .58868 L p
1 g
F P
s
P
p
.002 w
.46281 .71195 m .45343 .67667 L .5136 .65793 L p
1 g
F P
s
P
p
.002 w
.5136 .65793 m .52877 .69134 L .46281 .71195 L p
1 g
F P
s
P
p
.002 w
.52877 .69134 m .5136 .65793 L .56813 .62564 L p
1 g
F P
s
P
p
.002 w
.54597 .59506 m .56813 .62564 L .5136 .65793 L p
1 g
F P
s
P
p
.002 w
.56813 .62564 m .54597 .59506 L .58399 .55749 L p
1 g
F P
s
P
p
.002 w
.54597 .59506 m .52265 .56495 L .5543 .5335 L p
1 g
F P
s
P
p
.002 w
.5543 .5335 m .58399 .55749 L .54597 .59506 L p
1 g
F P
s
P
p
.002 w
.52265 .56495 m .4987 .536 L .52319 .51155 L p
1 g
F P
s
P
p
.002 w
.52319 .51155 m .5543 .5335 L .52265 .56495 L p
1 g
F P
s
P
p
.002 w
.39357 .67989 m .39275 .64249 L .44529 .63983 L p
1 g
F P
s
P
p
.002 w
.44529 .63983 m .45343 .67667 L .39357 .67989 L p
1 g
F P
s
P
p
.002 w
.43858 .6023 m .44529 .63983 L .39275 .64249 L p
1 g
F P
s
P
p
.002 w
.39275 .64249 m .39472 .60439 L .43858 .6023 L p
1 g
F P
s
P
p
.002 w
.43345 .56498 m .43858 .6023 L .39472 .60439 L p
1 g
F P
s
P
p
.002 w
.43858 .6023 m .43345 .56498 L .46772 .55444 L p
1 g
F P
s
P
p
.002 w
.4535 .52154 m .46772 .55444 L .43345 .56498 L p
1 g
F P
s
P
p
.002 w
.46772 .55444 m .4535 .52154 L .47468 .50891 L p
1 g
F P
s
P
p
.002 w
.47468 .50891 m .4987 .536 L .46772 .55444 L p
1 g
F P
s
P
p
.002 w
.56813 .62564 m .58858 .65597 L .52877 .69134 L p
1 g
F P
s
P
p
.002 w
.58858 .65597 m .56813 .62564 L .61155 .58294 L p
1 g
F P
s
P
p
.002 w
.58399 .55749 m .61155 .58294 L .56813 .62564 L p
1 g
F P
s
P
p
.002 w
.4987 .536 m .47468 .50891 L .49138 .49215 L p
1 g
F P
s
P
p
.002 w
.49138 .49215 m .52319 .51155 L .4987 .536 L p
1 g
F P
s
P
p
.002 w
.39719 .71568 m .39357 .67989 L .45343 .67667 L p
1 g
F P
s
P
p
.002 w
.45343 .67667 m .46281 .71195 L .39719 .71568 L p
1 g
F P
s
P
p
.002 w
.39472 .60439 m .39944 .56649 L .43345 .56498 L p
1 g
F P
s
P
p
.002 w
.43005 .52872 m .43345 .56498 L .39944 .56649 L p
1 g
F P
s
P
p
.002 w
.43345 .56498 m .43005 .52872 L .4535 .52154 L p
1 g
F P
s
P
p
.002 w
.47323 .74484 m .46281 .71195 L .52877 .69134 L p
1 g
F P
s
P
p
.002 w
.52877 .69134 m .54328 .72287 L .47323 .74484 L p
1 g
F P
s
P
p
.002 w
.54328 .72287 m .52877 .69134 L .58858 .65597 L p
1 g
F P
s
P
p
.002 w
.58399 .55749 m .5543 .5335 L .57433 .49751 L p
1 g
F P
s
P
p
.002 w
.5543 .5335 m .52319 .51155 L .53858 .48358 L p
1 g
F P
s
P
p
.002 w
.53858 .48358 m .57433 .49751 L .5543 .5335 L p
1 g
F P
s
P
p
.002 w
.58858 .65597 m .60685 .68533 L .54328 .72287 L p
1 g
F P
s
P
p
.002 w
.60685 .68533 m .58858 .65597 L .63632 .60927 L p
1 g
F P
s
P
p
.002 w
.61155 .58294 m .63632 .60927 L .58858 .65597 L p
1 g
F P
s
P
p
.002 w
.61155 .58294 m .58399 .55749 L .6082 .51445 L p
1 g
F P
s
P
p
.002 w
.57433 .49751 m .6082 .51445 L .58399 .55749 L p
1 g
F P
s
P
p
.002 w
.44039 .49077 m .4535 .52154 L .43005 .52872 L p
1 g
F P
s
P
p
.002 w
.4535 .52154 m .44039 .49077 L .45117 .48433 L p
1 g
F P
s
P
p
.002 w
.45117 .48433 m .47468 .50891 L .4535 .52154 L p
1 g
F P
s
P
p
.002 w
.52319 .51155 m .49138 .49215 L .50181 .473 L p
1 g
F P
s
P
p
.002 w
.50181 .473 m .53858 .48358 L .52319 .51155 L p
1 g
F P
s
P
p
.002 w
.34588 .631 m .35567 .59461 L .39472 .60439 L p
1 g
F P
s
P
p
.002 w
.39472 .60439 m .39275 .64249 L .34588 .631 L p
1 g
F P
s
P
p
.002 w
.39944 .56649 m .39472 .60439 L .35567 .59461 L p
1 g
F P
s
P
p
.002 w
.47468 .50891 m .45117 .48433 L .45964 .47579 L p
1 g
F P
s
P
p
.002 w
.45964 .47579 m .49138 .49215 L .47468 .50891 L p
1 g
F P
s
P
p
.002 w
.40354 .749 m .39719 .71568 L .46281 .71195 L p
1 g
F P
s
P
p
.002 w
.46281 .71195 m .47323 .74484 L .40354 .749 L p
1 g
F P
s
P
p
.002 w
.39944 .56649 m .40679 .52969 L .43005 .52872 L p
1 g
F P
s
P
p
.002 w
.42845 .49441 m .43005 .52872 L .40679 .52969 L p
1 g
F P
s
P
p
.002 w
.43005 .52872 m .42845 .49441 L .44039 .49077 L p
1 g
F P
s
P
p
.002 w
.35567 .59461 m .36922 .55875 L .39944 .56649 L p
1 g
F P
s
P
p
.002 w
.40679 .52969 m .39944 .56649 L .36922 .55875 L p
1 g
F P
s
P
p
.002 w
.3401 .66705 m .34588 .631 L .39275 .64249 L p
1 g
F P
s
P
p
.002 w
.39275 .64249 m .39357 .67989 L .3401 .66705 L p
1 g
F P
s
P
p
.002 w
.63632 .60927 m .61155 .58294 L .63936 .53403 L p
1 g
F P
s
P
p
.002 w
.6082 .51445 m .63936 .53403 L .61155 .58294 L p
1 g
F P
s
P
p
.002 w
.48445 .77452 m .47323 .74484 L .54328 .72287 L p
1 g
F P
s
P
p
.002 w
.54328 .72287 m .55678 .75175 L .48445 .77452 L p
1 g
F P
s
P
p
.002 w
.55678 .75175 m .54328 .72287 L .60685 .68533 L p
1 g
F P
s
P
p
.002 w
.49138 .49215 m .45964 .47579 L .46489 .46604 L p
1 g
F P
s
P
p
.002 w
.46489 .46604 m .50181 .473 L .49138 .49215 L p
1 g
F P
s
P
p
.002 w
.36922 .55875 m .38619 .5243 L .40679 .52969 L p
1 g
F P
s
P
p
.002 w
.41663 .49487 m .40679 .52969 L .38619 .5243 L p
1 g
F P
s
P
p
.002 w
.40679 .52969 m .41663 .49487 L .42845 .49441 L p
1 g
F P
s
P
p
.002 w
.33851 .70188 m .3401 .66705 L .39357 .67989 L p
1 g
F P
s
P
p
.002 w
.39357 .67989 m .39719 .71568 L .33851 .70188 L p
1 g
F P
s
P
p
.002 w
.60685 .68533 m .62247 .71301 L .55678 .75175 L p
1 g
F P
s
P
p
.002 w
.62247 .71301 m .60685 .68533 L .65768 .63585 L p
1 g
F P
s
P
p
.002 w
.63632 .60927 m .65768 .63585 L .60685 .68533 L p
1 g
F P
s
P
p
.002 w
.57433 .49751 m .53858 .48358 L .54317 .45501 L p
1 g
F P
s
P
p
.002 w
.53858 .48358 m .50181 .473 L .50481 .45349 L p
1 g
F P
s
P
p
.002 w
.50481 .45349 m .54317 .45501 L .53858 .48358 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .44039 .49077 L .42845 .49441 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .45117 .48433 L .44039 .49077 L closepath p
1 g
F P
s
P
p
.002 w
.41251 .77899 m .40354 .749 L .47323 .74484 L p
1 g
F P
s
P
p
.002 w
.47323 .74484 m .48445 .77452 L .41251 .77899 L p
1 g
F P
s
P
p
.002 w
.6082 .51445 m .57433 .49751 L .58049 .46066 L p
1 g
F P
s
P
p
.002 w
.54317 .45501 m .58049 .46066 L .57433 .49751 L p
1 g
F P
s
P
p
.002 w
.65768 .63585 m .63632 .60927 L .66704 .55577 L p
1 g
F P
s
P
p
.002 w
.63936 .53403 m .66704 .55577 L .63632 .60927 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .45964 .47579 L .45117 .48433 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .42845 .49441 L .41663 .49487 L closepath p
1 g
F P
s
P
p
.002 w
.50181 .473 m .46489 .46604 L .46635 .45614 L p
1 g
F P
s
P
p
.002 w
.46635 .45614 m .50481 .45349 L .50181 .473 L p
1 g
F P
s
P
p
.002 w
.32561 .57378 m .34605 .54247 L .36922 .55875 L p
1 g
F P
s
P
p
.002 w
.36922 .55875 m .35567 .59461 L .32561 .57378 L p
1 g
F P
s
P
p
.002 w
.38619 .5243 m .36922 .55875 L .34605 .54247 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .46489 .46604 L .45964 .47579 L closepath p
1 g
F P
s
P
p
.002 w
.34605 .54247 m .37046 .51308 L .38619 .5243 L p
1 g
F P
s
P
p
.002 w
.40618 .49208 m .38619 .5243 L .37046 .51308 L p
1 g
F P
s
P
p
.002 w
.38619 .5243 m .40618 .49208 L .41663 .49487 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .41663 .49487 L .40618 .49208 L closepath p
1 g
F P
s
P
p
.002 w
.30968 .60627 m .32561 .57378 L .35567 .59461 L p
1 g
F P
s
P
p
.002 w
.35567 .59461 m .34588 .631 L .30968 .60627 L p
1 g
F P
s
P
p
.002 w
.63936 .53403 m .6082 .51445 L .61586 .47032 L p
1 g
F P
s
P
p
.002 w
.58049 .46066 m .61586 .47032 L .6082 .51445 L p
1 g
F P
s
P
p
.002 w
.3412 .73461 m .33851 .70188 L .39719 .71568 L p
1 g
F P
s
P
p
.002 w
.39719 .71568 m .40354 .749 L .3412 .73461 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .46635 .45614 L .46489 .46604 L closepath p
1 g
F P
s
P
p
.002 w
.49619 .80021 m .48445 .77452 L .55678 .75175 L p
1 g
F P
s
P
p
.002 w
.55678 .75175 m .56893 .77724 L .49619 .80021 L p
1 g
F P
s
P
p
.002 w
.56893 .77724 m .55678 .75175 L .62247 .71301 L p
1 g
F P
s
P
p
.002 w
.37046 .51308 m .39825 .48634 L .40618 .49208 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .40618 .49208 L .39825 .48634 L closepath p
1 g
F P
s
P
p
.002 w
.29869 .63914 m .30968 .60627 L .34588 .631 L p
1 g
F P
s
P
p
.002 w
.34588 .631 m .3401 .66705 L .29869 .63914 L p
1 g
F P
s
P
p
.002 w
.54317 .45501 m .50481 .45349 L .49998 .4357 L p
1 g
F P
s
P
p
.002 w
.50481 .45349 m .46635 .45614 L .46383 .44714 L p
1 g
F P
s
P
p
.002 w
.46383 .44714 m .49998 .4357 L .50481 .45349 L p
1 g
F P
s
P
p
.002 w
.62247 .71301 m .63502 .73832 L .56893 .77724 L p
1 g
F P
s
P
p
.002 w
.63502 .73832 m .62247 .71301 L .67506 .66203 L p
1 g
F P
s
P
p
.002 w
.65768 .63585 m .67506 .66203 L .62247 .71301 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .46383 .44714 L .46635 .45614 L closepath p
1 g
F P
s
P
p
.002 w
.67506 .66203 m .65768 .63585 L .69051 .57918 L p
1 g
F P
s
P
p
.002 w
.66704 .55577 m .69051 .57918 L .65768 .63585 L p
1 g
F P
s
P
p
.002 w
.66704 .55577 m .63936 .53403 L .64838 .4838 L p
1 g
F P
s
P
p
.002 w
.61586 .47032 m .64838 .4838 L .63936 .53403 L p
1 g
F P
s
P
p
.002 w
.36134 .49718 m .39369 .47825 L .39825 .48634 L p
1 g
F P
s
P
p
.002 w
.39825 .48634 m .37046 .51308 L .36134 .49718 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39825 .48634 L .39369 .47825 L closepath p
1 g
F P
s
P
p
.002 w
.58049 .46066 m .54317 .45501 L .53629 .42887 L p
1 g
F P
s
P
p
.002 w
.49998 .4357 m .53629 .42887 L .54317 .45501 L p
1 g
F P
s
P
p
.002 w
.3325 .51925 m .36134 .49718 L .37046 .51308 L p
1 g
F P
s
P
p
.002 w
.37046 .51308 m .34605 .54247 L .3325 .51925 L p
1 g
F P
s
P
p
.002 w
.4239 .80486 m .41251 .77899 L .48445 .77452 L p
1 g
F P
s
P
p
.002 w
.48445 .77452 m .49619 .80021 L .4239 .80486 L p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39302 .46866 L .39633 .45863 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39369 .47825 L .39302 .46866 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .39633 .45863 L .40329 .44925 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .4576 .44003 L .46383 .44714 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .4483 .4356 L .4576 .44003 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .43695 .43433 L .4483 .4356 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .42478 .43639 L .43695 .43433 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .41313 .44156 L .42478 .43639 L closepath p
1 g
F P
s
P
p
.002 w
.42872 .46288 m .40329 .44925 L .41313 .44156 L closepath p
1 g
F P
s
P
p
.002 w
.34815 .76438 m .3412 .73461 L .40354 .749 L p
1 g
F P
s
P
p
.002 w
.40354 .749 m .41251 .77899 L .34815 .76438 L p
1 g
F P
s
P
p
.002 w
.49998 .4357 m .46383 .44714 L .4576 .44003 L p
1 g
F P
s
P
p
.002 w
.30791 .54394 m .3325 .51925 L .34605 .54247 L p
1 g
F P
s
P
p
.002 w
.34605 .54247 m .32561 .57378 L .30791 .54394 L p
1 g
F P
s
P
p
.002 w
.29299 .67155 m .29869 .63914 L .3401 .66705 L p
1 g
F P
s
P
p
.002 w
.3401 .66705 m .33851 .70188 L .29299 .67155 L p
1 g
F P
s
P
p
.002 w
.3599 .47828 m .39302 .46866 L .39369 .47825 L p
1 g
F P
s
P
p
.002 w
.39369 .47825 m .36134 .49718 L .3599 .47828 L p
1 g
F P
s
P
p
.002 w
.61586 .47032 m .58049 .46066 L .57185 .42685 L p
1 g
F P
s
P
p
.002 w
.53629 .42887 m .57185 .42685 L .58049 .46066 L p
1 g
F P
s
P
p
.002 w
.53629 .42887 m .49998 .4357 L .48777 .42159 L p
1 g
F P
s
P
p
.002 w
.4576 .44003 m .48777 .42159 L .49998 .4357 L p
1 g
F P
s
P
p
.002 w
.69051 .57918 m .66704 .55577 L .67722 .5008 L p
1 g
F P
s
P
p
.002 w
.64838 .4838 m .67722 .5008 L .66704 .55577 L p
1 g
F P
s
P
p
.002 w
.48777 .42159 m .4576 .44003 L .4483 .4356 L p
1 g
F P
s
P
p
.002 w
.28825 .57064 m .30791 .54394 L .32561 .57378 L p
1 g
F P
s
P
p
.002 w
.32561 .57378 m .30968 .60627 L .28825 .57064 L p
1 g
F P
s
P
p
.002 w
.36637 .45841 m .39633 .45863 L .39302 .46866 L p
1 g
F P
s
P
p
.002 w
.39302 .46866 m .3599 .47828 L .36637 .45841 L p
1 g
F P
s
P
p
.002 w
.50819 .82121 m .49619 .80021 L .56893 .77724 L p
1 g
F P
s
P
p
.002 w
.56893 .77724 m .57939 .79867 L .50819 .82121 L p
1 g
F P
s
P
p
.002 w
.57939 .79867 m .56893 .77724 L .63502 .73832 L p
1 g
F P
s
P
p
.002 w
.33022 .49153 m .3599 .47828 L .36134 .49718 L p
1 g
F P
s
P
p
.002 w
.36134 .49718 m .3325 .51925 L .33022 .49153 L p
1 g
F P
s
P
p
.002 w
.67506 .66203 m .68799 .68717 L .63502 .73832 L p
1 g
F P
s
P
p
.002 w
.68799 .68717 m .67506 .66203 L .70914 .60368 L p
1 g
F P
s
P
p
.002 w
.69051 .57918 m .70914 .60368 L .67506 .66203 L p
1 g
F P
s
P
p
.002 w
.64838 .4838 m .61586 .47032 L .60577 .42975 L p
1 g
F P
s
P
p
.002 w
.57185 .42685 m .60577 .42975 L .61586 .47032 L p
1 g
F P
s
P
p
.002 w
.4483 .4356 m .46944 .41273 L .48777 .42159 L p
1 g
F P
s
P
p
.002 w
.46944 .41273 m .4483 .4356 L .43695 .43433 L p
1 g
F P
s
P
p
.002 w
.29278 .70269 m .29299 .67155 L .33851 .70188 L p
1 g
F P
s
P
p
.002 w
.33851 .70188 m .3412 .73461 L .29278 .70269 L p
1 g
F P
s
P
p
.002 w
.38012 .43978 m .40329 .44925 L .39633 .45863 L p
1 g
F P
s
P
p
.002 w
.39633 .45863 m .36637 .45841 L .38012 .43978 L p
1 g
F P
s
P
p
.002 w
.63502 .73832 m .64413 .76058 L .57939 .79867 L p
1 g
F P
s
P
p
.002 w
.64413 .76058 m .63502 .73832 L .68799 .68717 L p
1 g
F P
s
P
p
.002 w
.57185 .42685 m .53629 .42887 L .51851 .40805 L p
1 g
F P
s
P
p
.002 w
.48777 .42159 m .51851 .40805 L .53629 .42887 L p
1 g
F P
s
P
p
.002 w
.43695 .43433 m .44695 .41017 L .46944 .41273 L p
1 g
F P
s
P
p
.002 w
.44695 .41017 m .43695 .43433 L .42478 .43639 L p
1 g
F P
s
P
p
.002 w
.43747 .82588 m .4239 .80486 L .49619 .80021 L p
1 g
F P
s
P
p
.002 w
.49619 .80021 m .50819 .82121 L .43747 .82588 L p
1 g
F P
s
P
p
.002 w
.35925 .7904 m .34815 .76438 L .41251 .77899 L p
1 g
F P
s
P
p
.002 w
.41251 .77899 m .4239 .80486 L .35925 .7904 L p
1 g
F P
s
P
p
.002 w
.39965 .42448 m .41313 .44156 L .40329 .44925 L p
1 g
F P
s
P
p
.002 w
.40329 .44925 m .38012 .43978 L .39965 .42448 L p
1 g
F P
s
P
p
.002 w
.27407 .59871 m .28825 .57064 L .30968 .60627 L p
1 g
F P
s
P
p
.002 w
.30968 .60627 m .29869 .63914 L .27407 .59871 L p
1 g
F P
s
P
p
.002 w
.51851 .40805 m .48777 .42159 L .46944 .41273 L p
1 g
F P
s
P
p
.002 w
.42478 .43639 m .42279 .41423 L .44695 .41017 L p
1 g
F P
s
P
p
.002 w
.42279 .41423 m .42478 .43639 L .41313 .44156 L p
1 g
F P
s
P
p
.002 w
.41313 .44156 m .39965 .42448 L .42279 .41423 L p
1 g
F P
s
P
p
.002 w
.30478 .50813 m .33022 .49153 L .3325 .51925 L p
1 g
F P
s
P
p
.002 w
.3325 .51925 m .30791 .54394 L .30478 .50813 L p
1 g
F P
s
P
p
.002 w
.70914 .60368 m .69051 .57918 L .70158 .52093 L p
1 g
F P
s
P
p
.002 w
.67722 .5008 m .70158 .52093 L .69051 .57918 L p
1 g
F P
s
P
p
.002 w
.33963 .46229 m .36637 .45841 L .3599 .47828 L p
1 g
F P
s
P
p
.002 w
.3599 .47828 m .33022 .49153 L .33963 .46229 L p
1 g
F P
s
P
p
.002 w
.67722 .5008 m .64838 .4838 L .63717 .43754 L p
1 g
F P
s
P
p
.002 w
.60577 .42975 m .63717 .43754 L .64838 .4838 L p
1 g
F P
s
P
p
.002 w
.60577 .42975 m .57185 .42685 L .54905 .39983 L p
1 g
F P
s
P
p
.002 w
.51851 .40805 m .54905 .39983 L .57185 .42685 L p
1 g
F P
s
P
p
.002 w
.29817 .73171 m .29278 .70269 L .3412 .73461 L p
1 g
F P
s
P
p
.002 w
.3412 .73461 m .34815 .76438 L .29817 .73171 L p
1 g
F P
s
P
p
.002 w
.46944 .41273 m .49163 .39493 L .51851 .40805 L p
1 g
F P
s
P
p
.002 w
.49163 .39493 m .46944 .41273 L .44695 .41017 L p
1 g
F P
s
P
p
.002 w
.68799 .68717 m .69605 .7106 L .64413 .76058 L p
1 g
F P
s
P
p
.002 w
.69605 .7106 m .68799 .68717 L .72238 .62868 L p
1 g
F P
s
P
p
.002 w
.70914 .60368 m .72238 .62868 L .68799 .68717 L p
1 g
F P
s
P
p
.002 w
.52014 .83689 m .50819 .82121 L .57939 .79867 L p
1 g
F P
s
P
p
.002 w
.57939 .79867 m .58788 .8154 L .52014 .83689 L p
1 g
F P
s
P
p
.002 w
.58788 .8154 m .57939 .79867 L .64413 .76058 L p
1 g
F P
s
P
p
.002 w
.26584 .62743 m .27407 .59871 L .29869 .63914 L p
1 g
F P
s
P
p
.002 w
.29869 .63914 m .29299 .67155 L .26584 .62743 L p
1 g
F P
s
P
p
.002 w
.35984 .4348 m .38012 .43978 L .36637 .45841 L p
1 g
F P
s
P
p
.002 w
.36637 .45841 m .33963 .46229 L .35984 .4348 L p
1 g
F P
s
P
p
.002 w
.28431 .52772 m .30478 .50813 L .30791 .54394 L p
1 g
F P
s
P
p
.002 w
.30791 .54394 m .28825 .57064 L .28431 .52772 L p
1 g
F P
s
P
p
.002 w
.54905 .39983 m .51851 .40805 L .49163 .39493 L p
1 g
F P
s
P
p
.002 w
.64413 .76058 m .64951 .77917 L .58788 .8154 L p
1 g
F P
s
P
p
.002 w
.64951 .77917 m .64413 .76058 L .69605 .7106 L p
1 g
F P
s
P
p
.002 w
.3743 .81192 m .35925 .7904 L .4239 .80486 L p
1 g
F P
s
P
p
.002 w
.4239 .80486 m .43747 .82588 L .3743 .81192 L p
1 g
F P
s
P
p
.002 w
.31686 .47024 m .33963 .46229 L .33022 .49153 L p
1 g
F P
s
P
p
.002 w
.33022 .49153 m .30478 .50813 L .31686 .47024 L p
1 g
F P
s
P
p
.002 w
.44695 .41017 m .45851 .39108 L .49163 .39493 L p
1 g
F P
s
P
p
.002 w
.45851 .39108 m .44695 .41017 L .42279 .41423 L p
1 g
F P
s
P
p
.002 w
.70158 .52093 m .67722 .5008 L .6652 .4501 L p
1 g
F P
s
P
p
.002 w
.63717 .43754 m .6652 .4501 L .67722 .5008 L p
1 g
F P
s
P
p
.002 w
.72238 .62868 m .70914 .60368 L .72079 .54373 L p
1 g
F P
s
P
p
.002 w
.70158 .52093 m .72079 .54373 L .70914 .60368 L p
1 g
F P
s
P
p
.002 w
.45292 .84142 m .43747 .82588 L .50819 .82121 L p
1 g
F P
s
P
p
.002 w
.50819 .82121 m .52014 .83689 L .45292 .84142 L p
1 g
F P
s
P
p
.002 w
.38866 .41218 m .39965 .42448 L .38012 .43978 L p
1 g
F P
s
P
p
.002 w
.38012 .43978 m .35984 .4348 L .38866 .41218 L p
1 g
F P
s
P
p
.002 w
.63717 .43754 m .60577 .42975 L .5786 .39722 L p
1 g
F P
s
P
p
.002 w
.54905 .39983 m .5786 .39722 L .60577 .42975 L p
1 g
F P
s
P
p
.002 w
.42279 .41423 m .42284 .39704 L .45851 .39108 L p
1 g
F P
s
P
p
.002 w
.42284 .39704 m .42279 .41423 L .39965 .42448 L p
1 g
F P
s
P
p
.002 w
.39965 .42448 m .38866 .41218 L .42284 .39704 L p
1 g
F P
s
P
p
.002 w
.30909 .75782 m .29817 .73171 L .34815 .76438 L p
1 g
F P
s
P
p
.002 w
.34815 .76438 m .35925 .7904 L .30909 .75782 L p
1 g
F P
s
P
p
.002 w
.26387 .65606 m .26584 .62743 L .29299 .67155 L p
1 g
F P
s
P
p
.002 w
.29299 .67155 m .29278 .70269 L .26387 .65606 L p
1 g
F P
s
P
p
.002 w
.26943 .54983 m .28431 .52772 L .28825 .57064 L p
1 g
F P
s
P
p
.002 w
.28825 .57064 m .27407 .59871 L .26943 .54983 L p
1 g
F P
s
P
p
.002 w
.49163 .39493 m .51432 .38274 L .54905 .39983 L p
1 g
F P
s
P
p
.002 w
.51432 .38274 m .49163 .39493 L .45851 .39108 L p
1 g
F P
s
P
p
.002 w
.5786 .39722 m .54905 .39983 L .51432 .38274 L p
1 g
F P
s
P
p
.002 w
.34304 .43452 m .35984 .4348 L .33963 .46229 L p
1 g
F P
s
P
p
.002 w
.33963 .46229 m .31686 .47024 L .34304 .43452 L p
1 g
F P
s
P
p
.002 w
.69605 .7106 m .69894 .7317 L .64951 .77917 L p
1 g
F P
s
P
p
.002 w
.69894 .7317 m .69605 .7106 L .72978 .65353 L p
1 g
F P
s
P
p
.002 w
.72238 .62868 m .72978 .65353 L .69605 .7106 L p
1 g
F P
s
P
p
.002 w
.29874 .48215 m .31686 .47024 L .30478 .50813 L p
1 g
F P
s
P
p
.002 w
.30478 .50813 m .28431 .52772 L .29874 .48215 L p
1 g
F P
s
P
p
.002 w
.72079 .54373 m .70158 .52093 L .68907 .46719 L p
1 g
F P
s
P
p
.002 w
.6652 .4501 m .68907 .46719 L .70158 .52093 L p
1 g
F P
s
P
p
.002 w
.53173 .84672 m .52014 .83689 L .58788 .8154 L p
1 g
F P
s
P
p
.002 w
.58788 .8154 m .59414 .8269 L .53173 .84672 L p
1 g
F P
s
P
p
.002 w
.59414 .8269 m .58788 .8154 L .64951 .77917 L p
1 g
F P
s
P
p
.002 w
.6652 .4501 m .63717 .43754 L .60637 .40038 L p
1 g
F P
s
P
p
.002 w
.5786 .39722 m .60637 .40038 L .63717 .43754 L p
1 g
F P
s
P
p
.002 w
.72978 .65353 m .72238 .62868 L .73423 .56863 L p
1 g
F P
s
P
p
.002 w
.72079 .54373 m .73423 .56863 L .72238 .62868 L p
1 g
F P
s
P
p
.002 w
.39297 .82827 m .3743 .81192 L .43747 .82588 L p
1 g
F P
s
P
p
.002 w
.43747 .82588 m .45292 .84142 L .39297 .82827 L p
1 g
F P
s
P
p
.002 w
.64951 .77917 m .65094 .79353 L .59414 .8269 L p
1 g
F P
s
P
p
.002 w
.65094 .79353 m .64951 .77917 L .69894 .7317 L p
1 g
F P
s
P
p
.002 w
.45851 .39108 m .47137 .37768 L .51432 .38274 L p
1 g
F P
s
P
p
.002 w
.47137 .37768 m .45851 .39108 L .42284 .39704 L p
1 g
F P
s
P
p
.002 w
.3805 .40509 m .38866 .41218 L .35984 .4348 L p
1 g
F P
s
P
p
.002 w
.35984 .4348 m .34304 .43452 L .3805 .40509 L p
1 g
F P
s
P
p
.002 w
.46987 .85095 m .45292 .84142 L .52014 .83689 L p
1 g
F P
s
P
p
.002 w
.52014 .83689 m .53173 .84672 L .46987 .85095 L p
1 g
F P
s
P
p
.002 w
.26833 .68384 m .26387 .65606 L .29278 .70269 L p
1 g
F P
s
P
p
.002 w
.29278 .70269 m .29817 .73171 L .26833 .68384 L p
1 g
F P
s
P
p
.002 w
.26064 .57391 m .26943 .54983 L .27407 .59871 L p
1 g
F P
s
P
p
.002 w
.27407 .59871 m .26584 .62743 L .26064 .57391 L p
1 g
F P
s
P
p
.002 w
.32537 .78026 m .30909 .75782 L .35925 .7904 L p
1 g
F P
s
P
p
.002 w
.35925 .7904 m .3743 .81192 L .32537 .78026 L p
1 g
F P
s
P
p
.002 w
.42284 .39704 m .42499 .38539 L .47137 .37768 L p
1 g
F P
s
P
p
.002 w
.42499 .38539 m .42284 .39704 L .38866 .41218 L p
1 g
F P
s
P
p
.002 w
.60637 .40038 m .5786 .39722 L .53693 .37658 L p
1 g
F P
s
P
p
.002 w
.51432 .38274 m .53693 .37658 L .5786 .39722 L p
1 g
F P
s
P
p
.002 w
.38866 .41218 m .3805 .40509 L .42499 .38539 L p
1 g
F P
s
P
p
.002 w
.53693 .37658 m .51432 .38274 L .47137 .37768 L p
1 g
F P
s
P
p
.002 w
.73423 .56863 m .72079 .54373 L .70807 .48841 L p
1 g
F P
s
P
p
.002 w
.68907 .46719 m .70807 .48841 L .72079 .54373 L p
1 g
F P
s
P
p
.002 w
.68907 .46719 m .6652 .4501 L .63159 .40934 L p
1 g
F P
s
P
p
.002 w
.60637 .40038 m .63159 .40934 L .6652 .4501 L p
1 g
F P
s
P
p
.002 w
.33026 .43907 m .34304 .43452 L .31686 .47024 L p
1 g
F P
s
P
p
.002 w
.31686 .47024 m .29874 .48215 L .33026 .43907 L p
1 g
F P
s
P
p
.002 w
.28584 .49777 m .29874 .48215 L .28431 .52772 L p
1 g
F P
s
P
p
.002 w
.28431 .52772 m .26943 .54983 L .28584 .49777 L p
1 g
F P
s
P
p
.002 w
.69894 .7317 m .69647 .74987 L .65094 .79353 L p
1 g
F P
s
P
p
.002 w
.69647 .74987 m .69894 .7317 L .73105 .67759 L p
1 g
F P
s
P
p
.002 w
.72978 .65353 m .73105 .67759 L .69894 .7317 L p
1 g
F P
s
P
p
.002 w
.73105 .67759 m .72978 .65353 L .74147 .59502 L p
1 g
F P
s
P
p
.002 w
.73423 .56863 m .74147 .59502 L .72978 .65353 L p
1 g
F P
s
P
p
.002 w
.41483 .83892 m .39297 .82827 L .45292 .84142 L p
1 g
F P
s
P
p
.002 w
.45292 .84142 m .46987 .85095 L .41483 .83892 L p
1 g
F P
s
P
p
.002 w
.25831 .59936 m .26064 .57391 L .26584 .62743 L p
1 g
F P
s
P
p
.002 w
.26584 .62743 m .26387 .65606 L .25831 .59936 L p
1 g
F P
s
P
p
.002 w
.27921 .70997 m .26833 .68384 L .29817 .73171 L p
1 g
F P
s
P
p
.002 w
.29817 .73171 m .30909 .75782 L .27921 .70997 L p
1 g
F P
s
P
p
.002 w
.54264 .85031 m .53173 .84672 L .59414 .8269 L p
1 g
F P
s
P
p
.002 w
.59414 .8269 m .59793 .83273 L .54264 .85031 L p
1 g
F P
s
P
p
.002 w
.59793 .83273 m .59414 .8269 L .65094 .79353 L p
1 g
F P
s
P
p
.002 w
.47137 .37768 m .4852 .37044 L .53693 .37658 L p
1 g
F P
s
P
p
.002 w
.4852 .37044 m .47137 .37768 L .42499 .38539 L p
1 g
F P
s
P
p
.002 w
.65094 .79353 m .64827 .80317 L .59793 .83273 L p
1 g
F P
s
P
p
.002 w
.64827 .80317 m .65094 .79353 L .69647 .74987 L p
1 g
F P
s
P
p
.002 w
.34666 .79835 m .32537 .78026 L .3743 .81192 L p
1 g
F P
s
P
p
.002 w
.3743 .81192 m .39297 .82827 L .34666 .79835 L p
1 g
F P
s
P
p
.002 w
.63159 .40934 m .60637 .40038 L .55886 .37676 L p
1 g
F P
s
P
p
.002 w
.53693 .37658 m .55886 .37676 L .60637 .40038 L p
1 g
F P
s
P
p
.002 w
.37548 .40353 m .3805 .40509 L .34304 .43452 L p
1 g
F P
s
P
p
.002 w
.34304 .43452 m .33026 .43907 L .37548 .40353 L p
1 g
F P
s
P
p
.002 w
.48791 .85407 m .46987 .85095 L .53173 .84672 L p
1 g
F P
s
P
p
.002 w
.53173 .84672 m .54264 .85031 L .48791 .85407 L p
1 g
F P
s
P
p
.002 w
.70807 .48841 m .68907 .46719 L .65354 .42395 L p
1 g
F P
s
P
p
.002 w
.63159 .40934 m .65354 .42395 L .68907 .46719 L p
1 g
F P
s
P
p
.002 w
.55886 .37676 m .53693 .37658 L .4852 .37044 L p
1 g
F P
s
P
p
.002 w
.74147 .59502 m .73423 .56863 L .72161 .51328 L p
1 g
F P
s
P
p
.002 w
.70807 .48841 m .72161 .51328 L .73423 .56863 L p
1 g
F P
s
P
p
.002 w
.42499 .38539 m .42922 .37973 L .4852 .37044 L p
1 g
F P
s
P
p
.002 w
.42922 .37973 m .42499 .38539 L .3805 .40509 L p
1 g
F P
s
P
p
.002 w
.27865 .51676 m .28584 .49777 L .26943 .54983 L p
1 g
F P
s
P
p
.002 w
.26943 .54983 m .26064 .57391 L .27865 .51676 L p
1 g
F P
s
P
p
.002 w
.3805 .40509 m .37548 .40353 L .42922 .37973 L p
1 g
F P
s
P
p
.002 w
.32193 .44844 m .33026 .43907 L .29874 .48215 L p
1 g
F P
s
P
p
.002 w
.29874 .48215 m .28584 .49777 L .32193 .44844 L p
1 g
F P
s
P
p
.002 w
.69647 .74987 m .68859 .76454 L .64827 .80317 L p
1 g
F P
s
P
p
.002 w
.68859 .76454 m .69647 .74987 L .72601 .70018 L p
1 g
F P
s
P
p
.002 w
.73105 .67759 m .72601 .70018 L .69647 .74987 L p
1 g
F P
s
P
p
.002 w
.74147 .59502 m .74217 .6222 L .73105 .67759 L p
1 g
F P
s
P
p
.002 w
.72601 .70018 m .73105 .67759 L .74217 .6222 L p
1 g
F P
s
P
p
.002 w
.26262 .62549 m .25831 .59936 L .26387 .65606 L p
1 g
F P
s
P
p
.002 w
.26387 .65606 m .26833 .68384 L .26262 .62549 L p
1 g
F P
s
P
p
.002 w
.29632 .73371 m .27921 .70997 L .30909 .75782 L p
1 g
F P
s
P
p
.002 w
.30909 .75782 m .32537 .78026 L .29632 .73371 L p
1 g
F P
s
P
p
.002 w
.43933 .84345 m .41483 .83892 L .46987 .85095 L p
1 g
F P
s
P
p
.002 w
.46987 .85095 m .48791 .85407 L .43933 .84345 L p
1 g
F P
s
P
p
.002 w
.55886 .37676 m .57948 .38339 L .63159 .40934 L p
1 g
F P
s
P
p
.002 w
.65354 .42395 m .63159 .40934 L .57948 .38339 L p
1 g
F P
s
P
p
.002 w
.37244 .81151 m .34666 .79835 L .39297 .82827 L p
1 g
F P
s
P
p
.002 w
.39297 .82827 m .41483 .83892 L .37244 .81151 L p
1 g
F P
s
P
p
.002 w
.55256 .8474 m .54264 .85031 L .59793 .83273 L p
1 g
F P
s
P
p
.002 w
.59793 .83273 m .59911 .83261 L .55256 .8474 L p
1 g
F P
s
P
p
.002 w
.59911 .83261 m .59793 .83273 L .64827 .80317 L p
1 g
F P
s
P
p
.002 w
.4852 .37044 m .49966 .36971 L .55886 .37676 L p
1 g
F P
s
P
p
.002 w
.49966 .36971 m .4852 .37044 L .42922 .37973 L p
1 g
F P
s
P
p
.002 w
.65354 .42395 m .67154 .44393 L .70807 .48841 L p
1 g
F P
s
P
p
.002 w
.72161 .51328 m .70807 .48841 L .67154 .44393 L p
1 g
F P
s
P
p
.002 w
.72161 .51328 m .72919 .54116 L .74147 .59502 L p
1 g
F P
s
P
p
.002 w
.74217 .6222 m .74147 .59502 L .72919 .54116 L p
1 g
F P
s
P
p
.002 w
.64827 .80317 m .64149 .80771 L .59911 .83261 L p
1 g
F P
s
P
p
.002 w
.64149 .80771 m .64827 .80317 L .68859 .76454 L p
1 g
F P
s
P
p
.002 w
.3738 .40769 m .37548 .40353 L .33026 .43907 L p
1 g
F P
s
P
p
.002 w
.33026 .43907 m .32193 .44844 L .3738 .40769 L p
1 g
F P
s
P
p
.002 w
.50656 .85055 m .48791 .85407 L .54264 .85031 L p
1 g
F P
s
P
p
.002 w
.54264 .85031 m .55256 .8474 L .50656 .85055 L p
1 g
F P
s
P
p
.002 w
.57948 .38339 m .55886 .37676 L .49966 .36971 L p
1 g
F P
s
P
p
.002 w
.27748 .53867 m .27865 .51676 L .26064 .57391 L p
1 g
F P
s
P
p
.002 w
.26064 .57391 m .25831 .59936 L .27748 .53867 L p
1 g
F P
s
P
p
.002 w
.27359 .65157 m .26262 .62549 L .26833 .68384 L p
1 g
F P
s
P
p
.002 w
.26833 .68384 m .27921 .70997 L .27359 .65157 L p
1 g
F P
s
P
p
.002 w
.42922 .37973 m .43547 .38037 L .49966 .36971 L p
1 g
F P
s
P
p
.002 w
.43547 .38037 m .42922 .37973 L .37548 .40353 L p
1 g
F P
s
P
p
.002 w
.31839 .4625 m .32193 .44844 L .28584 .49777 L p
1 g
F P
s
P
p
.002 w
.28584 .49777 m .27865 .51676 L .31839 .4625 L p
1 g
F P
s
P
p
.002 w
.3193 .75433 m .29632 .73371 L .32537 .78026 L p
1 g
F P
s
P
p
.002 w
.32537 .78026 m .34666 .79835 L .3193 .75433 L p
1 g
F P
s
P
p
.002 w
.37548 .40353 m .3738 .40769 L .43547 .38037 L p
1 g
F P
s
P
p
.002 w
.72601 .70018 m .71469 .72065 L .68859 .76454 L p
1 g
F P
s
P
p
.002 w
.71469 .72065 m .72601 .70018 L .7362 .64944 L p
1 g
F P
s
P
p
.002 w
.74217 .6222 m .7362 .64944 L .72601 .70018 L p
1 g
F P
s
P
p
.002 w
.68859 .76454 m .67539 .77522 L .64149 .80771 L p
1 g
F P
s
P
p
.002 w
.67539 .77522 m .68859 .76454 L .71469 .72065 L p
1 g
F P
s
P
p
.002 w
.67154 .44393 m .65354 .42395 L .59821 .39643 L p
1 g
F P
s
P
p
.002 w
.57948 .38339 m .59821 .39643 L .65354 .42395 L p
1 g
F P
s
P
p
.002 w
.46585 .84161 m .43933 .84345 L .48791 .85407 L p
1 g
F P
s
P
p
.002 w
.48791 .85407 m .50656 .85055 L .46585 .84161 L p
1 g
F P
s
P
p
.002 w
.40208 .81926 m .37244 .81151 L .41483 .83892 L p
1 g
F P
s
P
p
.002 w
.41483 .83892 m .43933 .84345 L .40208 .81926 L p
1 g
F P
s
P
p
.002 w
.72919 .54116 m .72161 .51328 L .685 .46882 L p
1 g
F P
s
P
p
.002 w
.67154 .44393 m .685 .46882 L .72161 .51328 L p
1 g
F P
s
P
p
.002 w
.7362 .64944 m .74217 .6222 L .73052 .57133 L p
1 g
F P
s
P
p
.002 w
.72919 .54116 m .73052 .57133 L .74217 .6222 L p
1 g
F P
s
P
p
.002 w
.49966 .36971 m .51436 .37566 L .57948 .38339 L p
1 g
F P
s
P
p
.002 w
.51436 .37566 m .49966 .36971 L .43547 .38037 L p
1 g
F P
s
P
p
.002 w
.56119 .83791 m .55256 .8474 L .59911 .83261 L p
1 g
F P
s
P
p
.002 w
.59911 .83261 m .59756 .82636 L .56119 .83791 L p
1 g
F P
s
P
p
.002 w
.59756 .82636 m .59911 .83261 L .64149 .80771 L p
1 g
F P
s
P
p
.004 w
.60536 .83192 m
.61733 .85693 L
s
P
p
.002 w
.28252 .56293 m .27748 .53867 L .25831 .59936 L p
1 g
F P
s
P
p
.002 w
.25831 .59936 m .26262 .62549 L .28252 .56293 L p
1 g
F P
s
P
p
.002 w
.59821 .39643 m .57948 .38339 L .51436 .37566 L p
1 g
F P
s
P
p
.002 w
.64149 .80771 m .63067 .80691 L .59756 .82636 L p
1 g
F P
s
P
p
.002 w
.63067 .80691 m .64149 .80771 L .67539 .77522 L p
1 g
F P
s
P
p
.002 w
.3756 .41758 m .3738 .40769 L .32193 .44844 L p
1 g
F P
s
P
p
.002 w
.32193 .44844 m .31839 .4625 L .3756 .41758 L p
1 g
F P
s
P
p
.002 w
.29103 .67685 m .27359 .65157 L .27921 .70997 L p
1 g
F P
s
P
p
.002 w
.27921 .70997 m .29632 .73371 L .29103 .67685 L p
1 g
F P
s
P
p
.002 w
.34757 .77119 m .3193 .75433 L .34666 .79835 L p
1 g
F P
s
P
p
.002 w
.34666 .79835 m .37244 .81151 L .34757 .77119 L p
1 g
F P
s
P
p
.002 w
.52531 .84034 m .50656 .85055 L .55256 .8474 L p
1 g
F P
s
P
p
.002 w
.55256 .8474 m .56119 .83791 L .52531 .84034 L p
1 g
F P
s
P
p
.002 w
.31987 .48094 m .31839 .4625 L .27865 .51676 L p
1 g
F P
s
P
p
.002 w
.27865 .51676 m .27748 .53867 L .31987 .48094 L p
1 g
F P
s
P
p
.002 w
.71469 .72065 m .69725 .7384 L .67539 .77522 L p
1 g
F P
s
P
p
.002 w
.69725 .7384 m .71469 .72065 L .7236 .67596 L p
1 g
F P
s
P
p
.002 w
.7362 .64944 m .7236 .67596 L .71469 .72065 L p
1 g
F P
s
P
p
.002 w
.43547 .38037 m .44362 .38745 L .51436 .37566 L p
1 g
F P
s
P
p
.002 w
.44362 .38745 m .43547 .38037 L .3738 .40769 L p
1 g
F P
s
P
p
.002 w
.685 .46882 m .67154 .44393 L .61446 .41566 L p
1 g
F P
s
P
p
.002 w
.59821 .39643 m .61446 .41566 L .67154 .44393 L p
1 g
F P
s
P
p
.002 w
.3738 .40769 m .3756 .41758 L .44362 .38745 L p
1 g
F P
s
P
p
.002 w
.73052 .57133 m .72919 .54116 L .69348 .49799 L p
1 g
F P
s
P
p
.002 w
.685 .46882 m .69348 .49799 L .72919 .54116 L p
1 g
F P
s
P
p
.002 w
.67539 .77522 m .65711 .78154 L .63067 .80691 L p
1 g
F P
s
P
p
.002 w
.65711 .78154 m .67539 .77522 L .69725 .7384 L p
1 g
F P
s
P
p
.002 w
.43478 .82129 m .40208 .81926 L .43933 .84345 L p
1 g
F P
s
P
p
.002 w
.43933 .84345 m .46585 .84161 L .43478 .82129 L p
1 g
F P
s
P
p
.002 w
.7236 .67596 m .7362 .64944 L .72543 .60297 L p
1 g
F P
s
P
p
.002 w
.73052 .57133 m .72543 .60297 L .7362 .64944 L p
1 g
F P
s
P
p
.002 w
.49366 .83332 m .46585 .84161 L .50656 .85055 L p
1 g
F P
s
P
p
.002 w
.50656 .85055 m .52531 .84034 L .49366 .83332 L p
1 g
F P
s
P
p
.002 w
.29372 .58888 m .28252 .56293 L .26262 .62549 L p
1 g
F P
s
P
p
.002 w
.26262 .62549 m .27359 .65157 L .29372 .58888 L p
1 g
F P
s
P
p
.002 w
.31452 .70057 m .29103 .67685 L .29632 .73371 L p
1 g
F P
s
P
p
.002 w
.29632 .73371 m .3193 .75433 L .31452 .70057 L p
1 g
F P
s
P
p
.002 w
.3804 .78374 m .34757 .77119 L .37244 .81151 L p
1 g
F P
s
P
p
.002 w
.37244 .81151 m .40208 .81926 L .3804 .78374 L p
1 g
F P
s
P
p
.002 w
.61446 .41566 m .59821 .39643 L .5289 .38829 L p
1 g
F P
s
P
p
.002 w
.51436 .37566 m .5289 .38829 L .59821 .39643 L p
1 g
F P
s
P
p
.002 w
.5289 .38829 m .51436 .37566 L .44362 .38745 L p
1 g
F P
s
P
p
.002 w
.56825 .82195 m .56119 .83791 L .59756 .82636 L p
1 g
F P
s
P
p
.002 w
.59756 .82636 m .59325 .81402 L .56825 .82195 L p
1 g
F P
s
P
p
.002 w
.59325 .81402 m .59756 .82636 L .63067 .80691 L p
1 g
F P
s
P
p
.002 w
.38091 .43308 m .3756 .41758 L .31839 .4625 L p
1 g
F P
s
P
p
.002 w
.31839 .4625 m .31987 .48094 L .38091 .43308 L p
1 g
F P
s
P
p
.002 w
.63067 .80691 m .61602 .80064 L .59325 .81402 L p
1 g
F P
s
P
p
.002 w
.61602 .80064 m .63067 .80691 L .65711 .78154 L p
1 g
F P
s
P
p
.002 w
.69725 .7384 m .67408 .75284 L .65711 .78154 L p
1 g
F P
s
P
p
.002 w
.67408 .75284 m .69725 .7384 L .70461 .701 L p
1 g
F P
s
P
p
.002 w
.7236 .67596 m .70461 .701 L .69725 .7384 L p
1 g
F P
s
P
p
.002 w
.54362 .82359 m .52531 .84034 L .56119 .83791 L p
1 g
F P
s
P
p
.002 w
.56119 .83791 m .56825 .82195 L .54362 .82359 L p
1 g
F P
s
P
p
.002 w
.32644 .50333 m .31987 .48094 L .27748 .53867 L p
1 g
F P
s
P
p
.002 w
.27748 .53867 m .28252 .56293 L .32644 .50333 L p
1 g
F P
s
P
p
.002 w
.72543 .60297 m .73052 .57133 L .69661 .53068 L p
1 g
F P
s
P
p
.002 w
.69348 .49799 m .69661 .53068 L .73052 .57133 L p
1 g
F P
s
P
p
.002 w
.69348 .49799 m .685 .46882 L .62771 .44064 L p
1 g
F P
s
P
p
.002 w
.61446 .41566 m .62771 .44064 L .685 .46882 L p
1 g
F P
s
P
p
.002 w
.70461 .701 m .7236 .67596 L .71397 .63517 L p
1 g
F P
s
P
p
.002 w
.72543 .60297 m .71397 .63517 L .7236 .67596 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .48792 .82276 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.46403 .82325 m .48758 .82869 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .46502 .81746 L .46403 .82325 L p
1 g
F P
s
P
p
.002 w
.43478 .82129 m .46585 .84161 L p
.46811 .82714 L 1 g
F P
s
P
p
.46811 .82714 m .46822 .82644 L .46557 .82603 L 1 g
F
P
p
.46811 .82714 m .46557 .82603 L .43478 .82129 L 1 g
F
P
p
.002 w
.4637 .82521 m .46403 .82325 L p
.45402 .82099 L 1 g
F P
s
P
p
.002 w
.44504 .82017 m .43478 .82129 L p
.46822 .82644 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .46403 .82325 L .4637 .82521 L p
1 g
F P
s
P
p
.46585 .84161 m .49365 .83332 L .48741 .83163 L 1 g
F
P
p
.46783 .82896 m .48741 .83163 L .46822 .82644 L 1 g
F
P
p
.46585 .84161 m .48741 .83163 L .46783 .82896 L 1 g
F
P
p
.002 w
.53597 .82325 m .51242 .82869 L .51256 .83108 L p
1 g
F P
s
P
p
.52531 .84034 m .52375 .83027 L .5096 .8317 L 1 g
F
P
p
.002 w
.49766 .83421 m .52531 .84034 L p
.5096 .8317 L 1 g
F P
s
P
p
.53597 .82325 m .51256 .83108 L .52558 .82835 L 1 g
F
P
p
.002 w
.51256 .83108 m .51242 .82869 L p
.49772 .83216 L 1 g
F P
s
P
p
.002 w
.48758 .82869 m .51242 .82869 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .51208 .82276 L .51242 .82869 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .53498 .81746 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.49561 .83232 m .49366 .83332 L p
.52375 .83027 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .48758 .82869 L .48741 .83163 L p
1 g
F P
s
P
p
.002 w
.49365 .83332 m .49205 .83226 L p
.48741 .83163 L 1 g
F P
s
P
p
.002 w
.49205 .83226 m .49366 .83332 L p
.49414 .83229 L 1 g
F P
s
P
p
.51242 .82869 m .48741 .83163 L .49205 .83226 L 1 g
F
P
p
.002 w
.49366 .83332 m .49561 .83232 L p
.49414 .83229 L 1 g
F P
s
P
p
.49698 .83234 m .49205 .83226 L .49538 .83272 L 1 g
F
P
p
.51242 .82869 m .49205 .83226 L .49698 .83234 L 1 g
F
P
p
.002 w
.4886 .81091 m .5114 .81091 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .4886 .81091 L .48826 .81683 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .51174 .81683 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .5114 .81091 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.48792 .82276 m .51208 .82276 L .51174 .81683 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .48826 .81683 L .48792 .82276 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .51174 .81683 L .51208 .82276 L p
1 g
F P
s
P
p
.002 w
.51174 .81683 m .534 .81167 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.51208 .82276 m .48792 .82276 L .48758 .82869 L p
1 g
F P
s
P
p
.002 w
.52196 .81872 m .50561 .80781 L p
.49414 .83229 L 1 g
F P
s
P
p
.002 w
.49561 .83232 m .52196 .81872 L p
.49414 .83229 L 1 g
F P
s
P
p
.48758 .82869 m .4637 .82521 L .47712 .82885 L 1 g
F
P
p
.002 w
.48741 .83163 m .48758 .82869 L p
.47712 .82885 L 1 g
F P
s
P
p
.002 w
.466 .81167 m .48826 .81683 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.48826 .81683 m .466 .81167 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.50561 .80781 m .46962 .81747 L .49205 .83226 L p
1 g
F P
s
P
p
.49414 .83229 m .50561 .80781 L .49205 .83226 L 1 g
F
P
p
.49538 .83272 m .49205 .83226 L .48724 .83464 L 1 g
F
P
p
.002 w
.48741 .83163 m .48738 .83219 L p
.49205 .83226 L 1 g
F P
s
P
p
.002 w
.48738 .83219 m .48724 .83464 L p
.49205 .83226 L 1 g
F P
s
P
p
.46822 .82644 m .48741 .83163 L .46962 .81747 L 1 g
F
P
p
.002 w
.49205 .83226 m .46962 .81747 L p
.48741 .83163 L 1 g
F P
s
P
p
.002 w
.51242 .82869 m .53597 .82325 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.52196 .81872 m .49561 .83232 L p
.51256 .83108 L 1 g
F P
s
P
p
.52375 .83027 m .52352 .82878 L .51256 .83108 L 1 g
F
P
p
.52352 .82878 m .52196 .81872 L .51256 .83108 L 1 g
F
P
p
.002 w
.53644 .82606 m .53597 .82325 L p
.52558 .82835 L 1 g
F P
s
P
p
.002 w
.5542 .80739 m .53498 .81746 L .53597 .82325 L p
1 g
F P
s
P
p
.002 w
.52531 .84034 m .54362 .82359 L .54321 .8235 L p
1 g
F P
s
P
p
.002 w
.55573 .81291 m .53597 .82325 L .53644 .82606 L p
1 g
F P
s
P
p
.55573 .81291 m .53644 .82606 L .54321 .8235 L 1 g
F
P
p
.002 w
.55114 .79637 m .53301 .8059 L .534 .81167 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .534 .81167 L .53498 .81746 L p
1 g
F P
s
P
p
.002 w
.534 .81167 m .55267 .80188 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.53498 .81746 m .5542 .80739 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.53597 .82325 m .55573 .81291 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.54993 .79814 m .52196 .81872 L .54321 .8235 L p
1 g
F P
s
P
p
.002 w
.54321 .8235 m .54362 .82359 L p
.54371 .82322 L 1 g
F P
s
P
p
.55573 .81291 m .54321 .8235 L .54349 .82334 L 1 g
F
P
p
.54379 .82317 m .54338 .82344 L .54374 .82321 L 1 g
F
P
p
.55573 .81291 m .54349 .82334 L .54379 .82317 L 1 g
F
P
p
.54349 .82334 m .54338 .82344 L .54379 .82317 L 1 g
F
P
p
.002 w
.56384 .78332 m .55114 .79637 L .55267 .80188 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .55267 .80188 L .5542 .80739 L p
1 g
F P
s
P
p
.002 w
.55267 .80188 m .56575 .78845 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5542 .80739 L .55573 .81291 L p
1 g
F P
s
P
p
.002 w
.5542 .80739 m .56767 .79359 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56093 .80065 m .54993 .79814 L p
.54371 .82322 L 1 g
F P
s
P
p
.002 w
.54362 .82359 m .54404 .82303 L p
.54371 .82322 L 1 g
F P
s
P
p
.56825 .82195 m .56432 .81052 L .55608 .81573 L 1 g
F
P
p
.002 w
.54362 .82359 m .54828 .82328 L p
.55608 .81573 L 1 g
F P
s
P
p
.002 w
.54828 .82328 m .56825 .82195 L p
.55608 .81573 L 1 g
F P
s
P
p
.002 w
.56958 .79874 m .55573 .81291 L .55642 .8154 L p
1 g
F P
s
P
p
.56958 .79874 m .55642 .8154 L .56339 .80864 L 1 g
F
P
p
.002 w
.54404 .82303 m .54362 .82359 L p
.55608 .81573 L 1 g
F P
s
P
p
.56432 .81052 m .55642 .8154 L .55608 .81573 L 1 g
F
P
p
.55642 .8154 m .54404 .82303 L .55608 .81573 L 1 g
F
P
p
.002 w
.57065 .80161 m .56958 .79874 L p
.56339 .80864 L 1 g
F P
s
P
p
.002 w
.55642 .8154 m .55573 .81291 L p
.54374 .82321 L 1 g
F P
s
P
p
.002 w
.55573 .81291 m .56958 .79874 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.56093 .80065 m .54404 .82303 L p
.56432 .81052 L 1 g
F P
s
P
p
.002 w
.56825 .82195 m .57349 .79984 L .57151 .79997 L p
1 g
F P
s
P
p
.002 w
.576 .78222 m .56958 .79874 L .57065 .80161 L p
1 g
F P
s
P
p
.576 .78222 m .57065 .80161 L .57151 .79997 L 1 g
F
P
p
.002 w
.57181 .77281 m .56575 .78845 L .56767 .79359 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .56767 .79359 L .56958 .79874 L p
1 g
F P
s
P
p
.002 w
.56767 .79359 m .5739 .77751 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.56958 .79874 m .576 .78222 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .57181 .77281 L .5739 .77751 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .5739 .77751 L .576 .78222 L p
1 g
F P
s
P
p
.002 w
.5739 .77751 m .57215 .76086 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.57918 .77819 m .57673 .7721 L .57629 .77586 L p
1 g
F P
s
P
p
.002 w
.57421 .76511 m .576 .78222 L .57699 .78443 L p
1 g
F P
s
P
p
.57421 .76511 m .57699 .78443 L .57697 .78426 L 1 g
F
P
p
.57918 .77819 m .57629 .77586 L .57699 .78443 L 1 g
F
P
p
.57642 .77748 m .57701 .78447 L .57642 .77751 L 1 g
F
P
p
.57421 .76511 m .57697 .78426 L .57642 .77748 L 1 g
F
P
p
.57697 .78426 m .57701 .78447 L .57642 .77748 L 1 g
F
P
p
.002 w
.57444 .79171 m .57349 .79984 L p
.57712 .78602 L 1 g
F P
s
P
p
.57918 .77819 m .57699 .78443 L .57712 .78602 L 1 g
F
P
p
.57699 .78443 m .57444 .79171 L .57712 .78602 L 1 g
F
P
p
.576 .78222 m .57151 .79997 L .57169 .79947 L 1 g
F
P
p
.002 w
.57151 .79997 m .57349 .79984 L .57444 .79171 L p
1 g
F P
s
P
p
.576 .78222 m .57161 .79978 L .57345 .79455 L 1 g
F
P
p
.002 w
.58626 .7958 m .57918 .77819 L p
.57712 .78602 L 1 g
F P
s
P
p
.002 w
.57349 .79984 m .57813 .79837 L p
.57712 .78602 L 1 g
F P
s
P
p
.002 w
.57813 .79837 m .58626 .7958 L p
.57712 .78602 L 1 g
F P
s
P
p
.002 w
.57673 .7721 m .57607 .77328 L p
.57621 .77488 L 1 g
F P
s
P
p
.57421 .76511 m .57642 .77748 L .57629 .77586 L 1 g
F
P
p
.002 w
.5715 .8039 m .57811 .78694 L .57701 .78447 L p
1 g
F P
s
P
p
.002 w
.57701 .78447 m .576 .78222 L p
.57346 .79447 L 1 g
F P
s
P
p
.57346 .79447 m .5715 .8039 L .57701 .78447 L 1 g
F
P
p
.002 w
.576 .78222 m .57421 .76511 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.57444 .79171 m .57629 .77586 L p
.57151 .79997 L 1 g
F P
s
P
p
.002 w
.57629 .77586 m .57673 .7721 L p
.57621 .77488 L 1 g
F P
s
P
p
.57421 .76511 m .57629 .77586 L .57607 .77328 L 1 g
F
P
p
.57421 .76511 m .57607 .77328 L .57601 .77264 L 1 g
F
P
p
.57421 .76511 m .57601 .77264 L .57598 .77233 L 1 g
F
P
p
.002 w
.54506 .77443 m .5291 .78287 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .53007 .78861 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .54658 .7799 L .54506 .77443 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .5481 .78538 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55624 .76288 m .54506 .77443 L .54658 .7799 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .54658 .7799 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.54658 .7799 m .55813 .76798 L .55624 .76288 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .5481 .78538 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.5481 .78538 m .56003 .77309 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.54962 .79087 m .56194 .7782 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56003 .77309 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .56194 .7782 L .56384 .78332 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .56762 .76344 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56384 .78332 L .56575 .78845 L p
1 g
F P
s
P
p
.002 w
.56384 .78332 m .56971 .76812 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56575 .78845 m .57181 .77281 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .56971 .76812 L .57181 .77281 L p
1 g
F P
s
P
p
.002 w
.57181 .77281 m .5701 .75662 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.53663 .77478 m .53707 .78448 L .57598 .77233 L p
1 g
F P
s
P
p
.002 w
.57598 .77233 m .57673 .7721 L .57596 .77215 L p
1 g
F P
s
P
p
.57421 .76511 m .57598 .77233 L .57597 .77224 L 1 g
F
P
p
.57421 .76511 m .57597 .77224 L .57592 .77179 L 1 g
F
P
p
.57421 .76511 m .57592 .77179 L .57589 .77158 L 1 g
F
P
p
.002 w
.56138 .74943 m .55624 .76288 L .55813 .76798 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .55813 .76798 L .56003 .77309 L p
1 g
F P
s
P
p
.002 w
.55813 .76798 m .56346 .75409 L .56138 .74943 L p
1 g
F P
s
P
p
.002 w
.56003 .77309 m .56554 .75876 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.55989 .73553 m .56138 .74943 L .56346 .75409 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .56346 .75409 L .56554 .75876 L p
1 g
F P
s
P
p
.002 w
.56346 .75409 m .56192 .73973 L .55989 .73553 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .56554 .75876 L .56762 .76344 L p
1 g
F P
s
P
p
.002 w
.56554 .75876 m .56396 .74394 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .56762 .76344 L .56971 .76812 L p
1 g
F P
s
P
p
.002 w
.56762 .76344 m .566 .74815 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56971 .76812 m .56805 .75238 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.5481 .75479 m .57589 .77159 L p
.5588 .74673 L 1 g
F P
s
P
p
.002 w
.55876 .7467 m .5481 .75479 L p
.5588 .74673 L 1 g
F P
s
P
p
.002 w
.51784 .73323 m .5481 .75479 L .55876 .7467 L p
1 g
F P
s
P
p
.54732 .73647 m .55927 .74706 L .55874 .74668 L 1 g
F
P
p
.002 w
.55876 .7467 m .55877 .74669 L p
.55873 .74667 L 1 g
F P
s
P
p
.51784 .73323 m .55876 .7467 L .55873 .74667 L 1 g
F
P
p
.002 w
.54793 .73807 m .54732 .73647 L p
.55874 .74668 L 1 g
F P
s
P
p
.002 w
.54206 .7226 m .55718 .73402 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .54206 .7226 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .53944 .71572 L .54075 .71916 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .55896 .73782 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.55896 .73782 m .54337 .72606 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .54075 .71916 L .54206 .7226 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .52157 .71196 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .56074 .74163 L .56252 .74545 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .54468 .72952 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .54206 .7226 L .54337 .72606 L p
1 g
F P
s
P
p
.002 w
.54206 .7226 m .52227 .71519 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .56252 .74545 L .56431 .74928 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .546 .73299 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .54337 .72606 L .54468 .72952 L p
1 g
F P
s
P
p
.002 w
.54337 .72606 m .52296 .71841 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.5753 .76737 m .57421 .76511 L p
.57589 .7716 L 1 g
F P
s
P
p
.002 w
.55896 .73782 m .56805 .75238 L .5701 .75662 L p
1 g
F P
s
P
p
.002 w
.56074 .74163 m .5701 .75662 L .57215 .76086 L p
1 g
F P
s
P
p
.002 w
.5701 .75662 m .56074 .74163 L .55896 .73782 L p
1 g
F P
s
P
p
.002 w
.56252 .74545 m .57215 .76086 L .57421 .76511 L p
1 g
F P
s
P
p
.002 w
.57215 .76086 m .56252 .74545 L .56074 .74163 L p
1 g
F P
s
P
p
.002 w
.5588 .74673 m .57578 .77076 L p
.57525 .76728 L 1 g
F P
s
P
p
.002 w
.56431 .74928 m .57421 .76511 L .5753 .76737 L p
1 g
F P
s
P
p
.56431 .74928 m .5753 .76737 L .57051 .75969 L 1 g
F
P
p
.002 w
.57421 .76511 m .56431 .74928 L .56252 .74545 L p
1 g
F P
s
P
p
.5588 .74673 m .57525 .76728 L .56522 .75121 L 1 g
F
P
p
.002 w
.57578 .77076 m .57673 .7721 L .57302 .75095 L p
1 g
F P
s
P
p
.002 w
.57539 .76755 m .5753 .76737 L p
.57589 .7716 L 1 g
F P
s
P
p
.002 w
.57302 .75095 m .57129 .74111 L p
.57578 .77076 L 1 g
F P
s
P
p
.002 w
.5755 .76778 m .57539 .76755 L p
.57597 .77224 L 1 g
F P
s
P
p
.002 w
.5756 .76799 m .5755 .76778 L p
.57596 .77216 L 1 g
F P
s
P
p
.57596 .77216 m .57599 .77234 L .5756 .76799 L 1 g
F
P
p
.002 w
.57564 .76805 m .5756 .76799 L p
.57603 .77278 L 1 g
F P
s
P
p
.002 w
.57589 .77159 m .57673 .7721 L .57578 .77076 L p
1 g
F P
s
P
p
.57603 .77278 m .57605 .77298 L .57564 .76805 L 1 g
F
P
p
.002 w
.57593 .77193 m .57673 .7721 L .57589 .77159 L p
1 g
F P
s
P
p
.002 w
.57565 .76808 m .57564 .76805 L p
.57629 .77586 L 1 g
F P
s
P
p
.002 w
.57596 .77215 m .57673 .7721 L .57593 .77193 L p
1 g
F P
s
P
p
.002 w
.576 .77252 m .57673 .7721 L .57598 .77233 L p
1 g
F P
s
P
p
.002 w
.57603 .77278 m .57673 .7721 L .576 .77252 L p
1 g
F P
s
P
p
.002 w
.57607 .77328 m .57673 .7721 L .57603 .77278 L p
1 g
F P
s
P
p
.002 w
.58427 .73866 m .57129 .74111 L .57613 .76869 L p
1 g
F P
s
P
p
.002 w
.57613 .76869 m .57673 .7721 L .57713 .7703 L p
1 g
F P
s
P
p
.002 w
.57713 .7703 m .58427 .73866 L p
.57613 .76869 L 1 g
F P
s
P
p
.002 w
.57569 .76842 m .57628 .76938 L .57565 .76808 L p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .5757 .76845 L p
.57811 .78694 L 1 g
F P
s
P
p
.57642 .77748 m .57811 .78694 L .57565 .76808 L 1 g
F
P
p
.002 w
.57628 .76938 m .56611 .75311 L .56528 .75134 L p
1 g
F P
s
P
p
.002 w
.56528 .75134 m .56522 .75121 L p
.56594 .7524 L 1 g
F P
s
P
p
.56594 .7524 m .57628 .76938 L .56528 .75134 L 1 g
F
P
p
.002 w
.56522 .75121 m .56431 .74928 L p
.57051 .75969 L 1 g
F P
s
P
p
.57051 .75969 m .57628 .76938 L .56522 .75121 L 1 g
F
P
p
.002 w
.5554 .73023 m .56396 .74394 L .566 .74815 L p
1 g
F P
s
P
p
.002 w
.55718 .73402 m .566 .74815 L .56805 .75238 L p
1 g
F P
s
P
p
.002 w
.566 .74815 m .55718 .73402 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.56805 .75238 m .55896 .73782 L .55718 .73402 L p
1 g
F P
s
P
p
.56163 .74546 m .57372 .75715 L .57129 .74111 L 1 g
F
P
p
.002 w
.54732 .73647 m .56431 .74928 L .56522 .75121 L p
1 g
F P
s
P
p
.002 w
.56522 .75121 m .56611 .75311 L p
.55927 .74706 L 1 g
F P
s
P
p
.54732 .73647 m .56522 .75121 L .55927 .74706 L 1 g
F
P
p
.55927 .74706 m .5588 .74673 L .55876 .7467 L 1 g
F
P
p
.55927 .74706 m .55876 .7467 L .55874 .74668 L 1 g
F
P
p
.002 w
.56431 .74928 m .54732 .73647 L .546 .73299 L p
1 g
F P
s
P
p
.5588 .74673 m .56522 .75121 L .56163 .74546 L 1 g
F
P
p
.56522 .75121 m .57372 .75715 L .56163 .74546 L 1 g
F
P
p
.56522 .75121 m .57525 .76728 L .57372 .75715 L 1 g
F
P
p
.002 w
.5753 .76737 m .57628 .76938 L p
.57051 .75969 L 1 g
F P
s
P
p
.002 w
.52366 .72165 m .54468 .72952 L .546 .73299 L p
1 g
F P
s
P
p
.002 w
.54468 .72952 m .52366 .72165 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .546 .73299 L .54732 .73647 L p
1 g
F P
s
P
p
.002 w
.546 .73299 m .52436 .7249 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .54732 .73647 L .54793 .73807 L p
1 g
F P
s
P
p
.52506 .72815 m .54793 .73807 L .53674 .734 L 1 g
F
P
p
.002 w
.54732 .73647 m .52506 .72815 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .52436 .7249 L .52506 .72815 L p
1 g
F P
s
P
p
.002 w
.52506 .72815 m .5 .72527 L .5 .72209 L p
1 g
F P
s
P
p
.51784 .73323 m .55873 .74667 L .54793 .73807 L 1 g
F
P
p
.002 w
.52543 .72988 m .52506 .72815 L p
.53674 .734 L 1 g
F P
s
P
p
.002 w
.5 .72527 m .52506 .72815 L .52543 .72988 L p
1 g
F P
s
P
p
.5 .72527 m .52543 .72988 L .52246 .72971 L 1 g
F
P
p
.5 .72527 m .52246 .72971 L .51637 .72898 L 1 g
F
P
p
.002 w
.51196 .72845 m .51784 .73323 L .52246 .72971 L p
1 g
F P
s
P
p
.5 .72527 m .51856 .72948 L .51595 .72907 L 1 g
F
P
p
.002 w
.5 .70947 m .47843 .71196 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .5 .70634 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .47773 .71519 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .5 .70947 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.5 .70947 m .52157 .71196 L .52227 .71519 L p
1 g
F P
s
P
p
.002 w
.52227 .71519 m .5 .71262 L .5 .70947 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .47704 .71841 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .5 .71262 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71262 m .52227 .71519 L .52296 .71841 L p
1 g
F P
s
P
p
.002 w
.52296 .71841 m .5 .71577 L .5 .71262 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .5 .71577 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.5 .71577 m .52296 .71841 L .52366 .72165 L p
1 g
F P
s
P
p
.002 w
.52366 .72165 m .5 .71892 L .5 .71577 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .52366 .72165 L .52436 .7249 L p
1 g
F P
s
P
p
.002 w
.52436 .7249 m .5 .72209 L .5 .71892 L p
1 g
F P
s
P
p
.002 w
.51784 .73323 m .51196 .72845 L p
.46484 .73644 L 1 g
F P
s
P
p
.002 w
.47564 .7249 m .454 .73299 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .47634 .72165 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47494 .72815 m .45268 .73647 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .47564 .7249 L .47494 .72815 L p
1 g
F P
s
P
p
.002 w
.5 .72209 m .47564 .7249 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .72527 m .47494 .72815 L .47564 .7249 L p
1 g
F P
s
P
p
.002 w
.47564 .7249 m .5 .72209 L .5 .72527 L p
1 g
F P
s
P
p
.46484 .73644 m .51196 .72845 L .5 .7266 L 1 g
F
P
p
.46484 .73644 m .5 .7266 L .47799 .72926 L 1 g
F
P
p
.002 w
.47461 .72967 m .47494 .72815 L p
.48606 .72828 L 1 g
F P
s
P
p
.002 w
.46786 .73255 m .46484 .73644 L p
.47799 .72926 L 1 g
F P
s
P
p
.002 w
.47494 .72815 m .5 .72527 L .5 .7266 L p
1 g
F P
s
P
p
.47494 .72815 m .5 .7266 L .48606 .72828 L 1 g
F
P
p
.47799 .72926 m .48665 .72453 L .47461 .72967 L 1 g
F
P
p
.47799 .72926 m .47461 .72967 L .46786 .73255 L 1 g
F
P
p
.002 w
.5 .7266 m .5 .72845 L p
.48606 .72828 L 1 g
F P
s
P
p
.002 w
.5 .72845 m .47424 .73141 L .47461 .72967 L p
1 g
F P
s
P
p
.48606 .72828 m .5 .72845 L .47461 .72967 L 1 g
F
P
p
.47799 .72926 m .5 .7266 L .48665 .72453 L 1 g
F
P
p
.002 w
.45268 .73647 m .47494 .72815 L .47455 .72997 L p
1 g
F P
s
P
p
.45268 .73647 m .47455 .72997 L .46725 .73279 L 1 g
F
P
p
.002 w
.46187 .73486 m .46484 .73644 L .46786 .73255 L p
1 g
F P
s
P
p
.45268 .73647 m .47433 .731 L .46912 .73261 L 1 g
F
P
p
.002 w
.43808 .73973 m .43654 .75409 L .43862 .74943 L p
1 g
F P
s
P
p
.002 w
.43862 .74943 m .44011 .73553 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .43446 .75876 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .43808 .73973 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43604 .74394 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .434 .74815 L .43604 .74394 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .43238 .76344 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .434 .74815 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .43195 .75238 L .434 .74815 L p
1 g
F P
s
P
p
.002 w
.434 .74815 m .44282 .73402 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .43029 .76812 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43195 .75238 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .4299 .75662 L .43195 .75238 L p
1 g
F P
s
P
p
.002 w
.43195 .75238 m .44104 .73782 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .42819 .77281 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .4299 .75662 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .42785 .76086 L .4299 .75662 L p
1 g
F P
s
P
p
.002 w
.4299 .75662 m .43926 .74163 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .43748 .74545 L .43569 .74928 L p
1 g
F P
s
P
p
.002 w
.454 .73299 m .43748 .74545 L .43926 .74163 L p
1 g
F P
s
P
p
.002 w
.45268 .73647 m .43569 .74928 L .43748 .74545 L p
1 g
F P
s
P
p
.002 w
.43748 .74545 m .454 .73299 L .45268 .73647 L p
1 g
F P
s
P
p
.002 w
.46484 .73644 m .46187 .73486 L p
.44834 .74071 L 1 g
F P
s
P
p
.44312 .74461 m .46484 .73644 L .44834 .74071 L 1 g
F
P
p
.002 w
.43569 .74928 m .45268 .73647 L .45215 .73788 L p
1 g
F P
s
P
p
.43569 .74928 m .45215 .73788 L .44143 .74586 L 1 g
F
P
p
.002 w
.4446 .73023 m .43604 .74394 L .43808 .73973 L p
1 g
F P
s
P
p
.002 w
.43604 .74394 m .4446 .73023 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.41662 .74891 m .41434 .75542 L p
.46187 .73486 L 1 g
F P
s
P
p
.002 w
.43507 .7506 m .43569 .74928 L p
.44143 .74586 L 1 g
F P
s
P
p
.002 w
.45494 .77443 m .44376 .76288 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.43654 .75409 m .44187 .76798 L .44376 .76288 L p
1 g
F P
s
P
p
.002 w
.44376 .76288 m .43862 .74943 L .43654 .75409 L p
1 g
F P
s
P
p
.002 w
.43446 .75876 m .43997 .77309 L .44187 .76798 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .43654 .75409 L .43446 .75876 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .43446 .75876 L .43238 .76344 L p
1 g
F P
s
P
p
.002 w
.42785 .76086 m .4261 .77751 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.4261 .77751 m .42785 .76086 L .42579 .76511 L p
1 g
F P
s
P
p
.002 w
.43569 .74928 m .42579 .76511 L .42785 .76086 L p
1 g
F P
s
P
p
.002 w
.45418 .76632 m .46484 .73644 L p
.43743 .74674 L 1 g
F P
s
P
p
.42579 .76511 m .42994 .75896 L .42956 .75958 L 1 g
F
P
p
.002 w
.42579 .76511 m .424 .78222 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.4161 .78068 m .41686 .79155 L p
.42439 .7726 L 1 g
F P
s
P
p
.42439 .7726 m .42502 .7667 L .4161 .78068 L 1 g
F
P
p
.002 w
.424 .78222 m .42579 .76511 L .42502 .7667 L p
1 g
F P
s
P
p
.41686 .79155 m .42279 .78754 L .42316 .7841 L 1 g
F
P
p
.42169 .77938 m .42316 .7841 L .42439 .7726 L 1 g
F
P
p
.41686 .79155 m .42316 .7841 L .42169 .77938 L 1 g
F
P
p
.002 w
.41686 .79155 m .43478 .82129 L p
.43775 .8175 L 1 g
F P
s
P
p
.43042 .79874 m .42567 .79218 L .42567 .79218 L 1 g
F
P
p
.002 w
.42971 .80064 m .43042 .79874 L p
.42567 .79218 L 1 g
F P
s
P
p
.002 w
.44886 .79637 m .46699 .8059 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .45038 .79087 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .466 .81167 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .44886 .79637 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.466 .81167 m .44733 .80188 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .44886 .79637 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .44733 .80188 L .44886 .79637 L p
1 g
F P
s
P
p
.002 w
.44886 .79637 m .43616 .78332 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4458 .80739 L .44733 .80188 L p
1 g
F P
s
P
p
.002 w
.44733 .80188 m .43425 .78845 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .44427 .81291 L .4458 .80739 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .43233 .79359 L .43042 .79874 L p
1 g
F P
s
P
p
.43775 .8175 m .44147 .81275 L .42971 .80064 L 1 g
F
P
p
.43775 .8175 m .42971 .80064 L .41686 .79155 L 1 g
F
P
p
.002 w
.42567 .79218 m .42118 .79186 L p
.42971 .80064 L 1 g
F P
s
P
p
.002 w
.42118 .79186 m .41686 .79155 L p
.42971 .80064 L 1 g
F P
s
P
p
.002 w
.44427 .81291 m .43042 .79874 L .42971 .80064 L p
1 g
F P
s
P
p
.002 w
.42971 .80064 m .4285 .8039 L p
.43832 .80951 L 1 g
F P
s
P
p
.44427 .81291 m .42971 .80064 L .43832 .80951 L 1 g
F
P
p
.002 w
.44368 .81504 m .44427 .81291 L p
.43832 .80951 L 1 g
F P
s
P
p
.002 w
.4886 .81091 m .46699 .8059 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.4458 .80739 m .46502 .81746 L .466 .81167 L p
1 g
F P
s
P
p
.002 w
.44427 .81291 m .46403 .82325 L .46502 .81746 L p
1 g
F P
s
P
p
.002 w
.46502 .81746 m .4458 .80739 L .44427 .81291 L p
1 g
F P
s
P
p
.002 w
.43478 .82129 m .45071 .81954 L p
.44102 .81333 L 1 g
F P
s
P
p
.002 w
.46403 .82325 m .44427 .81291 L .44333 .81632 L p
1 g
F P
s
P
p
.46403 .82325 m .44333 .81632 L .45402 .82099 L 1 g
F
P
p
.002 w
.46962 .81747 m .45071 .81954 L p
.46822 .82644 L 1 g
F P
s
P
p
.002 w
.45071 .81954 m .44504 .82017 L p
.4637 .82521 L 1 g
F P
s
P
p
.46822 .82644 m .45071 .81954 L .4637 .82521 L 1 g
F
P
p
.002 w
.44333 .81632 m .44274 .81844 L p
.45402 .82099 L 1 g
F P
s
P
p
.002 w
.46962 .81747 m .4559 .79433 L p
.44102 .81333 L 1 g
F P
s
P
p
.002 w
.45071 .81954 m .46962 .81747 L p
.44102 .81333 L 1 g
F P
s
P
p
.002 w
.44274 .81844 m .46305 .82905 L .46329 .82761 L p
1 g
F P
s
P
p
.002 w
.46329 .82761 m .4637 .82521 L p
.45534 .82251 L 1 g
F P
s
P
p
.45534 .82251 m .44274 .81844 L .46329 .82761 L 1 g
F
P
p
.002 w
.4285 .8039 m .44274 .81844 L .44368 .81504 L p
1 g
F P
s
P
p
.43832 .80951 m .4285 .8039 L .44368 .81504 L 1 g
F
P
p
.002 w
.4261 .77751 m .43233 .79359 L .43425 .78845 L p
1 g
F P
s
P
p
.002 w
.424 .78222 m .43042 .79874 L .43233 .79359 L p
1 g
F P
s
P
p
.002 w
.43233 .79359 m .4261 .77751 L .424 .78222 L p
1 g
F P
s
P
p
.002 w
.43042 .79874 m .424 .78222 L .42316 .7841 L p
1 g
F P
s
P
p
.42279 .78754 m .42398 .78673 L .42316 .7841 L 1 g
F
P
p
.43042 .79874 m .42316 .7841 L .42567 .79218 L 1 g
F
P
p
.002 w
.45342 .7799 m .46993 .78861 L .4709 .78287 L p
1 g
F P
s
P
p
.002 w
.4709 .78287 m .45494 .77443 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .46895 .79437 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .45342 .7799 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .46797 .80013 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .4519 .78538 L .45038 .79087 L p
1 g
F P
s
P
p
.002 w
.44187 .76798 m .45342 .7799 L .45494 .77443 L p
1 g
F P
s
P
p
.002 w
.43997 .77309 m .4519 .78538 L .45342 .7799 L p
1 g
F P
s
P
p
.002 w
.45342 .7799 m .44187 .76798 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .45038 .79087 L .4519 .78538 L p
1 g
F P
s
P
p
.002 w
.4519 .78538 m .43997 .77309 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.45038 .79087 m .43806 .7782 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43238 .76344 m .43806 .7782 L .43997 .77309 L p
1 g
F P
s
P
p
.002 w
.43029 .76812 m .43616 .78332 L .43806 .7782 L p
1 g
F P
s
P
p
.002 w
.43806 .7782 m .43238 .76344 L .43029 .76812 L p
1 g
F P
s
P
p
.002 w
.42819 .77281 m .43425 .78845 L .43616 .78332 L p
1 g
F P
s
P
p
.002 w
.43616 .78332 m .43029 .76812 L .42819 .77281 L p
1 g
F P
s
P
p
.002 w
.43425 .78845 m .42819 .77281 L .4261 .77751 L p
1 g
F P
s
P
p
.002 w
.41686 .79155 m .4559 .79433 L .45418 .76632 L p
1 g
F P
s
P
p
.002 w
.42316 .7841 m .42189 .78694 L p
.42567 .79218 L 1 g
F P
s
P
p
.424 .78222 m .42502 .7667 L .42389 .77726 L 1 g
F
P
p
.002 w
.42316 .7841 m .424 .78222 L p
.42389 .77726 L 1 g
F P
s
P
p
.42316 .7841 m .45418 .76632 L .42439 .7726 L 1 g
F
P
p
.42398 .78673 m .45418 .76632 L .42316 .7841 L 1 g
F
P
p
.002 w
.4559 .79433 m .42567 .79218 L p
.42971 .80064 L 1 g
F P
s
P
p
.44147 .81275 m .4559 .79433 L .42971 .80064 L 1 g
F
P
p
.002 w
.42895 .80269 m .42971 .80064 L p
.42567 .79218 L 1 g
F P
s
P
p
.002 w
.42189 .78694 m .4285 .8039 L .42895 .80269 L p
1 g
F P
s
P
p
.42567 .79218 m .42189 .78694 L .42895 .80269 L 1 g
F
P
p
.002 w
.42502 .7667 m .42372 .76938 L p
.42389 .77726 L 1 g
F P
s
P
p
.002 w
.45418 .76632 m .42956 .75958 L p
.42439 .7726 L 1 g
F P
s
P
p
.42439 .7726 m .42956 .75958 L .42502 .7667 L 1 g
F
P
p
.002 w
.42372 .76938 m .42189 .78694 L .42316 .7841 L p
1 g
F P
s
P
p
.42389 .77726 m .42372 .76938 L .42316 .7841 L 1 g
F
P
p
.002 w
.42435 .76809 m .42502 .7667 L p
.42956 .75958 L 1 g
F P
s
P
p
.002 w
.42502 .7667 m .42579 .76511 L p
.42956 .75958 L 1 g
F P
s
P
p
.002 w
.42956 .75958 m .45418 .76632 L p
.43743 .74674 L 1 g
F P
s
P
p
.002 w
.42579 .76511 m .43569 .74928 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.42956 .75958 m .41434 .75542 L .4161 .78068 L p
1 g
F P
s
P
p
.002 w
.41434 .75542 m .42956 .75958 L p
.43743 .74674 L 1 g
F P
s
P
p
.002 w
.43389 .75311 m .42372 .76938 L .42435 .76809 L p
1 g
F P
s
P
p
.42994 .75896 m .43389 .75311 L .42435 .76809 L 1 g
F
P
p
.002 w
.45215 .73788 m .45136 .73996 L p
.44143 .74586 L 1 g
F P
s
P
p
.002 w
.44637 .72645 m .43808 .73973 L .44011 .73553 L p
1 g
F P
s
P
p
.002 w
.44011 .73553 m .44813 .72267 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.43808 .73973 m .44637 .72645 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .44282 .73402 L .4446 .73023 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .44104 .73782 L .44282 .73402 L p
1 g
F P
s
P
p
.002 w
.44282 .73402 m .45794 .7226 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45532 .72952 m .43926 .74163 L .44104 .73782 L p
1 g
F P
s
P
p
.002 w
.44104 .73782 m .45663 .72606 L .45532 .72952 L p
1 g
F P
s
P
p
.002 w
.43926 .74163 m .45532 .72952 L .454 .73299 L p
1 g
F P
s
P
p
.002 w
.42785 .71679 m .41662 .74891 L p
.45215 .73788 L 1 g
F P
s
P
p
.45268 .73647 m .466 .73335 L .46397 .73421 L 1 g
F
P
p
.002 w
.45152 .73953 m .45215 .73788 L p
.46397 .73421 L 1 g
F P
s
P
p
.002 w
.45215 .73788 m .45268 .73647 L p
.46397 .73421 L 1 g
F P
s
P
p
.002 w
.46187 .73486 m .45856 .73311 L p
.45215 .73788 L 1 g
F P
s
P
p
.002 w
.45925 .71916 m .4446 .73023 L .44637 .72645 L p
1 g
F P
s
P
p
.002 w
.4446 .73023 m .45925 .71916 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45856 .73311 m .42785 .71679 L p
.45215 .73788 L 1 g
F P
s
P
p
.41434 .75542 m .44312 .74461 L .44834 .74071 L 1 g
F
P
p
.002 w
.45136 .73996 m .43389 .75311 L .43507 .7506 L p
1 g
F P
s
P
p
.44143 .74586 m .45136 .73996 L .43507 .7506 L 1 g
F
P
p
.002 w
.46056 .71572 m .44637 .72645 L .44813 .72267 L p
1 g
F P
s
P
p
.002 w
.44813 .72267 m .46186 .71229 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.44637 .72645 m .46056 .71572 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.47912 .70875 m .46056 .71572 L .46186 .71229 L p
1 g
F P
s
P
p
.002 w
.46186 .71229 m .47981 .70555 L .47912 .70875 L p
1 g
F P
s
P
p
.002 w
.47843 .71196 m .45925 .71916 L .46056 .71572 L p
1 g
F P
s
P
p
.002 w
.46056 .71572 m .47912 .70875 L .47843 .71196 L p
1 g
F P
s
P
p
.002 w
.47773 .71519 m .45794 .7226 L .45925 .71916 L p
1 g
F P
s
P
p
.002 w
.45925 .71916 m .47843 .71196 L .47773 .71519 L p
1 g
F P
s
P
p
.002 w
.47704 .71841 m .45663 .72606 L .45794 .7226 L p
1 g
F P
s
P
p
.002 w
.45794 .7226 m .47773 .71519 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.47634 .72165 m .45532 .72952 L .45663 .72606 L p
1 g
F P
s
P
p
.002 w
.45663 .72606 m .47704 .71841 L .47634 .72165 L p
1 g
F P
s
P
p
.002 w
.5 .71892 m .47634 .72165 L .47704 .71841 L p
1 g
F P
s
P
p
.002 w
.42785 .71679 m .46187 .73486 L p
.48686 .70805 L 1 g
F P
s
P
p
.002 w
.46786 .73255 m .48686 .70805 L p
.46187 .73486 L 1 g
F P
s
P
p
.002 w
.47455 .72997 m .47433 .731 L p
.46725 .73279 L 1 g
F P
s
P
p
.002 w
.47433 .731 m .47424 .73141 L p
.46912 .73261 L 1 g
F P
s
P
p
.002 w
.47543 .72279 m .46786 .73255 L p
.48665 .72453 L 1 g
F P
s
P
p
.002 w
.47424 .73141 m .45136 .73996 L .45152 .73953 L p
1 g
F P
s
P
p
.466 .73335 m .47424 .73141 L .45152 .73953 L 1 g
F
P
p
.51784 .73323 m .54793 .73807 L .52543 .72988 L 1 g
F
P
p
.002 w
.52327 .72909 m .52246 .72971 L p
.52543 .72988 L 1 g
F P
s
P
p
.002 w
.52246 .72971 m .51784 .73323 L p
.52543 .72988 L 1 g
F P
s
P
p
.002 w
.52576 .73141 m .5 .72845 L .5 .72838 L p
1 g
F P
s
P
p
.002 w
.5 .72838 m .5 .72527 L p
.51735 .7294 L 1 g
F P
s
P
p
.51735 .7294 m .52576 .73141 L .5 .72838 L 1 g
F
P
p
.002 w
.48686 .70805 m .51196 .72845 L p
.53895 .71715 L 1 g
F P
s
P
p
.002 w
.52246 .72971 m .53895 .71715 L p
.51196 .72845 L 1 g
F P
s
P
p
.51637 .72898 m .52246 .72971 L .51856 .72948 L 1 g
F
P
p
.51595 .72907 m .51856 .72948 L .51735 .7294 L 1 g
F
P
p
.002 w
.47634 .72165 m .5 .71892 L .5 .72209 L p
1 g
F P
s
P
p
.002 w
.51196 .72845 m .48686 .70805 L .47543 .72279 L p
1 g
F P
s
P
p
.002 w
.52543 .72988 m .52576 .73141 L p
.51735 .7294 L 1 g
F P
s
P
p
.002 w
.53011 .72389 m .52327 .72909 L p
.52543 .72988 L 1 g
F P
s
P
p
.52543 .72988 m .54793 .73807 L .53862 .73066 L 1 g
F
P
p
.52543 .72988 m .53862 .73066 L .53011 .72389 L 1 g
F
P
p
.002 w
.54864 .73996 m .52576 .73141 L .52543 .72988 L p
1 g
F P
s
P
p
.53674 .734 m .54864 .73996 L .52543 .72988 L 1 g
F
P
p
.002 w
.54793 .73807 m .54864 .73996 L p
.53674 .734 L 1 g
F P
s
P
p
.002 w
.53895 .71715 m .53011 .72389 L p
.54796 .73808 L 1 g
F P
s
P
p
.002 w
.55877 .74669 m .55463 .74051 L p
.54796 .73808 L 1 g
F P
s
P
p
.002 w
.55463 .74051 m .53895 .71715 L p
.54796 .73808 L 1 g
F P
s
P
p
.55873 .74667 m .55877 .74669 L .53011 .72389 L 1 g
F
P
p
.55874 .74668 m .55876 .7467 L .54845 .73945 L 1 g
F
P
p
.002 w
.54845 .73945 m .54793 .73807 L p
.55874 .74668 L 1 g
F P
s
P
p
.55927 .74706 m .55928 .74707 L .5588 .74673 L 1 g
F
P
p
.002 w
.57129 .74111 m .55877 .74669 L .5588 .74673 L p
1 g
F P
s
P
p
.002 w
.57578 .77076 m .55877 .74669 L p
.57589 .77159 L 1 g
F P
s
P
p
.002 w
.56611 .75311 m .54864 .73996 L .54845 .73945 L p
1 g
F P
s
P
p
.55928 .74707 m .56611 .75311 L .54845 .73945 L 1 g
F
P
p
.002 w
.55877 .74669 m .55876 .7467 L p
.5588 .74673 L 1 g
F P
s
P
p
.57589 .77158 m .57592 .77179 L .57589 .7716 L 1 g
F
P
p
.002 w
.57596 .77215 m .53663 .77478 L p
.57598 .77233 L 1 g
F P
s
P
p
.57597 .77224 m .57598 .77233 L .57597 .77224 L 1 g
F
P
p
.002 w
.54044 .76451 m .53663 .77478 L .57596 .77215 L p
1 g
F P
s
P
p
.002 w
.57593 .77193 m .54044 .76451 L p
.57596 .77215 L 1 g
F P
s
P
p
.002 w
.5481 .75479 m .54044 .76451 L .57593 .77193 L p
1 g
F P
s
P
p
.002 w
.57589 .77159 m .5481 .75479 L p
.57593 .77193 L 1 g
F P
s
P
p
.57596 .77216 m .57601 .77264 L .57599 .77234 L 1 g
F
P
p
.002 w
.5481 .78538 m .53105 .79437 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .54962 .79087 L .5481 .78538 L p
1 g
F P
s
P
p
.002 w
.56194 .7782 m .54962 .79087 L .55114 .79637 L p
1 g
F P
s
P
p
.002 w
.55114 .79637 m .56384 .78332 L .56194 .7782 L p
1 g
F P
s
P
p
.002 w
.53707 .78448 m .54167 .79255 L .576 .77252 L p
1 g
F P
s
P
p
.002 w
.57598 .77233 m .53707 .78448 L p
.576 .77252 L 1 g
F P
s
P
p
.002 w
.54962 .79087 m .53203 .80013 L .53301 .8059 L p
1 g
F P
s
P
p
.002 w
.53301 .8059 m .55114 .79637 L .54962 .79087 L p
1 g
F P
s
P
p
.002 w
.54167 .79255 m .54993 .79814 L .57603 .77278 L p
1 g
F P
s
P
p
.002 w
.576 .77252 m .54167 .79255 L p
.57603 .77278 L 1 g
F P
s
P
p
.57603 .77278 m .57607 .77328 L .57605 .77298 L 1 g
F
P
p
.002 w
.54993 .79814 m .56093 .80065 L .57607 .77328 L p
1 g
F P
s
P
p
.002 w
.57603 .77278 m .54993 .79814 L p
.57607 .77328 L 1 g
F P
s
P
p
.57629 .77586 m .57621 .77488 L .57151 .79997 L 1 g
F
P
p
.002 w
.57629 .77586 m .57444 .79171 L p
.57699 .78443 L 1 g
F P
s
P
p
.002 w
.57699 .78443 m .57701 .78447 L p
.57697 .78426 L 1 g
F P
s
P
p
.002 w
.57701 .78447 m .57811 .78694 L p
.57642 .77751 L 1 g
F P
s
P
p
.002 w
.56093 .80065 m .57151 .79997 L p
.57621 .77488 L 1 g
F P
s
P
p
.002 w
.57607 .77328 m .56093 .80065 L p
.57621 .77488 L 1 g
F P
s
P
p
.57169 .79947 m .57151 .79997 L .57161 .79978 L 1 g
F
P
p
.57345 .79455 m .57161 .79978 L .57285 .79743 L 1 g
F
P
p
.002 w
.57151 .79997 m .56093 .80065 L p
.56497 .81241 L 1 g
F P
s
P
p
.56825 .82195 m .57151 .79997 L .56497 .81241 L 1 g
F
P
p
.002 w
.57065 .80161 m .5715 .8039 L p
.57285 .79743 L 1 g
F P
s
P
p
.002 w
.55726 .81844 m .5715 .8039 L .57065 .80161 L p
1 g
F P
s
P
p
.56339 .80864 m .55726 .81844 L .57065 .80161 L 1 g
F
P
p
.52531 .84034 m .54321 .8235 L .52384 .83084 L 1 g
F
P
p
.002 w
.53695 .82905 m .55726 .81844 L .55642 .8154 L p
1 g
F P
s
P
p
.54374 .82321 m .53695 .82905 L .55642 .8154 L 1 g
F
P
p
.002 w
.55642 .8154 m .55726 .81844 L p
.56339 .80864 L 1 g
F P
s
P
p
.002 w
.54404 .82303 m .56093 .80065 L p
.54371 .82322 L 1 g
F P
s
P
p
.54371 .82322 m .54993 .79814 L .54321 .8235 L 1 g
F
P
p
.54349 .82334 m .54321 .8235 L .54338 .82344 L 1 g
F
P
p
.54374 .82321 m .54338 .82344 L .54356 .82337 L 1 g
F
P
p
.002 w
.54321 .8235 m .52196 .81872 L p
.52384 .83084 L 1 g
F P
s
P
p
.002 w
.53644 .82606 m .53695 .82905 L p
.54356 .82337 L 1 g
F P
s
P
p
.002 w
.51276 .83464 m .53695 .82905 L .53644 .82606 L p
1 g
F P
s
P
p
.52558 .82835 m .51276 .83464 L .53644 .82606 L 1 g
F
P
p
.002 w
.51256 .83108 m .51276 .83464 L p
.52558 .82835 L 1 g
F P
s
P
p
.002 w
.49366 .83332 m .49766 .83421 L p
.5096 .8317 L 1 g
F P
s
P
p
.002 w
.51276 .83464 m .51256 .83108 L p
.49538 .83272 L 1 g
F P
s
P
p
.49772 .83216 m .49538 .83272 L .51256 .83108 L 1 g
F
P
p
.002 w
.46585 .84161 m .49366 .83332 L .49365 .83332 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .50949 .83464 L p
.49538 .83272 L 1 g
F P
s
P
p
.002 w
.50949 .83464 m .51276 .83464 L p
.49538 .83272 L 1 g
F P
s
P
p
.002 w
.4637 .82521 m .46305 .82905 L p
.47712 .82885 L 1 g
F P
s
P
p
.45402 .82099 m .44274 .81844 L .4637 .82521 L 1 g
F
P
p
.002 w
.46305 .82905 m .48724 .83464 L .48741 .83163 L p
1 g
F P
s
P
p
.47712 .82885 m .46305 .82905 L .48741 .83163 L 1 g
F
P
p
.002 w
.44362 .38745 m .45349 .40093 L .5289 .38829 L p
1 g
F P
s
P
p
.002 w
.45349 .40093 m .44362 .38745 L .3756 .41758 L p
1 g
F P
s
P
p
.002 w
.65711 .78154 m .63416 .7832 L .61602 .80064 L p
1 g
F P
s
P
p
.002 w
.63416 .7832 m .65711 .78154 L .67408 .75284 L p
1 g
F P
s
P
p
.002 w
.3756 .41758 m .38091 .43308 L .45349 .40093 L p
1 g
F P
s
P
p
.002 w
.34347 .72201 m .31452 .70057 L .3193 .75433 L p
1 g
F P
s
P
p
.002 w
.3193 .75433 m .34757 .77119 L .34347 .72201 L p
1 g
F P
s
P
p
.002 w
.46993 .78861 m .48961 .7932 L .48995 .78731 L p
1 g
F P
s
P
p
.002 w
.48995 .78731 m .4709 .78287 L .46993 .78861 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .51039 .7932 L .51005 .78731 L p
1 g
F P
s
P
p
.004 w
.5 .6118 m
.56008 .73733 L
s
P
p
.002 w
.51005 .78731 m .48995 .78731 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.5291 .78287 m .51005 .78731 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.31089 .61579 m .29372 .58888 L .27359 .65157 L p
1 g
F P
s
P
p
.002 w
.27359 .65157 m .29103 .67685 L .31089 .61579 L p
1 g
F P
s
P
p
.002 w
.41686 .79155 m .3804 .78374 L .40208 .81926 L p
1 g
F P
s
P
p
.002 w
.40208 .81926 m .43478 .82129 L .41686 .79155 L p
1 g
F P
s
P
p
.002 w
.46895 .79437 m .48927 .7991 L .48961 .7932 L p
1 g
F P
s
P
p
.002 w
.48961 .7932 m .46993 .78861 L .46895 .79437 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .51073 .7991 L .51039 .7932 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .48961 .7932 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.53007 .78861 m .51039 .7932 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51039 .7932 m .53007 .78861 L .5291 .78287 L p
1 g
F P
s
P
p
.002 w
.46797 .80013 m .48893 .805 L .48927 .7991 L p
1 g
F P
s
P
p
.002 w
.48927 .7991 m .46895 .79437 L .46797 .80013 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .51107 .805 L .51073 .7991 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .48927 .7991 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.53105 .79437 m .51073 .7991 L .51107 .805 L p
1 g
F P
s
P
p
.002 w
.51073 .7991 m .53105 .79437 L .53007 .78861 L p
1 g
F P
s
P
p
.002 w
.62771 .44064 m .61446 .41566 L .54283 .40739 L p
1 g
F P
s
P
p
.002 w
.5289 .38829 m .54283 .40739 L .61446 .41566 L p
1 g
F P
s
P
p
.002 w
.46699 .8059 m .4886 .81091 L .48893 .805 L p
1 g
F P
s
P
p
.002 w
.48893 .805 m .46797 .80013 L .46699 .8059 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .48893 .805 L .4886 .81091 L p
1 g
F P
s
P
p
.002 w
.53203 .80013 m .51107 .805 L .5114 .81091 L p
1 g
F P
s
P
p
.002 w
.51107 .805 m .53203 .80013 L .53105 .79437 L p
1 g
F P
s
P
p
.002 w
.71397 .63517 m .72543 .60297 L .69425 .56596 L p
1 g
F P
s
P
p
.002 w
.69661 .53068 m .69425 .56596 L .72543 .60297 L p
1 g
F P
s
P
p
.002 w
.5114 .81091 m .53301 .8059 L .53203 .80013 L p
1 g
F P
s
P
p
.002 w
.54283 .40739 m .5289 .38829 L .45349 .40093 L p
1 g
F P
s
P
p
.002 w
.69661 .53068 m .69348 .49799 L .63753 .47073 L p
1 g
F P
s
P
p
.002 w
.62771 .44064 m .63753 .47073 L .69348 .49799 L p
1 g
F P
s
P
p
.002 w
.67408 .75284 m .64575 .76351 L .63416 .7832 L p
1 g
F P
s
P
p
.002 w
.64575 .76351 m .67408 .75284 L .67969 .7238 L p
1 g
F P
s
P
p
.002 w
.70461 .701 m .67969 .7238 L .67408 .75284 L p
1 g
F P
s
P
p
.002 w
.67969 .7238 m .70461 .701 L .6964 .667 L p
1 g
F P
s
P
p
.002 w
.71397 .63517 m .6964 .667 L .70461 .701 L p
1 g
F P
s
P
p
.002 w
.33801 .5291 m .32644 .50333 L .28252 .56293 L p
1 g
F P
s
P
p
.002 w
.28252 .56293 m .29372 .58888 L .33801 .5291 L p
1 g
F P
s
P
p
.002 w
.57349 .79984 m .56825 .82195 L .59325 .81402 L p
1 g
F P
s
P
p
.002 w
.59325 .81402 m .58626 .7958 L .57349 .79984 L p
1 g
F P
s
P
p
.002 w
.58626 .7958 m .59325 .81402 L .61602 .80064 L p
1 g
F P
s
P
p
.002 w
.38967 .45386 m .38091 .43308 L .31987 .48094 L p
1 g
F P
s
P
p
.002 w
.31987 .48094 m .32644 .50333 L .38967 .45386 L p
1 g
F P
s
P
p
.002 w
.61602 .80064 m .59789 .78896 L .58626 .7958 L p
1 g
F P
s
P
p
.002 w
.59789 .78896 m .61602 .80064 L .63416 .7832 L p
1 g
F P
s
P
p
.002 w
.37707 .74049 m .34347 .72201 L .34757 .77119 L p
1 g
F P
s
P
p
.002 w
.34757 .77119 m .3804 .78374 L .37707 .74049 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .4869 .84059 L .48724 .83464 L p
1 g
F P
s
P
p
.002 w
.48724 .83464 m .46305 .82905 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .5131 .84059 L .51276 .83464 L p
1 g
F P
s
P
p
.002 w
.51276 .83464 m .48724 .83464 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.53695 .82905 m .51276 .83464 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.33359 .64285 m .31089 .61579 L .29103 .67685 L p
1 g
F P
s
P
p
.002 w
.29103 .67685 m .31452 .70057 L .33359 .64285 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .48655 .84654 L .4869 .84059 L p
1 g
F P
s
P
p
.002 w
.4869 .84059 m .46206 .83486 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .51345 .84654 L .5131 .84059 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .4869 .84059 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .5131 .84059 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.5131 .84059 m .53794 .83486 L .53695 .82905 L p
1 g
F P
s
P
p
.002 w
.63416 .7832 m .60713 .78005 L .59789 .78896 L p
1 g
F P
s
P
p
.002 w
.60713 .78005 m .63416 .7832 L .64575 .76351 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .46206 .83486 L .46305 .82905 L p
1 g
F P
s
P
p
.002 w
.46305 .82905 m .44274 .81844 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.55726 .81844 m .53695 .82905 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .48621 .85251 L .48655 .84654 L p
1 g
F P
s
P
p
.002 w
.48655 .84654 m .46107 .84067 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .51379 .85251 L .51345 .84654 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .48655 .84654 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .51345 .84654 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.51345 .84654 m .53893 .84067 L .53794 .83486 L p
1 g
F P
s
P
p
.002 w
.45349 .40093 m .46481 .42055 L .54283 .40739 L p
1 g
F P
s
P
p
.002 w
.46481 .42055 m .45349 .40093 L .38091 .43308 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .48587 .85848 L .48621 .85251 L p
1 g
F P
s
P
p
.002 w
.48621 .85251 m .46008 .8465 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .48621 .85251 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .51413 .85848 L .51379 .85251 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .51379 .85251 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51379 .85251 m .53992 .8465 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .46107 .84067 L .46206 .83486 L p
1 g
F P
s
P
p
.002 w
.46206 .83486 m .44121 .82398 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .53794 .83486 L .53893 .84067 L p
1 g
F P
s
P
p
.002 w
.53794 .83486 m .55879 .82398 L .55726 .81844 L p
1 g
F P
s
P
p
.002 w
.6964 .667 m .71397 .63517 L .68637 .60282 L p
1 g
F P
s
P
p
.002 w
.69425 .56596 m .68637 .60282 L .71397 .63517 L p
1 g
F P
s
P
p
.002 w
.38091 .43308 m .38967 .45386 L .46481 .42055 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .48553 .86446 L .48587 .85848 L p
1 g
F P
s
P
p
.002 w
.48587 .85848 m .45909 .85233 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .51447 .86446 L .51413 .85848 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .48587 .85848 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .51413 .85848 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51413 .85848 m .54091 .85233 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .46008 .8465 L .46107 .84067 L p
1 g
F P
s
P
p
.002 w
.46107 .84067 m .43967 .82952 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .53893 .84067 L .53992 .8465 L p
1 g
F P
s
P
p
.002 w
.53893 .84067 m .56033 .82952 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.63753 .47073 m .62771 .44064 L .55574 .43251 L p
1 g
F P
s
P
p
.002 w
.54283 .40739 m .55574 .43251 L .62771 .44064 L p
1 g
F P
s
P
p
.002 w
.69425 .56596 m .69661 .53068 L .64355 .50513 L p
1 g
F P
s
P
p
.002 w
.63753 .47073 m .64355 .50513 L .69661 .53068 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .48519 .87045 L .48553 .86446 L p
1 g
F P
s
P
p
.002 w
.48553 .86446 m .45809 .85817 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .51481 .87045 L .51447 .86446 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .48553 .86446 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .51447 .86446 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51447 .86446 m .54191 .85817 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .45909 .85233 L .46008 .8465 L p
1 g
F P
s
P
p
.002 w
.46008 .8465 m .43813 .83508 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .53992 .8465 L .54091 .85233 L p
1 g
F P
s
P
p
.002 w
.53992 .8465 m .56187 .83508 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.67969 .7238 m .64948 .74365 L .64575 .76351 L p
1 g
F P
s
P
p
.002 w
.64948 .74365 m .67969 .7238 L .67316 .6975 L p
1 g
F P
s
P
p
.002 w
.6964 .667 m .67316 .6975 L .67969 .7238 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .44121 .82398 L .44274 .81844 L p
1 g
F P
s
P
p
.002 w
.44274 .81844 m .4285 .8039 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.5715 .8039 m .55726 .81844 L .55879 .82398 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .48484 .87644 L .48519 .87045 L p
1 g
F P
s
P
p
.002 w
.48519 .87045 m .4571 .86401 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .51516 .87644 L .51481 .87045 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .48519 .87045 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .51481 .87045 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51481 .87045 m .5429 .86401 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .45809 .85817 L .45909 .85233 L p
1 g
F P
s
P
p
.002 w
.45909 .85233 m .43659 .84064 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .54091 .85233 L .54191 .85817 L p
1 g
F P
s
P
p
.002 w
.54091 .85233 m .56341 .84064 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.64575 .76351 m .61299 .77002 L .60713 .78005 L p
1 g
F P
s
P
p
.002 w
.61299 .77002 m .64575 .76351 L .64948 .74365 L p
1 g
F P
s
P
p
.002 w
.41434 .75542 m .37707 .74049 L .3804 .78374 L p
1 g
F P
s
P
p
.002 w
.3804 .78374 m .41686 .79155 L .41434 .75542 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .43967 .82952 L .44121 .82398 L p
1 g
F P
s
P
p
.002 w
.44121 .82398 m .42657 .80907 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .55879 .82398 L .56033 .82952 L p
1 g
F P
s
P
p
.002 w
.55879 .82398 m .57343 .80907 L .5715 .8039 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4845 .88245 L .48484 .87644 L p
1 g
F P
s
P
p
.002 w
.48484 .87644 m .4561 .86987 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .5155 .88245 L .51516 .87644 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .48484 .87644 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .51516 .87644 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.51516 .87644 m .5439 .86987 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.55574 .43251 m .54283 .40739 L .46481 .42055 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .4571 .86401 L .45809 .85817 L p
1 g
F P
s
P
p
.002 w
.45809 .85817 m .43505 .84621 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .54191 .85817 L .5429 .86401 L p
1 g
F P
s
P
p
.002 w
.54191 .85817 m .56495 .84621 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.54167 .79255 m .50561 .80781 L .52196 .81872 L p
1 g
F P
s
P
p
.002 w
.52196 .81872 m .54993 .79814 L .54167 .79255 L p
1 g
F P
s
P
p
.002 w
.49638 .79196 m .4559 .79433 L .46962 .81747 L p
1 g
F P
s
P
p
.002 w
.46962 .81747 m .50561 .80781 L .49638 .79196 L p
1 g
F P
s
P
p
.002 w
.35431 .55752 m .33801 .5291 L .29372 .58888 L p
1 g
F P
s
P
p
.002 w
.29372 .58888 m .31089 .61579 L .35431 .55752 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .43813 .83508 L .43967 .82952 L p
1 g
F P
s
P
p
.002 w
.43967 .82952 m .42465 .81424 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .56033 .82952 L .56187 .83508 L p
1 g
F P
s
P
p
.002 w
.56033 .82952 m .57535 .81424 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .48415 .88846 L .4845 .88245 L p
1 g
F P
s
P
p
.002 w
.4845 .88245 m .45511 .87573 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .51585 .88846 L .5155 .88245 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .4845 .88245 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5155 .88245 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.5155 .88245 m .54489 .87573 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .4561 .86987 L .4571 .86401 L p
1 g
F P
s
P
p
.002 w
.4571 .86401 m .4335 .85179 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .5429 .86401 L .5439 .86987 L p
1 g
F P
s
P
p
.002 w
.5429 .86401 m .5665 .85179 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.36121 .66924 m .33359 .64285 L .31452 .70057 L p
1 g
F P
s
P
p
.002 w
.31452 .70057 m .34347 .72201 L .36121 .66924 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .48381 .89448 L .48415 .88846 L p
1 g
F P
s
P
p
.002 w
.48415 .88846 m .45411 .8816 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .51619 .89448 L .51585 .88846 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .48415 .88846 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .51585 .88846 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51585 .88846 m .54589 .8816 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .43659 .84064 L .43813 .83508 L p
1 g
F P
s
P
p
.002 w
.43813 .83508 m .42272 .81942 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .56187 .83508 L .56341 .84064 L p
1 g
F P
s
P
p
.002 w
.56187 .83508 m .57728 .81942 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.40168 .47941 m .38967 .45386 L .32644 .50333 L p
1 g
F P
s
P
p
.002 w
.32644 .50333 m .33801 .5291 L .40168 .47941 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .45511 .87573 L .4561 .86987 L p
1 g
F P
s
P
p
.002 w
.4561 .86987 m .43195 .85738 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .5439 .86987 L .54489 .87573 L p
1 g
F P
s
P
p
.002 w
.5439 .86987 m .56805 .85738 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.67316 .6975 m .6964 .667 L .67316 .64016 L p
1 g
F P
s
P
p
.002 w
.68637 .60282 m .67316 .64016 L .6964 .667 L p
1 g
F P
s
P
p
.002 w
.55187 .72267 m .55989 .73553 L .56192 .73973 L p
1 g
F P
s
P
p
.002 w
.45211 .89337 m .48346 .9005 L .48381 .89448 L p
1 g
F P
s
P
p
.002 w
.48381 .89448 m .45311 .88748 L .45211 .89337 L p
1 g
F P
s
P
p
.002 w
.48346 .9005 m .51654 .9005 L .51619 .89448 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .48381 .89448 L .48346 .9005 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .51619 .89448 L .51654 .9005 L p
1 g
F P
s
P
p
.002 w
.51619 .89448 m .54689 .88748 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.59789 .78896 m .57673 .7721 L .58626 .7958 L closepath p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .43505 .84621 L .43659 .84064 L p
1 g
F P
s
P
p
.002 w
.43659 .84064 m .42079 .82461 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .56341 .84064 L .56495 .84621 L p
1 g
F P
s
P
p
.002 w
.56341 .84064 m .57921 .82461 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .45411 .8816 L .45511 .87573 L p
1 g
F P
s
P
p
.002 w
.45511 .87573 m .4304 .86297 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .54489 .87573 L .54589 .8816 L p
1 g
F P
s
P
p
.002 w
.54489 .87573 m .5696 .86297 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.60713 .78005 m .57673 .7721 L .59789 .78896 L closepath p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42657 .80907 L .4285 .8039 L p
1 g
F P
s
P
p
.002 w
.4285 .8039 m .42189 .78694 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.57811 .78694 m .5715 .8039 L .57343 .80907 L p
1 g
F P
s
P
p
.002 w
.51654 .9005 m .54789 .89337 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .4335 .85179 L .43505 .84621 L p
1 g
F P
s
P
p
.002 w
.43505 .84621 m .41885 .82981 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .56495 .84621 L .5665 .85179 L p
1 g
F P
s
P
p
.002 w
.56495 .84621 m .58115 .82981 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .45311 .88748 L .45411 .8816 L p
1 g
F P
s
P
p
.002 w
.45411 .8816 m .42885 .86858 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .54589 .8816 L .54689 .88748 L p
1 g
F P
s
P
p
.002 w
.54589 .8816 m .57115 .86858 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .56192 .73973 L .56396 .74394 L p
1 g
F P
s
P
p
.002 w
.56192 .73973 m .55363 .72645 L .55187 .72267 L p
1 g
F P
s
P
p
.002 w
.68637 .60282 m .69425 .56596 L .64554 .54284 L p
1 g
F P
s
P
p
.002 w
.64355 .50513 m .64554 .54284 L .69425 .56596 L p
1 g
F P
s
P
p
.002 w
.61299 .77002 m .57673 .7721 L .60713 .78005 L closepath p
1 g
F P
s
P
p
.002 w
.64948 .74365 m .61483 .75993 L .61299 .77002 L p
1 g
F P
s
P
p
.002 w
.61483 .75993 m .64948 .74365 L .6449 .72575 L p
1 g
F P
s
P
p
.002 w
.67316 .6975 m .6449 .72575 L .64948 .74365 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .42465 .81424 L .42657 .80907 L p
1 g
F P
s
P
p
.002 w
.42657 .80907 m .41978 .79167 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57343 .80907 L .57535 .81424 L p
1 g
F P
s
P
p
.002 w
.57343 .80907 m .58022 .79167 L .57811 .78694 L p
1 g
F P
s
P
p
.002 w
.42574 .87981 m .45211 .89337 L .45311 .88748 L p
1 g
F P
s
P
p
.002 w
.45311 .88748 m .42729 .87419 L .42574 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .54689 .88748 L .54789 .89337 L p
1 g
F P
s
P
p
.002 w
.54689 .88748 m .57271 .87419 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .43195 .85738 L .4335 .85179 L p
1 g
F P
s
P
p
.002 w
.4335 .85179 m .41691 .83502 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .5665 .85179 L .56805 .85738 L p
1 g
F P
s
P
p
.002 w
.5665 .85179 m .58309 .83502 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.64355 .50513 m .63753 .47073 L .56722 .46302 L p
1 g
F P
s
P
p
.002 w
.55574 .43251 m .56722 .46302 L .63753 .47073 L p
1 g
F P
s
P
p
.002 w
.56396 .74394 m .5554 .73023 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .42272 .81942 L .42465 .81424 L p
1 g
F P
s
P
p
.002 w
.42465 .81424 m .41767 .79641 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .57535 .81424 L .57728 .81942 L p
1 g
F P
s
P
p
.002 w
.57535 .81424 m .58233 .79641 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.53707 .78448 m .49638 .79196 L .50561 .80781 L p
1 g
F P
s
P
p
.002 w
.50561 .80781 m .54167 .79255 L .53707 .78448 L p
1 g
F P
s
P
p
.002 w
.54789 .89337 m .57426 .87981 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .4304 .86297 L .43195 .85738 L p
1 g
F P
s
P
p
.002 w
.43195 .85738 m .41497 .84024 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .56805 .85738 L .5696 .86297 L p
1 g
F P
s
P
p
.002 w
.56805 .85738 m .58503 .84024 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.46481 .42055 m .47729 .44588 L .55574 .43251 L p
1 g
F P
s
P
p
.002 w
.47729 .44588 m .46481 .42055 L .38967 .45386 L p
1 g
F P
s
P
p
.002 w
.61483 .75993 m .57673 .7721 L .61299 .77002 L closepath p
1 g
F P
s
P
p
.002 w
.53814 .71229 m .55187 .72267 L .55363 .72645 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .42079 .82461 L .42272 .81942 L p
1 g
F P
s
P
p
.002 w
.42272 .81942 m .41555 .80115 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .57728 .81942 L .57921 .82461 L p
1 g
F P
s
P
p
.002 w
.57728 .81942 m .58445 .80115 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.6449 .72575 m .67316 .6975 L .65499 .67686 L p
1 g
F P
s
P
p
.002 w
.67316 .64016 m .65499 .67686 L .67316 .6975 L p
1 g
F P
s
P
p
.002 w
.38967 .45386 m .40168 .47941 L .47729 .44588 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .42885 .86858 L .4304 .86297 L p
1 g
F P
s
P
p
.002 w
.4304 .86297 m .41303 .84546 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .5696 .86297 L .57115 .86858 L p
1 g
F P
s
P
p
.002 w
.5696 .86297 m .58697 .84546 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.39295 .69415 m .36121 .66924 L .34347 .72201 L p
1 g
F P
s
P
p
.002 w
.34347 .72201 m .37707 .74049 L .39295 .69415 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41885 .82981 L .42079 .82461 L p
1 g
F P
s
P
p
.002 w
.42079 .82461 m .41343 .80591 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .57921 .82461 L .58115 .82981 L p
1 g
F P
s
P
p
.002 w
.57921 .82461 m .58657 .80591 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .42729 .87419 L .42885 .86858 L p
1 g
F P
s
P
p
.002 w
.42885 .86858 m .41108 .8507 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .57115 .86858 L .57271 .87419 L p
1 g
F P
s
P
p
.002 w
.57115 .86858 m .58892 .8507 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .55363 .72645 L .5554 .73023 L p
1 g
F P
s
P
p
.002 w
.55363 .72645 m .53944 .71572 L .53814 .71229 L p
1 g
F P
s
P
p
.002 w
.37494 .58776 m .35431 .55752 L .31089 .61579 L p
1 g
F P
s
P
p
.002 w
.31089 .61579 m .33359 .64285 L .37494 .58776 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .41978 .79167 L .42189 .78694 L p
1 g
F P
s
P
p
.002 w
.42189 .78694 m .42372 .76938 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.61243 .75088 m .57673 .7721 L .61483 .75993 L closepath p
1 g
F P
s
P
p
.002 w
.60602 .74385 m .57673 .7721 L .61243 .75088 L closepath p
1 g
F P
s
P
p
.002 w
.59629 .73962 m .57673 .7721 L .60602 .74385 L closepath p
1 g
F P
s
P
p
.002 w
.58427 .73866 m .57673 .7721 L .59629 .73962 L closepath p
1 g
F P
s
P
p
.002 w
.57628 .76938 m .57811 .78694 L .58022 .79167 L p
1 g
F P
s
P
p
.002 w
.49536 .77284 m .45418 .76632 L .4559 .79433 L p
1 g
F P
s
P
p
.002 w
.4559 .79433 m .49638 .79196 L .49536 .77284 L p
1 g
F P
s
P
p
.002 w
.56722 .46302 m .55574 .43251 L .47729 .44588 L p
1 g
F P
s
P
p
.002 w
.6449 .72575 m .61243 .75088 L .61483 .75993 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41691 .83502 L .41885 .82981 L p
1 g
F P
s
P
p
.002 w
.41885 .82981 m .41131 .81067 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58115 .82981 L .58309 .83502 L p
1 g
F P
s
P
p
.002 w
.58115 .82981 m .58869 .81067 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.40717 .86119 m .42574 .87981 L .42729 .87419 L p
1 g
F P
s
P
p
.002 w
.42729 .87419 m .40913 .85594 L .40717 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .57271 .87419 L .57426 .87981 L p
1 g
F P
s
P
p
.002 w
.57271 .87419 m .59087 .85594 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.67316 .64016 m .68637 .60282 L .64339 .58274 L p
1 g
F P
s
P
p
.002 w
.64554 .54284 m .64339 .58274 L .68637 .60282 L p
1 g
F P
s
P
p
.002 w
.54075 .71916 m .5554 .73023 L .55718 .73402 L p
1 g
F P
s
P
p
.002 w
.5554 .73023 m .54075 .71916 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.52019 .70555 m .53814 .71229 L .53944 .71572 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .41767 .79641 L .41978 .79167 L p
1 g
F P
s
P
p
.002 w
.41978 .79167 m .42166 .77365 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .58022 .79167 L .58233 .79641 L p
1 g
F P
s
P
p
.002 w
.58022 .79167 m .57834 .77365 L .57628 .76938 L p
1 g
F P
s
P
p
.002 w
.61243 .75088 m .6449 .72575 L .63238 .71177 L p
1 g
F P
s
P
p
.002 w
.65499 .67686 m .63238 .71177 L .6449 .72575 L p
1 g
F P
s
P
p
.002 w
.57426 .87981 m .59283 .86119 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .41497 .84024 L .41691 .83502 L p
1 g
F P
s
P
p
.002 w
.41691 .83502 m .40918 .81544 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58309 .83502 L .58503 .84024 L p
1 g
F P
s
P
p
.002 w
.58309 .83502 m .59082 .81544 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.41663 .50903 m .40168 .47941 L .33801 .5291 L p
1 g
F P
s
P
p
.002 w
.33801 .5291 m .35431 .55752 L .41663 .50903 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .41555 .80115 L .41767 .79641 L p
1 g
F P
s
P
p
.002 w
.41767 .79641 m .41959 .77793 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .58233 .79641 L .58445 .80115 L p
1 g
F P
s
P
p
.002 w
.58233 .79641 m .58041 .77793 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.53663 .77478 m .49536 .77284 L .49638 .79196 L p
1 g
F P
s
P
p
.002 w
.49638 .79196 m .53707 .78448 L .53663 .77478 L p
1 g
F P
s
P
p
.002 w
.53944 .71572 m .52088 .70875 L .52019 .70555 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .41303 .84546 L .41497 .84024 L p
1 g
F P
s
P
p
.002 w
.41497 .84024 m .40705 .82022 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .58503 .84024 L .58697 .84546 L p
1 g
F P
s
P
p
.002 w
.58503 .84024 m .59295 .82022 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.64554 .54284 m .64355 .50513 L .57689 .49807 L p
1 g
F P
s
P
p
.002 w
.56722 .46302 m .57689 .49807 L .64355 .50513 L p
1 g
F P
s
P
p
.002 w
.63238 .71177 m .60602 .74385 L .61243 .75088 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .47912 .70875 L .47981 .70555 L p
1 g
F P
s
P
p
.002 w
.47981 .70555 m .5 .70321 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.5 .70321 m .52019 .70555 L .52088 .70875 L p
1 g
F P
s
P
p
.002 w
.42785 .71679 m .39295 .69415 L .37707 .74049 L p
1 g
F P
s
P
p
.002 w
.37707 .74049 m .41434 .75542 L .42785 .71679 L p
1 g
F P
s
P
p
.002 w
.52088 .70875 m .5 .70634 L .5 .70321 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .41343 .80591 L .41555 .80115 L p
1 g
F P
s
P
p
.002 w
.41555 .80115 m .41751 .78222 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .58445 .80115 L .58657 .80591 L p
1 g
F P
s
P
p
.002 w
.58445 .80115 m .58249 .78222 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .41108 .8507 L .41303 .84546 L p
1 g
F P
s
P
p
.002 w
.41303 .84546 m .40491 .82501 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .58697 .84546 L .58892 .8507 L p
1 g
F P
s
P
p
.002 w
.58697 .84546 m .59509 .82501 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.65499 .67686 m .67316 .64016 L .63715 .62363 L p
1 g
F P
s
P
p
.002 w
.64339 .58274 m .63715 .62363 L .67316 .64016 L p
1 g
F P
s
P
p
.002 w
.5 .70634 m .52088 .70875 L .52157 .71196 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40913 .85594 L .41108 .8507 L p
1 g
F P
s
P
p
.002 w
.41108 .8507 m .40277 .82981 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .58892 .8507 L .59087 .85594 L p
1 g
F P
s
P
p
.002 w
.58892 .8507 m .59723 .82981 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .41131 .81067 L .41343 .80591 L p
1 g
F P
s
P
p
.002 w
.41343 .80591 m .41543 .78651 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .58657 .80591 L .58869 .81067 L p
1 g
F P
s
P
p
.002 w
.58657 .80591 m .58457 .78651 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .42166 .77365 L .42372 .76938 L p
1 g
F P
s
P
p
.002 w
.42372 .76938 m .43389 .75311 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.56611 .75311 m .57628 .76938 L .57834 .77365 L p
1 g
F P
s
P
p
.002 w
.52157 .71196 m .5 .70947 L .5 .70634 L p
1 g
F P
s
P
p
.002 w
.60602 .74385 m .63238 .71177 L .61322 .7033 L p
1 g
F P
s
P
p
.002 w
.61322 .7033 m .59629 .73962 L .60602 .74385 L p
1 g
F P
s
P
p
.002 w
.39929 .6189 m .37494 .58776 L .33359 .64285 L p
1 g
F P
s
P
p
.002 w
.33359 .64285 m .36121 .66924 L .39929 .6189 L p
1 g
F P
s
P
p
.002 w
.39848 .83944 m .40717 .86119 L .40913 .85594 L p
1 g
F P
s
P
p
.002 w
.40913 .85594 m .40063 .83462 L .39848 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59087 .85594 L .59283 .86119 L p
1 g
F P
s
P
p
.002 w
.59087 .85594 m .59937 .83462 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.63238 .71177 m .65499 .67686 L .62699 .66423 L p
1 g
F P
s
P
p
.002 w
.63715 .62363 m .62699 .66423 L .65499 .67686 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .40918 .81544 L .41131 .81067 L p
1 g
F P
s
P
p
.002 w
.41131 .81067 m .41335 .79082 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .58869 .81067 L .59082 .81544 L p
1 g
F P
s
P
p
.002 w
.58869 .81067 m .58665 .79082 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.47729 .44588 m .49056 .47623 L .56722 .46302 L p
1 g
F P
s
P
p
.002 w
.49056 .47623 m .47729 .44588 L .40168 .47941 L p
1 g
F P
s
P
p
.002 w
.49536 .77284 m .53663 .77478 L .54044 .76451 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .41959 .77793 L .42166 .77365 L p
1 g
F P
s
P
p
.002 w
.42166 .77365 m .43209 .75696 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .57834 .77365 L .58041 .77793 L p
1 g
F P
s
P
p
.002 w
.57834 .77365 m .56791 .75696 L .56611 .75311 L p
1 g
F P
s
P
p
.002 w
.62699 .66423 m .61322 .7033 L .63238 .71177 L p
1 g
F P
s
P
p
.002 w
.40168 .47941 m .41663 .50903 L .49056 .47623 L p
1 g
F P
s
P
p
.002 w
.59283 .86119 m .60152 .83944 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.57689 .49807 m .56722 .46302 L .49056 .47623 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .40705 .82022 L .40918 .81544 L p
1 g
F P
s
P
p
.002 w
.40918 .81544 m .41126 .79513 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .59082 .81544 L .59295 .82022 L p
1 g
F P
s
P
p
.002 w
.59082 .81544 m .58874 .79513 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.50276 .75251 m .46484 .73644 L .45418 .76632 L p
1 g
F P
s
P
p
.002 w
.45418 .76632 m .49536 .77284 L .50276 .75251 L p
1 g
F P
s
P
p
.002 w
.54044 .76451 m .50276 .75251 L .49536 .77284 L p
1 g
F P
s
P
p
.002 w
.64339 .58274 m .64554 .54284 L .58444 .53663 L p
1 g
F P
s
P
p
.002 w
.57689 .49807 m .58444 .53663 L .64554 .54284 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .41751 .78222 L .41959 .77793 L p
1 g
F P
s
P
p
.002 w
.41959 .77793 m .43029 .76081 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .58041 .77793 L .58249 .78222 L p
1 g
F P
s
P
p
.002 w
.58041 .77793 m .56971 .76081 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.59629 .73962 m .61322 .7033 L .58948 .70132 L p
1 g
F P
s
P
p
.002 w
.58948 .70132 m .58427 .73866 L .59629 .73962 L p
1 g
F P
s
P
p
.002 w
.50276 .75251 m .54044 .76451 L .5481 .75479 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .40491 .82501 L .40705 .82022 L p
1 g
F P
s
P
p
.002 w
.40705 .82022 m .40916 .79946 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .59295 .82022 L .59509 .82501 L p
1 g
F P
s
P
p
.002 w
.59295 .82022 m .59084 .79946 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.43411 .54187 m .41663 .50903 L .35431 .55752 L p
1 g
F P
s
P
p
.002 w
.35431 .55752 m .37494 .58776 L .43411 .54187 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .41543 .78651 L .41751 .78222 L p
1 g
F P
s
P
p
.002 w
.41751 .78222 m .42848 .76467 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .58249 .78222 L .58457 .78651 L p
1 g
F P
s
P
p
.002 w
.58249 .78222 m .57152 .76467 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.58427 .73866 m .58948 .70132 L .56376 .7061 L p
1 g
F P
s
P
p
.002 w
.56376 .7061 m .57129 .74111 L .58427 .73866 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .40277 .82981 L .40491 .82501 L p
1 g
F P
s
P
p
.002 w
.40491 .82501 m .40707 .80379 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .59509 .82501 L .59723 .82981 L p
1 g
F P
s
P
p
.002 w
.59509 .82501 m .59293 .80379 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .43209 .75696 L .43389 .75311 L p
1 g
F P
s
P
p
.002 w
.43389 .75311 m .45136 .73996 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.54864 .73996 m .56611 .75311 L .56791 .75696 L p
1 g
F P
s
P
p
.002 w
.5481 .75479 m .51784 .73323 L .50276 .75251 L p
1 g
F P
s
P
p
.002 w
.42664 .64997 m .39929 .6189 L .36121 .66924 L p
1 g
F P
s
P
p
.002 w
.36121 .66924 m .39295 .69415 L .42664 .64997 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .41335 .79082 L .41543 .78651 L p
1 g
F P
s
P
p
.002 w
.41543 .78651 m .42667 .76854 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .58457 .78651 L .58665 .79082 L p
1 g
F P
s
P
p
.002 w
.58457 .78651 m .57333 .76854 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.57129 .74111 m .56376 .7061 L .53895 .71715 L p
1 g
F P
s
P
p
.002 w
.53895 .71715 m .55877 .74669 L .57129 .74111 L p
1 g
F P
s
P
p
.002 w
.63715 .62363 m .64339 .58274 L .58959 .57752 L p
1 g
F P
s
P
p
.002 w
.58444 .53663 m .58959 .57752 L .64339 .58274 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .40063 .83462 L .40277 .82981 L p
1 g
F P
s
P
p
.002 w
.40277 .82981 m .40496 .80813 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .59723 .82981 L .59937 .83462 L p
1 g
F P
s
P
p
.002 w
.59723 .82981 m .59504 .80813 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.61322 .7033 m .62699 .66423 L .59215 .66117 L p
1 g
F P
s
P
p
.002 w
.59215 .66117 m .58948 .70132 L .61322 .7033 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .43029 .76081 L .43209 .75696 L p
1 g
F P
s
P
p
.002 w
.43209 .75696 m .45003 .74346 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .56791 .75696 L .56971 .76081 L p
1 g
F P
s
P
p
.002 w
.56791 .75696 m .54997 .74346 L .54864 .73996 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .41126 .79513 L .41335 .79082 L p
1 g
F P
s
P
p
.002 w
.41335 .79082 m .42486 .77242 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .58665 .79082 L .58874 .79513 L p
1 g
F P
s
P
p
.002 w
.58665 .79082 m .57514 .77242 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.46484 .73644 m .50276 .75251 L .51784 .73323 L p
1 g
F P
s
P
p
.002 w
.40075 .81685 m .39848 .83944 L .40063 .83462 L p
1 g
F P
s
P
p
.002 w
.40063 .83462 m .40286 .81248 L .40075 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .59937 .83462 L .60152 .83944 L p
1 g
F P
s
P
p
.002 w
.59937 .83462 m .59714 .81248 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.62699 .66423 m .63715 .62363 L .59219 .61947 L p
1 g
F P
s
P
p
.002 w
.58959 .57752 m .59219 .61947 L .63715 .62363 L p
1 g
F P
s
P
p
.002 w
.59219 .61947 m .59215 .66117 L .62699 .66423 L p
1 g
F P
s
P
p
.002 w
.58444 .53663 m .57689 .49807 L .50422 .51074 L p
1 g
F P
s
P
p
.002 w
.49056 .47623 m .50422 .51074 L .57689 .49807 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .42848 .76467 L .43029 .76081 L p
1 g
F P
s
P
p
.002 w
.43029 .76081 m .4487 .74696 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .56971 .76081 L .57152 .76467 L p
1 g
F P
s
P
p
.002 w
.56971 .76081 m .5513 .74696 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.50422 .51074 m .49056 .47623 L .41663 .50903 L p
1 g
F P
s
P
p
.002 w
.45614 .68001 m .42664 .64997 L .39295 .69415 L p
1 g
F P
s
P
p
.002 w
.39295 .69415 m .42785 .71679 L .45614 .68001 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .40916 .79946 L .41126 .79513 L p
1 g
F P
s
P
p
.002 w
.41126 .79513 m .42304 .77631 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .58874 .79513 L .59084 .79946 L p
1 g
F P
s
P
p
.002 w
.58874 .79513 m .57696 .77631 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.60152 .83944 m .59925 .81685 L .59714 .81248 L p
1 g
F P
s
P
p
.004 w
.59955 .81978 m
.60536 .83192 L
s
P
p
.002 w
.41663 .50903 m .43411 .54187 L .50422 .51074 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .45003 .74346 L .45136 .73996 L p
1 g
F P
s
P
p
.002 w
.45136 .73996 m .47424 .73141 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.52576 .73141 m .54864 .73996 L .54997 .74346 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .42667 .76854 L .42848 .76467 L p
1 g
F P
s
P
p
.002 w
.42848 .76467 m .44736 .75048 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .57152 .76467 L .57333 .76854 L p
1 g
F P
s
P
p
.002 w
.57152 .76467 m .55264 .75048 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.48686 .70805 m .45614 .68001 L .42785 .71679 L p
1 g
F P
s
P
p
.002 w
.4536 .57693 m .43411 .54187 L .37494 .58776 L p
1 g
F P
s
P
p
.002 w
.37494 .58776 m .39929 .6189 L .4536 .57693 L p
1 g
F P
s
P
p
.002 w
.58948 .70132 m .59215 .66117 L .55434 .66813 L p
1 g
F P
s
P
p
.002 w
.55434 .66813 m .56376 .7061 L .58948 .70132 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .40707 .80379 L .40916 .79946 L p
1 g
F P
s
P
p
.002 w
.40916 .79946 m .42122 .78021 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .59084 .79946 L .59293 .80379 L p
1 g
F P
s
P
p
.002 w
.59084 .79946 m .57878 .78021 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .4487 .74696 L .45003 .74346 L p
1 g
F P
s
P
p
.002 w
.45003 .74346 m .47353 .73468 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .54997 .74346 L .5513 .74696 L p
1 g
F P
s
P
p
.002 w
.54997 .74346 m .52647 .73468 L .52576 .73141 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .42486 .77242 L .42667 .76854 L p
1 g
F P
s
P
p
.002 w
.42667 .76854 m .44603 .754 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .57333 .76854 L .57514 .77242 L p
1 g
F P
s
P
p
.002 w
.57333 .76854 m .55397 .754 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .40496 .80813 L .40707 .80379 L p
1 g
F P
s
P
p
.002 w
.40707 .80379 m .41939 .78411 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .59293 .80379 L .59504 .80813 L p
1 g
F P
s
P
p
.002 w
.59293 .80379 m .58061 .78411 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .47353 .73468 L .47424 .73141 L p
1 g
F P
s
P
p
.002 w
.47424 .73141 m .5 .72845 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.5 .72845 m .52576 .73141 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.56376 .7061 m .55434 .66813 L .51786 .68437 L p
1 g
F P
s
P
p
.002 w
.51786 .68437 m .53895 .71715 L .56376 .7061 L p
1 g
F P
s
P
p
.002 w
.58959 .57752 m .58444 .53663 L .51785 .54839 L p
1 g
F P
s
P
p
.002 w
.50422 .51074 m .51785 .54839 L .58444 .53663 L p
1 g
F P
s
P
p
.002 w
.53895 .71715 m .51786 .68437 L .48686 .70805 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .44736 .75048 L .4487 .74696 L p
1 g
F P
s
P
p
.002 w
.4487 .74696 m .47283 .73796 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5513 .74696 L .55264 .75048 L p
1 g
F P
s
P
p
.002 w
.5513 .74696 m .52717 .73796 L .52647 .73468 L p
1 g
F P
s
P
p
.002 w
.52647 .73468 m .5 .73164 L .5 .72845 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .42304 .77631 L .42486 .77242 L p
1 g
F P
s
P
p
.002 w
.42486 .77242 m .44469 .75753 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .57514 .77242 L .57696 .77631 L p
1 g
F P
s
P
p
.002 w
.57514 .77242 m .55531 .75753 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .40286 .81248 L .40496 .80813 L p
1 g
F P
s
P
p
.002 w
.40496 .80813 m .41756 .78803 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .59504 .80813 L .59714 .81248 L p
1 g
F P
s
P
p
.002 w
.59504 .80813 m .58244 .78803 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .47283 .73796 L .47353 .73468 L p
1 g
F P
s
P
p
.002 w
.47353 .73468 m .5 .73164 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.5 .73164 m .52647 .73468 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.59215 .66117 m .59219 .61947 L .54332 .62834 L p
1 g
F P
s
P
p
.002 w
.54332 .62834 m .55434 .66813 L .59215 .66117 L p
1 g
F P
s
P
p
.002 w
.51785 .54839 m .50422 .51074 L .43411 .54187 L p
1 g
F P
s
P
p
.002 w
.4745 .61313 m .4536 .57693 L .39929 .6189 L p
1 g
F P
s
P
p
.002 w
.39929 .6189 m .42664 .64997 L .4745 .61313 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .44603 .754 L .44736 .75048 L p
1 g
F P
s
P
p
.002 w
.44736 .75048 m .47212 .74125 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .55264 .75048 L .55397 .754 L p
1 g
F P
s
P
p
.002 w
.55264 .75048 m .52788 .74125 L .52717 .73796 L p
1 g
F P
s
P
p
.002 w
.52717 .73796 m .5 .73484 L .5 .73164 L p
1 g
F P
s
P
p
.002 w
.45614 .68001 m .48686 .70805 L .51786 .68437 L p
1 g
F P
s
P
p
.002 w
.41388 .79588 m .40075 .81685 L .40286 .81248 L p
1 g
F P
s
P
p
.002 w
.40286 .81248 m .41572 .79195 L .41388 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .59714 .81248 L .59925 .81685 L p
1 g
F P
s
P
p
.002 w
.59714 .81248 m .58428 .79195 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .42122 .78021 L .42304 .77631 L p
1 g
F P
s
P
p
.002 w
.42304 .77631 m .44334 .76107 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .57696 .77631 L .57878 .78021 L p
1 g
F P
s
P
p
.002 w
.57696 .77631 m .55666 .76107 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.43411 .54187 m .4536 .57693 L .51785 .54839 L p
1 g
F P
s
P
p
.002 w
.59219 .61947 m .58959 .57752 L .53102 .588 L p
1 g
F P
s
P
p
.002 w
.51785 .54839 m .53102 .588 L .58959 .57752 L p
1 g
F P
s
P
p
.002 w
.53102 .588 m .54332 .62834 L .59219 .61947 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .47212 .74125 L .47283 .73796 L p
1 g
F P
s
P
p
.002 w
.47283 .73796 m .5 .73484 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.5 .73484 m .52717 .73796 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .44469 .75753 L .44603 .754 L p
1 g
F P
s
P
p
.002 w
.44603 .754 m .47141 .74454 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .55397 .754 L .55531 .75753 L p
1 g
F P
s
P
p
.002 w
.55397 .754 m .52859 .74454 L .52788 .74125 L p
1 g
F P
s
P
p
.002 w
.59925 .81685 m .58612 .79588 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.49615 .64933 m .4745 .61313 L .42664 .64997 L p
1 g
F P
s
P
p
.002 w
.42664 .64997 m .45614 .68001 L .49615 .64933 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .41939 .78411 L .42122 .78021 L p
1 g
F P
s
P
p
.002 w
.42122 .78021 m .442 .76462 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .57878 .78021 L .58061 .78411 L p
1 g
F P
s
P
p
.002 w
.57878 .78021 m .558 .76462 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.52788 .74125 m .5 .73805 L .5 .73484 L p
1 g
F P
s
P
p
.002 w
.51786 .68437 m .49615 .64933 L .45614 .68001 L p
1 g
F P
s
P
p
.002 w
.55434 .66813 m .54332 .62834 L .49615 .64933 L p
1 g
F P
s
P
p
.002 w
.49615 .64933 m .51786 .68437 L .55434 .66813 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .47141 .74454 L .47212 .74125 L p
1 g
F P
s
P
p
.002 w
.47212 .74125 m .5 .73805 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .73805 m .52788 .74125 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .44334 .76107 L .44469 .75753 L p
1 g
F P
s
P
p
.002 w
.44469 .75753 m .4707 .74784 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .55531 .75753 L .55666 .76107 L p
1 g
F P
s
P
p
.002 w
.55531 .75753 m .5293 .74784 L .52859 .74454 L p
1 g
F P
s
P
p
.002 w
.53102 .588 m .51785 .54839 L .4536 .57693 L p
1 g
F P
s
P
p
.004 w
.47102 .55687 m
.48091 .57563 L
s
P
p
.004 w
.48127 .57631 m
.48142 .57658 L
s
P
p
.004 w
.48389 .58126 m
.5 .6118 L
s
P
p
.004 w
.48091 .57563 m
.48127 .57631 L
s
P
p
.002 w
.43929 .77174 m .41756 .78803 L .41939 .78411 L p
1 g
F P
s
P
p
.002 w
.41939 .78411 m .44065 .76817 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .58061 .78411 L .58244 .78803 L p
1 g
F P
s
P
p
.002 w
.58061 .78411 m .55935 .76817 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.52859 .74454 m .5 .74126 L .5 .73805 L p
1 g
F P
s
P
p
.002 w
.4536 .57693 m .4745 .61313 L .53102 .588 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .4707 .74784 L .47141 .74454 L p
1 g
F P
s
P
p
.002 w
.47141 .74454 m .5 .74126 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .74126 m .52859 .74454 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.54332 .62834 m .53102 .588 L .4745 .61313 L p
1 g
F P
s
P
p
.002 w
.4745 .61313 m .49615 .64933 L .54332 .62834 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .442 .76462 L .44334 .76107 L p
1 g
F P
s
P
p
.002 w
.44334 .76107 m .46998 .75116 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .55666 .76107 L .558 .76462 L p
1 g
F P
s
P
p
.002 w
.55666 .76107 m .53002 .75116 L .5293 .74784 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .41572 .79195 L .41756 .78803 L p
1 g
F P
s
P
p
.002 w
.41756 .78803 m .43929 .77174 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .58244 .78803 L .58428 .79195 L p
1 g
F P
s
P
p
.002 w
.58244 .78803 m .56071 .77174 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.5293 .74784 m .5 .74449 L .5 .74126 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .46998 .75116 L .4707 .74784 L p
1 g
F P
s
P
p
.002 w
.4707 .74784 m .5 .74449 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .74449 m .5293 .74784 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.43658 .7789 m .41388 .79588 L .41572 .79195 L p
1 g
F P
s
P
p
.002 w
.41572 .79195 m .43794 .77531 L .43658 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .58428 .79195 L .58612 .79588 L p
1 g
F P
s
P
p
.002 w
.58428 .79195 m .56206 .77531 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .44065 .76817 L .442 .76462 L p
1 g
F P
s
P
p
.002 w
.442 .76462 m .46927 .75448 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .558 .76462 L .55935 .76817 L p
1 g
F P
s
P
p
.002 w
.558 .76462 m .53073 .75448 L .53002 .75116 L p
1 g
F P
s
P
p
.002 w
.53002 .75116 m .5 .74772 L .5 .74449 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .46927 .75448 L .46998 .75116 L p
1 g
F P
s
P
p
.002 w
.46998 .75116 m .5 .74772 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .74772 m .53002 .75116 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.58612 .79588 m .56342 .7789 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .43929 .77174 L .44065 .76817 L p
1 g
F P
s
P
p
.002 w
.44065 .76817 m .46855 .7578 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .55935 .76817 L .56071 .77174 L p
1 g
F P
s
P
p
.002 w
.55935 .76817 m .53145 .7578 L .53073 .75448 L p
1 g
F P
s
P
p
.002 w
.53073 .75448 m .5 .75096 L .5 .74772 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .46855 .7578 L .46927 .75448 L p
1 g
F P
s
P
p
.002 w
.46927 .75448 m .5 .75096 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .75096 m .53073 .75448 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .43794 .77531 L .43929 .77174 L p
1 g
F P
s
P
p
.002 w
.43929 .77174 m .46783 .76114 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .56071 .77174 L .56206 .77531 L p
1 g
F P
s
P
p
.002 w
.56071 .77174 m .53217 .76114 L .53145 .7578 L p
1 g
F P
s
P
p
.002 w
.53145 .7578 m .5 .75421 L .5 .75096 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .46783 .76114 L .46855 .7578 L p
1 g
F P
s
P
p
.002 w
.46855 .7578 m .5 .75421 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .75421 m .53145 .7578 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.46639 .76784 m .43658 .7789 L .43794 .77531 L p
1 g
F P
s
P
p
.002 w
.43794 .77531 m .46711 .76449 L .46639 .76784 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .56206 .77531 L .56342 .7789 L p
1 g
F P
s
P
p
.002 w
.56206 .77531 m .53289 .76449 L .53217 .76114 L p
1 g
F P
s
P
p
.002 w
.53217 .76114 m .5 .75746 L .5 .75421 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .46711 .76449 L .46783 .76114 L p
1 g
F P
s
P
p
.002 w
.46783 .76114 m .5 .75746 L .5 .76073 L p
1 g
F P
s
P
p
.002 w
.5 .75746 m .53217 .76114 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.56342 .7789 m .53361 .76784 L .53289 .76449 L p
1 g
F P
s
P
p
.002 w
.53289 .76449 m .5 .76073 L .5 .75746 L p
1 g
F P
s
P
p
.002 w
.5 .764 m .46639 .76784 L .46711 .76449 L p
1 g
F P
s
P
p
.002 w
.46711 .76449 m .5 .76073 L .5 .764 L p
1 g
F P
s
P
p
.002 w
.5 .76073 m .53289 .76449 L .53361 .76784 L p
1 g
F P
s
P
p
.002 w
.53361 .76784 m .5 .764 L .5 .76073 L p
1 g
F P
s
P
p
P
p
p
/Courier-Bold findfont 14 scalefont setfont
[(n)] .47102 .55687 0 0 Mshowa
P
p
/Courier-Bold findfont 14 scalefont setfont
[(k)] .61733 .85693 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{234, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[TextData[{
  StyleBox[
  "\tWhat you see with this animation is essentially a 'strobe' effect.  Each \
plot represents one time that the emission vector, ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  ", is pointed in our direction.  One must be careful to remember that we're \
displaying snapshots here, and that this is not a continuous animation of the \
the motion of ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " as we've had before.  \n\tThe number at the top of the plot represents \
the time index of each plot.  It is especially helpful to look at because ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " plays the animation sequence over and over again, and it is nice to know \
when you start watching a repeat performance!\n\tAs you watch this animation \
play out, you'll see that the beam ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" \"bobs\" up and down and the symmetry axis,  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", seems to run circles around its cone while ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " stays still.  The reason for this is fairly simple. The precession of the \
star moves ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" around in its \"orbit\" faster than it does ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[".  However, the distance between ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " must remain constant since they are both stationary points on the same \
star, so as ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" \"pulls ahead\" of ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" in its orbit,  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " must move up relative to our point of view in order to keep at a constant \
angle to and constant distance from ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[".  As ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" catches up and begins to \"lap\" ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[", the vector ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " has to move down relative to our line of sight in order to keep that \
constant distance.  Thus, we see the vector ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" move up and down as ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" moves along its cone.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "\tThis animation also illustrates the changing behavior of linear \
polarization through the precession cycle.  Let ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " be the magnetic pole of the pulsar, and let the line connecting ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["k",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " be a magnetic field line along which linearly polarized emission is \
oriented.  As ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " animates this series of plots, one should see the position angle of this \
line swinging back and forth.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Acknowledgements"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tJ.E.E. and J.M.W. were supported by NSF grant AST 92-22435."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 509},
WindowMargins->{{12, Automatic}, {Automatic, 16}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060001T1T00000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1711, 51, 970, 34, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2704, 87, 112, 2, 70, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2839, 91, 89, 2, 70, "Section",
  Evaluatable->False],
Cell[2931, 95, 378, 7, 70, "Text",
  Evaluatable->False],
Cell[3312, 104, 794, 12, 70, "Text",
  Evaluatable->False],
Cell[4109, 118, 221, 5, 70, "Text",
  Evaluatable->False],
Cell[4333, 125, 116, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4481, 129, 121, 2, 70, "Section",
  Evaluatable->False],
Cell[4605, 133, 7806, 276, 70, "Text",
  Evaluatable->False],
Cell[12414, 411, 933, 13, 70, "Input"],
Cell[13350, 426, 288, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13670, 433, 98, 2, 70, "Section",
  Evaluatable->False],
Cell[13771, 437, 418, 7, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14212, 446, 97, 2, 70, "Subsubsection",
  Evaluatable->False],
Cell[14312, 450, 151, 4, 70, "Text",
  Evaluatable->False],
Cell[14466, 456, 437, 7, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14935, 465, 102, 2, 70, "Subsubsection",
  Evaluatable->False],
Cell[15040, 469, 1204, 39, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[16267, 510, 245, 4, 70, "Input"],
Cell[16515, 516, 57664, 5762, 70, 57506, 5757, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[74220, 6280, 93, 2, 70, "Subsubsection",
  Evaluatable->False],
Cell[74316, 6284, 587, 9, 70, "Text",
  Evaluatable->False],
Cell[74906, 6295, 1257, 17, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[76204, 6314, 102, 2, 70, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[76329, 6318, 95, 2, 70, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[76447, 6322, 153, 4, 70, "Subsubsection",
  Evaluatable->False],
Cell[76603, 6328, 314, 6, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[76940, 6336, 117, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[77080, 6340, 115070, 11252, 70, 114885, 11246, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[192153, 17594, 116425, 11368, 70, 116240, 11362, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[308581, 28964, 117743, 11488, 70, 117558, 11482, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[426327, 40454, 117617, 11472, 70, 117432, 11466, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[543947, 51928, 117179, 11447, 70, 116994, 11441, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[661129, 63377, 117537, 11457, 70, 117352, 11451, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[778669, 74836, 116982, 11409, 70, 116797, 11403, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[895654, 86247, 116817, 11373, 70, 116632, 11367, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1012474, 97622, 116868, 11406, 70, 116683, 11400, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1129345, 109030, 116132, 11371, 70, 115947, 11365, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1245480, 120403, 116585, 11358, 70, 116400, 11352, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1362068, 131763, 115856, 11316, 70, 115671, 11310, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1477927, 143081, 116003, 11323, 70, 115818, 11317, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1593933, 154406, 116575, 11387, 70, 116390, 11381, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1710511, 165795, 117569, 11471, 70, 117384, 11465, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1828083, 177268, 115959, 11329, 70, 115774, 11323, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1944045, 188599, 116507, 11394, 70, 116322, 11388, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2060555, 199995, 115781, 11285, 70, 115596, 11279, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2176339, 211282, 116438, 11363, 70, 116253, 11357, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2292780, 222647, 117321, 11446, 70, 117136, 11440, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Closed]]
}, Open  ]],
Cell[2410122, 234095, 2126, 63, 70, "Text",
  Evaluatable->False],
Cell[2412251, 234160, 2714, 86, 70, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2415006, 234248, 101, 2, 70, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2415130, 234252, 153, 4, 70, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2415306, 234258, 117, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[2415446, 234262, 115070, 11252, 70, 114885, 11246, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2530519, 245516, 118111, 11498, 70, 117926, 11492, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2648633, 257016, 117181, 11448, 70, 116996, 11442, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2765817, 268466, 116824, 11407, 70, 116639, 11401, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2882644, 279875, 116221, 11333, 70, 116036, 11327, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2998868, 291210, 117061, 11416, 70, 116876, 11410, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3115932, 302628, 117736, 11474, 70, 117551, 11468, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3233671, 314104, 117852, 11485, 70, 117667, 11479, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3351526, 325591, 115470, 11297, 70, 115285, 11291, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3466999, 336890, 116520, 11383, 70, 116335, 11377, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3583522, 348275, 116748, 11371, 70, 116563, 11365, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3700273, 359648, 116534, 11378, 70, 116349, 11372, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3816810, 371028, 116044, 11326, 70, 115859, 11320, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3932857, 382356, 117314, 11435, 70, 117129, 11429, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4050174, 393793, 118803, 11568, 70, 118618, 11562, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4168980, 405363, 118573, 11551, 70, 118388, 11545, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4287556, 416916, 117561, 11455, 70, 117376, 11449, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4405120, 428373, 117534, 11458, 70, 117349, 11452, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4522657, 439833, 117233, 11445, 70, 117048, 11439, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4639893, 451280, 115316, 11274, 70, 115131, 11268, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4755212, 462556, 116489, 11380, 70, 116304, 11374, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4871704, 473938, 116433, 11368, 70, 116248, 11362, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4988140, 485308, 116053, 11310, 70, 115868, 11304, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5104196, 496620, 115911, 11308, 70, 115726, 11302, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5220110, 507930, 116228, 11346, 70, 116043, 11340, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5336341, 519278, 116878, 11399, 70, 116693, 11393, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5453222, 530679, 116612, 11396, 70, 116427, 11390, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5569837, 542077, 118102, 11497, 70, 117917, 11491, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5687942, 553576, 116805, 11390, 70, 116620, 11384, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5804750, 564968, 116781, 11387, 70, 116596, 11381, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5921534, 576357, 117695, 11484, 70, 117510, 11478, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6039232, 587843, 116455, 11363, 70, 116270, 11357, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6155690, 599208, 116394, 11380, 70, 116209, 11374, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6272087, 610590, 117555, 11454, 70, 117370, 11448, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6389645, 622046, 117303, 11455, 70, 117118, 11449, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6506951, 633503, 115944, 11333, 70, 115759, 11327, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6622898, 644838, 115134, 11224, 70, 114949, 11218, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6738035, 656064, 116712, 11386, 70, 116527, 11380, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6854750, 667452, 116983, 11415, 70, 116798, 11409, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6971736, 678869, 116606, 11387, 70, 116421, 11381, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7088345, 690258, 119120, 11583, 70, 118935, 11577, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7207468, 701843, 117206, 11449, 70, 117021, 11443, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7324677, 713294, 116140, 11377, 70, 115955, 11371, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7440820, 724673, 115900, 11315, 70, 115715, 11309, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7556723, 735990, 117340, 11426, 70, 117155, 11420, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7674066, 747418, 116282, 11360, 70, 116097, 11354, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7790351, 758780, 117735, 11460, 70, 117550, 11454, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7908089, 770242, 116735, 11400, 70, 116550, 11394, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8024827, 781644, 115757, 11313, 70, 115572, 11307, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8140587, 792959, 116560, 11385, 70, 116375, 11379, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8257150, 804346, 117240, 11420, 70, 117055, 11414, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8374393, 815768, 117508, 11451, 70, 117323, 11445, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8491904, 827221, 118255, 11514, 70, 118070, 11508, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8610162, 838737, 115607, 11298, 70, 115422, 11292, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8725772, 850037, 115510, 11279, 70, 115325, 11273, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8841285, 861318, 113161, 11084, 70, 112976, 11078, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8954449, 872404, 116732, 11389, 70, 116547, 11383, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9071184, 883795, 118129, 11494, 70, 117944, 11488, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9189316, 895291, 118015, 11499, 70, 117830, 11493, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9307334, 906792, 117451, 11431, 70, 117266, 11425, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9424788, 918225, 116026, 11332, 70, 115841, 11326, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9540817, 929559, 116740, 11409, 70, 116555, 11403, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9657560, 940970, 117956, 11509, 70, 117771, 11503, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9775519, 952481, 117528, 11473, 70, 117343, 11467, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9893050, 963956, 116641, 11371, 70, 116456, 11365, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10009694, 975329, 116903, 11396, 70, 116718, 11390, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10126600, 986727, 116417, 11365, 70, 116232, 11359, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10243020, 998094, 116669, 11393, 70, 116484, 11387, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10359692, 1009489, 115586, 11321, 70, 115401, 11315, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10475281, 1020812, 115937, 11341, 70, 115752, 11335, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10591221, 1032155, 116182, 11336, 70, 115997, 11330, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10707406, 1043493, 116987, 11405, 70, 116802, 11399, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10824396, 1054900, 116473, 11364, 70, 116288, 11358, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[10940872, 1066266, 115658, 11287, 70, 115473, 11281, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11056533, 1077555, 116706, 11410, 70, 116521, 11404, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11173242, 1088967, 117133, 11431, 70, 116948, 11425, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11290378, 1100400, 117157, 11438, 70, 116972, 11432, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11407538, 1111840, 116754, 11404, 70, 116569, 11398, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11524295, 1123246, 115106, 11260, 70, 114921, 11254, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11639404, 1134508, 116452, 11383, 70, 116267, 11377, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11755859, 1145893, 116061, 11364, 70, 115876, 11358, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11871923, 1157259, 117933, 11488, 70, 117748, 11482, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[11989859, 1168749, 118013, 11492, 70, 117828, 11486, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12107875, 1180243, 116362, 11339, 70, 116177, 11333, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12224240, 1191584, 117195, 11435, 70, 117010, 11429, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12341438, 1203021, 116749, 11377, 70, 116564, 11371, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12458190, 1214400, 117673, 11454, 70, 117488, 11448, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12575866, 1225856, 117986, 11494, 70, 117801, 11488, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12693855, 1237352, 117280, 11438, 70, 117095, 11432, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12811138, 1248792, 117334, 11451, 70, 117149, 11445, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[12928475, 1260245, 115802, 11293, 70, 115617, 11287, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13044280, 1271540, 116753, 11390, 70, 116568, 11384, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13161036, 1282932, 117286, 11454, 70, 117101, 11448, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13278325, 1294388, 116849, 11403, 70, 116664, 11397, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13395177, 1305793, 117389, 11439, 70, 117204, 11433, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13512569, 1317234, 116146, 11351, 70, 115961, 11345, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13628718, 1328587, 115618, 11298, 70, 115433, 11292, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13744339, 1339887, 117787, 11460, 70, 117602, 11454, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13862129, 1351349, 116926, 11414, 70, 116741, 11408, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[13979058, 1362765, 116808, 11403, 70, 116623, 11397, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14095869, 1374170, 116266, 11364, 70, 116081, 11358, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14212138, 1385536, 116723, 11408, 70, 116538, 11402, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14328864, 1396946, 115659, 11291, 70, 115474, 11285, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14444526, 1408239, 116629, 11390, 70, 116444, 11384, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14561158, 1419631, 116996, 11429, 70, 116811, 11423, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14678157, 1431062, 117767, 11487, 70, 117582, 11481, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14795927, 1442551, 116640, 11381, 70, 116455, 11375, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[14912570, 1453934, 118711, 11547, 70, 118526, 11541, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15031284, 1465483, 115904, 11319, 70, 115719, 11313, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15147191, 1476804, 116902, 11392, 70, 116717, 11386, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15264096, 1488198, 117454, 11436, 70, 117269, 11430, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15381553, 1499636, 116136, 11345, 70, 115951, 11339, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15497692, 1510983, 115945, 11333, 70, 115760, 11327, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15613640, 1522318, 117452, 11443, 70, 117267, 11437, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15731095, 1533763, 116421, 11352, 70, 116236, 11346, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15847519, 1545117, 116478, 11398, 70, 116293, 11392, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[15964000, 1556517, 116238, 11337, 70, 116053, 11331, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16080241, 1567856, 117074, 11426, 70, 116889, 11420, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16197318, 1579284, 116904, 11414, 70, 116719, 11408, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16314225, 1590700, 117317, 11422, 70, 117132, 11416, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16431545, 1602124, 115445, 11284, 70, 115260, 11278, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16546993, 1613410, 115580, 11283, 70, 115395, 11277, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16662576, 1624695, 117316, 11446, 70, 117131, 11440, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16779895, 1636143, 117783, 11473, 70, 117598, 11467, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[16897681, 1647618, 115938, 11323, 70, 115753, 11317, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17013622, 1658943, 115946, 11318, 70, 115761, 11312, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17129571, 1670263, 117308, 11439, 70, 117123, 11433, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17246882, 1681704, 116612, 11380, 70, 116427, 11374, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17363497, 1693086, 116939, 11430, 70, 116754, 11424, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17480439, 1704518, 117363, 11465, 70, 117178, 11459, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Closed]]
}, Open  ]],
Cell[17597823, 1715985, 2366, 75, 70, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17600239, 1716062, 96, 2, 70, "Section",
  Evaluatable->False],
Cell[17600338, 1716066, 2850, 81, 70, "Text",
  Evaluatable->False],
Cell[17603191, 1716149, 1711, 23, 70, "Input"],

Cell[CellGroupData[{
Cell[17604925, 1716174, 81, 1, 70, "Input"],

Cell[CellGroupData[{
Cell[17605029, 1716177, 115963, 11334, 70, 115805, 11329, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17720995, 1727513, 116441, 11367, 70, 116283, 11362, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17837439, 1738882, 116921, 11412, 70, 116763, 11407, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[17954363, 1750296, 117213, 11428, 70, 117055, 11423, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18071579, 1761726, 117437, 11455, 70, 117279, 11450, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18189019, 1773183, 117073, 11427, 70, 116915, 11422, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18306095, 1784612, 116544, 11399, 70, 116386, 11394, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18422642, 1796013, 117424, 11460, 70, 117266, 11455, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18540069, 1807475, 117672, 11475, 70, 117514, 11470, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18657744, 1818952, 115969, 11334, 70, 115811, 11329, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[18773716, 1830288, 116439, 11367, 70, 116281, 11362, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Closed]]
}, Open  ]],
Cell[18890176, 1841657, 5773, 205, 70, "Text",
  Evaluatable->False],
Cell[18895952, 1841864, 1410, 50, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18897385, 1841916, 99, 2, 70, "Subsubsection",
  Evaluatable->False],
Cell[18897487, 1841920, 136, 3, 70, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
